/**
 * Copyright 2000 Systemcorp - All rights reserved. Made in Canada.
 *
 * Description:
 *
 * Author: Tudor Toma
 * Revision: 42
 * Date: 7/31/00 6:18p
 *
 **/
/*
#Stored Procedure  :SP_SEARCH_2
#Short Description :Search and Assign a resource or profile to a element.
#Description       :Search or Search and Assign a resource or profile with effort to a WBS or CRI element.
				   :If search/assign a participant (without effort) all effort related parameters are not required.
				   :Search criteria is a sum of input parameters, witch tells how to filter out the result set.
				   :This function gets called from RPM client, Import and Level/Calculate.
RULE1: cannot assign more then once a resource to a element.
RULE2: cannot assign a resource to a project if the resource is already assigned to a task whitin the project.
RULE3: cannot assign to a task from project reserve more effort then remaining effort at the project.
RULE4: if bitflag = 9 then assignment without effort, otherwise assignment with effort.
RULE5: if bitflag between 1 and 8 the assignment is contoured: contour > 0 and work > 0
RULE6: if search by name then partially ignore the search criteria: org_id, geo_id, pool_id, work_loc, and_roles, and_skills, shw_roles, shw_skills
RULE7: if effort = 0 and bitflag < 9 then both start  finish dates are required
RULE8: if assign units <> 100%, then bitflag < 9 and effort > 0 and both start  finish dates are required
RULE9: cannot assign a resource if is not active, effective date is in the future or discontinue date is in the past
#Table Name        :
#Parameters        :
 $$bitflag  = 0 - ASP ---------------------------------------------------------------------------------------------
            = 1 - Daily         -- contour3
            = 2 - Weekly        -- contour3{, contur1}, {amount falg}
            = 3 - Monthly(C)    -- contour3{, contur2}
            = 4 - Monthly(B)    -- contour3{, contur2}
            = 5 - Monthly(A)    -- contour3{, contur2 | contour2  countour1}
            = 6 - Yearly(C)     -- contour2, contur4
            = 7 - Yearly(B)     -- contour2, contur4, contur1(only one day)
            = 8 - Yearly(A)     -- contour2, contur4, contur1(many days)
            = 9 - Participant
 $$contour (contour structure) ------------------------------------------------------------------------------------
  contur1:  DAY:    bits 0-6    0 = Su, 1 = Mo, 2 = Tu, 3 = We, 4 = Th, 5 = Fr, 6 = Sa,
  contur2:  WEEK:   bits 7-11   A) 7 = week1, 8 = week2, 8 = week3, 9 = week4
                                B) 1-First/2-Second/3-Third/4-Fourth/5-Last
                                C) The Day 1 to 31
  contour3:     EVRY:   bits 12-16  EVRY 1 to 31 day / week / month
  contour4:     MONTH:  bits 17-28  17 = Jan, 18 = Feb, ... 28 = Dec
  2 2 2 2 2 2 2 2 2 1 1 1 1 1 1 1 1 1 1
  8 7 6 5 4 3 2 1 0 9 8 7 6 5 4 3 2 1 0 9 8 7 6 5 4 3 2 1 0
                                                S F T W T M S
                                      w1 to w4  A(7 days from the 1st)
                                      5 4 3 2 1 B(Last, Fourth, Third, Second, First)
                                      31 .... 1 C(The Day 6)
                            31 ........ 1 (Day)
                            31 ........ 1 (week)
                            12 ........ 1 (month)
  D N O S A J J M A M F J (Month)
  Exemple:
  2 2 2 2 2 2 2 2 2 2 1 1 1 1 1 1 1 1 1 1 
  9 8 7 6 5 4 3 2 1 0 9 8 7 6 5 4 3 2 1 0 9 8 7 6 5 4 3 2 1 0 
                                      5-4-3-2-1               B) 1-First/2-Second/3-Third/4-Fourth/5-Last
  X D N O S A J J M A M F J --EVERY-- -THE-DAY- S F T W T M S C) The Day 1 to 31
  0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 = 4096      1 (every day) 	
  0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 = 8192      1 (every 2nd day) 
  0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 1 0 0 0 0 0 0 0 0 0 0 0 0 0 = 12288     1 (every 3rd day) 
  1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 1 0 = 536875014 2 (Monday, Tuesday, every week)	
  0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 1 0 = 4102      2 (Monday, Tuesday, every week)	
  0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0 0 0 0 0 0 0 0 1 1 0 = 8198      2 (Monday, Monday, every 2nd week)	
  0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 1 0 0 0 0 0 0 0 0 = 4864      3 (6th day of every month)
  0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0 0 0 1 0 0 0 0 0 1 0 = 8322      4 (1st Monday of every 2nd month)	
  0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0 0 0 0 0 = 4224      5 (week1 of every month)	
  0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 1 0 0 0 0 0 0 0 = 4480      5 (week1, week2 of every month)	
  0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0 0 1 1 0 0 0 0 0 0 0 = 8576      5 (week1, week2 of every 2nd month)
  0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0 0 1 0 0 0 0 0 1 1 0 = 8454      5 (Monday, Tuesday, week2 every 2nd month)	
  1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0 0 1 0 0 0 0 0 1 1 0 = 536879366 5 (Monday, Tuesday, week2 every 2nd month)	
  0 1 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 1 0 0 0 0 0 0 0 0 = 301990656 6 (6th day of month 9, 12)	
  0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0 0 0 0 1 0 = 301990146 7 (1st Monday of month 1, 2)	
  0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0 1 0 0 0 0 0 1 0 0 = 4356      7 (2nd Tuesday, every month)	
  0 1 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 1 0 0 0 0 1 1 0 = 301990534 8 (Monday, Tuesday; week1, week3 of month 9, 12)	
  1 1 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 1 0 0 0 0 1 1 0 = 838861446 8 (Monday, Tuesday; week1, week3 of month 9, 12)	
 $$consider_planned_sched ------------------------------------------------------------------------------------------
  CONSIDER                                              inner current project   outer current project   all projects
  scheduled                                                         1                   2                   3
  scheduled  planned                                               4                   5                   6
  NONE(consider all available time)                                 7
  scheduled outer current project				                                        13                  14
  scheduled  planned outer current project				                                15                  16
  scheduled outer current project  planned all projects            20
  scheduled outer current project  planned inner current project   21
  scheduled all projects    planned outer current project          22
  planned inner current project                                     24
  search from project assignments		= 10  pool_id   = resource_id
  search create new profile				= 12  and_roles = the first role_id is used to create a new profile
  duplicate profile						= 12  pool_id   = profile_id
  Note: bits 30 - 31 (in addition to above values): Consider All Scop Element Exceptions = 1 consider, 0 don't consider
  $$eunit, applies to effort
		= 0 MINUTE (default), 
		= 1 h, 
		= 2 d, 
		= 3 w
  $$unit, applies to work
		= 0 h/d,
		= 3 h/w, 
		= 4 h/m, 
		= 1 d/w, 
		= 2 d/m, 
		= 5 w/m
		= 100 then work = percent units
#Returns           :Result Set of resource(s), Best Start date, Best Finish date and daly contour (5*480,2*0,3*400,...) 
				   :For search the number of rows depends on search criteria and is limited by max_rows parameter.
				   :For search/assign is always only one row, the resource whith has been assigned
#Errors            :The errors are returned only in search/assign
				   : TASK_ASSIGNMENT_ERROR (200062) - many reasons the assignment failed.
				   : CHILD_TASK_ASSIGNMENT_ALREADY_EXISTS (20083) - violation of RULE2
				   : CANNOT_ASSIGN_FROM_PROJECT_AFFECTED (20085) - violation of RULE3
				   : RESOURCE_NOT_ACTIVE (200019) - violation of RULE9
				   : F_DATE_EARLIER_THAN_S_DATE - finish date is earlier then start date
				   : 200220 - violation of RULE7
*/
Prompt == FUNCTION SP_SEARCH_2 ==
CREATE OR REPLACE FUNCTION SP_SEARCH_2 wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
2ed
2 :e:
1FUNCTION:
1SP_SEARCH_2:
1PRJ_ID:
1VARCHAR2:
1START_DATE001:
1FINISH_DATE001:
1EFFORT001:
1PLS_INTEGER:
1WORK001:
1BITFLAG001:
1EUNIT:
1UNIT:
1CONTOUR001:
1OCCURRENCE:
1CONSIDER_PLANNED_SCHED:
1FNAME:
1COST001:
1ORG_ID001:
1GEO_ID001:
1POOL_ID001:
1WORK_LOCATION001:
1AND_ROLES:
1AND_SKILLS:
1SHW_ROLES:
1SHW_SKILLS:
1MAX_ROWS:
1P_UPDATE:
1WORK_TYPE:
1P_TYPE:
1LAST_ID:
1REC_USER001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_WBS_ID:
132:
1H_PROJECT_ID:
1H_TASK_ID:
1H_RS_ID:
1H_UNIQUEID:
1H_REC_USER:
1H_FNAME:
1255:
1H_COST:
110:
1H_AND_ROLES:
18000:
1H_AND_SKILLS:
1H_SHW_ROLES:
1H_SHW_SKILLS:
1H_AND_ROLE:
1H_AND_SKILL:
1H_SHW_ROLE:
1H_SHW_SKILL:
1H_SOURCE_IDS:
1H_TARGET_IDS:
1H_RES_ID:
1H_LAST_ID:
1H_RANK:
1200:
1H_DAYOFYEAR:
1DATE:
1H_START_DATE:
126:
1H_START_DT:
1H_FINISH_DT:
1H_TASK_START_DT:
1H_TASK_FINISH_DT:
1H_RES_TYPE:
11:
1H_ASSIGN_ID:
1H_ROLE_ID:
1H_SKILL_ID:
1H_FULL_NAME:
1H_REC_STATUS:
1H_BITFLAG:
10:
1H_EXISTS:
1H_TYPE:
1H_COUNT:
1H_UPDATE:
1H_WORK_TYPE:
1H_WORK_LOCATION:
1H_CRI:
1H_MAX_ROWS:
1H_WORK:
1H_OCCURRENCE:
1H_EFFORT:
1H_EUNIT:
1H_UNIT:
1H_CONSIDER:
1H_CONTOUR:
1H_EVERY:
1H_PER_DAY:
1H_PER_WEEK:
1H_DURATION:
1H_BIT_MINUTES:
1H_NUMBER:
1H_PRIORITY:
1H_DAYS:
1H_RES_COST:
1NUMBER:
10.00:
1H_RATE_ECHANGE:
1H_TOTAL:
1H_POOL_TYPE:
1H_CURRENCY_ID:
1H_JULIAN_DAY:
1H_J_EFECTIVE_DATE:
1H_J_DISCONTI_DATE:
1H_WEEK:
1H_ACTIVE:
1H_TASK_TYPE:
1H_SCHED_WORK:
1H_PARTICIPANT:
1STMT:
17999:
1STWHERE:
12999:
1H_TEMP_STMT:
1H_TABLE_TYPE:
1H_TEMP_PARTICIPANT:
1H_TEMP_SECURITY_ID:
1CHAR:
1H_TEMP2_SECURITY_ID:
1H_PROFILE_ID:
1H_RESOURCE_ID:
1H_CRI_SECURITY_ID:
1H_CHAR:
1H_TEMP_VAR:
1H_TEMP_BITFLAG:
1H_TEMP_SC_STATE:
1I:
1II:
1I_ROW:
1I_RETURN:
1ISF:
1TOKEN:
1I_NOSKILL:
1NUMITEMS:
1BCREATEPROFILE:
1LEN:
1K:
1NLEN:
1NLEN001:
1NLEN002:
1C12:
1CURSOR:
1C42:
1PROJECT_ASSIGNMENT_ID:
1TASK_ASSIGNMENTS:
1PROJECT_ID:
1TASK_ID:
1RESOURCE_ID:
1SELECT PROJECT_ASSIGNMENT_ID:n         FROM TASK_ASSIGNMENTS:n         WHERE +
1PROJECT_ID = h_project_id:n         AND TASK_ID = h_project_id:n         AND +
1RESOURCE_ID = h_res_id:
1CU42:
1RS_ID:
1RES_ID:
1RTRIM:
1ROLE_ID:
1COALESCE:
1ROLE_NAME:
1SKILL_ID:
1SKILL_NAME:
1SHOW_ROLE:
1SHOW_SKILL:
1PMO_TMP_SEARCH:
1SELECT:n         RS_ID:n         , RES_ID:n         , RTRIM(ROLE_ID):n       +
1  , COALESCE(ROLE_NAME , ''):n         , RTRIM(SKILL_ID):n         , COALESCE+
1(SKILL_NAME , ''):n         , COALESCE(SHOW_ROLE , ''):n         , COALESCE(S+
1HOW_SKILL , ''):n         FROM PMO_TMP_SEARCH:n         ORDER BY RES_ID:
1C775C0:
1C775E1:
1C775E0:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_SEARCH_2(:
1':
1, :
1TO_CHAR:
1NULL:
1);:
1CHECK_TRACE:
1196:
1+:
1FPUT:
1               ENTER:: SP_SEARCH_2(197) :: cplan.sql(343) :: :
1PMO_CNST:
1!=:
1SC_SRCH_PARTICIPANT:
1IS NULL:
18:
1239:
1      RETURN_INVALID:: SP_SEARCH_2(240) :: cplan.sql(386) :: :
1 :
1STATE:: :
1ELEMENT_ID_REQUIRED:
1242:
1                EXIT:: SP_SEARCH_2(243) :: cplan.sql(389) :: :
1PMODEFINES:
1PMO_RETURN_INVALID_SP:
1TRUE:
1SC_SRCH_FROM_PROJECT:
1=:
1SC_SRCH_PROFILE:
1251:
1      RETURN_INVALID:: SP_SEARCH_2(252) :: cplan.sql(398) :: :
1INVALID_PARAMS:
1254:
1                EXIT:: SP_SEARCH_2(255) :: cplan.sql(401) :: :
1ELSIF:
1259:
1      RETURN_INVALID:: SP_SEARCH_2(260) :: cplan.sql(406) :: :
1262:
1                EXIT:: SP_SEARCH_2(263) :: cplan.sql(409) :: :
15:
1282:
1      RETURN_INVALID:: SP_SEARCH_2(283) :: cplan.sql(429) :: :
1285:
1                EXIT:: SP_SEARCH_2(286) :: cplan.sql(432) :: :
1265:
1IS NOT NULL:
1PMO_ORASTD:
1DAYS:
1DUAL:
1SELECT PMO_ORASTD.DAYS(finish_date001) - PMO_ORASTD.DAYS(start_date001):n    +
1     INTO h_total:n         FROM DUAL:
1SC_STATE:
1SQLCODE:
1OTHERS:
116:
1309:
1           EXCEPTION:: SP_SEARCH_2(310) :: cplan.sql(456) :: :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1SC_SQL_SUCCESS:
1<:
1316:
1      RETURN_INVALID:: SP_SEARCH_2(317) :: cplan.sql(463) :: :
1F_DATE_EARLIER_THAN_S_DATE:
1319:
1                EXIT:: SP_SEARCH_2(320) :: cplan.sql(466) :: :
1SELECT SYSTIMESTAMP INTO h_start_date FROM DUAL:
1335:
1           EXCEPTION:: SP_SEARCH_2(336) :: cplan.sql(482) :: :
1PMO_FUNC:
1SHIFTRIGHT:
1BITAND:
1SC_C0000000:
130:
1SC_1FFFFFFF:
1>:
1LEVEL_LOCK:
1PROJECT_DETAILS:
1SELECT LEVEL_LOCK INTO h_temp_var:n         FROM PROJECT_DETAILS:n         WH+
1ERE PROJECT_ID = h_project_id:
1367:
1           EXCEPTION:: SP_SEARCH_2(368) :: cplan.sql(514) :: :
1REC_STATUS:
1TMT_WBS:
1ELEMENT_ID:
1SELECT REC_STATUS INTO h_rec_status:n            FROM TMT_WBS:n            WH+
1ERE ELEMENT_ID = h_project_id:
1383:
1           EXCEPTION:: SP_SEARCH_2(384) :: cplan.sql(530) :: :
1STRCMP:
1L:
1390:
1        RETURN_ERROR:: SP_SEARCH_2(391) :: cplan.sql(537) :: :
1LEV_LOCKED_BY_COPY:
1 ID:: :
1393:
1                EXIT:: SP_SEARCH_2(394) :: cplan.sql(540) :: :
1PMO_RETURN_ERROR_SP:
1GETTABLE:
1GETASSNTYPE:
1404:
1      RETURN_INVALID:: SP_SEARCH_2(405) :: cplan.sql(551) :: :
1407:
1                EXIT:: SP_SEARCH_2(408) :: cplan.sql(554) :: :
1SC_TABLE_WBS:
1420:
1      RETURN_INVALID:: SP_SEARCH_2(421) :: cplan.sql(567) :: :
1423:
1                EXIT:: SP_SEARCH_2(424) :: cplan.sql(570) :: :
1ASSIGNRESOURCE:
1438:
1        RETURN_ERROR:: SP_SEARCH_2(439) :: cplan.sql(585) :: :
1441:
1                EXIT:: SP_SEARCH_2(442) :: cplan.sql(588) :: :
1447:
1        RETURN_ERROR:: SP_SEARCH_2(448) :: cplan.sql(594) :: :
1450:
1                EXIT:: SP_SEARCH_2(451) :: cplan.sql(597) :: :
1ISPROJECTTYPE:
1MINUTE_PER_DAY:
1MINUTE_PER_WEEK:
1PRIORITY:
1SELECT:n               PROJECT_ID:n               , COALESCE(MINUTE_PER_DAY, +
1480):n               , COALESCE(MINUTE_PER_WEEK, 2400):n               , PRIO+
1RITY:n               INTO:n               h_project_id:n               , h_pe+
1r_day:n               , h_per_week:n               , h_priority:n            +
1   FROM TMT_WBS:n               WHERE ELEMENT_ID = h_task_id:
1476:
1           EXCEPTION:: SP_SEARCH_2(477) :: cplan.sql(623) :: :
1B:
1TASK_TYPE:
1UNRESOLVED_START:
1UNRESOLVED_FINISH:
1A:
1PLANNED_EFFORT:
1SCHED_EFFORT:
1SELECT:n               B.TASK_TYPE:n               , B.UNRESOLVED_START:n    +
1           , B.UNRESOLVED_FINISH:n               , B.PROJECT_ID:n            +
1   , COALESCE(A.MINUTE_PER_DAY, 480):n               , COALESCE(A.MINUTE_PER_+
1WEEK, 2400):n               , A.PRIORITY:n               , B.PLANNED_EFFORT ++
1 B.SCHED_EFFORT:n               INTO:n               h_task_type:n           +
1    , h_task_start_DT:n               , h_task_finish_DT:n               , h_+
1project_id:n               , h_per_day:n               , h_per_week:n        +
1       , h_priority:n               , h_sched_work:n               FROM TMT_W+
1BS A, TMT_WBS B:n               WHERE B.ELEMENT_ID = h_task_id:n             +
1  AND A.ELEMENT_ID = B.PROJECT_ID:
1509:
1           EXCEPTION:: SP_SEARCH_2(510) :: cplan.sql(656) :: :
1517:
1        RETURN_ERROR:: SP_SEARCH_2(518) :: cplan.sql(664) :: :
1RECORD_NOT_FOUND:
1520:
1                EXIT:: SP_SEARCH_2(521) :: cplan.sql(667) :: :
1SC_TABLE_CRI:
1TYPE_ID:
1WBS_ID:
1TMT_CRI:
1SELECT:n            PROJECT_ID:n            , TYPE_ID:n            , WBS_ID:n+
1            INTO:n            h_project_id:n            , h_type:n           +
1 , h_wbs_id:n            FROM TMT_CRI:n            WHERE ELEMENT_ID = h_task_+
1id:
1542:
1           EXCEPTION:: SP_SEARCH_2(543) :: cplan.sql(689) :: :
1549:
1        RETURN_ERROR:: SP_SEARCH_2(550) :: cplan.sql(696) :: :
1552:
1                EXIT:: SP_SEARCH_2(553) :: cplan.sql(699) :: :
1START_DT:
1TO_TIMESTAMP:
1SELECT:n            CASE:n            WHEN START_DT > h_start_DT:n           +
1 THEN START_DT:n            ELSE TO_TIMESTAMP(h_start_DT):n            END:n +
1           , COALESCE(MINUTE_PER_DAY, 480):n            , COALESCE(MINUTE_PER+
1_WEEK, 2400):n            , PRIORITY:n            INTO:n            h_start_D+
1T:n            , h_per_day:n            , h_per_week:n            , h_priorit+
1y:n            FROM TMT_WBS:n            WHERE PROJECT_ID = h_project_id:n   +
1         AND ELEMENT_ID = h_project_id:
1583:
1           EXCEPTION:: SP_SEARCH_2(584) :: cplan.sql(730) :: :
1590:
1        RETURN_ERROR:: SP_SEARCH_2(591) :: cplan.sql(737) :: :
1593:
1                EXIT:: SP_SEARCH_2(594) :: cplan.sql(740) :: :
1FC_MIRROR_TYPE:
1608:
1        RETURN_ERROR:: SP_SEARCH_2(609) :: cplan.sql(755) :: :
1611:
1                EXIT:: SP_SEARCH_2(612) :: cplan.sql(758) :: :
1NICK_NAME:
1JULIAN_DAY:
1ACTIVE:
1EFFECTIVE_DATE:
1DISCONTINUE_DATE:
1RESOURCES:
1SELECT:n            NICK_NAME:n            , PMO_ORASTD.JULIAN_DAY(h_start_DT+
1):n            , ACTIVE:n            , COALESCE(PMO_ORASTD.JULIAN_DAY(EFFECTI+
1VE_DATE) ,0):n            , COALESCE(PMO_ORASTD.JULIAN_DAY(DISCONTINUE_DATE) +
1,0):n            INTO:n            h_full_name:n            , h_julian_day:n +
1           , h_active:n            , h_j_efective_date:n            , h_j_dis+
1conti_date:n            FROM RESOURCES:n            WHERE RESOURCE_ID = h_res+
1_id:
1640:
1           EXCEPTION:: SP_SEARCH_2(641) :: cplan.sql(787) :: :
1SC_SQL_NO_DATA:
1647:
1        RETURN_ERROR:: SP_SEARCH_2(648) :: cplan.sql(794) :: :
1650:
1                EXIT:: SP_SEARCH_2(651) :: cplan.sql(797) :: :
1658:
1        RETURN_ERROR:: SP_SEARCH_2(659) :: cplan.sql(805) :: :
1RESOURCE_NOT_ACTIVE:
1661:
1                EXIT:: SP_SEARCH_2(662) :: cplan.sql(808) :: :
1680:
1        RETURN_ERROR:: SP_SEARCH_2(681) :: cplan.sql(827) :: :
1CANNOT_ASSIGN_COMPETENCY:
1683:
1                EXIT:: SP_SEARCH_2(684) :: cplan.sql(830) :: :
1SELECT:n            PRIORITY:n            , COALESCE(MINUTE_PER_DAY, 480):n  +
1          , COALESCE(MINUTE_PER_WEEK, 2400):n            INTO:n            h_+
1priority:n            , h_per_day:n            , h_per_week:n            FROM+
1 TMT_WBS:n            WHERE ELEMENT_ID = h_project_id:
1708:
1           EXCEPTION:: SP_SEARCH_2(709) :: cplan.sql(855) :: :
1TMT_POOLS:
1SELECT:n               480:n               , 2400:n               INTO:n     +
1          h_per_day:n               , h_per_week:n               FROM TMT_POO+
1LS WHERE ELEMENT_ID = h_project_id:
1730:
1           EXCEPTION:: SP_SEARCH_2(731) :: cplan.sql(877) :: :
1737:
1        RETURN_ERROR:: SP_SEARCH_2(738) :: cplan.sql(884) :: :
1740:
1                EXIT:: SP_SEARCH_2(741) :: cplan.sql(887) :: :
1100:
11899-12-31 00::00::00:
1:
1FC_CALC_DURATION:
1777:
1      RETURN_INVALID:: SP_SEARCH_2(778) :: cplan.sql(924) :: :
1780:
1                EXIT:: SP_SEARCH_2(781) :: cplan.sql(927) :: :
1785:
1        RETURN_ERROR:: SP_SEARCH_2(786) :: cplan.sql(932) :: :
1788:
1                EXIT:: SP_SEARCH_2(789) :: cplan.sql(935) :: :
12:
13:
14:
1SYS_GUID:
1PROFILES:
1PROFILE_ID:
1SELECT REC_STATUS INTO h_rec_status:n            FROM PROFILES:n            W+
1HERE PROFILE_ID = h_res_id:
1843:
1           EXCEPTION:: SP_SEARCH_2(844) :: cplan.sql(990) :: :
1RES_ASSIGNMENT_ID:
1RESOURCE_ASSIGNMENTS:
1RESOURCE_TYPE:
1PARTICIPANT:
1SC_TEAMMEMBER:
1SELECT:n                  RES_ASSIGNMENT_ID:n                  INTO:n        +
1          h_uniqueID:n                  FROM RESOURCE_ASSIGNMENTS:n          +
1        WHERE ELEMENT_ID = h_task_id:n                  AND RESOURCE_ID = h_r+
1es_id:n                  AND RESOURCE_TYPE = '1':n                  AND PARTI+
1CIPANT = PMO_CNST.SC_TEAMMEMBER:
1866:
1           EXCEPTION:: SP_SEARCH_2(867) :: cplan.sql(1013) :: :
1MAX:
1PROF_NUMBER:
1SELECT:n            COALESCE(MAX(PROF_NUMBER),0)+1:n            INTO:n       +
1     h_number:n            FROM PROFILES:n            WHERE PROJECT_ID=h_proj+
1ect_id:n            AND ROLE_ID=h_role_id:
1895:
1           EXCEPTION:: SP_SEARCH_2(896) :: cplan.sql(1042) :: :
1STRINGCONCAT:
1TCP:
1ELEMENT_NAME:
1TC:
1TMT_COMPETENCIES:
1PARENT_ID:
1SELECT:n            PMO_ORASTD.StringConcat(PMO_ORASTD.StringConcat(PMO_ORAST+
1D.StringConcat(PMO_ORASTD.StringConcat(PMO_ORASTD.StringConcat(RTRIM(TCP.ELEM+
1ENT_NAME):n            , ', '), RTRIM(TC.ELEMENT_NAME)), '('), RTRIM(TO_CHAR(+
1h_number))), ')'):n            INTO h_full_name:n            FROM TMT_COMPETE+
1NCIES TC, TMT_COMPETENCIES TCP:n            WHERE TC.ELEMENT_ID = h_role_id:n+
1            AND TCP.ELEMENT_ID = TC.PARENT_ID:
1914:
1           EXCEPTION:: SP_SEARCH_2(915) :: cplan.sql(1061) :: :
1921:
1        RETURN_ERROR:: SP_SEARCH_2(922) :: cplan.sql(1068) :: :
1924:
1                EXIT:: SP_SEARCH_2(925) :: cplan.sql(1071) :: :
1U:
1D:
1PROFILE_NAME:
1POOL_ID:
1GEO_ID:
1ORG_ID:
1INSERT INTO PROFILES:n            (:n            PROFILE_ID:n            , PR+
1OJECT_ID:n            , ROLE_ID:n            , PROF_NUMBER:n            , PRO+
1FILE_NAME:n            , REC_STATUS:n            , POOL_ID:n            , GEO+
1_ID:n            , ORG_ID:n            ):n            VALUES:n            (:n+
1            h_res_id:n            , h_project_id:n            , h_role_id:n  +
1          , h_number:n            , h_full_name:n            , h_char:n      +
1      , pool_id001:n            , geo_id001:n            , org_id001:n       +
1     ):
1FOUND:
1966:
1           EXCEPTION:: SP_SEARCH_2(967) :: cplan.sql(1113) :: :
1UPDATE PROFILES SET REC_STATUS = 'U',:n            POOL_ID = pool_id001,:n   +
1         GEO_ID  = geo_id001,:n            ORG_ID  = org_id001:n            W+
1HERE PROFILE_ID = h_res_id:
1989:
1           EXCEPTION:: SP_SEARCH_2(990) :: cplan.sql(1136) :: :
1RESOURCE_ASSIGN_SKILLS:
1DELETE FROM RESOURCE_ASSIGN_SKILLS:n         WHERE RES_ASSIGNMENT_ID IN (:n  +
1       SELECT PROFILE_ID:n         FROM PROFILES:n         WHERE PROJECT_ID =+
1 h_project_id:n         AND REC_STATUS='D':n         AND PROFILE_ID <> h_res_+
1id):
11015:
1           EXCEPTION:: SP_SEARCH_2(1016) :: cplan.sql(1162) :: :
1RESOURCE_ASSIGN_ROLES:
1DELETE FROM RESOURCE_ASSIGN_ROLES:n         WHERE RES_ASSIGNMENT_ID IN (:n   +
1      SELECT PROFILE_ID:n         FROM PROFILES:n         WHERE PROJECT_ID = +
1h_project_id:n         AND REC_STATUS='D':n         AND PROFILE_ID <> h_res_i+
1d):
11038:
1           EXCEPTION:: SP_SEARCH_2(1039) :: cplan.sql(1185) :: :
1DELETE FROM PROFILES:n         WHERE PROJECT_ID = h_project_id:n         AND +
1REC_STATUS='D':n         AND PROFILE_ID <> h_res_id:
11058:
1           EXCEPTION:: SP_SEARCH_2(1059) :: cplan.sql(1205) :: :
1FC_DECLARE_PMO_TMP_SEARCH:
1SC_MAX_ROWS:
1SELECT ':
1' AS RESOURCE_ID :
1FROM TMT_COMPETENCIES r :
1WHERE r.TYPE_ID=73 :
1      AND r.ELEMENT_ID = ':
1SELECT ra.RESOURCE_ID :
1FROM RESOURCE_ASSIGNMENTS ra :
1JOIN TASK_ASSIGNMENTS ta ON ra.ELEMENT_ID=':
1' :
1AND ra.RESOURCE_ID=':
1AND ra.RES_ASSIGNMENT_ID=ta.RES_ASSIGNMENT_ID :
1SELECT r.RESOURCE_ID :
1FROM RESOURCES r :
1WHERE r.CALENDAR_ID IS NOT NuLL :
1        AND r.RESOURCE_ID = ':
1EXECUTE:
1IMMEDIATE:
1DELETE FROM PMO_TMP_CPLN_0007:
1DELETE FROM PMO_TMP_CPLN_007a:
1PMO_TMP_CPLN_007A:
1RANK:
1PUBLIC_FLAG:
1P:
1JOIN:
1RA:
1ELEMENT_TYPE:
1INSERT INTO PMO_TMP_CPLN_007a:n               SELECT ELEMENT_ID, RANK:n      +
1         FROM TMT_POOLS:n               WHERE PUBLIC_FLAG = '1':n            +
1   UNION ALL:n               ---- All pools to which the resource is assigned+
1:n               SELECT P.ELEMENT_ID, P.RANK:n               FROM TMT_POOLS P+
1:n               JOIN RESOURCE_ASSIGNMENTS RA ON:n               P.ELEMENT_ID+
1 = RA.ELEMENT_ID:n               AND RA.ELEMENT_TYPE = 11:n               AND+
1 RA.RESOURCE_ID = h_rec_user:
11183:
1           EXCEPTION:: SP_SEARCH_2(1184) :: cplan.sql(1330) :: :
1PMO_TMP_CPLN_0007:
1M:
1LENGTH:
1INSERT INTO PMO_TMP_CPLN_0007:n               SELECT M.RANK:n               F+
1ROM PMO_TMP_CPLN_007a M:n               WHERE NOT EXISTS (:n               SE+
1LECT A.ELEMENT_ID:n               FROM PMO_TMP_CPLN_007a A:n               WH+
1ERE A.RANK < M.RANK:n               AND SUBSTR(M.RANK, 1, LENGTH(A.RANK)) = A+
1.RANK):
11209:
1           EXCEPTION:: SP_SEARCH_2(1210) :: cplan.sql(1356) :: :
132767:
165535:
1-:
165536:
1WHILE:
1LOOP:
1ASCII:
137:
195:
1EXIT:
11236:
1      RETURN_INVALID:: SP_SEARCH_2(1237) :: cplan.sql(1383) :: :
11239:
1                EXIT:: SP_SEARCH_2(1240) :: cplan.sql(1386) :: :
1REPLACE:
1SELECT REPLACE(h_fname,'''',''''''):n            INTO h_fname:n            FR+
1OM DUAL:
11254:
1           EXCEPTION:: SP_SEARCH_2(1255) :: cplan.sql(1401) :: :
1SELECT p.PROFILE_ID AS RESOURCE_ID FROM PROFILES p JOIN TMT_COMPETENCIES r ON+
1 p.ROLE_ID = r.ELEMENT_ID:
1 WHERE p.PROFILE_ID=':
1SELECT r.RESOURCE_ID FROM RESOURCES r JOIN RESOURCE_ASSIGNMENTS ra ON BITAND(+
1ra.PARTICIPANT,4096)>0 AND ra.ELEMENT_ID=':
1' AND ra.RESOURCE_ID=r.RESOURCE_ID:
1 WHERE 0=0 :
1SELECT DISTINCT r.RESOURCE_ID FROM RESOURCES r:
1 AND r.RESOURCE_ID > ':
1 AND r.CALENDAR_ID IS NOT NuLL :
1AND UPPER(r.FULL_NAME) like UPPER(':
1%'):
1SELECT r.RESOURCE_ID FROM RESOURCES r:
1SELECT DISTINCT r.RESOURCE_ID :
1FROM TMT_POOLS TP, PMO_TMP_CPLN_0007 MP, RESOURCES r:
1AND TP.ELEMENT_ID=R.RESOURCE_ID :
1  AND (MP.RANK >= SUBSTR(TP.RANK, 1, 8) :
1        AND MP.RANK <= TP.RANK :
1        AND length(MP.RANK) <= length(TP.RANK) :
1        AND substr(TP.RANK, 1, length(MP.RANK)) = MP.RANK) :
1  AND r.CALENDAR_ID IS NOT NuLL :
1  AND UPPER(r.FULL_NAME) LIKE UPPER(':
1SELECT RANK INTO h_rank:n               FROM TMT_POOLS:n               WHERE +
1ELEMENT_ID = pool_id001:
11337:
1           EXCEPTION:: SP_SEARCH_2(1338) :: cplan.sql(1484) :: :
1,TMT_POOLS p:
1 AND r.RESOURCE_ID = p.ELEMENT_ID :
1AND p.RANK LIKE ':
1%' :
11351:
1        RETURN_ERROR:: SP_SEARCH_2(1352) :: cplan.sql(1498) :: :
11354:
1                EXIT:: SP_SEARCH_2(1355) :: cplan.sql(1501) :: :
1TMT_ORGANIZATIONS:
1SELECT RANK INTO h_rank:n               FROM TMT_ORGANIZATIONS:n             +
1  WHERE ELEMENT_ID = org_id001:
11371:
1           EXCEPTION:: SP_SEARCH_2(1372) :: cplan.sql(1518) :: :
1,TMT_ORGANIZATIONS o:
1 AND r.RESOURCE_ID=o.ELEMENT_ID :
1AND o.RANK LIKE ':
11382:
1        RETURN_ERROR:: SP_SEARCH_2(1383) :: cplan.sql(1529) :: :
11385:
1                EXIT:: SP_SEARCH_2(1386) :: cplan.sql(1532) :: :
1TMT_GEOGRAPHIES:
1SELECT RANK INTO h_rank:n               FROM TMT_GEOGRAPHIES:n               +
1WHERE ELEMENT_ID = geo_id001:
11402:
1           EXCEPTION:: SP_SEARCH_2(1403) :: cplan.sql(1549) :: :
1,TMT_GEOGRAPHIES g:
1 AND r.RESOURCE_ID=g.ELEMENT_ID :
1AND g.RANK LIKE ':
11413:
1        RETURN_ERROR:: SP_SEARCH_2(1414) :: cplan.sql(1560) :: :
11416:
1                EXIT:: SP_SEARCH_2(1417) :: cplan.sql(1563) :: :
1 AND r.WORK_LOCATION=:
1PMO_STPU:
1STRNPCPY:
1SELECT RANK INTO h_rank:n               FROM TMT_COMPETENCIES:n              +
1 WHERE ELEMENT_ID = h_role_id:
11446:
1           EXCEPTION:: SP_SEARCH_2(1447) :: cplan.sql(1593) :: :
11453:
1        RETURN_ERROR:: SP_SEARCH_2(1454) :: cplan.sql(1600) :: :
11456:
1                EXIT:: SP_SEARCH_2(1457) :: cplan.sql(1603) :: :
1 AND EXISTS :
1(SELECT t1.ELEMENT_ID :
1  FROM TMT_COMPETENCIES t1:
1  WHERE t1.RANK LIKE ':
1%':
1AND r.ELEMENT_ID=t1.ELEMENT_ID) :
1AND r.RESOURCE_ID=t1.RESOURCE_ID) :
11499:
1           EXCEPTION:: SP_SEARCH_2(1500) :: cplan.sql(1646) :: :
11506:
1        RETURN_ERROR:: SP_SEARCH_2(1507) :: cplan.sql(1653) :: :
11509:
1                EXIT:: SP_SEARCH_2(1510) :: cplan.sql(1656) :: :
1     AND r.RESOURCE_ID=t1.RESOURCE_ID) :
1 ORDER BY RESOURCE_ID  :
1OPEN:
1CLOSE:
11571:
1           EXCEPTION:: SP_SEARCH_2(1572) :: cplan.sql(1718) :: :
1CONTINUE0000:
11589:
1           EXCEPTION:: SP_SEARCH_2(1590) :: cplan.sql(1736) :: :
1COUNT:
1TSK_ASSIGNMENT_ID:
1SELECT COUNT(TSK_ASSIGNMENT_ID) INTO h_temp_var :n                  FROM TASK+
1_ASSIGNMENTS:n                  WHERE PROJECT_ID = h_project_id:n            +
1      AND RESOURCE_ID = h_res_id:n                  AND RESOURCE_TYPE = '0':
11618:
1           EXCEPTION:: SP_SEARCH_2(1619) :: cplan.sql(1765) :: :
11632:
1           EXCEPTION:: SP_SEARCH_2(1633) :: cplan.sql(1779) :: :
11638:
1        RETURN_ERROR:: SP_SEARCH_2(1639) :: cplan.sql(1785) :: :
1CHILD_TASK_ASSIGNMENT_ALREADY_:
11641:
1                EXIT:: SP_SEARCH_2(1642) :: cplan.sql(1788) :: :
1FC_SEARCH_2:
11665:
1           EXCEPTION:: SP_SEARCH_2(1666) :: cplan.sql(1812) :: :
1DB_OFFSET:
1TASK_ASSIGNMENT_ERROR:
11675:
1        RETURN_ERROR:: SP_SEARCH_2(1676) :: cplan.sql(1822) :: :
11678:
1                EXIT:: SP_SEARCH_2(1679) :: cplan.sql(1825) :: :
1UPDATE PROFILES SET REC_STATUS='U' WHERE PROFILE_ID = h_res_id AND REC_STATUS+
1='D':
11694:
1           EXCEPTION:: SP_SEARCH_2(1695) :: cplan.sql(1841) :: :
11734:
1           EXCEPTION:: SP_SEARCH_2(1735) :: cplan.sql(1881) :: :
1ASSIGN_STRING_TOLONG:
11743:
1        RETURN_ERROR:: SP_SEARCH_2(1744) :: cplan.sql(1890) :: :
11746:
1                EXIT:: SP_SEARCH_2(1747) :: cplan.sql(1893) :: :
1NOTNULL:
1UPDATE PMO_TMP_SEARCH SET:n                  ROLE_ID = h_source_ids:n        +
1          , ROLE_NAME = h_and_roles:n                  , SKILL_ID = h_target_+
1ids:n                  , SKILL_NAME = h_and_skills:n                  , SHOW_+
1ROLE = h_shw_roles:n                  , SHOW_SKILL = h_shw_skills:n          +
1        WHERE RS_ID = h_last_id:
11812:
1           EXCEPTION:: SP_SEARCH_2(1813) :: cplan.sql(1959) :: :
1UPDATE PMO_TMP_SEARCH SET:n               ROLE_ID = NuLL:n               , RO+
1LE_NAME = NuLL:n               , SKILL_ID = NuLL:n               , SKILL_NAME+
1 = NuLL:n               , SHOW_ROLE = NuLL:n               , SHOW_SKILL = NuL+
1L:n               WHERE RS_ID = h_last_id:
11853:
1           EXCEPTION:: SP_SEARCH_2(1854) :: cplan.sql(2000) :: :
1,:
11912:
1           EXCEPTION:: SP_SEARCH_2(1913) :: cplan.sql(2059) :: :
1UPDATE PMO_TMP_SEARCH SET:n            ROLE_ID = h_source_ids:n            , +
1ROLE_NAME = h_and_roles:n            , SKILL_ID = h_target_ids:n            ,+
1 SKILL_NAME = h_and_skills:n            , SHOW_ROLE = h_shw_roles:n          +
1  , SHOW_SKILL = h_shw_skills:n            WHERE RS_ID = h_last_id:
11938:
1           EXCEPTION:: SP_SEARCH_2(1939) :: cplan.sql(2085) :: :
1SUM:
1AVAILABLE_MIN:
1CALENDAR_DAY_OF_YEAR:
1DAY_YEAR:
1TO_DATE:
1SELECT COALESCE(SUM(AVAILABLE_MIN),0) INTO h_effort:n            FROM CALENDA+
1R_DAY_OF_YEAR:n            WHERE ELEMENT_ID=h_project_id:n            AND DAY+
1_YEAR BETWEEN TO_DATE(SubStr(h_start_DT, 1, 10)) AND TO_DATE(SubStr(h_finish_+
1DT, 1, 10)):
11958:
1           EXCEPTION:: SP_SEARCH_2(1959) :: cplan.sql(2105) :: :
1CURRENCY_ID:
1TODECIMAL:
1TD:
1TW:
1TMT_DATAFIELDS:
1SELECT CURRENCY_ID, PMO_ORASTD.TODECIMAL(td.ELEMENT_NAME,20,4) INTO h_currenc+
1y_id, h_rate_echange:n      FROM TMT_WBS tw JOIN TMT_DATAFIELDS td on tw.CURR+
1ENCY_ID = td.ELEMENT_ID:n      WHERE tw.ELEMENT_ID = h_project_id:
11978:
1           EXCEPTION:: SP_SEARCH_2(1979) :: cplan.sql(2125) :: :
1DELETE FROM PMO_TMP_CPLN_0005:
1PMO_TMP_CPLN_0005:
1REGULAR_COST:
1REGULAR_SALE:
1SPECIAL_COST:
1SPECIAL_SALE:
1INSERT INTO PMO_TMP_CPLN_0005:n         SELECT RES_ID:n         , REGULAR_COS+
1T:n         , REGULAR_SALE:n         , SPECIAL_COST:n         , SPECIAL_SALE+
1:n         FROM PMO_TMP_SEARCH:n         WHERE RS_ID = h_rs_id:n         AND +
1(REGULAR_COST + REGULAR_SALE) > 0:
12014:
1           EXCEPTION:: SP_SEARCH_2(2015) :: cplan.sql(2161) :: :
1INSERT INTO PMO_TMP_CPLN_0005:n            SELECT RES_ID:n            , MAX(R+
1EGULAR_COST) AS REGULAR_COST:n            , MAX(REGULAR_SALE) AS REGULAR_SALE+
1:n            , MAX(SPECIAL_COST) AS SPECIAL_COST:n            , MAX(SPECIAL_+
1SALE) AS SPECIAL_SALE:n            FROM PMO_TMP_SEARCH:n            WHERE RS_+
1ID <> h_rs_id:n            GROUP BY RES_ID:
12041:
1           EXCEPTION:: SP_SEARCH_2(2042) :: cplan.sql(2188) :: :
1INSERT INTO PMO_TMP_CPLN_0005:n               SELECT RES_ID, 0.00, 0.00, 0.00+
1, 0.00:n               FROM PMO_TMP_SEARCH:n               WHERE RS_ID = h_rs+
1_id:n               GROUP BY RES_ID:
12063:
1           EXCEPTION:: SP_SEARCH_2(2064) :: cplan.sql(2210) :: :
1RS:
1WORK_LOCATION:
1O1:
1ORGANIZATION:
1G1:
1GEOGRAPHY:
1ROUND:
1PA:
1RES_SALE_RATE:
1TEMP:
1REGULAR_RATE:
1SPECIAL_RATE:
1START_DATE:
1FINISH_DATE:
1ASSIGNABLE:
1PLANNED:
1SCHED:
1PROPOSED:
1WORK_EFFORT:
1UNIT_EFFORT:
1AVAILABLE:
1VERIFIED:
1STATUS2_ID:
1FULL_NAME:
1PP:
1POOL_NAME:
1E_MAIL_ADDRESS:
1UNIQUE_ID:
1CONTOUR:
1ASSIGN_STRING:
1ASSIGNED_FLAG:
1FS_LABOR_CODE:
1RES_MODIFIED_DATE:
1LEFT:
1OUTER:
1PROJECT_ASSIGNMENTS:
1R:
1RATES:
1RATE_ID:
1SELECT h_res_id AS ELEMENT_ID, 41 AS TYPE_ID, p.PROFILE_NAME AS ELEMENT_NAME,+
1 rs.ROLE_NAME, rs.SKILL_NAME, rs.SHOW_ROLE, rs.SHOW_SKILL, h_work_location AS+
1 WORK_LOCATION,:n      o1.ELEMENT_NAME AS ORGANIZATION,g1.ELEMENT_NAME AS GEO+
1GRAPHY,:n      ROUND(CASE WHEN pa.REGULAR_COST>0 THEN pa.REGULAR_COST WHEN rs+
1.RES_SALE_RATE=0 THEN temp.REGULAR_COST * h_rate_echange ELSE a.REGULAR_COST +
1* h_rate_echange END,2) AS REGULAR_COST,:n      ROUND(CASE WHEN pa.REGULAR_RA+
1TE>0 THEN pa.REGULAR_RATE WHEN rs.RES_SALE_RATE=0 THEN temp.REGULAR_SALE * h_+
1rate_echange ELSE a.REGULAR_SALE * h_rate_echange END,2) AS REGULAR_SALE,:n  +
1    ROUND(CASE WHEN pa.SPECIAL_COST>0 THEN pa.SPECIAL_COST WHEN rs.RES_SALE_R+
1ATE=0 THEN temp.SPECIAL_COST * h_rate_echange ELSE a.SPECIAL_COST * h_rate_ec+
1hange END,2) AS SPECIAL_COST,:n      ROUND(CASE WHEN pa.SPECIAL_RATE>0 THEN p+
1a.SPECIAL_RATE WHEN rs.RES_SALE_RATE=0 THEN temp.SPECIAL_SALE * h_rate_echang+
1e ELSE a.SPECIAL_SALE * h_rate_echange END,2) AS SPECIAL_SALE,:n      rs.STAR+
1T_DATE,rs.FINISH_DATE,rs.ASSIGNABLE,rs.PLANNED,rs.SCHED, CASE WHEN rs.PROPOSE+
1D > 0 THEN rs.PROPOSED ELSE h_effort END AS WORK_EFFORT, h_eunit AS UNIT_EFFO+
1RT,(rs.ASSIGNABLE - rs.PLANNED - rs.SCHED) AS AVAILABLE,:n      '' AS VERIFIE+
1D, 0 AS STATUS2_ID, '' AS FULL_NAME, pp.ELEMENT_NAME AS POOL_NAME, '' AS E_MA+
1IL_ADDRESS, '' AS UNIQUE_ID, h_per_day AS MINUTE_PER_DAY, rs.CONTOUR AS ASSIG+
1N_STRING, h_and_roles AS ROLE_ID, h_and_skills AS SKILL_ID, 0 AS ASSIGNED_FLA+
1G,:n      'PMOFFICE' AS FS_LABOR_CODE, TO_TIMESTAMP('1899-12-31 00::00::00') +
1AS RES_MODIFIED_DATE:n      FROM PMO_TMP_CPLN_0005 temp JOIN PMO_TMP_SEARCH r+
1s ON rs.RES_ID = temp.RES_ID:n      LEFT OUTER JOIN PROJECT_ASSIGNMENTS pa ON+
1 pa.PROJECT_ID=h_project_id AND pa.RESOURCE_ID=rs.RES_ID:n      JOIN PROFILES+
1 p ON p.PROFILE_ID = h_res_id:n      JOIN TMT_COMPETENCIES r ON p.ROLE_ID=r.E+
1LEMENT_ID:n      LEFT OUTER JOIN RATES a ON r.RATE_ID=a.RATE_ID:n      LEFT O+
1UTER JOIN TMT_ORGANIZATIONS o1 ON p.ORG_ID = o1.ELEMENT_ID:n      LEFT OUTER +
1JOIN TMT_GEOGRAPHIES g1 ON p.GEO_ID = g1.ELEMENT_ID:n      LEFT OUTER JOIN TM+
1T_POOLS pp ON pp.ELEMENT_ID = p.POOL_ID:n      WHERE NOT (rs.ROLE_NAME IS NuL+
1L AND rs.SKILL_NAME IS NuLL AND rs.SHOW_ROLE IS NuLL AND rs.SHOW_SKILL IS NuL+
1L):
12089:
1                EXIT:: SP_SEARCH_2(2090) :: cplan.sql(2236) :: :
1O2:
1G2:
1DEFAULT_FLAG:
1RV:
1RM:
1PLANNED_WORK:
1SCHED_WORK:
1REC_DATETIME:
1MANAGER_ID:
1VERIFIED_1:
1SELECT rs.RES_ID AS ELEMENT_ID, 13 AS TYPE_ID, r.FULL_NAME AS ELEMENT_NAME, r+
1s.ROLE_NAME, rs.SKILL_NAME, rs.SHOW_ROLE, rs.SHOW_SKILL, r.WORK_LOCATION,:n  +
1       o2.ELEMENT_NAME AS ORGANIZATION,g2.ELEMENT_NAME AS GEOGRAPHY,:n       +
1  ROUND(CASE WHEN rs.DEFAULT_FLAG='0' THEN rs.REGULAR_COST * CASE WHEN (r.CUR+
1RENCY_ID = h_currency_id) OR (r.CURRENCY_ID * h_currency_id = 0) THEN 1 ELSE +
1(SELECT PMO_ORASTD.TODECIMAL(ELEMENT_NAME,20,4) FROM TMT_DATAFIELDS WHERE ELE+
1MENT_ID = h_currency_id) / (SELECT PMO_ORASTD.TODECIMAL(ELEMENT_NAME,20,4) FR+
1OM TMT_DATAFIELDS WHERE ELEMENT_ID = r.CURRENCY_ID) END WHEN rs.DEFAULT_FLAG=+
1'1' THEN rs.REGULAR_COST ELSE rs.REGULAR_COST * h_rate_echange END,2) AS REGU+
1LAR_COST,:n         ROUND(CASE WHEN rs.DEFAULT_FLAG='0' THEN rs.REGULAR_SALE +
1* CASE WHEN (r.CURRENCY_ID = h_currency_id) OR (r.CURRENCY_ID * h_currency_id+
1 = 0) THEN 1 ELSE (SELECT PMO_ORASTD.TODECIMAL(ELEMENT_NAME,20,4) FROM TMT_DA+
1TAFIELDS WHERE ELEMENT_ID = h_currency_id) / (SELECT PMO_ORASTD.TODECIMAL(ELE+
1MENT_NAME,20,4) FROM TMT_DATAFIELDS WHERE ELEMENT_ID = r.CURRENCY_ID) END WHE+
1N rs.DEFAULT_FLAG='1' THEN rs.REGULAR_SALE ELSE rs.REGULAR_SALE * h_rate_echa+
1nge END,2) AS REGULAR_SALE,:n         ROUND(CASE WHEN rs.DEFAULT_FLAG='0' THE+
1N rs.SPECIAL_COST * CASE WHEN (r.CURRENCY_ID = h_currency_id) OR (r.CURRENCY_+
1ID * h_currency_id = 0) THEN 1 ELSE (SELECT PMO_ORASTD.TODECIMAL(ELEMENT_NAME+
1,20,4) FROM TMT_DATAFIELDS WHERE ELEMENT_ID = h_currency_id) / (SELECT PMO_OR+
1ASTD.TODECIMAL(ELEMENT_NAME,20,4) FROM TMT_DATAFIELDS WHERE ELEMENT_ID = r.CU+
1RRENCY_ID) END WHEN rs.DEFAULT_FLAG='1' THEN rs.SPECIAL_COST ELSE rs.SPECIAL_+
1COST * h_rate_echange END,2) AS SPECIAL_COST,:n         ROUND(CASE WHEN rs.DE+
1FAULT_FLAG='0' THEN rs.SPECIAL_SALE * CASE WHEN (r.CURRENCY_ID = h_currency_i+
1d) OR (r.CURRENCY_ID * h_currency_id = 0) THEN 1 ELSE (SELECT PMO_ORASTD.TODE+
1CIMAL(ELEMENT_NAME,20,4) FROM TMT_DATAFIELDS WHERE ELEMENT_ID = h_currency_id+
1) / (SELECT PMO_ORASTD.TODECIMAL(ELEMENT_NAME,20,4) FROM TMT_DATAFIELDS WHERE+
1 ELEMENT_ID = r.CURRENCY_ID) END WHEN rs.DEFAULT_FLAG='1' THEN rs.SPECIAL_SAL+
1E ELSE rs.SPECIAL_SALE * h_rate_echange END,2) AS SPECIAL_SALE,:n         rs.+
1START_DATE, rs.FINISH_DATE,rs.ASSIGNABLE,rs.PLANNED,rs.SCHED, CASE WHEN rs.PR+
1OPOSED > 0 THEN rs.PROPOSED ELSE h_effort END AS WORK_EFFORT, h_eunit AS UNIT+
1_EFFORT,(rs.ASSIGNABLE - rs.PLANNED - rs.SCHED) AS AVAILABLE,:n         rv.FU+
1LL_NAME AS VERIFIED, r.STATUS2_ID, pp.ELEMENT_NAME AS POOL_NAME, RM.FULL_NAME+
1, RM.E_MAIL_ADDRESS, '' AS UNIQUE_ID, h_per_day AS MINUTE_PER_DAY, rs.CONTOUR+
1 AS ASSIGN_STRING, rs.ROLE_ID, rs.SKILL_ID, COALESCE(pa.PLANNED_WORK + pa.SCH+
1ED_WORK,0) AS ASSIGNED_FLAG,:n         r.FS_LABOR_CODE, r.REC_DATETIME AS RES+
1_MODIFIED_DATE:n         FROM PMO_TMP_SEARCH rs JOIN TMT_POOLS p ON rs.RES_ID+
1=p.ELEMENT_ID:n         JOIN TMT_POOLS pp ON pp.ELEMENT_ID=p.PARENT_ID:n     +
1    LEFT OUTER JOIN RESOURCES RM ON pp.MANAGER_ID=RM.RESOURCE_ID:n         JO+
1IN RESOURCES r ON rs.RES_ID=r.RESOURCE_ID LEFT OUTER JOIN RESOURCES rv ON rv.+
1RESOURCE_ID=r.VERIFIED_1:n         LEFT OUTER JOIN PROJECT_ASSIGNMENTS pa ON +
1pa.PROJECT_ID=h_project_id AND pa.RESOURCE_ID=rs.RES_ID:n         LEFT OUTER +
1JOIN TMT_ORGANIZATIONS o1 ON r.RESOURCE_ID=o1.ELEMENT_ID:n         LEFT OUTER+
1 JOIN TMT_ORGANIZATIONS o2 ON o1.PARENT_ID=o2.ELEMENT_ID:n         LEFT OUTER+
1 JOIN TMT_GEOGRAPHIES g1 ON r.RESOURCE_ID=g1.ELEMENT_ID:n         LEFT OUTER +
1JOIN TMT_GEOGRAPHIES g2 ON g1.PARENT_ID=g2.ELEMENT_ID:n         ORDER BY ELEM+
1ENT_ID:
12114:
1                EXIT:: SP_SEARCH_2(2115) :: cplan.sql(2261) :: :
1DELETE FROM PMO_TMP_CPLN_0006:
1PMO_TMP_CPLN_0006:
1INSERT INTO PMO_TMP_CPLN_0006:n            SELECT RES_ID, REGULAR_COST, REGUL+
1AR_SALE, SPECIAL_COST, SPECIAL_SALE, 1:n            FROM PMO_TMP_SEARCH WHERE+
1 DEFAULT_FLAG = '1':
12136:
1           EXCEPTION:: SP_SEARCH_2(2137) :: cplan.sql(2283) :: :
1INSERT INTO PMO_TMP_CPLN_0006:n            SELECT  RES_ID,                   +
1          MAX(REGULAR_COST) AS REGULAR_COST,:n            MAX(REGULAR_SALE) A+
1S REGULAR_SALE,  MAX(SPECIAL_COST) AS SPECIAL_COST,:n            MAX(SPECIAL_+
1SALE) AS SPECIAL_SALE , 0:n            FROM PMO_TMP_SEARCH:n            WHERE+
1 RES_ID NOT IN (SELECT RES_ID:n            FROM PMO_TMP_SEARCH WHERE DEFAULT_+
1FLAG = '1'):n            GROUP BY RES_ID:
12160:
1           EXCEPTION:: SP_SEARCH_2(2161) :: cplan.sql(2307) :: :
1DEF:
1PRF:
1RR:
1SELECT rs.RES_ID AS ELEMENT_ID, 13 AS TYPE_ID, r.FULL_NAME AS ELEMENT_NAME, r+
1s.ROLE_NAME, rs.SKILL_NAME, rs.SHOW_ROLE, rs.SHOW_SKILL, r.WORK_LOCATION,:n  +
1       o2.ELEMENT_NAME AS ORGANIZATION,g2.ELEMENT_NAME AS GEOGRAPHY,:n       +
1  :n         ROUND(CASE WHEN pa.REGULAR_COST>0 THEN pa.REGULAR_COST:n        +
1 WHEN a.REGULAR_COST>0 THEN a.REGULAR_COST * CASE WHEN (r.CURRENCY_ID = h_cur+
1rency_id) OR (r.CURRENCY_ID * h_currency_id = 0) THEN 1 ELSE (SELECT PMO_ORAS+
1TD.TODECIMAL(ELEMENT_NAME,20,4) FROM TMT_DATAFIELDS WHERE ELEMENT_ID = h_curr+
1ency_id) / (SELECT PMO_ORASTD.TODECIMAL(ELEMENT_NAME,20,4) FROM TMT_DATAFIELD+
1S WHERE ELEMENT_ID = r.CURRENCY_ID) END:n         WHEN def.REGULAR_COST>0 THE+
1N def.REGULAR_COST * CASE WHEN (r.CURRENCY_ID = h_currency_id) OR (r.CURRENCY+
1_ID * h_currency_id = 0) THEN 1 ELSE (SELECT PMO_ORASTD.TODECIMAL(ELEMENT_NAM+
1E,20,4) FROM TMT_DATAFIELDS WHERE ELEMENT_ID = h_currency_id) / (SELECT PMO_O+
1RASTD.TODECIMAL(ELEMENT_NAME,20,4) FROM TMT_DATAFIELDS WHERE ELEMENT_ID = r.C+
1URRENCY_ID) END:n         else prf.REGULAR_COST * h_rate_echange:n         EN+
1D,2) AS REGULAR_COST,:n         :n         ROUND(CASE WHEN pa.REGULAR_COST> 0+
1 THEN pa.REGULAR_RATE:n         WHEN a.REGULAR_COST > 0 THEN a.REGULAR_SALE *+
1 CASE WHEN (r.CURRENCY_ID = h_currency_id) OR (r.CURRENCY_ID * h_currency_id +
1= 0) THEN 1 ELSE (SELECT PMO_ORASTD.TODECIMAL(ELEMENT_NAME,20,4) FROM TMT_DAT+
1AFIELDS WHERE ELEMENT_ID = h_currency_id) / (SELECT PMO_ORASTD.TODECIMAL(ELEM+
1ENT_NAME,20,4) FROM TMT_DATAFIELDS WHERE ELEMENT_ID = r.CURRENCY_ID) END:n   +
1      WHEN def.REGULAR_COST>0 THEN def.REGULAR_SALE * CASE WHEN (r.CURRENCY_I+
1D = h_currency_id) OR (r.CURRENCY_ID * h_currency_id = 0) THEN 1 ELSE (SELECT+
1 PMO_ORASTD.TODECIMAL(ELEMENT_NAME,20,4) FROM TMT_DATAFIELDS WHERE ELEMENT_ID+
1 = h_currency_id) / (SELECT PMO_ORASTD.TODECIMAL(ELEMENT_NAME,20,4) FROM TMT_+
1DATAFIELDS WHERE ELEMENT_ID = r.CURRENCY_ID) END:n         else prf.REGULAR_S+
1ALE * h_rate_echange:n         END,2) AS REGULAR_SALE,:n         :n         R+
1OUND(CASE WHEN pa.REGULAR_COST>0 THEN pa.SPECIAL_COST:n         WHEN a.REGULA+
1R_COST>0 THEN a.SPECIAL_COST * CASE WHEN (r.CURRENCY_ID = h_currency_id) OR (+
1r.CURRENCY_ID * h_currency_id = 0) THEN 1 ELSE (SELECT PMO_ORASTD.TODECIMAL(E+
1LEMENT_NAME,20,4) FROM TMT_DATAFIELDS WHERE ELEMENT_ID = h_currency_id) / (SE+
1LECT PMO_ORASTD.TODECIMAL(ELEMENT_NAME,20,4) FROM TMT_DATAFIELDS WHERE ELEMEN+
1T_ID = r.CURRENCY_ID) END:n         WHEN def.REGULAR_COST>0 THEN def.SPECIAL_+
1COST * CASE WHEN (r.CURRENCY_ID = h_currency_id) OR (r.CURRENCY_ID * h_curren+
1cy_id = 0) THEN 1 ELSE (SELECT PMO_ORASTD.TODECIMAL(ELEMENT_NAME,20,4) FROM T+
1MT_DATAFIELDS WHERE ELEMENT_ID = h_currency_id) / (SELECT PMO_ORASTD.TODECIMA+
1L(ELEMENT_NAME,20,4) FROM TMT_DATAFIELDS WHERE ELEMENT_ID = r.CURRENCY_ID) EN+
1D:n         else prf.SPECIAL_COST * h_rate_echange:n         END,2) AS SPECIA+
1L_COST,:n         :n         ROUND(CASE WHEN pa.REGULAR_RATE>0 THEN pa.SPECIA+
1L_RATE:n         WHEN a.REGULAR_SALE>0 THEN a.SPECIAL_SALE * CASE WHEN (r.CUR+
1RENCY_ID = h_currency_id) OR (r.CURRENCY_ID * h_currency_id = 0) THEN 1 ELSE +
1(SELECT PMO_ORASTD.TODECIMAL(ELEMENT_NAME,20,4) FROM TMT_DATAFIELDS WHERE ELE+
1MENT_ID = h_currency_id) / (SELECT PMO_ORASTD.TODECIMAL(ELEMENT_NAME,20,4) FR+
1OM TMT_DATAFIELDS WHERE ELEMENT_ID = r.CURRENCY_ID) END:n         WHEN def.RE+
1GULAR_COST>0 THEN def.SPECIAL_SALE * CASE WHEN (r.CURRENCY_ID = h_currency_id+
1) OR (r.CURRENCY_ID * h_currency_id = 0) THEN 1 ELSE (SELECT PMO_ORASTD.TODEC+
1IMAL(ELEMENT_NAME,20,4) FROM TMT_DATAFIELDS WHERE ELEMENT_ID = h_currency_id)+
1 / (SELECT PMO_ORASTD.TODECIMAL(ELEMENT_NAME,20,4) FROM TMT_DATAFIELDS WHERE +
1ELEMENT_ID = r.CURRENCY_ID) END:n         else prf.SPECIAL_SALE * h_rate_echa+
1nge:n         END,2) AS SPECIAL_SALE,:n         :n         rs.START_DATE,rs.F+
1INISH_DATE,rs.ASSIGNABLE,rs.PLANNED,rs.SCHED, CASE WHEN rs.PROPOSED > 0 THEN +
1rs.PROPOSED ELSE h_effort END AS WORK_EFFORT, h_eunit AS UNIT_EFFORT,(rs.ASSI+
1GNABLE - rs.PLANNED - rs.SCHED) AS AVAILABLE,:n         rv.FULL_NAME AS VERIF+
1IED, r.STATUS2_ID, pp.ELEMENT_NAME AS POOL_NAME, RM.FULL_NAME, RM.E_MAIL_ADDR+
1ESS, '' AS UNIQUE_ID, h_per_day AS MINUTE_PER_DAY, rs.CONTOUR AS ASSIGN_STRIN+
1G,:n         rs.ROLE_ID, rs.SKILL_ID, COALESCE(pa.PLANNED_WORK + pa.SCHED_WOR+
1K,0) AS ASSIGNED_FLAG,:n         r.FS_LABOR_CODE, r.REC_DATETIME AS RES_MODIF+
1IED_DATE:n         FROM PMO_TMP_SEARCH rs:n         LEFT JOIN PMO_TMP_CPLN_00+
106 def ON rs.RES_ID=def.RES_ID AND def.DEFAULT_FLAG = 1:n         LEFT JOIN P+
1MO_TMP_CPLN_0006 prf ON rs.RES_ID=prf.RES_ID AND prf.DEFAULT_FLAG = 0:n      +
1   JOIN TMT_POOLS p ON rs.RES_ID=p.ELEMENT_ID:n         JOIN TMT_POOLS pp ON +
1pp.ELEMENT_ID=p.PARENT_ID:n         LEFT OUTER JOIN RESOURCES RM ON pp.MANAGE+
1R_ID=RM.RESOURCE_ID:n         JOIN RESOURCES r ON rs.RES_ID=r.RESOURCE_ID LEF+
1T OUTER JOIN RESOURCES rv ON rv.RESOURCE_ID=r.VERIFIED_1:n         LEFT OUTER+
1 JOIN PROJECT_ASSIGNMENTS pa ON pa.PROJECT_ID=h_project_id AND pa.RESOURCE_ID+
1=rs.RES_ID:n         LEFT OUTER JOIN RESOURCES rr ON r.VERIFIED_1=rr.RESOURCE+
1_ID:n         LEFT OUTER JOIN TMT_ORGANIZATIONS o1 ON r.RESOURCE_ID=o1.ELEMEN+
1T_ID LEFT OUTER JOIN TMT_ORGANIZATIONS o2 ON o1.PARENT_ID=o2.ELEMENT_ID:n    +
1     LEFT OUTER JOIN TMT_GEOGRAPHIES g1 ON r.RESOURCE_ID=g1.ELEMENT_ID LEFT O+
1UTER JOIN TMT_GEOGRAPHIES g2 ON g1.PARENT_ID=g2.ELEMENT_ID:n         LEFT OUT+
1ER JOIN RATES a ON r.RATE_ID=a.RATE_ID:n         WHERE NOT (rs.ROLE_NAME IS N+
1uLL AND rs.SKILL_NAME IS NuLL AND rs.SHOW_ROLE IS NuLL AND rs.SHOW_SKILL IS N+
1uLL):n         ORDER BY ELEMENT_ID:
12211:
1                EXIT:: SP_SEARCH_2(2212) :: cplan.sql(2358) :: :
1RETURN_ERROR_EXCEPTION:
12221:
1           EXCEPTION:: SP_SEARCH_2(2222) :: cplan.sql(2368) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1ERROR:
1ID:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
12233:
1           EXCEPTION:: SP_SEARCH_2(2234) :: cplan.sql(2380) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
34ca
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 81 b0 a3 a0 1c
81 b0 a3 a0 1c 81 b0 a3
a0 1c 81 b0 a3 a0 1c 81
b0 a3 a0 1c 81 b0 a3 a0
1c 81 b0 a3 :2 a0 6b 1c 81
b0 a0 f4 b4 bf c8 :8 a0 12a
bd b7 11 a4 b1 a0 f4 b4
bf c8 :10 a0 12a bd b7 11 a4
b1 a3 :2 a0 6b 1c 81 b0 a3
:2 a0 6b 1c 81 b0 a3 :2 a0 6b
1c 81 b0 a3 :2 a0 6b 1c 81
b0 :2 a0 6b :2 a0 6b 6e a5 b
a 10 :2 a0 6b 6e :2 a0 6b 6e
a5 b 6e 7e a0 b4 2e 6e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :3 a0 a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e :3 a0 a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
:3 a0 a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e :3 a0 a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e :3 a0 a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e :3 a0
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e :3 a0 a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :3 a0 a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :3 a0 a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
:3 a0 a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e :3 a0 a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 d :2 a0 d :2 a0 d :2 a0
d :2 a0 d :2 a0 d :2 a0 d :2 a0
d :2 a0 d :2 a0 d :2 a0 d :2 a0
d :2 a0 d :2 a0 d :2 a0 d :2 a0
d :2 a0 d :2 a0 d :2 a0 d :2 a0
d :2 a0 d :2 a0 d a0 51 d
a0 51 d :2 a0 51 a5 b a0
7e a0 6b b4 2e 5a a0 7e
b4 2e :2 5a a 10 :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b a0 a5 57 b7 19 3c a0
7e b4 2e :2 5a a0 7e b4 2e
:2 5a a 10 a0 7e b4 2e :2 5a
a 10 a0 7e b4 2e :2 5a a
10 :2 a0 51 a5 b a0 7e a0
6b b4 2e 5a a 10 a0 7e
b4 2e :2 5a :2 a0 51 a5 b a0
7e a0 6b b4 2e 5a a 10
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b a0 a5 57 a0
b7 a0 7e b4 2e :2 5a a0 7e
b4 2e :2 5a a 10 :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b a0 a5 57 b7 :2 19 3c b7
19 3c :2 a0 51 a5 b 7e 51
b4 2e :2 a0 51 a5 b 7e 51
b4 2e a 10 :2 a0 51 a5 b
7e 51 b4 2e a 10 :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b a0 a5 57 b7 19 3c
a0 7e b4 2e :2 5a a0 51 d
b7 :2 a0 d b7 :2 19 3c :2 a0 51
a5 b a0 7e a0 6b b4 2e
5a a0 7e b4 2e :2 5a a 10
a0 7e b4 2e :2 5a a 10 :8 a0
12a :2 a0 6b a0 d b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 6b a0 7e a0 6b
b4 2e 5a :2 a0 51 a5 b 7e
51 b4 2e 5a a 10 :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b a0 a5 57 b7 19 3c
a0 51 d b7 19 3c a0 7e
b4 2e :2 5a a0 7e b4 2e :2 5a
a 10 :3 a0 12a :2 a0 6b a0 d
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 19 3c
:2 a0 d :3 a0 6b :3 a0 51 a5 b
:2 a0 6b a5 b 5a 51 a5 b
d :4 a0 51 a5 b :2 a0 6b a5
b d :3 a0 6b :3 a0 51 a5 b
:2 a0 6b a5 b 5a 51 a5 b
d :4 a0 51 a5 b :2 a0 6b a5
b d :3 a0 51 a5 b a0 7e
a0 6b b4 2e 51 a6 122 51
122 124 d :2 a0 51 a5 b 7e
51 b4 2e a0 51 d :5 a0 12a
:2 a0 6b a0 d b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 51 a5 b 7e 51 b4
2e :5 a0 12a :2 a0 6b a0 d b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 6b a0 6e
a5 b 7e 51 b4 2e :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b :2 a0 a5 57 b7 19 3c
b7 19 3c :4 a0 51 a5 b a5
b d :2 a0 51 a5 b 7e 51
b4 2e :4 a0 51 a5 b a5 b
d :2 a0 51 a5 b 7e 51 b4
2e :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b a0 a5 57
b7 19 3c :3 a0 6b d b7 19
3c :2 a0 d :2 a0 51 a5 b 7e
51 b4 2e :2 a0 d b7 :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b a0 a5 57 b7 :2 19 3c
:8 a0 a5 b d :2 a0 51 a5 b
7e 51 b4 2e :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 51 a5
b :2 a0 a5 57 b7 19 3c :2 a0
51 a5 b a0 7e a0 6b b4
2e :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b :2 a0 a5 57
b7 19 3c :2 a0 51 a5 b a0
7e a0 6b b4 2e :3 a0 51 a5
b a5 b 7e 51 b4 2e :d a0
12a :2 a0 6b a0 d b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 :27 a0 12a :2 a0 6b a0
d b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 :2 19
3c :2 a0 6b a0 7e a0 6b b4
2e 5a :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b :2 a0 a5
57 b7 19 3c a0 b7 :2 a0 51
a5 b a0 7e a0 6b b4 2e
:9 a0 12a :2 a0 6b a0 d b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 6b a0 7e a0
6b b4 2e 5a :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :4 a0 6b a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
:2 a0 a5 57 b7 19 3c :13 a0 12a
:2 a0 6b a0 d b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6b a0 7e a0 6b b4
2e 5a :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b :2 a0 a5
57 b7 19 3c a0 7e b4 2e
5a :3 a0 6b d :3 a0 a5 b d
b7 19 3c b7 19 :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b :2 a0 a5 57 b7 :2 19 3c :2 a0
51 a5 b a0 7e a0 6b b4
2e :15 a0 12a :2 a0 6b a0 d b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 6b a0 7e
a0 6b b4 2e 5a :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b :2 a0 a5 57 a0 b7 :2 a0 6b
a0 7e a0 6b b4 2e 5a :2 a0
:2 51 a5 b 7e 6e b4 2e :2 a0
51 a5 b 7e 51 b4 2e :2 a0
51 a5 b a0 7e a0 51 a5
b b4 2e a 10 5a 52 10
:2 a0 51 a5 b a0 7e a0 51
a5 b b4 2e 52 10 :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b :2 a0 a5 57 b7 19 3c
b7 :2 19 3c b7 19 3c b7 19
3c :2 a0 51 a5 b 7e 51 b4
2e :2 a0 51 a5 b a0 7e a0
6b b4 2e a0 7e b4 2e 5a
a 10 :2 a0 51 a5 b 7e 51
b4 2e a 10 :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :4 a0 6b a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
:2 a0 a5 57 b7 19 3c :2 a0 51
a5 b a0 7e a0 6b b4 2e
:b a0 12a :2 a0 6b a0 d b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 6b a0 7e a0
6b b4 2e 5a :5 a0 12a :2 a0 6b
a0 d b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
6b a0 7e a0 6b b4 2e 5a
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b :2 a0 a5 57 b7
19 3c b7 19 3c b7 19 3c
b7 19 3c :2 a0 51 a5 b 7e
51 b4 2e :2 a0 51 a5 b 7e
51 b4 2e a 10 a0 51 d
b7 19 3c :2 a0 51 a5 b a0
7e a0 6b b4 2e a0 7e b4
2e 5a a0 6e d a0 6e d
b7 :2 a0 d :2 a0 d b7 :2 19 3c
a0 51 d b7 a0 7e 51 b4
2e a0 6e d :6 a0 51 a5 b
:2 a0 51 a5 b :2 a0 51 a5 b
:2 a0 51 a5 b :2 a0 51 a5 b
:2 a0 51 a5 b :2 a0 51 a5 b
:2 a0 51 a5 b :3 a0 a5 b d
:2 a0 51 a5 b a0 7e a0 6b
b4 2e :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b a0 a5
57 a0 b7 :2 a0 51 a5 b 7e
51 b4 2e :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :3 a0 a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 51 a5 b
:2 a0 a5 57 b7 :2 19 3c b7 :2 a0
d b7 :2 19 3c :2 a0 51 a5 b
7e 51 b4 2e 5a :2 a0 51 a5
b 7e 51 b4 2e 5a a 10
:2 a0 51 a5 b 7e 51 b4 2e
5a :2 a0 51 a5 b 7e 51 b4
2e 5a 52 10 a0 51 d a0
b7 :2 a0 51 a5 b 7e 51 b4
2e a0 51 d a0 b7 19 :2 a0
51 a5 b 7e 51 b4 2e 5a
:2 a0 51 a5 b 7e 51 b4 2e
5a 52 10 a0 51 d a0 b7
19 :2 a0 51 a5 b 7e 51 b4
2e a0 51 d b7 :2 19 3c b7
19 3c b7 :2 19 3c :2 a0 51 a5
b a0 7e a0 6b b4 2e a0
51 d :2 a0 d :2 a0 d :3 a0 :2 51
a5 b d a0 4d d :2 a0 51
a5 b 7e 51 b4 2e :2 a0 b4
2e d a0 51 d b7 :5 a0 12a
:2 a0 6b a0 d b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6b a0 7e a0 6b b4
2e 5a :2 a0 51 a5 b 7e 51
b4 2e :b a0 12a :2 a0 6b a0 d
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 6b a0
7e a0 6b b4 2e 5a a0 51
d b7 19 3c b7 19 3c b7
a0 51 d b7 :2 19 3c b7 :2 19
3c a0 7e 51 b4 2e :9 a0 12a
:2 a0 6b a0 d b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :1f a0 12a :2 a0 6b a0 d b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 6b a0 7e
a0 6b b4 2e 5a :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b :2 a0 a5 57 b7 19 3c :3 a0
51 a5 b 7e 51 b4 2e 6e
a6 122 6e 122 124 d :13 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f a0
b7 :2 a0 :2 51 a5 b 7e 6e b4
2e :a a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 :2 19 3c :9 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :9 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :6 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 19 3c :2 a0 b4 2e d :2 a0
51 a5 b 7e 51 b4 2e :2 a0
51 a5 b a0 7e a0 6b b4
2e a 10 :2 a0 51 a5 b a0
7e a0 6b b4 2e a 10 a0
7e b4 2e 5a :2 a0 d b7 19
3c b7 19 3c :2 a0 51 a5 b
7e 51 b4 2e :3 a0 6b d b7
19 3c a0 7e b4 2e 5a a0
7e b4 2e 5a a 10 a0 7e
b4 2e 5a a 10 a0 7e b4
2e :2 5a a 10 a0 51 d b7
19 3c a0 6e d a0 6e d
:2 a0 51 a5 b 7e 51 b4 2e
:2 a0 51 a5 b a0 7e a0 6b
b4 2e a0 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
d a0 b7 :2 a0 51 a5 b 7e
51 b4 2e a0 6e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e d b7 19
a0 6e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e d b7
:2 19 3c b7 :2 a0 51 a5 b a0
7e a0 6b b4 2e :2 a0 51 a5
b a0 7e a0 6b b4 2e a
10 :2 a0 51 a5 b a0 7e a0
6b b4 2e a 10 :2 a0 6e 11e
11d :2 a0 6b 51 d a0 7e b4
2e 5a :2 a0 6e 11e 11d :2 a0 6b
51 d :17 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :15 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 :2 a0 d b7
:2 19 3c b7 19 3c a0 7e b4
2e 5a :4 a0 a5 b 51 a5 b
7e 51 b4 2e :4 a0 a5 b 51
a5 b 51 a5 b 7e 51 b4
2e a6 122 :4 a0 a5 b 51 a5
b 51 a5 b 122 124 d a0
51 d :3 a0 7e a0 b4 2e 82
:5 a0 7e 51 b4 2e 51 a5 b
a5 b 51 a5 b 7e 51 b4
2e :5 a0 7e 51 b4 2e 51 a5
b a5 b 51 a5 b 7e 51
b4 2e a 10 a0 2b b7 19
3c :2 a0 7e 51 b4 2e d b7
a0 47 :2 a0 7e b4 2e :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b a0 a5 57 b7 19 3c
:4 a0 12a :2 a0 6b a0 d b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 19 3c :2 a0 51
a5 b a0 7e a0 6b b4 2e
a0 6e d a0 6e d :2 a0 7e
a0 b4 2e d :2 a0 7e 6e b4
2e d a0 b7 :2 a0 51 a5 b
a0 7e a0 6b b4 2e a0 6e
d :2 a0 7e a0 b4 2e d :2 a0
7e 6e b4 2e d a0 6e d
b7 19 :2 a0 51 a5 b a0 7e
a0 6b b4 2e a0 6e d a0
6e d a0 7e b4 2e 5a :2 a0
7e 6e b4 2e d :2 a0 7e a0
b4 2e d :2 a0 7e 6e b4 2e
d b7 19 3c :2 a0 7e 6e b4
2e d a0 7e b4 2e 5a :2 a0
7e 6e b4 2e d :2 a0 7e a0
b4 2e d :2 a0 7e 6e b4 2e
d b7 19 3c b7 a0 7e b4
2e 5a :2 a0 7e 6e b4 2e d
a0 6e d b7 :2 a0 7e 6e b4
2e 7e 6e b4 2e d a0 6e
d a0 7e b4 2e 5a :2 a0 7e
6e b4 2e d :2 a0 7e a0 b4
2e d :2 a0 7e 6e b4 2e d
b7 19 3c :2 a0 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e d b7 :2 19 3c
a0 7e b4 2e 5a :2 a0 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e d b7 19 3c b7 :2 19
3c b7 :2 19 3c :2 a0 51 a5 b
a0 7e a0 6b b4 2e a0 7e
b4 2e 5a :5 a0 12a :2 a0 6b a0
d b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
a0 7e a0 6b b4 2e 5a :4 a0
a5 b 51 a5 b d :2 a0 7e
6e b4 2e d :2 a0 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e d b7 :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b :2 a0 a5 57 b7 :2 19
3c b7 19 3c a0 7e b4 2e
5a :5 a0 12a :2 a0 6b a0 d b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 6b a0 7e
a0 6b b4 2e 5a :2 a0 7e 6e
b4 2e d :2 a0 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e d b7 :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b :2 a0 a5 57 b7 :2 19 3c
b7 19 3c a0 7e b4 2e 5a
:5 a0 12a :2 a0 6b a0 d b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 6b a0 7e a0
6b b4 2e 5a :2 a0 7e 6e b4
2e d :2 a0 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e d b7 :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b :2 a0 a5 57 b7 :2 19 3c b7
19 3c :2 a0 51 a5 b 7e 51
b4 2e :2 a0 51 a5 b 7e 51
b4 2e a 10 :2 a0 7e 6e b4
2e 7e :3 a0 51 a5 b a5 b
b4 2e 7e 6e b4 2e d b7
19 3c b7 19 3c a0 7e b4
2e 5a :4 a0 a5 b 51 a5 b
d a0 51 d :3 a0 7e a0 b4
2e 82 :3 a0 6b :2 51 a0 7e 51
b4 2e a0 a5 b d :5 a0 12a
:2 a0 6b a0 d b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6b a0 7e a0 6b b4
2e 5a :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b :2 a0 a5
57 b7 19 3c :2 a0 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e d :2 a0 51
a5 b a0 7e a0 6b b4 2e
:2 a0 7e 6e b4 2e d b7 :2 a0
7e 6e b4 2e d b7 :2 19 3c
:2 a0 51 a5 b a0 7e a0 6b
b4 2e a0 2b b7 19 3c :2 a0
7e 51 b4 2e d b7 a0 47
b7 19 3c :2 a0 51 a5 b a0
7e a0 6b b4 2e :4 a0 a5 b
51 a5 b d a0 51 d :3 a0
7e a0 b4 2e 82 :3 a0 6b :2 51
a0 7e 51 b4 2e a0 a5 b
d :5 a0 12a :2 a0 6b a0 d b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 6b a0 7e
a0 6b b4 2e 5a :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b :2 a0 a5 57 b7 19 3c :2 a0
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e d :2 a0 7e 51
b4 2e d b7 a0 47 b7 19
3c :2 a0 7e a0 b4 2e d b7
:2 19 3c :2 a0 7e 6e b4 2e d
:3 a0 11c 11d :3 a0 e9 d3 :2 a0 f
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c :2 a0 6b a0 7e
a0 6b b4 2e 5a a0 2b b7
19 3c :2 a0 51 a5 b 7e 51
b4 2e :2 a0 51 a5 b a0 7e
a0 6b b4 2e a 10 :2 a0 51
a5 b a0 7e a0 6b b4 2e
a 10 :2 a0 51 a5 b a0 7e
a0 6b b4 2e a0 7e b4 2e
5a 52 10 5a a 10 :2 a0 e9
dd b3 :2 a0 e9 d3 :2 a0 f :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c :2 a0 6b a0 7e a0
6b b4 2e 5a :2 a0 e9 c1 :2 a0
6b a0 d b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
a0 3b b7 :2 a0 e9 c1 :2 a0 6b
a0 d b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
:2 19 3c b7 19 3c :2 a0 d :2 a0
d :2 a0 51 a5 b 7e 51 b4
2e :2 a0 :2 51 a5 b 7e 6e b4
2e :2 a0 b4 2e d a0 51 d
b7 :3 a0 51 a5 b a5 b 7e
51 b4 2e :9 a0 12a :2 a0 6b a0
d b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 51
a5 b 7e 51 b4 2e :2 a0 e9
c1 :2 a0 6b a0 d b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b :2 a0 a5
57 b7 19 3c b7 19 3c b7
:2 19 3c :20 a0 51 a5 b :3 51 a5
b d a0 7e 51 b4 2e :2 a0
e9 c1 :2 a0 6b a0 d b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 7e a0 6b b4
2e :3 a0 6b d b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :3 a0 a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 6b
:3 a0 a5 57 a0 b7 :2 a0 :2 51 a5
b 7e 6e b4 2e 5a :2 a0 :2 51
a5 b 7e 6e b4 2e 5a a
10 :5 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 :2 19 3c a0 2b b7
:2 a0 51 a5 b a0 7e a0 6b
b4 2e :2 a0 d :2 a0 d b7 19
3c :1e a0 :4 51 a5 b d a0 7e
51 b4 2e :2 a0 7e 51 b4 2e
d b7 19 3c :2 a0 7e a0 51
a5 b b4 2e a0 2b b7 19
3c b7 :2 19 3c 93 4f b0 46
b7 a0 47 :2 a0 e9 c1 :2 a0 6b
a0 d b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
7e a0 6b b4 2e 5a a0 7e
51 b4 2e 5a :2 a0 51 a5 b
7e 51 b4 2e 5a a 10 5a
52 10 :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :3 a0 a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b :3 a0 a5 57 b7 19
3c a0 7e 51 b4 2e a0 6e
d a0 6e d a0 6e d :2 a0
e9 dd b3 a0 51 d :a a0 e9
d3 5 :2 a0 f :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
:2 a0 6b a0 7e a0 6b b4 2e
5a a0 2b b7 19 3c a0 7e
b4 2e 5a :2 a0 6b :2 a0 a5 b
7e 51 b4 2e a 10 :3 a0 a5
b 51 a5 b 7e 51 b4 2e
a 10 :2 a0 d b7 19 3c :2 a0
6b :2 a0 a5 b 7e 51 b4 2e
a0 7e 51 b4 2e :f a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 19
3c a0 6e d a0 6e d a0
6e d a0 6e d a0 6e d
a0 6e d :2 a0 d a0 51 d
b7 19 3c a0 7e 51 b4 2e
a0 7e b4 2e 5a a 10 :9 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 19 3c a0 7e b4 2e 5a
a0 7e b4 2e 5a :3 a0 7e 6e
b4 2e :2 51 a5 b d b7 19
3c :3 a0 7e a0 b4 2e :2 51 a5
b d b7 19 3c a0 7e b4
2e 5a :3 a0 7e a0 b4 2e :2 51
a5 b d b7 19 3c a0 7e
b4 2e 5a a0 7e b4 2e 5a
:3 a0 7e 6e b4 2e :2 51 a5 b
d b7 19 3c :3 a0 7e a0 b4
2e :2 51 a5 b d b7 19 3c
a0 7e b4 2e 5a :3 a0 7e a0
b4 2e :2 51 a5 b d b7 19
3c a0 7e b4 2e 5a a0 7e
b4 2e 5a :3 a0 7e 6e b4 2e
:2 51 a5 b d b7 19 3c :3 a0
7e a0 b4 2e :2 51 a5 b d
b7 19 3c a0 7e b4 2e 5a
a0 7e b4 2e 5a :3 a0 7e 6e
b4 2e :2 51 a5 b d b7 19
3c :3 a0 7e a0 b4 2e :2 51 a5
b d b7 19 3c :2 a0 7e 51
b4 2e d :2 a0 d b7 a0 47
:2 a0 e9 c1 :2 a0 6b a0 d b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f a0 7e 51 b4
2e :f a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 19 3c b7 19 3c
a0 7e b4 2e 5a :2 a0 51 a5
b 7e 51 b4 2e :e a0 12a :2 a0
6b a0 d b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 a0 51 d 4f b7 :2 19 3c
b7 19 3c :13 a0 12a :2 a0 6b a0
d b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 51
a5 b a0 7e a0 6b b4 2e
:2 a0 6e 11e 11d :2 a0 6b 51 d
:b a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6b a0 7e a0 6b b4
2e 5a :12 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 6b a0 7e a0
6b b4 2e 5a :6 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 19 3c
b7 19 3c :cc a0 12a e9 dd :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 65 b7 a0 7e 51
b4 2e :12d a0 12a e9 dd :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 65 b7 :2 a0 6e 11e 11d
:2 a0 6b 51 d :8 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :14 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :1b7 a0 12a
e9 dd :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 65 b7
:2 19 3c b7 :2 19 3c b7 :2 a0 6b
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
:2 a0 6b :2 6e 7e :2 a0 6b b4 2e
7e 6e b4 2e 7e :2 a0 6b b4
2e a5 57 b7 19 3c :9 a0 12a
e9 dd :2 a0 65 b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c :7 a0 12a e9 dd
:2 a0 65 b7 a4 b1 11 4f b7
a6 9 a4 b1 11 68 4f 1d
17 b5 
34ca
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 5e
5a 30 66 6f 6b 59 77 84
80 56 8c 95 91 7f 9d aa
a6 7c b2 bb b7 a5 c3 d0
cc a2 d8 e1 dd cb e9 f6
f2 c8 fe 107 103 f1 10f 11c
118 ee 124 12d 129 117 135 142
13e 114 14a 153 14f 13d 15b 168
164 13a 170 179 175 163 181 18e
18a 160 196 19f 19b 189 1a7 1b4
1b0 186 1bc 1c5 1c1 1af 1cd 1da
1d6 1ac 1e2 1eb 1e7 1d5 1f3 200
1fc 1d2 208 211 20d 1fb 219 1f8
21e 222 226 22a 22d 231 24e 239
23d 240 241 249 238 26b 259 235
25d 25e 266 258 288 276 255 27a
27b 283 275 2a5 293 272 297 298
2a0 292 2c2 2b0 28f 2b4 2b5 2bd
2af 2df 2cd 2ac 2d1 2d2 2da 2cc
2fc 2ea 2c9 2ee 2ef 2f7 2e9 319
307 2e6 30b 30c 314 306 336 324
303 328 329 331 323 353 341 320
345 346 34e 340 370 35e 33d 362
363 36b 35d 38d 37b 35a 37f 380
388 37a 3aa 398 377 39c 39d 3a5
397 3c7 3b5 394 3b9 3ba 3c2 3b4
3e4 3d2 3b1 3d6 3d7 3df 3d1 401
3ef 3ce 3f3 3f4 3fc 3ee 41e 40c
3eb 410 411 419 40b 43b 429 408
42d 42e 436 428 458 446 425 44a
44b 453 445 475 463 442 467 468
470 462 492 480 45f 484 485 48d
47f 4ae 49d 4a1 4a9 47c 4ca 4b5
4b9 4bc 4bd 4c5 49c 4e7 4d5 499
4d9 4da 4e2 4d4 504 4f2 4d1 4f6
4f7 4ff 4f1 521 50f 4ee 513 514
51c 50e 53e 52c 50b 530 531 539
52b 55b 549 528 54d 54e 556 548
578 566 545 56a 56b 573 565 595
583 562 587 588 590 582 5b2 5a0
57f 5a4 5a5 5ad 59f 5cf 5bd 59c
5c1 5c2 5ca 5bc 5ec 5da 5b9 5de
5df 5e7 5d9 608 5f7 5fb 5d6 603
5f6 624 613 617 5f3 61f 612 640
62f 633 60f 63b 62e 65c 64b 64f
62b 657 64a 678 667 66b 647 673
666 694 683 687 663 68f 682 6b0
69f 6a3 67f 6ab 69e 6cc 6bb 6bf
69b 6c7 6ba 6e8 6d7 6db 6b7 6e3
6d6 704 6f3 6f7 6d3 6ff 6f2 720
70f 713 6ef 71b 70e 73c 72b 72f
70b 737 72a 758 747 74b 727 753
746 774 763 767 743 76f 762 790
77f 783 75f 78b 77e 7ac 79b 79f
77b 7a7 79a 7c8 7b7 7bb 797 7c3
7b6 7e4 7d3 7d7 7b3 7df 7d2 800
7ef 7f3 7cf 7fb 7ee 81c 80b 80f
7eb 817 80a 838 827 82b 807 833
826 854 843 847 823 84f 842 870
85f 863 83f 86b 85e 88c 87b 87f
85b 887 87a 8a8 897 89b 877 8a3
896 8c4 8b3 8b7 893 8bf 8b2 8e0
8cf 8d3 8af 8db 8ce 8fc 8eb 8ef
8cb 8f7 8ea 918 907 90b 8e7 913
906 934 923 927 903 92f 922 950
93f 943 91f 94b 93e 96c 95b 95f
93b 967 95a 988 977 97b 957 983
976 9a5 993 973 997 998 9a0 992
9c1 9b0 9b4 98f 9bc 9af 9dd 9cc
9d0 9ac 9d8 9cb 9f9 9e8 9ec 9c8
9f4 9e7 a16 a04 9e4 a08 a09 a11
a03 a33 a21 a00 a25 a26 a2e a20
a50 a3e a1d a42 a43 a4b a3d a6c
a5b a5f a3a a67 a5a a88 a77 a7b
a57 a83 a76 aa5 a93 a73 a97 a98
aa0 a92 ac2 ab0 a8f ab4 ab5 abd
aaf adf acd aac ad1 ad2 ada acc
afc aea ac9 aee aef af7 ae9 b19
b07 ae6 b0b b0c b14 b06 b36 b24
b03 b28 b29 b31 b23 b52 b41 b45
b20 b4d b40 b6e b5d b61 b3d b69
b5c b8a b79 b7d b59 b85 b78 ba6
b95 b99 b75 ba1 b94 bc2 bb1 bb5
b91 bbd bb0 bde bcd bd1 bad bd9
bcc bfa be9 bed bc9 bf5 be8 c16
c05 c09 be5 c11 c04 c33 c21 c01
c25 c26 c2e c20 c4f c3e c42 c1d
c4a c3d c6b c5a c5e c66 c3a c83
c72 c76 c7e c59 c9f c8e c92 c9a
c56 cb7 ca6 caa cb2 c8d cd3 cc2
cc6 cce c8a ceb cda cde ce6 cc1
d07 cf6 cfa d02 cbe d26 d0e d12
d16 d19 d21 cf5 d2d d31 cf2 d42
d45 d49 d4d d51 d55 d59 d5d d61
d65 d69 d75 d7a d7c d88 d8c d8e
d92 da3 da4 da7 dab daf db3 db7
dbb dbf dc3 dc7 dcb dcf dd3 dd7
ddb ddf de3 de7 deb df7 dfc dfe
e0a e0e e2c e14 e18 e1c e1f e27
e13 e4c e37 e3b e10 e3f e47 e36
e6c e57 e5b e33 e5f e67 e56 e8c
e77 e7b e53 e7f e87 e76 e93 e97
e73 e9b e9f ea3 ea6 eab eac 1
eae eb3 eb7 ebb ebe ec3 ec7 ecb
ece ed3 ed4 ed6 edb ede ee2 ee3
ee8 eed ef0 ef5 ef6 efb efe f02
f03 f08 f0b f10 f11 f16 f19 f1e
f1f f24 f27 f2c f2d f32 f35 f39
f3a f3f f42 f47 f48 f4d f50 f55
f56 f5b f5e f63 f64 f69 f6c f70
f71 f76 f79 f7e f7f f84 f87 f8c
f8d f92 f95 f99 f9d fa1 fa2 fa4
fa9 faa fac fad fb2 fb5 fba fbb
fc0 fc3 fc7 fcb fcf fd0 fd2 fd7
fd8 fda fdb fe0 fe3 fe8 fe9 fee
ff1 ff5 ff9 ffd ffe 1000 1005 1006
1008 1009 100e 1011 1016 1017 101c 101f
1023 1027 102b 102c 102e 1033 1034 1036
1037 103c 103f 1044 1045 104a 104d 1051
1055 1059 105a 105c 1061 1062 1064 1065
106a 106d 1072 1073 1078 107b 107f 1083
1087 1088 108a 108f 1090 1092 1093 1098
109b 10a0 10a1 10a6 10a9 10ad 10b1 10b5
10b6 10b8 10bd 10be 10c0 10c1 10c6 10c9
10ce 10cf 10d4 10d7 10db 10df 10e3 10e4
10e6 10eb 10ec 10ee 10ef 10f4 10f7 10fc
10fd 1102 1105 110a 110b 1110 1113 1117
1118 111d 1120 1125 1126 112b 112e 1133
1134 1139 113c 1141 1142 1147 114a 114e
114f 1154 1157 115c 115d 1162 1165 116a
116b 1170 1173 1178 1179 117e 1181 1185
1186 118b 118e 1193 1194 1199 119c 11a1
11a2 11a7 11aa 11af 11b0 11b5 11b8 11bc
11bd 11c2 11c5 11ca 11cb 11d0 11d3 11d8
11d9 11de 11e1 11e6 11e7 11ec 11ef 11f3
11f4 11f9 11fc 1201 1202 1207 120a 120f
1210 1215 1218 121c 1220 1224 1225 1227
122c 122d 122f 1230 1235 1238 123d 123e
1243 1246 124b 124c 1251 1254 1258 1259
125e 1261 1266 1267 126c 126f 1274 1275
127a 127d 1282 1283 1288 128b 128f 1290
1295 1298 129d 129e 12a3 12a6 12ab 12ac
12b1 12b4 12b9 12ba 12bf 12c2 12c6 12c7
12cc 12cf 12d4 12d5 12da 12dd 12e2 12e3
12e8 12eb 12f0 12f1 12f6 12f9 12fd 12fe
1303 1306 130b 130c 1311 1314 1319 131a
131f 1322 1326 132a 132e 132f 1331 1336
1337 1339 133a 133f 1342 1347 1348 134d
1350 1354 1358 135c 135d 135f 1364 1365
1367 1368 136d 1370 1375 1376 137b 137e
1382 1386 138a 138b 138d 1392 1393 1395
1396 139b 139e 13a3 13a4 13a9 13ac 13b0
13b4 13b8 13b9 13bb 13c0 13c1 13c3 13c4
13c9 13cc 13d1 13d2 13d7 13da 13df 13e0
13e5 13e8 13ec 13ed 13f2 13f5 13fa 13fb
1400 1403 1408 1409 140e 1411 1416 1417
141c 141f 1423 1424 1429 142c 1431 1432
1437 143a 143f 1440 1445 1446 144b 144d
1451 1454 1458 145c 145f 1463 1467 146a
146d 1472 1475 1478 147b 147c 1481 1482
1 1484 1489 148d 1491 1494 1499 149e
14a1 14a5 14a6 14ab 14ac 14b1 14b3 14b7
14ba 14be 14c2 14c6 14ca 14ce 14d2 14d6
14da 14de 14e2 14e6 14ea 14ee 14f2 14f6
14fa 14fe 1502 1506 150a 150e 1512 1516
151a 151e 1522 1526 152a 152e 1532 1536
153a 153e 1542 1546 154a 154e 1552 1556
155a 155e 1562 1566 156a 156e 1572 1576
157a 157e 1582 1586 158a 158e 1592 1596
159a 159e 15a2 15a6 15aa 15ae 15b2 15b6
15ba 15be 15c2 15c6 15c9 15cd 15d1 15d4
15d8 15dc 15e0 15e3 15e4 15e6 15ea 15ed
15f1 15f4 15f5 15fa 15fd 1601 1604 1605
160a 160d 1 1610 1615 1619 161d 1620
1624 1628 162b 162e 1633 1636 1639 163c
163d 1642 1643 1 1645 164a 164e 1652
1655 165a 165f 1662 1666 1667 166c 166f
1674 1675 167a 167d 1682 1683 1688 168b
168f 1693 1697 169b 169e 169f 16a1 16a6
16a7 16a9 16aa 16af 16b0 16b5 16b7 16bb
16be 16c2 16c6 16c9 16cd 16d1 16d4 16d7
16dc 16df 16e2 16e5 16e6 16eb 16ec 1
16ee 16f3 16f7 16fb 16fe 1703 1708 170b
170f 1710 1715 1716 171b 171d 1721 1724
1728 172c 172f 1733 1737 173a 173e 173f
1744 1746 174a 174d 1751 1754 1755 175a
175d 1760 1764 1767 1768 176d 1770 1
1773 1778 177c 177f 1780 1785 1788 1
178b 1790 1794 1797 1798 179d 17a0 1
17a3 17a8 17ac 17b0 17b3 17b4 17b6 17ba
17bd 17c1 17c4 17c5 17ca 1 17cd 17d2
17d6 17d9 17da 17df 17e2 17e5 17e9 17ed
17f0 17f1 17f3 17f7 17fa 17fe 1801 1802
1807 1 180a 180f 1813 1817 181a 181e
1822 1825 1828 182d 1830 1833 1836 1837
183c 183d 1 183f 1844 1848 184c 184f
1854 1859 185c 1860 1861 1866 1869 186e
186f 1874 1877 187c 187d 1882 1885 1889
188d 1891 1895 1898 1899 189b 18a0 18a1
18a3 18a4 18a9 18aa 18af 18b1 18b5 18b8
18bc 18c0 18c3 18c7 18cb 18ce 18d1 18d6
18d9 18dc 18df 18e0 18e5 18e6 1 18e8
18ed 18f1 18f5 18f8 18fd 1902 1905 1909
190a 190f 1910 1915 1917 191b 191e 1922
1926 1929 192d 1931 1934 1938 1939 193e
1942 1944 1948 194b 194c 1951 1954 1957
195b 195e 195f 1964 1967 1 196a 196f
1973 1977 197a 197e 1982 1985 1988 198d
1990 1993 1996 1997 199c 199d 1 199f
19a4 19a8 19ac 19af 19b4 19b9 19bc 19c0
19c1 19c6 19c9 19ce 19cf 19d4 19d7 19dc
19dd 19e2 19e5 19e9 19ed 19f1 19f5 19f8
19f9 19fb 1a00 1a01 1a03 1a04 1a09 1a0a
1a0f 1a11 1a15 1a18 1a1c 1a20 1a23 1a27
1a2b 1a2e 1a31 1a36 1a39 1a3c 1a3f 1a40
1a45 1a46 1 1a48 1a4d 1a51 1a55 1a58
1a5d 1a62 1a65 1a69 1a6a 1a6f 1a70 1a75
1a77 1a7b 1a7e 1a82 1a86 1a89 1a8d 1a91
1a94 1a98 1a99 1a9e 1aa0 1aa4 1aa8 1aab
1aad 1ab1 1ab4 1ab8 1abc 1abf 1ac0 1ac2
1ac5 1ac8 1ac9 1ace 1ad2 1ad6 1ad9 1ada
1adc 1adf 1ae2 1ae3 1 1ae8 1aed 1af1
1af5 1af8 1af9 1afb 1afe 1b01 1b02 1
1b07 1b0c 1b10 1b14 1b17 1b1b 1b1f 1b22
1b25 1b2a 1b2d 1b30 1b33 1b34 1b39 1b3a
1 1b3c 1b41 1b45 1b49 1b4c 1b51 1b56
1b59 1b5d 1b5e 1b63 1b66 1b6b 1b6c 1b71
1b74 1b79 1b7a 1b7f 1b82 1b86 1b8a 1b8e
1b92 1b95 1b96 1b98 1b9d 1b9e 1ba0 1ba1
1ba6 1ba7 1bac 1bae 1bb2 1bb5 1bb9 1bbd
1bc0 1bc4 1bc8 1bcb 1bce 1bd3 1bd6 1bd9
1bdc 1bdd 1be2 1be3 1 1be5 1bea 1bee
1bf2 1bf5 1bfa 1bff 1c02 1c06 1c07 1c0c
1c0d 1c12 1c14 1c18 1c1b 1c1f 1c23 1c26
1c2a 1c2e 1c31 1c35 1c36 1c3b 1c3d 1c41
1c44 1c48 1c4b 1c4c 1c51 1c54 1c57 1c5b
1c5e 1c62 1c64 1c68 1c6c 1c70 1c72 1c76
1c7a 1c7d 1c81 1c85 1c88 1c89 1c8b 1c8f
1c92 1c96 1c99 1c9a 1c9f 1ca2 1ca6 1ca9
1caa 1caf 1cb2 1 1cb5 1cba 1cbe 1cc1
1cc2 1cc7 1cca 1 1ccd 1cd2 1cd6 1cda
1cde 1ce2 1ce6 1cea 1cee 1cf2 1cfe 1d02
1d06 1d09 1d0d 1d11 1d13 1 1d17 1d1b
1d1f 1d22 1d26 1d2a 1d2e 1d32 1d35 1d39
1d3d 1d40 1d43 1d48 1d4b 1d4e 1d51 1d52
1d57 1d58 1 1d5a 1d5f 1d63 1d67 1d6a
1d6f 1d74 1d77 1d7b 1d7c 1d81 1d84 1d89
1d8a 1d8f 1d92 1d97 1d98 1d9d 1da0 1da4
1da5 1daa 1dad 1db2 1db3 1db8 1dbb 1dbf
1dc3 1dc6 1dc9 1dca 1dcc 1dcd 1dd2 1dd3
1dd8 1dda 1dde 1de1 1de3 1de7 1de9 1df5
1df7 1df9 1dfa 1dff 1e03 1e05 1e11 1e13
1e17 1e1b 1e1e 1e22 1e25 1e29 1e2c 1e2d
1e32 1e35 1e39 1e3d 1e40 1e41 1e43 1e46
1e49 1e4a 1e4f 1 1e52 1e57 1e5b 1e5f
1e62 1e66 1e6a 1e6d 1e70 1e75 1e78 1e7b
1e7e 1e7f 1e84 1e85 1 1e87 1e8c 1e90
1e94 1e97 1e9c 1ea1 1ea4 1ea8 1ea9 1eae
1eb1 1eb6 1eb7 1ebc 1ebf 1ec4 1ec5 1eca
1ecd 1ed1 1ed5 1ed9 1edd 1ee0 1ee1 1ee3
1ee8 1ee9 1eeb 1eec 1ef1 1ef2 1ef7 1ef9
1efd 1f00 1f04 1f08 1f0b 1f0f 1f13 1f16
1f19 1f1e 1f21 1f24 1f27 1f28 1f2d 1f2e
1 1f30 1f35 1f39 1f3d 1f40 1f45 1f4a
1f4d 1f51 1f52 1f57 1f58 1f5d 1f5f 1f63
1f66 1f6a 1f6e 1f71 1f75 1f79 1f7c 1f80
1f81 1f86 1f88 1f8c 1f8f 1f93 1f96 1f9a
1f9c 1fa0 1fa3 1fa7 1faa 1fab 1fb0 1fb3
1fb6 1fba 1fbd 1fbe 1fc3 1fc6 1 1fc9
1fce 1fd2 1fd6 1fda 1fe6 1fea 1fee 1ff1
1ff5 1ff9 1ffb 1 1fff 2003 2007 200a
200e 2012 2016 201a 201d 2021 2025 2028
202b 2030 2033 2036 2039 203a 203f 2040
1 2042 2047 204b 204f 2052 2057 205c
205f 2063 2064 2069 206c 2071 2072 2077
207a 207f 2080 2085 2088 208c 208d 2092
2095 209a 209b 20a0 20a3 20a7 20ab 20ae
20b1 20b2 20b4 20b5 20ba 20bb 20c0 20c2
20c6 20c9 20cb 20cf 20d1 20dd 20df 20e1
20e2 20e7 20eb 20ed 20f9 20fb 20fd 2101
2104 2108 210c 2110 2114 2118 211c 211f
2123 2127 212b 212e 212f 2131 2135 2139
213c 213d 213f 2142 2145 2146 2148 214c
2150 2154 2158 215c 215f 2160 2162 2166
216a 216d 216e 2170 2174 2178 217c 2180
2183 2187 218b 218f 2192 2193 2195 2199
219d 21a0 21a1 21a3 21a6 21a9 21aa 21ac
21b0 21b4 21b8 21bc 21c0 21c3 21c4 21c6
21ca 21ce 21d1 21d2 21d4 21d8 21dc 21e0
21e4 21e7 21e8 21ea 21ee 21f1 21f5 21f8
21f9 21fe 2201 2202 2204 2207 2209 220d
2211 2215 2219 221c 221d 221f 2222 2225
2226 222b 222f 2232 2236 223a 223e 2242
2246 224a 2256 225a 225e 2261 2265 2269
226b 1 226f 2273 2277 227a 227e 2282
2286 228a 228d 2291 2295 2298 229b 22a0
22a3 22a6 22a9 22aa 22af 22b0 1 22b2
22b7 22bb 22bf 22c2 22c7 22cc 22cf 22d3
22d4 22d9 22dc 22e1 22e2 22e7 22ea 22ef
22f0 22f5 22f8 22fc 22fd 2302 2305 230a
230b 2310 2313 2317 231b 231e 2321 2322
2324 2325 232a 232b 2330 2332 2336 2339
233b 233f 2341 234d 234f 2351 2352 2357
235b 235d 2369 236b 236f 2373 2376 2377
2379 237c 237f 2380 2385 2389 238d 2391
2395 2399 23a5 23a9 23ad 23b0 23b4 23b8
23ba 1 23be 23c2 23c6 23c9 23cd 23d1
23d5 23d9 23dc 23e0 23e4 23e7 23ea 23ef
23f2 23f5 23f8 23f9 23fe 23ff 1 2401
2406 240a 240e 2411 2416 241b 241e 2422
2423 2428 242b 2430 2431 2436 2439 243e
243f 2444 2447 244b 244c 2451 2454 2459
245a 245f 2462 2466 246a 246d 2470 2471
2473 2474 2479 247a 247f 2481 2485 2488
248a 248e 2490 249c 249e 24a0 24a1 24a6
24aa 24ac 24b8 24ba 24be 24c2 24c5 24c9
24ce 24cf 24d1 24d4 24d7 24d8 24dd 24e1
24e5 24e8 24ec 24f0 24f3 24f6 24fb 24fe
2501 2504 2505 250a 250b 1 250d 2512
2516 251a 251d 2522 2527 252a 252e 252f
2534 2537 253c 253d 2542 2545 254a 254b
2550 2553 2557 255b 255f 2563 2566 2567
2569 256e 256f 2571 2572 2577 257a 257f
2580 2585 2588 258d 258e 2593 2596 259a
259b 25a0 25a3 25a8 25a9 25ae 25af 25b4
25b6 25ba 25bd 25c1 25c5 25c8 25cc 25d0
25d3 25d6 25db 25de 25e1 25e4 25e5 25ea
25eb 1 25ed 25f2 25f6 25fa 25fd 2602
2607 260a 260e 260f 2614 2615 261a 261c
2620 2623 2627 262b 262e 2632 2636 2639
263d 2641 2642 2647 2649 264d 2650 2652
2656 2659 265d 2661 2665 2669 266c 266d
266f 2670 2672 2676 267a 267e 2681 2682
2684 2687 268a 268b 2690 2694 2698 269c
26a0 26a3 26a4 26a6 26a7 26a9 26ad 26b1
26b5 26b8 26b9 26bb 26be 26c1 26c2 26c7
26cb 26cf 26d2 26d6 26da 26dd 26e0 26e5
26e8 26eb 26ee 26ef 26f4 26f5 1 26f7
26fc 2700 2704 2707 270c 2711 2714 2718
2719 271e 2721 2726 2727 272c 272f 2734
2735 273a 273d 2741 2745 2749 274d 2750
2751 2753 2758 2759 275b 275c 2761 2762
2767 2769 276d 2770 2774 2778 277b 277f
2783 2786 2789 278e 2791 2794 2797 2798
279d 279e 1 27a0 27a5 27a9 27ad 27b0
27b5 27ba 27bd 27c1 27c2 27c7 27c8 27cd
27cf 27d3 27d6 27da 27de 27e1 27e5 27e9
27ec 27f0 27f1 27f6 27f8 27fc 27ff 2803
2807 280b 280e 2812 2814 2818 281b 281f
2823 2827 282b 282f 2832 2833 2835 2838
283b 283c 2841 2845 2849 284d 284f 2853
2857 285a 285e 2862 2865 2868 286d 2870
2873 2876 2877 287c 287d 1 287f 2884
2888 288c 288f 2894 2899 289c 28a0 28a1
28a6 28a9 28ae 28af 28b4 28b7 28bc 28bd
28c2 28c5 28c9 28cd 28d1 28d5 28d8 28d9
28db 28e0 28e1 28e3 28e4 28e9 28ea 28ef
28f1 28f5 28f8 28fc 2900 2903 2907 290b
290e 2911 2916 2919 291c 291f 2920 2925
2926 1 2928 292d 2931 2935 2938 293d
2942 2945 2949 294a 294f 2950 2955 2957
295b 295e 2962 2966 2969 296d 2971 2974
2978 2979 297e 2980 2984 2988 298b 298f
2993 2997 299b 299f 29a3 29a7 29ab 29ac
29ae 29b2 29b6 29ba 29bd 29be 29c0 29c3
29c6 29c7 29cc 29d0 29d4 29d7 29db 29df
29e2 29e5 29ea 29ed 29f0 29f3 29f4 29f9
29fa 1 29fc 2a01 2a05 2a09 2a0c 2a11
2a16 2a19 2a1d 2a1e 2a23 2a26 2a2b 2a2c
2a31 2a34 2a39 2a3a 2a3f 2a42 2a46 2a4a
2a4e 2a4f 2a51 2a56 2a57 2a59 2a5a 2a5f
2a62 2a67 2a68 2a6d 2a70 2a75 2a76 2a7b
2a7e 2a82 2a83 2a88 2a8b 2a90 2a91 2a96
2a97 2a9c 2a9e 2aa2 2aa5 2aa9 2aad 2ab0
2ab4 2ab8 2abb 2abe 2ac3 2ac6 2ac9 2acc
2acd 2ad2 2ad3 1 2ad5 2ada 2ade 2ae2
2ae5 2aea 2aef 2af2 2af6 2af7 2afc 2afd
2b02 2b04 2b08 2b0b 2b0f 2b13 2b16 2b1a
2b1e 2b21 2b22 2b24 2b28 2b2c 2b2d 2b32
2b34 2b38 2b3b 2b3f 2b43 2b46 2b47 2b49
2b4d 2b50 2b54 2b57 2b58 2b5d 2b61 2b65
2b68 2b6c 2b70 2b73 2b76 2b7b 2b7e 2b81
2b84 2b85 2b8a 2b8b 1 2b8d 2b92 2b96
2b9a 2b9d 2ba2 2ba7 2baa 2bae 2baf 2bb4
2bb7 2bbc 2bbd 2bc2 2bc5 2bca 2bcb 2bd0
2bd3 2bd7 2bdb 2bdf 2be3 2be6 2be7 2be9
2bee 2bef 2bf1 2bf2 2bf7 2bfa 2bff 2c00
2c05 2c08 2c0d 2c0e 2c13 2c16 2c1a 2c1b
2c20 2c23 2c28 2c29 2c2e 2c2f 2c34 2c36
2c3a 2c3d 2c41 2c45 2c48 2c4c 2c50 2c53
2c56 2c5b 2c5e 2c61 2c64 2c65 2c6a 2c6b
1 2c6d 2c72 2c76 2c7a 2c7d 2c82 2c87
2c8a 2c8e 2c8f 2c94 2c95 2c9a 2c9c 2ca0
2ca3 2ca7 2cab 2cae 2cb2 2cb6 2cb9 2cbd
2cc1 2cc2 2cc7 2cc9 2ccd 2cd0 2cd4 2cd8
2cdb 2cdc 2cde 2ce2 2ce5 2ce9 2cec 2ced
2cf2 2cf6 2cfa 2cfe 2d01 2d02 2d04 2d05
2d07 2d0a 2d0d 2d0e 2d13 2d17 2d1b 2d1f
2d23 2d27 2d2b 2d2f 2d33 2d37 2d3b 2d3f
2d43 2d47 2d53 2d57 2d5b 2d5e 2d62 2d66
2d68 1 2d6c 2d70 2d74 2d77 2d7b 2d7f
2d83 2d87 2d8a 2d8e 2d92 2d95 2d98 2d9d
2da0 2da3 2da6 2da7 2dac 2dad 1 2daf
2db4 2db8 2dbc 2dbf 2dc4 2dc9 2dcc 2dd0
2dd1 2dd6 2dd9 2dde 2ddf 2de4 2de7 2dec
2ded 2df2 2df5 2df9 2dfa 2dff 2e02 2e07
2e08 2e0d 2e10 2e14 2e18 2e1b 2e1e 2e1f
2e21 2e22 2e27 2e28 2e2d 2e2f 2e33 2e36
2e38 2e3c 2e3e 2e4a 2e4c 2e4e 2e4f 2e54
2e58 2e5a 2e66 2e68 2e6a 2e6e 2e72 2e76
2e7a 2e7e 2e82 2e86 2e8a 2e8e 2e92 2e96
2e9a 2e9e 2ea2 2ea6 2eaa 2eae 2eb2 2eb6
2eba 2ebe 2ec2 2ec6 2eca 2ece 2ed2 2ed6
2eda 2ede 2ee2 2ee6 2eea 2eee 2ef2 2ef6
2efa 2efe 2f02 2f06 2f12 2f16 2f1a 2f1d
2f21 2f25 2f27 1 2f2b 2f2f 2f33 2f36
2f3a 2f3e 2f42 2f46 2f49 2f4d 2f51 2f54
2f57 2f5c 2f5f 2f62 2f65 2f66 2f6b 2f6c
1 2f6e 2f73 2f77 2f7b 2f7e 2f83 2f88
2f8b 2f8f 2f90 2f95 2f98 2f9d 2f9e 2fa3
2fa6 2fab 2fac 2fb1 2fb4 2fb8 2fb9 2fbe
2fc1 2fc6 2fc7 2fcc 2fcf 2fd3 2fd7 2fda
2fdd 2fde 2fe0 2fe1 2fe6 2fe7 2fec 2fee
2ff2 2ff5 2ff7 2ffb 2ffd 3009 300b 300d
300e 3013 3017 3019 3025 3027 3029 302d
3031 3034 3038 303c 303f 3043 3046 304a
304d 304e 3053 3056 305a 305e 3061 3065
3069 306c 306f 3074 3077 307a 307d 307e
3083 3084 1 3086 308b 308f 3093 3096
309b 30a0 30a3 30a7 30a8 30ad 30b0 30b5
30b6 30bb 30be 30c3 30c4 30c9 30cc 30d0
30d4 30d8 30dc 30df 30e0 30e2 30e7 30e8
30ea 30eb 30f0 30f3 30f8 30f9 30fe 3101
3106 3107 310c 310f 3113 3114 3119 311c
3121 3122 3127 3128 312d 312f 3133 3136
313a 313e 3141 3145 3149 314c 314f 3154
3157 315a 315d 315e 3163 3164 1 3166
316b 316f 3173 3176 317b 3180 3183 3187
3188 318d 318e 3193 3195 3199 319c 31a0
31a4 31a7 31ab 31af 31b2 31b6 31ba 31bb
31c0 31c2 31c6 31c9 31cd 31cf 31d3 31d7
31da 31db 31dd 31e1 31e4 31e8 31eb 31ec
31f1 31f5 31f9 31fd 3201 3205 3209 320d
3211 3215 3221 3225 3229 322c 3230 3234
3236 1 323a 323e 3242 3245 3249 324d
3251 3255 3258 325c 3260 3263 3266 326b
326e 3271 3274 3275 327a 327b 1 327d
3282 3286 328a 328d 3292 3297 329a 329e
329f 32a4 32a7 32ac 32ad 32b2 32b5 32ba
32bb 32c0 32c3 32c7 32c8 32cd 32d0 32d5
32d6 32db 32de 32e2 32e6 32e9 32ec 32ed
32ef 32f0 32f5 32f6 32fb 32fd 3301 3304
3306 330a 330c 3318 331a 331c 331d 3322
3326 3328 3334 3336 333a 333e 3341 3345
3348 334c 334f 3350 3355 3358 335c 3360
3363 3367 336b 336e 3371 3376 3379 337c
337f 3380 3385 3386 1 3388 338d 3391
3395 3398 339d 33a2 33a5 33a9 33aa 33af
33b2 33b7 33b8 33bd 33c0 33c5 33c6 33cb
33ce 33d2 33d6 33da 33de 33e1 33e2 33e4
33e9 33ea 33ec 33ed 33f2 33f5 33fa 33fb
3400 3403 3408 3409 340e 3411 3415 3416
341b 341e 3423 3424 3429 342a 342f 3431
3435 3438 343c 3440 3443 3447 344b 344e
3451 3456 3459 345c 345f 3460 3465 3466
1 3468 346d 3471 3475 3478 347d 3482
3485 3489 348a 348f 3490 3495 3497 349b
349e 34a2 34a6 34a9 34ad 34b1 34b4 34b8
34bc 34bd 34c2 34c4 34c8 34cb 34cf 34d3
34d7 34db 34df 34e3 34e7 34eb 34ef 34f3
34f7 34fb 34ff 3503 3507 350b 350f 3513
3517 3523 3527 352b 352e 3532 3536 3538
1 353c 3540 3544 3547 354b 354f 3553
3557 355a 355e 3562 3565 3568 356d 3570
3573 3576 3577 357c 357d 1 357f 3584
3588 358c 358f 3594 3599 359c 35a0 35a1
35a6 35a9 35ae 35af 35b4 35b7 35bc 35bd
35c2 35c5 35c9 35ca 35cf 35d2 35d7 35d8
35dd 35e0 35e4 35e8 35eb 35ee 35ef 35f1
35f2 35f7 35f8 35fd 35ff 3603 3606 3608
360c 360e 361a 361c 361e 361f 3624 3628
362a 3636 3638 363c 3640 3643 3647 364a
364e 3651 3652 3657 365a 365e 3662 3665
3669 366d 3670 3673 3678 367b 367e 3681
3682 3687 3688 1 368a 368f 3693 3697
369a 369f 36a4 36a7 36ab 36ac 36b1 36b4
36b9 36ba 36bf 36c2 36c7 36c8 36cd 36d0
36d4 36d8 36dc 36e0 36e3 36e4 36e6 36eb
36ec 36ee 36ef 36f4 36f7 36fc 36fd 3702
3705 370a 370b 3710 3713 3717 3718 371d
3720 3725 3726 372b 372c 3731 3733 3737
373a 373e 3742 3745 3749 374d 3750 3753
3758 375b 375e 3761 3762 3767 3768 1
376a 376f 3773 3777 377a 377f 3784 3787
378b 378c 3791 3792 3797 3799 379d 37a0
37a4 37a8 37ab 37af 37b3 37b6 37ba 37be
37bf 37c4 37c6 37ca 37cd 37d1 37d4 37d5
37da 37dd 37e1 37e5 37e9 37ec 37f0 37f4
37f8 37fc 37fd 37ff 3803 3805 3809 380c
380e 3812 3816 381a 381d 3821 3825 3828
382b 3830 3833 3836 3839 383a 383f 3840
1 3842 3847 384b 384f 3852 3857 385c
385f 3863 3864 3869 386c 3871 3872 3877
387a 387f 3880 3885 3888 388c 3890 3894
3898 389b 389c 389e 38a3 38a4 38a6 38a7
38ac 38af 38b4 38b5 38ba 38bd 38c2 38c3
38c8 38cb 38cf 38d0 38d5 38d8 38dd 38de
38e3 38e4 38e9 38eb 38ef 38f2 38f6 38fa
38fd 3901 3905 3908 390b 3910 3913 3916
3919 391a 391f 3920 1 3922 3927 392b
392f 3932 3937 393c 393f 3943 3944 3949
394a 394f 3951 3955 3958 395c 3960 3963
3967 396b 396e 3972 3976 3977 397c 397e
3982 3986 3989 398d 3991 3994 3995 3997
399b 399e 39a2 39a5 39a6 39ab 39af 39b3
39b7 39bb 39bf 39c3 39c7 39cb 39cf 39d3
39d7 39db 39df 39e3 39e7 39eb 39ef 39f3
39f7 39fb 39ff 3a0b 3a0f 3a13 3a16 3a1a
3a1e 3a20 1 3a24 3a28 3a2c 3a2f 3a33
3a37 3a3b 3a3f 3a42 3a46 3a4a 3a4d 3a50
3a55 3a58 3a5b 3a5e 3a5f 3a64 3a65 1
3a67 3a6c 3a70 3a74 3a77 3a7c 3a81 3a84
3a88 3a89 3a8e 3a91 3a96 3a97 3a9c 3a9f
3aa4 3aa5 3aaa 3aad 3ab1 3ab2 3ab7 3aba
3abf 3ac0 3ac5 3ac8 3acc 3ad0 3ad3 3ad6
3ad7 3ad9 3ada 3adf 3ae0 3ae5 3ae7 3aeb
3aee 3af0 3af4 3af6 3b02 3b04 3b06 3b07
3b0c 3b10 3b12 3b1e 3b20 3b24 3b28 3b2b
3b2f 3b32 3b36 3b39 3b3a 3b3f 3b42 3b46
3b4a 3b4d 3b51 3b55 3b58 3b5b 3b60 3b63
3b66 3b69 3b6a 3b6f 3b70 1 3b72 3b77
3b7b 3b7f 3b82 3b87 3b8c 3b8f 3b93 3b94
3b99 3b9c 3ba1 3ba2 3ba7 3baa 3baf 3bb0
3bb5 3bb8 3bbc 3bc0 3bc4 3bc8 3bcb 3bcc
3bce 3bd3 3bd4 3bd6 3bd7 3bdc 3bdf 3be4
3be5 3bea 3bed 3bf2 3bf3 3bf8 3bfb 3bff
3c00 3c05 3c08 3c0d 3c0e 3c13 3c14 3c19
3c1b 3c1f 3c22 3c26 3c2a 3c2d 3c31 3c35
3c38 3c3b 3c40 3c43 3c46 3c49 3c4a 3c4f
3c50 1 3c52 3c57 3c5b 3c5f 3c62 3c67
3c6c 3c6f 3c73 3c74 3c79 3c7a 3c7f 3c81
3c85 3c88 3c8c 3c90 3c93 3c97 3c9b 3c9e
3ca2 3ca6 3ca7 3cac 3cb0 3cb2 3cb6 3cba
3cbd 3cc1 3cc4 3cc8 3ccb 3ccc 3cd1 3cd4
3cd8 3cdc 3cdf 3ce2 3ce3 3ce5 3ce8 3ced
3cee 3cf3 3cf7 3cfb 3cfe 3cff 3d01 3d04
3d07 3d08 3d0d 3d11 3d15 3d18 3d19 3d1b
3d1f 3d22 3d26 3d29 3d2a 3d2c 3d2d 1
3d32 3d37 1 3d3a 3d3f 3d43 3d47 3d4a
3d4b 3d4d 3d51 3d54 3d58 3d5b 3d5c 3d5e
3d5f 1 3d64 3d69 3d6d 3d71 3d74 3d78
3d7c 3d7f 3d82 3d87 3d8a 3d8d 3d90 3d91
3d96 3d97 1 3d99 3d9e 3da2 3da6 3da9
3dae 3db3 3db6 3dba 3dbb 3dc0 3dc3 3dc8
3dc9 3dce 3dd1 3dd6 3dd7 3ddc 3ddf 3de3
3de7 3deb 3def 3df2 3df3 3df5 3dfa 3dfb
3dfd 3dfe 3e03 3e06 3e0b 3e0c 3e11 3e14
3e19 3e1a 3e1f 3e22 3e26 3e27 3e2c 3e2f
3e34 3e35 3e3a 3e3b 3e40 3e42 3e46 3e49
3e4d 3e51 3e54 3e58 3e5c 3e5f 3e62 3e67
3e6a 3e6d 3e70 3e71 3e76 3e77 1 3e79
3e7e 3e82 3e86 3e89 3e8e 3e93 3e96 3e9a
3e9b 3ea0 3ea1 3ea6 3ea8 3eac 3eaf 3eb3
3eb7 3eba 3ebe 3ec2 3ec5 3ec9 3ecd 3ece
3ed3 3ed5 3ed9 3edc 3ede 3ee2 3ee6 3ee9
3eeb 3eef 3ef2 3ef4 3ef8 3efb 3eff 3f03
3f06 3f07 3f09 3f0c 3f0f 3f10 3f15 3f19
3f1d 3f20 3f21 3f23 3f27 3f2a 3f2e 3f31
3f32 3f37 3f3b 3f3e 3f3f 3f44 1 3f47
3f4c 3f50 3f54 3f57 3f58 3f5a 3f5d 3f60
3f61 1 3f66 3f6b 3f6f 3f73 3f76 3f7a
3f7e 3f81 3f84 3f89 3f8c 3f8f 3f92 3f93
3f98 3f99 1 3f9b 3fa0 3fa4 3fa8 3fab
3fb0 3fb5 3fb8 3fbc 3fbd 3fc2 3fc5 3fca
3fcb 3fd0 3fd3 3fd8 3fd9 3fde 3fe1 3fe5
3fe9 3fed 3ff1 3ff4 3ff5 3ff7 3ffc 3ffd
3fff 4000 4005 4008 400d 400e 4013 4016
401b 401c 4021 4024 4028 4029 402e 4031
4036 4037 403c 403d 4042 4044 4048 404b
404f 4053 4056 405a 405e 4061 4064 4069
406c 406f 4072 4073 4078 4079 1 407b
4080 4084 4088 408b 4090 4095 4098 409c
409d 40a2 40a3 40a8 40aa 40ae 40b1 40b5
40b9 40bc 40c0 40c4 40c7 40cb 40cf 40d0
40d5 40d7 40db 40de 40e2 40e6 40e9 40ea
40ec 40f0 40f3 40f7 40fa 40fb 4100 4104
4108 410c 4110 4114 4118 411c 4120 4124
4128 412c 4138 413c 4140 4143 4147 414b
414d 1 4151 4155 4159 415c 4160 4164
4168 416c 416f 4173 4177 417a 417d 4182
4185 4188 418b 418c 4191 4192 1 4194
4199 419d 41a1 41a4 41a9 41ae 41b1 41b5
41b6 41bb 41be 41c3 41c4 41c9 41cc 41d1
41d2 41d7 41da 41de 41df 41e4 41e7 41ec
41ed 41f2 41f5 41f9 41fd 4200 4203 4204
4206 4207 420c 420d 4212 4214 4218 421b
421d 4221 4223 422f 4231 4233 4234 4239
423d 423f 424b 424d 4251 4255 4258 425c
425f 4263 4266 4267 426c 426f 4273 4277
427b 427f 4283 428f 4293 4297 429a 429e
42a2 42a4 1 42a8 42ac 42b0 42b3 42b7
42bb 42bf 42c3 42c6 42ca 42ce 42d1 42d4
42d9 42dc 42df 42e2 42e3 42e8 42e9 1
42eb 42f0 42f4 42f8 42fb 4300 4305 4308
430c 430d 4312 4315 431a 431b 4320 4323
4328 4329 432e 4331 4335 4336 433b 433e
4343 4344 4349 434c 4350 4354 4357 435a
435b 435d 435e 4363 4364 4369 436b 436f
4372 4374 4378 437a 4386 4388 438a 438b
4390 4394 4396 43a2 43a4 43a8 43ac 43af
43b3 43b6 43ba 43bd 43be 43c3 43c6 43ca
43ce 43d1 43d5 43d9 43dc 43df 43e4 43e7
43ea 43ed 43ee 43f3 43f4 1 43f6 43fb
43ff 4403 4406 440b 4410 4413 4417 4418
441d 4420 4425 4426 442b 442e 4433 4434
4439 443c 4440 4444 4448 444c 444f 4450
4452 4457 4458 445a 445b 4460 4463 4468
4469 446e 4471 4476 4477 447c 447f 4483
4484 4489 448c 4491 4492 4497 4498 449d
449f 44a3 44a6 44aa 44ae 44b1 44b5 44b9
44bc 44bf 44c4 44c7 44ca 44cd 44ce 44d3
44d4 1 44d6 44db 44df 44e3 44e6 44eb
44f0 44f3 44f7 44f8 44fd 44fe 4503 4505
4509 450c 4510 4514 4517 451b 451f 4522
4526 452a 452b 4530 4532 4536 4539 453b
453f 4542 4544 4548 454b 454d 4551 4554
4558 455c 455f 4560 4562 4565 4568 4569
456e 4572 4576 4579 457a 457c 457f 4582
4583 1 4588 458d 4591 4594 4598 459a
459e 45a1 45a5 45a9 45ac 45ad 45af 45b3
45b6 45ba 45bd 45be 45c3 45c7 45ca 45cb
45d0 45d3 45d7 45dc 45e0 45e4 45e9 45ed
45ef 45f3 45f7 45fb 45ff 4603 4607 4609
460d 4611 4614 4618 461b 461f 4621 4625
4628 462b 462c 4631 4635 463a 463e 4642
4646 464a 464e 4652 4656 4659 465a 465c
4660 4664 4667 4668 466a 466e 4672 4675
4676 4678 467c 4680 4683 4684 4686 468a
468e 4691 4692 4694 4698 469c 469f 46a0
46a2 46a6 46aa 46ad 46ae 46b0 46b4 46b8
46bb 46bc 46be 46c2 46c6 46ca 46cb 46cd
46d1 46d5 46d9 46dc 46dd 46df 46e3 46e6
46ea 46ed 46ee 46f3 46f7 46fb 46fe 4702
4706 4709 470c 4711 4714 4717 471a 471b
4720 4721 1 4723 4728 472c 4730 4733
4738 473d 4740 4744 4745 474a 474d 4752
4753 4758 475b 4760 4761 4766 4769 476d
4771 4775 4779 477c 477d 477f 4784 4785
4787 4788 478d 478e 4793 4795 4799 479c
47a0 47a4 47a7 47ab 47af 47b2 47b5 47ba
47bd 47c0 47c3 47c4 47c9 47ca 1 47cc
47d1 47d5 47d9 47dc 47e1 47e6 47e9 47ed
47ee 47f3 47f4 47f9 47fb 47ff 4802 4806
480a 480d 4811 4815 4818 481c 481d 4822
4826 4828 482c 4830 4833 4834 4836 4839
483c 483d 4842 4846 484a 484d 4851 4855
4858 485b 4860 4863 4866 4869 486a 486f
4870 1 4872 4877 487b 487f 4882 4887
488c 488f 4893 4894 4899 489c 48a1 48a2
48a7 48aa 48af 48b0 48b5 48b8 48bc 48c0
48c4 48c5 48c7 48cc 48cd 48cf 48d0 48d5
48d8 48dd 48de 48e3 48e6 48eb 48ec 48f1
48f4 48f8 48f9 48fe 4901 4906 4907 490c
490d 4912 4914 4918 491b 491f 4923 4926
492a 492e 4931 4934 4939 493c 493f 4942
4943 4948 4949 1 494b 4950 4954 4958
495b 4960 4965 4968 496c 496d 4972 4973
4978 497a 497e 4981 4985 4989 498c 4990
4994 4997 4998 499a 499e 49a2 49a3 49a8
49aa 49ae 49b2 49b5 49b7 49bb 49bf 49c3
49c5 49c9 49cd 49d0 49d4 49d8 49db 49dc
49de 49e1 49e4 49e5 49ea 49ed 49f1 49f5
49f8 49f9 49fb 49fe 4a01 4a02 4a07 1
4a0a 4a0f 4a13 4a17 4a1a 4a1b 4a1d 4a20
4a23 4a24 4a29 4a2c 4a30 4a34 4a37 4a38
4a3a 4a3d 4a40 4a41 4a46 1 4a49 4a4e
4a52 4a55 4a59 4a5d 4a5f 4a63 4a67 4a6a
4a6b 4a6d 4a70 4a73 4a74 4a79 4a7d 4a80
4a84 4a88 4a8a 4a8e 4a92 4a96 4a99 4a9a
4a9c 4a9f 4aa2 4aa3 4aa8 4aab 4aaf 4ab3
4ab6 4ab7 4ab9 4abc 4abf 4ac0 4ac5 1
4ac8 4acd 4ad1 4ad4 4ad8 4adc 4ade 4ae2
4ae6 4aea 4aed 4aee 4af0 4af3 4af6 4af7
4afc 4b00 4b03 4b07 4b09 4b0d 4b11 4b14
4b16 4b1a 4b1d 4b1f 4b23 4b27 4b2a 4b2e
4b32 4b35 4b36 4b38 4b3c 4b3f 4b43 4b46
4b47 4b4c 4b50 4b53 4b57 4b5b 4b5f 4b63
4b67 4b6b 4b6f 4b73 4b77 4b7b 4b7e 4b81
4b82 4b84 4b88 4b8c 4b8d 4b91 4b95 4b99
4b9c 4b9d 4b9f 4ba2 4ba5 4ba6 4bab 4baf
4bb3 4bb4 4bb9 4bbd 4bc1 4bc4 4bc8 4bca
4bce 4bd2 4bd6 4bda 4bde 4bea 4bee 4bf2
4bf5 4bf9 4bfd 4bff 1 4c03 4c07 4c0b
4c0e 4c12 4c16 4c1a 4c1e 4c21 4c25 4c29
4c2c 4c2f 4c34 4c37 4c3a 4c3d 4c3e 4c43
4c44 1 4c46 4c4b 4c4f 4c53 4c56 4c5b
4c60 4c63 4c67 4c68 4c6d 4c70 4c75 4c76
4c7b 4c7e 4c83 4c84 4c89 4c8c 4c90 4c91
4c96 4c99 4c9e 4c9f 4ca4 4ca7 4cab 4caf
4cb2 4cb5 4cb6 4cb8 4cb9 4cbe 4cbf 4cc4
4cc6 4cca 4ccd 4ccf 4cd3 4cd5 4ce1 4ce3
4ce5 4ce6 4ceb 4cef 4cf1 4cfd 4cff 4d03
4d07 4d0a 4d0e 4d11 4d15 4d18 4d19 4d1e
4d21 4d25 4d29 4d2c 4d2d 4d2f 4d32 4d35
4d36 4d3b 4d3f 4d43 4d47 4d4b 4d4f 4d53
4d57 4d5b 4d5f 4d63 4d67 4d73 4d77 4d7b
4d7e 4d82 4d86 4d88 1 4d8c 4d90 4d94
4d97 4d9b 4d9f 4da3 4da7 4daa 4dae 4db2
4db5 4db8 4dbd 4dc0 4dc3 4dc6 4dc7 4dcc
4dcd 1 4dcf 4dd4 4dd8 4ddc 4ddf 4de4
4de9 4dec 4df0 4df1 4df6 4df9 4dfe 4dff
4e04 4e07 4e0c 4e0d 4e12 4e15 4e19 4e1a
4e1f 4e22 4e27 4e28 4e2d 4e30 4e34 4e38
4e3b 4e3e 4e3f 4e41 4e42 4e47 4e48 4e4d
4e4f 4e53 4e56 4e58 4e5c 4e5e 4e6a 4e6c
4e6e 4e6f 4e74 4e78 4e7a 4e86 4e88 4e8c
4e90 4e93 4e97 4e9a 4e9e 4ea1 4ea2 4ea7
4eaa 4eae 4eb1 4eb5 4eb7 4ebb 4ebe 4ec0
4ec4 4ec7 4ec9 4ecd 4ed0 4ed4 4ed6 4eda
4ede 4ee1 4ee3 4ee7 4eeb 4eee 4ef2 4ef5
4ef8 4ef9 4efe 4f02 4f06 4f0a 4f0e 4f12
4f16 4f1a 4f1e 4f22 4f2e 4f32 4f36 4f39
4f3d 4f41 4f43 1 4f47 4f4b 4f4f 4f52
4f56 4f5a 4f5e 4f62 4f65 4f69 4f6d 4f70
4f73 4f78 4f7b 4f7e 4f81 4f82 4f87 4f88
1 4f8a 4f8f 4f93 4f97 4f9a 4f9f 4fa4
4fa7 4fab 4fac 4fb1 4fb4 4fb9 4fba 4fbf
4fc2 4fc7 4fc8 4fcd 4fd0 4fd4 4fd5 4fda
4fdd 4fe2 4fe3 4fe8 4feb 4fef 4ff3 4ff6
4ff9 4ffa 4ffc 4ffd 5002 5003 5008 500a
500e 5011 5013 5017 5019 5025 5027 5029
502a 502f 5033 5035 5041 5043 5047 504b
504f 5053 5057 505b 505f 5063 5067 506b
506f 5073 5077 507b 507f 5083 5087 508b
508f 5093 5097 509b 509f 50a3 50a7 50ab
50af 50b3 50b7 50bb 50bf 50cb 50cf 50d3
50d6 50da 50de 50e0 1 50e4 50e8 50ec
50ef 50f3 50f7 50fb 50ff 5102 5106 510a
510d 5110 5115 5118 511b 511e 511f 5124
5125 1 5127 512c 5130 5134 5137 513c
5141 5144 5148 5149 514e 5151 5156 5157
515c 515f 5164 5165 516a 516d 5171 5172
5177 517a 517f 5180 5185 5188 518c 5190
5193 5196 5197 5199 519a 519f 51a0 51a5
51a7 51ab 51ae 51b0 51b4 51b6 51c2 51c4
51c6 51c7 51cc 51d0 51d2 51de 51e0 51e4
51e8 51eb 51ef 51f2 51f6 51f9 51fa 51ff
5202 5206 520a 520d 5211 5215 5218 521b
5220 5223 5226 5229 522a 522f 5230 1
5232 5237 523b 523f 5242 5247 524c 524f
5253 5254 5259 525c 5261 5262 5267 526a
526f 5270 5275 5278 527c 5280 5284 5288
528b 528c 528e 5293 5294 5296 5297 529c
529f 52a4 52a5 52aa 52ad 52b2 52b3 52b8
52bb 52bf 52c0 52c5 52c8 52cd 52ce 52d3
52d4 52d9 52db 52df 52e2 52e6 52ea 52ed
52f1 52f5 52f8 52fb 5300 5303 5306 5309
530a 530f 5310 1 5312 5317 531b 531f
5322 5327 532c 532f 5333 5334 5339 533a
533f 5341 5345 5348 534c 5350 5353 5357
535b 535e 5362 5366 5367 536c 536e 5372
5375 5379 537d 5381 5384 5385 5387 538a
538d 538e 5393 5398 5399 539b 53a0 53a2
53a6 53aa 53ae 53b2 53b6 53ba 53be 53c2
53c6 53ca 53ce 53d2 53d6 53da 53de 53e2
53e6 53ea 53ee 53f2 53f6 5402 5406 540b
540f 5412 5413 5418 541c 5420 5423 5426
542a 542c 5430 5434 5437 543a 543e 5440
5444 5448 544b 544d 1 5451 5455 5459
545c 5460 5464 5468 546c 546f 5473 5477
547a 547d 5482 5485 5488 548b 548c 5491
5492 1 5494 5499 549d 54a1 54a4 54a9
54ae 54b1 54b5 54b6 54bb 54be 54c3 54c4
54c9 54cc 54d1 54d2 54d7 54da 54de 54df
54e4 54e7 54ec 54ed 54f2 54f5 54f9 54fd
5500 5503 5504 5506 5507 550c 550d 5512
5514 5518 551b 551d 5521 5523 552f 5531
5533 5534 5539 553d 553f 554b 554d 5551
5553 5557 555b 555e 5561 5562 5564 5567
556c 556d 5572 5576 557a 557e 5582 5586
558a 558e 5592 5596 559a 55a6 55aa 55af
55b3 55b6 55b7 55bc 55c0 55c4 55c7 55ca
55ce 55d0 55d4 55d8 55db 55de 55e2 55e4
55e8 55ec 55ef 55f1 1 55f5 55f9 55fd
5600 5604 5608 560c 5610 5613 5617 561b
561e 5621 5626 5629 562c 562f 5630 5635
5636 1 5638 563d 5641 5645 5648 564d
5652 5655 5659 565a 565f 5662 5667 5668
566d 5670 5675 5676 567b 567e 5682 5683
5688 568b 5690 5691 5696 5699 569d 56a1
56a4 56a7 56a8 56aa 56ab 56b0 56b1 56b6
56b8 56bc 56bf 56c1 56c5 56c7 56d3 56d5
56d7 56d8 56dd 56e1 56e3 56ef 56f1 56f3
56f7 56fb 56fe 5702 5706 570a 570e 5712
5716 571a 571e 5722 572e 5732 5737 573b
573e 573f 5744 5748 574c 574f 5752 5756
5758 575c 5760 5763 5766 576a 576c 5770
5774 5777 5779 1 577d 5781 5785 5788
578c 5790 5794 5798 579b 579f 57a3 57a6
57a9 57ae 57b1 57b4 57b7 57b8 57bd 57be
1 57c0 57c5 57c9 57cd 57d0 57d5 57da
57dd 57e1 57e2 57e7 57ea 57ef 57f0 57f5
57f8 57fd 57fe 5803 5806 580a 580b 5810
5813 5818 5819 581e 5821 5825 5829 582c
582f 5830 5832 5833 5838 5839 583e 5840
5844 5847 5849 584d 584f 585b 585d 585f
5860 5865 5869 586b 5877 5879 587d 5881
5885 5889 588d 5891 5895 5899 589d 58a9
58ad 58b2 58b6 58b9 58ba 58bf 58c3 58c7
58ca 58cd 58d1 58d3 58d7 58db 58de 58e1
58e5 58e7 58eb 58ef 58f2 58f4 1 58f8
58fc 5900 5903 5907 590b 590f 5913 5916
591a 591e 5921 5924 5929 592c 592f 5932
5933 5938 5939 1 593b 5940 5944 5948
594b 5950 5955 5958 595c 595d 5962 5965
596a 596b 5970 5973 5978 5979 597e 5981
5985 5986 598b 598e 5993 5994 5999 599c
59a0 59a4 59a7 59aa 59ab 59ad 59ae 59b3
59b4 59b9 59bb 59bf 59c2 59c4 59c8 59ca
59d6 59d8 59da 59db 59e0 59e4 59e6 59f2
59f4 59f8 59fc 5a00 5a04 5a08 5a0c 5a18
5a1c 5a21 5a25 5a28 5a29 5a2e 5a32 5a36
5a39 5a3c 5a40 5a42 5a46 5a4a 5a4d 5a50
5a54 5a56 5a5a 5a5e 5a61 5a63 1 5a67
5a6b 5a6f 5a72 5a76 5a7a 5a7e 5a82 5a85
5a89 5a8d 5a90 5a93 5a98 5a9b 5a9e 5aa1
5aa2 5aa7 5aa8 1 5aaa 5aaf 5ab3 5ab7
5aba 5abf 5ac4 5ac7 5acb 5acc 5ad1 5ad4
5ad9 5ada 5adf 5ae2 5ae7 5ae8 5aed 5af0
5af4 5af5 5afa 5afd 5b02 5b03 5b08 5b0b
5b0f 5b13 5b16 5b19 5b1a 5b1c 5b1d 5b22
5b23 5b28 5b2a 5b2e 5b31 5b33 5b37 5b39
5b45 5b47 5b49 5b4a 5b4f 5b53 5b55 5b61
5b63 5b65 5b69 5b6c 5b70 5b74 5b75 5b7a
5b7e 5b82 5b86 5b89 5b8a 5b8c 5b8f 5b92
5b93 5b98 5b9c 5ba0 5ba3 5ba4 5ba6 5baa
5bad 5bb1 5bb4 5bb5 1 5bba 5bbf 5bc3
5bc7 5bca 5bcb 5bcd 5bd1 5bd4 5bd8 5bdb
5bdc 1 5be1 5be6 5bea 5bed 5bee 5bf3
5bf6 5bfa 5bfe 5c02 5c04 5c08 5c0b 5c0d
5c11 5c14 5c18 5c1c 5c1f 5c20 5c22 5c25
5c28 5c29 5c2e 5c32 5c36 5c3a 5c3d 5c41
5c43 5c47 5c4a 5c4e 5c51 5c52 5c57 5c5a
5c5e 5c61 5c62 5c67 1 5c6a 5c6f 5c73
5c76 5c77 5c7c 1 5c7f 5c84 5c88 5c8b
5c8c 5c91 5c94 1 5c97 5c9c 5ca0 5ca3
5ca7 5ca9 5cad 5cb0 5cb4 5cb9 5cbd 5cc1
5cc6 5cca 5cce 5cd2 5cd5 5cd6 5cd8 5cdb
5cde 5cdf 5ce4 5ce8 5cec 5cef 5cf0 5cf2
5cf6 5cf9 5cfd 5d00 5d01 5d06 5d0a 5d0f
5d12 5d16 5d17 5d1c 5d1f 5d24 5d25 5d2a
5d2d 5d32 5d33 5d38 5d3b 5d40 5d41 5d46
5d49 5d4e 5d4f 5d54 5d57 5d5b 5d5c 5d61
5d64 5d69 5d6a 5d6f 5d73 5d77 5d79 5d7d
5d81 5d84 5d85 5d87 5d8a 5d8d 5d8e 5d93
5d97 5d9c 5d9f 5da4 5da5 5daa 5dad 5db2
5db3 5db8 5dbb 5dbf 5dc0 5dc5 5dc8 5dcd
5dce 5dd3 5dd6 5ddb 5ddc 5de1 5de4 5de8
5de9 5dee 5df1 5df6 5df7 5dfc 5dff 5e04
5e05 5e0a 5e0e 5e10 5e14 5e18 5e1d 5e20
5e25 5e26 5e2b 5e2e 5e33 5e34 5e39 5e3c
5e41 5e42 5e47 5e4a 5e4e 5e4f 5e54 5e57
5e5c 5e5d 5e62 5e66 5e68 5e6c 5e70 5e73
5e75 5e79 5e7d 5e80 5e81 5e83 5e87 5e8a
5e8e 5e91 5e92 5e97 5e9b 5e9f 5ea2 5ea3
5ea5 5ea9 5eac 5eb0 5eb3 5eb4 1 5eb9
5ebe 5ec2 5ec6 5ec9 5eca 5ecc 5ed0 5ed3
5ed7 5eda 5edb 1 5ee0 5ee5 5ee9 5eed
5ef2 5ef7 5efb 5eff 5f03 5f06 5f09 5f0d
5f11 5f14 5f15 5f1a 5f1d 5f21 5f25 5f2a
5f2f 5f33 5f37 5f3b 5f3e 5f41 5f45 5f49
5f4d 5f51 5f55 5f59 5f5d 5f61 5f65 5f69
5f6d 5f71 5f75 5f79 5f7d 5f81 5f85 5f89
5f8d 5f91 5f95 5f99 5f9d 5fa1 5fad 5fb1
5fb6 5fba 5fbd 5fbe 5fc3 5fc7 5fcb 5fce
5fd1 5fd5 5fd7 5fdb 5fdf 5fe2 5fe5 5fe9
5feb 5fef 5ff3 5ff6 5ff8 1 5ffc 6000
6004 6007 600b 600f 6013 6017 601a 601e
6022 6025 6028 602d 6030 6033 6036 6037
603c 603d 1 603f 6044 6048 604c 604f
6054 6059 605c 6060 6061 6066 6069 606e
606f 6074 6077 607c 607d 6082 6085 6089
608a 608f 6092 6097 6098 609d 60a0 60a4
60a8 60ab 60ae 60af 60b1 60b2 60b7 60b8
60bd 60bf 60c3 60c6 60c8 60cc 60ce 60da
60dc 60de 60df 60e4 60e8 60ea 60f6 60f8
60fc 6100 6104 6108 610c 6110 6114 6118
611c 6120 6124 6128 612c 6130 6134 6138
613c 6140 6144 6148 614c 6158 615c 6161
6165 6168 6169 616e 6172 6176 6179 617c
6180 6182 6186 618a 618d 6190 6194 6196
619a 619e 61a1 61a3 1 61a7 61ab 61af
61b2 61b6 61ba 61be 61c2 61c5 61c9 61cd
61d0 61d3 61d8 61db 61de 61e1 61e2 61e7
61e8 1 61ea 61ef 61f3 61f7 61fa 61ff
6204 6207 620b 620c 6211 6214 6219 621a
621f 6222 6227 6228 622d 6230 6234 6235
623a 623d 6242 6243 6248 624b 624f 6253
6256 6259 625a 625c 625d 6262 6263 6268
626a 626e 6271 6273 6277 6279 6285 6287
6289 628a 628f 6293 6295 62a1 62a3 62a5
62a9 62ad 62b1 62b3 62b7 62bb 62be 62c0
62c4 62c7 62cb 62ce 62cf 62d4 62d7 62db
62df 62e3 62e7 62e8 62ea 62ed 62ee 62f0
62f3 62f6 62f7 62fc 6300 6304 6308 630c
630d 630f 6312 6313 6315 6318 6319 631b
631e 6321 6322 6327 6328 632a 632e 6332
6336 633a 633b 633d 6340 6341 6343 6346
6347 6349 634b 634f 6353 6357 635a 635e
6362 6366 636a 636d 6371 6372 6377 6379
637d 6381 6385 6389 638d 6390 6393 6394
6399 639c 639d 639f 63a0 63a2 63a5 63a6
63a8 63ab 63ae 63af 63b4 63b8 63bc 63c0
63c4 63c8 63cb 63ce 63cf 63d4 63d7 63d8
63da 63db 63dd 63e0 63e1 63e3 63e6 63e9
63ea 1 63ef 63f4 63f8 63fe 6400 6404
6407 640b 640f 6412 6415 6416 641b 641f
6421 6425 642c 6430 6434 6437 6438 643d
6441 6445 6448 644c 6450 6453 6456 645b
645e 6461 6464 6465 646a 646b 1 646d
6472 6476 647a 647d 6482 6487 648a 648e
648f 6494 6497 649c 649d 64a2 64a5 64aa
64ab 64b0 64b3 64b7 64bb 64bf 64c3 64c6
64c7 64c9 64ce 64cf 64d1 64d2 64d7 64d8
64dd 64df 64e3 64e6 64ea 64ee 64f1 64f5
64f9 64fc 64ff 6504 6507 650a 650d 650e
6513 6514 1 6516 651b 651f 6523 6526
652b 6530 6533 6537 6538 653d 653e 6543
6545 6549 654c 6550 6554 6557 655b 655f
6562 6566 6567 656c 656e 6572 6575 6579
657d 6581 6585 6591 6595 6599 659c 65a0
65a4 65a6 1 65aa 65ae 65b2 65b5 65b9
65bd 65c1 65c5 65c8 65cc 65d0 65d3 65d6
65db 65de 65e1 65e4 65e5 65ea 65eb 1
65ed 65f2 65f6 65fa 65fd 6602 6607 660a
660e 660f 6614 6617 661c 661d 6622 6625
662a 662b 6630 6633 6637 6638 663d 6640
6645 6646 664b 664e 6652 6656 6659 665c
665d 665f 6660 6665 6666 666b 666d 6671
6674 6676 667a 667c 6688 668a 668c 668d
6692 6696 6698 66a4 66a6 66a8 66ac 66af
66b3 66b7 66ba 66bb 66bd 66c1 66c4 66c8
66cb 66cc 66d1 66d5 66da 66de 66e2 66e7
66eb 66ef 66f3 66f6 66fa 66fb 6700 6704
6708 670c 670f 6714 6715 671a 671e 6722
6724 6728 672c 672f 6730 6732 6736 6739
673d 6740 6741 6746 674a 674f 6753 6757
675b 675e 6762 6763 6768 676c 6770 6774
6777 677c 677d 6782 6786 678a 678f 6793
6795 6799 679d 67a1 67a4 67a5 67a7 67ab
67ae 67b2 67b5 67b6 67bb 67bf 67c4 67c8
67cc 67d1 67d5 67d9 67dc 67dd 67e2 67e5
67e9 67ed 67f0 67f5 67f6 67fb 67ff 6803
6807 680a 680e 680f 6814 6818 681c 6820
6823 6828 6829 682e 6832 6834 6838 683b
683f 6843 6846 684b 684c 6851 6855 6859
685c 685d 6862 6865 6869 686d 6870 6875
6876 687b 687f 6883 6887 688a 688e 688f
6894 6898 689c 68a0 68a3 68a8 68a9 68ae
68b2 68b4 68b8 68bb 68bd 68c1 68c4 68c5
68ca 68cd 68d1 68d5 68d8 68dd 68de 68e3
68e7 68eb 68f0 68f4 68f6 68fa 68fe 6901
6906 6907 690c 690f 6914 6915 691a 691e
6922 6927 692b 692f 6932 6933 6938 693b
693f 6943 6946 694b 694c 6951 6955 6959
695d 6960 6964 6965 696a 696e 6972 6976
6979 697e 697f 6984 6988 698a 698e 6991
6995 6999 699c 69a1 69a2 69a7 69aa 69af
69b0 69b5 69b8 69bd 69be 69c3 69c6 69cb
69cc 69d1 69d4 69d9 69da 69df 69e2 69e7
69e8 69ed 69f1 69f3 69f7 69fb 69fe 6a02
6a05 6a06 6a0b 6a0e 6a12 6a16 6a19 6a1e
6a1f 6a24 6a27 6a2b 6a2c 6a31 6a34 6a39
6a3a 6a3f 6a43 6a45 6a49 6a4c 6a4e 6a52
6a56 6a59 6a5b 6a5f 6a63 6a66 6a6a 6a6e
6a71 6a72 6a74 6a78 6a7b 6a7f 6a82 6a83
6a88 6a8c 6a8f 6a90 6a95 6a98 6a9c 6aa0
6aa4 6aa8 6aac 6ab8 6abc 6ac0 6ac3 6ac7
6acb 6acd 1 6ad1 6ad5 6ad9 6adc 6ae0
6ae4 6ae8 6aec 6aef 6af3 6af7 6afa 6afd
6b02 6b05 6b08 6b0b 6b0c 6b11 6b12 1
6b14 6b19 6b1d 6b21 6b24 6b29 6b2e 6b31
6b35 6b36 6b3b 6b3e 6b43 6b44 6b49 6b4c
6b51 6b52 6b57 6b5a 6b5e 6b5f 6b64 6b67
6b6c 6b6d 6b72 6b75 6b79 6b7d 6b80 6b83
6b84 6b86 6b87 6b8c 6b8d 6b92 6b94 6b98
6b9b 6b9d 6ba1 6ba3 6baf 6bb1 6bb3 6bb4
6bb9 6bbd 6bbf 6bcb 6bcd 6bd1 6bd5 6bd8
6bdc 6bdf 6be3 6be6 6be7 6bec 6bef 6bf3
6bf7 6bfb 6bff 6c00 6c02 6c05 6c06 6c08
6c0c 6c10 6c14 6c17 6c1c 6c1d 6c22 6c26
6c2a 6c2e 6c31 6c36 6c37 6c3c 6c3f 6c44
6c45 6c4a 6c4d 6c51 6c52 6c57 6c5a 6c5f
6c60 6c65 6c69 6c6b 6c6f 6c73 6c76 6c7a
6c7e 6c81 6c84 6c89 6c8c 6c8f 6c92 6c93
6c98 6c99 1 6c9b 6ca0 6ca4 6ca8 6cab
6cb0 6cb5 6cb8 6cbc 6cbd 6cc2 6cc5 6cca
6ccb 6cd0 6cd3 6cd8 6cd9 6cde 6ce1 6ce5
6ce9 6ced 6cf1 6cf4 6cf5 6cf7 6cfc 6cfd
6cff 6d00 6d05 6d08 6d0d 6d0e 6d13 6d16
6d1b 6d1c 6d21 6d24 6d28 6d29 6d2e 6d31
6d36 6d37 6d3c 6d3d 6d42 6d44 6d48 6d4b
6d4f 6d53 6d56 6d5a 6d5e 6d61 6d64 6d69
6d6c 6d6f 6d72 6d73 6d78 6d79 1 6d7b
6d80 6d84 6d88 6d8b 6d90 6d95 6d98 6d9c
6d9d 6da2 6da3 6da8 6daa 6dae 6db1 6db5
6db9 6dbc 6dc0 6dc4 6dc7 6dcb 6dcf 6dd0
6dd5 6dd7 6ddb 6ddf 6de2 6de4 6de8 6deb
6def 6df2 6df3 6df8 6dfb 6dff 6e03 6e07
6e0b 6e0f 6e1b 6e1f 6e23 6e26 6e2a 6e2e
6e30 1 6e34 6e38 6e3c 6e3f 6e43 6e47
6e4b 6e4f 6e52 6e56 6e5a 6e5d 6e60 6e65
6e68 6e6b 6e6e 6e6f 6e74 6e75 1 6e77
6e7c 6e80 6e84 6e87 6e8c 6e91 6e94 6e98
6e99 6e9e 6ea1 6ea6 6ea7 6eac 6eaf 6eb4
6eb5 6eba 6ebd 6ec1 6ec2 6ec7 6eca 6ecf
6ed0 6ed5 6ed8 6edc 6ee0 6ee3 6ee6 6ee7
6ee9 6eea 6eef 6ef0 6ef5 6ef7 6efb 6efe
6f00 6f04 6f06 6f12 6f14 6f16 6f17 6f1c
6f20 6f22 6f2e 6f30 6f34 6f38 6f3b 6f3f
6f42 6f46 6f49 6f4a 6f4f 6f52 6f56 6f5a
6f5d 6f62 6f63 6f68 6f6c 6f70 6f74 6f77
6f7c 6f7d 6f82 6f85 6f8a 6f8b 6f90 6f93
6f97 6f98 6f9d 6fa0 6fa5 6fa6 6fab 6faf
6fb1 6fb5 6fb9 6fbc 6fc0 6fc4 6fc7 6fca
6fcf 6fd2 6fd5 6fd8 6fd9 6fde 6fdf 1
6fe1 6fe6 6fea 6fee 6ff1 6ff6 6ffb 6ffe
7002 7003 7008 700b 7010 7011 7016 7019
701e 701f 7024 7027 702b 702f 7033 7037
703a 703b 703d 7042 7043 7045 7046 704b
704e 7053 7054 7059 705c 7061 7062 7067
706a 706e 706f 7074 7077 707c 707d 7082
7083 7088 708a 708e 7091 7095 7099 709c
70a0 70a4 70a7 70aa 70af 70b2 70b5 70b8
70b9 70be 70bf 1 70c1 70c6 70ca 70ce
70d1 70d6 70db 70de 70e2 70e3 70e8 70e9
70ee 70f0 70f4 70f7 70fb 70ff 7102 7106
710a 710d 7111 7115 7116 711b 711d 7121
7125 7128 712a 712e 7131 7135 7138 7139
713e 7141 7145 7149 714d 7151 7155 7161
7165 7169 716c 7170 7174 7176 1 717a
717e 7182 7185 7189 718d 7191 7195 7198
719c 71a0 71a3 71a6 71ab 71ae 71b1 71b4
71b5 71ba 71bb 1 71bd 71c2 71c6 71ca
71cd 71d2 71d7 71da 71de 71df 71e4 71e7
71ec 71ed 71f2 71f5 71fa 71fb 7200 7203
7207 7208 720d 7210 7215 7216 721b 721e
7222 7226 7229 722c 722d 722f 7230 7235
7236 723b 723d 7241 7244 7246 724a 724c
7258 725a 725c 725d 7262 7266 7268 7274
7276 727a 727e 7281 7285 7288 728c 728f
7290 7295 7298 729c 72a0 72a3 72a8 72a9
72ae 72b2 72b6 72ba 72bd 72c2 72c3 72c8
72cb 72d0 72d1 72d6 72d9 72dd 72de 72e3
72e6 72eb 72ec 72f1 72f5 72f7 72fb 72ff
7302 7306 730a 730d 7310 7315 7318 731b
731e 731f 7324 7325 1 7327 732c 7330
7334 7337 733c 7341 7344 7348 7349 734e
7351 7356 7357 735c 735f 7364 7365 736a
736d 7371 7375 7379 737d 7380 7381 7383
7388 7389 738b 738c 7391 7394 7399 739a
739f 73a2 73a7 73a8 73ad 73b0 73b4 73b5
73ba 73bd 73c2 73c3 73c8 73c9 73ce 73d0
73d4 73d7 73db 73df 73e2 73e6 73ea 73ed
73f0 73f5 73f8 73fb 73fe 73ff 7404 7405
1 7407 740c 7410 7414 7417 741c 7421
7424 7428 7429 742e 742f 7434 7436 743a
743d 7441 7445 7448 744c 7450 7453 7457
745b 745c 7461 7463 7467 746b 746e 7470
7474 7477 747b 747f 7482 7483 7485 7488
748b 748c 7491 7495 7499 749c 749d 749f
74a2 74a5 74a6 1 74ab 74b0 74b4 74b8
74bb 74c0 74c1 74c6 74c9 74cd 74d1 74d5
74d8 74d9 74db 74dc 74de 74df 74e4 74e7
74ec 74ed 74f2 74f6 74f8 74fc 74ff 7501
7505 7508 750c 750f 7510 7515 7518 751c
7520 7524 7528 7529 752b 752e 752f 7531
7535 7539 753c 7540 7544 7548 754c 754f
7553 7554 7559 755b 755f 7563 7567 756a
756d 7570 7574 7577 757a 757b 7580 7584
7585 7587 758b 758f 7593 7597 759b 759f
75ab 75af 75b3 75b6 75ba 75be 75c0 1
75c4 75c8 75cc 75cf 75d3 75d7 75db 75df
75e2 75e6 75ea 75ed 75f0 75f5 75f8 75fb
75fe 75ff 7604 7605 1 7607 760c 7610
7614 7617 761c 7621 7624 7628 7629 762e
7631 7636 7637 763c 763f 7644 7645 764a
764d 7651 7652 7657 765a 765f 7660 7665
7668 766c 7670 7673 7676 7677 7679 767a
767f 7680 7685 7687 768b 768e 7690 7694
7696 76a2 76a4 76a6 76a7 76ac 76b0 76b2
76be 76c0 76c4 76c8 76cb 76cf 76d2 76d6
76d9 76da 76df 76e2 76e6 76ea 76ed 76f1
76f5 76f8 76fb 7700 7703 7706 7709 770a
770f 7710 1 7712 7717 771b 771f 7722
7727 772c 772f 7733 7734 7739 773c 7741
7742 7747 774a 774f 7750 7755 7758 775c
7760 7764 7768 776b 776c 776e 7773 7774
7776 7777 777c 777f 7784 7785 778a 778d
7792 7793 7798 779b 779f 77a0 77a5 77a8
77ad 77ae 77b3 77b4 77b9 77bb 77bf 77c2
77c6 77ca 77cd 77d1 77d5 77d8 77db 77e0
77e3 77e6 77e9 77ea 77ef 77f0 1 77f2
77f7 77fb 77ff 7802 7807 780c 780f 7813
7814 7819 781a 781f 7821 7825 7828 782c
7830 7833 7837 783b 783e 7842 7846 7847
784c 784e 7852 7855 7859 785d 7860 7865
7866 786b 786e 7873 7874 7879 787c 7881
7882 7887 788a 788f 7890 7895 7898 789c
789d 78a2 78a5 78aa 78ab 78b0 78b4 78b8
78bc 78bf 78c0 78c2 78c6 78c9 78cd 78d0
78d1 78d6 78da 78de 78e1 78e6 78e7 78ec
78f0 78f2 78f6 78fa 78fd 7902 7903 7908
790c 790e 7912 7916 7919 791d 7921 7924
7925 7927 792b 792e 7932 7935 7936 793b
793f 7945 7947 794b 794e 7952 7956 7959
795c 795d 7962 7966 7968 796c 7973 7975
7979 797c 7980 7984 7987 7988 798a 798e
7991 7995 7998 7999 799e 79a2 79a6 79aa
79ae 79af 79b1 79b4 79b5 79b7 79bb 79bf
79c2 79c6 79ca 79ce 79d2 79d5 79d9 79da
79df 79e1 79e5 79e9 79ed 79f0 79f3 79f6
79fa 79fd 7a00 7a01 7a06 7a0a 7a0b 7a0d
7a11 7a15 7a19 7a1d 7a21 7a25 7a31 7a35
7a39 7a3c 7a40 7a44 7a46 1 7a4a 7a4e
7a52 7a55 7a59 7a5d 7a61 7a65 7a68 7a6c
7a70 7a73 7a76 7a7b 7a7e 7a81 7a84 7a85
7a8a 7a8b 1 7a8d 7a92 7a96 7a9a 7a9d
7aa2 7aa7 7aaa 7aae 7aaf 7ab4 7ab7 7abc
7abd 7ac2 7ac5 7aca 7acb 7ad0 7ad3 7ad7
7ad8 7add 7ae0 7ae5 7ae6 7aeb 7aee 7af2
7af6 7af9 7afc 7afd 7aff 7b00 7b05 7b06
7b0b 7b0d 7b11 7b14 7b16 7b1a 7b1c 7b28
7b2a 7b2c 7b2d 7b32 7b36 7b38 7b44 7b46
7b4a 7b4e 7b51 7b55 7b58 7b5c 7b5f 7b60
7b65 7b68 7b6c 7b70 7b73 7b77 7b7b 7b7e
7b81 7b86 7b89 7b8c 7b8f 7b90 7b95 7b96
1 7b98 7b9d 7ba1 7ba5 7ba8 7bad 7bb2
7bb5 7bb9 7bba 7bbf 7bc2 7bc7 7bc8 7bcd
7bd0 7bd5 7bd6 7bdb 7bde 7be2 7be6 7bea
7bee 7bf1 7bf2 7bf4 7bf9 7bfa 7bfc 7bfd
7c02 7c05 7c0a 7c0b 7c10 7c13 7c18 7c19
7c1e 7c21 7c25 7c26 7c2b 7c2e 7c33 7c34
7c39 7c3a 7c3f 7c41 7c45 7c48 7c4c 7c50
7c53 7c57 7c5b 7c5e 7c61 7c66 7c69 7c6c
7c6f 7c70 7c75 7c76 1 7c78 7c7d 7c81
7c85 7c88 7c8d 7c92 7c95 7c99 7c9a 7c9f
7ca0 7ca5 7ca7 7cab 7cae 7cb2 7cb6 7cb9
7cbd 7cc1 7cc4 7cc8 7ccc 7ccd 7cd2 7cd4
7cd8 7cdb 7cdf 7ce3 7ce6 7ceb 7cec 7cf1
7cf4 7cf9 7cfa 7cff 7d02 7d07 7d08 7d0d
7d10 7d15 7d16 7d1b 7d1e 7d22 7d23 7d28
7d2b 7d30 7d31 7d36 7d39 7d3e 7d3f 7d44
7d48 7d4c 7d50 7d53 7d56 7d57 7d5c 7d60
7d62 7d66 7d6d 7d6f 7d73 7d76 7d7a 7d7e
7d81 7d85 7d86 7d8b 7d8f 7d91 7d95 7d99
7d9c 7da0 7da4 7da7 7dac 7dad 7db2 7db6
7dba 7dbe 7dc2 7dc5 7dc9 7dcd 7dd1 7dd5
7dda 7ddf 7de3 7de7 7dec 7df0 7df4 7df7
7dfa 7dfe 7e00 7e04 7e08 7e0b 7e0e 7e12
7e14 7e18 7e1c 7e1f 7e23 7e27 7e2a 7e2e
7e31 7e35 7e38 7e39 7e3e 7e41 7e45 7e4b
7e4d 7e51 7e54 7e58 7e5c 7e5f 7e60 7e62
7e65 7e68 7e69 7e6e 7e72 7e76 7e79 7e7a
7e7c 7e80 7e83 7e87 7e8a 7e8b 1 7e90
7e95 7e99 7e9d 7ea0 7ea1 7ea3 7ea7 7eaa
7eae 7eb1 7eb2 1 7eb7 7ebc 7ec0 7ec4
7ec7 7ec8 7eca 7ece 7ed1 7ed5 7ed8 7ed9
7ede 7ee2 7ee5 7ee6 7eeb 1 7eee 7ef3
1 7ef6 7efb 7eff 7f03 7f08 7f0c 7f0d
7f11 7f15 7f1a 7f1f 7f23 7f27 7f2c 7f30
7f34 7f37 7f3a 7f3e 7f40 7f44 7f48 7f4b
7f4e 7f52 7f54 7f58 7f5c 7f5f 7f63 7f67
7f6a 7f6e 7f71 7f75 7f78 7f79 7f7e 7f81
7f85 7f89 7f8e 7f90 7f94 7f98 7f9b 7f9f
7fa3 7fa5 1 7fa9 7fad 7fb1 7fb4 7fb8
7fbc 7fc0 7fc4 7fc7 7fcb 7fcf 7fd2 7fd5
7fda 7fdd 7fe0 7fe3 7fe4 7fe9 7fea 1
7fec 7ff1 7ff5 7ff9 7ffc 8001 8006 8009
800d 800e 8013 8016 801b 801c 8021 8024
8029 802a 802f 8032 8036 8037 803c 803f
8044 8045 804a 804d 8051 8055 8058 805b
805c 805e 805f 8064 8065 806a 806c 8070
8073 8075 8079 807b 8087 8089 808b 808c
8091 8095 8097 80a3 80a5 80a9 80af 80b1
80b5 80b9 80be 80c0 80c4 80c8 80cb 80cf
80d3 80d5 1 80d9 80dd 80e1 80e4 80e8
80ec 80f0 80f4 80f7 80fb 80ff 8102 8105
810a 810d 8110 8113 8114 8119 811a 1
811c 8121 8125 8129 812c 8131 8136 8139
813d 813e 8143 8146 814b 814c 8151 8154
8159 815a 815f 8162 8166 8167 816c 816f
8174 8175 817a 817d 8181 8185 8188 818b
818c 818e 818f 8194 8195 819a 819c 81a0
81a3 81a5 81a9 81ab 81b7 81b9 81bb 81bc
81c1 81c5 81c7 81d3 81d5 81d7 81db 81df
81e2 81e4 81e8 81eb 81ef 81f3 81f7 81fb
81ff 8203 8207 820b 820e 820f 8211 8214
8217 8218 821d 8221 8225 8228 822b 822c
822e 8231 8236 8237 823c 8240 8244 8245
824a 824e 8252 8255 8259 825b 825f 8263
8267 826a 826b 826d 826e 8270 8273 8276
8277 827c 8280 8284 8288 828c 8290 8294
8298 829c 82a0 82ac 82b0 82b4 82b7 82bb
82bf 82c1 1 82c5 82c9 82cd 82d0 82d4
82d8 82dc 82e0 82e3 82e7 82eb 82ee 82f1
82f6 82f9 82fc 82ff 8300 8305 8306 1
8308 830d 8311 8315 8318 831d 8322 8325
8329 832a 832f 8332 8337 8338 833d 8340
8345 8346 834b 834e 8352 8353 8358 835b
8360 8361 8366 8369 836d 8371 8374 8377
8378 837a 837b 8380 8381 8386 8388 838c
838f 8391 8395 8397 83a3 83a5 83a7 83a8
83ad 83b1 83b3 83bf 83c1 83c5 83c9 83cc
83cd 83cf 83d2 83d5 83d6 83db 83df 83e3
83e8 83ea 83ee 83f2 83f5 83f9 83fd 83ff
1 8403 8407 840b 840e 8412 8416 841a
841e 8421 8425 8429 842c 842f 8434 8437
843a 843d 843e 8443 8444 1 8446 844b
844f 8453 8456 845b 8460 8463 8467 8468
846d 8470 8475 8476 847b 847e 8483 8484
8489 848c 8490 8491 8496 8499 849e 849f
84a4 84a7 84ab 84af 84b2 84b5 84b6 84b8
84b9 84be 84bf 84c4 84c6 84ca 84cd 84cf
84d3 84d5 84e1 84e3 84e5 84e6 84eb 84ef
84f1 84fd 84ff 8503 8507 850a 850e 8512
8515 8518 851d 8520 8523 8526 8527 852c
852d 1 852f 8534 8538 853c 853f 8544
8549 854c 8550 8551 8556 8559 855e 855f
8564 8567 856c 856d 8572 8575 8579 857d
8581 8585 8588 8589 858b 8590 8591 8593
8594 8599 859c 85a1 85a2 85a7 85aa 85af
85b0 85b5 85b8 85bc 85bd 85c2 85c5 85ca
85cb 85d0 85d1 85d6 85d8 85dc 85df 85e3
85e7 85ea 85ee 85f2 85f5 85f8 85fd 8600
8603 8606 8607 860c 860d 1 860f 8614
8618 861c 861f 8624 8629 862c 8630 8631
8636 8637 863c 863e 8642 8645 8649 864d
8650 8654 8658 865b 865f 8663 8664 8669
866b 866f 8672 8674 8678 867b 867d 8681
8685 8688 868c 8690 8694 8698 869c 86a0
86a4 86a8 86ac 86b0 86b4 86b8 86bc 86c0
86c4 86c8 86cc 86d0 86d4 86d8 86dc 86e0
86e4 86e8 86ec 86f0 86f4 86f8 86fc 8700
8704 8708 870b 870c 870e 8711 8714 8717
8718 871a 871e 8722 8725 8728 8729 872e
8732 8736 873b 873d 8741 8745 8748 874c
8750 8752 1 8756 875a 875e 8761 8765
8769 876d 8771 8774 8778 877c 877f 8782
8787 878a 878d 8790 8791 8796 8797 1
8799 879e 87a2 87a6 87a9 87ae 87b3 87b6
87ba 87bb 87c0 87c3 87c8 87c9 87ce 87d1
87d6 87d7 87dc 87df 87e3 87e4 87e9 87ec
87f1 87f2 87f7 87fa 87fe 8802 8805 8808
8809 880b 880c 8811 8812 8817 8819 881d
8820 8822 8826 8828 8834 8836 8838 8839
883e 8842 8844 8850 8852 8856 885a 885d
8861 8864 8865 886a 886e 8872 8876 8879
887d 887f 8883 8886 888a 888e 8891 8895
8899 889c 889f 88a4 88a7 88aa 88ad 88ae
88b3 88b4 1 88b6 88bb 88bf 88c3 88c6
88cb 88d0 88d3 88d7 88d8 88dd 88e0 88e5
88e6 88eb 88ee 88f3 88f4 88f9 88fc 8900
8904 8908 8909 890b 8910 8911 8913 8914
8919 891c 8921 8922 8927 892a 892f 8930
8935 8938 893c 893d 8942 8945 894a 894b
8950 8951 8956 8958 895c 895f 8963 8967
896a 896e 8972 8975 8978 897d 8980 8983
8986 8987 898c 898d 1 898f 8994 8998
899c 899f 89a4 89a9 89ac 89b0 89b1 89b6
89b7 89bc 89be 89c2 89c5 89c9 89cd 89d0
89d4 89d8 89dc 89dd 89e2 89e6 89e8 89ec
89f0 89f3 89f6 89f7 89f9 89fc 8a01 8a02
8a07 8a0a 8a0e 8a12 8a15 8a18 8a19 8a1b
8a1e 8a23 8a24 8a29 1 8a2c 8a31 8a35
8a39 8a3d 8a41 8a45 8a51 8a55 8a5a 8a5e
8a61 8a62 8a67 8a6b 8a6f 8a72 8a75 8a79
8a7b 8a7f 8a83 8a86 8a89 8a8d 8a8f 8a93
8a97 8a9a 8a9c 1 8aa0 8aa4 8aa8 8aab
8aaf 8ab3 8ab7 8abb 8abe 8ac2 8ac6 8ac9
8acc 8ad1 8ad4 8ad7 8ada 8adb 8ae0 8ae1
1 8ae3 8ae8 8aec 8af0 8af3 8af8 8afd
8b00 8b04 8b05 8b0a 8b0d 8b12 8b13 8b18
8b1b 8b20 8b21 8b26 8b29 8b2d 8b2e 8b33
8b36 8b3b 8b3c 8b41 8b44 8b48 8b4c 8b4f
8b52 8b53 8b55 8b56 8b5b 8b5c 8b61 8b63
8b67 8b6a 8b6c 8b70 8b72 8b7e 8b80 8b82
8b83 8b88 8b8c 8b8e 8b9a 8b9c 8b9e 8ba2
8ba6 8ba9 8bad 8bb3 8bb5 8bb9 8bbd 8bc0
8bc1 8bc3 8bc7 8bca 8bce 8bd1 8bd2 8bd7
8bdb 8bdf 8be3 8be7 8beb 8bef 8bf1 8bf5
8bf8 8bfc 8c00 8c04 8c08 8c0c 8c10 8c14
8c18 8c1c 8c20 8c24 8c28 8c2c 8c30 8c34
8c38 8c3c 8c40 8c44 8c48 8c4c 8c50 8c54
8c58 8c5c 8c60 8c64 8c68 8c6c 8c70 8c73
8c76 8c79 8c7c 8c7d 8c7f 8c83 8c87 8c8a
8c8d 8c8e 8c93 8c97 8c9b 8c9e 8ca1 8ca2
8ca7 8cab 8cad 8cb1 8cb4 8cb8 8cbc 8cbf
8cc3 8cc6 8cc7 8cc9 8cca 8ccf 8cd3 8cd9
8cdb 8cdf 8ce2 8ce4 8ce8 8cec 8cef 8cf7
8cf9 8cfa 8cfd 8cff 8d03 8d0a 8d0e 8d12
8d17 8d19 8d1d 8d21 8d24 8d28 8d2c 8d2e
1 8d32 8d36 8d3a 8d3d 8d41 8d45 8d49
8d4d 8d50 8d54 8d58 8d5b 8d5e 8d63 8d66
8d69 8d6c 8d6d 8d72 8d73 1 8d75 8d7a
8d7e 8d82 8d85 8d8a 8d8f 8d92 8d96 8d97
8d9c 8d9f 8da4 8da5 8daa 8dad 8db2 8db3
8db8 8dbb 8dbf 8dc0 8dc5 8dc8 8dcd 8dce
8dd3 8dd6 8dda 8dde 8de1 8de4 8de5 8de7
8de8 8ded 8dee 8df3 8df5 8df9 8dfc 8dfe
8e02 8e04 8e10 8e12 8e14 8e15 8e1a 8e1e
8e20 8e2c 8e2e 8e32 8e36 8e39 8e3d 8e40
8e41 8e46 8e49 8e4d 8e50 8e53 8e54 8e59
8e5c 8e60 8e64 8e67 8e68 8e6a 8e6d 8e70
8e71 8e76 1 8e79 8e7e 1 8e81 8e86
8e8a 8e8e 8e91 8e95 8e99 8e9c 8e9f 8ea4
8ea7 8eaa 8ead 8eae 8eb3 8eb4 1 8eb6
8ebb 8ebf 8ec3 8ec6 8ecb 8ed0 8ed3 8ed7
8ed8 8edd 8ee0 8ee5 8ee6 8eeb 8eee 8ef3
8ef4 8ef9 8efc 8f00 8f04 8f08 8f09 8f0b
8f10 8f11 8f13 8f14 8f19 8f1c 8f21 8f22
8f27 8f2a 8f2f 8f30 8f35 8f38 8f3c 8f3d
8f42 8f45 8f4a 8f4b 8f50 8f51 8f56 8f58
8f5c 8f5f 8f63 8f67 8f6a 8f6e 8f72 8f75
8f78 8f7d 8f80 8f83 8f86 8f87 8f8c 8f8d
1 8f8f 8f94 8f98 8f9c 8f9f 8fa4 8fa9
8fac 8fb0 8fb1 8fb6 8fb7 8fbc 8fbe 8fc2
8fc5 8fc9 8fcd 8fd0 8fd4 8fd8 8fdc 8fdd
8fe2 8fe4 8fe8 8feb 8fef 8ff2 8ff5 8ff6
8ffb 8fff 9004 9008 900c 9011 9015 9019
901e 9022 9026 902a 902f 9033 9034 9038
903b 903f 9043 9047 904b 904f 9053 9057
905b 905f 9063 9067 906c 9071 9075 9079
907d 9082 9086 908a 908d 9090 9094 9096
909a 909e 90a1 90a4 90a8 90aa 90ae 90b2
90b5 90b9 90bd 90c0 90c4 90c7 90cb 90ce
90cf 90d4 90d7 90db 90e1 90e3 90e7 90ea
90ee 90f1 90f2 90f7 90fa 90fe 9102 9105
9109 910d 910e 9110 9113 9116 9117 1
911c 9121 9125 9129 912d 912e 9130 9133
9134 9136 9139 913c 913d 1 9142 9147
914b 914f 9153 9155 9159 915c 9160 9164
9167 916b 916f 9170 9172 9175 9178 9179
917e 9182 9185 9188 9189 918e 9192 9196
919a 919e 91a2 91a6 91aa 91ae 91b2 91b6
91ba 91be 91c2 91c6 91ca 91d6 91da 91df
91e3 91e6 91e7 91ec 91f0 91f4 91f7 91fa
91fe 9200 9204 9208 920b 920e 9212 9214
9218 921c 921f 9221 1 9225 9229 922d
9230 9234 9238 923c 9240 9243 9247 924b
924e 9251 9256 9259 925c 925f 9260 9265
9266 1 9268 926d 9271 9275 9278 927d
9282 9285 9289 928a 928f 9292 9297 9298
929d 92a0 92a5 92a6 92ab 92ae 92b2 92b3
92b8 92bb 92c0 92c1 92c6 92c9 92cd 92d1
92d4 92d7 92d8 92da 92db 92e0 92e1 92e6
92e8 92ec 92ef 92f1 92f5 92f7 9303 9305
9307 9308 930d 9311 9313 931f 9321 9323
9327 932a 932e 9333 9337 933b 9340 9344
9348 934d 9351 9355 935a 935e 9362 9367
936b 936f 9374 9378 937c 9380 9384 9388
938b 938f 9391 9395 9398 939c 939f 93a2
93a3 93a8 93ac 93af 93b0 93b5 1 93b8
93bd 93c1 93c5 93c9 93cd 93d1 93d5 93d9
93dd 93e1 93ed 93f1 93f6 93fa 93fd 93fe
9403 9407 940b 940e 9411 9415 9417 941b
941f 9422 9425 9429 942b 942f 9433 9436
9438 1 943c 9440 9444 9447 944b 944f
9453 9457 945a 945e 9462 9465 9468 946d
9470 9473 9476 9477 947c 947d 1 947f
9484 9488 948c 948f 9494 9499 949c 94a0
94a1 94a6 94a9 94ae 94af 94b4 94b7 94bc
94bd 94c2 94c5 94c9 94ca 94cf 94d2 94d7
94d8 94dd 94e0 94e4 94e8 94eb 94ee 94ef
94f1 94f2 94f7 94f8 94fd 94ff 9503 9506
9508 950c 950e 951a 951c 951e 951f 9524
9528 952a 9536 9538 953a 953e 9541 9545
9548 9549 954e 9551 9555 9558 9559 955e
9561 9565 9569 956d 9570 9575 9576 957b
957e 9581 9582 9584 9588 958a 958e 9591
9595 9599 959d 95a0 95a4 95a5 95aa 95ad
95b0 95b1 95b3 95b7 95b9 95bd 95c0 95c4
95c7 95c8 95cd 95d0 95d4 95d8 95dc 95df
95e3 95e4 95e9 95ec 95ef 95f0 95f2 95f6
95f8 95fc 95ff 9603 9606 9607 960c 960f
9613 9616 9617 961c 961f 9623 9627 962b
962e 9633 9634 9639 963c 963f 9640 9642
9646 9648 964c 964f 9653 9657 965b 965e
9662 9663 9668 966b 966e 966f 9671 9675
9677 967b 967e 9682 9685 9686 968b 968e
9692 9696 969a 969d 96a1 96a2 96a7 96aa
96ad 96ae 96b0 96b4 96b6 96ba 96bd 96c1
96c4 96c5 96ca 96cd 96d1 96d4 96d5 96da
96dd 96e1 96e5 96e9 96ec 96f1 96f2 96f7
96fa 96fd 96fe 9700 9704 9706 970a 970d
9711 9715 9719 971c 9720 9721 9726 9729
972c 972d 972f 9733 9735 9739 973c 9740
9743 9744 9749 974c 9750 9753 9754 9759
975c 9760 9764 9768 976b 9770 9771 9776
9779 977c 977d 977f 9783 9785 9789 978c
9790 9794 9798 979b 979f 97a0 97a5 97a8
97ab 97ac 97ae 97b2 97b4 97b8 97bb 97bf
97c3 97c6 97c9 97ca 97cf 97d3 97d7 97db
97df 97e1 97e5 97ec 97f0 97f4 97f9 97fb
97ff 9803 9806 980a 980e 9810 1 9814
9818 981c 981f 9823 9827 982b 982f 9832
9836 983a 983d 9840 9845 9848 984b 984e
984f 9854 9855 1 9857 985c 9860 9864
9867 986c 9871 9874 9878 9879 987e 9881
9886 9887 988c 988f 9894 9895 989a 989d
98a1 98a2 98a7 98aa 98af 98b0 98b5 98b8
98bc 98c0 98c3 98c6 98c7 98c9 98ca 98cf
98d0 98d5 98d7 98db 98de 98e0 98e4 98e6
98f2 98f4 98f6 98f7 98fc 9900 9902 990e
9910 9914 9917 991a 991b 9920 9924 9928
992c 9930 9934 9938 993c 9940 9944 9948
994c 9950 9954 9958 995c 9968 996c 9971
9975 9978 9979 997e 9982 9986 9989 998c
9990 9992 9996 999a 999d 99a0 99a4 99a6
99aa 99ae 99b1 99b3 1 99b7 99bb 99bf
99c2 99c6 99ca 99ce 99d2 99d5 99d9 99dd
99e0 99e3 99e8 99eb 99ee 99f1 99f2 99f7
99f8 1 99fa 99ff 9a03 9a07 9a0a 9a0f
9a14 9a17 9a1b 9a1c 9a21 9a24 9a29 9a2a
9a2f 9a32 9a37 9a38 9a3d 9a40 9a44 9a45
9a4a 9a4d 9a52 9a53 9a58 9a5b 9a5f 9a63
9a66 9a69 9a6a 9a6c 9a6d 9a72 9a73 9a78
9a7a 9a7e 9a81 9a83 9a87 9a89 9a95 9a97
9a99 9a9a 9a9f 9aa3 9aa5 9ab1 9ab3 9ab5
9ab9 9abc 9abe 9ac2 9ac5 9ac9 9acc 9acd
9ad2 9ad5 9ad9 9add 9ae0 9ae1 9ae3 9ae6
9ae9 9aea 9aef 9af3 9af7 9afb 9aff 9b03
9b07 9b0b 9b0f 9b13 9b17 9b1b 9b1f 9b23
9b27 9b33 9b37 9b3b 9b3e 9b42 9b46 9b48
1 9b4c 9b50 9b54 9b57 9b5b 9b5f 9b63
9b67 9b6a 9b6e 9b72 9b75 9b78 9b7d 9b80
9b83 9b86 9b87 9b8c 9b8d 1 9b8f 9b94
9b98 9b9c 9b9f 9ba4 9ba9 9bac 9bb0 9bb1
9bb6 9bb9 9bbe 9bbf 9bc4 9bc7 9bcc 9bcd
9bd2 9bd5 9bd9 9bda 9bdf 9be2 9be7 9be8
9bed 9bf0 9bf4 9bf8 9bfb 9bfe 9bff 9c01
9c02 9c07 9c08 9c0d 9c0f 9c13 9c16 9c18
9c1c 9c1e 9c2a 9c2c 9c2e 9c2f 9c34 9c38
9c3a 9c46 9c48 9c4a 9c4e 9c51 9c55 9c57
9c59 9c5d 9c61 9c64 9c66 9c6a 9c6d 9c71
9c75 9c79 9c7d 9c81 9c85 9c89 9c8d 9c91
9c95 9c99 9c9d 9ca1 9ca5 9ca9 9cad 9cb1
9cb5 9cb9 9cc5 9cc9 9ccd 9cd0 9cd4 9cd8
9cda 1 9cde 9ce2 9ce6 9ce9 9ced 9cf1
9cf5 9cf9 9cfc 9d00 9d04 9d07 9d0a 9d0f
9d12 9d15 9d18 9d19 9d1e 9d1f 1 9d21
9d26 9d2a 9d2e 9d31 9d36 9d3b 9d3e 9d42
9d43 9d48 9d4b 9d50 9d51 9d56 9d59 9d5e
9d5f 9d64 9d67 9d6b 9d6c 9d71 9d74 9d79
9d7a 9d7f 9d82 9d86 9d8a 9d8d 9d90 9d91
9d93 9d94 9d99 9d9a 9d9f 9da1 9da5 9da8
9daa 9dae 9db0 9dbc 9dbe 9dc0 9dc1 9dc6
9dca 9dcc 9dd8 9dda 9dde 9de2 9de5 9de6
9de8 9dec 9def 9df3 9df6 9df7 9dfc 9e00
9e04 9e09 9e0e 9e12 9e16 9e1a 9e1d 9e20
9e24 9e28 9e2c 9e30 9e34 9e38 9e3c 9e40
9e44 9e48 9e4c 9e50 9e5c 9e60 9e65 9e69
9e6c 9e6d 9e72 9e76 9e7a 9e7d 9e80 9e84
9e86 9e8a 9e8e 9e91 9e94 9e98 9e9a 9e9e
9ea2 9ea5 9ea7 1 9eab 9eaf 9eb3 9eb6
9eba 9ebe 9ec2 9ec6 9ec9 9ecd 9ed1 9ed4
9ed7 9edc 9edf 9ee2 9ee5 9ee6 9eeb 9eec
1 9eee 9ef3 9ef7 9efb 9efe 9f03 9f08
9f0b 9f0f 9f10 9f15 9f18 9f1d 9f1e 9f23
9f26 9f2b 9f2c 9f31 9f34 9f38 9f39 9f3e
9f41 9f46 9f47 9f4c 9f4f 9f53 9f57 9f5a
9f5d 9f5e 9f60 9f61 9f66 9f67 9f6c 9f6e
9f72 9f75 9f77 9f7b 9f7d 9f89 9f8b 9f8d
9f8e 9f93 9f97 9f99 9fa5 9fa7 9fab 9faf
9fb2 9fb6 9fb9 9fbd 9fc0 9fc1 9fc6 9fc9
9fcd 9fd1 9fd5 9fd9 9fdd 9fe1 9fe5 9fe9
9fed 9ff1 9ff5 9ff9 9ffd a001 a005 a009
a00d a011 a01d a021 a026 a02a a02d a02e
a033 a037 a03b a03e a041 a045 a047 a04b
a04f a052 a055 a059 a05b a05f a063 a066
a068 1 a06c a070 a074 a077 a07b a07f
a083 a087 a08a a08e a092 a095 a098 a09d
a0a0 a0a3 a0a6 a0a7 a0ac a0ad 1 a0af
a0b4 a0b8 a0bc a0bf a0c4 a0c9 a0cc a0d0
a0d1 a0d6 a0d9 a0de a0df a0e4 a0e7 a0ec
a0ed a0f2 a0f5 a0f9 a0fa a0ff a102 a107
a108 a10d a110 a114 a118 a11b a11e a11f
a121 a122 a127 a128 a12d a12f a133 a136
a138 a13c a13e a14a a14c a14e a14f a154
a158 a15a a166 a168 a16c a170 a173 a177
a17a a17e a181 a182 a187 a18a a18e a192
a196 a19a a19e a1a2 a1ae a1b2 a1b7 a1bb
a1be a1bf a1c4 a1c8 a1cc a1cf a1d2 a1d6
a1d8 a1dc a1e0 a1e3 a1e6 a1ea a1ec a1f0
a1f4 a1f7 a1f9 1 a1fd a201 a205 a208
a20c a210 a214 a218 a21b a21f a223 a226
a229 a22e a231 a234 a237 a238 a23d a23e
1 a240 a245 a249 a24d a250 a255 a25a
a25d a261 a262 a267 a26a a26f a270 a275
a278 a27d a27e a283 a286 a28a a28b a290
a293 a298 a299 a29e a2a1 a2a5 a2a9 a2ac
a2af a2b0 a2b2 a2b3 a2b8 a2b9 a2be a2c0
a2c4 a2c7 a2c9 a2cd a2cf a2db a2dd a2df
a2e0 a2e5 a2e9 a2eb a2f7 a2f9 a2fb a2ff
a302 a304 a308 a30b a30f a313 a317 a31b
a31f a323 a327 a32b a32f a333 a337 a33b
a33f a343 a347 a34b a34f a353 a357 a35b
a35f a363 a367 a36b a36f a373 a377 a37b
a37f a383 a387 a38b a38f a393 a397 a39b
a39f a3a3 a3a7 a3ab a3af a3b3 a3b7 a3bb
a3bf a3c3 a3c7 a3cb a3cf a3d3 a3d7 a3db
a3df a3e3 a3e7 a3eb a3ef a3f3 a3f7 a3fb
a3ff a403 a407 a40b a40f a413 a417 a41b
a41f a423 a427 a42b a42f a433 a437 a43b
a43f a443 a447 a44b a44f a453 a457 a45b
a45f a463 a467 a46b a46f a473 a477 a47b
a47f a483 a487 a48b a48f a493 a497 a49b
a49f a4a3 a4a7 a4ab a4af a4b3 a4b7 a4bb
a4bf a4c3 a4c7 a4cb a4cf a4d3 a4d7 a4db
a4df a4e3 a4e7 a4eb a4ef a4f3 a4f7 a4fb
a4ff a503 a507 a50b a50f a513 a517 a51b
a51f a523 a527 a52b a52f a533 a537 a53b
a53f a543 a547 a54b a54f a553 a557 a55b
a55f a563 a567 a56b a56f a573 a577 a57b
a57f a583 a587 a58b a58f a593 a597 a59b
a59f a5a3 a5a7 a5ab a5af a5b3 a5b7 a5bb
a5bf a5c3 a5c7 a5cb a5cf a5d3 a5d7 a5db
a5df a5e3 a5e7 a5eb a5ef a5f3 a5f7 a5fb
a5ff a603 a607 a60b a60f a613 a617 a61b
a61f a623 a627 a62b a62f a633 a637 a63b
a647 a64c a650 a654 a658 a65b a65f a663
a666 a669 a66e a671 a674 a677 a678 a67d
a67e 1 a680 a685 a689 a68d a690 a695
a69a a69d a6a1 a6a2 a6a7 a6a8 a6ad a6af
a6b3 a6b6 a6ba a6be a6c2 a6c4 a6c8 a6cb
a6ce a6cf a6d4 a6d8 a6dc a6e0 a6e4 a6e8
a6ec a6f0 a6f4 a6f8 a6fc a700 a704 a708
a70c a710 a714 a718 a71c a720 a724 a728
a72c a730 a734 a738 a73c a740 a744 a748
a74c a750 a754 a758 a75c a760 a764 a768
a76c a770 a774 a778 a77c a780 a784 a788
a78c a790 a794 a798 a79c a7a0 a7a4 a7a8
a7ac a7b0 a7b4 a7b8 a7bc a7c0 a7c4 a7c8
a7cc a7d0 a7d4 a7d8 a7dc a7e0 a7e4 a7e8
a7ec a7f0 a7f4 a7f8 a7fc a800 a804 a808
a80c a810 a814 a818 a81c a820 a824 a828
a82c a830 a834 a838 a83c a840 a844 a848
a84c a850 a854 a858 a85c a860 a864 a868
a86c a870 a874 a878 a87c a880 a884 a888
a88c a890 a894 a898 a89c a8a0 a8a4 a8a8
a8ac a8b0 a8b4 a8b8 a8bc a8c0 a8c4 a8c8
a8cc a8d0 a8d4 a8d8 a8dc a8e0 a8e4 a8e8
a8ec a8f0 a8f4 a8f8 a8fc a900 a904 a908
a90c a910 a914 a918 a91c a920 a924 a928
a92c a930 a934 a938 a93c a940 a944 a948
a94c a950 a954 a958 a95c a960 a964 a968
a96c a970 a974 a978 a97c a980 a984 a988
a98c a990 a994 a998 a99c a9a0 a9a4 a9a8
a9ac a9b0 a9b4 a9b8 a9bc a9c0 a9c4 a9c8
a9cc a9d0 a9d4 a9d8 a9dc a9e0 a9e4 a9e8
a9ec a9f0 a9f4 a9f8 a9fc aa00 aa04 aa08
aa0c aa10 aa14 aa18 aa1c aa20 aa24 aa28
aa2c aa30 aa34 aa38 aa3c aa40 aa44 aa48
aa4c aa50 aa54 aa58 aa5c aa60 aa64 aa68
aa6c aa70 aa74 aa78 aa7c aa80 aa84 aa88
aa8c aa90 aa94 aa98 aa9c aaa0 aaa4 aaa8
aaac aab0 aab4 aab8 aabc aac0 aac4 aac8
aacc aad0 aad4 aad8 aadc aae0 aae4 aae8
aaec aaf0 aaf4 aaf8 aafc ab00 ab04 ab08
ab0c ab10 ab14 ab18 ab1c ab20 ab24 ab28
ab2c ab30 ab34 ab38 ab3c ab40 ab44 ab48
ab4c ab50 ab54 ab58 ab5c ab60 ab64 ab68
ab6c ab70 ab74 ab78 ab7c ab80 ab84 ab88
ab94 ab99 ab9d aba1 aba5 aba8 abac abb0
abb3 abb6 abbb abbe abc1 abc4 abc5 abca
abcb 1 abcd abd2 abd6 abda abdd abe2
abe7 abea abee abef abf4 abf5 abfa abfc
ac00 ac03 ac07 ac0b ac0f ac11 ac15 ac19
ac1e ac23 ac27 ac2b ac2f ac32 ac35 ac39
ac3d ac41 ac45 ac49 ac4d ac51 ac55 ac59
ac65 ac69 ac6e ac72 ac75 ac76 ac7b ac7f
ac83 ac86 ac89 ac8d ac8f ac93 ac97 ac9a
ac9d aca1 aca3 aca7 acab acae acb0 1
acb4 acb8 acbc acbf acc3 acc7 accb accf
acd2 acd6 acda acdd ace0 ace5 ace8 aceb
acee acef acf4 acf5 1 acf7 acfc ad00
ad04 ad07 ad0c ad11 ad14 ad18 ad19 ad1e
ad21 ad26 ad27 ad2c ad2f ad34 ad35 ad3a
ad3d ad41 ad42 ad47 ad4a ad4f ad50 ad55
ad58 ad5c ad60 ad63 ad66 ad67 ad69 ad6a
ad6f ad70 ad75 ad77 ad7b ad7e ad80 ad84
ad86 ad92 ad94 ad96 ad97 ad9c ada0 ada2
adae adb0 adb4 adb8 adbc adc0 adc4 adc8
adcc add0 add4 add8 addc ade0 ade4 ade8
adec adf0 adf4 adf8 adfc ae00 ae0c ae10
ae15 ae19 ae1c ae1d ae22 ae26 ae2a ae2d
ae30 ae34 ae36 ae3a ae3e ae41 ae44 ae48
ae4a ae4e ae52 ae55 ae57 1 ae5b ae5f
ae63 ae66 ae6a ae6e ae72 ae76 ae79 ae7d
ae81 ae84 ae87 ae8c ae8f ae92 ae95 ae96
ae9b ae9c 1 ae9e aea3 aea7 aeab aeae
aeb3 aeb8 aebb aebf aec0 aec5 aec8 aecd
aece aed3 aed6 aedb aedc aee1 aee4 aee8
aee9 aeee aef1 aef6 aef7 aefc aeff af03
af07 af0a af0d af0e af10 af11 af16 af17
af1c af1e af22 af25 af27 af2b af2d af39
af3b af3d af3e af43 af47 af49 af55 af57
af5b af5f af63 af67 af6b af6f af73 af77
af7b af7f af83 af87 af8b af8f af93 af97
af9b af9f afa3 afa7 afab afaf afb3 afb7
afbb afbf afc3 afc7 afcb afcf afd3 afd7
afdb afdf afe3 afe7 afeb afef aff3 aff7
affb afff b003 b007 b00b b00f b013 b017
b01b b01f b023 b027 b02b b02f b033 b037
b03b b03f b043 b047 b04b b04f b053 b057
b05b b05f b063 b067 b06b b06f b073 b077
b07b b07f b083 b087 b08b b08f b093 b097
b09b b09f b0a3 b0a7 b0ab b0af b0b3 b0b7
b0bb b0bf b0c3 b0c7 b0cb b0cf b0d3 b0d7
b0db b0df b0e3 b0e7 b0eb b0ef b0f3 b0f7
b0fb b0ff b103 b107 b10b b10f b113 b117
b11b b11f b123 b127 b12b b12f b133 b137
b13b b13f b143 b147 b14b b14f b153 b157
b15b b15f b163 b167 b16b b16f b173 b177
b17b b17f b183 b187 b18b b18f b193 b197
b19b b19f b1a3 b1a7 b1ab b1af b1b3 b1b7
b1bb b1bf b1c3 b1c7 b1cb b1cf b1d3 b1d7
b1db b1df b1e3 b1e7 b1eb b1ef b1f3 b1f7
b1fb b1ff b203 b207 b20b b20f b213 b217
b21b b21f b223 b227 b22b b22f b233 b237
b23b b23f b243 b247 b24b b24f b253 b257
b25b b25f b263 b267 b26b b26f b273 b277
b27b b27f b283 b287 b28b b28f b293 b297
b29b b29f b2a3 b2a7 b2ab b2af b2b3 b2b7
b2bb b2bf b2c3 b2c7 b2cb b2cf b2d3 b2d7
b2db b2df b2e3 b2e7 b2eb b2ef b2f3 b2f7
b2fb b2ff b303 b307 b30b b30f b313 b317
b31b b31f b323 b327 b32b b32f b333 b337
b33b b33f b343 b347 b34b b34f b353 b357
b35b b35f b363 b367 b36b b36f b373 b377
b37b b37f b383 b387 b38b b38f b393 b397
b39b b39f b3a3 b3a7 b3ab b3af b3b3 b3b7
b3bb b3bf b3c3 b3c7 b3cb b3cf b3d3 b3d7
b3db b3df b3e3 b3e7 b3eb b3ef b3f3 b3f7
b3fb b3ff b403 b407 b40b b40f b413 b417
b41b b41f b423 b427 b42b b42f b433 b437
b43b b43f b443 b447 b44b b44f b453 b457
b45b b45f b463 b467 b46b b46f b473 b477
b47b b47f b483 b487 b48b b48f b493 b497
b49b b49f b4a3 b4a7 b4ab b4af b4b3 b4b7
b4bb b4bf b4c3 b4c7 b4cb b4cf b4d3 b4d7
b4db b4df b4e3 b4e7 b4eb b4ef b4f3 b4f7
b4fb b4ff b503 b507 b50b b50f b513 b517
b51b b51f b523 b527 b52b b52f b533 b537
b53b b53f b543 b547 b54b b54f b553 b557
b55b b55f b563 b567 b56b b56f b573 b577
b57b b57f b583 b587 b58b b58f b593 b597
b59b b59f b5a3 b5a7 b5ab b5af b5b3 b5b7
b5bb b5bf b5c3 b5c7 b5cb b5cf b5d3 b5d7
b5db b5df b5e3 b5e7 b5eb b5ef b5f3 b5f7
b5fb b5ff b603 b607 b60b b60f b613 b617
b61b b61f b623 b627 b62b b62f b633 b63f
b644 b648 b64c b650 b653 b657 b65b b65e
b661 b666 b669 b66c b66f b670 b675 b676
1 b678 b67d b681 b685 b688 b68d b692
b695 b699 b69a b69f b6a0 b6a5 b6a7 b6ab
b6ae b6b2 b6b6 b6ba b6bc b6c0 b6c4 b6c7
b6c9 b6cd b6d1 b6d4 b6d6 b6da b6de b6e1
b6e5 b6e9 b6ec b6f0 b6f4 b6f7 b6fa b6ff
b702 b705 b708 b709 b70e b70f 1 b711
b716 b71a b71e b721 b726 b72b b72e b732
b733 b738 b739 b73e b742 b746 b749 b74e
b753 b756 b75a b75e b761 b762 b767 b76a
b76f b770 b775 b778 b77c b780 b783 b784
b789 b78a b78f b791 b795 b798 b79c b7a0
b7a4 b7a8 b7ac b7b0 b7b4 b7b8 b7bc b7c8
b7cd b7d1 b7d5 b7d9 b7dd b7df b7e0 b7e5
1 b7e9 b7ed b7f1 b7f4 b7f8 b7fc b800
b804 b807 b80b b80f b812 b815 b81a b81d
b820 b823 b824 b829 b82a 1 b82c b831
b835 b839 b83c b841 b846 b849 b84d b84e
b853 b854 b859 b85d b861 b864 b869 b86e
b871 b875 b876 b87b b87e b883 b884 b889
b88c b890 b894 b897 b89a b89b b89d b89e
b8a3 b8a4 b8a9 b8ab b8af b8b2 b8b6 b8ba
b8be b8c2 b8c6 b8ca b8ce b8da b8df b8e3
b8e7 b8eb b8ef b8f1 b8f5 b8f7 b903 b905
b907 b908 b90d b911 b913 b91f b923 b925
b926 b92f 
34ca
2
0 1 a 6 d :3 6 14 :3 6
15 :3 6 10 :3 6 e :3 6 11 :3 6
c :3 6 b :3 6 11 :3 6 11 :3 6
1d :3 6 c :3 6 e :3 6 10 :3 6
10 :3 6 11 :3 6 17 :3 6 10 :3 6
11 :3 6 10 :3 6 11 :3 6 f :3 6
f :3 6 10 :3 6 d :3 6 e :3 6
12 :2 6 1 3 a 13 a :2 1
4 d 16 15 :2 d :2 4 11 1a
19 :2 11 :2 4 e 17 16 :2 e :2 4
c 15 14 :2 c :2 4 f 18 17
:2 f :2 4 f 18 17 :2 f :2 4 c
15 14 :2 c :2 4 b 14 13 :2 b
:2 4 10 19 18 :2 10 :2 4 11 1a
19 :2 11 :2 4 10 19 18 :2 10 :2 4
11 1a 19 :2 11 :2 4 f 18 17
:2 f :2 4 10 19 18 :2 10 :2 4 f
18 17 :2 f :2 4 10 19 18 :2 10
:2 4 11 1a 19 :2 11 :2 4 11 1a
19 :2 11 :2 4 d 16 15 :2 d :2 4
e 17 16 :2 e :2 4 b 14 13
:2 b :2 4 :3 10 :2 4 11 1a 19 :2 11
:2 4 f 18 17 :2 f :2 4 10 19
18 :2 10 :2 4 14 1d 1c :2 14 :2 4
15 1e 1d :2 15 :2 4 f 18 17
:2 f :2 4 10 19 18 :2 10 :2 4 e
17 16 :2 e :2 4 f 18 17 :2 f
:2 4 10 19 18 :2 10 :2 4 11 1a
19 :2 11 :2 4 :2 e 1d e :2 4 :2 d
1c d :2 4 :2 b 1a b :2 4 :2 c
1b c :2 4 :2 d 1c d :2 4 :2 10
1f 10 :2 4 :2 14 23 14 :2 4 :2 a
19 a :2 4 :2 f 1e f :2 4 :2 b
1a b :2 4 :2 11 20 11 :2 4 :2 d
1c d :2 4 :2 c 1b c :2 4 :2 b
1a b :2 4 :2 f 1e f :2 4 :2 e
1d e :2 4 :2 c 1b c :2 4 :2 e
1d e :2 4 :2 f 1e f :2 4 :2 f
1e f :2 4 :2 12 21 12 :2 4 :2 d
1c d :2 4 :2 f 1e f :2 4 :2 b
1a b :2 4 :2 f 19 f :2 4 :2 13
1d 13 :2 4 :2 c 1b c :2 4 :2 10
1f 10 :2 4 :2 12 21 12 :2 4 :2 11
20 11 :2 4 :2 16 25 16 :2 4 :2 16
25 16 :2 4 :2 b 1a b :2 4 d
16 15 :2 d :2 4 :2 10 1f 10 :2 4
:2 11 20 11 :2 4 :2 12 21 12 :2 4
9 12 11 :2 9 :2 4 c 15 14
:2 c :2 4 10 19 18 :2 10 :2 4 :2 11
20 11 :2 4 :2 17 26 17 :2 4 17
1c 1b :2 17 :2 4 18 1d 1c :2 18
:2 4 11 1a 19 :2 11 :2 4 12 1b
1a :2 12 :2 4 16 1f 1e :2 16 :2 4
b 14 13 :2 b :2 4 :2 f 1e f
:2 4 :2 13 22 13 :2 4 :2 14 23 14
:2 4 :2 6 1e 6 :2 4 :2 7 1f 7
:2 4 :2 a 22 a :2 4 :2 d 25 d
:2 4 :2 8 20 8 :2 4 a 13 12
:2 a :2 4 :2 e 26 e :2 4 :3 d :2 4
:3 13 :2 4 :3 8 :2 4 :3 6 :2 4 :3 9 :2 4
:3 c :2 4 :3 c 4 7 b 14 :3 b
:2 7 e 0 :2 7 11 f 10 1d
e 18 e 1c a :6 7 e 0
:2 7 a :2 c 12 c 15 c 12
c 15 c 15 c 15 f 13
fffa :6 7 e 17 :3 e :2 7 e 17
:3 e :2 7 e 17 :3 e 7 4 e
17 :3 e 4 7 :2 11 23 :2 2d 3a
:2 23 :3 7 :2 d 19 25 :2 2f 43 :2 25
53 59 5c :2 53 6a 7f 8 :2 6a
d 10 :2 6a 17 1a :2 6a b e
:2 6a 13 16 :2 6a 1b 1e :2 6a 2c
2f :2 6a b e :2 6a 13 16 :2 6a
1b 1e :2 6a 2d 30 :2 6a b e
:2 6a 13 16 1f 27 :2 1f 33 :2 16
:2 6a b e :2 6a 13 16 1f 27
:2 1f 31 :2 16 :2 6a b e :2 6a 13
16 1f 27 :2 1f 34 :2 16 :2 6a b
e :2 6a 13 16 1f 27 :2 1f 2f
:2 16 :2 6a b e :2 6a 13 16 1f
27 :2 1f 2e :2 16 :2 6a b e :2 6a
13 16 1f 27 :2 1f 34 :2 16 :2 6a
b e :2 6a 13 16 1f 27 :2 1f
34 :2 16 :2 6a b e :2 6a 13 16
1f 27 :2 1f 40 :2 16 :2 6a b e
:2 6a 13 16 :2 6a 1b 1e :2 6a 24
27 :2 6a b e :2 6a 13 16 :2 6a
1b 1e :2 6a 26 29 :2 6a b e
:2 6a 13 16 :2 6a 1b 1e :2 6a 28
2b :2 6a b e :2 6a 13 16 :2 6a
1b 1e :2 6a 28 2b :2 6a b e
:2 6a 13 16 :2 6a 1b 1e :2 6a 29
2c :2 6a b e :2 6a 13 16 1f
27 :2 1f 3a :2 16 :2 6a b e :2 6a
13 16 :2 6a 1b 1e :2 6a 28 2b
:2 6a b e :2 6a 13 16 :2 6a 1b
1e :2 6a 29 2c :2 6a b e :2 6a
13 16 :2 6a 1b 1e :2 6a 28 2b
:2 6a b e :2 6a 13 16 :2 6a 1b
1e :2 6a 29 2c :2 6a b e :2 6a
13 16 1f 27 :2 1f 32 :2 16 :2 6a
b e :2 6a 13 16 1f 27 :2 1f
32 :2 16 :2 6a b e :2 6a 13 16
1f 27 :2 1f 33 :2 16 :2 6a b e
:2 6a 13 16 1f 27 :2 1f 30 :2 16
:2 6a b e :2 6a 13 16 :2 6a 1b
1e :2 6a 26 29 :2 6a b e :2 6a
13 16 :2 6a 1b 1e :2 6a 2a 2d
:2 6a 32 35 :2 6a :2 7 49 :2 4 7
:2 11 23 :2 2d 39 3c 4b 4e 4f
:2 4b :2 23 :3 7 :2 d 12 1e 5b 5e
:2 1e :2 7 52 :3 4 14 :2 4 14 :2 4
13 :2 4 f :2 4 e :2 4 13 :2 4
14 :2 4 13 :2 4 14 :2 4 12 :2 4
10 :2 4 e :2 4 14 :2 4 12 :2 4
f :2 4 12 :2 4 e :2 4 e :2 4
11 :2 4 11 :2 4 10 :2 4 13 :2 4
13 :2 4 14 4 8 11 1c :2 8
22 1f :2 2b :2 1f 7 :4 46 45 44
:2 7 a :2 14 26 :2 30 3c 3f 4e
51 52 :2 4e :2 26 :3 a :2 10 15 21
5e 61 :2 21 6e 71 :2 21 75 78
:2 21 82 85 8e 96 :2 9f :2 8e b5
:2 85 :2 21 :2 a 55 :2 7 a :2 14 26
:2 30 3c 3f 4e 51 52 :2 4e :2 26
:3 a :2 10 15 21 5e 61 :2 21 :2 a
55 :3 7 :2 12 28 :2 31 46 :2 7 57
:2 4 :4 9 8 7 :4 1f 1e 1d :2 7
:4 39 38 37 :2 7 :4 53 52 51 :2 7
f 18 24 :2 f 2a 27 :2 33 :2 27
e :2 7 :4 c b a 25 2e 3a
:2 25 3f 3d :2 48 :2 3d 24 :2 a d
:2 17 29 :2 33 3f 42 51 54 55
:2 51 :2 29 :3 d :2 13 18 24 61 64
:2 24 71 74 :2 24 78 7b :2 24 85
88 91 99 :2 a2 :2 91 b3 :2 88 :2 24
:2 d 58 :2 a d :2 17 29 :2 33 3f
42 51 54 55 :2 51 :2 29 :3 d :2 13
18 24 61 64 :2 24 :2 d 58 :3 a
:2 15 2b :2 34 44 :2 a 7 59 :4 f
e d :4 29 28 27 :3 d :2 17 29
:2 33 3f 42 51 54 55 :2 51 :2 29
:3 d :2 13 18 24 61 64 :2 24 71
74 :2 24 78 7b :2 24 85 88 91
99 :2 a2 :2 91 b3 :2 88 :2 24 :2 d 58
:2 a d :2 17 29 :2 33 3f 42 51
54 55 :2 51 :2 29 :3 d :2 13 18 24
61 64 :2 24 :2 d 58 :3 a :2 15 2b
:2 34 44 :2 a 3e 59 :2 7 49 :2 4
7 10 1b :2 7 1e 20 :2 1e 26
2f 37 :2 26 3a 3c :2 3a :2 7 42
4b 53 :2 42 56 58 :2 56 :2 7 a
:2 14 26 :2 30 3c 3f 4e 51 52
:2 4e :2 26 :3 a :2 10 15 21 5e 61
:2 21 6e 71 :2 21 75 78 :2 21 82
85 8e 96 :2 9f :2 8e b0 :2 85 :2 21
:2 a 55 :2 7 a :2 14 26 :2 30 3c
3f 4e 51 52 :2 4e :2 26 :3 a :2 10
15 21 5e 61 :2 21 :2 a 55 :3 7
:2 12 28 :2 31 41 :2 7 5a :2 4 :4 9
8 :2 7 1a 7 24 7 1a 7
:4 4 8 11 1c :2 8 22 1f :2 2b
:2 1f 7 :4 46 45 44 :2 7 :4 14 13
12 :2 7 11 1c 21 33 3e 43
:2 f :2 a :2 13 1f a 7 :2 f d
:2 16 22 d 10 :2 1a 2c :2 36 42
46 55 58 59 :2 55 :2 2c :3 10 :2 16
1b 27 64 67 :2 27 74 77 :2 27
7b 7e :2 27 8a 8d :2 27 95 98
:2 27 a4 a7 ae b7 ba :2 a7 :2 27
:2 10 5c :2 d :2 a :4 16 :2 a 7 :3 31
b :2 14 1f 1d :2 28 :2 1d a 3d
46 4f :2 3d 52 54 :2 52 3c :2 a
d :2 17 29 :2 33 3f 42 51 54
55 :2 51 :2 29 :3 d :2 13 18 24 61
64 :2 24 71 74 :2 24 78 7b :2 24
85 88 91 99 :2 a2 :2 91 bf :2 88
:2 24 :2 d 58 :2 a d :2 17 29 :2 33
3f 42 51 54 55 :2 51 :2 29 :3 d
:2 13 18 24 61 64 :2 24 :2 d 58
:3 a :2 15 2b :2 34 50 :2 a 57 :3 7
e 7 31 :2 4 :4 9 8 7 :4 27
26 25 :2 7 11 23 35 :2 a :2 13
1f a 7 :2 f d :2 16 22 d
10 :2 1a 2c :2 36 42 46 55 58
59 :2 55 :2 2c :3 10 :2 16 1b 27 64
67 :2 27 74 77 :2 27 7b 7e :2 27
8a 8d :2 27 95 98 :2 27 a4 a7
ae b7 ba :2 a7 :2 27 :2 10 5c :2 d
:2 a :4 16 :2 a 7 :4 40 :3 4 12 :2 4
13 :2 1c 28 2f 38 40 :2 2f 44
:2 4d :2 28 27 5c :2 13 :2 4 e 15
1e 26 :2 15 2a :2 33 :2 e :2 4 d
:2 16 22 29 32 3e :2 29 42 :2 4b
:2 22 21 5a :2 d :2 4 12 19 22
2e :2 19 32 :2 3b :2 12 :2 4 1c 25
31 :2 1c 36 34 :2 3f :2 34 54 :2 17
5b :2 12 4 7 10 18 :2 7 1b
1d :2 1b 7 15 7 11 21 f
10 1d :2 a :2 13 1f a 7 :2 f
d :2 16 22 d 10 :2 1a 2c :2 36
42 46 55 58 59 :2 55 :2 2c :3 10
:2 16 1b 27 64 67 :2 27 74 77
:2 27 7b 7e :2 27 8a 8d :2 27 95
98 :2 27 a4 a7 ae b7 ba :2 a7
:2 27 :2 10 5c :2 d :2 a :4 16 :2 a 7
:3 1f a 13 1f :2 a 22 24 :2 22
14 24 12 13 20 :2 d :2 16 22
d a :2 12 10 :2 19 25 10 13
:2 1d 2f :2 39 45 49 58 5b 5c
:2 58 :2 2f :3 13 :2 19 1e 2a 67 6a
:2 2a 77 7a :2 2a 7e 81 :2 2a 8d
90 :2 2a 98 9b :2 2a a7 aa b1
ba bd :2 aa :2 2a :2 13 5f :2 10 :2 d
:4 19 :2 d a :3 26 d :2 18 1f 2d
:2 d 32 34 :2 32 10 :2 1a 2c :2 36
42 46 55 58 59 :2 55 :2 2c :3 10
:2 16 1b 27 64 67 :2 27 74 77
:2 27 7b 7e :2 27 88 8b 94 9c
:2 a5 :2 94 ba :2 8b :2 27 c2 c5 :2 27
cd d0 :2 27 d5 d8 :2 27 e5 e8
:2 27 :2 10 5c :2 d 10 :2 1a 2c :2 36
42 45 54 57 58 :2 54 :2 2c :3 10
:2 16 1b 27 64 67 :2 27 :2 10 5b
:3 d :2 18 2c :2 35 49 57 :2 d 36
:2 a 26 :3 7 17 20 29 31 :2 20
:2 17 7 a 13 21 :2 a 24 26
:2 24 a 14 20 29 31 :2 20 :2 14
a d 16 1e :2 d 21 23 :2 21
10 :2 1a 2c :2 36 42 45 54 57
58 :2 54 :2 2c :3 10 :2 16 1b 27 64
67 :2 27 74 77 :2 27 7b 7e :2 27
88 8b 94 9c :2 a5 :2 94 b6 :2 8b
:2 27 :2 10 5b :2 d 10 :2 1a 2c :2 36
42 45 54 57 58 :2 54 :2 2c :3 10
:2 16 1b 27 64 67 :2 27 :2 10 5b
:3 d :2 18 2e :2 37 47 :2 d 25 :3 a
1a :2 23 a 28 :3 7 14 7 a
13 20 :2 a 23 26 :2 23 a 16
a 28 d :2 17 29 :2 33 3f 42
51 54 55 :2 51 :2 29 :3 d :2 13 18
24 61 64 :2 24 71 74 :2 24 78
7b :2 24 85 88 91 99 :2 a2 :2 91
b3 :2 88 :2 24 :2 d 58 :2 a d :2 17
29 :2 33 3f 42 51 54 55 :2 51
:2 29 :3 d :2 13 18 24 61 64 :2 24
:2 d 58 :3 a :2 15 2b :2 34 44 :2 a
:5 7 1a 29 37 3f 4a 54 25
:2 1a 7 a 13 24 :2 a 27 2a
:2 27 d :2 17 29 :2 33 3f 43 52
55 56 :2 52 :2 29 :3 d :2 13 18 24
61 64 :2 24 71 74 :2 24 78 7b
:2 24 85 88 91 99 :2 91 ab :2 88
:2 24 b3 b6 :2 24 be c1 :2 24 c6
c9 :2 24 d5 d8 :2 24 :2 d 59 :2 a
d :2 17 29 :2 33 3f 42 51 54
55 :2 51 :2 29 :3 d :2 13 18 24 61
64 :2 24 :2 d 58 :3 a :2 15 29 32
43 :2 29 47 54 :2 a 2c :2 7 a
13 1e :2 a 23 21 :2 2c :2 21 d
:2 17 29 :2 33 3f 43 52 55 56
:2 52 :2 29 :3 d :2 13 18 24 61 64
:2 24 71 74 :2 24 78 7b :2 24 85
88 91 99 :2 a2 :2 91 ad :2 88 :2 24
b5 b8 :2 24 c0 c3 :2 24 c8 cb
:2 24 d7 da :2 24 :2 d 59 :2 a d
:2 17 29 :2 33 3f 42 51 54 55
:2 51 :2 29 :3 d :2 13 18 24 61 64
:2 24 :2 d 58 :3 a :2 15 29 :2 32 3c
49 :2 a 40 :2 7 a 13 21 :2 a
26 24 :2 2f :2 24 d 1b 24 2c
:2 1b :2 d 30 33 :2 30 10 12 1b
12 1b 12 10 :3 12 15 16 23
fffa 10 :2 19 25 10 d :2 15 13
:2 1c 28 13 16 :2 20 32 :2 3c 48
4c 5b 5e 5f :2 5b :2 32 :3 16 :2 1c
21 2d 6a 6d :2 2d 7a 7d :2 2d
81 84 :2 2d 90 93 :2 2d 9b 9e
:2 2d aa ad b4 bd c0 :2 ad :2 2d
:2 16 62 :2 13 :2 10 :4 1c :2 10 d :4 35
10 :2 12 14 12 14 12 14 12
1b 1d 12 1b 1d 12 14 12
14 25 27 10 :7 12 15 1d 20
28 16 18 25 14 16 23 25
fffa 10 :2 19 25 10 d :2 15 13
:2 1c 28 13 16 :2 20 32 :2 3c 48
4c 5b 5e 5f :2 5b :2 32 :3 16 :2 1c
21 2d 6a 6d :2 2d 7a 7d :2 2d
81 84 :2 2d 90 93 :2 2d 9b 9e
:2 2d aa ad b4 bd c0 :2 ad :2 2d
:2 16 62 :2 13 :2 10 :4 1c :2 10 d :7 a
e :2 17 23 20 :2 2c :2 20 d 10
:2 1a 2c :2 36 42 46 55 58 59
:2 55 :2 2c :3 10 :2 16 1b 27 64 67
:2 27 74 77 :2 27 7b 7e :2 27 88
8b 94 9c :2 a5 :2 94 b8 :2 8b :2 27
c0 c3 :2 27 cb ce :2 27 d3 d6
:2 27 e0 e3 :2 27 :2 10 5c :2 d 10
:2 1a 2c :2 36 42 45 54 57 58
:2 54 :2 2c :3 10 :2 16 1b 27 64 67
:2 27 :2 10 5b :3 d :2 18 2c :2 35 47
52 :2 d 3c :2 a 7 3c d 16
24 :2 d 29 27 :2 32 :2 27 d :2 f
d :2 f 12 13 20 fffa d :2 16
22 d a :2 12 10 :2 19 25 10
13 :2 1d 2f :2 39 45 49 58 5b
5c :2 58 :2 2f :3 13 :2 19 1e 2a 67
6a :2 2a 77 7a :2 2a 7e 81 :2 2a
8d 90 :2 2a 98 9b :2 2a a7 aa
b1 ba bd :2 aa :2 2a :2 13 5f :2 10
:2 d :4 19 :2 d a :3 3f e :2 17 23
20 :2 2c :2 20 d 10 :2 1a 2c :2 36
42 46 55 58 59 :2 55 :2 2c :3 10
:2 16 1b 27 64 67 :2 27 74 77
:2 27 7b 7e :2 27 88 8b 94 9c
:2 a5 :2 94 b8 :2 8b :2 27 c0 c3 :2 27
cb ce :2 27 d3 d6 :2 27 e0 e3
:2 27 :2 10 5c :2 d 10 :2 1a 2c :2 36
42 45 54 57 58 :2 54 :2 2c :3 10
:2 16 1b 27 64 67 :2 27 :2 10 5b
:3 d :2 18 2c :2 35 47 52 :2 d 3c
:2 a 12 1d :2 12 1f f 18 f
18 f d :3 f 12 13 20 11
1e fffa d :2 16 22 d a :2 12
10 :2 19 25 10 13 :2 1d 2f :2 39
45 49 58 5b 5c :2 58 :2 2f :3 13
:2 19 1e 2a 67 6a :2 2a 77 7a
:2 2a 7e 81 :2 2a 8d 90 :2 2a 98
9b :2 2a a7 aa b1 ba bd :2 aa
:2 2a :2 13 5f :2 10 :2 d :4 19 :2 d a
:3 3f e :2 17 23 20 :2 2c :2 20 d
10 :2 1a 2c :2 36 42 46 55 58
59 :2 55 :2 2c :3 10 :2 16 1b 27 64
67 :2 27 74 77 :2 27 7b 7e :2 27
88 8b 94 9c :2 a5 :2 94 b8 :2 8b
:2 27 c0 c3 :2 27 cb ce :2 27 d3
d6 :2 27 e3 e6 :2 27 :2 10 5c :2 d
10 :2 1a 2c :2 36 42 45 54 57
58 :2 54 :2 2c :3 10 :2 16 1b 27 64
67 :2 27 :2 10 5b :3 d :2 18 2c :2 35
47 55 :2 d 3c :2 a :4 e :2 d 1d
:2 26 :2 d 17 26 :2 17 d 24 :2 a
3f 3c d :2 17 29 :2 33 3f 43
52 55 56 :2 52 :2 29 :3 d :2 13 18
24 61 64 :2 24 71 74 :2 24 78
7b :2 24 85 88 91 99 :2 a2 :2 91
b3 :2 88 :2 24 bb be :2 24 c6 c9
:2 24 ce d1 :2 24 de e1 :2 24 :2 d
59 :2 a d :2 17 29 :2 33 3f 42
51 54 55 :2 51 :2 29 :3 d :2 13 18
24 61 64 :2 24 :2 d 58 :3 a :2 15
29 :2 32 42 50 :2 a :4 7 a 13
1f :2 a 25 22 :2 2e :2 22 d f
1a 25 :2 f 18 23 2e f 18
23 2e d :4 f 12 13 21 fffa
d :2 16 22 d a :2 12 10 :2 19
25 10 13 :2 1d 2f :2 39 45 49
58 5b 5c :2 58 :2 2f :3 13 :2 19 1e
2a 67 6a :2 2a 77 7a :2 2a 7e
81 :2 2a 8d 90 :2 2a 98 9b :2 2a
a7 aa b1 ba bd :2 aa :2 2a :2 13
5f :2 10 :2 d :4 19 :2 d a :3 3e e
:2 17 22 20 :2 2b :2 20 d 10 :2 1a
2c :2 36 42 46 55 58 59 :2 55
:2 2c :3 10 :2 16 1b 27 64 67 :2 27
74 77 :2 27 7b 7e :2 27 88 8b
94 9c :2 a5 :2 94 b8 :2 8b :2 27 c0
c3 :2 27 cb ce :2 27 d3 d6 :2 27
df e2 :2 27 :2 10 5c :2 d 10 :2 1a
2c :2 36 42 45 54 57 58 :2 54
:2 2c :3 10 :2 16 1b 27 64 67 :2 27
:2 10 5b :3 d :2 18 2c :2 35 47 51
:2 d a 3b 11 :2 1a 25 23 :2 2e
:2 23 :2 10 17 21 24 :2 10 27 29
:2 27 31 3a 4d :2 31 50 52 :2 50
58 13 21 :2 58 26 24 2f 42
:2 26 :2 24 :2 31 30 :2 10 49 13 21
:2 49 26 24 2f 42 :2 26 :2 24 :2 10
13 :2 1d 2f :2 39 45 49 58 5b
5c :2 58 :2 2f :3 13 :2 19 1e 2a 67
6a :2 2a 77 7a :2 2a 7e 81 :2 2a
8b 8e 97 9f :2 a8 :2 97 be :2 8e
:2 2a c6 c9 :2 2a d1 d4 :2 2a d9
dc :2 2a e5 e8 :2 2a :2 13 5f :2 10
13 :2 1d 2f :2 39 45 48 57 5a
5b :2 57 :2 2f :3 13 :2 19 1e 2a 67
6a :2 2a :2 13 5e :3 10 :2 1b 2f :2 38
4d 57 :2 10 45 :2 d 3e 3b :2 a
3e :2 7 1f :2 4 7 10 18 :2 7
1b 1d :2 1b a 13 1f :2 a 24
22 :2 2d :2 22 :4 42 41 :2 a 59 d
1a :2 59 1d 1f :2 1d :2 a d :2 17
29 :2 33 3f 43 52 55 56 :2 52
:2 29 :3 d :2 13 18 24 61 64 :2 24
71 74 :2 24 78 7b :2 24 85 88
91 99 :2 a2 :2 91 bd :2 88 :2 24 c5
c8 :2 24 d0 d3 :2 24 d8 db :2 24
e8 eb :2 24 :2 d 59 :2 a d :2 17
29 :2 33 3f 42 51 54 55 :2 51
:2 29 :3 d :2 13 18 24 61 64 :2 24
:2 d 58 :3 a :2 15 29 :2 32 4c 12
:2 a 21 :2 7 a 13 1e :2 a 24
21 :2 2d :2 21 d f 18 f 18
d :2 f 12 13 20 fffa d :2 16
22 d a :2 12 10 :2 19 25 10
13 :2 1d 2f :2 39 45 49 58 5b
5c :2 58 :2 2f :3 13 :2 19 1e 2a 67
6a :2 2a 77 7a :2 2a 7e 81 :2 2a
8d 90 :2 2a 98 9b :2 2a a7 aa
b1 ba bd :2 aa :2 2a :2 13 5f :2 10
:2 d :4 19 :2 d a :3 41 e :2 17 22
20 :2 2b :2 20 d 10 12 15 25
32 fffa 10 :2 19 25 10 d :2 15
13 :2 1c 28 13 16 :2 20 32 :2 3c
48 4c 5b 5e 5f :2 5b :2 32 :3 16
:2 1c 21 2d 6a 6d :2 2d 7a 7d
:2 2d 81 84 :2 2d 90 93 :2 2d 9b
9e :2 2d aa ad b4 bd c0 :2 ad
:2 2d :2 16 62 :2 13 :2 10 :4 1c :2 10 d
:3 3b 11 :2 1a 25 23 :2 2e :2 23 10
13 :2 1d 2f :2 39 45 49 58 5b
5c :2 58 :2 2f :3 13 :2 19 1e 2a 67
6a :2 2a 77 7a :2 2a 7e 81 :2 2a
8b 8e 97 9f :2 a8 :2 97 b9 :2 8e
:2 2a c1 c4 :2 2a cc cf :2 2a d4
d7 :2 2a e4 e7 :2 2a :2 13 5f :2 10
13 :2 1d 2f :2 39 45 48 57 5a
5b :2 57 :2 2f :3 13 :2 19 1e 2a 67
6a :2 2a :2 13 5e :3 10 :2 1b 2f :2 38
48 56 :2 10 3e :2 d 3b :2 a 41
:2 7 1f :2 4 7 10 1c :2 7 1f
21 :2 1f 27 30 38 :2 27 3b 3e
:2 3b :3 7 11 7 42 :2 4 7 10
1b :2 7 20 1e :2 29 :2 1e :4 b :2 a
18 :2 a 19 a 22 a 18 :2 a
19 a :5 7 13 7 3d a e
10 :2 e a 19 :2 a 18 29 35
42 4b 54 :2 42 58 61 69 :2 58
22 2b 37 :2 22 3b 44 4f :2 3b
53 20 2b :2 53 2f 38 46 :2 2f
4a 53 5e :2 4a 22 2b 37 :2 22
3b 43 4d :2 18 a d 16 22
:2 d 27 25 :2 30 :2 25 10 :2 1a 2c
:2 36 42 45 54 57 58 :2 54 :2 2c
:3 10 :2 16 1b 27 64 67 :2 27 74
77 :2 27 7b 7e :2 27 88 8b 94
9c :2 a5 :2 94 b6 :2 8b :2 27 :2 10 5b
:2 d 10 :2 1a 2c :2 36 42 45 54
57 58 :2 54 :2 2c :3 10 :2 16 1b 27
64 67 :2 27 :2 10 5b :3 d :2 18 2e
:2 37 47 :2 d a 3f 10 19 25
:2 10 28 2b :2 28 10 :2 1a 2c :2 36
42 46 55 58 59 :2 55 :2 2c :3 10
:2 16 1b 27 64 67 :2 27 74 77
:2 27 7b 7e :2 27 88 8b 94 9c
:2 94 a9 :2 8b :2 27 b1 b4 :2 27 bc
bf :2 27 c4 c7 :2 27 d4 d7 :2 27
:2 10 5c :2 d 10 :2 1a 2c :2 36 42
45 54 57 58 :2 54 :2 2c :3 10 :2 16
1b 27 64 67 :2 27 :2 10 5b :3 d
:2 18 2c 35 41 :2 2c 45 53 :2 d
2d 3f :2 a 12 a 19 a :4 7
b 14 1c :2 b 1f 21 :2 1f a
29 32 3a :2 29 3d 40 :2 3d 28
:2 a e 17 1f :2 e 22 24 :2 22
d 2b 34 3c :2 2b 3f 41 :2 3f
2a :3 d 18 d a 44 10 19
21 :2 10 24 26 :2 24 d 18 d
a 28 44 11 1a 22 :2 11 25
27 :2 25 10 2e 37 3f :2 2e 42
44 :2 42 2d :2 10 d 18 d a
47 44 10 19 21 :2 10 24 26
:2 24 d 18 d 28 44 :2 a 45
:2 7 :4 4 7 10 1c :2 7 21 1f
:2 2a :2 1f 7 19 :2 7 16 :2 7 17
:2 7 14 1b 28 2b :2 14 :2 7 17
7 a 13 20 :2 a 23 25 :2 23
a :3 16 :2 a 1c a 27 14 24
12 13 20 :2 d :2 16 22 d a
:2 12 10 :2 19 25 10 13 :2 1d 2f
:2 39 45 49 58 5b 5c :2 58 :2 2f
:3 13 :2 19 1e 2a 67 6a :2 2a 77
7a :2 2a 7e 81 :2 2a 8d 90 :2 2a
98 9b :2 2a a7 aa b1 ba bd
:2 aa :2 2a :2 13 5f :2 10 :2 d :4 19 :2 d
a :3 7 e :2 17 22 20 :2 2b :2 20
d 10 19 21 :2 10 24 26 :2 24
:2 13 18 19 26 17 25 :2 17 25
2e fffa 13 :2 1c 28 13 10 :2 18
16 :2 1f 2b 16 19 :2 23 35 :2 3f
4b 4f 5e 61 62 :2 5e :2 35 :3 19
:2 1f 24 30 6e 71 :2 30 7e 81
:2 30 85 88 :2 30 94 97 :2 30 9f
a2 :2 30 ae b1 b8 c1 c4 :2 b1
:2 30 :2 19 65 :2 16 :2 13 :4 1f :2 13 10
:3 28 14 :2 1d 28 26 :2 31 :2 26 :2 13
25 13 41 :2 10 28 :2 d 3b d
1f d :4 a :4 7 a 19 1c :2 19
d 16 1a d 12 13 1e 11
19 fffa d :2 16 22 d a :2 12
10 :2 19 25 10 13 :2 1d 2f :2 39
45 49 58 5b 5c :2 58 :2 2f :3 13
:2 19 1e 2a 68 6b :2 2a 78 7b
:2 2a 7f 82 :2 2a 8e 91 :2 2a 99
9c :2 2a a8 ab b2 bb be :2 ab
:2 2a :2 13 5f :2 10 :2 d :4 19 :2 d a
:3 1e d 18 25 30 3d 48 55
60 6d 78 85 8b 8f 16 1c
1f 35 3b 43 :2 12 23 27 38
13 16 23 11 15 22 25 fffa
d :2 16 22 d a :2 12 10 :2 19
25 10 13 :2 1d 2f :2 39 45 49
58 5b 5c :2 58 :2 2f :3 13 :2 19 1e
2a 68 6b :2 2a 78 7b :2 2a 7f
82 :2 2a 8e 91 :2 2a 99 9c :2 2a
a8 ab b2 bb be :2 ab :2 2a :2 13
5f :2 10 :2 d :4 19 :2 d a :3 1e e
:2 17 22 20 :2 2b :2 20 d 10 :2 1a
2c :2 36 42 46 55 58 59 :2 55
:2 2c :3 10 :2 16 1b 27 65 68 :2 27
75 78 :2 27 7c 7f :2 27 89 8c
95 9d :2 a6 :2 95 b9 :2 8c :2 27 c1
c4 :2 27 cc cf :2 27 d4 d7 :2 27
e1 e4 :2 27 :2 10 5c :2 d 10 :2 1a
2c :2 36 42 45 54 57 58 :2 54
:2 2c :3 10 :2 16 1b 27 65 68 :2 27
:2 10 5b :3 d :2 18 2c :2 35 47 52
:2 d 3b :3 a 1e 27 2f :2 1e 32
34 :2 32 3b :2 19 44 :2 14 a 19
d :8 f d :8 f d 14 10 1c
:3 1a 10 :2 19 25 10 21 10 :2 19
25 10 :4 d a :2 12 10 :2 19 25
10 13 :2 1d 2f :2 39 45 49 58
5b 5c :2 58 :2 2f :3 13 :2 19 1e 2a
68 6b :2 2a 78 7b :2 2a 7f 82
:2 2a 8e 91 :2 2a 99 9c :2 2a a8
ab b2 bb be :2 ab :2 2a :2 13 5f
:2 10 :2 d :4 19 :2 d a :3 1e 7 1e
d 14 22 25 :2 d 28 2a :2 28
14 21 d 17 d 17 d 17
13 20 d 14 10 1c :3 1a 10
:2 19 25 10 21 10 :2 19 25 10
:4 d a :2 12 10 :2 19 25 10 13
:2 1d 2f :2 39 45 49 58 5b 5c
:2 58 :2 2f :3 13 :2 19 1e 2a 68 6b
:2 2a 78 7b :2 2a 7f 82 :2 2a 8e
91 :2 2a 99 9c :2 2a a8 ab b2
bb be :2 ab :2 2a :2 13 5f :2 10 :2 d
:4 19 :2 d a :4 2e 1e :2 7 16 10
11 f 10 1d :2 e 1c a 11
d 19 :3 17 d :2 16 22 d 1e
d :2 16 22 d :4 a 7 :2 f d
:2 16 22 d 10 :2 1a 2c :2 36 42
46 55 59 5a :2 55 :2 2c :3 10 :2 16
1b 27 66 69 :2 27 76 79 :2 27
7d 80 :2 27 8c 8f :2 27 97 9a
:2 27 a6 a9 b0 b9 bc :2 a9 :2 27
:2 10 5d :2 d :2 a :4 16 :2 a 7 :3 3a
16 10 11 f 10 1d :2 e 1c
a 11 d 19 :3 17 d :2 16 22
d 1e d :2 16 22 d :4 a 7
:2 f d :2 16 22 d 10 :2 1a 2c
:2 36 42 46 55 59 5a :2 55 :2 2c
:3 10 :2 16 1b 27 66 69 :2 27 76
79 :2 27 7d 80 :2 27 8c 8f :2 27
97 9a :2 27 a6 a9 b0 b9 bc
:2 a9 :2 27 :2 10 5d :2 d :2 a :4 16 :2 a
7 :3 3a 16 10 1d :2 e 1c a
11 d 19 :3 17 d :2 16 22 d
1e d :2 16 22 d :4 a 7 :2 f
d :2 16 22 d 10 :2 1a 2c :2 36
42 46 55 59 5a :2 55 :2 2c :3 10
:2 16 1b 27 66 69 :2 27 76 79
:2 27 7d 80 :2 27 8c 8f :2 27 97
9a :2 27 a6 a9 b0 b9 bc :2 a9
:2 27 :2 10 5d :2 d :2 a :4 16 :2 a 7
:4 3a :3 4 :3 17 4 7 10 18 :2 7
1b 1d :2 1b 23 2c 38 :2 23 3e
3b :2 47 :2 3b :2 7 5b d 19 :2 5b
1f 1c :2 28 :2 1c :2 7 :4 b :2 a 17
a 20 :2 7 3d :2 4 7 10 1c
:2 7 1f 21 :2 1f 7 15 :2 1e 7
23 :2 4 :4 8 7 :4 20 1f :2 7 :4 39
38 :2 7 :4 10 f e :3 7 14 7
25 :3 4 c :2 4 f 4 7 10
18 :2 7 1b 1d :2 1b a 13 1f
:2 a 24 22 :2 2d :2 22 a 12 1e
21 :2 12 2a 2d :2 12 11 14 :2 12
11 14 :2 12 11 14 :2 12 32 35
:2 12 3f 42 :2 12 a 7 3d d
16 22 :2 d 25 27 :2 25 a 12
11 14 :2 12 11 14 :2 12 43 46
:2 12 53 56 :2 12 11 14 :2 12 2c
2f :2 12 38 3b :2 12 11 14 :2 12
a 2a 3d a 12 11 14 :2 12
11 14 :2 12 11 14 :2 12 35 38
:2 12 41 44 :2 12 a :4 7 1f a
13 1f :2 a 25 22 :2 2e :2 22 42
d 19 :2 42 1f 1c :2 28 :2 1c :2 a
41 d 19 :2 41 1f 1c :2 28 :2 1c
:3 a 12 1c :3 a :2 13 1f a :4 e
:2 d 15 1f :3 d :2 16 22 d 1c
17 23 15 16 17 19 25 27
15 1f 10 15 2a 10 12 1f
22 14 17 14 17 25 10 17
13 1f :3 1d 13 :2 1c 28 13 24
13 :2 1c 28 13 :4 10 d :2 15 13
:2 1c 28 13 16 :2 20 32 :2 3c 48
4c 5b 5f 60 :2 5b :2 32 :3 16 :2 1c
21 2d 6c 6f :2 2d 7c 7f :2 2d
83 86 :2 2d 92 95 :2 2d 9d a0
:2 2d ac af b6 bf c2 :2 af :2 2d
:2 16 63 :2 13 :2 10 :4 1c :2 10 d :3 22
1c 17 19 15 27 17 19 15
27 16 18 1f 21 14 1b 1d
26 2d 2f 38 3a 10 17 13
1f :3 1d 13 :2 1c 28 13 24 13
:2 1c 28 13 :4 10 d :2 15 13 :2 1c
28 13 16 :2 20 32 :2 3c 48 4c
5b 5f 60 :2 5b :2 32 :3 16 :2 1c 21
2d 6c 6f :2 2d 7c 7f :2 2d 83
86 :2 2d 92 95 :2 2d 9d a0 :2 2d
ac af b6 bf c2 :2 af :2 2d :2 16
63 :2 13 :2 10 :4 1c :2 10 d :4 22 d
19 d :4 a 3c :2 7 :4 b :2 a 12
1b 22 :2 1b 2a :2 12 2d 2f :2 2d
3a 41 4a 51 :2 4a 59 :2 41 5d
:2 3a 64 66 :2 3a :2 16 71 78 81
88 :2 81 90 :2 78 94 :2 71 :2 11 :2 a
f :2 a 10 14 12 18 :2 12 a
10 19 1f 26 2f 31 33 :2 2f
36 :2 1f :2 19 3b :2 10 3e 41 :2 3e
17 20 26 2d 36 38 3a :2 36
3d :2 26 :2 20 42 :2 17 45 48 :2 45
:4 10 4b :3 d 12 14 16 :2 12 d
18 e a d 11 :3 f 10 :2 1a
2c :2 36 42 45 54 58 59 :2 54
:2 2c :3 10 :2 16 1b 27 66 69 :2 27
76 79 :2 27 7d 80 :2 27 8a 8d
96 9e :2 a7 :2 96 b8 :2 8d :2 27 :2 10
5c :2 d 10 :2 1a 2c :2 36 42 45
54 58 59 :2 54 :2 2c :3 10 :2 16 1b
27 66 69 :2 27 :2 10 5c :3 d :2 18
2e :2 37 47 :2 d 15 :2 a 14 1c
:2 12 :2 d :2 16 22 d a :2 12 10
:2 19 25 10 13 :2 1d 2f :2 39 45
49 58 5c 5d :2 58 :2 2f :3 13 :2 19
1e 2a 69 6c :2 2a 79 7c :2 2a
80 83 :2 2a 8f 92 :2 2a 9a 9d
:2 2a a9 ac b3 bc bf :2 ac :2 2a
:2 13 60 :2 10 :2 d :4 19 :2 d a :4 1e
:2 7 a 13 1f :2 a 24 22 :2 2d
:2 22 a 10 :2 a 15 :2 a 15 1d
20 :2 15 :2 a 15 1d 20 :2 15 a
7 3d d 16 22 :2 d 27 25
:2 30 :2 25 a 10 :2 a 12 17 1a
:2 12 :2 a 12 17 1a :2 12 :2 a 15
a 45 3d d 16 22 :2 d 27
25 :2 30 :2 25 d 15 :2 d 18 d
:4 11 :2 10 1b 23 26 :2 1b :2 10 1b
23 26 :2 1b :2 10 1b 23 26 :2 1b
10 26 :3 d 18 20 23 :2 18 d
:4 11 :2 10 1b 23 26 :2 1b :2 10 1b
23 26 :2 1b :2 10 1b 23 26 :2 1b
10 24 :2 d 44 :4 11 :2 10 18 1d
20 :2 18 :2 10 1b 10 29 10 18
1d 20 :2 18 17 1a :2 18 :2 10 1b
10 :4 14 :2 13 1e 26 29 :2 1e :2 13
1e 26 29 :2 1e :2 13 1e 26 29
:2 1e 13 29 :3 10 1b 23 26 :2 1b
17 1a :2 1b 17 1a :2 1b 17 1a
:2 1b 17 1a :2 1b 17 1a :2 1b 10
:4 d :4 11 :2 10 1b 23 26 :2 1b 4f
52 :2 1b 5a 5d :2 1b 10 24 :2 d
:4 a :4 7 a 13 1f :2 a 25 22
:2 2e :2 22 :4 e d 17 21 15 16
23 :2 10 :2 19 25 10 d :2 15 13
:2 1c 28 13 16 :2 20 32 :2 3c 48
4c 5b 5f 60 :2 5b :2 32 :3 16 :2 1c
21 2d 6c 6f :2 2d 7c 7f :2 2d
83 86 :2 2d 92 95 :2 2d 9d a0
:2 2d ac af b6 bf c2 :2 af :2 2d
:2 16 63 :2 13 :2 10 :4 1c :2 10 d :3 26
11 :2 1a 25 23 :2 2e :2 23 :2 10 18
21 28 :2 21 31 :2 18 :2 10 18 1d
20 :2 18 :2 10 1b 23 26 :2 1b 17
1a :2 1b 2f 32 :2 1b 39 3c :2 1b
10 3e 13 :2 1d 2f :2 39 45 49
58 5c 5d :2 58 :2 2f :3 13 :2 19 1e
2a 69 6c :2 2a 79 7c :2 2a 80
83 :2 2a 8d 90 99 a1 :2 aa :2 99
bb :2 90 :2 2a c3 c6 :2 2a ce d1
:2 2a d6 d9 :2 2a e4 e7 :2 2a :2 13
60 :2 10 13 :2 1d 2f :2 39 45 48
57 5b 5c :2 57 :2 2f :3 13 :2 19 1e
2a 69 6c :2 2a :2 13 5f :3 10 :2 1b
2f :2 38 48 54 :2 10 :4 d 26 :2 a
:4 e d 17 21 15 16 23 :2 10
:2 19 25 10 d :2 15 13 :2 1c 28
13 16 :2 20 32 :2 3c 48 4c 5b
5f 60 :2 5b :2 32 :3 16 :2 1c 21 2d
6c 6f :2 2d 7c 7f :2 2d 83 86
:2 2d 92 95 :2 2d 9d a0 :2 2d ac
af b6 bf c2 :2 af :2 2d :2 16 63
:2 13 :2 10 :4 1c :2 10 d :3 25 11 :2 1a
25 23 :2 2e :2 23 :2 10 18 1d 20
:2 18 :2 10 1b 23 26 :2 1b 17 1a
:2 1b 2f 32 :2 1b 39 3c :2 1b 10
3e 13 :2 1d 2f :2 39 45 49 58
5c 5d :2 58 :2 2f :3 13 :2 19 1e 2a
69 6c :2 2a 79 7c :2 2a 80 83
:2 2a 8d 90 99 a1 :2 aa :2 99 bb
:2 90 :2 2a c3 c6 :2 2a ce d1 :2 2a
d6 d9 :2 2a e3 e6 :2 2a :2 13 60
:2 10 13 :2 1d 2f :2 39 45 48 57
5b 5c :2 57 :2 2f :3 13 :2 19 1e 2a
69 6c :2 2a :2 13 5f :3 10 :2 1b 2f
:2 38 48 53 :2 10 :4 d 25 :2 a :4 e
d 17 21 15 16 23 :2 10 :2 19
25 10 d :2 15 13 :2 1c 28 13
16 :2 20 32 :2 3c 48 4c 5b 5f
60 :2 5b :2 32 :3 16 :2 1c 21 2d 6c
6f :2 2d 7c 7f :2 2d 83 86 :2 2d
92 95 :2 2d 9d a0 :2 2d ac af
b6 bf c2 :2 af :2 2d :2 16 63 :2 13
:2 10 :4 1c :2 10 d :3 25 11 :2 1a 25
23 :2 2e :2 23 :2 10 18 1d 20 :2 18
:2 10 1b 23 26 :2 1b 17 1a :2 1b
2f 32 :2 1b 39 3c :2 1b 10 3e
13 :2 1d 2f :2 39 45 49 58 5c
5d :2 58 :2 2f :3 13 :2 19 1e 2a 69
6c :2 2a 79 7c :2 2a 80 83 :2 2a
8d 90 99 a1 :2 aa :2 99 bb :2 90
:2 2a c3 c6 :2 2a ce d1 :2 2a d6
d9 :2 2a e3 e6 :2 2a :2 13 60 :2 10
13 :2 1d 2f :2 39 45 48 57 5b
5c :2 57 :2 2f :3 13 :2 19 1e 2a 69
6c :2 2a :2 13 5f :3 10 :2 1b 2f :2 38
48 53 :2 10 :4 d 25 :2 a d 16
27 :2 d 2a 2c :2 2a 32 3b 4c
:2 32 4f 52 :2 4f :3 d 18 20 23
:2 18 3b 3e 46 4f 61 :2 46 :2 3e
:2 18 65 68 :2 18 d 56 :2 a 3e
:2 7 :4 b :2 a 15 1e 25 :2 1e 33
:2 15 :2 a f :2 a 10 14 12 1c
:2 12 a d 1a :2 23 2c 30 34
35 36 :2 34 39 :2 1a d 17 21
15 16 23 :2 10 :2 19 25 10 d
:2 15 13 :2 1c 28 13 16 :2 20 32
:2 3c 48 4c 5b 5f 60 :2 5b :2 32
:3 16 :2 1c 21 2d 6c 6f :2 2d 7c
7f :2 2d 83 86 :2 2d 92 95 :2 2d
9d a0 :2 2d ac af b6 bf c2
:2 af :2 2d :2 16 63 :2 13 :2 10 :4 1c :2 10
d :3 1c 11 :2 1a 26 23 :2 2f :2 23
10 13 :2 1d 2f :2 39 45 49 58
5c 5d :2 58 :2 2f :3 13 :2 19 1e 2a
69 6c :2 2a 79 7c :2 2a 80 83
:2 2a 8d 90 99 a1 :2 aa :2 99 bb
:2 90 :2 2a c3 c6 :2 2a ce d1 :2 2a
d6 d9 :2 2a e3 e6 :2 2a :2 13 60
:2 10 13 :2 1d 2f :2 39 45 48 57
5b 5c :2 57 :2 2f :3 13 :2 19 1e 2a
69 6c :2 2a :2 13 5f :3 10 :2 1b 2f
:2 38 48 53 :2 10 3f :3 d 18 20
23 :2 18 14 17 :2 18 14 17 :2 18
14 17 :2 18 31 34 :2 18 3b 3e
:2 18 d 10 19 25 :2 10 2a 28
:2 33 :2 28 10 1b 23 26 :2 1b 10
43 10 1b 23 26 :2 1b 10 :4 d
10 19 25 :2 10 2a 28 :2 33 :2 28
:2 10 43 :2 d a f 11 13 :2 f
a 1c e a 22 :2 7 a 13
1f :2 a 25 22 :2 2e :2 22 a 15
1e 25 :2 1e 34 :2 15 :2 a f :2 a
10 14 12 1c :2 12 a d 1a
:2 23 2c 30 34 35 36 :2 34 39
:2 1a d 17 21 15 16 23 :2 10
:2 19 25 10 d :2 15 13 :2 1c 28
13 16 :2 20 32 :2 3c 48 4c 5b
5f 60 :2 5b :2 32 :3 16 :2 1c 21 2d
6c 6f :2 2d 7c 7f :2 2d 83 86
:2 2d 92 95 :2 2d 9d a0 :2 2d ac
af b6 bf c2 :2 af :2 2d :2 16 63
:2 13 :2 10 :4 1c :2 10 d :3 1c 11 :2 1a
26 23 :2 2f :2 23 10 13 :2 1d 2f
:2 39 45 49 58 5c 5d :2 58 :2 2f
:3 13 :2 19 1e 2a 69 6c :2 2a 79
7c :2 2a 80 83 :2 2a 8d 90 99
a1 :2 aa :2 99 bb :2 90 :2 2a c3 c6
:2 2a ce d1 :2 2a d6 d9 :2 2a e3
e6 :2 2a :2 13 60 :2 10 13 :2 1d 2f
:2 39 45 48 57 5b 5c :2 57 :2 2f
:3 13 :2 19 1e 2a 69 6c :2 2a :2 13
5f :3 10 :2 1b 2f :2 38 48 53 :2 10
3f :3 d 18 20 23 :2 18 14 17
:2 18 14 17 :2 18 14 17 :2 18 31
34 :2 18 3b 3e :2 18 14 17 :2 18
d a f 11 13 :2 f a 1c
e a 3e :3 7 f 14 17 :2 f
7 :5 4 c 11 14 :2 c :2 4 9
:2 11 :2 4 d 16 :2 7 a e :2 a
:2 13 1f a 14 a :2 13 1f a
:4 7 b :2 14 20 1d :2 29 :2 1d :3 a
39 :2 7 a 13 1b :2 a 1e 20
:2 1e 26 2f 3b :2 26 41 3e :2 4a
:2 3e :2 a 62 d 19 :2 62 1f 1c
:2 28 :2 1c :2 a 42 d 19 :2 42 1f
1c :2 28 :2 1c :4 3c 3b :2 42 41 :3 a
f :3 a 10 19 :2 a d 11 :2 d
:2 16 22 d 17 d :2 16 22 d
:4 a e :2 17 22 20 :2 2b :2 20 d
10 16 :3 10 :2 19 25 10 d :2 15
13 :2 1c 28 13 16 :2 20 32 :2 3c
48 4c 5b 5f 60 :2 5b :2 32 :3 16
:2 1c 21 2d 6c 6f :2 2d 7c 7f
:2 2d 83 86 :2 2d 92 95 :2 2d 9d
a0 :2 2d ac af b6 bf c2 :2 af
:2 2d :2 16 63 :2 13 :2 10 :4 1c :2 10 d
:3 3b 12 d 3b 10 16 :3 10 :2 19
25 10 d :2 15 13 :2 1c 28 13
16 :2 20 32 :2 3c 48 4c 5b 5f
60 :2 5b :2 32 :3 16 :2 1c 21 2d 6c
6f :2 2d 7c 7f :2 2d 83 86 :2 2d
92 95 :2 2d 9d a0 :2 2d ac af
b6 bf c2 :2 af :2 2d :2 16 63 :2 13
:2 10 :4 1c :2 10 d :7 a 51 :3 7 16
:2 7 17 7 a 13 1b :2 a 1e
20 :2 1e d 14 20 23 :2 d 26
28 :2 26 d :3 1c :2 d 19 d 2c
10 1e 27 2f :2 1e :2 10 33 36
:2 33 1a 20 38 18 19 26 17
25 17 :2 13 :2 1c 28 13 10 :2 18
16 :2 1f 2b 16 19 :2 23 35 :2 3f
4b 4f 5e 62 63 :2 5e :2 35 :3 19
:2 1f 24 30 6f 72 :2 30 7f 82
:2 30 86 89 :2 30 95 98 :2 30 a0
a3 :2 30 af b2 b9 c2 c5 :2 b2
:2 30 :2 19 66 :2 16 :2 13 :4 1f :2 13 10
:3 38 13 1c 28 :2 13 2b 2d :2 2b
16 1c :3 16 :2 1f 2b 16 13 :2 1b
19 :2 22 2e 19 1c :2 26 38 :2 42
4e 52 61 65 66 :2 61 :2 38 :3 1c
:2 22 27 33 72 75 :2 33 82 85
:2 33 89 8c :2 33 98 9b :2 33 a3
a6 :2 33 b2 b5 bc c5 c8 :2 b5
:2 33 :2 1c 69 :2 19 :2 16 :4 22 :2 16 13
:3 2f 16 :2 20 32 :2 3c 48 4c 5b
5f 60 :2 5b :2 32 :3 16 :2 1c 21 2d
6c 6f :2 2d 7c 7f :2 2d 83 86
:2 2d 90 93 9c a4 :2 ad :2 9c ce
:2 93 :2 2d d6 d9 :2 2d e1 e4 :2 2d
e9 ec :2 2d f5 f8 :2 2d :2 16 63
:2 13 16 :2 20 32 :2 3c 48 4b 5a
5e 5f :2 5a :2 32 :3 16 :2 1c 21 2d
6c 6f :2 2d :2 16 62 :3 13 :2 1e 32
:2 3b 5b 1b :2 13 2f :2 10 38 :2 d
:5 a 16 22 2f 3d 48 52 5e
1b 28 36 43 51 1b 28 34
3e 46 4f 57 1b 27 33 40
4b 56 1b 25 30 3c 48 51
5c :2 48 60 1b 21 :2 16 a d
16 19 :2 16 10 16 :3 10 :2 19 25
10 d :2 15 13 :2 1c 28 13 16
:2 20 32 :2 3c 48 4c 5b 5f 60
:2 5b :2 32 :3 16 :2 1c 21 2d 6c 6f
:2 2d 7c 7f :2 2d 83 86 :2 2d 92
95 :2 2d 9d a0 :2 2d ac af b6
bf c2 :2 af :2 2d :2 16 63 :2 13 :2 10
:4 1c :2 10 d :3 1b 10 1b 19 :2 24
:2 19 10 1c :2 25 10 2e :2 d 10
:2 1a 2c :2 36 42 46 55 59 5a
:2 55 :2 2c :3 10 :2 16 1b 27 66 69
:2 27 76 79 :2 27 7d 80 :2 27 8a
8d 96 9e :2 96 a9 :2 8d :2 27 b1
b4 :2 27 bc bf :2 27 c4 c7 :2 27
d3 d6 :2 27 :2 10 5d :2 d 10 :2 1a
2c :2 36 42 45 54 58 59 :2 54
:2 2c :3 10 :2 16 1b 27 66 69 :2 27
:2 10 5c :3 d :2 18 2c 36 43 :2 d
a 1b 11 18 24 27 :2 11 2a
2c :2 2a 10 36 3d 4b 4e :2 36
51 53 :2 51 35 :2 10 17 24 39
46 53 10 17 13 1f :3 1d 13
:2 1c 28 13 24 13 :2 1c 28 13
:4 10 d :2 15 13 :2 1c 28 13 16
:2 20 32 :2 3c 48 4c 5b 5f 60
:2 5b :2 32 :3 16 :2 1c 21 2d 6c 6f
:2 2d 7c 7f :2 2d 83 86 :2 2d 92
95 :2 2d 9d a0 :2 2d ac af b6
bf c2 :2 af :2 2d :2 16 63 :2 13 :2 10
:4 1c :2 10 d :4 58 1b :4 a 22 d
16 21 :2 d 27 24 :2 30 :2 24 d
1b :2 d 1c d 44 :3 a 16 22
2f 3d 48 52 5e 1b 28 36
43 51 1b 28 34 3e 46 4f
57 1b 27 33 40 4b 56 1b
25 30 3c 48 4b 4e 54 :2 16
a d 16 18 :2 16 d 16 1c
1e :2 16 d 1a :2 a d 15 13
1e 2a :2 15 :2 13 :2 d 2d :2 a :4 7
9 7 :3 4 8 1 7 d :3 7
:2 10 1c 7 4 :2 c a :2 13 1f
a d :2 17 29 :2 33 3f 43 52
56 57 :2 52 :2 29 :3 d :2 13 18 24
63 66 :2 24 73 76 :2 24 7a 7d
:2 24 89 8c :2 24 94 97 :2 24 a3
a6 ad b6 b9 :2 a6 :2 24 :2 d 5a
:2 a :2 7 :4 13 :2 7 4 :3 1 8 13
11 :2 1c :2 11 7 37 40 43 :2 40
36 4b a 12 :2 4b 15 17 :2 15
4a :2 36 35 :2 7 a :2 14 26 :2 30
3c 40 4f 53 54 :2 4f :2 26 :3 a
:2 10 15 21 60 63 :2 21 70 73
:2 21 77 7a :2 21 84 87 90 98
:2 90 a3 :2 87 :2 21 ab ae :2 21 b6
b9 :2 21 be c1 :2 21 cd d0 :2 21
:2 a 57 :2 7 a :2 14 26 :2 30 3c
3f 4e 52 53 :2 4e :2 26 :3 a :2 10
15 21 60 63 :2 21 :2 a 56 :3 7
:2 12 26 30 3d :2 7 1b :2 4 7
11 14 :2 11 7 12 :2 7 15 :2 7
14 :2 7 c :4 7 c :2 7 10 a
:7 c :3 a d 12 :2 d :2 16 22 d
18 d :2 16 22 d :4 a e :2 17
23 20 :2 2c :2 20 :3 d 3c :2 a :4 e
d 29 :2 34 3b 46 :2 29 50 52
:2 50 :2 d 14 1d 24 :2 1d 2e :2 14
31 33 :2 31 :3 d 18 d 35 :2 a
d :2 18 1f 2b :2 d 35 38 :2 35
10 12 15 :2 12 1a 13 1d 15
21 15 20 15 22 15 21 15
22 19 21 13 1a 16 22 :3 20
16 :2 1f 2b 16 27 16 :2 1f 2b
16 :4 13 10 :2 18 16 :2 1f 2b 16
19 :2 23 35 :2 3f 4b 4f 5e 62
63 :2 5e :2 35 :3 19 :2 1f 24 30 6f
72 :2 30 7f 82 :2 30 86 89 :2 30
95 98 :2 30 a0 a3 :2 30 af b2
b9 c2 c5 :2 b2 :2 30 :2 19 66 :2 16
:2 13 :4 1f :2 13 10 :4 17 :3 d 1c :2 d
1d :2 d 1c :2 d 1d :2 d 1d :2 d
1d :2 d 1b :2 d 12 d 3a :2 a
d f 12 :2 f :4 19 18 :2 d 17
10 :5 12 16 1e 10 17 13 1f
:3 1d 13 :2 1c 28 13 24 13 :2 1c
28 13 :4 10 d :2 15 13 :2 1c 28
13 16 :2 20 32 :2 3c 48 4c 5b
5f 60 :2 5b :2 32 :3 16 :2 1c 21 2d
6c 6f :2 2d 7c 7f :2 2d 83 86
:2 2d 92 95 :2 2d 9d a0 :2 2d ac
af b6 bf c2 :2 af :2 2d :2 16 63
:2 13 :2 10 :4 1c :2 10 d :4 30 :2 a :4 e
d :4 11 :2 10 1f 26 32 35 :2 26
3a 3d :2 1f 10 2a :3 d 1c 23
2f 32 :2 23 3e 41 :2 1c d 26
:2 a :4 e :2 d 1d 24 31 34 :2 24
3f 42 :2 1d d 25 :2 a :4 e d
:4 11 :2 10 20 27 34 37 :2 27 3c
3f :2 20 10 2b :3 d 1d 24 31
34 :2 24 41 44 :2 1d d 27 :2 a
:4 e :2 d 1d 24 31 34 :2 24 40
43 :2 1d d 26 :2 a :4 e d :4 11
:2 10 1f 26 32 35 :2 26 3a 3d
:2 1f 10 2a :3 d 1c 23 2f 32
:2 23 3e 41 :2 1c d 26 :2 a :4 e
d :4 11 :2 10 20 27 34 37 :2 27
3c 3f :2 20 10 2b :3 d 1d 24
31 34 :2 24 41 44 :2 1d d 27
:3 a f 11 13 :2 f :2 a 17 a
7 b 16 a 10 :3 a :2 13 1f
a 7 :2 f d :2 16 22 d 10
:2 1a 2c :2 36 42 46 55 59 5a
:2 55 :2 2c :3 10 :2 16 1b 27 66 69
:2 27 76 79 :2 27 7d 80 :2 27 8c
8f :2 27 97 9a :2 27 a6 a9 b0
b9 bc :2 a9 :2 27 :2 10 5d :2 d :2 a
:4 16 :2 a 7 :3 16 a c f :2 c
14 d 17 f 1b f 1a f
1c f 1b f 1c 13 1b d
14 10 1c :3 1a 10 :2 19 25 10
21 10 :2 19 25 10 :4 d a :2 12
10 :2 19 25 10 13 :2 1d 2f :2 39
45 49 58 5c 5d :2 58 :2 2f :3 13
:2 19 1e 2a 69 6c :2 2a 79 7c
:2 2a 80 83 :2 2a 8f 92 :2 2a 9a
9d :2 2a a9 ac b3 bc bf :2 ac
:2 2a :2 13 60 :2 10 :2 d :4 19 :2 d a
:4 11 :2 7 16 :2 4 :4 8 7 a 13
1b :2 a 1e 20 :2 1e 14 1d 21
38 12 13 1e 11 22 2a 31
49 51 58 :2 d :2 16 22 d a
:2 12 10 :2 19 25 10 13 :2 1d 2f
:2 39 45 49 58 5c 5d :2 58 :2 2f
:3 13 :2 19 1e 2a 69 6c :2 2a 79
7c :2 2a 80 83 :2 2a 8f 92 :2 2a
9a 9d :2 2a a9 ac b3 bc bf
:2 ac :2 2a :2 13 60 :2 10 :2 d :4 19 :2 d
a :4 22 a 18 :2 a :4 7 24 :2 4
e 1b 26 30 33 4b 5a c
14 17 1c 2b 31 34 42 45
d 10 1d :2 7 :2 10 1c 7 4
:2 c a :2 13 1f a d :2 17 29
:2 33 3f 43 52 56 57 :2 52 :2 29
:3 d :2 13 18 24 63 66 :2 24 73
76 :2 24 7a 7d :2 24 89 8c :2 24
94 97 :2 24 a3 a6 ad b6 b9
:2 a6 :2 24 :2 d 5a :2 a :2 7 :4 13 :2 7
4 :3 1 7 10 1c :2 7 21 1f
:2 2a :2 1f 7 f 19 :3 7 :2 10 1c
7 16 11 :4 c f 10 18 f
1e a 11 d 19 :3 17 d :2 16
22 d 1e d :2 16 22 d :4 a
7 :2 f d :2 16 22 d 10 :2 1a
2c :2 36 42 46 55 59 5a :2 55
:2 2c :3 10 :2 16 1b 27 66 69 :2 27
76 79 :2 27 7d 80 :2 27 8c 8f
:2 27 97 9a :2 27 a6 a9 b0 b9
bc :2 a9 :2 27 :2 10 5d :2 d :2 a :4 16
:2 a 7 :3 3a b :2 14 1f 1d :2 28
:2 1d a 19 14 f 13 24 f
13 24 f 13 24 f 13 24
12 13 1c 16 d 14 10 1c
:3 1a 10 :2 19 25 10 21 10 :2 19
25 10 :4 d a :2 12 10 :2 19 25
10 13 :2 1d 2f :2 39 45 49 58
5c 5d :2 58 :2 2f :3 13 :2 19 1e 2a
69 6c :2 2a 79 7c :2 2a 80 83
:2 2a 8f 92 :2 2a 9a 9d :2 2a a9
ac b3 bc bf :2 ac :2 2a :2 13 60
:2 10 :2 d :4 19 :2 d a :3 38 e :2 17
22 20 :2 2b :2 20 d 1c 17 15
16 1e 19 10 17 13 1f :3 1d
13 :2 1c 28 13 24 13 :2 1c 28
13 :4 10 d :2 15 13 :2 1c 28 13
16 :2 20 32 :2 3c 48 4c 5b 5f
60 :2 5b :2 32 :3 16 :2 1c 21 2d 6c
6f :2 2d 7c 7f :2 2d 83 86 :2 2d
92 95 :2 2d 9d a0 :2 2d ac af
b6 bf c2 :2 af :2 2d :2 16 63 :2 13
:2 10 :4 1c :2 10 d :4 3b :2 a 38 :3 7
c 1e 2a 3c 45 47 57 65
68 73 76 82 85 90 93 9f
b2 7 a 1a 27 2a 3a 7
17 1a 2e 31 43 46 5b 60
6f 83 85 94 ad 7 17 1a
2e 31 43 46 5b 60 6f 83
85 94 ad 7 17 1a 2e 31
43 46 5b 60 6f 83 85 94
ad 7 17 1a 2e 31 43 46
5b 60 6f 83 85 94 ad 7
a 15 18 24 27 32 35 3d
40 51 54 66 69 77 87 94
9f ac af bc bf c9 cc d6
d 1c 2e 39 3c 4c 5d 73
7e 8b 9b 9e a9 b8 c7 d0
e0 ef 15 24 4b c 1e 23
28 37 3d 40 49 4e 7 c
12 17 2b 31 34 3f 50 53
5f 62 7 c 15 1a 1c 29
7 c 1d 22 24 2c 2e 7
c 12 17 1d 22 24 2c 2e
7 c 12 17 29 2f 31 3a
3d 7 c 12 17 27 2d 2f
38 3b 7 c 12 17 21 27
2a 37 39 12 15 2b 2e 45
48 5e 61 17 7 17 a :2 14
26 :2 30 3c 3f 4e 52 53 :2 4e
:2 26 :3 a :2 10 15 21 60 63 :2 21
:2 a 56 :3 7 e 7 3a a 14
16 :2 14 a f 21 24 2e 40
49 4b 58 66 69 74 77 83
86 91 94 a0 a2 a d 1d
2a 2d 3d a 1a 1d 33 36
50 52 60 73 75 83 aa b5
bf d7 ec f9 112 11d 127 13f
154 161 163 179 17c 192 195 1a7
1aa 1b9 1d2 a 1a 1d 33 36
50 52 60 73 75 83 aa b5
bf d7 ec f9 112 11d 127 13f
154 161 163 179 17c 192 195 1a7
1aa 1b9 1d2 a 1a 1d 33 36
50 52 60 73 75 83 aa b5
bf d7 ec f9 112 11d 127 13f
154 161 163 179 17c 192 195 1a7
1aa 1b9 1d2 a 1a 1d 33 36
50 52 60 73 75 83 aa b5
bf d7 ec f9 112 11d 127 13f
154 161 163 179 17c 192 195 1a7
1aa 1b9 1d2 a d 19 1c 28
2b 36 39 41 44 55 58 6a
6d 7b 8b 98 a3 b0 b3 c0
c3 cd d0 da a d 1a 24
26 32 35 45 50 53 5e 61
77 82 8f 9f a2 ad bc bf
c8 cb d5 de e1 f0 f3 104
a c 1b 1d 2d f 1e 21
26 30 35 38 3f 41 a f
19 1f 22 2d 2f a f 15
1a 24 2a 2d 38 3b a f
19 1e 21 28 2a 36 3b 41
46 50 56 59 65 67 a f
15 1a 2e 34 37 42 53 56
62 65 a f 15 1a 2c 32
34 40 43 a f 15 1a 2c
32 35 3f 42 a f 15 1a
2a 30 32 3e 41 a f 15
1a 2a 30 33 3d 40 13 1a
a 1a d :2 17 29 :2 33 3f 42
51 55 56 :2 51 :2 29 :3 d :2 13 18
24 63 66 :2 24 :2 d 59 :3 a 11
a 18 a 12 1c :3 a :2 13 1f
a 19 14 1c 2a 38 46 12
27 d 14 10 1c :3 1a 10 :2 19
25 10 21 10 :2 19 25 10 :4 d
a :2 12 10 :2 19 25 10 13 :2 1d
2f :2 39 45 49 58 5c 5d :2 58
:2 2f :3 13 :2 19 1e 2a 69 6c :2 2a
79 7c :2 2a 80 83 :2 2a 8f 92
:2 2a 9a 9d :2 2a a9 ac b3 bc
bf :2 ac :2 2a :2 13 60 :2 10 :2 d :4 19
:2 d a :3 7 19 15 39 3d 4e
d 11 22 31 35 46 d 11
22 12 13 29 12 27 16 d
14 10 1c :3 1a 10 :2 19 25 10
21 10 :2 19 25 10 :4 d a :2 12
10 :2 19 25 10 13 :2 1d 2f :2 39
45 49 58 5c 5d :2 58 :2 2f :3 13
:2 19 1e 2a 69 6c :2 2a 79 7c
:2 2a 80 83 :2 2a 8f 92 :2 2a 9a
9d :2 2a a9 ac b3 bc bf :2 ac
:2 2a :2 13 60 :2 10 :2 d :4 19 :2 d a
:3 7 a f 21 24 2e 40 49
4b 58 66 69 74 77 83 86
91 94 a0 a2 a d 1d 2a
2d 3d a 1a 1d 31 34 f
11 25 27 41 43 51 64 66
74 9b a6 b0 c8 dd ea 103
10e 118 130 145 152 154 f 13
27 2b 45 47 55 68 6a 78
9f aa b4 cc e1 ee 107 112
11c 134 149 156 158 f 13 22
14 a 1a 1d 32 35 f 11
27 29 43 45 53 66 68 76
9d a8 b2 ca df ec 105 110
11a 132 147 154 156 f 13 27
2b 45 47 55 68 6a 78 9f
aa b4 cc e1 ee 107 112 11c
134 149 156 158 f 13 22 14
a 1a 1d 31 34 f 11 25
27 41 43 51 64 66 74 9b
a6 b0 c8 dd ea 103 10e 118
130 145 152 154 f 13 27 2b
45 47 55 68 6a 78 9f aa
b4 cc e1 ee 107 112 11c 134
149 156 158 f 13 22 14 a
1a 1d 31 34 f 11 25 27
41 43 51 64 66 74 9b a6
b0 c8 dd ea 103 10e 118 130
145 152 154 f 13 27 2b 45
47 55 68 6a 78 9f aa b4
cc e1 ee 107 112 11c 134 149
156 158 f 13 22 14 a d
18 1b 27 2a 35 38 40 43
54 57 69 6c 7a 8a 97 a2
af b2 bf c2 cc cf d9 a
d 1a 24 26 32 35 45 50
53 5e 61 77 82 8f 9f a2
ad a d 16 19 23 2c 2f
3e 41 52 a c 1b 1d 2d
f 1e a f 14 26 2d 30
37 3b 46 4a a f 14 26
2d 30 37 3b 46 4a a f
19 1e 21 28 2a a f 19
1f 22 2d 2f a f 15 1a
24 2a 2d 38 3b a f 19
1e 21 28 2a 36 3b 41 46
50 56 59 65 67 a f 15
1a 2e 34 37 42 53 56 62
65 a f 15 1a 24 2a 2c
37 3a a f 15 1a 2c 32
34 40 43 4e 53 59 5e 70
76 79 83 86 a f 15 1a
2a 30 32 3e 41 4c 51 57
5c 6c 72 75 7f 82 a f
15 1a 20 25 27 2f 31 15
18 2e 31 48 4b 61 64 13
1a a 1a d :2 17 29 :2 33 3f
42 51 55 56 :2 51 :2 29 :3 d :2 13
18 24 63 66 :2 24 :2 d 59 :3 a
11 a :4 7 :4 4 1 9 12 9
a :2 14 26 :2 30 3c 40 4f 53
54 :2 4f :2 26 :3 a :2 10 15 21 60
63 :2 21 :3 a :2 10 15 39 5c 5f
:2 68 :2 39 76 79 :2 39 81 84 :2 8d
:2 39 :2 a 57 :3 7 c 15 1e 2c
a 13 1e f e 7 e 7
e 7 29 :2 4 :2 9 7 :2 10 1c
:2 7 :2 11 23 :2 2d 39 3d 4c 50
51 :2 4c :2 23 :3 7 :2 d 12 1e 5d
60 :2 1e :3 7 :2 d 12 36 42 45
:2 36 4d 50 :2 36 5c 5f 66 6f
72 :2 5f :2 36 :2 7 54 :2 4 7 c
1b a 13 1e f e 7 e
7 e 7 :2 4 :4 10 :2 4 :8 1 
34ca
4
0 :2 1 :4 3 :4 4
:4 5 :4 6 :4 7 :4 8
:4 9 :4 a :4 b :4 c
:4 d :4 e :4 f :4 10
:4 11 :4 12 :4 13 :4 14
:4 15 :4 16 :4 17 :4 18
:4 19 :4 1a :4 1b :4 1c
:4 1d 2 :4 1e :2 1
:7 20 :7 21 :7 22 :7 23
:7 24 :7 25 :7 26 :7 27
:7 28 :7 29 :7 2a :7 2b
:7 2c :7 2d :7 2e :7 2f
:7 30 :7 31 :7 32 :7 33
:7 34 :5 35 :7 36 :7 37
:7 38 :7 39 :7 3a :7 3b
:7 3c :7 3d :7 3e :7 3f
:7 40 :6 41 :6 42 :6 43
:6 44 :6 45 :6 46 :6 47
:6 48 :6 49 :6 4a :6 4b
:6 4c :6 4d :6 4e :6 4f
:6 50 :6 51 :6 52 :6 53
:6 54 :6 55 :6 56 :6 57
:6 58 :6 59 :6 5a :6 5b
:6 5c :6 5d :6 5e :6 5f
:6 60 :6 61 :7 62 :6 63
:6 64 :6 65 :7 66 :7 67
:7 68 :6 69 :6 6a :7 6b
:7 6c :7 6d :7 6e :7 6f
:7 70 :6 71 :6 72 :6 73
:6 74 :6 75 :6 76 :6 77
:6 78 :7 79 :6 7a :5 7b
:5 7c :5 7d :5 7e :5 7f
:5 80 :5 81 :7 84 :2 86
0 :2 86 87 88
:2 89 :2 8a :2 8b 87
:5 86 :2 8d 0 :2 8d
8f 90 :2 91 :2 92
:2 93 :2 94 :2 95 :2 96
97 98 8f :5 8d
:7 9b :7 9e :7 a1 :7 a3
:b a5 :11 a6 a7 :2 a6
:2 a7 :2 a6 :2 a7 :2 a6
:2 a8 :2 a6 :2 a8 :2 a6
:2 a8 :2 a6 :2 a8 :2 a6
:2 a9 :2 a6 :2 a9 :2 a6
:2 a9 :2 a6 :2 a9 :2 a6
:2 aa :2 a6 :9 aa :2 a6
:2 ab :2 a6 :9 ab :2 a6
:2 ac :2 a6 :9 ac :2 a6
:2 ad :2 a6 :9 ad :2 a6
:2 ae :2 a6 :9 ae :2 a6
:2 af :2 a6 :9 af :2 a6
:2 b0 :2 a6 :9 b0 :2 a6
:2 b1 :2 a6 :9 b1 :2 a6
:2 b2 :2 a6 :2 b2 :2 a6
:2 b2 :2 a6 :2 b2 :2 a6
:2 b3 :2 a6 :2 b3 :2 a6
:2 b3 :2 a6 :2 b3 :2 a6
:2 b4 :2 a6 :2 b4 :2 a6
:2 b4 :2 a6 :2 b4 :2 a6
:2 b5 :2 a6 :2 b5 :2 a6
:2 b5 :2 a6 :2 b5 :2 a6
:2 b6 :2 a6 :2 b6 :2 a6
:2 b6 :2 a6 :2 b6 :2 a6
:2 b7 :2 a6 :9 b7 :2 a6
:2 b8 :2 a6 :2 b8 :2 a6
:2 b8 :2 a6 :2 b8 :2 a6
:2 b9 :2 a6 :2 b9 :2 a6
:2 b9 :2 a6 :2 b9 :2 a6
:2 ba :2 a6 :2 ba :2 a6
:2 ba :2 a6 :2 ba :2 a6
:2 bb :2 a6 :2 bb :2 a6
:2 bb :2 a6 :2 bb :2 a6
:2 bc :2 a6 :9 bc :2 a6
:2 bd :2 a6 :9 bd :2 a6
:2 be :2 a6 :9 be :2 a6
:2 bf :2 a6 :9 bf :2 a6
:2 c0 :2 a6 :2 c0 :2 a6
:2 c0 :2 a6 :2 c0 :2 a6
:2 c1 :2 a6 :2 c1 :2 a6
:2 c1 :2 a6 :2 c1 :2 a6
:2 c1 :4 a6 :3 a5 :11 c4
:b c5 :3 c4 :3 cd :3 ce
:3 cf :3 d0 :3 d1 :3 d2
:3 d3 :3 d4 :3 d5 :3 d6
:3 d8 :3 da :3 dc :3 de
:3 df :3 e0 :3 e1 :3 e2
:3 e3 :3 e4 :3 e5 :3 e6
:3 e8 :3 e9 :14 ee :11 ef
:20 f0 :3 ef :11 f2 :b f3
:3 f2 :9 f5 :3 ee :1e f8
:c f9 :2 f8 :14 fa :11 fb
:20 fc :3 fb :11 fe :b ff
:3 fe :9 101 102 fa
:e 102 :11 103 :20 104 :3 103
:11 106 :b 107 :3 106 :9 109
102 :3 fa f9 :2 f8
:1f 119 :11 11a :20 11b :3 11a
:11 11d :b 11e :3 11d :9 120
:3 119 :6 124 :3 125 124
:3 127 126 :3 124 :14 12a
:6 12b :2 12a :6 12d 12e
12f 12d :5 130 12c
:2 132 :5 134 :11 135 :24 136
:3 135 :2 133 :6 132 131
:3 12b :16 13b :11 13c :20 13d
:3 13c :11 13f :b 140 :3 13f
:9 142 :3 13b :3 144 12b
:2 12a :e 147 :4 149 :5 14a
148 :2 14c :5 14e :11 14f
:24 150 :3 14f :2 14d :6 14c
14b :6 147 :3 156 :14 15a
:d 15c :14 15e :d 160 :13 162
:9 164 :3 165 :2 167 168
:2 169 167 :5 16a 166
:2 16c :5 16e :11 16f :24 170
:3 16f :2 16d :6 16c 16b
:3 164 :9 175 :2 177 178
:2 179 177 :5 17a 176
:2 17c :5 17e :11 17f :24 180
:3 17f :2 17d :6 17c 17b
:3 175 :b 185 :11 186 :30 187
:3 186 :11 189 :b 18a :3 189
:a 18c :3 185 :3 175 :a 190
:9 191 :a 192 :9 193 :11 194
:20 195 :3 194 :11 197 :b 198
:3 197 :9 19a :3 193 :5 19c
:3 191 :3 19e :9 1a0 :3 1a1
1a0 :11 1a4 :20 1a5 :3 1a4
:11 1a7 :b 1a8 :3 1a7 :9 1aa
1a2 :3 1a0 :7 1b2 1b3
:3 1b2 :9 1b5 :11 1b6 :2e 1b7
:3 1b6 :11 1b9 :b 1ba :3 1b9
:c 1bc :3 1b5 :b 1be :11 1bf
:30 1c0 :3 1bf :11 1c2 :b 1c3
:3 1c2 :a 1c5 :3 1be :b 1c8
:c 1c9 1cc :2 1cd :2 1ce
1cf 1d1 1d2 1d3
1d4 1d5 :2 1d6 1cc
:5 1d7 1ca :2 1d9 :5 1db
:11 1dc :24 1dd :3 1dc :2 1da
:6 1d9 1d8 :4 1c9 :2 1e4
:2 1e5 :2 1e6 :2 1e7 :3 1e8
:3 1e9 :2 1ea :4 1eb 1ed
1ee 1ef 1f0 1f1
1f2 1f3 1f4 :4 1f5
:3 1f6 :4 1f7 1e4 :5 1f8
1e2 :2 1fa :5 1fc :11 1fd
:24 1fe :3 1fd :2 1fb :6 1fa
1f9 :4 1e1 :3 1c9 :a 204
:11 205 :30 206 :3 205 :11 208
:b 209 :3 208 :a 20b :3 204
20d 1c8 :b 20d 210
211 212 214 215
216 217 :2 218 210
:5 219 20e :2 21b :5 21d
:11 21e :24 21f :3 21e :2 21c
:6 21b 21a :3 20d :a 224
:11 225 :30 226 :3 225 :11 228
:b 229 :3 228 :a 22b :3 224
:2 233 234 :2 235 :2 237
:2 238 239 23b 23c
23d 23e 23f :2 240
:2 241 232 :5 242 230
:2 244 :5 246 :11 247 :24 248
:3 247 :2 245 :6 244 243
:3 20d :a 24d :11 24e :30 24f
:3 24e :11 251 :b 252 :3 251
:a 254 :3 24d :5 257 :5 25b
:6 25c :3 257 20d 1c8
:11 260 :30 261 :3 260 :11 263
:b 264 :3 263 :a 266 25e
:3 1c8 :b 26a 26e :3 26f
270 :4 271 :4 272 274
275 276 277 278
279 :2 27a 26e :5 27b
26c :2 27d :5 27f :11 280
:24 281 :3 280 :2 27e :6 27d
27c :3 26a :a 286 :11 287
:30 288 :3 287 :11 28a :b 28b
:3 28a :a 28d 28e 286
:a 28e :14 28f :2 290 :2 28f
:8 290 :5 28f 290 :2 291
:2 290 :8 291 :2 28f :11 292
:30 293 :3 292 :11 295 :b 296
:3 295 :a 298 291 :2 28f
28e :3 286 :3 26a :3 164
:9 2a0 :13 2a6 :2 2a7 :2 2a6
:4 2a7 :2 2a6 :11 2a8 :30 2a9
:3 2a8 :11 2ab :b 2ac :3 2ab
:7 2ae 2af :2 2ae 2a7
:2 2a6 :b 2b3 2b6 :2 2b7
:2 2b8 2ba 2bb 2bc
2bd :2 2be 2b6 :5 2bf
2b4 :2 2c1 :5 2c3 :11 2c4
:24 2c5 :3 2c4 :2 2c2 :6 2c1
2c0 :3 2b3 :a 2cc 2d2
2d3 :3 2d4 2cf :5 2d5
2cd :2 2d7 :5 2d9 :11 2da
:24 2db :3 2da :2 2d8 :6 2d7
2d6 :3 2cc :a 2e0 :11 2e1
:30 2e2 :3 2e1 :11 2e4 :b 2e5
:3 2e4 :a 2e7 :3 2e0 :3 2cc
:3 2b3 :3 2a0 :14 2ee :3 2ef
:3 2ee :b 2f2 :5 2f4 :3 2f5
:3 2f6 2f4 :3 2f8 :3 2f9
2f7 :3 2f4 :3 2fc 2f2
:5 2ff :3 301 :e 303 :b 304
:2 305 :2 304 :a 305 :8 306
:3 303 :b 308 :11 309 :20 30a
:3 309 :11 30c :b 30d :3 30c
:9 30f 310 308 :9 310
:11 311 :2e 312 :3 311 :11 314
:b 315 :3 314 :c 317 310
:3 308 2ff :3 31a 319
:3 2ff :16 31c :16 31d :3 31e
31f 31d :9 31f :3 320
321 31f 31d :16 321
:3 322 323 321 31d
:9 323 :3 324 323 :3 31d
:3 31c 2fd :3 2f2 :b 32e
:3 32f :3 331 :3 332 :8 335
:3 336 :9 33d :5 33e :3 33f
33d :2 343 344 :2 345
343 :5 346 342 :2 348
:5 34a :11 34b :24 34c :3 34b
:2 349 :6 348 347 :3 340
:a 351 :9 352 355 357
358 :2 359 :2 35a 35b
:3 35c 355 :5 35d 353
:2 35f :5 361 :11 362 :24 363
:3 362 :2 360 :6 35f 35e
:3 352 :a 368 :3 369 :3 368
:3 352 351 :3 36d 36c
:3 351 340 :3 33d :5 371
:3 374 376 377 :2 378
:2 379 374 :5 37a 372
:2 37c :5 37e :11 37f :24 380
:3 37f :2 37d :6 37c 37b
:3 371 :d 387 :6 388 389
:4 38a :3 38b :4 38c 387
:5 38d 385 :2 38f :5 391
:11 392 :24 393 :3 392 :2 390
:6 38f 38e :3 371 :a 398
:11 399 :30 39a :3 399 :11 39c
:b 39d :3 39c :a 39f :3 398
:11 3a2 3a5 3a7 3a8
3a9 3aa 3ab 3ac
3ad 3ae 3af 3b3
3b4 3b5 3b6 3b7
3b8 3b9 3ba 3bb
3a5 :6 3bd :5 3be 3bd
:5 3c0 3bf :3 3bd 3a4
:2 3c3 :5 3c5 :11 3c6 :24 3c7
:3 3c6 :2 3c4 :6 3c3 3c2
:3 371 3cb 371 :a 3cb
:2 3cf :2 3d0 :2 3d1 :2 3d2
:2 3d3 3cf :6 3d4 :5 3d5
3d4 :5 3d7 3d6 :3 3d4
3ce :2 3da :5 3dc :11 3dd
:24 3de :3 3dd :2 3db :6 3da
3d9 :4 3cb :3 371 3e7
3e8 3e9 3ea :2 3eb
3ec :2 3ed 3e7 :6 3ee
:5 3ef 3ee :5 3f1 3f0
:3 3ee 3e6 :2 3f4 :5 3f6
:11 3f7 :24 3f8 :3 3f7 :2 3f5
:6 3f4 3f3 :3 32e 3fe
3ff 400 401 :2 402
403 :2 404 3fe :6 405
:5 406 405 :5 408 407
:3 405 3fd :2 40b :5 40d
:11 40e :24 40f :3 40e :2 40c
:6 40b 40a :3 32e 415
:2 416 417 :2 418 415
:6 419 :5 41a 419 :5 41c
41b :3 419 414 :2 41f
:5 421 :11 422 :24 423 :3 422
:2 420 :6 41f 41e :6 32e
:5 445 :17 447 :2 448 :2 447
:6 448 :2 447 :5 449 :3 44a
:3 449 448 :2 447 :9 44e
:5 44f :3 44e :13 452 :6 453
:2 452 :3 454 453 :2 452
:3 458 :3 459 :9 45a :b 461
:a 462 :2 463 :2 462 :2 464
:2 462 :2 465 :2 462 :2 465
:2 462 :2 465 :3 462 466
461 :9 466 :2 467 :2 468
:2 467 :2 469 :2 467 :2 469
:2 467 :2 469 :2 467 :2 46a
:2 467 :2 46a :2 467 :2 46a
:2 467 :2 46b :3 467 466
461 :2 46d :2 46e :2 46d
:2 46f :2 46d :2 470 :2 46d
:2 470 :2 46d :2 470 :3 46d
46c :3 461 45a :c 47a
:2 47b :2 47a :6 47b :2 47a
47b :2 47c :2 47b :6 47c
:2 47a :5 480 :5 481 :5 483
:5 486 :5 487 48a :2 48b
48c 48d :4 490 :2 491
:3 492 :4 493 :2 494 :3 495
48a :6 496 :5 497 496
:5 499 498 :3 496 489
:2 49c :5 49e :11 49f :24 4a0
:3 49f :2 49d :6 49c 49b
:3 483 4a8 :2 4a9 :2 4aa
:2 4ac :2 4ad :4 4ae :8 4af
4a8 :6 4b0 :5 4b1 4b0
:5 4b3 4b2 :3 4b0 4a7
:2 4b6 :5 4b8 :11 4b9 :24 4ba
:3 4b9 :2 4b7 :6 4b6 4b5
:4 483 :3 4c0 4be :3 483
47c :2 47a :5 4c4 4c6
:1c 4c7 :2 4c6 :c 4c7 :3 4c6
:3 4c8 :8 4cb :15 4cc :15 4cd
:2 4cc :2 4ce 4cd :2 4cc
:7 4d0 4cb 4d1 4cb
:5 4d3 :11 4d4 :20 4d5 :3 4d4
:11 4d7 :b 4d8 :3 4d7 :9 4da
:3 4d3 :2 4de 4df 4e0
4de :5 4e1 4dd :2 4e3
:5 4e5 :11 4e6 :24 4e7 :3 4e6
:2 4e4 :6 4e3 4e2 :6 4c4
:b 4ed 4ef 4f0 4ef
:3 4f1 :7 4f2 :7 4f3 4f4
4ed :b 4f4 4f6 4f7
4f6 :7 4f8 :7 4f9 :3 4fa
4f4 4ed :b 4fc :3 4ff
:3 500 :5 502 :7 503 :7 504
:7 505 :3 502 :7 508 :5 50a
:7 50b :7 50c :7 50d :3 50a
4fc :5 510 :7 511 :3 512
510 :6 515 :2 516 :3 515
:3 518 :5 51a :7 51b :7 51c
:7 51d :3 51a :6 520 :2 521
:2 520 :2 522 :2 520 :2 523
:2 520 :2 524 :2 520 :2 525
:3 520 513 :3 510 :5 528
:f 529 :3 528 50f :3 4fc
4fb :3 4ed :b 52e :5 52f
:2 531 532 :2 533 531
:5 534 530 :2 536 :5 538
:11 539 :24 53a :3 539 :2 537
:6 536 535 :3 52f :a 53f
:a 540 :7 543 :6 544 :2 545
:2 544 :2 545 :2 544 :2 545
:3 544 53f :11 547 :30 548
:3 547 :11 54a :b 54b :3 54a
:a 54d 546 :3 53f :3 52f
:5 551 :2 553 554 :2 555
553 :5 556 552 :2 558
:5 55a :11 55b :24 55c :3 55b
:2 559 :6 558 557 :3 551
:a 561 :7 562 :6 563 :2 564
:2 563 :2 564 :2 563 :2 564
:3 563 561 :11 566 :30 567
:3 566 :11 569 :b 56a :3 569
:a 56c 565 :3 561 :3 551
:5 570 :2 572 573 :2 574
572 :5 575 571 :2 577
:5 579 :11 57a :24 57b :3 57a
:2 578 :6 577 576 :3 570
:a 580 :7 581 :6 582 :2 583
:2 582 :2 583 :2 582 :2 583
:3 582 580 :11 585 :30 586
:3 585 :11 588 :b 589 :3 588
:a 58b 584 :3 580 :3 570
:14 58f :16 590 :3 58f :3 52e
:5 595 :a 596 :3 598 :8 599
:f 59b :2 59e 59f :2 5a0
59e :5 5a1 59d :2 5a3
:5 5a5 :11 5a6 :24 5a7 :3 5a6
:2 5a4 :6 5a3 5a2 :3 599
:a 5ac :11 5ad :30 5ae :3 5ad
:11 5b0 :b 5b1 :3 5b0 :a 5b3
:3 5ac :6 5b6 :2 5b7 :2 5b6
:2 5b8 :2 5b6 :2 5b9 :2 5b6
:2 5b9 :2 5b6 :2 5b9 :3 5b6
:b 5bb :7 5bc 5bb :7 5be
5bd :3 5bb :b 5c2 :2 5c3
:3 5c2 :7 5c5 599 5c6
599 :3 595 :b 5ca :a 5cb
:3 5cd :8 5ce :f 5d0 :2 5d3
5d4 :2 5d5 5d3 :5 5d6
5d2 :2 5d8 :5 5da :11 5db
:24 5dc :3 5db :2 5d9 :6 5d8
5d7 :3 5ce :a 5e1 :11 5e2
:30 5e3 :3 5e2 :11 5e5 :b 5e6
:3 5e5 :a 5e8 :3 5e1 :6 5eb
:2 5ec :2 5eb :2 5ed :2 5eb
:2 5ee :2 5eb :2 5ee :2 5eb
:2 5ee :2 5eb :2 5ef :3 5eb
:7 5f0 5ce 5f1 5ce
:3 5ca :7 5f4 472 :3 45a
:7 5f7 :5 5fb 5fe :4 5ff
:3 600 :5 601 600 :5 603
602 :3 600 :a 607 :2 608
:3 607 :17 60d :2 60e :2 60d
:6 60e :2 60d 60e :2 60f
:2 60e :b 60f :3 60e :2 60d
:5 612 :4 614 :3 615 :5 616
615 :5 618 617 :3 615
:a 61b :4 61d :5 61e 61c
:2 620 :5 622 :11 623 :24 624
:3 623 :2 621 :6 620 61f
:3 61b :2 62c 61b :4 62f
:5 630 62e :2 632 :5 634
:11 635 :24 636 :3 635 :2 633
:6 632 631 :4 62d :3 61b
60f :2 60d :3 63d :3 63e
:9 63f :a 640 :5 642 :3 643
640 :c 645 :3 648 649
:2 64a :2 64b 64c 648
:5 64d 647 :2 64f :5 651
:11 652 :24 653 :3 652 :2 650
:6 64f 64e :3 645 :9 658
:4 65a :5 65b 659 :2 65d
:5 65f :11 660 :24 661 :3 660
:2 65e :6 65d 65c :3 658
:11 666 :30 667 :3 666 :11 669
:b 66a :3 669 :7 66c 66d
:2 66c :3 658 :3 645 644
:3 640 :8 672 :5 673 :7 674
:6 675 :a 676 :2 677 :3 672
:5 679 :4 67b :5 67c 67a
:2 67e :5 680 :11 681 :24 682
:3 681 :2 67f :6 67e 67d
:3 679 :7 687 :5 688 :3 687
:11 68b :2e 68c :3 68b :11 68e
:b 68f :3 68e :8 691 692
679 :18 692 :6 694 :6 695
:5 696 695 :5 698 697
:3 695 693 :2 69b :5 69d
:11 69e :24 69f :3 69e :2 69c
:6 69b 69a :4 692 :3 679
:2 6a5 63f :b 6a7 :3 6a8
:3 6a9 :3 6a7 :8 6ac :5 6ad
:7 6ae :6 6af :8 6b0 :3 6ac
:5 6b2 :7 6b3 :3 6b2 :9 6b6
:2 6b7 :3 6b6 6a6 :3 63f
6ba 6bb :3 5fe 6bc
a4 :4 6c0 :5 6c1 6bf
:2 6c3 :5 6c5 :11 6c6 :24 6c7
:3 6c6 :2 6c4 :6 6c3 6c2
:3 a4 :f 6cd :2 6ce :2 6cd
:4 6ce :6 6cd :11 6cf :2e 6d0
:3 6cf :11 6d2 :b 6d3 :3 6d2
:8 6d5 6ce :2 6cd :5 6d8
:3 6d9 :3 6da :3 6db :5 6dd
:3 6df 6e1 6e2 6e3
6e4 6e5 6e6 6e7
6e8 6e9 6ea :3 6e2
:3 6eb :5 6ec 6eb :5 6ee
6ed :3 6eb :a 6f1 :2 6f2
:3 6f1 :12 6f7 :c 6f8 :2 6f7
:3 6fa 6f8 :2 6f7 :b 6fe
:5 700 703 :2 704 :2 705
:2 706 :2 707 :2 708 :2 709
:2 70a 703 :6 70b :5 70c
70b :5 70e 70d :3 70b
702 :2 711 :5 713 :11 714
:24 715 :3 714 :2 712 :6 711
710 :6 700 :3 71b :3 71c
:3 71d :3 71e :3 71f :3 721
:3 725 :3 726 :3 6fe :c 729
72c 72d 72e 72f
730 731 732 :2 733
72c :6 734 :5 735 734
:5 737 736 :3 734 72b
:2 73a :5 73c :11 73d :24 73e
:3 73d :2 73b :6 73a 739
:6 729 :5 744 :5 745 :c 746
:3 745 :c 749 :3 744 :5 74c
:c 74d :3 74c :5 750 :5 751
:c 752 :3 751 :c 755 :3 750
:5 758 :c 759 :3 758 :5 75c
:5 75d :c 75e :3 75d :c 761
:3 75c :5 764 :5 765 :c 766
:3 765 :c 769 :3 764 :7 76d
:3 76f 6e1 770 6d8
:4 772 :5 773 771 :2 775
:5 777 :11 778 :24 779 :3 778
:2 776 :6 775 774 :3 6d8
:5 77e 781 :2 782 :2 783
:2 784 :2 785 :2 786 :2 787
:2 788 781 :6 789 :5 78a
789 :5 78c 78b :3 789
780 :2 78f :5 791 :11 792
:24 793 :3 792 :2 790 :6 78f
78e :6 77e :3 6d8 :5 79a
:9 79b :4 79d 79e :2 79f
:7 7a0 79d :5 7a1 79c
:2 7a3 :5 7a5 :11 7a6 :24 7a7
:3 7a6 :2 7a4 :6 7a3 7a2
:4 79b :3 7ac 7ad 7ab
:3 79b :3 79a :7 7b2 :9 7b3
:3 7b4 7b2 :5 7b5 7b1
:2 7b7 :5 7b9 :11 7ba :24 7bb
:3 7ba :2 7b8 :6 7b7 7b6
:3 a4 :b 7c3 :5 7c6 :5 7c7
7cc 7cd 7ce 7cf
7d0 7d1 7d2 :2 7d3
:2 7d4 7cc :6 7d5 :5 7d6
7d5 :5 7d8 7d7 :3 7d5
7cb :2 7db :5 7dd :11 7de
:24 7df :3 7de :2 7dc :6 7db
7da :3 7c3 :a 7e5 7e7
7e8 :3 7e9 :3 7ea :3 7eb
:3 7ec 7ed :2 7ee 7ef
7e7 :6 7f0 :5 7f1 7f0
:5 7f3 7f2 :3 7f0 7e6
:2 7f6 :5 7f8 :11 7f9 :24 7fa
:3 7f9 :2 7f7 :6 7f6 7f5
:3 7e5 :a 7ff 801 802
803 :2 804 805 801
:6 806 :5 807 806 :5 809
808 :3 806 800 :2 80c
:5 80e :11 80f :24 810 :3 80f
:2 80d :6 80c 80b :6 7ff
:3 7e5 :12 817 :6 818 :e 819
:e 81a :e 81b :e 81c :19 81d
:12 81e :3 81f :9 820 :c 821
:6 822 :7 823 :9 824 :9 825
:9 826 :9 827 :8 828 :3 817
:11 829 :b 82a :3 829 :3 82c
7c3 :5 82e :13 82f :6 830
:20 831 :20 832 :20 833 :20 834
:19 835 :1c 836 :5 837 :9 838
:7 839 :9 83a :10 83b :c 83c
:9 83d :9 83e :9 83f :9 840
841 :3 82f :11 842 :b 843
:3 842 :3 845 82e :5 848
:5 849 84c :5 84d :2 84e
84c :6 84f :5 850 84f
:5 852 851 :3 84f 84b
:2 855 :5 857 :11 858 :24 859
:3 858 :2 856 :6 855 854
:3 846 85f :4 860 :6 861
:3 862 863 :2 864 :2 865
866 85f :6 867 :5 868
867 :5 86a 869 :3 867
85e :2 86d :5 86f :11 870
:24 871 :3 870 :2 86e :6 86d
86c :3 846 :13 876 :6 877
:5 879 :17 87a :17 87b :3 87c
87d :5 87f :17 880 :17 881
:3 882 883 :5 885 :17 886
:17 887 :3 888 889 :5 88b
:17 88c :17 88d :3 88e 88f
:19 891 :12 892 :a 893 :5 894
:2 895 :a 896 :a 897 :7 898
:7 899 :9 89a :10 89b :c 89c
:9 89d :12 89e :12 89f :9 8a0
:8 8a1 8a2 :3 876 :11 8a3
:b 8a4 :3 8a3 :3 8a6 846
:3 82e 82d :3 7c3 a4
:3 8ac :11 8ad :b 8ae :17 8af
:3 8ad :2 8b1 :3 8b2 :3 8b3
8b4 8b2 8b1 8b2
:3 8b5 :3 8ac :2 8b6 :5 8b8
:11 8b9 :b 8ba :18 8bb :3 8b9
:2 8bd 8be :3 8bf 8c0
8be 8bd 8be :3 8c1
:2 8b7 :6 8b6 8ab :7 1

b931
4
:3 0 1 :3 0 2
:a 0 34c5 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
56 0 7 4
:3 0 5 :7 0 9
8 :3 0 4 :3 0
6 :7 0 d c
:3 0 d 7c 0
b 8 :3 0 7
:7 0 11 10 :3 0
8 :3 0 9 :7 0
15 14 :3 0 11
a2 0 f 8
:3 0 a :7 0 19
18 :3 0 8 :3 0
b :7 0 1d 1c
:3 0 15 c8 0
13 8 :3 0 c
:7 0 21 20 :3 0
8 :3 0 d :7 0
25 24 :3 0 19
ee 0 17 8
:3 0 e :7 0 29
28 :3 0 8 :3 0
f :7 0 2d 2c
:3 0 1d 114 0
1b 4 :3 0 10
:7 0 31 30 :3 0
4 :3 0 11 :7 0
35 34 :3 0 21
13a 0 1f 4
:3 0 12 :7 0 39
38 :3 0 4 :3 0
13 :7 0 3d 3c
:3 0 25 160 0
23 4 :3 0 14
:7 0 41 40 :3 0
8 :3 0 15 :7 0
45 44 :3 0 29
186 0 27 4
:3 0 16 :7 0 49
48 :3 0 4 :3 0
17 :7 0 4d 4c
:3 0 2d 1ac 0
2b 4 :3 0 18
:7 0 51 50 :3 0
4 :3 0 19 :7 0
55 54 :3 0 31
1d2 0 2f 8
:3 0 1a :7 0 59
58 :3 0 8 :3 0
1b :7 0 5d 5c
:3 0 35 1f8 0
33 8 :3 0 1c
:7 0 61 60 :3 0
8 :3 0 1d :7 0
65 64 :3 0 39
:2 0 37 4 :3 0
1e :7 0 69 68
:3 0 4 :3 0 1f
:7 0 6d 6c :3 0
20 :3 0 21 :3 0
22 :2 0 4 71
72 0 6f 73
0 34c5 2 74
:2 0 24 :2 0 57
4 :3 0 24 :2 0
55 77 79 :6 0
7c 7a 0 34c3
0 23 :6 0 24
:2 0 5b 4 :3 0
59 7e 80 :6 0
83 81 0 34c3
0 25 :6 0 24
:2 0 5f 4 :3 0
5d 85 87 :6 0
8a 88 0 34c3
0 26 :6 0 24
:2 0 63 4 :3 0
61 8c 8e :6 0
91 8f 0 34c3
0 27 :6 0 24
:2 0 67 4 :3 0
65 93 95 :6 0
98 96 0 34c3
0 28 :6 0 2b
:2 0 6b 4 :3 0
69 9a 9c :6 0
9f 9d 0 34c3
0 29 :6 0 2d
:2 0 6f 4 :3 0
6d a1 a3 :6 0
a6 a4 0 34c3
0 2a :6 0 2f
:2 0 73 4 :3 0
71 a8 aa :6 0
ad ab 0 34c3
0 2c :6 0 2f
:2 0 77 4 :3 0
75 af b1 :6 0
b4 b2 0 34c3
0 2e :6 0 2f
:2 0 7b 4 :3 0
79 b6 b8 :6 0
bb b9 0 34c3
0 30 :6 0 2f
:2 0 7f 4 :3 0
7d bd bf :6 0
c2 c0 0 34c3
0 31 :6 0 2f
:2 0 83 4 :3 0
81 c4 c6 :6 0
c9 c7 0 34c3
0 32 :6 0 2f
:2 0 87 4 :3 0
85 cb cd :6 0
d0 ce 0 34c3
0 33 :6 0 2f
:2 0 8b 4 :3 0
89 d2 d4 :6 0
d7 d5 0 34c3
0 34 :6 0 2f
:2 0 8f 4 :3 0
8d d9 db :6 0
de dc 0 34c3
0 35 :6 0 2f
:2 0 93 4 :3 0
91 e0 e2 :6 0
e5 e3 0 34c3
0 36 :6 0 2f
:2 0 97 4 :3 0
95 e7 e9 :6 0
ec ea 0 34c3
0 37 :6 0 24
:2 0 9b 4 :3 0
99 ee f0 :6 0
f3 f1 0 34c3
0 38 :6 0 24
:2 0 9f 4 :3 0
9d f5 f7 :6 0
fa f8 0 34c3
0 39 :6 0 3c
:2 0 a3 4 :3 0
a1 fc fe :6 0
101 ff 0 34c3
0 3a :6 0 a9
499 0 a7 4
:3 0 a5 103 105
:6 0 108 106 0
34c3 0 3b :6 0
40 :2 0 ad 3e
:3 0 10a :7 0 10d
10b 0 34c3 0
3d :6 0 4 :3 0
40 :2 0 ab 10f
111 :6 0 114 112
0 34c3 0 3f
:6 0 40 :2 0 b1
4 :3 0 af 116
118 :6 0 11b 119
0 34c3 0 41
:6 0 40 :2 0 b5
4 :3 0 b3 11d
11f :6 0 122 120
0 34c3 0 42
:6 0 40 :2 0 b9
4 :3 0 b7 124
126 :6 0 129 127
0 34c3 0 43
:6 0 46 :2 0 bd
4 :3 0 bb 12b
12d :6 0 130 12e
0 34c3 0 44
:6 0 24 :2 0 c1
4 :3 0 bf 132
134 :6 0 137 135
0 34c3 0 45
:6 0 24 :2 0 c5
4 :3 0 c3 139
13b :6 0 13e 13c
0 34c3 0 47
:6 0 24 :2 0 c9
4 :3 0 c7 140
142 :6 0 145 143
0 34c3 0 48
:6 0 2b :2 0 cd
4 :3 0 cb 147
149 :6 0 14c 14a
0 34c3 0 49
:6 0 46 :2 0 d1
4 :3 0 cf 14e
150 :6 0 153 151
0 34c3 0 4a
:6 0 4d :2 0 d5
4 :3 0 d3 155
157 :6 0 15a 158
0 34c3 0 4b
:6 0 4d :2 0 d7
8 :3 0 15c :7 0
160 15d 15e 34c3
0 4c :6 0 4d
:2 0 d9 8 :3 0
162 :7 0 166 163
164 34c3 0 4e
:6 0 4d :2 0 db
8 :3 0 168 :7 0
16c 169 16a 34c3
0 4f :6 0 4d
:2 0 dd 8 :3 0
16e :7 0 172 16f
170 34c3 0 50
:6 0 4d :2 0 df
8 :3 0 174 :7 0
178 175 176 34c3
0 51 :6 0 4d
:2 0 e1 8 :3 0
17a :7 0 17e 17b
17c 34c3 0 52
:6 0 4d :2 0 e3
8 :3 0 180 :7 0
184 181 182 34c3
0 53 :6 0 4d
:2 0 e5 8 :3 0
186 :7 0 18a 187
188 34c3 0 54
:6 0 4d :2 0 e7
8 :3 0 18c :7 0
190 18d 18e 34c3
0 55 :6 0 4d
:2 0 e9 8 :3 0
192 :7 0 196 193
194 34c3 0 56
:6 0 4d :2 0 eb
8 :3 0 198 :7 0
19c 199 19a 34c3
0 57 :6 0 4d
:2 0 ed 8 :3 0
19e :7 0 1a2 19f
1a0 34c3 0 58
:6 0 4d :2 0 ef
8 :3 0 1a4 :7 0
1a8 1a5 1a6 34c3
0 59 :6 0 4d
:2 0 f1 8 :3 0
1aa :7 0 1ae 1ab
1ac 34c3 0 5a
:6 0 4d :2 0 f3
8 :3 0 1b0 :7 0
1b4 1b1 1b2 34c3
0 5b :6 0 4d
:2 0 f5 8 :3 0
1b6 :7 0 1ba 1b7
1b8 34c3 0 5c
:6 0 4d :2 0 f7
8 :3 0 1bc :7 0
1c0 1bd 1be 34c3
0 5d :6 0 4d
:2 0 f9 8 :3 0
1c2 :7 0 1c6 1c3
1c4 34c3 0 5e
:6 0 4d :2 0 fb
8 :3 0 1c8 :7 0
1cc 1c9 1ca 34c3
0 5f :6 0 4d
:2 0 fd 8 :3 0
1ce :7 0 1d2 1cf
1d0 34c3 0 60
:6 0 4d :2 0 ff
8 :3 0 1d4 :7 0
1d8 1d5 1d6 34c3
0 61 :6 0 4d
:2 0 101 8 :3 0
1da :7 0 1de 1db
1dc 34c3 0 62
:6 0 4d :2 0 103
8 :3 0 1e0 :7 0
1e4 1e1 1e2 34c3
0 63 :6 0 67
:2 0 105 8 :3 0
1e6 :7 0 1ea 1e7
1e8 34c3 0 64
:6 0 67 :2 0 107
66 :3 0 1ec :7 0
1f0 1ed 1ee 34c3
0 65 :6 0 4d
:2 0 109 66 :3 0
1f2 :7 0 1f6 1f3
1f4 34c3 0 68
:6 0 4d :2 0 10b
8 :3 0 1f8 :7 0
1fc 1f9 1fa 34c3
0 69 :6 0 4d
:2 0 10d 8 :3 0
1fe :7 0 202 1ff
200 34c3 0 6a
:6 0 4d :2 0 10f
8 :3 0 204 :7 0
208 205 206 34c3
0 6b :6 0 4d
:2 0 111 8 :3 0
20a :7 0 20e 20b
20c 34c3 0 6c
:6 0 4d :2 0 113
8 :3 0 210 :7 0
214 211 212 34c3
0 6d :6 0 4d
:2 0 115 8 :3 0
216 :7 0 21a 217
218 34c3 0 6e
:6 0 46 :2 0 117
8 :3 0 21c :7 0
220 21d 21e 34c3
0 6f :6 0 4d
:2 0 11b 4 :3 0
119 222 224 :6 0
227 225 0 34c3
0 70 :6 0 4d
:2 0 11d 8 :3 0
229 :7 0 22d 22a
22b 34c3 0 71
:6 0 4d :2 0 11f
8 :3 0 22f :7 0
233 230 231 34c3
0 72 :6 0 75
:2 0 121 8 :3 0
235 :7 0 239 236
237 34c3 0 73
:6 0 77 :2 0 125
4 :3 0 123 23b
23d :6 0 240 23e
0 34c3 0 74
:6 0 75 :2 0 129
4 :3 0 127 242
244 :6 0 247 245
0 34c3 0 76
:6 0 4d :2 0 12d
4 :3 0 12b 249
24b :6 0 24e 24c
0 34c3 0 78
:6 0 4d :2 0 12f
8 :3 0 250 :7 0
254 251 252 34c3
0 79 :6 0 24
:2 0 131 8 :3 0
256 :7 0 25a 257
258 34c3 0 7a
:6 0 24 :2 0 135
7c :3 0 133 25c
25e :6 0 261 25f
0 34c3 0 7b
:6 0 24 :2 0 139
7c :3 0 137 263
265 :6 0 268 266
0 34c3 0 7d
:6 0 24 :2 0 13d
4 :3 0 13b 26a
26c :6 0 26f 26d
0 34c3 0 7e
:6 0 24 :2 0 141
4 :3 0 13f 271
273 :6 0 276 274
0 34c3 0 7f
:6 0 46 :2 0 145
4 :3 0 143 278
27a :6 0 27d 27b
0 34c3 0 80
:6 0 4d :2 0 149
4 :3 0 147 27f
281 :6 0 284 282
0 34c3 0 81
:6 0 4d :2 0 14b
8 :3 0 286 :7 0
28a 287 288 34c3
0 82 :6 0 4d
:2 0 14d 8 :3 0
28c :7 0 290 28d
28e 34c3 0 83
:6 0 46 :2 0 14f
8 :3 0 292 :7 0
296 293 294 34c3
0 84 :6 0 46
:2 0 151 8 :3 0
298 0 2 :5 0
29c 299 29a 34c3
0 85 :6 0 4d
:2 0 153 8 :3 0
29e 0 2 :5 0
2a2 29f 2a0 34c3
0 86 :6 0 4d
:2 0 155 8 :3 0
2a4 0 2 :5 0
2a8 2a5 2a6 34c3
0 87 :6 0 4d
:2 0 157 8 :3 0
2aa 0 2 :5 0
2ae 2ab 2ac 34c3
0 88 :6 0 24
:2 0 159 8 :3 0
2b0 0 2 :5 0
2b4 2b1 2b2 34c3
0 89 :6 0 4d
:2 0 15d 4 :3 0
15b 2b6 2b8 :6 0
2bb 2b9 0 34c3
0 8a :6 0 161
c56 0 15f 8
:3 0 2bd 0 2
:5 0 2c1 2be 2bf
34c3 0 8b :6 0
165 c8a 0 163
8 :3 0 2c3 :7 0
2c6 2c4 0 34c3
0 8c :6 0 8
:3 0 2c8 :7 0 2cb
2c9 0 34c3 0
8d :6 0 169 cbe
0 167 8 :3 0
2cd :7 0 2d0 2ce
0 34c3 0 8e
:6 0 8 :3 0 2d2
:7 0 2d5 2d3 0
34c3 0 8f :6 0
16d cf2 0 16b
8 :3 0 2d7 :7 0
2da 2d8 0 34c3
0 90 :6 0 8
:3 0 2dc :7 0 2df
2dd 0 34c3 0
91 :9 0 16f 8
:3 0 2e1 :7 0 2e4
2e2 0 34c3 0
92 :6 0 21 :3 0
22 :2 0 4 2e6
2e7 0 2e8 :7 0
2eb 2e9 0 34c3
0 93 :6 0 94
:3 0 95 :a 0 2
2fa :4 0 2ed 2f0
0 2ee :3 0 96
:3 0 97 :3 0 98
:3 0 25 :3 0 99
:3 0 25 :3 0 9a
:3 0 39 :4 0 9b
1 :8 0 2fb 2ed
2f0 2fc 0 34c3
171 2fc 2fe 2fb
2fd :6 0 2fa :7 0
2fc 94 :3 0 9c
:a 0 3 315 :5 0
300 303 0 301
:3 0 9d :3 0 9e
:3 0 9f :3 0 a0
:3 0 a1 :3 0 a2
:3 0 9f :3 0 a3
:3 0 a1 :3 0 a4
:3 0 a1 :3 0 a5
:3 0 a1 :3 0 a6
:3 0 a7 :3 0 9e
:4 0 a8 1 :8 0
316 300 303 317
0 34c3 173 317
319 316 318 :6 0
315 :7 0 317 322
323 0 175 21
:3 0 22 :2 0 4
31b 31c 0 31d
:7 0 320 31e 0
34c3 0 a9 :6 0
329 32a 0 177
21 :3 0 22 :2 0
4 324 :7 0 327
325 0 34c3 0
aa :6 0 330 331
0 179 21 :3 0
22 :2 0 4 32b
:7 0 32e 32c 0
34c3 0 ab :6 0
336 337 0 17b
21 :3 0 22 :2 0
4 332 :7 0 335
333 0 34c3 0
ac :6 0 ad :3 0
ae :3 0 ad :3 0
af :3 0 339 33a
0 2 :4 0 17d
33b 33d 338 33f
33e :2 0 b0 :3 0
b1 :3 0 341 342
0 b2 :4 0 ad
:3 0 b3 :3 0 345
346 0 2 :4 0
17f 347 349 b4
:4 0 b5 :2 0 b6
:3 0 181 34c 34e
:3 0 b7 :4 0 b5
:2 0 b8 :4 0 184
351 353 :3 0 b5
:2 0 3 :3 0 187
355 357 :3 0 b5
:2 0 b8 :4 0 18a
359 35b :3 0 b5
:2 0 b9 :4 0 18d
35d 35f :3 0 b5
:2 0 b8 :4 0 190
361 363 :3 0 b5
:2 0 5 :3 0 193
365 367 :3 0 b5
:2 0 b8 :4 0 196
369 36b :3 0 b5
:2 0 b9 :4 0 199
36d 36f :3 0 b5
:2 0 b8 :4 0 19c
371 373 :3 0 b5
:2 0 6 :3 0 19f
375 377 :3 0 b5
:2 0 b8 :4 0 1a2
379 37b :3 0 b5
:2 0 b9 :4 0 1a5
37d 37f :3 0 b5
:2 0 a1 :3 0 ba
:3 0 7 :3 0 1a8
383 385 bb :4 0
1aa 382 388 1ad
381 38a :3 0 b5
:2 0 b9 :4 0 1b0
38c 38e :3 0 b5
:2 0 a1 :3 0 ba
:3 0 9 :3 0 1b3
392 394 bb :4 0
1b5 391 397 1b8
390 399 :3 0 b5
:2 0 b9 :4 0 1bb
39b 39d :3 0 b5
:2 0 a1 :3 0 ba
:3 0 a :3 0 1be
3a1 3a3 bb :4 0
1c0 3a0 3a6 1c3
39f 3a8 :3 0 b5
:2 0 b9 :4 0 1c6
3aa 3ac :3 0 b5
:2 0 a1 :3 0 ba
:3 0 b :3 0 1c9
3b0 3b2 bb :4 0
1cb 3af 3b5 1ce
3ae 3b7 :3 0 b5
:2 0 b9 :4 0 1d1
3b9 3bb :3 0 b5
:2 0 a1 :3 0 ba
:3 0 c :3 0 1d4
3bf 3c1 bb :4 0
1d6 3be 3c4 1d9
3bd 3c6 :3 0 b5
:2 0 b9 :4 0 1dc
3c8 3ca :3 0 b5
:2 0 a1 :3 0 ba
:3 0 d :3 0 1df
3ce 3d0 bb :4 0
1e1 3cd 3d3 1e4
3cc 3d5 :3 0 b5
:2 0 b9 :4 0 1e7
3d7 3d9 :3 0 b5
:2 0 a1 :3 0 ba
:3 0 e :3 0 1ea
3dd 3df bb :4 0
1ec 3dc 3e2 1ef
3db 3e4 :3 0 b5
:2 0 b9 :4 0 1f2
3e6 3e8 :3 0 b5
:2 0 a1 :3 0 ba
:3 0 f :3 0 1f5
3ec 3ee bb :4 0
1f7 3eb 3f1 1fa
3ea 3f3 :3 0 b5
:2 0 b9 :4 0 1fd
3f5 3f7 :3 0 b5
:2 0 b8 :4 0 200
3f9 3fb :3 0 b5
:2 0 10 :3 0 203
3fd 3ff :3 0 b5
:2 0 b8 :4 0 206
401 403 :3 0 b5
:2 0 b9 :4 0 209
405 407 :3 0 b5
:2 0 b8 :4 0 20c
409 40b :3 0 b5
:2 0 11 :3 0 20f
40d 40f :3 0 b5
:2 0 b8 :4 0 212
411 413 :3 0 b5
:2 0 b9 :4 0 215
415 417 :3 0 b5
:2 0 b8 :4 0 218
419 41b :3 0 b5
:2 0 12 :3 0 21b
41d 41f :3 0 b5
:2 0 b8 :4 0 21e
421 423 :3 0 b5
:2 0 b9 :4 0 221
425 427 :3 0 b5
:2 0 b8 :4 0 224
429 42b :3 0 b5
:2 0 13 :3 0 227
42d 42f :3 0 b5
:2 0 b8 :4 0 22a
431 433 :3 0 b5
:2 0 b9 :4 0 22d
435 437 :3 0 b5
:2 0 b8 :4 0 230
439 43b :3 0 b5
:2 0 14 :3 0 233
43d 43f :3 0 b5
:2 0 b8 :4 0 236
441 443 :3 0 b5
:2 0 b9 :4 0 239
445 447 :3 0 b5
:2 0 a1 :3 0 ba
:3 0 15 :3 0 23c
44b 44d bb :4 0
23e 44a 450 241
449 452 :3 0 b5
:2 0 b9 :4 0 244
454 456 :3 0 b5
:2 0 b8 :4 0 247
458 45a :3 0 b5
:2 0 16 :3 0 24a
45c 45e :3 0 b5
:2 0 b8 :4 0 24d
460 462 :3 0 b5
:2 0 b9 :4 0 250
464 466 :3 0 b5
:2 0 b8 :4 0 253
468 46a :3 0 b5
:2 0 17 :3 0 256
46c 46e :3 0 b5
:2 0 b8 :4 0 259
470 472 :3 0 b5
:2 0 b9 :4 0 25c
474 476 :3 0 b5
:2 0 b8 :4 0 25f
478 47a :3 0 b5
:2 0 18 :3 0 262
47c 47e :3 0 b5
:2 0 b8 :4 0 265
480 482 :3 0 b5
:2 0 b9 :4 0 268
484 486 :3 0 b5
:2 0 b8 :4 0 26b
488 48a :3 0 b5
:2 0 19 :3 0 26e
48c 48e :3 0 b5
:2 0 b8 :4 0 271
490 492 :3 0 b5
:2 0 b9 :4 0 274
494 496 :3 0 b5
:2 0 a1 :3 0 ba
:3 0 1a :3 0 277
49a 49c bb :4 0
279 499 49f 27c
498 4a1 :3 0 b5
:2 0 b9 :4 0 27f
4a3 4a5 :3 0 b5
:2 0 a1 :3 0 ba
:3 0 1b :3 0 282
4a9 4ab bb :4 0
284 4a8 4ae 287
4a7 4b0 :3 0 b5
:2 0 b9 :4 0 28a
4b2 4b4 :3 0 b5
:2 0 a1 :3 0 ba
:3 0 1c :3 0 28d
4b8 4ba bb :4 0
28f 4b7 4bd 292
4b6 4bf :3 0 b5
:2 0 b9 :4 0 295
4c1 4c3 :3 0 b5
:2 0 a1 :3 0 ba
:3 0 1d :3 0 298
4c7 4c9 bb :4 0
29a 4c6 4cc 29d
4c5 4ce :3 0 b5
:2 0 b9 :4 0 2a0
4d0 4d2 :3 0 b5
:2 0 b8 :4 0 2a3
4d4 4d6 :3 0 b5
:2 0 1e :3 0 2a6
4d8 4da :3 0 b5
:2 0 b8 :4 0 2a9
4dc 4de :3 0 b5
:2 0 b9 :4 0 2ac
4e0 4e2 :3 0 b5
:2 0 b8 :4 0 2af
4e4 4e6 :3 0 b5
:2 0 1f :3 0 2b2
4e8 4ea :3 0 b5
:2 0 b8 :4 0 2b5
4ec 4ee :3 0 b5
:2 0 bc :4 0 2b8
4f0 4f2 :3 0 2bb
343 4f4 :2 0 4f6
2c0 4f7 340 4f6
0 4f8 2c2 0
3423 ad :3 0 ae
:3 0 4f9 4fa 0
ad :3 0 bd :3 0
4fc 4fd 0 46
:2 0 2 :4 0 be
:2 0 bf :2 0 46
:2 0 2c4 502 504
:3 0 2c7 4fe 506
4fb 508 507 :2 0
b0 :3 0 c0 :3 0
50a 50b 0 b2
:4 0 c1 :4 0 b5
:2 0 b6 :3 0 2cb
50f 511 :3 0 2ce
50c 513 :2 0 515
2d1 516 509 515
0 517 2d3 0
3423 25 :3 0 3
:3 0 518 519 0
3423 3f :3 0 5
:3 0 51b 51c 0
3423 42 :3 0 6
:3 0 51e 51f 0
3423 2a :3 0 10
:3 0 521 522 0
3423 2c :3 0 11
:3 0 524 525 0
3423 2e :3 0 16
:3 0 527 528 0
3423 30 :3 0 17
:3 0 52a 52b 0
3423 31 :3 0 18
:3 0 52d 52e 0
3423 32 :3 0 19
:3 0 530 531 0
3423 29 :3 0 1f
:3 0 533 534 0
3423 58 :3 0 7
:3 0 536 537 0
3423 56 :3 0 9
:3 0 539 53a 0
3423 57 :3 0 e
:3 0 53c 53d 0
3423 55 :3 0 1a
:3 0 53f 540 0
3423 59 :3 0 b
:3 0 542 543 0
3423 5b :3 0 f
:3 0 545 546 0
3423 5a :3 0 c
:3 0 548 549 0
3423 4f :3 0 1d
:3 0 54b 54c 0
3423 4c :3 0 a
:3 0 54e 54f 0
3423 5c :3 0 d
:3 0 551 552 0
3423 51 :3 0 1b
:3 0 554 555 0
3423 52 :3 0 1c
:3 0 557 558 0
3423 71 :3 0 4d
:2 0 55a 55b 0
3423 72 :3 0 4d
:2 0 55d 55e 0
3423 a1 :3 0 4c
:3 0 4d :2 0 2d5
560 563 c2 :3 0
c3 :2 0 c4 :3 0
565 567 0 2da
566 569 :3 0 56a
:2 0 3 :3 0 c5
:2 0 2dd 56d 56e
:3 0 56f :2 0 570
:2 0 56b 572 571
:2 0 ad :3 0 ae
:3 0 574 575 0
ad :3 0 bd :3 0
577 578 0 c6
:2 0 2 :4 0 c7
:2 0 bf :2 0 46
:2 0 2df 57d 57f
:3 0 2e2 579 581
576 583 582 :2 0
b0 :3 0 c0 :3 0
585 586 0 b2
:4 0 c8 :4 0 b5
:2 0 b6 :3 0 2e6
58a 58c :3 0 b5
:2 0 c9 :4 0 2e9
58e 590 :3 0 b5
:2 0 ca :4 0 2ec
592 594 :3 0 b5
:2 0 a1 :3 0 ba
:3 0 c2 :3 0 cb
:3 0 599 59a 0
2ef 598 59c bb
:4 0 2f1 597 59f
2f4 596 5a1 :3 0
2f7 587 5a3 :2 0
5a5 2fa 5a6 584
5a5 0 5a7 2fc
0 5d0 ad :3 0
ae :3 0 5a8 5a9
0 ad :3 0 bd
:3 0 5ab 5ac 0
46 :2 0 2 :4 0
cc :2 0 bf :2 0
46 :2 0 2fe 5b1
5b3 :3 0 301 5ad
5b5 5aa 5b7 5b6
:2 0 b0 :3 0 c0
:3 0 5b9 5ba 0
b2 :4 0 cd :4 0
b5 :2 0 b6 :3 0
305 5be 5c0 :3 0
308 5bb 5c2 :2 0
5c4 30b 5c5 5b8
5c4 0 5c6 30d
0 5d0 ce :3 0
cf :3 0 5c7 5c8
0 c2 :3 0 cb
:3 0 5ca 5cb 0
d0 :3 0 30f 5c9
5ce :2 0 5d0 312
5d1 573 5d0 0
5d2 316 0 3423
10 :3 0 c5 :2 0
318 5d4 5d5 :3 0
5d6 :2 0 5d7 :2 0
12 :3 0 c5 :2 0
31a 5da 5db :3 0
5dc :2 0 5dd :2 0
5d8 5df 5de :2 0
13 :3 0 c5 :2 0
31c 5e2 5e3 :3 0
5e4 :2 0 5e5 :2 0
5e0 5e7 5e6 :2 0
14 :3 0 c5 :2 0
31e 5ea 5eb :3 0
5ec :2 0 5ed :2 0
5e8 5ef 5ee :2 0
a1 :3 0 5b :3 0
4d :2 0 320 5f1
5f4 c2 :3 0 c3
:2 0 d1 :3 0 5f6
5f8 0 325 5f7
5fa :3 0 5fb :2 0
5f0 5fd 5fc :2 0
16 :3 0 c5 :2 0
328 600 601 :3 0
602 :2 0 603 :2 0
a1 :3 0 5b :3 0
4d :2 0 32a 605
608 c2 :3 0 d2
:2 0 d3 :3 0 60a
60c 0 32f 60b
60e :3 0 60f :2 0
604 611 610 :2 0
ad :3 0 ae :3 0
613 614 0 ad
:3 0 bd :3 0 616
617 0 c6 :2 0
2 :4 0 d4 :2 0
bf :2 0 46 :2 0
332 61c 61e :3 0
335 618 620 615
622 621 :2 0 b0
:3 0 c0 :3 0 624
625 0 b2 :4 0
d5 :4 0 b5 :2 0
b6 :3 0 339 629
62b :3 0 b5 :2 0
c9 :4 0 33c 62d
62f :3 0 b5 :2 0
ca :4 0 33f 631
633 :3 0 b5 :2 0
a1 :3 0 ba :3 0
c2 :3 0 d6 :3 0
638 639 0 342
637 63b bb :4 0
344 636 63e 347
635 640 :3 0 34a
626 642 :2 0 644
34d 645 623 644
0 646 34f 0
670 ad :3 0 ae
:3 0 647 648 0
ad :3 0 bd :3 0
64a 64b 0 46
:2 0 2 :4 0 d7
:2 0 bf :2 0 46
:2 0 351 650 652
:3 0 354 64c 654
649 656 655 :2 0
b0 :3 0 c0 :3 0
658 659 0 b2
:4 0 d8 :4 0 b5
:2 0 b6 :3 0 358
65d 65f :3 0 35b
65a 661 :2 0 663
35e 664 657 663
0 665 360 0
670 ce :3 0 cf
:3 0 666 667 0
c2 :3 0 d6 :3 0
669 66a 0 d0
:3 0 362 668 66d
:2 0 670 d9 :3 0
365 6dd 16 :3 0
c5 :2 0 369 672
673 :3 0 674 :2 0
675 :2 0 17 :3 0
c5 :2 0 36b 678
679 :3 0 67a :2 0
67b :2 0 676 67d
67c :2 0 ad :3 0
ae :3 0 67f 680
0 ad :3 0 bd
:3 0 682 683 0
c6 :2 0 2 :4 0
da :2 0 bf :2 0
46 :2 0 36d 688
68a :3 0 370 684
68c 681 68e 68d
:2 0 b0 :3 0 c0
:3 0 690 691 0
b2 :4 0 db :4 0
b5 :2 0 b6 :3 0
374 695 697 :3 0
b5 :2 0 c9 :4 0
377 699 69b :3 0
b5 :2 0 ca :4 0
37a 69d 69f :3 0
b5 :2 0 a1 :3 0
ba :3 0 c2 :3 0
d6 :3 0 6a4 6a5
0 37d 6a3 6a7
bb :4 0 37f 6a2
6aa 382 6a1 6ac
:3 0 385 692 6ae
:2 0 6b0 388 6b1
68f 6b0 0 6b2
38a 0 6db ad
:3 0 ae :3 0 6b3
6b4 0 ad :3 0
bd :3 0 6b6 6b7
0 46 :2 0 2
:4 0 dc :2 0 bf
:2 0 46 :2 0 38c
6bc 6be :3 0 38f
6b8 6c0 6b5 6c2
6c1 :2 0 b0 :3 0
c0 :3 0 6c4 6c5
0 b2 :4 0 dd
:4 0 b5 :2 0 b6
:3 0 393 6c9 6cb
:3 0 396 6c6 6cd
:2 0 6cf 399 6d0
6c3 6cf 0 6d1
39b 0 6db ce
:3 0 cf :3 0 6d2
6d3 0 c2 :3 0
d6 :3 0 6d5 6d6
0 d0 :3 0 39d
6d4 6d9 :2 0 6db
3a0 6dc 67e 6db
0 6de 612 670
0 6de 3a4 0
6df 3a7 6e0 5fe
6df 0 6e1 3a9
0 3423 a1 :3 0
4c :3 0 4d :2 0
3ab 6e2 6e5 d2
:2 0 de :2 0 3b0
6e7 6e9 :3 0 a1
:3 0 5a :3 0 4d
:2 0 3b3 6eb 6ee
d2 :2 0 de :2 0
3b8 6f0 6f2 :3 0
6ea 6f4 6f3 :2 0
a1 :3 0 56 :3 0
4d :2 0 3bb 6f6
6f9 d2 :2 0 de
:2 0 3c0 6fb 6fd
:3 0 6f5 6ff 6fe
:2 0 ad :3 0 ae
:3 0 701 702 0
ad :3 0 bd :3 0
704 705 0 c6
:2 0 2 :4 0 df
:2 0 bf :2 0 46
:2 0 3c3 70a 70c
:3 0 3c6 706 70e
703 710 70f :2 0
b0 :3 0 c0 :3 0
712 713 0 b2
:4 0 e0 :4 0 b5
:2 0 b6 :3 0 3ca
717 719 :3 0 b5
:2 0 c9 :4 0 3cd
71b 71d :3 0 b5
:2 0 ca :4 0 3d0
71f 721 :3 0 b5
:2 0 a1 :3 0 ba
:3 0 c2 :3 0 d6
:3 0 726 727 0
3d3 725 729 bb
:4 0 3d5 724 72c
3d8 723 72e :3 0
3db 714 730 :2 0
732 3de 733 711
732 0 734 3e0
0 75d ad :3 0
ae :3 0 735 736
0 ad :3 0 bd
:3 0 738 739 0
46 :2 0 2 :4 0
e1 :2 0 bf :2 0
46 :2 0 3e2 73e
740 :3 0 3e5 73a
742 737 744 743
:2 0 b0 :3 0 c0
:3 0 746 747 0
b2 :4 0 e2 :4 0
b5 :2 0 b6 :3 0
3e9 74b 74d :3 0
3ec 748 74f :2 0
751 3ef 752 745
751 0 753 3f1
0 75d ce :3 0
cf :3 0 754 755
0 c2 :3 0 d6
:3 0 757 758 0
d0 :3 0 3f3 756
75b :2 0 75d 3f6
75e 700 75d 0
75f 3fa 0 3423
15 :3 0 c5 :2 0
3fc 761 762 :3 0
763 :2 0 764 :2 0
53 :3 0 e3 :2 0
766 767 0 769
3fe 76e 53 :3 0
15 :3 0 76a 76b
0 76d 400 76f
765 769 0 770
0 76d 0 770
402 0 3423 a1
:3 0 4c :3 0 4d
:2 0 405 771 774
c2 :3 0 c3 :2 0
c4 :3 0 776 778
0 40a 777 77a
:3 0 77b :2 0 5
:3 0 e4 :2 0 40d
77e 77f :3 0 780
:2 0 781 :2 0 77c
783 782 :2 0 6
:3 0 e4 :2 0 40f
786 787 :3 0 788
:2 0 789 :2 0 784
78b 78a :2 0 e5
:3 0 e6 :3 0 6
:3 0 e5 :3 0 e6
:3 0 5 :3 0 69
:3 0 e7 :4 0 e8
1 :8 0 79b 21
:3 0 e9 :3 0 796
797 0 ea :3 0
798 799 0 79b
411 7e5 eb :3 0
21 :3 0 e9 :3 0
79e 79f 0 ea
:3 0 7a0 7a1 0
7db ad :3 0 ae
:3 0 7a3 7a4 0
ad :3 0 bd :3 0
7a6 7a7 0 ec
:2 0 2 :4 0 ed
:2 0 bf :2 0 46
:2 0 414 7ac 7ae
:3 0 417 7a8 7b0
7a5 7b2 7b1 :2 0
b0 :3 0 c0 :3 0
7b4 7b5 0 b2
:4 0 ee :4 0 b5
:2 0 b6 :3 0 41b
7b9 7bb :3 0 b5
:2 0 c9 :4 0 41e
7bd 7bf :3 0 b5
:2 0 ef :4 0 421
7c1 7c3 :3 0 b5
:2 0 ea :3 0 424
7c5 7c7 :3 0 b5
:2 0 f0 :4 0 427
7c9 7cb :3 0 b5
:2 0 f1 :3 0 f2
:3 0 46 :2 0 f3
:2 0 42a 7ce 7d2
42e 7cd 7d4 :3 0
431 7b6 7d6 :2 0
7d8 434 7d9 7b3
7d8 0 7da 436
0 7db 438 7de
:3 0 7de 0 7de
7dd 7db 7dc :6 0
7e0 4 :3 0 43b
7e2 43d 7e1 7e0
:2 0 7e3 43f :2 0
7e5 0 7e5 7e4
79b 7e3 :6 0 85f
1 :3 0 21 :3 0
e9 :3 0 7e7 7e8
0 21 :3 0 d2
:2 0 f4 :3 0 7ea
7ec 0 443 7eb
7ee :3 0 7ef :2 0
a1 :3 0 69 :3 0
4d :2 0 446 7f1
7f4 f5 :2 0 4d
:2 0 44b 7f6 7f8
:3 0 7f9 :2 0 7f0
7fb 7fa :2 0 ad
:3 0 ae :3 0 7fd
7fe 0 ad :3 0
bd :3 0 800 801
0 c6 :2 0 2
:4 0 f6 :2 0 bf
:2 0 46 :2 0 44e
806 808 :3 0 451
802 80a 7ff 80c
80b :2 0 b0 :3 0
c0 :3 0 80e 80f
0 b2 :4 0 f7
:4 0 b5 :2 0 b6
:3 0 455 813 815
:3 0 b5 :2 0 c9
:4 0 458 817 819
:3 0 b5 :2 0 ca
:4 0 45b 81b 81d
:3 0 b5 :2 0 a1
:3 0 ba :3 0 c2
:3 0 f8 :3 0 822
823 0 45e 821
825 bb :4 0 460
820 828 463 81f
82a :3 0 466 810
82c :2 0 82e 469
82f 80d 82e 0
830 46b 0 859
ad :3 0 ae :3 0
831 832 0 ad
:3 0 bd :3 0 834
835 0 46 :2 0
2 :4 0 f9 :2 0
bf :2 0 46 :2 0
46d 83a 83c :3 0
470 836 83e 833
840 83f :2 0 b0
:3 0 c0 :3 0 842
843 0 b2 :4 0
fa :4 0 b5 :2 0
b6 :3 0 474 847
849 :3 0 477 844
84b :2 0 84d 47a
84e 841 84d 0
84f 47c 0 859
ce :3 0 cf :3 0
850 851 0 c2
:3 0 f8 :3 0 853
854 0 d0 :3 0
47e 852 857 :2 0
859 481 85a 7fc
859 0 85b 485
0 85f 89 :3 0
46 :2 0 85c 85d
0 85f 487 860
78c 85f 0 861
48b 0 3423 5
:3 0 c5 :2 0 48d
863 864 :3 0 865
:2 0 866 :2 0 6
:3 0 c5 :2 0 48f
869 86a :3 0 86b
:2 0 86c :2 0 867
86e 86d :2 0 b6
:3 0 3f :3 0 e7
:4 0 fb 1 :8 0
879 21 :3 0 e9
:3 0 874 875 0
ea :3 0 876 877
0 879 491 8c3
eb :3 0 21 :3 0
e9 :3 0 87c 87d
0 ea :3 0 87e
87f 0 8b9 ad
:3 0 ae :3 0 881
882 0 ad :3 0
bd :3 0 884 885
0 ec :2 0 2
:4 0 fc :2 0 bf
:2 0 46 :2 0 494
88a 88c :3 0 497
886 88e 883 890
88f :2 0 b0 :3 0
c0 :3 0 892 893
0 b2 :4 0 fd
:4 0 b5 :2 0 b6
:3 0 49b 897 899
:3 0 b5 :2 0 c9
:4 0 49e 89b 89d
:3 0 b5 :2 0 ef
:4 0 4a1 89f 8a1
:3 0 b5 :2 0 ea
:3 0 4a4 8a3 8a5
:3 0 b5 :2 0 f0
:4 0 4a7 8a7 8a9
:3 0 b5 :2 0 f1
:3 0 f2 :3 0 46
:2 0 f3 :2 0 4aa
8ac 8b0 4ae 8ab
8b2 :3 0 4b1 894
8b4 :2 0 8b6 4b4
8b7 891 8b6 0
8b8 4b6 0 8b9
4b8 8bc :3 0 8bc
0 8bc 8bb 8b9
8ba :6 0 8be 6
:3 0 4bb 8c0 4bd
8bf 8be :2 0 8c1
4bf :2 0 8c3 0
8c3 8c2 879 8c1
:6 0 8c5 1 :3 0
4c1 8c6 86f 8c5
0 8c7 4c3 0
3423 41 :3 0 3f
:3 0 8c8 8c9 0
3423 6a :3 0 fe
:3 0 ff :3 0 8cc
8cd 0 100 :3 0
a1 :3 0 4f :3 0
4d :2 0 4c5 8d0
8d3 c2 :3 0 101
:3 0 8d5 8d6 0
4c8 8cf 8d8 8d9
:2 0 102 :2 0 4cb
8ce 8dc 8cb 8dd
0 3423 4f :3 0
100 :3 0 a1 :3 0
4f :3 0 4d :2 0
4ce 8e1 8e4 c2
:3 0 103 :3 0 8e6
8e7 0 4d1 8e0
8e9 8df 8ea 0
3423 54 :3 0 fe
:3 0 ff :3 0 8ed
8ee 0 100 :3 0
a1 :3 0 5b :3 0
4d :2 0 4d4 8f1
8f4 c2 :3 0 101
:3 0 8f6 8f7 0
4d7 8f0 8f9 8fa
:2 0 102 :2 0 4da
8ef 8fd 8ec 8fe
0 3423 5b :3 0
100 :3 0 a1 :3 0
5b :3 0 4d :2 0
4dd 902 905 c2
:3 0 103 :3 0 907
908 0 4e0 901
90a 900 90b 0
3423 45 :3 0 a1
:3 0 5b :3 0 4d
:2 0 4e3 90e 911
c2 :3 0 d2 :2 0
d3 :3 0 913 915
0 4e8 914 917
:3 0 46 :2 0 4eb
91a 919 4d :3 0
91c 0 4ed :2 0
90d 91e 0 3423
a1 :3 0 4f :3 0
4d :2 0 4f0 920
923 104 :2 0 4d
:2 0 4f5 925 927
:3 0 82 :3 0 4d
:2 0 929 92a 0
11b2 105 :3 0 82
:3 0 106 :3 0 98
:3 0 25 :4 0 107
1 :8 0 937 21
:3 0 e9 :3 0 932
933 0 ea :3 0
934 935 0 937
4f8 981 eb :3 0
21 :3 0 e9 :3 0
93a 93b 0 ea
:3 0 93c 93d 0
977 ad :3 0 ae
:3 0 93f 940 0
ad :3 0 bd :3 0
942 943 0 ec
:2 0 2 :4 0 108
:2 0 bf :2 0 46
:2 0 4fb 948 94a
:3 0 4fe 944 94c
941 94e 94d :2 0
b0 :3 0 c0 :3 0
950 951 0 b2
:4 0 109 :4 0 b5
:2 0 b6 :3 0 502
955 957 :3 0 b5
:2 0 c9 :4 0 505
959 95b :3 0 b5
:2 0 ef :4 0 508
95d 95f :3 0 b5
:2 0 ea :3 0 50b
961 963 :3 0 b5
:2 0 f0 :4 0 50e
965 967 :3 0 b5
:2 0 f1 :3 0 f2
:3 0 46 :2 0 f3
:2 0 511 96a 96e
515 969 970 :3 0
518 952 972 :2 0
974 51b 975 94f
974 0 976 51d
0 977 51f 97a
:3 0 97a 0 97a
979 977 978 :6 0
97c 8 :3 0 522
97e 524 97d 97c
:2 0 97f 526 :2 0
981 0 981 980
937 97f :6 0 11b2
1 :3 0 a1 :3 0
82 :3 0 4d :2 0
528 983 986 104
:2 0 4d :2 0 52d
988 98a :3 0 10a
:3 0 4b :3 0 10b
:3 0 10c :3 0 25
:4 0 10d 1 :8 0
997 21 :3 0 e9
:3 0 992 993 0
ea :3 0 994 995
0 997 530 9e1
eb :3 0 21 :3 0
e9 :3 0 99a 99b
0 ea :3 0 99c
99d 0 9d7 ad
:3 0 ae :3 0 99f
9a0 0 ad :3 0
bd :3 0 9a2 9a3
0 ec :2 0 2
:4 0 10e :2 0 bf
:2 0 46 :2 0 533
9a8 9aa :3 0 536
9a4 9ac 9a1 9ae
9ad :2 0 b0 :3 0
c0 :3 0 9b0 9b1
0 b2 :4 0 10f
:4 0 b5 :2 0 b6
:3 0 53a 9b5 9b7
:3 0 b5 :2 0 c9
:4 0 53d 9b9 9bb
:3 0 b5 :2 0 ef
:4 0 540 9bd 9bf
:3 0 b5 :2 0 ea
:3 0 543 9c1 9c3
:3 0 b5 :2 0 f0
:4 0 546 9c5 9c7
:3 0 b5 :2 0 f1
:3 0 f2 :3 0 46
:2 0 f3 :2 0 549
9ca 9ce 54d 9c9
9d0 :3 0 550 9b2
9d2 :2 0 9d4 553
9d5 9af 9d4 0
9d6 555 0 9d7
557 9da :3 0 9da
0 9da 9d9 9d7
9d8 :6 0 9dc a
:3 0 55a 9de 55c
9dd 9dc :2 0 9df
55e :2 0 9e1 0
9e1 9e0 997 9df
:6 0 a5e 1 :3 0
e5 :3 0 110 :3 0
9e3 9e4 0 4b
:3 0 111 :4 0 560
9e5 9e8 d2 :2 0
4d :2 0 565 9ea
9ec :3 0 ad :3 0
ae :3 0 9ee 9ef
0 ad :3 0 bd
:3 0 9f1 9f2 0
24 :2 0 2 :4 0
112 :2 0 bf :2 0
46 :2 0 568 9f7
9f9 :3 0 56b 9f3
9fb 9f0 9fd 9fc
:2 0 b0 :3 0 c0
:3 0 9ff a00 0
b2 :4 0 113 :4 0
b5 :2 0 b6 :3 0
56f a04 a06 :3 0
b5 :2 0 c9 :4 0
572 a08 a0a :3 0
b5 :2 0 ca :4 0
575 a0c a0e :3 0
b5 :2 0 a1 :3 0
ba :3 0 c2 :3 0
114 :3 0 a13 a14
0 578 a12 a16
bb :4 0 57a a11
a19 57d a10 a1b
:3 0 b5 :2 0 115
:4 0 580 a1d a1f
:3 0 b5 :2 0 b8
:4 0 583 a21 a23
:3 0 b5 :2 0 25
:3 0 586 a25 a27
:3 0 b5 :2 0 b8
:4 0 589 a29 a2b
:3 0 58c a01 a2d
:2 0 a2f 58f a30
9fe a2f 0 a31
591 0 a5b ad
:3 0 ae :3 0 a32
a33 0 ad :3 0
bd :3 0 a35 a36
0 46 :2 0 2
:4 0 116 :2 0 bf
:2 0 46 :2 0 593
a3b a3d :3 0 596
a37 a3f a34 a41
a40 :2 0 b0 :3 0
c0 :3 0 a43 a44
0 b2 :4 0 117
:4 0 b5 :2 0 b6
:3 0 59a a48 a4a
:3 0 59d a45 a4c
:2 0 a4e 5a0 a4f
a42 a4e 0 a50
5a2 0 a5b ce
:3 0 118 :3 0 a51
a52 0 c2 :3 0
114 :3 0 a54 a55
0 25 :3 0 d0
:3 0 5a4 a53 a59
:2 0 a5b 5a8 a5c
9ed a5b 0 a5d
5ac 0 a5e 5ae
a5f 98b a5e 0
a60 5b1 0 11b2
79 :3 0 119 :3 0
a1 :3 0 4f :3 0
4d :2 0 5b3 a63
a66 5b6 a62 a68
a61 a69 0 11b2
a1 :3 0 79 :3 0
4d :2 0 5b8 a6b
a6e d2 :2 0 4d
:2 0 5bd a70 a72
:3 0 4f :3 0 11a
:3 0 a1 :3 0 4f
:3 0 4d :2 0 5c0
a76 a79 5c3 a75
a7b a74 a7c 0
aeb a1 :3 0 4f
:3 0 4d :2 0 5c5
a7e a81 d2 :2 0
4d :2 0 5ca a83
a85 :3 0 ad :3 0
ae :3 0 a87 a88
0 ad :3 0 bd
:3 0 a8a a8b 0
c6 :2 0 2 :4 0
11b :2 0 bf :2 0
46 :2 0 5cd a90
a92 :3 0 5d0 a8c
a94 a89 a96 a95
:2 0 b0 :3 0 c0
:3 0 a98 a99 0
b2 :4 0 11c :4 0
b5 :2 0 b6 :3 0
5d4 a9d a9f :3 0
b5 :2 0 c9 :4 0
5d7 aa1 aa3 :3 0
b5 :2 0 ca :4 0
5da aa5 aa7 :3 0
b5 :2 0 a1 :3 0
ba :3 0 c2 :3 0
d6 :3 0 aac aad
0 5dd aab aaf
bb :4 0 5df aaa
ab2 5e2 aa9 ab4
:3 0 5e5 a9a ab6
:2 0 ab8 5e8 ab9
a97 ab8 0 aba
5ea 0 ae3 ad
:3 0 ae :3 0 abb
abc 0 ad :3 0
bd :3 0 abe abf
0 46 :2 0 2
:4 0 11d :2 0 bf
:2 0 46 :2 0 5ec
ac4 ac6 :3 0 5ef
ac0 ac8 abd aca
ac9 :2 0 b0 :3 0
c0 :3 0 acc acd
0 b2 :4 0 11e
:4 0 b5 :2 0 b6
:3 0 5f3 ad1 ad3
:3 0 5f6 ace ad5
:2 0 ad7 5f9 ad8
acb ad7 0 ad9
5fb 0 ae3 ce
:3 0 cf :3 0 ada
adb 0 c2 :3 0
d6 :3 0 add ade
0 d0 :3 0 5fd
adc ae1 :2 0 ae3
600 ae4 a86 ae3
0 ae5 604 0
aeb 79 :3 0 c2
:3 0 11f :3 0 ae7
ae8 0 ae6 ae9
0 aeb 606 aec
a73 aeb 0 aed
60a 0 11b2 26
:3 0 25 :3 0 aee
aef 0 11b2 a1
:3 0 6a :3 0 4d
:2 0 60c af1 af4
c3 :2 0 4d :2 0
611 af6 af8 :3 0
39 :3 0 14 :3 0
afa afb 0 afd
614 b5b ad :3 0
ae :3 0 afe aff
0 ad :3 0 bd
:3 0 b01 b02 0
c6 :2 0 2 :4 0
120 :2 0 bf :2 0
46 :2 0 616 b07
b09 :3 0 619 b03
b0b b00 b0d b0c
:2 0 b0 :3 0 c0
:3 0 b0f b10 0
b2 :4 0 121 :4 0
b5 :2 0 b6 :3 0
61d b14 b16 :3 0
b5 :2 0 c9 :4 0
620 b18 b1a :3 0
b5 :2 0 ca :4 0
623 b1c b1e :3 0
b5 :2 0 a1 :3 0
ba :3 0 c2 :3 0
d6 :3 0 b23 b24
0 626 b22 b26
bb :4 0 628 b21
b29 62b b20 b2b
:3 0 62e b11 b2d
:2 0 b2f 631 b30
b0e b2f 0 b31
633 0 b5a ad
:3 0 ae :3 0 b32
b33 0 ad :3 0
bd :3 0 b35 b36
0 46 :2 0 2
:4 0 122 :2 0 bf
:2 0 46 :2 0 635
b3b b3d :3 0 638
b37 b3f b34 b41
b40 :2 0 b0 :3 0
c0 :3 0 b43 b44
0 b2 :4 0 123
:4 0 b5 :2 0 b6
:3 0 63c b48 b4a
:3 0 63f b45 b4c
:2 0 b4e 642 b4f
b42 b4e 0 b50
644 0 b5a ce
:3 0 cf :3 0 b51
b52 0 c2 :3 0
d6 :3 0 b54 b55
0 d0 :3 0 646
b53 b58 :2 0 b5a
649 b5c af9 afd
0 b5d 0 b5a
0 b5d 64d 0
11b2 84 :3 0 124
:3 0 79 :3 0 4f
:3 0 26 :3 0 39
:3 0 29 :3 0 47
:3 0 650 b5f b66
b5e b67 0 11b2
a1 :3 0 84 :3 0
4d :2 0 657 b69
b6c c3 :2 0 4d
:2 0 65c b6e b70
:3 0 ad :3 0 ae
:3 0 b72 b73 0
ad :3 0 bd :3 0
b75 b76 0 24
:2 0 2 :4 0 125
:2 0 bf :2 0 46
:2 0 65f b7b b7d
:3 0 662 b77 b7f
b74 b81 b80 :2 0
b0 :3 0 c0 :3 0
b83 b84 0 b2
:4 0 126 :4 0 b5
:2 0 b6 :3 0 666
b88 b8a :3 0 b5
:2 0 c9 :4 0 669
b8c b8e :3 0 b5
:2 0 ca :4 0 66c
b90 b92 :3 0 b5
:2 0 a1 :3 0 ba
:3 0 84 :3 0 66f
b96 b98 bb :4 0
671 b95 b9b 674
b94 b9d :3 0 b5
:2 0 115 :4 0 677
b9f ba1 :3 0 b5
:2 0 b8 :4 0 67a
ba3 ba5 :3 0 b5
:2 0 47 :3 0 67d
ba7 ba9 :3 0 b5
:2 0 b8 :4 0 680
bab bad :3 0 683
b85 baf :2 0 bb1
686 bb2 b82 bb1
0 bb3 688 0
bdf ad :3 0 ae
:3 0 bb4 bb5 0
ad :3 0 bd :3 0
bb7 bb8 0 46
:2 0 2 :4 0 127
:2 0 bf :2 0 46
:2 0 68a bbd bbf
:3 0 68d bb9 bc1
bb6 bc3 bc2 :2 0
b0 :3 0 c0 :3 0
bc5 bc6 0 b2
:4 0 128 :4 0 b5
:2 0 b6 :3 0 691
bca bcc :3 0 694
bc7 bce :2 0 bd0
697 bd1 bc4 bd0
0 bd2 699 0
bdf ce :3 0 118
:3 0 bd3 bd4 0
a1 :3 0 84 :3 0
4d :2 0 69b bd6
bd9 47 :3 0 d0
:3 0 69e bd5 bdd
:2 0 bdf 6a2 be0
b71 bdf 0 be1
6a6 0 11b2 a1
:3 0 4c :3 0 4d
:2 0 6a8 be2 be5
c2 :3 0 d2 :2 0
c4 :3 0 be7 be9
0 6ad be8 beb
:3 0 ad :3 0 ae
:3 0 bed bee 0
ad :3 0 bd :3 0
bf0 bf1 0 24
:2 0 2 :4 0 129
:2 0 bf :2 0 46
:2 0 6b0 bf6 bf8
:3 0 6b3 bf2 bfa
bef bfc bfb :2 0
b0 :3 0 c0 :3 0
bfe bff 0 b2
:4 0 12a :4 0 b5
:2 0 b6 :3 0 6b7
c03 c05 :3 0 b5
:2 0 c9 :4 0 6ba
c07 c09 :3 0 b5
:2 0 ca :4 0 6bd
c0b c0d :3 0 b5
:2 0 a1 :3 0 ba
:3 0 21 :3 0 e9
:3 0 c12 c13 0
6c0 c11 c15 bb
:4 0 6c2 c10 c18
6c5 c0f c1a :3 0
b5 :2 0 115 :4 0
6c8 c1c c1e :3 0
b5 :2 0 b8 :4 0
6cb c20 c22 :3 0
b5 :2 0 47 :3 0
6ce c24 c26 :3 0
b5 :2 0 b8 :4 0
6d1 c28 c2a :3 0
6d4 c00 c2c :2 0
c2e 6d7 c2f bfd
c2e 0 c30 6d9
0 c5a ad :3 0
ae :3 0 c31 c32
0 ad :3 0 bd
:3 0 c34 c35 0
46 :2 0 2 :4 0
12b :2 0 bf :2 0
46 :2 0 6db c3a
c3c :3 0 6de c36
c3e c33 c40 c3f
:2 0 b0 :3 0 c0
:3 0 c42 c43 0
b2 :4 0 12c :4 0
b5 :2 0 b6 :3 0
6e2 c47 c49 :3 0
6e5 c44 c4b :2 0
c4d 6e8 c4e c41
c4d 0 c4f 6ea
0 c5a ce :3 0
118 :3 0 c50 c51
0 21 :3 0 e9
:3 0 c53 c54 0
47 :3 0 d0 :3 0
6ec c52 c58 :2 0
c5a 6f0 c5b bec
c5a 0 c5c 6f4
0 11b2 a1 :3 0
79 :3 0 4d :2 0
6f6 c5d c60 c2
:3 0 d2 :2 0 11f
:3 0 c62 c64 0
6fb c63 c66 :3 0
12d :3 0 a1 :3 0
4f :3 0 4d :2 0
6fe c69 c6c 701
c68 c6e c3 :2 0
4d :2 0 705 c70
c72 :3 0 98 :3 0
a1 :3 0 12e :3 0
a1 :3 0 12f :3 0
130 :3 0 25 :3 0
5e :3 0 5f :3 0
63 :3 0 10b :3 0
10c :3 0 26 :4 0
131 1 :8 0 c87
21 :3 0 e9 :3 0
c82 c83 0 ea
:3 0 c84 c85 0
c87 708 cd1 eb
:3 0 21 :3 0 e9
:3 0 c8a c8b 0
ea :3 0 c8c c8d
0 cc7 ad :3 0
ae :3 0 c8f c90
0 ad :3 0 bd
:3 0 c92 c93 0
ec :2 0 2 :4 0
132 :2 0 bf :2 0
46 :2 0 70b c98
c9a :3 0 70e c94
c9c c91 c9e c9d
:2 0 b0 :3 0 c0
:3 0 ca0 ca1 0
b2 :4 0 133 :4 0
b5 :2 0 b6 :3 0
712 ca5 ca7 :3 0
b5 :2 0 c9 :4 0
715 ca9 cab :3 0
b5 :2 0 ef :4 0
718 cad caf :3 0
b5 :2 0 ea :3 0
71b cb1 cb3 :3 0
b5 :2 0 f0 :4 0
71e cb5 cb7 :3 0
b5 :2 0 f1 :3 0
f2 :3 0 46 :2 0
f3 :2 0 721 cba
cbe 725 cb9 cc0
:3 0 728 ca2 cc2
:2 0 cc4 72b cc5
c9f cc4 0 cc6
72d 0 cc7 72f
cca :3 0 cca 0
cca cc9 cc7 cc8
:6 0 ccc c :3 0
732 cce 734 ccd
ccc :2 0 ccf 736
:2 0 cd1 0 cd1
cd0 c87 ccf :6 0
cd3 1 :3 0 738
d4e 134 :3 0 135
:3 0 134 :3 0 136
:3 0 134 :3 0 137
:3 0 134 :3 0 98
:3 0 a1 :3 0 138
:3 0 12e :3 0 a1
:3 0 138 :3 0 12f
:3 0 138 :3 0 130
:3 0 134 :3 0 139
:3 0 134 :3 0 13a
:3 0 71 :3 0 43
:3 0 44 :3 0 25
:3 0 5e :3 0 5f
:3 0 63 :3 0 72
:3 0 10b :3 0 138
:3 0 10b :3 0 134
:3 0 134 :3 0 10c
:3 0 26 :3 0 138
:3 0 10c :3 0 134
:3 0 98 :4 0 13b
1 :8 0 d01 21
:3 0 e9 :3 0 cfc
cfd 0 ea :3 0
cfe cff 0 d01
73a d4b eb :3 0
21 :3 0 e9 :3 0
d04 d05 0 ea
:3 0 d06 d07 0
d41 ad :3 0 ae
:3 0 d09 d0a 0
ad :3 0 bd :3 0
d0c d0d 0 ec
:2 0 2 :4 0 13c
:2 0 bf :2 0 46
:2 0 73d d12 d14
:3 0 740 d0e d16
d0b d18 d17 :2 0
b0 :3 0 c0 :3 0
d1a d1b 0 b2
:4 0 13d :4 0 b5
:2 0 b6 :3 0 744
d1f d21 :3 0 b5
:2 0 c9 :4 0 747
d23 d25 :3 0 b5
:2 0 ef :4 0 74a
d27 d29 :3 0 b5
:2 0 ea :3 0 74d
d2b d2d :3 0 b5
:2 0 f0 :4 0 750
d2f d31 :3 0 b5
:2 0 f1 :3 0 f2
:3 0 46 :2 0 f3
:2 0 753 d34 d38
757 d33 d3a :3 0
75a d1c d3c :2 0
d3e 75d d3f d19
d3e 0 d40 75f
0 d41 761 d44
:3 0 d44 0 d44
d43 d41 d42 :6 0
d46 e :3 0 764
d48 766 d47 d46
:2 0 d49 768 :2 0
d4b 0 d4b d4a
d01 d49 :6 0 d4d
1 :3 0 76a d4f
c73 cd3 0 d50
0 d4d 0 d50
76c 0 dcc 21
:3 0 e9 :3 0 d51
d52 0 21 :3 0
c3 :2 0 f4 :3 0
d54 d56 0 771
d55 d58 :3 0 d59
:2 0 ad :3 0 ae
:3 0 d5b d5c 0
ad :3 0 bd :3 0
d5e d5f 0 24
:2 0 2 :4 0 13e
:2 0 bf :2 0 46
:2 0 774 d64 d66
:3 0 777 d60 d68
d5d d6a d69 :2 0
b0 :3 0 c0 :3 0
d6c d6d 0 b2
:4 0 13f :4 0 b5
:2 0 b6 :3 0 77b
d71 d73 :3 0 b5
:2 0 c9 :4 0 77e
d75 d77 :3 0 b5
:2 0 ca :4 0 781
d79 d7b :3 0 b5
:2 0 a1 :3 0 ba
:3 0 c2 :3 0 140
:3 0 d80 d81 0
784 d7f d83 bb
:4 0 786 d7e d86
789 d7d d88 :3 0
b5 :2 0 115 :4 0
78c d8a d8c :3 0
b5 :2 0 b8 :4 0
78f d8e d90 :3 0
b5 :2 0 26 :3 0
792 d92 d94 :3 0
b5 :2 0 b8 :4 0
795 d96 d98 :3 0
798 d6e d9a :2 0
d9c 79b d9d d6b
d9c 0 d9e 79d
0 dc8 ad :3 0
ae :3 0 d9f da0
0 ad :3 0 bd
:3 0 da2 da3 0
46 :2 0 2 :4 0
141 :2 0 bf :2 0
46 :2 0 79f da8
daa :3 0 7a2 da4
dac da1 dae dad
:2 0 b0 :3 0 c0
:3 0 db0 db1 0
b2 :4 0 142 :4 0
b5 :2 0 b6 :3 0
7a6 db5 db7 :3 0
7a9 db2 db9 :2 0
dbb 7ac dbc daf
dbb 0 dbd 7ae
0 dc8 ce :3 0
118 :3 0 dbe dbf
0 c2 :3 0 140
:3 0 dc1 dc2 0
26 :3 0 d0 :3 0
7b0 dc0 dc6 :2 0
dc8 7b4 dc9 d5a
dc8 0 dca 7b8
0 dcc d9 :3 0
7ba 100f a1 :3 0
79 :3 0 4d :2 0
7bd dcd dd0 c2
:3 0 d2 :2 0 143
:3 0 dd2 dd4 0
7c2 dd3 dd6 :3 0
98 :3 0 144 :3 0
145 :3 0 25 :3 0
4f :3 0 23 :3 0
146 :3 0 10c :3 0
26 :4 0 147 1
:8 0 de7 21 :3 0
e9 :3 0 de2 de3
0 ea :3 0 de4
de5 0 de7 7c5
e31 eb :3 0 21
:3 0 e9 :3 0 dea
deb 0 ea :3 0
dec ded 0 e27
ad :3 0 ae :3 0
def df0 0 ad
:3 0 bd :3 0 df2
df3 0 ec :2 0
2 :4 0 148 :2 0
bf :2 0 46 :2 0
7c8 df8 dfa :3 0
7cb df4 dfc df1
dfe dfd :2 0 b0
:3 0 c0 :3 0 e00
e01 0 b2 :4 0
149 :4 0 b5 :2 0
b6 :3 0 7cf e05
e07 :3 0 b5 :2 0
c9 :4 0 7d2 e09
e0b :3 0 b5 :2 0
ef :4 0 7d5 e0d
e0f :3 0 b5 :2 0
ea :3 0 7d8 e11
e13 :3 0 b5 :2 0
f0 :4 0 7db e15
e17 :3 0 b5 :2 0
f1 :3 0 f2 :3 0
46 :2 0 f3 :2 0
7de e1a e1e 7e2
e19 e20 :3 0 7e5
e02 e22 :2 0 e24
7e8 e25 dff e24
0 e26 7ea 0
e27 7ec e2a :3 0
e2a 0 e2a e29
e27 e28 :6 0 e2c
10 :3 0 7ef e2e
7f1 e2d e2c :2 0
e2f 7f3 :2 0 e31
0 e31 e30 de7
e2f :6 0 f9f 1
:3 0 21 :3 0 e9
:3 0 e33 e34 0
21 :3 0 c3 :2 0
f4 :3 0 e36 e38
0 7f7 e37 e3a
:3 0 e3b :2 0 ad
:3 0 ae :3 0 e3d
e3e 0 ad :3 0
bd :3 0 e40 e41
0 24 :2 0 2
:4 0 14a :2 0 bf
:2 0 46 :2 0 7fa
e46 e48 :3 0 7fd
e42 e4a e3f e4c
e4b :2 0 b0 :3 0
c0 :3 0 e4e e4f
0 b2 :4 0 14b
:4 0 b5 :2 0 b6
:3 0 801 e53 e55
:3 0 b5 :2 0 c9
:4 0 804 e57 e59
:3 0 b5 :2 0 ca
:4 0 807 e5b e5d
:3 0 b5 :2 0 a1
:3 0 ba :3 0 c2
:3 0 140 :3 0 e62
e63 0 80a e61
e65 bb :4 0 80c
e60 e68 80f e5f
e6a :3 0 b5 :2 0
115 :4 0 812 e6c
e6e :3 0 b5 :2 0
b8 :4 0 815 e70
e72 :3 0 b5 :2 0
26 :3 0 818 e74
e76 :3 0 b5 :2 0
b8 :4 0 81b e78
e7a :3 0 81e e50
e7c :2 0 e7e 821
e7f e4d e7e 0
e80 823 0 eaa
ad :3 0 ae :3 0
e81 e82 0 ad
:3 0 bd :3 0 e84
e85 0 46 :2 0
2 :4 0 14c :2 0
bf :2 0 46 :2 0
825 e8a e8c :3 0
828 e86 e8e e83
e90 e8f :2 0 b0
:3 0 c0 :3 0 e92
e93 0 b2 :4 0
14d :4 0 b5 :2 0
b6 :3 0 82c e97
e99 :3 0 82f e94
e9b :2 0 e9d 832
e9e e91 e9d 0
e9f 834 0 eaa
ce :3 0 118 :3 0
ea0 ea1 0 c2
:3 0 140 :3 0 ea3
ea4 0 26 :3 0
d0 :3 0 836 ea2
ea8 :2 0 eaa 83a
eab e3c eaa 0
eac 83e 0 f9f
14e :3 0 41 :3 0
14e :3 0 14f :3 0
41 :3 0 a1 :3 0
12e :3 0 a1 :3 0
12f :3 0 130 :3 0
41 :3 0 5e :3 0
5f :3 0 63 :3 0
10b :3 0 98 :3 0
25 :3 0 10c :3 0
25 :4 0 150 1
:8 0 ec6 21 :3 0
e9 :3 0 ec1 ec2
0 ea :3 0 ec3
ec4 0 ec6 840
f10 eb :3 0 21
:3 0 e9 :3 0 ec9
eca 0 ea :3 0
ecb ecc 0 f06
ad :3 0 ae :3 0
ece ecf 0 ad
:3 0 bd :3 0 ed1
ed2 0 ec :2 0
2 :4 0 151 :2 0
bf :2 0 46 :2 0
843 ed7 ed9 :3 0
846 ed3 edb ed0
edd edc :2 0 b0
:3 0 c0 :3 0 edf
ee0 0 b2 :4 0
152 :4 0 b5 :2 0
b6 :3 0 84a ee4
ee6 :3 0 b5 :2 0
c9 :4 0 84d ee8
eea :3 0 b5 :2 0
ef :4 0 850 eec
eee :3 0 b5 :2 0
ea :3 0 853 ef0
ef2 :3 0 b5 :2 0
f0 :4 0 856 ef4
ef6 :3 0 b5 :2 0
f1 :3 0 f2 :3 0
46 :2 0 f3 :2 0
859 ef9 efd 85d
ef8 eff :3 0 860
ee1 f01 :2 0 f03
863 f04 ede f03
0 f05 865 0
f06 867 f09 :3 0
f09 0 f09 f08
f06 f07 :6 0 f0b
12 :3 0 86a f0d
86c f0c f0b :2 0
f0e 86e :2 0 f10
0 f10 f0f ec6
f0e :6 0 f9f 1
:3 0 21 :3 0 e9
:3 0 f12 f13 0
21 :3 0 c3 :2 0
f4 :3 0 f15 f17
0 872 f16 f19
:3 0 f1a :2 0 ad
:3 0 ae :3 0 f1c
f1d 0 ad :3 0
bd :3 0 f1f f20
0 24 :2 0 2
:4 0 153 :2 0 bf
:2 0 46 :2 0 875
f25 f27 :3 0 878
f21 f29 f1e f2b
f2a :2 0 b0 :3 0
c0 :3 0 f2d f2e
0 b2 :4 0 154
:4 0 b5 :2 0 b6
:3 0 87c f32 f34
:3 0 b5 :2 0 c9
:4 0 87f f36 f38
:3 0 b5 :2 0 ca
:4 0 882 f3a f3c
:3 0 b5 :2 0 a1
:3 0 ba :3 0 c2
:3 0 140 :3 0 f41
f42 0 885 f40
f44 bb :4 0 887
f3f f47 88a f3e
f49 :3 0 b5 :2 0
115 :4 0 88d f4b
f4d :3 0 b5 :2 0
b8 :4 0 890 f4f
f51 :3 0 b5 :2 0
25 :3 0 893 f53
f55 :3 0 b5 :2 0
b8 :4 0 896 f57
f59 :3 0 899 f2f
f5b :2 0 f5d 89c
f5e f2c f5d 0
f5f 89e 0 f89
ad :3 0 ae :3 0
f60 f61 0 ad
:3 0 bd :3 0 f63
f64 0 46 :2 0
2 :4 0 155 :2 0
bf :2 0 46 :2 0
8a0 f69 f6b :3 0
8a3 f65 f6d f62
f6f f6e :2 0 b0
:3 0 c0 :3 0 f71
f72 0 b2 :4 0
156 :4 0 b5 :2 0
b6 :3 0 8a7 f76
f78 :3 0 8aa f73
f7a :2 0 f7c 8ad
f7d f70 f7c 0
f7e 8af 0 f89
ce :3 0 118 :3 0
f7f f80 0 c2
:3 0 140 :3 0 f82
f83 0 25 :3 0
d0 :3 0 8b1 f81
f87 :2 0 f89 8b5
f8a f1b f89 0
f8b 8b9 0 f9f
23 :3 0 e4 :2 0
8bb f8d f8e :3 0
f8f :2 0 79 :3 0
c2 :3 0 11f :3 0
f92 f93 0 f91
f94 0 f9c 4f
:3 0 157 :3 0 4f
:3 0 8bd f97 f99
f96 f9a 0 f9c
8bf f9d f90 f9c
0 f9e 8c2 0
f9f 8c4 fa0 dd7
f9f 0 1011 ad
:3 0 ae :3 0 fa1
fa2 0 ad :3 0
bd :3 0 fa4 fa5
0 24 :2 0 2
:4 0 158 :2 0 bf
:2 0 46 :2 0 8ca
faa fac :3 0 8cd
fa6 fae fa3 fb0
faf :2 0 b0 :3 0
c0 :3 0 fb2 fb3
0 b2 :4 0 159
:4 0 b5 :2 0 b6
:3 0 8d1 fb7 fb9
:3 0 b5 :2 0 c9
:4 0 8d4 fbb fbd
:3 0 b5 :2 0 ca
:4 0 8d7 fbf fc1
:3 0 b5 :2 0 a1
:3 0 ba :3 0 c2
:3 0 d6 :3 0 fc6
fc7 0 8da fc5
fc9 bb :4 0 8dc
fc4 fcc 8df fc3
fce :3 0 b5 :2 0
115 :4 0 8e2 fd0
fd2 :3 0 b5 :2 0
b8 :4 0 8e5 fd4
fd6 :3 0 b5 :2 0
25 :3 0 8e8 fd8
fda :3 0 b5 :2 0
b8 :4 0 8eb fdc
fde :3 0 8ee fb4
fe0 :2 0 fe2 8f1
fe3 fb1 fe2 0
fe4 8f3 0 100e
ad :3 0 ae :3 0
fe5 fe6 0 ad
:3 0 bd :3 0 fe8
fe9 0 46 :2 0
2 :4 0 15a :2 0
bf :2 0 46 :2 0
8f5 fee ff0 :3 0
8f8 fea ff2 fe7
ff4 ff3 :2 0 b0
:3 0 c0 :3 0 ff6
ff7 0 b2 :4 0
15b :4 0 b5 :2 0
b6 :3 0 8fc ffb
ffd :3 0 8ff ff8
fff :2 0 1001 902
1002 ff5 1001 0
1003 904 0 100e
ce :3 0 118 :3 0
1004 1005 0 c2
:3 0 d6 :3 0 1007
1008 0 25 :3 0
d0 :3 0 906 1006
100c :2 0 100e 90a
1010 c67 dcc 0
1011 0 100e 0
1011 90e 0 11b2
a1 :3 0 5b :3 0
4d :2 0 912 1012
1015 c2 :3 0 c3
:2 0 d3 :3 0 1017
1019 0 917 1018
101b :3 0 15c :3 0
e5 :3 0 15d :3 0
41 :3 0 15e :3 0
a1 :3 0 e5 :3 0
15d :3 0 15f :3 0
a1 :3 0 e5 :3 0
15d :3 0 160 :3 0
4a :3 0 6c :3 0
70 :3 0 6d :3 0
6e :3 0 161 :3 0
9a :3 0 39 :4 0
162 1 :8 0 1038
21 :3 0 e9 :3 0
1033 1034 0 ea
:3 0 1035 1036 0
1038 91a 1082 eb
:3 0 21 :3 0 e9
:3 0 103b 103c 0
ea :3 0 103d 103e
0 1078 ad :3 0
ae :3 0 1040 1041
0 ad :3 0 bd
:3 0 1043 1044 0
ec :2 0 2 :4 0
163 :2 0 bf :2 0
46 :2 0 91d 1049
104b :3 0 920 1045
104d 1042 104f 104e
:2 0 b0 :3 0 c0
:3 0 1051 1052 0
b2 :4 0 164 :4 0
b5 :2 0 b6 :3 0
924 1056 1058 :3 0
b5 :2 0 c9 :4 0
927 105a 105c :3 0
b5 :2 0 ef :4 0
92a 105e 1060 :3 0
b5 :2 0 ea :3 0
92d 1062 1064 :3 0
b5 :2 0 f0 :4 0
930 1066 1068 :3 0
b5 :2 0 f1 :3 0
f2 :3 0 46 :2 0
f3 :2 0 933 106b
106f 937 106a 1071
:3 0 93a 1053 1073
:2 0 1075 93d 1076
1050 1075 0 1077
93f 0 1078 941
107b :3 0 107b 0
107b 107a 1078 1079
:6 0 107d 14 :3 0
944 107f 946 107e
107d :2 0 1080 948
:2 0 1082 0 1082
1081 1038 1080 :6 0
11af 1 :3 0 21
:3 0 e9 :3 0 1084
1085 0 21 :3 0
d2 :2 0 165 :3 0
1087 1089 0 94c
1088 108b :3 0 108c
:2 0 ad :3 0 ae
:3 0 108e 108f 0
ad :3 0 bd :3 0
1091 1092 0 24
:2 0 2 :4 0 166
:2 0 bf :2 0 46
:2 0 94f 1097 1099
:3 0 952 1093 109b
1090 109d 109c :2 0
b0 :3 0 c0 :3 0
109f 10a0 0 b2
:4 0 167 :4 0 b5
:2 0 b6 :3 0 956
10a4 10a6 :3 0 b5
:2 0 c9 :4 0 959
10a8 10aa :3 0 b5
:2 0 ca :4 0 95c
10ac 10ae :3 0 b5
:2 0 a1 :3 0 ba
:3 0 c2 :3 0 140
:3 0 10b3 10b4 0
95f 10b2 10b6 bb
:4 0 961 10b1 10b9
964 10b0 10bb :3 0
b5 :2 0 115 :4 0
967 10bd 10bf :3 0
b5 :2 0 b8 :4 0
96a 10c1 10c3 :3 0
b5 :2 0 39 :3 0
96d 10c5 10c7 :3 0
b5 :2 0 b8 :4 0
970 10c9 10cb :3 0
973 10a1 10cd :2 0
10cf 976 10d0 109e
10cf 0 10d1 978
0 10fc ad :3 0
ae :3 0 10d2 10d3
0 ad :3 0 bd
:3 0 10d5 10d6 0
46 :2 0 2 :4 0
168 :2 0 bf :2 0
46 :2 0 97a 10db
10dd :3 0 97d 10d7
10df 10d4 10e1 10e0
:2 0 b0 :3 0 c0
:3 0 10e3 10e4 0
b2 :4 0 169 :4 0
b5 :2 0 b6 :3 0
981 10e8 10ea :3 0
984 10e5 10ec :2 0
10ee 987 10ef 10e2
10ee 0 10f0 989
0 10fc ce :3 0
118 :3 0 10f1 10f2
0 c2 :3 0 140
:3 0 10f4 10f5 0
39 :3 0 d0 :3 0
98b 10f3 10f9 :2 0
10fc d9 :3 0 98f
11ad 21 :3 0 e9
:3 0 10fd 10fe 0
21 :3 0 d2 :2 0
f4 :3 0 1100 1102
0 995 1101 1104
:3 0 1105 :2 0 f1
:3 0 70 :3 0 46
:2 0 46 :2 0 998
1107 110b d2 :2 0
4d :4 0 99e 110d
110f :3 0 a1 :3 0
6e :3 0 4d :2 0
9a1 1111 1114 104
:2 0 4d :2 0 9a6
1116 1118 :3 0 a1
:3 0 6c :3 0 4d
:2 0 9a9 111a 111d
a1 :3 0 104 :2 0
6e :3 0 4d :2 0
9ac 111f 1123 9b1
1120 1125 :3 0 1119
1127 1126 :2 0 1128
:2 0 1110 112a 1129
:2 0 a1 :3 0 6c
:3 0 4d :2 0 9b4
112c 112f a1 :3 0
f5 :2 0 6d :3 0
4d :2 0 9b7 1131
1135 9bc 1132 1137
:3 0 112b 1139 1138
:2 0 ad :3 0 ae
:3 0 113b 113c 0
ad :3 0 bd :3 0
113e 113f 0 24
:2 0 2 :4 0 16a
:2 0 bf :2 0 46
:2 0 9bf 1144 1146
:3 0 9c2 1140 1148
113d 114a 1149 :2 0
b0 :3 0 c0 :3 0
114c 114d 0 b2
:4 0 16b :4 0 b5
:2 0 b6 :3 0 9c6
1151 1153 :3 0 b5
:2 0 c9 :4 0 9c9
1155 1157 :3 0 b5
:2 0 ca :4 0 9cc
1159 115b :3 0 b5
:2 0 a1 :3 0 ba
:3 0 c2 :3 0 16c
:3 0 1160 1161 0
9cf 115f 1163 bb
:4 0 9d1 115e 1166
9d4 115d 1168 :3 0
b5 :2 0 115 :4 0
9d7 116a 116c :3 0
b5 :2 0 b8 :4 0
9da 116e 1170 :3 0
b5 :2 0 39 :3 0
9dd 1172 1174 :3 0
b5 :2 0 b8 :4 0
9e0 1176 1178 :3 0
9e3 114e 117a :2 0
117c 9e6 117d 114b
117c 0 117e 9e8
0 11a8 ad :3 0
ae :3 0 117f 1180
0 ad :3 0 bd
:3 0 1182 1183 0
46 :2 0 2 :4 0
16d :2 0 bf :2 0
46 :2 0 9ea 1188
118a :3 0 9ed 1184
118c 1181 118e 118d
:2 0 b0 :3 0 c0
:3 0 1190 1191 0
b2 :4 0 16e :4 0
b5 :2 0 b6 :3 0
9f1 1195 1197 :3 0
9f4 1192 1199 :2 0
119b 9f7 119c 118f
119b 0 119d 9f9
0 11a8 ce :3 0
118 :3 0 119e 119f
0 c2 :3 0 16c
:3 0 11a1 11a2 0
39 :3 0 d0 :3 0
9fb 11a0 11a6 :2 0
11a8 9ff 11a9 113a
11a8 0 11aa a03
0 11ab a05 11ac
1106 11ab 0 11ae
108d 10fc 0 11ae
a07 0 11af a0a
11b0 101c 11af 0
11b1 a0d 0 11b2
a0f 11b3 928 11b2
0 11b4 a1c 0
3423 a1 :3 0 4f
:3 0 4d :2 0 a1e
11b5 11b8 d2 :2 0
4d :2 0 a23 11ba
11bc :3 0 a1 :3 0
5b :3 0 4d :2 0
a26 11be 11c1 c2
:3 0 d2 :2 0 d3
:3 0 11c3 11c5 0
a2b 11c4 11c7 :3 0
16 :3 0 c5 :2 0
a2e 11ca 11cb :3 0
11cc :2 0 11c8 11ce
11cd :2 0 a1 :3 0
6a :3 0 4d :2 0
a30 11d0 11d3 d2
:2 0 4d :2 0 a35
11d5 11d7 :3 0 11cf
11d9 11d8 :2 0 ad
:3 0 ae :3 0 11db
11dc 0 ad :3 0
bd :3 0 11de 11df
0 24 :2 0 2
:4 0 16f :2 0 bf
:2 0 46 :2 0 a38
11e4 11e6 :3 0 a3b
11e0 11e8 11dd 11ea
11e9 :2 0 b0 :3 0
c0 :3 0 11ec 11ed
0 b2 :4 0 170
:4 0 b5 :2 0 b6
:3 0 a3f 11f1 11f3
:3 0 b5 :2 0 c9
:4 0 a42 11f5 11f7
:3 0 b5 :2 0 ca
:4 0 a45 11f9 11fb
:3 0 b5 :2 0 a1
:3 0 ba :3 0 c2
:3 0 171 :3 0 1200
1201 0 a48 11ff
1203 bb :4 0 a4a
11fe 1206 a4d 11fd
1208 :3 0 b5 :2 0
115 :4 0 a50 120a
120c :3 0 b5 :2 0
b8 :4 0 a53 120e
1210 :3 0 b5 :2 0
25 :3 0 a56 1212
1214 :3 0 b5 :2 0
b8 :4 0 a59 1216
1218 :3 0 a5c 11ee
121a :2 0 121c a5f
121d 11eb 121c 0
121e a61 0 1248
ad :3 0 ae :3 0
121f 1220 0 ad
:3 0 bd :3 0 1222
1223 0 46 :2 0
2 :4 0 172 :2 0
bf :2 0 46 :2 0
a63 1228 122a :3 0
a66 1224 122c 1221
122e 122d :2 0 b0
:3 0 c0 :3 0 1230
1231 0 b2 :4 0
173 :4 0 b5 :2 0
b6 :3 0 a6a 1235
1237 :3 0 a6d 1232
1239 :2 0 123b a70
123c 122f 123b 0
123d a72 0 1248
ce :3 0 118 :3 0
123e 123f 0 c2
:3 0 171 :3 0 1241
1242 0 25 :3 0
d0 :3 0 a74 1240
1246 :2 0 1248 a78
1249 11da 1248 0
124a a7c 0 1394
a1 :3 0 4c :3 0
4d :2 0 a7e 124b
124e c2 :3 0 c3
:2 0 c4 :3 0 1250
1252 0 a83 1251
1254 :3 0 130 :3 0
a1 :3 0 12e :3 0
a1 :3 0 12f :3 0
63 :3 0 5e :3 0
5f :3 0 10b :3 0
10c :3 0 25 :4 0
174 1 :8 0 1267
21 :3 0 e9 :3 0
1262 1263 0 ea
:3 0 1264 1265 0
1267 a86 12b1 eb
:3 0 21 :3 0 e9
:3 0 126a 126b 0
ea :3 0 126c 126d
0 12a7 ad :3 0
ae :3 0 126f 1270
0 ad :3 0 bd
:3 0 1272 1273 0
ec :2 0 2 :4 0
175 :2 0 bf :2 0
46 :2 0 a89 1278
127a :3 0 a8c 1274
127c 1271 127e 127d
:2 0 b0 :3 0 c0
:3 0 1280 1281 0
b2 :4 0 176 :4 0
b5 :2 0 b6 :3 0
a90 1285 1287 :3 0
b5 :2 0 c9 :4 0
a93 1289 128b :3 0
b5 :2 0 ef :4 0
a96 128d 128f :3 0
b5 :2 0 ea :3 0
a99 1291 1293 :3 0
b5 :2 0 f0 :4 0
a9c 1295 1297 :3 0
b5 :2 0 f1 :3 0
f2 :3 0 46 :2 0
f3 :2 0 a9f 129a
129e aa3 1299 12a0
:3 0 aa6 1282 12a2
:2 0 12a4 aa9 12a5
127f 12a4 0 12a6
aab 0 12a7 aad
12aa :3 0 12aa 0
12aa 12a9 12a7 12a8
:6 0 12ac 16 :3 0
ab0 12ae ab2 12ad
12ac :2 0 12af ab4
:2 0 12b1 0 12b1
12b0 1267 12af :6 0
1391 1 :3 0 21
:3 0 e9 :3 0 12b3
12b4 0 21 :3 0
d2 :2 0 165 :3 0
12b6 12b8 0 ab8
12b7 12ba :3 0 12bb
:2 0 5e :3 0 5f
:3 0 177 :3 0 10c
:3 0 25 :4 0 178
1 :8 0 12c8 21
:3 0 e9 :3 0 12c3
12c4 0 ea :3 0
12c5 12c6 0 12c8
abb 1312 eb :3 0
21 :3 0 e9 :3 0
12cb 12cc 0 ea
:3 0 12cd 12ce 0
1308 ad :3 0 ae
:3 0 12d0 12d1 0
ad :3 0 bd :3 0
12d3 12d4 0 ec
:2 0 2 :4 0 179
:2 0 bf :2 0 46
:2 0 abe 12d9 12db
:3 0 ac1 12d5 12dd
12d2 12df 12de :2 0
b0 :3 0 c0 :3 0
12e1 12e2 0 b2
:4 0 17a :4 0 b5
:2 0 b6 :3 0 ac5
12e6 12e8 :3 0 b5
:2 0 c9 :4 0 ac8
12ea 12ec :3 0 b5
:2 0 ef :4 0 acb
12ee 12f0 :3 0 b5
:2 0 ea :3 0 ace
12f2 12f4 :3 0 b5
:2 0 f0 :4 0 ad1
12f6 12f8 :3 0 b5
:2 0 f1 :3 0 f2
:3 0 46 :2 0 f3
:2 0 ad4 12fb 12ff
ad8 12fa 1301 :3 0
adb 12e3 1303 :2 0
1305 ade 1306 12e0
1305 0 1307 ae0
0 1308 ae2 130b
:3 0 130b 0 130b
130a 1308 1309 :6 0
130d 18 :3 0 ae5
130f ae7 130e 130d
:2 0 1310 ae9 :2 0
1312 0 1312 1311
12c8 1310 :6 0 138e
1 :3 0 21 :3 0
e9 :3 0 1314 1315
0 21 :3 0 d2
:2 0 165 :3 0 1317
1319 0 aed 1318
131b :3 0 131c :2 0
ad :3 0 ae :3 0
131e 131f 0 ad
:3 0 bd :3 0 1321
1322 0 24 :2 0
2 :4 0 17b :2 0
bf :2 0 46 :2 0
af0 1327 1329 :3 0
af3 1323 132b 1320
132d 132c :2 0 b0
:3 0 c0 :3 0 132f
1330 0 b2 :4 0
17c :4 0 b5 :2 0
b6 :3 0 af7 1334
1336 :3 0 b5 :2 0
c9 :4 0 afa 1338
133a :3 0 b5 :2 0
ca :4 0 afd 133c
133e :3 0 b5 :2 0
a1 :3 0 ba :3 0
c2 :3 0 d6 :3 0
1343 1344 0 b00
1342 1346 bb :4 0
b02 1341 1349 b05
1340 134b :3 0 b5
:2 0 115 :4 0 b08
134d 134f :3 0 b5
:2 0 b8 :4 0 b0b
1351 1353 :3 0 b5
:2 0 25 :3 0 b0e
1355 1357 :3 0 b5
:2 0 b8 :4 0 b11
1359 135b :3 0 b14
1331 135d :2 0 135f
b17 1360 132e 135f
0 1361 b19 0
138b ad :3 0 ae
:3 0 1362 1363 0
ad :3 0 bd :3 0
1365 1366 0 46
:2 0 2 :4 0 17d
:2 0 bf :2 0 46
:2 0 b1b 136b 136d
:3 0 b1e 1367 136f
1364 1371 1370 :2 0
b0 :3 0 c0 :3 0
1373 1374 0 b2
:4 0 17e :4 0 b5
:2 0 b6 :3 0 b22
1378 137a :3 0 b25
1375 137c :2 0 137e
b28 137f 1372 137e
0 1380 b2a 0
138b ce :3 0 118
:3 0 1381 1382 0
c2 :3 0 d6 :3 0
1384 1385 0 25
:3 0 d0 :3 0 b2c
1383 1389 :2 0 138b
b30 138c 131d 138b
0 138d b34 0
138e b36 138f 12bc
138e 0 1390 b39
0 1391 b3b 1392
1255 1391 0 1393
b3e 0 1394 b40
1395 11bd 1394 0
1396 b43 0 3423
a1 :3 0 d :3 0
4d :2 0 b45 1397
139a d2 :2 0 4d
:2 0 b4a 139c 139e
:3 0 a1 :3 0 5a
:3 0 4d :2 0 b4d
13a0 13a3 c3 :2 0
17f :2 0 b52 13a5
13a7 :3 0 139f 13a9
13a8 :2 0 56 :3 0
4d :2 0 13ab 13ac
0 13ae b55 13af
13aa 13ae 0 13b0
b57 0 3423 a1
:3 0 4c :3 0 4d
:2 0 b59 13b1 13b4
c2 :3 0 d2 :2 0
c4 :3 0 13b6 13b8
0 b5e 13b7 13ba
:3 0 5 :3 0 c5
:2 0 b61 13bd 13be
:3 0 13bf :2 0 41
:3 0 180 :4 0 13c1
13c2 0 13c7 42
:3 0 180 :4 0 13c4
13c5 0 13c7 b63
13cf 41 :3 0 5
:3 0 13c8 13c9 0
13ce 42 :3 0 5
:3 0 13cb 13cc 0
13ce b66 13d0 13c0
13c7 0 13d1 0
13ce 0 13d1 b69
0 13d5 58 :3 0
4d :2 0 13d2 13d3
0 13d5 b6c 156b
89 :3 0 d2 :2 0
4d :2 0 b71 13d7
13d9 :3 0 42 :3 0
181 :4 0 13db 13dc
0 14f3 82 :3 0
182 :3 0 41 :3 0
42 :3 0 a1 :3 0
59 :3 0 4d :2 0
b74 13e2 13e5 a1
:3 0 5a :3 0 4d
:2 0 b77 13e7 13ea
a1 :3 0 5b :3 0
4d :2 0 b7a 13ec
13ef a1 :3 0 4c
:3 0 4d :2 0 b7d
13f1 13f4 a1 :3 0
5c :3 0 4d :2 0
b80 13f6 13f9 a1
:3 0 57 :3 0 4d
:2 0 b83 13fb 13fe
a1 :3 0 5e :3 0
4d :2 0 b86 1400
1403 a1 :3 0 5f
:3 0 4d :2 0 b89
1405 1408 56 :3 0
58 :3 0 60 :3 0
b8c 13df 140d 13de
140e 0 14f3 a1
:3 0 82 :3 0 4d
:2 0 b9a 1410 1413
c2 :3 0 d2 :2 0
d6 :3 0 1415 1417
0 b9f 1416 1419
:3 0 ad :3 0 ae
:3 0 141b 141c 0
ad :3 0 bd :3 0
141e 141f 0 c6
:2 0 2 :4 0 183
:2 0 bf :2 0 46
:2 0 ba2 1424 1426
:3 0 ba5 1420 1428
141d 142a 1429 :2 0
b0 :3 0 c0 :3 0
142c 142d 0 b2
:4 0 184 :4 0 b5
:2 0 b6 :3 0 ba9
1431 1433 :3 0 b5
:2 0 c9 :4 0 bac
1435 1437 :3 0 b5
:2 0 ca :4 0 baf
1439 143b :3 0 b5
:2 0 a1 :3 0 ba
:3 0 c2 :3 0 d6
:3 0 1440 1441 0
bb2 143f 1443 bb
:4 0 bb4 143e 1446
bb7 143d 1448 :3 0
bba 142e 144a :2 0
144c bbd 144d 142b
144c 0 144e bbf
0 1478 ad :3 0
ae :3 0 144f 1450
0 ad :3 0 bd
:3 0 1452 1453 0
46 :2 0 2 :4 0
185 :2 0 bf :2 0
46 :2 0 bc1 1458
145a :3 0 bc4 1454
145c 1451 145e 145d
:2 0 b0 :3 0 c0
:3 0 1460 1461 0
b2 :4 0 186 :4 0
b5 :2 0 b6 :3 0
bc8 1465 1467 :3 0
bcb 1462 1469 :2 0
146b bce 146c 145f
146b 0 146d bd0
0 1478 ce :3 0
cf :3 0 146e 146f
0 c2 :3 0 d6
:3 0 1471 1472 0
d0 :3 0 bd2 1470
1475 :2 0 1478 d9
:3 0 bd5 14f1 a1
:3 0 82 :3 0 4d
:2 0 bd9 1479 147c
c3 :2 0 4d :2 0
bde 147e 1480 :3 0
ad :3 0 ae :3 0
1482 1483 0 ad
:3 0 bd :3 0 1485
1486 0 24 :2 0
2 :4 0 187 :2 0
bf :2 0 46 :2 0
be1 148b 148d :3 0
be4 1487 148f 1484
1491 1490 :2 0 b0
:3 0 c0 :3 0 1493
1494 0 b2 :4 0
188 :4 0 b5 :2 0
b6 :3 0 be8 1498
149a :3 0 b5 :2 0
c9 :4 0 beb 149c
149e :3 0 b5 :2 0
ca :4 0 bee 14a0
14a2 :3 0 b5 :2 0
a1 :3 0 ba :3 0
82 :3 0 bf1 14a6
14a8 bb :4 0 bf3
14a5 14ab bf6 14a4
14ad :3 0 b5 :2 0
115 :4 0 bf9 14af
14b1 :3 0 b5 :2 0
b8 :4 0 bfc 14b3
14b5 :3 0 b5 :2 0
25 :3 0 bff 14b7
14b9 :3 0 b5 :2 0
b8 :4 0 c02 14bb
14bd :3 0 c05 1495
14bf :2 0 14c1 c08
14c2 1492 14c1 0
14c3 c0a 0 14ef
ad :3 0 ae :3 0
14c4 14c5 0 ad
:3 0 bd :3 0 14c7
14c8 0 46 :2 0
2 :4 0 189 :2 0
bf :2 0 46 :2 0
c0c 14cd 14cf :3 0
c0f 14c9 14d1 14c6
14d3 14d2 :2 0 b0
:3 0 c0 :3 0 14d5
14d6 0 b2 :4 0
18a :4 0 b5 :2 0
b6 :3 0 c13 14da
14dc :3 0 c16 14d7
14de :2 0 14e0 c19
14e1 14d4 14e0 0
14e2 c1b 0 14ef
ce :3 0 118 :3 0
14e3 14e4 0 a1
:3 0 82 :3 0 4d
:2 0 c1d 14e6 14e9
25 :3 0 d0 :3 0
c20 14e5 14ed :2 0
14ef c24 14f0 1481
14ef 0 14f2 141a
1478 0 14f2 c28
0 14f3 c2b 14f8
42 :3 0 6 :3 0
14f4 14f5 0 14f7
c2f 14f9 13da 14f3
0 14fa 0 14f7
0 14fa c31 0
156a a1 :3 0 56
:3 0 4d :2 0 c34
14fb 14fe 104 :2 0
4d :2 0 c39 1500
1502 :3 0 1503 :2 0
a1 :3 0 5a :3 0
4d :2 0 c3c 1505
1508 c3 :2 0 17f
:2 0 c41 150a 150c
:3 0 150d :2 0 1504
150f 150e :2 0 a1
:3 0 5a :3 0 4d
:2 0 c44 1511 1514
d2 :2 0 46 :2 0
c49 1516 1518 :3 0
1519 :2 0 a1 :3 0
5a :3 0 4d :2 0
c4c 151b 151e d2
:2 0 18b :2 0 c51
1520 1522 :3 0 1523
:2 0 151a 1525 1524
:2 0 59 :3 0 18b
:2 0 1527 1528 0
152b d9 :3 0 c54
1565 a1 :3 0 5a
:3 0 4d :2 0 c56
152c 152f d2 :2 0
4d :2 0 c5b 1531
1533 :3 0 59 :3 0
46 :2 0 1535 1536
0 1539 d9 :3 0
c5e 153a 1534 1539
0 1566 a1 :3 0
5a :3 0 4d :2 0
c60 153b 153e d2
:2 0 18c :2 0 c65
1540 1542 :3 0 1543
:2 0 a1 :3 0 5a
:3 0 4d :2 0 c68
1545 1548 d2 :2 0
18d :2 0 c6d 154a
154c :3 0 154d :2 0
1544 154f 154e :2 0
59 :3 0 46 :2 0
1551 1552 0 1555
d9 :3 0 c70 1556
1550 1555 0 1566
a1 :3 0 5a :3 0
4d :2 0 c72 1557
155a d2 :2 0 de
:2 0 c77 155c 155e
:3 0 59 :3 0 18c
:2 0 1560 1561 0
1563 c7a 1564 155f
1563 0 1566 1526
152b 0 1566 c7c
0 1567 c81 1568
1510 1567 0 1569
c83 0 156a c85
156c 13bb 13d5 0
156d 0 156a 0
156d c88 0 3423
a1 :3 0 5b :3 0
4d :2 0 c8b 156e
1571 c2 :3 0 d2
:2 0 d3 :3 0 1573
1575 0 c90 1574
1577 :3 0 8d :3 0
4d :2 0 1579 157a
0 1a10 2e :3 0
16 :3 0 157c 157d
0 1a10 30 :3 0
17 :3 0 157f 1580
0 1a10 48 :3 0
f1 :3 0 2e :3 0
46 :2 0 24 :2 0
c93 1583 1587 1582
1588 0 1a10 4b
:4 0 158a 158b 0
1a10 a1 :3 0 6a
:3 0 4d :2 0 c97
158d 1590 d2 :2 0
4d :2 0 c9c 1592
1594 :3 0 39 :3 0
18e :4 0 1597 1598
:3 0 1596 1599 0
159e 8d :3 0 46
:2 0 159b 159c 0
159e c9f 1682 10a
:3 0 4b :3 0 18f
:3 0 190 :3 0 39
:4 0 191 1 :8 0
15aa 21 :3 0 e9
:3 0 15a5 15a6 0
ea :3 0 15a7 15a8
0 15aa ca2 15f4
eb :3 0 21 :3 0
e9 :3 0 15ad 15ae
0 ea :3 0 15af
15b0 0 15ea ad
:3 0 ae :3 0 15b2
15b3 0 ad :3 0
bd :3 0 15b5 15b6
0 ec :2 0 2
:4 0 192 :2 0 bf
:2 0 46 :2 0 ca5
15bb 15bd :3 0 ca8
15b7 15bf 15b4 15c1
15c0 :2 0 b0 :3 0
c0 :3 0 15c3 15c4
0 b2 :4 0 193
:4 0 b5 :2 0 b6
:3 0 cac 15c8 15ca
:3 0 b5 :2 0 c9
:4 0 caf 15cc 15ce
:3 0 b5 :2 0 ef
:4 0 cb2 15d0 15d2
:3 0 b5 :2 0 ea
:3 0 cb5 15d4 15d6
:3 0 b5 :2 0 f0
:4 0 cb8 15d8 15da
:3 0 b5 :2 0 f1
:3 0 f2 :3 0 46
:2 0 f3 :2 0 cbb
15dd 15e1 cbf 15dc
15e3 :3 0 cc2 15c5
15e5 :2 0 15e7 cc5
15e8 15c2 15e7 0
15e9 cc7 0 15ea
cc9 15ed :3 0 15ed
0 15ed 15ec 15ea
15eb :6 0 15ef 1a
:3 0 ccc 15f1 cce
15f0 15ef :2 0 15f2
cd0 :2 0 15f4 0
15f4 15f3 15aa 15f2
:6 0 1681 1 :3 0
21 :3 0 e9 :3 0
15f6 15f7 0 21
:3 0 d2 :2 0 f4
:3 0 15f9 15fb 0
cd4 15fa 15fd :3 0
15fe :2 0 a1 :3 0
4f :3 0 4d :2 0
cd7 1600 1603 104
:2 0 4d :2 0 cdc
1605 1607 :3 0 194
:3 0 28 :3 0 195
:3 0 10c :3 0 26
:3 0 9a :3 0 39
:3 0 196 :3 0 197
:3 0 c2 :3 0 198
:4 0 199 1 :8 0
161a 21 :3 0 e9
:3 0 1615 1616 0
ea :3 0 1617 1618
0 161a cdf 1664
eb :3 0 21 :3 0
e9 :3 0 161d 161e
0 ea :3 0 161f
1620 0 165a ad
:3 0 ae :3 0 1622
1623 0 ad :3 0
bd :3 0 1625 1626
0 ec :2 0 2
:4 0 19a :2 0 bf
:2 0 46 :2 0 ce2
162b 162d :3 0 ce5
1627 162f 1624 1631
1630 :2 0 b0 :3 0
c0 :3 0 1633 1634
0 b2 :4 0 19b
:4 0 b5 :2 0 b6
:3 0 ce9 1638 163a
:3 0 b5 :2 0 c9
:4 0 cec 163c 163e
:3 0 b5 :2 0 ef
:4 0 cef 1640 1642
:3 0 b5 :2 0 ea
:3 0 cf2 1644 1646
:3 0 b5 :2 0 f0
:4 0 cf5 1648 164a
:3 0 b5 :2 0 f1
:3 0 f2 :3 0 46
:2 0 f3 :2 0 cf8
164d 1651 cfc 164c
1653 :3 0 cff 1635
1655 :2 0 1657 d02
1658 1632 1657 0
1659 d04 0 165a
d06 165d :3 0 165d
0 165d 165c 165a
165b :6 0 165f 1c
:3 0 d09 1661 d0b
1660 165f :2 0 1662
d0d :2 0 1664 0
1664 1663 161a 1662
:6 0 1676 1 :3 0
21 :3 0 e9 :3 0
1666 1667 0 21
:3 0 d2 :2 0 f4
:3 0 1669 166b 0
d11 166a 166d :3 0
166e :2 0 8d :3 0
46 :2 0 1670 1671
0 1673 d14 1674
166f 1673 0 1675
d16 0 1676 d18
1677 1608 1676 0
1678 d1b 0 1679
d1d 167e 8d :3 0
46 :2 0 167a 167b
0 167d d1f 167f
15ff 1679 0 1680
0 167d 0 1680
d21 0 1681 d24
1683 1595 159e 0
1684 0 1681 0
1684 d27 0 1a10
8d :3 0 c3 :2 0
4d :2 0 d2c 1686
1688 :3 0 a1 :3 0
19c :3 0 19d :3 0
62 :3 0 18f :3 0
98 :3 0 25 :3 0
a0 :3 0 48 :4 0
19e 1 :8 0 1699
21 :3 0 e9 :3 0
1694 1695 0 ea
:3 0 1696 1697 0
1699 d2f 16e3 eb
:3 0 21 :3 0 e9
:3 0 169c 169d 0
ea :3 0 169e 169f
0 16d9 ad :3 0
ae :3 0 16a1 16a2
0 ad :3 0 bd
:3 0 16a4 16a5 0
ec :2 0 2 :4 0
19f :2 0 bf :2 0
46 :2 0 d32 16aa
16ac :3 0 d35 16a6
16ae 16a3 16b0 16af
:2 0 b0 :3 0 c0
:3 0 16b2 16b3 0
b2 :4 0 1a0 :4 0
b5 :2 0 b6 :3 0
d39 16b7 16b9 :3 0
b5 :2 0 c9 :4 0
d3c 16bb 16bd :3 0
b5 :2 0 ef :4 0
d3f 16bf 16c1 :3 0
b5 :2 0 ea :3 0
d42 16c3 16c5 :3 0
b5 :2 0 f0 :4 0
d45 16c7 16c9 :3 0
b5 :2 0 f1 :3 0
f2 :3 0 46 :2 0
f3 :2 0 d48 16cc
16d0 d4c 16cb 16d2
:3 0 d4f 16b4 16d4
:2 0 16d6 d52 16d7
16b1 16d6 0 16d8
d54 0 16d9 d56
16dc :3 0 16dc 0
16dc 16db 16d9 16da
:6 0 16de 1e :3 0
d59 16e0 d5b 16df
16de :2 0 16e1 d5d
:2 0 16e3 0 16e3
16e2 1699 16e1 :6 0
1857 1 :3 0 e5
:3 0 1a1 :3 0 e5
:3 0 1a1 :3 0 e5
:3 0 1a1 :3 0 e5
:3 0 1a1 :3 0 e5
:3 0 1a1 :3 0 9f
:3 0 1a2 :3 0 1a3
:3 0 9f :3 0 1a4
:3 0 1a3 :3 0 9f
:3 0 ba :3 0 62
:3 0 4a :3 0 1a5
:3 0 1a4 :3 0 1a5
:3 0 1a2 :3 0 1a4
:3 0 10c :3 0 48
:3 0 1a2 :3 0 10c
:3 0 1a4 :3 0 1a6
:4 0 1a7 1 :8 0
170a 21 :3 0 e9
:3 0 1705 1706 0
ea :3 0 1707 1708
0 170a d5f 1754
eb :3 0 21 :3 0
e9 :3 0 170d 170e
0 ea :3 0 170f
1710 0 174a ad
:3 0 ae :3 0 1712
1713 0 ad :3 0
bd :3 0 1715 1716
0 ec :2 0 2
:4 0 1a8 :2 0 bf
:2 0 46 :2 0 d62
171b 171d :3 0 d65
1717 171f 1714 1721
1720 :2 0 b0 :3 0
c0 :3 0 1723 1724
0 b2 :4 0 1a9
:4 0 b5 :2 0 b6
:3 0 d69 1728 172a
:3 0 b5 :2 0 c9
:4 0 d6c 172c 172e
:3 0 b5 :2 0 ef
:4 0 d6f 1730 1732
:3 0 b5 :2 0 ea
:3 0 d72 1734 1736
:3 0 b5 :2 0 f0
:4 0 d75 1738 173a
:3 0 b5 :2 0 f1
:3 0 f2 :3 0 46
:2 0 f3 :2 0 d78
173d 1741 d7c 173c
1743 :3 0 d7f 1725
1745 :2 0 1747 d82
1748 1722 1747 0
1749 d84 0 174a
d86 174d :3 0 174d
0 174d 174c 174a
174b :6 0 174f 20
:3 0 d89 1751 d8b
1750 174f :2 0 1752
d8d :2 0 1754 0
1754 1753 170a 1752
:6 0 1857 1 :3 0
21 :3 0 e9 :3 0
1756 1757 0 21
:3 0 d2 :2 0 165
:3 0 1759 175b 0
d91 175a 175d :3 0
175e :2 0 ad :3 0
ae :3 0 1760 1761
0 ad :3 0 bd
:3 0 1763 1764 0
24 :2 0 2 :4 0
1aa :2 0 bf :2 0
46 :2 0 d94 1769
176b :3 0 d97 1765
176d 1762 176f 176e
:2 0 b0 :3 0 c0
:3 0 1771 1772 0
b2 :4 0 1ab :4 0
b5 :2 0 b6 :3 0
d9b 1776 1778 :3 0
b5 :2 0 c9 :4 0
d9e 177a 177c :3 0
b5 :2 0 ca :4 0
da1 177e 1780 :3 0
b5 :2 0 a1 :3 0
ba :3 0 c2 :3 0
140 :3 0 1785 1786
0 da4 1784 1788
bb :4 0 da6 1783
178b da9 1782 178d
:3 0 b5 :2 0 115
:4 0 dac 178f 1791
:3 0 b5 :2 0 b8
:4 0 daf 1793 1795
:3 0 b5 :2 0 48
:3 0 db2 1797 1799
:3 0 b5 :2 0 b8
:4 0 db5 179b 179d
:3 0 db8 1773 179f
:2 0 17a1 dbb 17a2
1770 17a1 0 17a3
dbd 0 17cd ad
:3 0 ae :3 0 17a4
17a5 0 ad :3 0
bd :3 0 17a7 17a8
0 46 :2 0 2
:4 0 1ac :2 0 bf
:2 0 46 :2 0 dbf
17ad 17af :3 0 dc2
17a9 17b1 17a6 17b3
17b2 :2 0 b0 :3 0
c0 :3 0 17b5 17b6
0 b2 :4 0 1ad
:4 0 b5 :2 0 b6
:3 0 dc6 17ba 17bc
:3 0 dc9 17b7 17be
:2 0 17c0 dcc 17c1
17b4 17c0 0 17c2
dce 0 17cd ce
:3 0 118 :3 0 17c3
17c4 0 c2 :3 0
140 :3 0 17c6 17c7
0 48 :3 0 d0
:3 0 dd0 17c5 17cb
:2 0 17cd dd4 17ce
175f 17cd 0 17cf
dd8 0 1857 81
:3 0 a1 :3 0 4f
:3 0 4d :2 0 dda
17d1 17d4 104 :2 0
4d :2 0 ddf 17d6
17d8 :3 0 1ae :4 0
de2 17db 17da 1af
:5 0 17dd 0 de4
:2 0 17d0 17df 0
1857 18f :3 0 190
:3 0 98 :3 0 a0
:3 0 19d :3 0 1b0
:3 0 10a :3 0 1b1
:3 0 1b2 :3 0 1b3
:3 0 39 :3 0 25
:3 0 48 :3 0 62
:3 0 4a :3 0 81
:3 0 14 :3 0 13
:3 0 12 :4 0 1b4
1 :8 0 180a 1b5
:4 0 17f5 :3 0 d0
:3 0 d2 :2 0 de9
17f8 17f9 :3 0 21
:3 0 e9 :3 0 17fb
17fc 0 4d :2 0
17fd 17fe 0 1800
dec 1807 21 :3 0
e9 :3 0 1801 1802
0 17f :2 0 1803
1804 0 1806 dee
1808 17fa 1800 0
1809 0 1806 0
1809 df0 0 180a
df3 1854 eb :3 0
21 :3 0 e9 :3 0
180d 180e 0 ea
:3 0 180f 1810 0
184a ad :3 0 ae
:3 0 1812 1813 0
ad :3 0 bd :3 0
1815 1816 0 ec
:2 0 2 :4 0 1b6
:2 0 bf :2 0 46
:2 0 df6 181b 181d
:3 0 df9 1817 181f
1814 1821 1820 :2 0
b0 :3 0 c0 :3 0
1823 1824 0 b2
:4 0 1b7 :4 0 b5
:2 0 b6 :3 0 dfd
1828 182a :3 0 b5
:2 0 c9 :4 0 e00
182c 182e :3 0 b5
:2 0 ef :4 0 e03
1830 1832 :3 0 b5
:2 0 ea :3 0 e06
1834 1836 :3 0 b5
:2 0 f0 :4 0 e09
1838 183a :3 0 b5
:2 0 f1 :3 0 f2
:3 0 46 :2 0 f3
:2 0 e0c 183d 1841
e10 183c 1843 :3 0
e13 1825 1845 :2 0
1847 e16 1848 1822
1847 0 1849 e18
0 184a e1a 184d
:3 0 184d 0 184d
184c 184a 184b :6 0
184f 22 :3 0 e1d
1851 e1f 1850 184f
:2 0 1852 e21 :2 0
1854 0 1854 1853
180a 1852 :6 0 1857
1 :3 0 d9 :3 0
e23 18d0 f1 :3 0
4b :3 0 46 :2 0
46 :2 0 e29 1858
185c d2 :2 0 1af
:4 0 e2f 185e 1860
:3 0 18f :3 0 10a
:3 0 1b1 :3 0 14
:3 0 1b2 :3 0 13
:3 0 1b3 :3 0 12
:3 0 190 :3 0 39
:4 0 1b8 1 :8 0
1882 1b5 :4 0 186d
:3 0 d0 :3 0 d2
:2 0 e34 1870 1871
:3 0 21 :3 0 e9
:3 0 1873 1874 0
4d :2 0 1875 1876
0 1878 e37 187f
21 :3 0 e9 :3 0
1879 187a 0 17f
:2 0 187b 187c 0
187e e39 1880 1872
1878 0 1881 0
187e 0 1881 e3b
0 1882 e3e 18cc
eb :3 0 21 :3 0
e9 :3 0 1885 1886
0 ea :3 0 1887
1888 0 18c2 ad
:3 0 ae :3 0 188a
188b 0 ad :3 0
bd :3 0 188d 188e
0 ec :2 0 2
:4 0 1b9 :2 0 bf
:2 0 46 :2 0 e41
1893 1895 :3 0 e44
188f 1897 188c 1899
1898 :2 0 b0 :3 0
c0 :3 0 189b 189c
0 b2 :4 0 1ba
:4 0 b5 :2 0 b6
:3 0 e48 18a0 18a2
:3 0 b5 :2 0 c9
:4 0 e4b 18a4 18a6
:3 0 b5 :2 0 ef
:4 0 e4e 18a8 18aa
:3 0 b5 :2 0 ea
:3 0 e51 18ac 18ae
:3 0 b5 :2 0 f0
:4 0 e54 18b0 18b2
:3 0 b5 :2 0 f1
:3 0 f2 :3 0 46
:2 0 f3 :2 0 e57
18b5 18b9 e5b 18b4
18bb :3 0 e5e 189d
18bd :2 0 18bf e61
18c0 189a 18bf 0
18c1 e63 0 18c2
e65 18c5 :3 0 18c5
0 18c5 18c4 18c2
18c3 :6 0 18c7 24
:3 0 e68 18c9 e6a
18c8 18c7 :2 0 18ca
e6c :2 0 18cc 0
18cc 18cb 1882 18ca
:6 0 18ce 1 :3 0
e6e 18cf 1861 18ce
0 18d1 1689 1857
0 18d1 e70 0
1a10 1bb :3 0 194
:3 0 190 :3 0 18f
:3 0 98 :3 0 25
:3 0 10a :3 0 190
:3 0 39 :4 0 1bc
1 :8 0 18f1 1b5
:4 0 18dc :3 0 d0
:3 0 d2 :2 0 e75
18df 18e0 :3 0 21
:3 0 e9 :3 0 18e2
18e3 0 4d :2 0
18e4 18e5 0 18e7
e78 18ee 21 :3 0
e9 :3 0 18e8 18e9
0 17f :2 0 18ea
18eb 0 18ed e7a
18ef 18e1 18e7 0
18f0 0 18ed 0
18f0 e7c 0 18f1
e7f 193b eb :3 0
21 :3 0 e9 :3 0
18f4 18f5 0 ea
:3 0 18f6 18f7 0
1931 ad :3 0 ae
:3 0 18f9 18fa 0
ad :3 0 bd :3 0
18fc 18fd 0 ec
:2 0 2 :4 0 1bd
:2 0 bf :2 0 46
:2 0 e82 1902 1904
:3 0 e85 18fe 1906
18fb 1908 1907 :2 0
b0 :3 0 c0 :3 0
190a 190b 0 b2
:4 0 1be :4 0 b5
:2 0 b6 :3 0 e89
190f 1911 :3 0 b5
:2 0 c9 :4 0 e8c
1913 1915 :3 0 b5
:2 0 ef :4 0 e8f
1917 1919 :3 0 b5
:2 0 ea :3 0 e92
191b 191d :3 0 b5
:2 0 f0 :4 0 e95
191f 1921 :3 0 b5
:2 0 f1 :3 0 f2
:3 0 46 :2 0 f3
:2 0 e98 1924 1928
e9c 1923 192a :3 0
e9f 190c 192c :2 0
192e ea2 192f 1909
192e 0 1930 ea4
0 1931 ea6 1934
:3 0 1934 0 1934
1933 1931 1932 :6 0
1936 26 :3 0 ea9
1938 eab 1937 1936
:2 0 1939 ead :2 0
193b 0 193b 193a
18f1 1939 :6 0 1a10
1 :3 0 1bf :3 0
194 :3 0 190 :3 0
18f :3 0 98 :3 0
25 :3 0 10a :3 0
190 :3 0 39 :4 0
1c0 1 :8 0 195c
1b5 :4 0 1947 :3 0
d0 :3 0 d2 :2 0
eb1 194a 194b :3 0
21 :3 0 e9 :3 0
194d 194e 0 4d
:2 0 194f 1950 0
1952 eb4 1959 21
:3 0 e9 :3 0 1953
1954 0 17f :2 0
1955 1956 0 1958
eb6 195a 194c 1952
0 195b 0 1958
0 195b eb8 0
195c ebb 19a6 eb
:3 0 21 :3 0 e9
:3 0 195f 1960 0
ea :3 0 1961 1962
0 199c ad :3 0
ae :3 0 1964 1965
0 ad :3 0 bd
:3 0 1967 1968 0
ec :2 0 2 :4 0
1c1 :2 0 bf :2 0
46 :2 0 ebe 196d
196f :3 0 ec1 1969
1971 1966 1973 1972
:2 0 b0 :3 0 c0
:3 0 1975 1976 0
b2 :4 0 1c2 :4 0
b5 :2 0 b6 :3 0
ec5 197a 197c :3 0
b5 :2 0 c9 :4 0
ec8 197e 1980 :3 0
b5 :2 0 ef :4 0
ecb 1982 1984 :3 0
b5 :2 0 ea :3 0
ece 1986 1988 :3 0
b5 :2 0 f0 :4 0
ed1 198a 198c :3 0
b5 :2 0 f1 :3 0
f2 :3 0 46 :2 0
f3 :2 0 ed4 198f
1993 ed8 198e 1995
:3 0 edb 1977 1997
:2 0 1999 ede 199a
1974 1999 0 199b
ee0 0 199c ee2
199f :3 0 199f 0
199f 199e 199c 199d
:6 0 19a1 28 :3 0
ee5 19a3 ee7 19a2
19a1 :2 0 19a4 ee9
:2 0 19a6 0 19a6
19a5 195c 19a4 :6 0
1a10 1 :3 0 18f
:3 0 98 :3 0 25
:3 0 10a :3 0 190
:3 0 39 :4 0 1c3
1 :8 0 19c4 1b5
:4 0 19af :3 0 d0
:3 0 d2 :2 0 eed
19b2 19b3 :3 0 21
:3 0 e9 :3 0 19b5
19b6 0 4d :2 0
19b7 19b8 0 19ba
ef0 19c1 21 :3 0
e9 :3 0 19bb 19bc
0 17f :2 0 19bd
19be 0 19c0 ef2
19c2 19b4 19ba 0
19c3 0 19c0 0
19c3 ef4 0 19c4
ef7 1a0e eb :3 0
21 :3 0 e9 :3 0
19c7 19c8 0 ea
:3 0 19c9 19ca 0
1a04 ad :3 0 ae
:3 0 19cc 19cd 0
ad :3 0 bd :3 0
19cf 19d0 0 ec
:2 0 2 :4 0 1c4
:2 0 bf :2 0 46
:2 0 efa 19d5 19d7
:3 0 efd 19d1 19d9
19ce 19db 19da :2 0
b0 :3 0 c0 :3 0
19dd 19de 0 b2
:4 0 1c5 :4 0 b5
:2 0 b6 :3 0 f01
19e2 19e4 :3 0 b5
:2 0 c9 :4 0 f04
19e6 19e8 :3 0 b5
:2 0 ef :4 0 f07
19ea 19ec :3 0 b5
:2 0 ea :3 0 f0a
19ee 19f0 :3 0 b5
:2 0 f0 :4 0 f0d
19f2 19f4 :3 0 b5
:2 0 f1 :3 0 f2
:3 0 46 :2 0 f3
:2 0 f10 19f7 19fb
f14 19f6 19fd :3 0
f17 19df 19ff :2 0
1a01 f1a 1a02 19dc
1a01 0 1a03 f1c
0 1a04 f1e 1a07
:3 0 1a07 0 1a07
1a06 1a04 1a05 :6 0
1a09 2a :3 0 f21
1a0b f23 1a0a 1a09
:2 0 1a0c f25 :2 0
1a0e 0 1a0e 1a0d
19c4 1a0c :6 0 1a10
1 :3 0 f27 1a11
1578 1a10 0 1a12
f32 0 3423 84
:3 0 1c6 :4 0 1a14
1a15 :3 0 1a13 1a16
0 3423 a1 :3 0
4f :3 0 4d :2 0
f34 1a18 1a1b d2
:2 0 4d :2 0 f39
1a1d 1a1f :3 0 a1
:3 0 5b :3 0 4d
:2 0 f3c 1a21 1a24
c2 :3 0 c3 :2 0
d3 :3 0 1a26 1a28
0 f41 1a27 1a2a
:3 0 1a20 1a2c 1a2b
:2 0 a1 :3 0 5b
:3 0 4d :2 0 f44
1a2e 1a31 c2 :3 0
c3 :2 0 d1 :3 0
1a33 1a35 0 f49
1a34 1a37 :3 0 1a2d
1a39 1a38 :2 0 1e
:3 0 e4 :2 0 f4c
1a3c 1a3d :3 0 1a3e
:2 0 3a :3 0 1e
:3 0 1a40 1a41 0
1a43 f4e 1a44 1a3f
1a43 0 1a45 f50
0 1a46 f52 1a47
1a3a 1a46 0 1a48
f54 0 3423 a1
:3 0 55 :3 0 4d
:2 0 f56 1a49 1a4c
d2 :2 0 4d :2 0
f5b 1a4e 1a50 :3 0
55 :3 0 c2 :3 0
1c7 :3 0 1a53 1a54
0 1a52 1a55 0
1a57 f5e 1a58 1a51
1a57 0 1a59 f60
0 3423 16 :3 0
c5 :2 0 f62 1a5b
1a5c :3 0 1a5d :2 0
17 :3 0 c5 :2 0
f64 1a60 1a61 :3 0
1a62 :2 0 1a5e 1a64
1a63 :2 0 18 :3 0
c5 :2 0 f66 1a67
1a68 :3 0 1a69 :2 0
1a65 1a6b 1a6a :2 0
19 :3 0 c5 :2 0
f68 1a6e 1a6f :3 0
1a70 :2 0 1a71 :2 0
1a6c 1a73 1a72 :2 0
8b :3 0 46 :2 0
1a75 1a76 0 1a78
f6a 1a79 1a74 1a78
0 1a7a f6c 0
3423 74 :3 0 181
:4 0 1a7b 1a7c 0
3423 76 :3 0 181
:4 0 1a7e 1a7f 0
3423 a1 :3 0 4f
:3 0 4d :2 0 f6e
1a81 1a84 104 :2 0
4d :2 0 f73 1a86
1a88 :3 0 a1 :3 0
5b :3 0 4d :2 0
f76 1a8a 1a8d c2
:3 0 d2 :2 0 d3
:3 0 1a8f 1a91 0
f7b 1a90 1a93 :3 0
74 :3 0 1c8 :4 0
b5 :2 0 39 :3 0
f7e 1a97 1a99 :3 0
b5 :2 0 1c9 :4 0
f81 1a9b 1a9d :3 0
b5 :2 0 1ca :4 0
f84 1a9f 1aa1 :3 0
b5 :2 0 1cb :4 0
f87 1aa3 1aa5 :3 0
b5 :2 0 1cc :4 0
f8a 1aa7 1aa9 :3 0
b5 :2 0 48 :3 0
f8d 1aab 1aad :3 0
b5 :2 0 b8 :4 0
f90 1aaf 1ab1 :3 0
1a95 1ab2 0 1ab5
d9 :3 0 f93 1afc
a1 :3 0 5b :3 0
4d :2 0 f95 1ab6
1ab9 d2 :2 0 2d
:2 0 f9a 1abb 1abd
:3 0 74 :3 0 1cd
:4 0 b5 :2 0 1ce
:4 0 f9d 1ac1 1ac3
:3 0 b5 :2 0 1cf
:4 0 fa0 1ac5 1ac7
:3 0 b5 :2 0 25
:3 0 fa3 1ac9 1acb
:3 0 b5 :2 0 1d0
:4 0 fa6 1acd 1acf
:3 0 b5 :2 0 1d1
:4 0 fa9 1ad1 1ad3
:3 0 b5 :2 0 39
:3 0 fac 1ad5 1ad7
:3 0 b5 :2 0 1d0
:4 0 faf 1ad9 1adb
:3 0 b5 :2 0 1d2
:4 0 fb2 1add 1adf
:3 0 1abf 1ae0 0
1ae2 fb5 1ae3 1abe
1ae2 0 1afe 74
:3 0 1d3 :4 0 b5
:2 0 1d4 :4 0 fb7
1ae6 1ae8 :3 0 b5
:2 0 1d5 :4 0 fba
1aea 1aec :3 0 b5
:2 0 1d6 :4 0 fbd
1aee 1af0 :3 0 b5
:2 0 39 :3 0 fc0
1af2 1af4 :3 0 b5
:2 0 1d0 :4 0 fc3
1af6 1af8 :3 0 1ae4
1af9 0 1afb fc6
1afd 1a94 1ab5 0
1afe 0 1afb 0
1afe fc8 0 1aff
fcc 2425 a1 :3 0
5b :3 0 4d :2 0
fce 1b00 1b03 c2
:3 0 c3 :2 0 d3
:3 0 1b05 1b07 0
fd3 1b06 1b09 :3 0
a1 :3 0 5b :3 0
4d :2 0 fd6 1b0b
1b0e c2 :3 0 c3
:2 0 d1 :3 0 1b10
1b12 0 fdb 1b11
1b14 :3 0 1b0a 1b16
1b15 :2 0 a1 :3 0
a :3 0 4d :2 0
fde 1b18 1b1b c2
:3 0 c3 :2 0 c4
:3 0 1b1d 1b1f 0
fe3 1b1e 1b21 :3 0
1b17 1b23 1b22 :2 0
1d7 :3 0 1d8 :3 0
1d9 :4 0 1b27 :4 0
1b28 :2 0 1c36 21
:3 0 e9 :3 0 1b2a
1b2b 0 4d :2 0
1b2c 1b2d 0 1c36
14 :3 0 c5 :2 0
fe6 1b30 1b31 :3 0
1b32 :2 0 1d7 :3 0
1d8 :3 0 1da :4 0
1b36 :4 0 1b37 :2 0
1c2e 21 :3 0 e9
:3 0 1b39 1b3a 0
4d :2 0 1b3b 1b3c
0 1c2e 1db :3 0
10c :3 0 1dc :3 0
177 :3 0 1dd :3 0
1de :3 0 10c :3 0
1de :3 0 1dc :3 0
177 :3 0 1de :3 0
1df :3 0 195 :3 0
1e0 :3 0 1de :3 0
10c :3 0 1e0 :3 0
10c :3 0 1e0 :3 0
1e1 :3 0 1e0 :3 0
9a :3 0 29 :4 0
1e2 1 :8 0 1b6b
1b5 :4 0 1b56 :3 0
d0 :3 0 d2 :2 0
fea 1b59 1b5a :3 0
21 :3 0 e9 :3 0
1b5c 1b5d 0 4d
:2 0 1b5e 1b5f 0
1b61 fed 1b68 21
:3 0 e9 :3 0 1b62
1b63 0 17f :2 0
1b64 1b65 0 1b67
fef 1b69 1b5b 1b61
0 1b6a 0 1b67
0 1b6a ff1 0
1b6b ff4 1bb5 eb
:3 0 21 :3 0 e9
:3 0 1b6e 1b6f 0
ea :3 0 1b70 1b71
0 1bab ad :3 0
ae :3 0 1b73 1b74
0 ad :3 0 bd
:3 0 1b76 1b77 0
ec :2 0 2 :4 0
1e3 :2 0 bf :2 0
46 :2 0 ff7 1b7c
1b7e :3 0 ffa 1b78
1b80 1b75 1b82 1b81
:2 0 b0 :3 0 c0
:3 0 1b84 1b85 0
b2 :4 0 1e4 :4 0
b5 :2 0 b6 :3 0
ffe 1b89 1b8b :3 0
b5 :2 0 c9 :4 0
1001 1b8d 1b8f :3 0
b5 :2 0 ef :4 0
1004 1b91 1b93 :3 0
b5 :2 0 ea :3 0
1007 1b95 1b97 :3 0
b5 :2 0 f0 :4 0
100a 1b99 1b9b :3 0
b5 :2 0 f1 :3 0
f2 :3 0 46 :2 0
f3 :2 0 100d 1b9e
1ba2 1011 1b9d 1ba4
:3 0 1014 1b86 1ba6
:2 0 1ba8 1017 1ba9
1b83 1ba8 0 1baa
1019 0 1bab 101b
1bae :3 0 1bae 0
1bae 1bad 1bab 1bac
:6 0 1bb0 2c :3 0
101e 1bb2 1020 1bb1
1bb0 :2 0 1bb3 1022
:2 0 1bb5 0 1bb5
1bb4 1b6b 1bb3 :6 0
1c2e 1 :3 0 1e5
:3 0 1e6 :3 0 1dc
:3 0 1db :3 0 1e6
:3 0 138 :3 0 10c
:3 0 1db :3 0 138
:3 0 138 :3 0 1dc
:3 0 1e6 :3 0 1dc
:3 0 f1 :3 0 1e6
:3 0 1dc :3 0 1e7
:3 0 138 :3 0 1dc
:3 0 138 :3 0 1dc
:4 0 1e8 1 :8 0
1be2 1b5 :4 0 1bcd
:3 0 d0 :3 0 d2
:2 0 1026 1bd0 1bd1
:3 0 21 :3 0 e9
:3 0 1bd3 1bd4 0
4d :2 0 1bd5 1bd6
0 1bd8 1029 1bdf
21 :3 0 e9 :3 0
1bd9 1bda 0 17f
:2 0 1bdb 1bdc 0
1bde 102b 1be0 1bd2
1bd8 0 1be1 0
1bde 0 1be1 102d
0 1be2 1030 1c2c
eb :3 0 21 :3 0
e9 :3 0 1be5 1be6
0 ea :3 0 1be7
1be8 0 1c22 ad
:3 0 ae :3 0 1bea
1beb 0 ad :3 0
bd :3 0 1bed 1bee
0 ec :2 0 2
:4 0 1e9 :2 0 bf
:2 0 46 :2 0 1033
1bf3 1bf5 :3 0 1036
1bef 1bf7 1bec 1bf9
1bf8 :2 0 b0 :3 0
c0 :3 0 1bfb 1bfc
0 b2 :4 0 1ea
:4 0 b5 :2 0 b6
:3 0 103a 1c00 1c02
:3 0 b5 :2 0 c9
:4 0 103d 1c04 1c06
:3 0 b5 :2 0 ef
:4 0 1040 1c08 1c0a
:3 0 b5 :2 0 ea
:3 0 1043 1c0c 1c0e
:3 0 b5 :2 0 f0
:4 0 1046 1c10 1c12
:3 0 b5 :2 0 f1
:3 0 f2 :3 0 46
:2 0 f3 :2 0 1049
1c15 1c19 104d 1c14
1c1b :3 0 1050 1bfd
1c1d :2 0 1c1f 1053
1c20 1bfa 1c1f 0
1c21 1055 0 1c22
1057 1c25 :3 0 1c25
0 1c25 1c24 1c22
1c23 :6 0 1c27 2e
:3 0 105a 1c29 105c
1c28 1c27 :2 0 1c2a
105e :2 0 1c2c 0
1c2c 1c2b 1be2 1c2a
:6 0 1c2e 1 :3 0
1060 1c33 39 :3 0
14 :3 0 1c2f 1c30
0 1c32 1065 1c34
1b33 1c2e 0 1c35
0 1c32 0 1c35
1067 0 1c36 106a
1c37 1b24 1c36 0
1c38 106e 0 2424
10 :3 0 e4 :2 0
1070 1c3a 1c3b :3 0
1c3c :2 0 8e :3 0
a1 :3 0 1e7 :3 0
10 :3 0 1072 1c40
1c42 4d :2 0 1074
1c3f 1c45 104 :2 0
1eb :2 0 1079 1c47
1c49 :3 0 100 :3 0
a1 :3 0 1e7 :3 0
10 :3 0 107c 1c4d
1c4f 4d :2 0 107e
1c4c 1c52 1ec :2 0
1081 1c4b 1c55 1ed
:2 0 1ee :2 0 1084
1c57 1c59 :3 0 1087
1c5b 1c5a 100 :3 0
a1 :3 0 1e7 :3 0
10 :3 0 1089 1c5f
1c61 4d :2 0 108b
1c5e 1c64 1ec :2 0
108e 1c5d 1c67 0
1c68 0 1091 :2 0
1c3e 1c6a 0 1d6c
8f :3 0 4d :2 0
1c6c 1c6d 0 1d6c
1ef :3 0 8f :3 0
8e :3 0 f5 :2 0
1f0 :3 0 1096 1c72
1c74 :3 0 1c75 1cb1
a1 :3 0 1f1 :3 0
f1 :3 0 2a :3 0
8f :3 0 bf :2 0
46 :2 0 1099 1c7c
1c7e :3 0 46 :2 0
109c 1c79 1c81 10a0
1c78 1c83 4d :2 0
10a2 1c77 1c86 c3
:2 0 1f2 :2 0 10a7
1c88 1c8a :3 0 a1
:3 0 1f1 :3 0 f1
:3 0 2a :3 0 8f
:3 0 bf :2 0 46
:2 0 10aa 1c91 1c93
:3 0 46 :2 0 10ad
1c8e 1c96 10b1 1c8d
1c98 4d :2 0 10b3
1c8c 1c9b c3 :2 0
1f3 :2 0 10b8 1c9d
1c9f :3 0 1c8b 1ca1
1ca0 :2 0 1f4 :8 0
1ca5 10bb 1ca6 1ca2
1ca5 0 1ca7 10bd
0 1caf 8f :3 0
8f :3 0 bf :2 0
46 :2 0 10bf 1caa
1cac :3 0 1ca8 1cad
0 1caf 10c2 1cb1
1f0 :3 0 1c76 1caf
:4 0 1d6c 8f :3 0
8e :3 0 d2 :2 0
10c7 1cb4 1cb5 :3 0
ad :3 0 ae :3 0
1cb7 1cb8 0 ad
:3 0 bd :3 0 1cba
1cbb 0 c6 :2 0
2 :4 0 1f5 :2 0
bf :2 0 46 :2 0
10ca 1cc0 1cc2 :3 0
10cd 1cbc 1cc4 1cb9
1cc6 1cc5 :2 0 b0
:3 0 c0 :3 0 1cc8
1cc9 0 b2 :4 0
1f6 :4 0 b5 :2 0
b6 :3 0 10d1 1ccd
1ccf :3 0 b5 :2 0
c9 :4 0 10d4 1cd1
1cd3 :3 0 b5 :2 0
ca :4 0 10d7 1cd5
1cd7 :3 0 b5 :2 0
a1 :3 0 ba :3 0
c2 :3 0 d6 :3 0
1cdc 1cdd 0 10da
1cdb 1cdf bb :4 0
10dc 1cda 1ce2 10df
1cd9 1ce4 :3 0 10e2
1cca 1ce6 :2 0 1ce8
10e5 1ce9 1cc7 1ce8
0 1cea 10e7 0
1d13 ad :3 0 ae
:3 0 1ceb 1cec 0
ad :3 0 bd :3 0
1cee 1cef 0 46
:2 0 2 :4 0 1f7
:2 0 bf :2 0 46
:2 0 10e9 1cf4 1cf6
:3 0 10ec 1cf0 1cf8
1ced 1cfa 1cf9 :2 0
b0 :3 0 c0 :3 0
1cfc 1cfd 0 b2
:4 0 1f8 :4 0 b5
:2 0 b6 :3 0 10f0
1d01 1d03 :3 0 10f3
1cfe 1d05 :2 0 1d07
10f6 1d08 1cfb 1d07
0 1d09 10f8 0
1d13 ce :3 0 cf
:3 0 1d0a 1d0b 0
c2 :3 0 d6 :3 0
1d0d 1d0e 0 d0
:3 0 10fa 1d0c 1d11
:2 0 1d13 10fd 1d14
1cb6 1d13 0 1d15
1101 0 1d6c 1f9
:3 0 2a :3 0 2a
:3 0 e7 :4 0 1fa
1 :8 0 1d20 21
:3 0 e9 :3 0 1d1b
1d1c 0 ea :3 0
1d1d 1d1e 0 1d20
1103 1d6a eb :3 0
21 :3 0 e9 :3 0
1d23 1d24 0 ea
:3 0 1d25 1d26 0
1d60 ad :3 0 ae
:3 0 1d28 1d29 0
ad :3 0 bd :3 0
1d2b 1d2c 0 ec
:2 0 2 :4 0 1fb
:2 0 bf :2 0 46
:2 0 1106 1d31 1d33
:3 0 1109 1d2d 1d35
1d2a 1d37 1d36 :2 0
b0 :3 0 c0 :3 0
1d39 1d3a 0 b2
:4 0 1fc :4 0 b5
:2 0 b6 :3 0 110d
1d3e 1d40 :3 0 b5
:2 0 c9 :4 0 1110
1d42 1d44 :3 0 b5
:2 0 ef :4 0 1113
1d46 1d48 :3 0 b5
:2 0 ea :3 0 1116
1d4a 1d4c :3 0 b5
:2 0 f0 :4 0 1119
1d4e 1d50 :3 0 b5
:2 0 f1 :3 0 f2
:3 0 46 :2 0 f3
:2 0 111c 1d53 1d57
1120 1d52 1d59 :3 0
1123 1d3b 1d5b :2 0
1d5d 1126 1d5e 1d38
1d5d 0 1d5f 1128
0 1d60 112a 1d63
:3 0 1d63 0 1d63
1d62 1d60 1d61 :6 0
1d65 31 :3 0 112d
1d67 112f 1d66 1d65
:2 0 1d68 1131 :2 0
1d6a 0 1d6a 1d69
1d20 1d68 :6 0 1d6c
1 :3 0 1133 1d6d
1c3d 1d6c 0 1d6e
1139 0 2424 a1
:3 0 5b :3 0 4d
:2 0 113b 1d6f 1d72
c2 :3 0 d2 :2 0
d3 :3 0 1d74 1d76
0 1140 1d75 1d78
:3 0 74 :3 0 1fd
:4 0 1d7a 1d7b 0
1d8f 76 :3 0 1fe
:4 0 1d7d 1d7e 0
1d8f 76 :3 0 76
:3 0 b5 :2 0 39
:3 0 1143 1d82 1d84
:3 0 1d80 1d85 0
1d8f 76 :3 0 76
:3 0 b5 :2 0 b8
:4 0 1146 1d89 1d8b
:3 0 1d87 1d8c 0
1d8f d9 :3 0 1149
1e7a a1 :3 0 5b
:3 0 4d :2 0 114e
1d90 1d93 c2 :3 0
d2 :2 0 d1 :3 0
1d95 1d97 0 1153
1d96 1d99 :3 0 74
:3 0 1ff :4 0 1d9b
1d9c 0 1daf 74
:3 0 74 :3 0 b5
:2 0 25 :3 0 1156
1da0 1da2 :3 0 1d9e
1da3 0 1daf 74
:3 0 74 :3 0 b5
:2 0 200 :4 0 1159
1da7 1da9 :3 0 1da5
1daa 0 1daf 76
:3 0 201 :4 0 1dac
1dad 0 1daf 115c
1db0 1d9a 1daf 0
1e7c a1 :3 0 a
:3 0 4d :2 0 1161
1db1 1db4 c2 :3 0
d2 :2 0 c4 :3 0
1db6 1db8 0 1166
1db7 1dba :3 0 74
:3 0 202 :4 0 1dbc
1dbd 0 1e03 76
:3 0 201 :4 0 1dbf
1dc0 0 1e03 1e
:3 0 e4 :2 0 1169
1dc3 1dc4 :3 0 1dc5
:2 0 76 :3 0 76
:3 0 b5 :2 0 203
:4 0 116b 1dc9 1dcb
:3 0 1dc7 1dcc 0
1ddc 76 :3 0 76
:3 0 b5 :2 0 3a
:3 0 116e 1dd0 1dd2
:3 0 1dce 1dd3 0
1ddc 76 :3 0 76
:3 0 b5 :2 0 1d0
:4 0 1171 1dd7 1dd9
:3 0 1dd5 1dda 0
1ddc 1174 1ddd 1dc6
1ddc 0 1dde 1178
0 1e03 76 :3 0
76 :3 0 b5 :2 0
204 :4 0 117a 1de1
1de3 :3 0 1ddf 1de4
0 1e03 10 :3 0
e4 :2 0 117d 1de7
1de8 :3 0 1de9 :2 0
76 :3 0 76 :3 0
b5 :2 0 205 :4 0
117f 1ded 1def :3 0
1deb 1df0 0 1e00
76 :3 0 76 :3 0
b5 :2 0 2a :3 0
1182 1df4 1df6 :3 0
1df2 1df7 0 1e00
76 :3 0 76 :3 0
b5 :2 0 206 :4 0
1185 1dfb 1dfd :3 0
1df9 1dfe 0 1e00
1188 1e01 1dea 1e00
0 1e02 118c 0
1e03 118e 1e76 14
:3 0 e4 :2 0 1194
1e05 1e06 :3 0 1e07
:2 0 74 :3 0 74
:3 0 b5 :2 0 207
:4 0 1196 1e0b 1e0d
:3 0 1e09 1e0e 0
1e13 76 :3 0 201
:4 0 1e10 1e11 0
1e13 1199 1e5b 74
:3 0 74 :3 0 b5
:2 0 208 :4 0 119c
1e16 1e18 :3 0 b5
:2 0 209 :4 0 119f
1e1a 1e1c :3 0 1e14
1e1d 0 1e5a 76
:3 0 201 :4 0 1e1f
1e20 0 1e5a 1e
:3 0 e4 :2 0 11a2
1e23 1e24 :3 0 1e25
:2 0 76 :3 0 76
:3 0 b5 :2 0 203
:4 0 11a4 1e29 1e2b
:3 0 1e27 1e2c 0
1e3c 76 :3 0 76
:3 0 b5 :2 0 3a
:3 0 11a7 1e30 1e32
:3 0 1e2e 1e33 0
1e3c 76 :3 0 76
:3 0 b5 :2 0 1d0
:4 0 11aa 1e37 1e39
:3 0 1e35 1e3a 0
1e3c 11ad 1e3d 1e26
1e3c 0 1e3e 11b1
0 1e5a 76 :3 0
76 :3 0 b5 :2 0
20a :4 0 11b3 1e41
1e43 :3 0 b5 :2 0
20b :4 0 11b6 1e45
1e47 :3 0 b5 :2 0
20c :4 0 11b9 1e49
1e4b :3 0 b5 :2 0
20d :4 0 11bc 1e4d
1e4f :3 0 b5 :2 0
20e :4 0 11bf 1e51
1e53 :3 0 b5 :2 0
20f :4 0 11c2 1e55
1e57 :3 0 1e3f 1e58
0 1e5a 11c5 1e5c
1e08 1e13 0 1e5d
0 1e5a 0 1e5d
11ca 0 1e75 10
:3 0 e4 :2 0 11cd
1e5f 1e60 :3 0 1e61
:2 0 76 :3 0 76
:3 0 b5 :2 0 210
:4 0 11cf 1e65 1e67
:3 0 b5 :2 0 2a
:3 0 11d2 1e69 1e6b
:3 0 b5 :2 0 206
:4 0 11d5 1e6d 1e6f
:3 0 1e63 1e70 0
1e72 11d8 1e73 1e62
1e72 0 1e74 11da
0 1e75 11dc 1e77
1dbb 1e03 0 1e78
0 1e75 0 1e78
11df 0 1e79 11e2
1e7b 1d79 1d8f 0
1e7c 0 1e79 0
1e7c 11e4 0 2424
a1 :3 0 5b :3 0
4d :2 0 11e8 1e7d
1e80 c2 :3 0 c3
:2 0 d3 :3 0 1e82
1e84 0 11ed 1e83
1e86 :3 0 14 :3 0
e4 :2 0 11f0 1e89
1e8a :3 0 1e8b :2 0
1dc :3 0 3b :3 0
177 :3 0 10c :3 0
14 :4 0 211 1
:8 0 1e98 21 :3 0
e9 :3 0 1e93 1e94
0 ea :3 0 1e95
1e96 0 1e98 11f2
1ee2 eb :3 0 21
:3 0 e9 :3 0 1e9b
1e9c 0 ea :3 0
1e9d 1e9e 0 1ed8
ad :3 0 ae :3 0
1ea0 1ea1 0 ad
:3 0 bd :3 0 1ea3
1ea4 0 ec :2 0
2 :4 0 212 :2 0
bf :2 0 46 :2 0
11f5 1ea9 1eab :3 0
11f8 1ea5 1ead 1ea2
1eaf 1eae :2 0 b0
:3 0 c0 :3 0 1eb1
1eb2 0 b2 :4 0
213 :4 0 b5 :2 0
b6 :3 0 11fc 1eb6
1eb8 :3 0 b5 :2 0
c9 :4 0 11ff 1eba
1ebc :3 0 b5 :2 0
ef :4 0 1202 1ebe
1ec0 :3 0 b5 :2 0
ea :3 0 1205 1ec2
1ec4 :3 0 b5 :2 0
f0 :4 0 1208 1ec6
1ec8 :3 0 b5 :2 0
f1 :3 0 f2 :3 0
46 :2 0 f3 :2 0
120b 1ecb 1ecf 120f
1eca 1ed1 :3 0 1212
1eb3 1ed3 :2 0 1ed5
1215 1ed6 1eb0 1ed5
0 1ed7 1217 0
1ed8 1219 1edb :3 0
1edb 0 1edb 1eda
1ed8 1ed9 :6 0 1edd
33 :3 0 121c 1edf
121e 1ede 1edd :2 0
1ee0 1220 :2 0 1ee2
0 1ee2 1ee1 1e98
1ee0 :6 0 1f84 1
:3 0 21 :3 0 e9
:3 0 1ee4 1ee5 0
21 :3 0 d2 :2 0
f4 :3 0 1ee7 1ee9
0 1224 1ee8 1eeb
:3 0 1eec :2 0 90
:3 0 a1 :3 0 1e7
:3 0 3b :3 0 1227
1ef0 1ef2 4d :2 0
1229 1eef 1ef5 1eee
1ef6 0 1f12 74
:3 0 74 :3 0 b5
:2 0 214 :4 0 122c
1efa 1efc :3 0 1ef8
1efd 0 1f12 76
:3 0 76 :3 0 b5
:2 0 215 :4 0 122f
1f01 1f03 :3 0 b5
:2 0 216 :4 0 1232
1f05 1f07 :3 0 b5
:2 0 3b :3 0 1235
1f09 1f0b :3 0 b5
:2 0 217 :4 0 1238
1f0d 1f0f :3 0 1eff
1f10 0 1f12 123b
1f81 ad :3 0 ae
:3 0 1f13 1f14 0
ad :3 0 bd :3 0
1f16 1f17 0 24
:2 0 2 :4 0 218
:2 0 bf :2 0 46
:2 0 123f 1f1c 1f1e
:3 0 1242 1f18 1f20
1f15 1f22 1f21 :2 0
b0 :3 0 c0 :3 0
1f24 1f25 0 b2
:4 0 219 :4 0 b5
:2 0 b6 :3 0 1246
1f29 1f2b :3 0 b5
:2 0 c9 :4 0 1249
1f2d 1f2f :3 0 b5
:2 0 ca :4 0 124c
1f31 1f33 :3 0 b5
:2 0 a1 :3 0 ba
:3 0 c2 :3 0 d6
:3 0 1f38 1f39 0
124f 1f37 1f3b bb
:4 0 1251 1f36 1f3e
1254 1f35 1f40 :3 0
b5 :2 0 115 :4 0
1257 1f42 1f44 :3 0
b5 :2 0 b8 :4 0
125a 1f46 1f48 :3 0
b5 :2 0 14 :3 0
125d 1f4a 1f4c :3 0
b5 :2 0 b8 :4 0
1260 1f4e 1f50 :3 0
1263 1f26 1f52 :2 0
1f54 1266 1f55 1f23
1f54 0 1f56 1268
0 1f80 ad :3 0
ae :3 0 1f57 1f58
0 ad :3 0 bd
:3 0 1f5a 1f5b 0
46 :2 0 2 :4 0
21a :2 0 bf :2 0
46 :2 0 126a 1f60
1f62 :3 0 126d 1f5c
1f64 1f59 1f66 1f65
:2 0 b0 :3 0 c0
:3 0 1f68 1f69 0
b2 :4 0 21b :4 0
b5 :2 0 b6 :3 0
1271 1f6d 1f6f :3 0
1274 1f6a 1f71 :2 0
1f73 1277 1f74 1f67
1f73 0 1f75 1279
0 1f80 ce :3 0
118 :3 0 1f76 1f77
0 c2 :3 0 d6
:3 0 1f79 1f7a 0
14 :3 0 d0 :3 0
127b 1f78 1f7e :2 0
1f80 127f 1f82 1eed
1f12 0 1f83 0
1f80 0 1f83 1283
0 1f84 1286 1f85
1e8c 1f84 0 1f86
1289 0 219e 12
:3 0 e4 :2 0 128b
1f88 1f89 :3 0 1f8a
:2 0 1dc :3 0 3b
:3 0 21c :3 0 10c
:3 0 12 :4 0 21d
1 :8 0 1f97 21
:3 0 e9 :3 0 1f92
1f93 0 ea :3 0
1f94 1f95 0 1f97
128d 1fe1 eb :3 0
21 :3 0 e9 :3 0
1f9a 1f9b 0 ea
:3 0 1f9c 1f9d 0
1fd7 ad :3 0 ae
:3 0 1f9f 1fa0 0
ad :3 0 bd :3 0
1fa2 1fa3 0 ec
:2 0 2 :4 0 21e
:2 0 bf :2 0 46
:2 0 1290 1fa8 1faa
:3 0 1293 1fa4 1fac
1fa1 1fae 1fad :2 0
b0 :3 0 c0 :3 0
1fb0 1fb1 0 b2
:4 0 21f :4 0 b5
:2 0 b6 :3 0 1297
1fb5 1fb7 :3 0 b5
:2 0 c9 :4 0 129a
1fb9 1fbb :3 0 b5
:2 0 ef :4 0 129d
1fbd 1fbf :3 0 b5
:2 0 ea :3 0 12a0
1fc1 1fc3 :3 0 b5
:2 0 f0 :4 0 12a3
1fc5 1fc7 :3 0 b5
:2 0 f1 :3 0 f2
:3 0 46 :2 0 f3
:2 0 12a6 1fca 1fce
12aa 1fc9 1fd0 :3 0
12ad 1fb2 1fd2 :2 0
1fd4 12b0 1fd5 1faf
1fd4 0 1fd6 12b2
0 1fd7 12b4 1fda
:3 0 1fda 0 1fda
1fd9 1fd7 1fd8 :6 0
1fdc 35 :3 0 12b7
1fde 12b9 1fdd 1fdc
:2 0 1fdf 12bb :2 0
1fe1 0 1fe1 1fe0
1f97 1fdf :6 0 2079
1 :3 0 21 :3 0
e9 :3 0 1fe3 1fe4
0 21 :3 0 d2
:2 0 f4 :3 0 1fe6
1fe8 0 12bf 1fe7
1fea :3 0 1feb :2 0
74 :3 0 74 :3 0
b5 :2 0 220 :4 0
12c2 1fef 1ff1 :3 0
1fed 1ff2 0 2007
76 :3 0 76 :3 0
b5 :2 0 221 :4 0
12c5 1ff6 1ff8 :3 0
b5 :2 0 222 :4 0
12c8 1ffa 1ffc :3 0
b5 :2 0 3b :3 0
12cb 1ffe 2000 :3 0
b5 :2 0 217 :4 0
12ce 2002 2004 :3 0
1ff4 2005 0 2007
12d1 2076 ad :3 0
ae :3 0 2008 2009
0 ad :3 0 bd
:3 0 200b 200c 0
24 :2 0 2 :4 0
223 :2 0 bf :2 0
46 :2 0 12d4 2011
2013 :3 0 12d7 200d
2015 200a 2017 2016
:2 0 b0 :3 0 c0
:3 0 2019 201a 0
b2 :4 0 224 :4 0
b5 :2 0 b6 :3 0
12db 201e 2020 :3 0
b5 :2 0 c9 :4 0
12de 2022 2024 :3 0
b5 :2 0 ca :4 0
12e1 2026 2028 :3 0
b5 :2 0 a1 :3 0
ba :3 0 c2 :3 0
d6 :3 0 202d 202e
0 12e4 202c 2030
bb :4 0 12e6 202b
2033 12e9 202a 2035
:3 0 b5 :2 0 115
:4 0 12ec 2037 2039
:3 0 b5 :2 0 b8
:4 0 12ef 203b 203d
:3 0 b5 :2 0 12
:3 0 12f2 203f 2041
:3 0 b5 :2 0 b8
:4 0 12f5 2043 2045
:3 0 12f8 201b 2047
:2 0 2049 12fb 204a
2018 2049 0 204b
12fd 0 2075 ad
:3 0 ae :3 0 204c
204d 0 ad :3 0
bd :3 0 204f 2050
0 46 :2 0 2
:4 0 225 :2 0 bf
:2 0 46 :2 0 12ff
2055 2057 :3 0 1302
2051 2059 204e 205b
205a :2 0 b0 :3 0
c0 :3 0 205d 205e
0 b2 :4 0 226
:4 0 b5 :2 0 b6
:3 0 1306 2062 2064
:3 0 1309 205f 2066
:2 0 2068 130c 2069
205c 2068 0 206a
130e 0 2075 ce
:3 0 118 :3 0 206b
206c 0 c2 :3 0
d6 :3 0 206e 206f
0 12 :3 0 d0
:3 0 1310 206d 2073
:2 0 2075 1314 2077
1fec 2007 0 2078
0 2075 0 2078
1318 0 2079 131b
207a 1f8b 2079 0
207b 131e 0 219e
13 :3 0 e4 :2 0
1320 207d 207e :3 0
207f :2 0 1dc :3 0
3b :3 0 227 :3 0
10c :3 0 13 :4 0
228 1 :8 0 208c
21 :3 0 e9 :3 0
2087 2088 0 ea
:3 0 2089 208a 0
208c 1322 20d6 eb
:3 0 21 :3 0 e9
:3 0 208f 2090 0
ea :3 0 2091 2092
0 20cc ad :3 0
ae :3 0 2094 2095
0 ad :3 0 bd
:3 0 2097 2098 0
ec :2 0 2 :4 0
229 :2 0 bf :2 0
46 :2 0 1325 209d
209f :3 0 1328 2099
20a1 2096 20a3 20a2
:2 0 b0 :3 0 c0
:3 0 20a5 20a6 0
b2 :4 0 22a :4 0
b5 :2 0 b6 :3 0
132c 20aa 20ac :3 0
b5 :2 0 c9 :4 0
132f 20ae 20b0 :3 0
b5 :2 0 ef :4 0
1332 20b2 20b4 :3 0
b5 :2 0 ea :3 0
1335 20b6 20b8 :3 0
b5 :2 0 f0 :4 0
1338 20ba 20bc :3 0
b5 :2 0 f1 :3 0
f2 :3 0 46 :2 0
f3 :2 0 133b 20bf
20c3 133f 20be 20c5
:3 0 1342 20a7 20c7
:2 0 20c9 1345 20ca
20a4 20c9 0 20cb
1347 0 20cc 1349
20cf :3 0 20cf 0
20cf 20ce 20cc 20cd
:6 0 20d1 37 :3 0
134c 20d3 134e 20d2
20d1 :2 0 20d4 1350
:2 0 20d6 0 20d6
20d5 208c 20d4 :6 0
216e 1 :3 0 21
:3 0 e9 :3 0 20d8
20d9 0 21 :3 0
d2 :2 0 f4 :3 0
20db 20dd 0 1354
20dc 20df :3 0 20e0
:2 0 74 :3 0 74
:3 0 b5 :2 0 22b
:4 0 1357 20e4 20e6
:3 0 20e2 20e7 0
20fc 76 :3 0 76
:3 0 b5 :2 0 22c
:4 0 135a 20eb 20ed
:3 0 b5 :2 0 22d
:4 0 135d 20ef 20f1
:3 0 b5 :2 0 3b
:3 0 1360 20f3 20f5
:3 0 b5 :2 0 217
:4 0 1363 20f7 20f9
:3 0 20e9 20fa 0
20fc 1366 216b ad
:3 0 ae :3 0 20fd
20fe 0 ad :3 0
bd :3 0 2100 2101
0 24 :2 0 2
:4 0 22e :2 0 bf
:2 0 46 :2 0 1369
2106 2108 :3 0 136c
2102 210a 20ff 210c
210b :2 0 b0 :3 0
c0 :3 0 210e 210f
0 b2 :4 0 22f
:4 0 b5 :2 0 b6
:3 0 1370 2113 2115
:3 0 b5 :2 0 c9
:4 0 1373 2117 2119
:3 0 b5 :2 0 ca
:4 0 1376 211b 211d
:3 0 b5 :2 0 a1
:3 0 ba :3 0 c2
:3 0 d6 :3 0 2122
2123 0 1379 2121
2125 bb :4 0 137b
2120 2128 137e 211f
212a :3 0 b5 :2 0
115 :4 0 1381 212c
212e :3 0 b5 :2 0
b8 :4 0 1384 2130
2132 :3 0 b5 :2 0
13 :3 0 1387 2134
2136 :3 0 b5 :2 0
b8 :4 0 138a 2138
213a :3 0 138d 2110
213c :2 0 213e 1390
213f 210d 213e 0
2140 1392 0 216a
ad :3 0 ae :3 0
2141 2142 0 ad
:3 0 bd :3 0 2144
2145 0 46 :2 0
2 :4 0 230 :2 0
bf :2 0 46 :2 0
1394 214a 214c :3 0
1397 2146 214e 2143
2150 214f :2 0 b0
:3 0 c0 :3 0 2152
2153 0 b2 :4 0
231 :4 0 b5 :2 0
b6 :3 0 139b 2157
2159 :3 0 139e 2154
215b :2 0 215d 13a1
215e 2151 215d 0
215f 13a3 0 216a
ce :3 0 118 :3 0
2160 2161 0 c2
:3 0 d6 :3 0 2163
2164 0 13 :3 0
d0 :3 0 13a5 2162
2168 :2 0 216a 13a9
216c 20e1 20fc 0
216d 0 216a 0
216d 13ad 0 216e
13b0 216f 2080 216e
0 2170 13b3 0
219e a1 :3 0 53
:3 0 4d :2 0 13b5
2171 2174 104 :2 0
4d :2 0 13ba 2176
2178 :3 0 a1 :3 0
53 :3 0 4d :2 0
13bd 217a 217d c3
:2 0 e3 :2 0 13c2
217f 2181 :3 0 2179
2183 2182 :2 0 76
:3 0 76 :3 0 b5
:2 0 232 :4 0 13c5
2187 2189 :3 0 b5
:2 0 ba :3 0 a1
:3 0 15 :3 0 4d
:2 0 13c8 218d 2190
13cb 218c 2192 13cd
218b 2194 :3 0 b5
:2 0 c9 :4 0 13d0
2196 2198 :3 0 2185
2199 0 219b 13d3
219c 2184 219b 0
219d 13d5 0 219e
13d7 219f 1e87 219e
0 21a0 13dc 0
2424 16 :3 0 e4
:2 0 13de 21a2 21a3
:3 0 21a4 :2 0 91
:3 0 a1 :3 0 1e7
:3 0 2e :3 0 13e0
21a8 21aa 4d :2 0
13e2 21a7 21ad 21a6
21ae 0 22ee 85
:3 0 4d :2 0 21b0
21b1 0 22ee 1ef
:3 0 85 :3 0 91
:3 0 f5 :2 0 1f0
:3 0 13e7 21b6 21b8
:3 0 21b9 22ed 48
:3 0 233 :3 0 234
:3 0 21bc 21bd 0
24 :2 0 24 :2 0
85 :3 0 bf :2 0
46 :2 0 13ea 21c2
21c4 :3 0 2e :3 0
13ed 21be 21c7 21bb
21c8 0 22eb 1dc
:3 0 3b :3 0 1a5
:3 0 10c :3 0 48
:4 0 235 1 :8 0
21d5 21 :3 0 e9
:3 0 21d0 21d1 0
ea :3 0 21d2 21d3
0 21d5 13f2 221f
eb :3 0 21 :3 0
e9 :3 0 21d8 21d9
0 ea :3 0 21da
21db 0 2215 ad
:3 0 ae :3 0 21dd
21de 0 ad :3 0
bd :3 0 21e0 21e1
0 ec :2 0 2
:4 0 236 :2 0 bf
:2 0 46 :2 0 13f5
21e6 21e8 :3 0 13f8
21e2 21ea 21df 21ec
21eb :2 0 b0 :3 0
c0 :3 0 21ee 21ef
0 b2 :4 0 237
:4 0 b5 :2 0 b6
:3 0 13fc 21f3 21f5
:3 0 b5 :2 0 c9
:4 0 13ff 21f7 21f9
:3 0 b5 :2 0 ef
:4 0 1402 21fb 21fd
:3 0 b5 :2 0 ea
:3 0 1405 21ff 2201
:3 0 b5 :2 0 f0
:4 0 1408 2203 2205
:3 0 b5 :2 0 f1
:3 0 f2 :3 0 46
:2 0 f3 :2 0 140b
2208 220c 140f 2207
220e :3 0 1412 21f0
2210 :2 0 2212 1415
2213 21ed 2212 0
2214 1417 0 2215
1419 2218 :3 0 2218
0 2218 2217 2215
2216 :6 0 221a 3a
:3 0 141c 221c 141e
221b 221a :2 0 221d
1420 :2 0 221f 0
221f 221e 21d5 221d
:6 0 22eb 39 :3 0
21 :3 0 e9 :3 0
2221 2222 0 21
:3 0 c3 :2 0 f4
:3 0 2224 2226 0
1424 2225 2228 :3 0
2229 :2 0 ad :3 0
ae :3 0 222b 222c
0 ad :3 0 bd
:3 0 222e 222f 0
24 :2 0 2 :4 0
238 :2 0 bf :2 0
46 :2 0 1427 2234
2236 :3 0 142a 2230
2238 222d 223a 2239
:2 0 b0 :3 0 c0
:3 0 223c 223d 0
b2 :4 0 239 :4 0
b5 :2 0 b6 :3 0
142e 2241 2243 :3 0
b5 :2 0 c9 :4 0
1431 2245 2247 :3 0
b5 :2 0 ca :4 0
1434 2249 224b :3 0
b5 :2 0 a1 :3 0
ba :3 0 c2 :3 0
d6 :3 0 2250 2251
0 1437 224f 2253
bb :4 0 1439 224e
2256 143c 224d 2258
:3 0 b5 :2 0 115
:4 0 143f 225a 225c
:3 0 b5 :2 0 b8
:4 0 1442 225e 2260
:3 0 b5 :2 0 48
:3 0 1445 2262 2264
:3 0 b5 :2 0 b8
:4 0 1448 2266 2268
:3 0 144b 223e 226a
:2 0 226c 144e 226d
223b 226c 0 226e
1450 0 2298 ad
:3 0 ae :3 0 226f
2270 0 ad :3 0
bd :3 0 2272 2273
0 46 :2 0 2
:4 0 23a :2 0 bf
:2 0 46 :2 0 1452
2278 227a :3 0 1455
2274 227c 2271 227e
227d :2 0 b0 :3 0
c0 :3 0 2280 2281
0 b2 :4 0 23b
:4 0 b5 :2 0 b6
:3 0 1459 2285 2287
:3 0 145c 2282 2289
:2 0 228b 145f 228c
227f 228b 0 228d
1461 0 2298 ce
:3 0 118 :3 0 228e
228f 0 c2 :3 0
d6 :3 0 2291 2292
0 48 :3 0 d0
:3 0 1463 2290 2296
:2 0 2298 1467 2299
222a 2298 0 229a
146b 0 22eb 76
:3 0 76 :3 0 b5
:2 0 23c :4 0 146d
229d 229f :3 0 b5
:2 0 23d :4 0 1470
22a1 22a3 :3 0 b5
:2 0 23e :4 0 1473
22a5 22a7 :3 0 b5
:2 0 23f :4 0 1476
22a9 22ab :3 0 b5
:2 0 3b :3 0 1479
22ad 22af :3 0 b5
:2 0 240 :4 0 147c
22b1 22b3 :3 0 229b
22b4 0 22eb a1
:3 0 5b :3 0 4d
:2 0 147f 22b6 22b9
c2 :3 0 d2 :2 0
d3 :3 0 22bb 22bd
0 1484 22bc 22bf
:3 0 76 :3 0 76
:3 0 b5 :2 0 241
:4 0 1487 22c3 22c5
:3 0 22c1 22c6 0
22c8 148a 22d1 76
:3 0 76 :3 0 b5
:2 0 242 :4 0 148c
22cb 22cd :3 0 22c9
22ce 0 22d0 148f
22d2 22c0 22c8 0
22d3 0 22d0 0
22d3 1491 0 22eb
a1 :3 0 5b :3 0
4d :2 0 1494 22d4
22d7 c2 :3 0 d2
:2 0 d3 :3 0 22d9
22db 0 1499 22da
22dd :3 0 1f4 :8 0
22e1 149c 22e2 22de
22e1 0 22e3 149e
0 22eb 85 :3 0
85 :3 0 bf :2 0
24 :2 0 14a0 22e6
22e8 :3 0 22e4 22e9
0 22eb 14a3 22ed
1f0 :3 0 21ba 22eb
:4 0 22ee 14ab 22ef
21a5 22ee 0 22f0
14af 0 2424 a1
:3 0 5b :3 0 4d
:2 0 14b1 22f1 22f4
c2 :3 0 c3 :2 0
d3 :3 0 22f6 22f8
0 14b6 22f7 22fa
:3 0 92 :3 0 a1
:3 0 1e7 :3 0 30
:3 0 14b9 22fe 2300
4d :2 0 14bb 22fd
2303 22fc 2304 0
241a 85 :3 0 4d
:2 0 2306 2307 0
241a 1ef :3 0 85
:3 0 92 :3 0 f5
:2 0 1f0 :3 0 14c0
230c 230e :3 0 230f
2419 48 :3 0 233
:3 0 234 :3 0 2312
2313 0 24 :2 0
24 :2 0 85 :3 0
bf :2 0 46 :2 0
14c3 2318 231a :3 0
30 :3 0 14c6 2314
231d 2311 231e 0
2417 1dc :3 0 3b
:3 0 1a5 :3 0 10c
:3 0 48 :4 0 235
1 :8 0 232b 21
:3 0 e9 :3 0 2326
2327 0 ea :3 0
2328 2329 0 232b
14cb 2375 eb :3 0
21 :3 0 e9 :3 0
232e 232f 0 ea
:3 0 2330 2331 0
236b ad :3 0 ae
:3 0 2333 2334 0
ad :3 0 bd :3 0
2336 2337 0 ec
:2 0 2 :4 0 243
:2 0 bf :2 0 46
:2 0 14ce 233c 233e
:3 0 14d1 2338 2340
2335 2342 2341 :2 0
b0 :3 0 c0 :3 0
2344 2345 0 b2
:4 0 244 :4 0 b5
:2 0 b6 :3 0 14d5
2349 234b :3 0 b5
:2 0 c9 :4 0 14d8
234d 234f :3 0 b5
:2 0 ef :4 0 14db
2351 2353 :3 0 b5
:2 0 ea :3 0 14de
2355 2357 :3 0 b5
:2 0 f0 :4 0 14e1
2359 235b :3 0 b5
:2 0 f1 :3 0 f2
:3 0 46 :2 0 f3
:2 0 14e4 235e 2362
14e8 235d 2364 :3 0
14eb 2346 2366 :2 0
2368 14ee 2369 2343
2368 0 236a 14f0
0 236b 14f2 236e
:3 0 236e 0 236e
236d 236b 236c :6 0
2370 3d :3 0 14f5
2372 14f7 2371 2370
:2 0 2373 14f9 :2 0
2375 0 2375 2374
232b 2373 :6 0 2417
3c :3 0 21 :3 0
e9 :3 0 2377 2378
0 21 :3 0 c3
:2 0 f4 :3 0 237a
237c 0 14fd 237b
237e :3 0 237f :2 0
ad :3 0 ae :3 0
2381 2382 0 ad
:3 0 bd :3 0 2384
2385 0 24 :2 0
2 :4 0 245 :2 0
bf :2 0 46 :2 0
1500 238a 238c :3 0
1503 2386 238e 2383
2390 238f :2 0 b0
:3 0 c0 :3 0 2392
2393 0 b2 :4 0
246 :4 0 b5 :2 0
b6 :3 0 1507 2397
2399 :3 0 b5 :2 0
c9 :4 0 150a 239b
239d :3 0 b5 :2 0
ca :4 0 150d 239f
23a1 :3 0 b5 :2 0
a1 :3 0 ba :3 0
c2 :3 0 d6 :3 0
23a6 23a7 0 1510
23a5 23a9 bb :4 0
1512 23a4 23ac 1515
23a3 23ae :3 0 b5
:2 0 115 :4 0 1518
23b0 23b2 :3 0 b5
:2 0 b8 :4 0 151b
23b4 23b6 :3 0 b5
:2 0 48 :3 0 151e
23b8 23ba :3 0 b5
:2 0 b8 :4 0 1521
23bc 23be :3 0 1524
2394 23c0 :2 0 23c2
1527 23c3 2391 23c2
0 23c4 1529 0
23ee ad :3 0 ae
:3 0 23c5 23c6 0
ad :3 0 bd :3 0
23c8 23c9 0 46
:2 0 2 :4 0 247
:2 0 bf :2 0 46
:2 0 152b 23ce 23d0
:3 0 152e 23ca 23d2
23c7 23d4 23d3 :2 0
b0 :3 0 c0 :3 0
23d6 23d7 0 b2
:4 0 248 :4 0 b5
:2 0 b6 :3 0 1532
23db 23dd :3 0 1535
23d8 23df :2 0 23e1
1538 23e2 23d5 23e1
0 23e3 153a 0
23ee ce :3 0 118
:3 0 23e4 23e5 0
c2 :3 0 d6 :3 0
23e7 23e8 0 48
:3 0 d0 :3 0 153c
23e6 23ec :2 0 23ee
1540 23ef 2380 23ee
0 23f0 1544 0
2417 76 :3 0 76
:3 0 b5 :2 0 23c
:4 0 1546 23f3 23f5
:3 0 b5 :2 0 23d
:4 0 1549 23f7 23f9
:3 0 b5 :2 0 23e
:4 0 154c 23fb 23fd
:3 0 b5 :2 0 23f
:4 0 154f 23ff 2401
:3 0 b5 :2 0 3b
:3 0 1552 2403 2405
:3 0 b5 :2 0 240
:4 0 1555 2407 2409
:3 0 b5 :2 0 249
:4 0 1558 240b 240d
:3 0 23f1 240e 0
2417 85 :3 0 85
:3 0 bf :2 0 24
:2 0 155b 2412 2414
:3 0 2410 2415 0
2417 155e 2419 1f0
:3 0 2310 2417 :4 0
241a 1564 241b 22fb
241a 0 241c 1568
0 2424 74 :3 0
74 :3 0 b5 :2 0
76 :3 0 156a 241f
2421 :3 0 241d 2422
0 2424 156d 2426
1a89 1aff 0 2427
0 2424 0 2427
1575 0 3423 74
:3 0 74 :3 0 b5
:2 0 24a :4 0 1578
242a 242c :3 0 2428
242d 0 3423 24b
:3 0 93 :3 0 74
:3 0 2430 2431 0
2432 :2 0 3423 1f0
:3 0 93 :3 0 39
:4 0 2438 :2 0 28aa
2435 2436 :3 0 93
:3 0 1b5 :3 0 2439
243a :3 0 21 :3 0
e9 :3 0 243c 243d
0 4d :2 0 243e
243f 0 2441 157b
2448 21 :3 0 e9
:3 0 2442 2443 0
17f :2 0 2444 2445
0 2447 157d 2449
243b 2441 0 244a
0 2447 0 244a
157f 0 28aa 21
:3 0 e9 :3 0 244b
244c 0 21 :3 0
c3 :2 0 f4 :3 0
244e 2450 0 1584
244f 2452 :3 0 2453
:2 0 1f4 :8 0 2457
1587 2458 2454 2457
0 2459 1589 0
28aa a1 :3 0 4f
:3 0 4d :2 0 158b
245a 245d d2 :2 0
4d :2 0 1590 245f
2461 :3 0 a1 :3 0
5b :3 0 4d :2 0
1593 2463 2466 c2
:3 0 c3 :2 0 c4
:3 0 2468 246a 0
1598 2469 246c :3 0
2462 246e 246d :2 0
a1 :3 0 5b :3 0
4d :2 0 159b 2470
2473 c2 :3 0 c3
:2 0 d1 :3 0 2475
2477 0 15a0 2476
2479 :3 0 246f 247b
247a :2 0 a1 :3 0
5b :3 0 4d :2 0
15a3 247d 2480 c2
:3 0 c3 :2 0 d3
:3 0 2482 2484 0
15a8 2483 2486 :3 0
14 :3 0 c5 :2 0
15ab 2489 248a :3 0
248b :2 0 2487 248d
248c :2 0 248e :2 0
247c 2490 248f :2 0
24b :3 0 95 :4 0
2495 :2 0 2568 2493
2496 :3 0 95 :3 0
28 :4 0 249a :2 0
2568 2497 2498 :3 0
95 :3 0 1b5 :3 0
249b 249c :3 0 21
:3 0 e9 :3 0 249e
249f 0 4d :2 0
24a0 24a1 0 24a3
15ad 24aa 21 :3 0
e9 :3 0 24a4 24a5
0 17f :2 0 24a6
24a7 0 24a9 15af
24ab 249d 24a3 0
24ac 0 24a9 0
24ac 15b1 0 2568
21 :3 0 e9 :3 0
24ad 24ae 0 21
:3 0 d2 :2 0 f4
:3 0 24b0 24b2 0
15b6 24b1 24b4 :3 0
24b5 :2 0 24c :3 0
95 :4 0 24ba :2 0
24c0 24b8 0 21
:3 0 e9 :3 0 24bb
24bc 0 ea :3 0
24bd 24be 0 24c0
15b9 250a eb :3 0
21 :3 0 e9 :3 0
24c3 24c4 0 ea
:3 0 24c5 24c6 0
2500 ad :3 0 ae
:3 0 24c8 24c9 0
ad :3 0 bd :3 0
24cb 24cc 0 ec
:2 0 2 :4 0 24d
:2 0 bf :2 0 46
:2 0 15bc 24d1 24d3
:3 0 15bf 24cd 24d5
24ca 24d7 24d6 :2 0
b0 :3 0 c0 :3 0
24d9 24da 0 b2
:4 0 24e :4 0 b5
:2 0 b6 :3 0 15c3
24de 24e0 :3 0 b5
:2 0 c9 :4 0 15c6
24e2 24e4 :3 0 b5
:2 0 ef :4 0 15c9
24e6 24e8 :3 0 b5
:2 0 ea :3 0 15cc
24ea 24ec :3 0 b5
:2 0 f0 :4 0 15cf
24ee 24f0 :3 0 b5
:2 0 f1 :3 0 f2
:3 0 46 :2 0 f3
:2 0 15d2 24f3 24f7
15d6 24f2 24f9 :3 0
15d9 24db 24fb :2 0
24fd 15dc 24fe 24d8
24fd 0 24ff 15de
0 2500 15e0 2503
:3 0 2503 0 2503
2502 2500 2501 :6 0
2505 40 :3 0 15e3
2507 15e5 2506 2505
:2 0 2508 15e7 :2 0
250a 0 250a 2509
24c0 2508 :6 0 250e
3f :3 0 24f :3 0
250c :4 0 250e 15e9
2565 24c :3 0 95
:4 0 2512 :2 0 2518
2510 0 21 :3 0
e9 :3 0 2513 2514
0 ea :3 0 2515
2516 0 2518 15ec
2562 eb :3 0 21
:3 0 e9 :3 0 251b
251c 0 ea :3 0
251d 251e 0 2558
ad :3 0 ae :3 0
2520 2521 0 ad
:3 0 bd :3 0 2523
2524 0 ec :2 0
2 :4 0 250 :2 0
bf :2 0 46 :2 0
15ef 2529 252b :3 0
15f2 2525 252d 2522
252f 252e :2 0 b0
:3 0 c0 :3 0 2531
2532 0 b2 :4 0
251 :4 0 b5 :2 0
b6 :3 0 15f6 2536
2538 :3 0 b5 :2 0
c9 :4 0 15f9 253a
253c :3 0 b5 :2 0
ef :4 0 15fc 253e
2540 :3 0 b5 :2 0
ea :3 0 15ff 2542
2544 :3 0 b5 :2 0
f0 :4 0 1602 2546
2548 :3 0 b5 :2 0
f1 :3 0 f2 :3 0
46 :2 0 f3 :2 0
1605 254b 254f 1609
254a 2551 :3 0 160c
2533 2553 :2 0 2555
160f 2556 2530 2555
0 2557 1611 0
2558 1613 255b :3 0
255b 0 255b 255a
2558 2559 :6 0 255d
42 :3 0 1616 255f
1618 255e 255d :2 0
2560 161a :2 0 2562
0 2562 2561 2518
2560 :6 0 2564 3f
:3 0 161c 2566 24b6
250e 0 2567 0
2564 0 2567 161e
0 2568 1621 2569
2491 2568 0 256a
1626 0 28aa 2e
:3 0 16 :3 0 256b
256c 0 28aa 30
:3 0 17 :3 0 256e
256f 0 28aa a1
:3 0 4f :3 0 4d
:2 0 1628 2571 2574
104 :2 0 4d :2 0
162d 2576 2578 :3 0
f1 :3 0 45 :3 0
46 :2 0 46 :2 0
1630 257a 257e d2
:2 0 46 :4 0 1636
2580 2582 :3 0 47
:3 0 18e :4 0 2585
2586 :3 0 2584 2587
0 258c 4e :3 0
4d :2 0 2589 258a
0 258c 1639 26c6
12d :3 0 a1 :3 0
4f :3 0 4d :2 0
163c 258e 2591 163f
258d 2593 c3 :2 0
4d :2 0 1643 2595
2597 :3 0 252 :3 0
253 :3 0 82 :3 0
97 :3 0 98 :3 0
25 :3 0 9a :3 0
39 :3 0 196 :4 0
254 1 :8 0 25a8
21 :3 0 e9 :3 0
25a3 25a4 0 ea
:3 0 25a5 25a6 0
25a8 1646 25f2 eb
:3 0 21 :3 0 e9
:3 0 25ab 25ac 0
ea :3 0 25ad 25ae
0 25e8 ad :3 0
ae :3 0 25b0 25b1
0 ad :3 0 bd
:3 0 25b3 25b4 0
ec :2 0 2 :4 0
255 :2 0 bf :2 0
46 :2 0 1649 25b9
25bb :3 0 164c 25b5
25bd 25b2 25bf 25be
:2 0 b0 :3 0 c0
:3 0 25c1 25c2 0
b2 :4 0 256 :4 0
b5 :2 0 b6 :3 0
1650 25c6 25c8 :3 0
b5 :2 0 c9 :4 0
1653 25ca 25cc :3 0
b5 :2 0 ef :4 0
1656 25ce 25d0 :3 0
b5 :2 0 ea :3 0
1659 25d2 25d4 :3 0
b5 :2 0 f0 :4 0
165c 25d6 25d8 :3 0
b5 :2 0 f1 :3 0
f2 :3 0 46 :2 0
f3 :2 0 165f 25db
25df 1663 25da 25e1
:3 0 1666 25c3 25e3
:2 0 25e5 1669 25e6
25c0 25e5 0 25e7
166b 0 25e8 166d
25eb :3 0 25eb 0
25eb 25ea 25e8 25e9
:6 0 25ed 44 :3 0
1670 25ef 1672 25ee
25ed :2 0 25f0 1674
:2 0 25f2 0 25f2
25f1 25a8 25f0 :6 0
26c2 3f :3 0 a1
:3 0 82 :3 0 4d
:2 0 1676 25f4 25f7
104 :2 0 4d :2 0
167b 25f9 25fb :3 0
24c :3 0 93 :4 0
2600 :2 0 2606 25fe
0 21 :3 0 e9
:3 0 2601 2602 0
ea :3 0 2603 2604
0 2606 167e 2650
eb :3 0 21 :3 0
e9 :3 0 2609 260a
0 ea :3 0 260b
260c 0 2646 ad
:3 0 ae :3 0 260e
260f 0 ad :3 0
bd :3 0 2611 2612
0 ec :2 0 2
:4 0 257 :2 0 bf
:2 0 46 :2 0 1681
2617 2619 :3 0 1684
2613 261b 2610 261d
261c :2 0 b0 :3 0
c0 :3 0 261f 2620
0 b2 :4 0 258
:4 0 b5 :2 0 b6
:3 0 1688 2624 2626
:3 0 b5 :2 0 c9
:4 0 168b 2628 262a
:3 0 b5 :2 0 ef
:4 0 168e 262c 262e
:3 0 b5 :2 0 ea
:3 0 1691 2630 2632
:3 0 b5 :2 0 f0
:4 0 1694 2634 2636
:3 0 b5 :2 0 f1
:3 0 f2 :3 0 46
:2 0 f3 :2 0 1697
2639 263d 169b 2638
263f :3 0 169e 2621
2641 :2 0 2643 16a1
2644 261e 2643 0
2645 16a3 0 2646
16a5 2649 :3 0 2649
0 2649 2648 2646
2647 :6 0 264b 46
:3 0 16a8 264d 16aa
264c 264b :2 0 264e
16ac :2 0 2650 0
2650 264f 2606 264e
:6 0 26bf 3f :3 0
ad :3 0 ae :3 0
2652 2653 0 ad
:3 0 bd :3 0 2655
2656 0 24 :2 0
2 :4 0 259 :2 0
bf :2 0 46 :2 0
16ae 265b 265d :3 0
16b1 2657 265f 2654
2661 2660 :2 0 b0
:3 0 c0 :3 0 2663
2664 0 b2 :4 0
25a :4 0 b5 :2 0
b6 :3 0 16b5 2668
266a :3 0 b5 :2 0
c9 :4 0 16b8 266c
266e :3 0 b5 :2 0
ca :4 0 16bb 2670
2672 :3 0 b5 :2 0
a1 :3 0 ba :3 0
c2 :3 0 25b :3 0
2677 2678 0 16be
2676 267a bb :4 0
16c0 2675 267d 16c3
2674 267f :3 0 b5
:2 0 115 :4 0 16c6
2681 2683 :3 0 b5
:2 0 b8 :4 0 16c9
2685 2687 :3 0 b5
:2 0 39 :3 0 16cc
2689 268b :3 0 b5
:2 0 b8 :4 0 16cf
268d 268f :3 0 16d2
2665 2691 :2 0 2693
16d5 2694 2662 2693
0 2695 16d7 0
26bf ad :3 0 ae
:3 0 2696 2697 0
ad :3 0 bd :3 0
2699 269a 0 46
:2 0 2 :4 0 25c
:2 0 bf :2 0 46
:2 0 16d9 269f 26a1
:3 0 16dc 269b 26a3
2698 26a5 26a4 :2 0
b0 :3 0 c0 :3 0
26a7 26a8 0 b2
:4 0 25d :4 0 b5
:2 0 b6 :3 0 16e0
26ac 26ae :3 0 16e3
26a9 26b0 :2 0 26b2
16e6 26b3 26a6 26b2
0 26b4 16e8 0
26bf ce :3 0 118
:3 0 26b5 26b6 0
c2 :3 0 25b :3 0
26b8 26b9 0 39
:3 0 d0 :3 0 16ea
26b7 26bd :2 0 26bf
16ee 26c0 25fc 26bf
0 26c1 16f3 0
26c2 16f5 26c3 2598
26c2 0 26c4 16f8
0 26c5 16fa 26c7
2583 258c 0 26c8
0 26c5 0 26c8
16fc 0 284b 88
:3 0 25e :3 0 47
:3 0 25 :3 0 26
:3 0 39 :3 0 65
:3 0 4f :3 0 2e
:3 0 30 :3 0 31
:3 0 32 :3 0 41
:3 0 42 :3 0 60
:3 0 58 :3 0 56
:3 0 59 :3 0 5a
:3 0 54 :3 0 5b
:3 0 45 :3 0 52
:3 0 4c :3 0 5c
:3 0 57 :3 0 51
:3 0 5e :3 0 63
:3 0 29 :3 0 a1
:3 0 5e :3 0 4d
:2 0 16ff 26e7 26ea
4d :2 0 67 :2 0
67 :2 0 1702 26ca
26ef 26c9 26f0 0
284b 88 :3 0 c3
:2 0 4d :2 0 1725
26f3 26f5 :3 0 24c
:3 0 93 :4 0 26fa
:2 0 2700 26f8 0
21 :3 0 e9 :3 0
26fb 26fc 0 ea
:3 0 26fd 26fe 0
2700 1728 274a eb
:3 0 21 :3 0 e9
:3 0 2703 2704 0
ea :3 0 2705 2706
0 2740 ad :3 0
ae :3 0 2708 2709
0 ad :3 0 bd
:3 0 270b 270c 0
ec :2 0 2 :4 0
25f :2 0 bf :2 0
46 :2 0 172b 2711
2713 :3 0 172e 270d
2715 270a 2717 2716
:2 0 b0 :3 0 c0
:3 0 2719 271a 0
b2 :4 0 260 :4 0
b5 :2 0 b6 :3 0
1732 271e 2720 :3 0
b5 :2 0 c9 :4 0
1735 2722 2724 :3 0
b5 :2 0 ef :4 0
1738 2726 2728 :3 0
b5 :2 0 ea :3 0
173b 272a 272c :3 0
b5 :2 0 f0 :4 0
173e 272e 2730 :3 0
b5 :2 0 f1 :3 0
f2 :3 0 46 :2 0
f3 :2 0 1741 2733
2737 1745 2732 2739
:3 0 1748 271b 273b
:2 0 273d 174b 273e
2718 273d 0 273f
174d 0 2740 174f
2743 :3 0 2743 0
2743 2742 2740 2741
:6 0 2745 48 :3 0
1752 2747 1754 2746
2745 :2 0 2748 1756
:2 0 274a 0 274a
2749 2700 2748 :6 0
27c5 3f :3 0 88
:3 0 c2 :3 0 f5
:2 0 261 :3 0 274d
274f 0 175a 274e
2751 :3 0 88 :3 0
c2 :3 0 262 :3 0
2754 2755 0 2753
2756 0 2758 175d
2759 2752 2758 0
275a 175f 0 27c5
ad :3 0 ae :3 0
275b 275c 0 ad
:3 0 bd :3 0 275e
275f 0 24 :2 0
2 :4 0 263 :2 0
bf :2 0 46 :2 0
1761 2764 2766 :3 0
1764 2760 2768 275d
276a 2769 :2 0 b0
:3 0 c0 :3 0 276c
276d 0 b2 :4 0
264 :4 0 b5 :2 0
b6 :3 0 1768 2771
2773 :3 0 b5 :2 0
c9 :4 0 176b 2775
2777 :3 0 b5 :2 0
ca :4 0 176e 2779
277b :3 0 b5 :2 0
a1 :3 0 ba :3 0
88 :3 0 1771 277f
2781 bb :4 0 1773
277e 2784 1776 277d
2786 :3 0 b5 :2 0
115 :4 0 1779 2788
278a :3 0 b5 :2 0
b8 :4 0 177c 278c
278e :3 0 b5 :2 0
47 :3 0 177f 2790
2792 :3 0 b5 :2 0
b8 :4 0 1782 2794
2796 :3 0 1785 276e
2798 :2 0 279a 1788
279b 276b 279a 0
279c 178a 0 27c5
ad :3 0 ae :3 0
279d 279e 0 ad
:3 0 bd :3 0 27a0
27a1 0 46 :2 0
2 :4 0 265 :2 0
bf :2 0 46 :2 0
178c 27a6 27a8 :3 0
178f 27a2 27aa 279f
27ac 27ab :2 0 b0
:3 0 c0 :3 0 27ae
27af 0 b2 :4 0
266 :4 0 b5 :2 0
b6 :3 0 1793 27b3
27b5 :3 0 1796 27b0
27b7 :2 0 27b9 1799
27ba 27ad 27b9 0
27bb 179b 0 27c5
ce :3 0 118 :3 0
27bc 27bd 0 88
:3 0 47 :3 0 d0
:3 0 179d 27be 27c2
:2 0 27c5 d9 :3 0
17a1 2847 f1 :3 0
45 :3 0 46 :2 0
46 :2 0 17a7 27c6
27ca d2 :2 0 46
:4 0 17ad 27cc 27ce
:3 0 27cf :2 0 f1
:3 0 4b :3 0 46
:2 0 46 :2 0 17b0
27d1 27d5 d2 :2 0
1af :4 0 17b6 27d7
27d9 :3 0 27da :2 0
27d0 27dc 27db :2 0
18f :3 0 10a :3 0
190 :3 0 39 :3 0
10a :4 0 267 1
:8 0 27f9 1b5 :4 0
27e4 :3 0 d0 :3 0
d2 :2 0 17bb 27e7
27e8 :3 0 21 :3 0
e9 :3 0 27ea 27eb
0 4d :2 0 27ec
27ed 0 27ef 17be
27f6 21 :3 0 e9
:3 0 27f0 27f1 0
17f :2 0 27f2 27f3
0 27f5 17c0 27f7
27e9 27ef 0 27f8
0 27f5 0 27f8
17c2 0 27f9 17c5
2843 eb :3 0 21
:3 0 e9 :3 0 27fc
27fd 0 ea :3 0
27fe 27ff 0 2839
ad :3 0 ae :3 0
2801 2802 0 ad
:3 0 bd :3 0 2804
2805 0 ec :2 0
2 :4 0 268 :2 0
bf :2 0 46 :2 0
17c8 280a 280c :3 0
17cb 2806 280e 2803
2810 280f :2 0 b0
:3 0 c0 :3 0 2812
2813 0 b2 :4 0
269 :4 0 b5 :2 0
b6 :3 0 17cf 2817
2819 :3 0 b5 :2 0
c9 :4 0 17d2 281b
281d :3 0 b5 :2 0
ef :4 0 17d5 281f
2821 :3 0 b5 :2 0
ea :3 0 17d8 2823
2825 :3 0 b5 :2 0
f0 :4 0 17db 2827
2829 :3 0 b5 :2 0
f1 :3 0 f2 :3 0
46 :2 0 f3 :2 0
17de 282c 2830 17e2
282b 2832 :3 0 17e5
2814 2834 :2 0 2836
17e8 2837 2811 2836
0 2838 17ea 0
2839 17ec 283c :3 0
283c 0 283c 283b
2839 283a :6 0 283e
4a :3 0 17ef 2840
17f1 283f 283e :2 0
2841 17f3 :2 0 2843
0 2843 2842 27f9
2841 :6 0 2845 3f
:3 0 17f5 2846 27dd
2845 0 2848 26f6
27c5 0 2848 17f7
0 284b 1f4 :8 0
284b 17fa 28a3 a1
:3 0 4c :3 0 4d
:2 0 17ff 284c 284f
c2 :3 0 c3 :2 0
c4 :3 0 2851 2853
0 1804 2852 2855
:3 0 41 :3 0 5
:3 0 2857 2858 0
285d 42 :3 0 6
:3 0 285a 285b 0
285d 1807 285e 2856
285d 0 285f 180a
0 28a2 88 :3 0
25e :3 0 47 :3 0
25 :3 0 26 :3 0
39 :3 0 65 :3 0
4f :3 0 2e :3 0
30 :3 0 31 :3 0
32 :3 0 41 :3 0
42 :3 0 60 :3 0
58 :3 0 56 :3 0
59 :3 0 5a :3 0
54 :3 0 5b :3 0
45 :3 0 52 :3 0
4c :3 0 5c :3 0
57 :3 0 51 :3 0
5e :3 0 63 :3 0
29 :3 0 4d :2 0
4d :2 0 67 :2 0
67 :2 0 180c 2861
2882 2860 2883 0
28a2 88 :3 0 d2
:2 0 4d :2 0 182f
2886 2888 :3 0 87
:3 0 87 :3 0 bf
:2 0 46 :2 0 1832
288c 288e :3 0 288a
288f 0 2891 1835
2892 2889 2891 0
2893 1837 0 28a2
87 :3 0 a1 :3 0
d2 :2 0 55 :3 0
4d :2 0 1839 2895
2899 183e 2896 289b
:3 0 1f4 :8 0 289f
1841 28a0 289c 289f
0 28a1 1843 0
28a2 1845 28a4 2579
284b 0 28a5 0
28a2 0 28a5 184a
0 28aa 24f :5 0
28a8 4c 0 28a9
184d 28a8 28a7 28aa
184f 28ac 1f0 :4 0
28aa :4 0 3423 24c
:3 0 93 :4 0 28b0
:2 0 28b6 28ae 0
21 :3 0 e9 :3 0
28b1 28b2 0 ea
:3 0 28b3 28b4 0
28b6 1858 2900 eb
:3 0 21 :3 0 e9
:3 0 28b9 28ba 0
ea :3 0 28bb 28bc
0 28f6 ad :3 0
ae :3 0 28be 28bf
0 ad :3 0 bd
:3 0 28c1 28c2 0
ec :2 0 2 :4 0
26a :2 0 bf :2 0
46 :2 0 185b 28c7
28c9 :3 0 185e 28c3
28cb 28c0 28cd 28cc
:2 0 b0 :3 0 c0
:3 0 28cf 28d0 0
b2 :4 0 26b :4 0
b5 :2 0 b6 :3 0
1862 28d4 28d6 :3 0
b5 :2 0 c9 :4 0
1865 28d8 28da :3 0
b5 :2 0 ef :4 0
1868 28dc 28de :3 0
b5 :2 0 ea :3 0
186b 28e0 28e2 :3 0
b5 :2 0 f0 :4 0
186e 28e4 28e6 :3 0
b5 :2 0 f1 :3 0
f2 :3 0 46 :2 0
f3 :2 0 1871 28e9
28ed 1875 28e8 28ef
:3 0 1878 28d1 28f1
:2 0 28f3 187b 28f4
28ce 28f3 0 28f5
187d 0 28f6 187f
28f9 :3 0 28f9 0
28f9 28f8 28f6 28f7
:6 0 28fb 4c :3 0
1882 28fd 1884 28fc
28fb :2 0 28fe 1886
:2 0 2900 0 2900
28ff 28b6 28fe :6 0
3423 1 :3 0 88
:3 0 c2 :3 0 d2
:2 0 26c :3 0 2903
2905 0 188a 2904
2907 :3 0 2908 :2 0
88 :3 0 c3 :2 0
4d :2 0 188f 290b
290d :3 0 290e :2 0
a1 :3 0 4f :3 0
4d :2 0 1892 2910
2913 104 :2 0 4d
:2 0 1897 2915 2917
:3 0 2918 :2 0 290f
291a 2919 :2 0 291b
:2 0 2909 291d 291c
:2 0 ad :3 0 ae
:3 0 291f 2920 0
ad :3 0 bd :3 0
2922 2923 0 24
:2 0 2 :4 0 26d
:2 0 bf :2 0 46
:2 0 189a 2928 292a
:3 0 189d 2924 292c
2921 292e 292d :2 0
b0 :3 0 c0 :3 0
2930 2931 0 b2
:4 0 26e :4 0 b5
:2 0 b6 :3 0 18a1
2935 2937 :3 0 b5
:2 0 c9 :4 0 18a4
2939 293b :3 0 b5
:2 0 ca :4 0 18a7
293d 293f :3 0 b5
:2 0 a1 :3 0 ba
:3 0 88 :3 0 18aa
2943 2945 bb :4 0
18ac 2942 2948 18af
2941 294a :3 0 b5
:2 0 115 :4 0 18b2
294c 294e :3 0 b5
:2 0 b8 :4 0 18b5
2950 2952 :3 0 b5
:2 0 47 :3 0 18b8
2954 2956 :3 0 b5
:2 0 b8 :4 0 18bb
2958 295a :3 0 18be
2932 295c :2 0 295e
18c1 295f 292f 295e
0 2960 18c3 0
2988 ad :3 0 ae
:3 0 2961 2962 0
ad :3 0 bd :3 0
2964 2965 0 46
:2 0 2 :4 0 26f
:2 0 bf :2 0 46
:2 0 18c5 296a 296c
:3 0 18c8 2966 296e
2963 2970 296f :2 0
b0 :3 0 c0 :3 0
2972 2973 0 b2
:4 0 270 :4 0 b5
:2 0 b6 :3 0 18cc
2977 2979 :3 0 18cf
2974 297b :2 0 297d
18d2 297e 2971 297d
0 297f 18d4 0
2988 ce :3 0 118
:3 0 2980 2981 0
88 :3 0 47 :3 0
d0 :3 0 18d6 2982
2986 :2 0 2988 18da
2989 291e 2988 0
298a 18de 0 3423
8b :3 0 c3 :2 0
46 :2 0 18e2 298c
298e :3 0 27 :3 0
271 :4 0 2990 2991
0 2cb1 28 :3 0
181 :4 0 2993 2994
0 2cb1 3a :3 0
181 :4 0 2996 2997
0 2cb1 24b :3 0
9c :4 0 299c :2 0
2cb1 299a 299d :3 0
85 :3 0 4d :2 0
299e 299f 0 2cb1
1f0 :3 0 9c :3 0
26 :3 0 39 :3 0
48 :3 0 33 :3 0
49 :3 0 34 :3 0
35 :3 0 36 :4 0
29ac :2 0 2be0 29a2
29ad :3 0 18e5 :3 0
9c :3 0 1b5 :3 0
29ae 29af :3 0 21
:3 0 e9 :3 0 29b1
29b2 0 4d :2 0
29b3 29b4 0 29b6
18ee 29bd 21 :3 0
e9 :3 0 29b7 29b8
0 17f :2 0 29b9
29ba 0 29bc 18f0
29be 29b0 29b6 0
29bf 0 29bc 0
29bf 18f2 0 2be0
21 :3 0 e9 :3 0
29c0 29c1 0 21
:3 0 c3 :2 0 f4
:3 0 29c3 29c5 0
18f7 29c4 29c7 :3 0
29c8 :2 0 1f4 :8 0
29cc 18fa 29cd 29c9
29cc 0 29ce 18fc
0 2be0 48 :3 0
e4 :2 0 18fe 29d0
29d1 :3 0 29d2 :2 0
e5 :3 0 110 :3 0
29d4 29d5 0 48
:3 0 39 :3 0 1900
29d6 29d9 d2 :2 0
4d :2 0 1905 29db
29dd :3 0 29d3 29df
29de :2 0 a1 :3 0
1e7 :3 0 27 :3 0
1908 29e2 29e4 4d
:2 0 190a 29e1 29e7
d2 :2 0 4d :2 0
190f 29e9 29eb :3 0
29e0 29ed 29ec :2 0
27 :3 0 26 :3 0
29ef 29f0 0 29f2
1912 29f3 29ee 29f2
0 29f4 1914 0
2be0 e5 :3 0 110
:3 0 29f5 29f6 0
28 :3 0 39 :3 0
1916 29f7 29fa c3
:2 0 4d :2 0 191b
29fc 29fe :3 0 85
:3 0 c3 :2 0 4d
:2 0 1920 2a01 2a03
:3 0 a7 :3 0 a0
:3 0 37 :3 0 a2
:3 0 2e :3 0 a3
:3 0 38 :3 0 a4
:3 0 30 :3 0 a5
:3 0 31 :3 0 a6
:3 0 32 :3 0 9d
:3 0 3a :4 0 272
1 :8 0 2a2a 1b5
:4 0 2a15 :3 0 d0
:3 0 d2 :2 0 1925
2a18 2a19 :3 0 21
:3 0 e9 :3 0 2a1b
2a1c 0 4d :2 0
2a1d 2a1e 0 2a20
1928 2a27 21 :3 0
e9 :3 0 2a21 2a22
0 17f :2 0 2a23
2a24 0 2a26 192a
2a28 2a1a 2a20 0
2a29 0 2a26 0
2a29 192c 0 2a2a
192f 2a74 eb :3 0
21 :3 0 e9 :3 0
2a2d 2a2e 0 ea
:3 0 2a2f 2a30 0
2a6a ad :3 0 ae
:3 0 2a32 2a33 0
ad :3 0 bd :3 0
2a35 2a36 0 ec
:2 0 2 :4 0 273
:2 0 bf :2 0 46
:2 0 1932 2a3b 2a3d
:3 0 1935 2a37 2a3f
2a34 2a41 2a40 :2 0
b0 :3 0 c0 :3 0
2a43 2a44 0 b2
:4 0 274 :4 0 b5
:2 0 b6 :3 0 1939
2a48 2a4a :3 0 b5
:2 0 c9 :4 0 193c
2a4c 2a4e :3 0 b5
:2 0 ef :4 0 193f
2a50 2a52 :3 0 b5
:2 0 ea :3 0 1942
2a54 2a56 :3 0 b5
:2 0 f0 :4 0 1945
2a58 2a5a :3 0 b5
:2 0 f1 :3 0 f2
:3 0 46 :2 0 f3
:2 0 1948 2a5d 2a61
194c 2a5c 2a63 :3 0
194f 2a45 2a65 :2 0
2a67 1952 2a68 2a42
2a67 0 2a69 1954
0 2a6a 1956 2a6d
:3 0 2a6d 0 2a6d
2a6c 2a6a 2a6b :6 0
2a6f 4f :3 0 1959
2a71 195b 2a70 2a6f
:2 0 2a72 195d :2 0
2a74 0 2a74 2a73
2a2a 2a72 :6 0 2a76
4e :3 0 195f 2a77
2a04 2a76 0 2a78
1961 0 2a91 2e
:3 0 181 :4 0 2a79
2a7a 0 2a91 30
:3 0 181 :4 0 2a7c
2a7d 0 2a91 31
:3 0 181 :4 0 2a7f
2a80 0 2a91 32
:3 0 181 :4 0 2a82
2a83 0 2a91 37
:3 0 181 :4 0 2a85
2a86 0 2a91 38
:3 0 181 :4 0 2a88
2a89 0 2a91 28
:3 0 39 :3 0 2a8b
2a8c 0 2a91 85
:3 0 4d :2 0 2a8e
2a8f 0 2a91 1963
2a92 29ff 2a91 0
2a93 196d 0 2be0
85 :3 0 c3 :2 0
4d :2 0 1971 2a95
2a97 :3 0 3a :3 0
e4 :2 0 1974 2a9a
2a9b :3 0 2a9c :2 0
2a98 2a9e 2a9d :2 0
a7 :3 0 a0 :3 0
a2 :3 0 a3 :3 0
a4 :3 0 a5 :3 0
a6 :3 0 9d :3 0
3a :4 0 275 1
:8 0 2abf 1b5 :4 0
2aaa :3 0 d0 :3 0
d2 :2 0 1978 2aad
2aae :3 0 21 :3 0
e9 :3 0 2ab0 2ab1
0 4d :2 0 2ab2
2ab3 0 2ab5 197b
2abc 21 :3 0 e9
:3 0 2ab6 2ab7 0
17f :2 0 2ab8 2ab9
0 2abb 197d 2abd
2aaf 2ab5 0 2abe
0 2abb 0 2abe
197f 0 2abf 1982
2b09 eb :3 0 21
:3 0 e9 :3 0 2ac2
2ac3 0 ea :3 0
2ac4 2ac5 0 2aff
ad :3 0 ae :3 0
2ac7 2ac8 0 ad
:3 0 bd :3 0 2aca
2acb 0 ec :2 0
2 :4 0 276 :2 0
bf :2 0 46 :2 0
1985 2ad0 2ad2 :3 0
1988 2acc 2ad4 2ac9
2ad6 2ad5 :2 0 b0
:3 0 c0 :3 0 2ad8
2ad9 0 b2 :4 0
277 :4 0 b5 :2 0
b6 :3 0 198c 2add
2adf :3 0 b5 :2 0
c9 :4 0 198f 2ae1
2ae3 :3 0 b5 :2 0
ef :4 0 1992 2ae5
2ae7 :3 0 b5 :2 0
ea :3 0 1995 2ae9
2aeb :3 0 b5 :2 0
f0 :4 0 1998 2aed
2aef :3 0 b5 :2 0
f1 :3 0 f2 :3 0
46 :2 0 f3 :2 0
199b 2af2 2af6 199f
2af1 2af8 :3 0 19a2
2ada 2afa :2 0 2afc
19a5 2afd 2ad7 2afc
0 2afe 19a7 0
2aff 19a9 2b02 :3 0
2b02 0 2b02 2b01
2aff 2b00 :6 0 2b04
51 :3 0 19ac 2b06
19ae 2b05 2b04 :2 0
2b07 19b0 :2 0 2b09
0 2b09 2b08 2abf
2b07 :6 0 2b0b 4e
:3 0 19b2 2b0c 2a9f
2b0b 0 2b0d 19b4
0 2be0 33 :3 0
e4 :2 0 19b6 2b0f
2b10 :3 0 2b11 :2 0
2e :3 0 e4 :2 0
19b8 2b14 2b15 :3 0
2b16 :2 0 2e :3 0
f1 :3 0 2e :3 0
b5 :2 0 278 :4 0
19ba 2b1b 2b1d :3 0
46 :2 0 2f :2 0
19bd 2b19 2b21 2b18
2b22 0 2b24 19c1
2b25 2b17 2b24 0
2b26 19c3 0 2b33
2e :3 0 f1 :3 0
2e :3 0 b5 :2 0
33 :3 0 19c5 2b2a
2b2c :3 0 46 :2 0
2f :2 0 19c8 2b28
2b30 2b27 2b31 0
2b33 19cc 2b34 2b12
2b33 0 2b35 19cf
0 2be0 48 :3 0
e4 :2 0 19d1 2b37
2b38 :3 0 2b39 :2 0
37 :3 0 f1 :3 0
37 :3 0 b5 :2 0
48 :3 0 19d3 2b3e
2b40 :3 0 46 :2 0
2f :2 0 19d6 2b3c
2b44 2b3b 2b45 0
2b47 19da 2b48 2b3a
2b47 0 2b49 19dc
0 2be0 34 :3 0
e4 :2 0 19de 2b4b
2b4c :3 0 2b4d :2 0
30 :3 0 e4 :2 0
19e0 2b50 2b51 :3 0
2b52 :2 0 30 :3 0
f1 :3 0 30 :3 0
b5 :2 0 278 :4 0
19e2 2b57 2b59 :3 0
46 :2 0 2f :2 0
19e5 2b55 2b5d 2b54
2b5e 0 2b60 19e9
2b61 2b53 2b60 0
2b62 19eb 0 2b6f
30 :3 0 f1 :3 0
30 :3 0 b5 :2 0
34 :3 0 19ed 2b66
2b68 :3 0 46 :2 0
2f :2 0 19f0 2b64
2b6c 2b63 2b6d 0
2b6f 19f4 2b70 2b4e
2b6f 0 2b71 19f7
0 2be0 49 :3 0
e4 :2 0 19f9 2b73
2b74 :3 0 2b75 :2 0
38 :3 0 f1 :3 0
38 :3 0 b5 :2 0
49 :3 0 19fb 2b7a
2b7c :3 0 46 :2 0
2f :2 0 19fe 2b78
2b80 2b77 2b81 0
2b83 1a02 2b84 2b76
2b83 0 2b85 1a04
0 2be0 35 :3 0
e4 :2 0 1a06 2b87
2b88 :3 0 2b89 :2 0
31 :3 0 e4 :2 0
1a08 2b8c 2b8d :3 0
2b8e :2 0 31 :3 0
f1 :3 0 31 :3 0
b5 :2 0 278 :4 0
1a0a 2b93 2b95 :3 0
46 :2 0 2f :2 0
1a0d 2b91 2b99 2b90
2b9a 0 2b9c 1a11
2b9d 2b8f 2b9c 0
2b9e 1a13 0 2bab
31 :3 0 f1 :3 0
31 :3 0 b5 :2 0
35 :3 0 1a15 2ba2
2ba4 :3 0 46 :2 0
2f :2 0 1a18 2ba0
2ba8 2b9f 2ba9 0
2bab 1a1c 2bac 2b8a
2bab 0 2bad 1a1f
0 2be0 36 :3 0
e4 :2 0 1a21 2baf
2bb0 :3 0 2bb1 :2 0
32 :3 0 e4 :2 0
1a23 2bb4 2bb5 :3 0
2bb6 :2 0 32 :3 0
f1 :3 0 32 :3 0
b5 :2 0 278 :4 0
1a25 2bbb 2bbd :3 0
46 :2 0 2f :2 0
1a28 2bb9 2bc1 2bb8
2bc2 0 2bc4 1a2c
2bc5 2bb7 2bc4 0
2bc6 1a2e 0 2bd3
32 :3 0 f1 :3 0
32 :3 0 b5 :2 0
36 :3 0 1a30 2bca
2bcc :3 0 46 :2 0
2f :2 0 1a33 2bc8
2bd0 2bc7 2bd1 0
2bd3 1a37 2bd4 2bb2
2bd3 0 2bd5 1a3a
0 2be0 85 :3 0
85 :3 0 bf :2 0
46 :2 0 1a3c 2bd8
2bda :3 0 2bd6 2bdb
0 2be0 3a :3 0
26 :3 0 2bdd 2bde
0 2be0 1a3f 2be2
1f0 :4 0 2be0 :4 0
2cb1 24c :3 0 9c
:4 0 2be6 :2 0 2bec
2be4 0 21 :3 0
e9 :3 0 2be7 2be8
0 ea :3 0 2be9
2bea 0 2bec 1a4e
2c36 eb :3 0 21
:3 0 e9 :3 0 2bef
2bf0 0 ea :3 0
2bf1 2bf2 0 2c2c
ad :3 0 ae :3 0
2bf4 2bf5 0 ad
:3 0 bd :3 0 2bf7
2bf8 0 ec :2 0
2 :4 0 279 :2 0
bf :2 0 46 :2 0
1a51 2bfd 2bff :3 0
1a54 2bf9 2c01 2bf6
2c03 2c02 :2 0 b0
:3 0 c0 :3 0 2c05
2c06 0 b2 :4 0
27a :4 0 b5 :2 0
b6 :3 0 1a58 2c0a
2c0c :3 0 b5 :2 0
c9 :4 0 1a5b 2c0e
2c10 :3 0 b5 :2 0
ef :4 0 1a5e 2c12
2c14 :3 0 b5 :2 0
ea :3 0 1a61 2c16
2c18 :3 0 b5 :2 0
f0 :4 0 1a64 2c1a
2c1c :3 0 b5 :2 0
f1 :3 0 f2 :3 0
46 :2 0 f3 :2 0
1a67 2c1f 2c23 1a6b
2c1e 2c25 :3 0 1a6e
2c07 2c27 :2 0 2c29
1a71 2c2a 2c04 2c29
0 2c2b 1a73 0
2c2c 1a75 2c2f :3 0
2c2f 0 2c2f 2c2e
2c2c 2c2d :6 0 2c31
53 :3 0 1a78 2c33
1a7a 2c32 2c31 :2 0
2c34 1a7c :2 0 2c36
0 2c36 2c35 2bec
2c34 :6 0 2cb1 1
:3 0 85 :3 0 c3
:2 0 4d :2 0 1a80
2c39 2c3b :3 0 a7
:3 0 a0 :3 0 37
:3 0 a2 :3 0 2e
:3 0 a3 :3 0 38
:3 0 a4 :3 0 30
:3 0 a5 :3 0 31
:3 0 a6 :3 0 32
:3 0 9d :3 0 3a
:4 0 27b 1 :8 0
2c62 1b5 :4 0 2c4d
:3 0 d0 :3 0 d2
:2 0 1a85 2c50 2c51
:3 0 21 :3 0 e9
:3 0 2c53 2c54 0
4d :2 0 2c55 2c56
0 2c58 1a88 2c5f
21 :3 0 e9 :3 0
2c59 2c5a 0 17f
:2 0 2c5b 2c5c 0
2c5e 1a8a 2c60 2c52
2c58 0 2c61 0
2c5e 0 2c61 1a8c
0 2c62 1a8f 2cac
eb :3 0 21 :3 0
e9 :3 0 2c65 2c66
0 ea :3 0 2c67
2c68 0 2ca2 ad
:3 0 ae :3 0 2c6a
2c6b 0 ad :3 0
bd :3 0 2c6d 2c6e
0 ec :2 0 2
:4 0 27c :2 0 bf
:2 0 46 :2 0 1a92
2c73 2c75 :3 0 1a95
2c6f 2c77 2c6c 2c79
2c78 :2 0 b0 :3 0
c0 :3 0 2c7b 2c7c
0 b2 :4 0 27d
:4 0 b5 :2 0 b6
:3 0 1a99 2c80 2c82
:3 0 b5 :2 0 c9
:4 0 1a9c 2c84 2c86
:3 0 b5 :2 0 ef
:4 0 1a9f 2c88 2c8a
:3 0 b5 :2 0 ea
:3 0 1aa2 2c8c 2c8e
:3 0 b5 :2 0 f0
:4 0 1aa5 2c90 2c92
:3 0 b5 :2 0 f1
:3 0 f2 :3 0 46
:2 0 f3 :2 0 1aa8
2c95 2c99 1aac 2c94
2c9b :3 0 1aaf 2c7d
2c9d :2 0 2c9f 1ab2
2ca0 2c7a 2c9f 0
2ca1 1ab4 0 2ca2
1ab6 2ca5 :3 0 2ca5
0 2ca5 2ca4 2ca2
2ca3 :6 0 2ca7 55
:3 0 1ab9 2ca9 1abb
2ca8 2ca7 :2 0 2caa
1abd :2 0 2cac 0
2cac 2cab 2c62 2caa
:6 0 2cae 1 :3 0
1abf 2caf 2c3c 2cae
0 2cb0 1ac1 0
2cb1 1ac3 2cb2 298f
2cb1 0 2cb3 1acc
0 3423 6 :3 0
e4 :2 0 1ace 2cb5
2cb6 :3 0 2cb7 :2 0
a1 :3 0 56 :3 0
4d :2 0 1ad0 2cb9
2cbc d2 :2 0 4d
:2 0 1ad5 2cbe 2cc0
:3 0 a1 :3 0 27e
:3 0 27f :3 0 58
:3 0 280 :3 0 10c
:3 0 25 :3 0 281
:3 0 282 :3 0 f1
:3 0 41 :3 0 282
:3 0 f1 :3 0 42
:4 0 283 1 :8 0
2cd6 21 :3 0 e9
:3 0 2cd1 2cd2 0
ea :3 0 2cd3 2cd4
0 2cd6 1ad8 2d20
eb :3 0 21 :3 0
e9 :3 0 2cd9 2cda
0 ea :3 0 2cdb
2cdc 0 2d16 ad
:3 0 ae :3 0 2cde
2cdf 0 ad :3 0
bd :3 0 2ce1 2ce2
0 ec :2 0 2
:4 0 284 :2 0 bf
:2 0 46 :2 0 1adb
2ce7 2ce9 :3 0 1ade
2ce3 2ceb 2ce0 2ced
2cec :2 0 b0 :3 0
c0 :3 0 2cef 2cf0
0 b2 :4 0 285
:4 0 b5 :2 0 b6
:3 0 1ae2 2cf4 2cf6
:3 0 b5 :2 0 c9
:4 0 1ae5 2cf8 2cfa
:3 0 b5 :2 0 ef
:4 0 1ae8 2cfc 2cfe
:3 0 b5 :2 0 ea
:3 0 1aeb 2d00 2d02
:3 0 b5 :2 0 f0
:4 0 1aee 2d04 2d06
:3 0 b5 :2 0 f1
:3 0 f2 :3 0 46
:2 0 f3 :2 0 1af1
2d09 2d0d 1af5 2d08
2d0f :3 0 1af8 2cf1
2d11 :2 0 2d13 1afb
2d14 2cee 2d13 0
2d15 1afd 0 2d16
1aff 2d19 :3 0 2d19
0 2d19 2d18 2d16
2d17 :6 0 2d1b 57
:3 0 1b02 2d1d 1b04
2d1c 2d1b :2 0 2d1e
1b06 :2 0 2d20 0
2d20 2d1f 2cd6 2d1e
:6 0 2d22 1 :3 0
1b08 2d28 60 :3 0
4d :2 0 2d23 2d24
0 2d27 0 2d27
1b0a 2d29 2cc1 2d22
0 2d2a 0 2d27
0 2d2a 1b0d 0
2d2b 1b10 2d2c 2cb8
2d2b 0 2d2d 1b12
0 3423 286 :3 0
e5 :3 0 287 :3 0
288 :3 0 1a3 :3 0
6b :3 0 68 :3 0
10b :3 0 289 :3 0
1df :3 0 28a :3 0
288 :3 0 289 :3 0
286 :3 0 288 :3 0
10c :3 0 289 :3 0
10c :3 0 25 :4 0
28b 1 :8 0 2d47
21 :3 0 e9 :3 0
2d42 2d43 0 ea
:3 0 2d44 2d45 0
2d47 1b14 2d91 eb
:3 0 21 :3 0 e9
:3 0 2d4a 2d4b 0
ea :3 0 2d4c 2d4d
0 2d87 ad :3 0
ae :3 0 2d4f 2d50
0 ad :3 0 bd
:3 0 2d52 2d53 0
ec :2 0 2 :4 0
28c :2 0 bf :2 0
46 :2 0 1b17 2d58
2d5a :3 0 1b1a 2d54
2d5c 2d51 2d5e 2d5d
:2 0 b0 :3 0 c0
:3 0 2d60 2d61 0
b2 :4 0 28d :4 0
b5 :2 0 b6 :3 0
1b1e 2d65 2d67 :3 0
b5 :2 0 c9 :4 0
1b21 2d69 2d6b :3 0
b5 :2 0 ef :4 0
1b24 2d6d 2d6f :3 0
b5 :2 0 ea :3 0
1b27 2d71 2d73 :3 0
b5 :2 0 f0 :4 0
1b2a 2d75 2d77 :3 0
b5 :2 0 f1 :3 0
f2 :3 0 46 :2 0
f3 :2 0 1b2d 2d7a
2d7e 1b31 2d79 2d80
:3 0 1b34 2d62 2d82
:2 0 2d84 1b37 2d85
2d5f 2d84 0 2d86
1b39 0 2d87 1b3b
2d8a :3 0 2d8a 0
2d8a 2d89 2d87 2d88
:6 0 2d8c 59 :3 0
1b3e 2d8e 1b40 2d8d
2d8c :2 0 2d8f 1b42
:2 0 2d91 0 2d91
2d90 2d47 2d8f :6 0
3423 1 :3 0 a1
:3 0 5b :3 0 4d
:2 0 1b44 2d93 2d96
c2 :3 0 d2 :2 0
d3 :3 0 2d98 2d9a
0 1b49 2d99 2d9c
:3 0 1d7 :3 0 1d8
:3 0 28e :4 0 2da0
:4 0 2da1 :2 0 2ffc
21 :3 0 e9 :3 0
2da3 2da4 0 4d
:2 0 2da5 2da6 0
2ffc 28f :3 0 9e
:3 0 290 :3 0 291
:3 0 292 :3 0 293
:3 0 a7 :3 0 9d
:3 0 27 :3 0 290
:3 0 291 :4 0 294
1 :8 0 2dc9 1b5
:4 0 2db4 :3 0 d0
:3 0 d2 :2 0 1b4e
2db7 2db8 :3 0 21
:3 0 e9 :3 0 2dba
2dbb 0 4d :2 0
2dbc 2dbd 0 2dbf
1b51 2dc6 21 :3 0
e9 :3 0 2dc0 2dc1
0 17f :2 0 2dc2
2dc3 0 2dc5 1b53
2dc7 2db9 2dbf 0
2dc8 0 2dc5 0
2dc8 1b55 0 2dc9
1b58 2e13 eb :3 0
21 :3 0 e9 :3 0
2dcc 2dcd 0 ea
:3 0 2dce 2dcf 0
2e09 ad :3 0 ae
:3 0 2dd1 2dd2 0
ad :3 0 bd :3 0
2dd4 2dd5 0 ec
:2 0 2 :4 0 295
:2 0 bf :2 0 46
:2 0 1b5b 2dda 2ddc
:3 0 1b5e 2dd6 2dde
2dd3 2de0 2ddf :2 0
b0 :3 0 c0 :3 0
2de2 2de3 0 b2
:4 0 296 :4 0 b5
:2 0 b6 :3 0 1b62
2de7 2de9 :3 0 b5
:2 0 c9 :4 0 1b65
2deb 2ded :3 0 b5
:2 0 ef :4 0 1b68
2def 2df1 :3 0 b5
:2 0 ea :3 0 1b6b
2df3 2df5 :3 0 b5
:2 0 f0 :4 0 1b6e
2df7 2df9 :3 0 b5
:2 0 f1 :3 0 f2
:3 0 46 :2 0 f3
:2 0 1b71 2dfc 2e00
1b75 2dfb 2e02 :3 0
1b78 2de4 2e04 :2 0
2e06 1b7b 2e07 2de1
2e06 0 2e08 1b7d
0 2e09 1b7f 2e0c
:3 0 2e0c 0 2e0c
2e0b 2e09 2e0a :6 0
2e0e 5b :3 0 1b82
2e10 1b84 2e0f 2e0e
:2 0 2e11 1b86 :2 0
2e13 0 2e13 2e12
2dc9 2e11 :6 0 2ffc
1 :3 0 21 :3 0
e9 :3 0 2e15 2e16
0 21 :3 0 d2
:2 0 165 :3 0 2e18
2e1a 0 1b8a 2e19
2e1c :3 0 2e1d :2 0
28f :3 0 9e :3 0
19c :3 0 290 :3 0
290 :3 0 19c :3 0
291 :3 0 291 :3 0
19c :3 0 292 :3 0
292 :3 0 19c :3 0
293 :3 0 293 :3 0
a7 :3 0 9d :3 0
27 :3 0 9e :4 0
297 1 :8 0 2e47
1b5 :4 0 2e32 :3 0
d0 :3 0 d2 :2 0
1b8f 2e35 2e36 :3 0
21 :3 0 e9 :3 0
2e38 2e39 0 4d
:2 0 2e3a 2e3b 0
2e3d 1b92 2e44 21
:3 0 e9 :3 0 2e3e
2e3f 0 17f :2 0
2e40 2e41 0 2e43
1b94 2e45 2e37 2e3d
0 2e46 0 2e43
0 2e46 1b96 0
2e47 1b99 2e91 eb
:3 0 21 :3 0 e9
:3 0 2e4a 2e4b 0
ea :3 0 2e4c 2e4d
0 2e87 ad :3 0
ae :3 0 2e4f 2e50
0 ad :3 0 bd
:3 0 2e52 2e53 0
ec :2 0 2 :4 0
298 :2 0 bf :2 0
46 :2 0 1b9c 2e58
2e5a :3 0 1b9f 2e54
2e5c 2e51 2e5e 2e5d
:2 0 b0 :3 0 c0
:3 0 2e60 2e61 0
b2 :4 0 299 :4 0
b5 :2 0 b6 :3 0
1ba3 2e65 2e67 :3 0
b5 :2 0 c9 :4 0
1ba6 2e69 2e6b :3 0
b5 :2 0 ef :4 0
1ba9 2e6d 2e6f :3 0
b5 :2 0 ea :3 0
1bac 2e71 2e73 :3 0
b5 :2 0 f0 :4 0
1baf 2e75 2e77 :3 0
b5 :2 0 f1 :3 0
f2 :3 0 46 :2 0
f3 :2 0 1bb2 2e7a
2e7e 1bb6 2e79 2e80
:3 0 1bb9 2e62 2e82
:2 0 2e84 1bbc 2e85
2e5f 2e84 0 2e86
1bbe 0 2e87 1bc0
2e8a :3 0 2e8a 0
2e8a 2e89 2e87 2e88
:6 0 2e8c 5d :3 0
1bc3 2e8e 1bc5 2e8d
2e8c :2 0 2e8f 1bc7
:2 0 2e91 0 2e91
2e90 2e47 2e8f :6 0
2f08 1 :3 0 21
:3 0 e9 :3 0 2e93
2e94 0 21 :3 0
d2 :2 0 165 :3 0
2e96 2e98 0 1bcb
2e97 2e9a :3 0 2e9b
:2 0 28f :3 0 9e
:3 0 a7 :3 0 9d
:3 0 27 :3 0 9e
:4 0 29a 1 :8 0
2eb9 1b5 :4 0 2ea4
:3 0 d0 :3 0 d2
:2 0 1bd0 2ea7 2ea8
:3 0 21 :3 0 e9
:3 0 2eaa 2eab 0
4d :2 0 2eac 2ead
0 2eaf 1bd3 2eb6
21 :3 0 e9 :3 0
2eb0 2eb1 0 17f
:2 0 2eb2 2eb3 0
2eb5 1bd5 2eb7 2ea9
2eaf 0 2eb8 0
2eb5 0 2eb8 1bd7
0 2eb9 1bda 2f03
eb :3 0 21 :3 0
e9 :3 0 2ebc 2ebd
0 ea :3 0 2ebe
2ebf 0 2ef9 ad
:3 0 ae :3 0 2ec1
2ec2 0 ad :3 0
bd :3 0 2ec4 2ec5
0 ec :2 0 2
:4 0 29b :2 0 bf
:2 0 46 :2 0 1bdd
2eca 2ecc :3 0 1be0
2ec6 2ece 2ec3 2ed0
2ecf :2 0 b0 :3 0
c0 :3 0 2ed2 2ed3
0 b2 :4 0 29c
:4 0 b5 :2 0 b6
:3 0 1be4 2ed7 2ed9
:3 0 b5 :2 0 c9
:4 0 1be7 2edb 2edd
:3 0 b5 :2 0 ef
:4 0 1bea 2edf 2ee1
:3 0 b5 :2 0 ea
:3 0 1bed 2ee3 2ee5
:3 0 b5 :2 0 f0
:4 0 1bf0 2ee7 2ee9
:3 0 b5 :2 0 f1
:3 0 f2 :3 0 46
:2 0 f3 :2 0 1bf3
2eec 2ef0 1bf7 2eeb
2ef2 :3 0 1bfa 2ed4
2ef4 :2 0 2ef6 1bfd
2ef7 2ed1 2ef6 0
2ef8 1bff 0 2ef9
1c01 2efc :3 0 2efc
0 2efc 2efb 2ef9
2efa :6 0 2efe 5f
:3 0 1c04 2f00 1c06
2eff 2efe :2 0 2f01
1c08 :2 0 2f03 0
2f03 2f02 2eb9 2f01
:6 0 2f05 1 :3 0
1c0a 2f06 2e9c 2f05
0 2f07 1c0c 0
2f08 1c0e 2f09 2e1e
2f08 0 2f0a 1c11
0 2ffc 24b :3 0
a9 :3 0 39 :3 0
10c :3 0 144 :3 0
1de :3 0 1b0 :3 0
1a3 :3 0 29d :3 0
a2 :3 0 29d :3 0
a4 :3 0 29d :3 0
a5 :3 0 29d :3 0
a6 :3 0 53 :3 0
29e :3 0 29f :3 0
1a3 :3 0 2a0 :3 0
2a1 :3 0 1a3 :3 0
2a2 :3 0 2a3 :3 0
2a4 :3 0 290 :3 0
2a4 :3 0 290 :3 0
29d :3 0 2a5 :3 0
2a6 :3 0 290 :3 0
68 :3 0 138 :3 0
290 :3 0 68 :3 0
290 :3 0 2a3 :3 0
2a4 :3 0 2a7 :3 0
2a4 :3 0 2a7 :3 0
29d :3 0 2a5 :3 0
2a6 :3 0 291 :3 0
68 :3 0 138 :3 0
291 :3 0 68 :3 0
291 :3 0 2a3 :3 0
2a4 :3 0 292 :3 0
2a4 :3 0 292 :3 0
29d :3 0 2a5 :3 0
2a6 :3 0 292 :3 0
68 :3 0 138 :3 0
292 :3 0 68 :3 0
292 :3 0 2a3 :3 0
2a4 :3 0 2a8 :3 0
2a4 :3 0 2a8 :3 0
29d :3 0 2a5 :3 0
2a6 :3 0 293 :3 0
68 :3 0 138 :3 0
293 :3 0 68 :3 0
293 :3 0 29d :3 0
2a9 :3 0 29d :3 0
2aa :3 0 29d :3 0
2ab :3 0 29d :3 0
2ac :3 0 29d :3 0
2ad :3 0 29d :3 0
2ae :3 0 29d :3 0
2ae :3 0 58 :3 0
2af :3 0 59 :3 0
2b0 :3 0 29d :3 0
2ab :3 0 29d :3 0
2ac :3 0 29d :3 0
2ad :3 0 2b1 :3 0
2b2 :3 0 2b3 :3 0
2b4 :3 0 2b5 :3 0
1a3 :3 0 2b6 :3 0
2b7 :3 0 2b8 :3 0
5e :3 0 12e :3 0
29d :3 0 2b9 :3 0
2ba :3 0 2e :3 0
a0 :3 0 30 :3 0
a3 :3 0 2bb :3 0
2bc :3 0 14f :3 0
2bd :3 0 28f :3 0
2a6 :3 0 1df :3 0
a7 :3 0 29d :3 0
29d :3 0 9e :3 0
2a6 :3 0 9e :3 0
2be :3 0 2bf :3 0
1df :3 0 2c0 :3 0
2a4 :3 0 2a4 :3 0
98 :3 0 25 :3 0
2a4 :3 0 9a :3 0
29d :3 0 9e :3 0
1df :3 0 18f :3 0
1de :3 0 1de :3 0
190 :3 0 39 :3 0
1df :3 0 1a5 :3 0
2c1 :3 0 1de :3 0
a0 :3 0 2c1 :3 0
10c :3 0 2be :3 0
2bf :3 0 1df :3 0
2c2 :3 0 138 :3 0
2c1 :3 0 2c3 :3 0
138 :3 0 2c3 :3 0
2be :3 0 2bf :3 0
1df :3 0 21c :3 0
29f :3 0 1de :3 0
1b3 :3 0 29f :3 0
10c :3 0 2be :3 0
2bf :3 0 1df :3 0
227 :3 0 2a1 :3 0
1de :3 0 1b2 :3 0
2a1 :3 0 10c :3 0
2be :3 0 2bf :3 0
1df :3 0 177 :3 0
2b5 :3 0 2b5 :3 0
10c :3 0 1de :3 0
1b1 :3 0 29d :3 0
a2 :3 0 29d :3 0
a4 :3 0 29d :3 0
a5 :3 0 29d :3 0
a6 :4 0 2c4 1
:a 0 2fd9 :2 0 2ffc
2f0c 2fd7 :2 0 ad
:3 0 ae :3 0 2fda
2fdb 0 ad :3 0
bd :3 0 2fdd 2fde
0 46 :2 0 2
:4 0 2c5 :2 0 bf
:2 0 46 :2 0 1c13
2fe3 2fe5 :3 0 1c16
2fdf 2fe7 2fdc 2fe9
2fe8 :2 0 b0 :3 0
c0 :3 0 2feb 2fec
0 b2 :4 0 2c6
:4 0 b5 :2 0 b6
:3 0 1c1a 2ff0 2ff2
:3 0 1c1d 2fed 2ff4
:2 0 2ff6 1c20 2ff7
2fea 2ff6 0 2ff8
1c22 0 2ffc 20
:3 0 a9 :3 0 2ffa
:2 0 2ffc 1c24 3420
8b :3 0 d2 :2 0
46 :2 0 1c2e 2ffe
3000 :3 0 24b :3 0
aa :3 0 29d :3 0
9e :3 0 10c :3 0
144 :3 0 2c1 :3 0
2b4 :3 0 1a3 :3 0
29d :3 0 a2 :3 0
29d :3 0 a4 :3 0
29d :3 0 a5 :3 0
29d :3 0 a6 :3 0
2c1 :3 0 29e :3 0
2c7 :3 0 1a3 :3 0
2a0 :3 0 2c8 :3 0
1a3 :3 0 2a2 :3 0
2a3 :3 0 29d :3 0
2c9 :3 0 29d :3 0
290 :3 0 2c1 :3 0
286 :3 0 6b :3 0
2c1 :3 0 286 :3 0
6b :3 0 e5 :3 0
287 :3 0 1a3 :3 0
28a :3 0 10c :3 0
6b :3 0 e5 :3 0
287 :3 0 1a3 :3 0
28a :3 0 10c :3 0
2c1 :3 0 286 :3 0
29d :3 0 2c9 :3 0
29d :3 0 290 :3 0
29d :3 0 290 :3 0
68 :3 0 290 :3 0
2a3 :3 0 29d :3 0
2c9 :3 0 29d :3 0
291 :3 0 2c1 :3 0
286 :3 0 6b :3 0
2c1 :3 0 286 :3 0
6b :3 0 e5 :3 0
287 :3 0 1a3 :3 0
28a :3 0 10c :3 0
6b :3 0 e5 :3 0
287 :3 0 1a3 :3 0
28a :3 0 10c :3 0
2c1 :3 0 286 :3 0
29d :3 0 2c9 :3 0
29d :3 0 291 :3 0
29d :3 0 291 :3 0
68 :3 0 291 :3 0
2a3 :3 0 29d :3 0
2c9 :3 0 29d :3 0
292 :3 0 2c1 :3 0
286 :3 0 6b :3 0
2c1 :3 0 286 :3 0
6b :3 0 e5 :3 0
287 :3 0 1a3 :3 0
28a :3 0 10c :3 0
6b :3 0 e5 :3 0
287 :3 0 1a3 :3 0
28a :3 0 10c :3 0
2c1 :3 0 286 :3 0
29d :3 0 2c9 :3 0
29d :3 0 292 :3 0
29d :3 0 292 :3 0
68 :3 0 292 :3 0
2a3 :3 0 29d :3 0
2c9 :3 0 29d :3 0
293 :3 0 2c1 :3 0
286 :3 0 6b :3 0
2c1 :3 0 286 :3 0
6b :3 0 e5 :3 0
287 :3 0 1a3 :3 0
28a :3 0 10c :3 0
6b :3 0 e5 :3 0
287 :3 0 1a3 :3 0
28a :3 0 10c :3 0
2c1 :3 0 286 :3 0
29d :3 0 2c9 :3 0
29d :3 0 293 :3 0
29d :3 0 293 :3 0
68 :3 0 293 :3 0
29d :3 0 2a9 :3 0
29d :3 0 2aa :3 0
29d :3 0 2ab :3 0
29d :3 0 2ac :3 0
29d :3 0 2ad :3 0
29d :3 0 2ae :3 0
29d :3 0 2ae :3 0
58 :3 0 2af :3 0
59 :3 0 2b0 :3 0
29d :3 0 2ab :3 0
29d :3 0 2ac :3 0
29d :3 0 2ad :3 0
2b1 :3 0 2ca :3 0
2b4 :3 0 2b2 :3 0
2c1 :3 0 2b3 :3 0
2b5 :3 0 1a3 :3 0
2b6 :3 0 2cb :3 0
2b4 :3 0 2cb :3 0
2b7 :3 0 2b8 :3 0
5e :3 0 12e :3 0
29d :3 0 2b9 :3 0
2ba :3 0 29d :3 0
a0 :3 0 29d :3 0
a3 :3 0 a1 :3 0
2a4 :3 0 2cc :3 0
2a4 :3 0 2cd :3 0
2bb :3 0 2c1 :3 0
2bc :3 0 2c1 :3 0
2ce :3 0 2bd :3 0
a7 :3 0 29d :3 0
1df :3 0 177 :3 0
1de :3 0 29d :3 0
9e :3 0 1de :3 0
10c :3 0 1df :3 0
177 :3 0 2b5 :3 0
2b5 :3 0 10c :3 0
1de :3 0 1a6 :3 0
2be :3 0 2bf :3 0
1df :3 0 161 :3 0
2cb :3 0 2b5 :3 0
2cf :3 0 2cb :3 0
9a :3 0 1df :3 0
161 :3 0 2c1 :3 0
29d :3 0 9e :3 0
2c1 :3 0 9a :3 0
2be :3 0 2bf :3 0
1df :3 0 161 :3 0
2ca :3 0 2ca :3 0
9a :3 0 2c1 :3 0
2d0 :3 0 2be :3 0
2bf :3 0 1df :3 0
2c0 :3 0 2a4 :3 0
2a4 :3 0 98 :3 0
25 :3 0 2a4 :3 0
9a :3 0 29d :3 0
9e :3 0 2be :3 0
2bf :3 0 1df :3 0
21c :3 0 29f :3 0
2c1 :3 0 9a :3 0
29f :3 0 10c :3 0
2be :3 0 2bf :3 0
1df :3 0 21c :3 0
2c7 :3 0 29f :3 0
1a6 :3 0 2c7 :3 0
10c :3 0 2be :3 0
2bf :3 0 1df :3 0
227 :3 0 2a1 :3 0
2c1 :3 0 9a :3 0
2a1 :3 0 10c :3 0
2be :3 0 2bf :3 0
1df :3 0 227 :3 0
2c8 :3 0 2a1 :3 0
1a6 :3 0 2c8 :3 0
10c :3 0 10c :4 0
2d1 1 :a 0 3131
:2 0 3154 3003 312f
:2 0 ad :3 0 ae
:3 0 3132 3133 0
ad :3 0 bd :3 0
3135 3136 0 46
:2 0 2 :4 0 2d2
:2 0 bf :2 0 46
:2 0 1c31 313b 313d
:3 0 1c34 3137 313f
3134 3141 3140 :2 0
b0 :3 0 c0 :3 0
3143 3144 0 b2
:4 0 2d3 :4 0 b5
:2 0 b6 :3 0 1c38
3148 314a :3 0 1c3b
3145 314c :2 0 314e
1c3e 314f 3142 314e
0 3150 1c40 0
3154 20 :3 0 aa
:3 0 3152 :2 0 3154
1c42 341c 1d7 :3 0
1d8 :3 0 2d4 :4 0
3157 :4 0 3158 :2 0
341b 21 :3 0 e9
:3 0 315a 315b 0
4d :2 0 315c 315d
0 341b 2d5 :3 0
9e :3 0 290 :3 0
291 :3 0 292 :3 0
293 :3 0 a7 :3 0
2c9 :4 0 2d6 1
:8 0 317d 1b5 :4 0
3168 :3 0 d0 :3 0
d2 :2 0 1c48 316b
316c :3 0 21 :3 0
e9 :3 0 316e 316f
0 4d :2 0 3170
3171 0 3173 1c4b
317a 21 :3 0 e9
:3 0 3174 3175 0
17f :2 0 3176 3177
0 3179 1c4d 317b
316d 3173 0 317c
0 3179 0 317c
1c4f 0 317d 1c52
31c7 eb :3 0 21
:3 0 e9 :3 0 3180
3181 0 ea :3 0
3182 3183 0 31bd
ad :3 0 ae :3 0
3185 3186 0 ad
:3 0 bd :3 0 3188
3189 0 ec :2 0
2 :4 0 2d7 :2 0
bf :2 0 46 :2 0
1c55 318e 3190 :3 0
1c58 318a 3192 3187
3194 3193 :2 0 b0
:3 0 c0 :3 0 3196
3197 0 b2 :4 0
2d8 :4 0 b5 :2 0
b6 :3 0 1c5c 319b
319d :3 0 b5 :2 0
c9 :4 0 1c5f 319f
31a1 :3 0 b5 :2 0
ef :4 0 1c62 31a3
31a5 :3 0 b5 :2 0
ea :3 0 1c65 31a7
31a9 :3 0 b5 :2 0
f0 :4 0 1c68 31ab
31ad :3 0 b5 :2 0
f1 :3 0 f2 :3 0
46 :2 0 f3 :2 0
1c6b 31b0 31b4 1c6f
31af 31b6 :3 0 1c72
3198 31b8 :2 0 31ba
1c75 31bb 3195 31ba
0 31bc 1c77 0
31bd 1c79 31c0 :3 0
31c0 0 31c0 31bf
31bd 31be :6 0 31c2
61 :3 0 1c7c 31c4
1c7e 31c3 31c2 :2 0
31c5 1c80 :2 0 31c7
0 31c7 31c6 317d
31c5 :6 0 341b 1
:3 0 2d5 :3 0 9e
:3 0 19c :3 0 290
:3 0 290 :3 0 19c
:3 0 291 :3 0 291
:3 0 19c :3 0 292
:3 0 292 :3 0 19c
:3 0 293 :3 0 293
:3 0 a7 :3 0 9e
:3 0 9e :3 0 a7
:3 0 2c9 :3 0 9e
:4 0 2d9 1 :8 0
31f3 1b5 :4 0 31de
:3 0 d0 :3 0 d2
:2 0 1c84 31e1 31e2
:3 0 21 :3 0 e9
:3 0 31e4 31e5 0
4d :2 0 31e6 31e7
0 31e9 1c87 31f0
21 :3 0 e9 :3 0
31ea 31eb 0 17f
:2 0 31ec 31ed 0
31ef 1c89 31f1 31e3
31e9 0 31f2 0
31ef 0 31f2 1c8b
0 31f3 1c8e 323d
eb :3 0 21 :3 0
e9 :3 0 31f6 31f7
0 ea :3 0 31f8
31f9 0 3233 ad
:3 0 ae :3 0 31fb
31fc 0 ad :3 0
bd :3 0 31fe 31ff
0 ec :2 0 2
:4 0 2da :2 0 bf
:2 0 46 :2 0 1c91
3204 3206 :3 0 1c94
3200 3208 31fd 320a
3209 :2 0 b0 :3 0
c0 :3 0 320c 320d
0 b2 :4 0 2db
:4 0 b5 :2 0 b6
:3 0 1c98 3211 3213
:3 0 b5 :2 0 c9
:4 0 1c9b 3215 3217
:3 0 b5 :2 0 ef
:4 0 1c9e 3219 321b
:3 0 b5 :2 0 ea
:3 0 1ca1 321d 321f
:3 0 b5 :2 0 f0
:4 0 1ca4 3221 3223
:3 0 b5 :2 0 f1
:3 0 f2 :3 0 46
:2 0 f3 :2 0 1ca7
3226 322a 1cab 3225
322c :3 0 1cae 320e
322e :2 0 3230 1cb1
3231 320b 3230 0
3232 1cb3 0 3233
1cb5 3236 :3 0 3236
0 3236 3235 3233
3234 :6 0 3238 63
:3 0 1cb8 323a 1cba
3239 3238 :2 0 323b
1cbc :2 0 323d 0
323d 323c 31f3 323b
:6 0 341b 1 :3 0
24b :3 0 ab :3 0
29d :3 0 9e :3 0
10c :3 0 144 :3 0
2c1 :3 0 2b4 :3 0
1a3 :3 0 29d :3 0
a2 :3 0 29d :3 0
a4 :3 0 29d :3 0
a5 :3 0 29d :3 0
a6 :3 0 2c1 :3 0
29e :3 0 2c7 :3 0
1a3 :3 0 2a0 :3 0
2c8 :3 0 1a3 :3 0
2a2 :3 0 2a3 :3 0
2a4 :3 0 290 :3 0
2a4 :3 0 290 :3 0
138 :3 0 290 :3 0
138 :3 0 290 :3 0
2c1 :3 0 286 :3 0
6b :3 0 2c1 :3 0
286 :3 0 6b :3 0
e5 :3 0 287 :3 0
1a3 :3 0 28a :3 0
10c :3 0 6b :3 0
e5 :3 0 287 :3 0
1a3 :3 0 28a :3 0
10c :3 0 2c1 :3 0
286 :3 0 2dc :3 0
290 :3 0 2dc :3 0
290 :3 0 2c1 :3 0
286 :3 0 6b :3 0
2c1 :3 0 286 :3 0
6b :3 0 e5 :3 0
287 :3 0 1a3 :3 0
28a :3 0 10c :3 0
6b :3 0 e5 :3 0
287 :3 0 1a3 :3 0
28a :3 0 10c :3 0
2c1 :3 0 286 :3 0
2dd :3 0 290 :3 0
68 :3 0 290 :3 0
2a3 :3 0 2a4 :3 0
290 :3 0 2a4 :3 0
2a7 :3 0 138 :3 0
290 :3 0 138 :3 0
291 :3 0 2c1 :3 0
286 :3 0 6b :3 0
2c1 :3 0 286 :3 0
6b :3 0 e5 :3 0
287 :3 0 1a3 :3 0
28a :3 0 10c :3 0
6b :3 0 e5 :3 0
287 :3 0 1a3 :3 0
28a :3 0 10c :3 0
2c1 :3 0 286 :3 0
2dc :3 0 290 :3 0
2dc :3 0 291 :3 0
2c1 :3 0 286 :3 0
6b :3 0 2c1 :3 0
286 :3 0 6b :3 0
e5 :3 0 287 :3 0
1a3 :3 0 28a :3 0
10c :3 0 6b :3 0
e5 :3 0 287 :3 0
1a3 :3 0 28a :3 0
10c :3 0 2c1 :3 0
286 :3 0 2dd :3 0
291 :3 0 68 :3 0
291 :3 0 2a3 :3 0
2a4 :3 0 290 :3 0
2a4 :3 0 292 :3 0
138 :3 0 290 :3 0
138 :3 0 292 :3 0
2c1 :3 0 286 :3 0
6b :3 0 2c1 :3 0
286 :3 0 6b :3 0
e5 :3 0 287 :3 0
1a3 :3 0 28a :3 0
10c :3 0 6b :3 0
e5 :3 0 287 :3 0
1a3 :3 0 28a :3 0
10c :3 0 2c1 :3 0
286 :3 0 2dc :3 0
290 :3 0 2dc :3 0
292 :3 0 2c1 :3 0
286 :3 0 6b :3 0
2c1 :3 0 286 :3 0
6b :3 0 e5 :3 0
287 :3 0 1a3 :3 0
28a :3 0 10c :3 0
6b :3 0 e5 :3 0
287 :3 0 1a3 :3 0
28a :3 0 10c :3 0
2c1 :3 0 286 :3 0
2dd :3 0 292 :3 0
68 :3 0 292 :3 0
2a3 :3 0 2a4 :3 0
2a7 :3 0 2a4 :3 0
2a8 :3 0 138 :3 0
291 :3 0 138 :3 0
293 :3 0 2c1 :3 0
286 :3 0 6b :3 0
2c1 :3 0 286 :3 0
6b :3 0 e5 :3 0
287 :3 0 1a3 :3 0
28a :3 0 10c :3 0
6b :3 0 e5 :3 0
287 :3 0 1a3 :3 0
28a :3 0 10c :3 0
2c1 :3 0 286 :3 0
2dc :3 0 290 :3 0
2dc :3 0 293 :3 0
2c1 :3 0 286 :3 0
6b :3 0 2c1 :3 0
286 :3 0 6b :3 0
e5 :3 0 287 :3 0
1a3 :3 0 28a :3 0
10c :3 0 6b :3 0
e5 :3 0 287 :3 0
1a3 :3 0 28a :3 0
10c :3 0 2c1 :3 0
286 :3 0 2dd :3 0
293 :3 0 68 :3 0
293 :3 0 29d :3 0
2a9 :3 0 29d :3 0
2aa :3 0 29d :3 0
2ab :3 0 29d :3 0
2ac :3 0 29d :3 0
2ad :3 0 29d :3 0
2ae :3 0 29d :3 0
2ae :3 0 58 :3 0
2af :3 0 59 :3 0
2b0 :3 0 29d :3 0
2ab :3 0 29d :3 0
2ac :3 0 29d :3 0
2ad :3 0 2b1 :3 0
2ca :3 0 2b4 :3 0
2b2 :3 0 2c1 :3 0
2b3 :3 0 2b5 :3 0
1a3 :3 0 2b6 :3 0
2cb :3 0 2b4 :3 0
2cb :3 0 2b7 :3 0
2b8 :3 0 5e :3 0
12e :3 0 29d :3 0
2b9 :3 0 2ba :3 0
29d :3 0 a0 :3 0
29d :3 0 a3 :3 0
a1 :3 0 2a4 :3 0
2cc :3 0 2a4 :3 0
2cd :3 0 2bb :3 0
2c1 :3 0 2bc :3 0
2c1 :3 0 2ce :3 0
2bd :3 0 a7 :3 0
29d :3 0 2be :3 0
1df :3 0 2d5 :3 0
2dc :3 0 29d :3 0
9e :3 0 2dc :3 0
9e :3 0 2dc :3 0
2c9 :3 0 2be :3 0
1df :3 0 2d5 :3 0
2dd :3 0 29d :3 0
9e :3 0 2dd :3 0
9e :3 0 2dd :3 0
2c9 :3 0 1df :3 0
177 :3 0 1de :3 0
29d :3 0 9e :3 0
1de :3 0 10c :3 0
1df :3 0 177 :3 0
2b5 :3 0 2b5 :3 0
10c :3 0 1de :3 0
1a6 :3 0 2be :3 0
2bf :3 0 1df :3 0
161 :3 0 2cb :3 0
2b5 :3 0 2cf :3 0
2cb :3 0 9a :3 0
1df :3 0 161 :3 0
2c1 :3 0 29d :3 0
9e :3 0 2c1 :3 0
9a :3 0 2be :3 0
2bf :3 0 1df :3 0
161 :3 0 2ca :3 0
2ca :3 0 9a :3 0
2c1 :3 0 2d0 :3 0
2be :3 0 2bf :3 0
1df :3 0 2c0 :3 0
2a4 :3 0 2a4 :3 0
98 :3 0 25 :3 0
2a4 :3 0 9a :3 0
29d :3 0 9e :3 0
2be :3 0 2bf :3 0
1df :3 0 161 :3 0
2de :3 0 2c1 :3 0
2d0 :3 0 2de :3 0
9a :3 0 2be :3 0
2bf :3 0 1df :3 0
21c :3 0 29f :3 0
2c1 :3 0 9a :3 0
29f :3 0 10c :3 0
2be :3 0 2bf :3 0
1df :3 0 21c :3 0
2c7 :3 0 29f :3 0
1a6 :3 0 2c7 :3 0
10c :3 0 2be :3 0
2bf :3 0 1df :3 0
227 :3 0 2a1 :3 0
2c1 :3 0 9a :3 0
2a1 :3 0 10c :3 0
2be :3 0 2bf :3 0
1df :3 0 227 :3 0
2c8 :3 0 2a1 :3 0
1a6 :3 0 2c8 :3 0
10c :3 0 2be :3 0
2bf :3 0 1df :3 0
2c2 :3 0 138 :3 0
2c1 :3 0 2c3 :3 0
138 :3 0 2c3 :3 0
29d :3 0 a2 :3 0
29d :3 0 a4 :3 0
29d :3 0 a5 :3 0
29d :3 0 a6 :3 0
10c :4 0 2df 1
:a 0 33f8 :2 0 341b
3240 33f6 :2 0 ad
:3 0 ae :3 0 33f9
33fa 0 ad :3 0
bd :3 0 33fc 33fd
0 46 :2 0 2
:4 0 2e0 :2 0 bf
:2 0 46 :2 0 1cbe
3402 3404 :3 0 1cc1
33fe 3406 33fb 3408
3407 :2 0 b0 :3 0
c0 :3 0 340a 340b
0 b2 :4 0 2e1
:4 0 b5 :2 0 b6
:3 0 1cc5 340f 3411
:3 0 1cc8 340c 3413
:2 0 3415 1ccb 3416
3409 3415 0 3417
1ccd 0 341b 20
:3 0 ab :3 0 3419
:2 0 341b 1ccf 341d
3001 3154 0 341e
0 341b 0 341e
1cd7 0 341f 1cda
3421 2d9d 2ffc 0
3422 0 341f 0
3422 1cdc 0 3423
1cdf 34c4 21 :3 0
2e2 :2 0 4 3424
3425 0 ad :3 0
ae :3 0 3427 3428
0 ad :3 0 bd
:3 0 342a 342b 0
ec :2 0 2 :4 0
2e3 :2 0 bf :2 0
46 :2 0 1d1b 3430
3432 :3 0 1d1e 342c
3434 3429 3436 3435
:2 0 b0 :3 0 c0
:3 0 3438 3439 0
b2 :4 0 2e4 :4 0
b5 :2 0 b6 :3 0
1d22 343d 343f :3 0
1d25 343a 3441 :2 0
345a b0 :3 0 c0
:3 0 3443 3444 0
b2 :4 0 2e5 :4 0
b5 :2 0 21 :3 0
2e6 :3 0 3449 344a
0 1d28 3448 344c
:3 0 b5 :2 0 115
:4 0 1d2b 344e 3450
:3 0 b5 :2 0 21
:3 0 2e7 :3 0 3453
3454 0 1d2e 3452
3456 :3 0 1d31 3445
3458 :2 0 345a 1d34
345b 3437 345a 0
345c 1d37 0 346c
24b :3 0 ac :3 0
21 :3 0 2e6 :3 0
2e8 :3 0 21 :3 0
2e7 :3 0 2e9 :3 0
e7 :4 0 2ea 1
:a 0 3468 :2 0 346c
345e 3466 :2 0 20
:3 0 ac :3 0 346a
:2 0 346c 1d39 346e
1d3d 346d 346c :2 0
34c2 eb :3 0 21
:3 0 e9 :3 0 3471
3472 0 ea :3 0
3473 3474 0 34ba
ad :3 0 ae :3 0
3476 3477 0 ad
:3 0 bd :3 0 3479
347a 0 ec :2 0
2 :4 0 2eb :2 0
bf :2 0 46 :2 0
1d3f 347f 3481 :3 0
1d42 347b 3483 3478
3485 3484 :2 0 b0
:3 0 c0 :3 0 3487
3488 0 b2 :4 0
2ec :4 0 b5 :2 0
b6 :3 0 1d46 348c
348e :3 0 1d49 3489
3490 :2 0 34aa b0
:3 0 c0 :3 0 3492
3493 0 b2 :4 0
ef :4 0 b5 :2 0
ea :3 0 1d4c 3497
3499 :3 0 b5 :2 0
f0 :4 0 1d4f 349b
349d :3 0 b5 :2 0
f1 :3 0 f2 :3 0
46 :2 0 f3 :2 0
1d52 34a0 34a4 1d56
349f 34a6 :3 0 1d59
3494 34a8 :2 0 34aa
1d5c 34ab 3486 34aa
0 34ac 1d5f 0
34ba 24b :3 0 ac
:3 0 2e8 :3 0 21
:3 0 2e7 :3 0 2e9
:3 0 e7 :4 0 2ed
1 :a 0 34b6 :2 0
34ba 34ae 34b4 :2 0
20 :3 0 ac :3 0
34b8 :2 0 34ba 1d61
34bd :3 0 34bd 0
34bd 34bc 34ba 34bb
:6 0 34bf 1 :3 0
1d66 34c1 1d68 34c0
34bf :2 0 34c2 1d6a
:2 0 34c4 1d6d 34c4
34c3 3423 34c2 :6 0
34c5 :2 0 2 74
34c4 34c8 :3 0 34c7
34c5 34c9 :8 0 
1dd7
4
:3 0 1 3 1
7 1 b 1
f 1 13 1
17 1 1b 1
1f 1 23 1
27 1 2b 1
2f 1 33 1
37 1 3b 1
3f 1 43 1
47 1 4b 1
4f 1 53 1
57 1 5b 1
5f 1 63 1
67 1 6b 1b
6 a e 12
16 1a 1e 22
26 2a 2e 32
36 3a 3e 42
46 4a 4e 52
56 5a 5e 62
66 6a 6e 1
78 1 76 1
7f 1 7d 1
86 1 84 1
8d 1 8b 1
94 1 92 1
9b 1 99 1
a2 1 a0 1
a9 1 a7 1
b0 1 ae 1
b7 1 b5 1
be 1 bc 1
c5 1 c3 1
cc 1 ca 1
d3 1 d1 1
da 1 d8 1
e1 1 df 1
e8 1 e6 1
ef 1 ed 1
f6 1 f4 1
fd 1 fb 1
104 1 102 1
109 1 110 1
10e 1 117 1
115 1 11e 1
11c 1 125 1
123 1 12c 1
12a 1 133 1
131 1 13a 1
138 1 141 1
13f 1 148 1
146 1 14f 1
14d 1 156 1
154 1 15b 1
161 1 167 1
16d 1 173 1
179 1 17f 1
185 1 18b 1
191 1 197 1
19d 1 1a3 1
1a9 1 1af 1
1b5 1 1bb 1
1c1 1 1c7 1
1cd 1 1d3 1
1d9 1 1df 1
1e5 1 1eb 1
1f1 1 1f7 1
1fd 1 203 1
209 1 20f 1
215 1 21b 1
223 1 221 1
228 1 22e 1
234 1 23c 1
23a 1 243 1
241 1 24a 1
248 1 24f 1
255 1 25d 1
25b 1 264 1
262 1 26b 1
269 1 272 1
270 1 279 1
277 1 280 1
27e 1 285 1
28b 1 291 1
297 1 29d 1
2a3 1 2a9 1
2af 1 2b7 1
2b5 1 2bc 1
2c2 1 2c7 1
2cc 1 2d1 1
2d6 1 2db 1
2e0 1 2e5 1
2f9 1 314 1
31a 1 321 1
328 1 32f 1
33c 1 348 2
34b 34d 2 350
352 2 354 356
2 358 35a 2
35c 35e 2 360
362 2 364 366
2 368 36a 2
36c 36e 2 370
372 2 374 376
2 378 37a 2
37c 37e 1 384
2 386 387 2
380 389 2 38b
38d 1 393 2
395 396 2 38f
398 2 39a 39c
1 3a2 2 3a4
3a5 2 39e 3a7
2 3a9 3ab 1
3b1 2 3b3 3b4
2 3ad 3b6 2
3b8 3ba 1 3c0
2 3c2 3c3 2
3bc 3c5 2 3c7
3c9 1 3cf 2
3d1 3d2 2 3cb
3d4 2 3d6 3d8
1 3de 2 3e0
3e1 2 3da 3e3
2 3e5 3e7 1
3ed 2 3ef 3f0
2 3e9 3f2 2
3f4 3f6 2 3f8
3fa 2 3fc 3fe
2 400 402 2
404 406 2 408
40a 2 40c 40e
2 410 412 2
414 416 2 418
41a 2 41c 41e
2 420 422 2
424 426 2 428
42a 2 42c 42e
2 430 432 2
434 436 2 438
43a 2 43c 43e
2 440 442 2
444 446 1 44c
2 44e 44f 2
448 451 2 453
455 2 457 459
2 45b 45d 2
45f 461 2 463
465 2 467 469
2 46b 46d 2
46f 471 2 473
475 2 477 479
2 47b 47d 2
47f 481 2 483
485 2 487 489
2 48b 48d 2
48f 491 2 493
495 1 49b 2
49d 49e 2 497
4a0 2 4a2 4a4
1 4aa 2 4ac
4ad 2 4a6 4af
2 4b1 4b3 1
4b9 2 4bb 4bc
2 4b5 4be 2
4c0 4c2 1 4c8
2 4ca 4cb 2
4c4 4cd 2 4cf
4d1 2 4d3 4d5
2 4d7 4d9 2
4db 4dd 2 4df
4e1 2 4e3 4e5
2 4e7 4e9 2
4eb 4ed 2 4ef
4f1 4 344 34a
34f 4f3 1 4f5
1 4f7 2 501
503 3 4ff 500
505 2 50e 510
2 50d 512 1
514 1 516 2
561 562 1 568
2 564 568 1
56c 2 57c 57e
3 57a 57b 580
2 589 58b 2
58d 58f 2 591
593 1 59b 2
59d 59e 2 595
5a0 2 588 5a2
1 5a4 1 5a6
2 5b0 5b2 3
5ae 5af 5b4 2
5bd 5bf 2 5bc
5c1 1 5c3 1
5c5 2 5cc 5cd
3 5a7 5c6 5cf
1 5d1 1 5d3
1 5d9 1 5e1
1 5e9 2 5f2
5f3 1 5f9 2
5f5 5f9 1 5ff
2 606 607 1
60d 2 609 60d
2 61b 61d 3
619 61a 61f 2
628 62a 2 62c
62e 2 630 632
1 63a 2 63c
63d 2 634 63f
2 627 641 1
643 1 645 2
64f 651 3 64d
64e 653 2 65c
65e 2 65b 660
1 662 1 664
2 66b 66c 3
646 665 66e 1
671 1 677 2
687 689 3 685
686 68b 2 694
696 2 698 69a
2 69c 69e 1
6a6 2 6a8 6a9
2 6a0 6ab 2
693 6ad 1 6af
1 6b1 2 6bb
6bd 3 6b9 6ba
6bf 2 6c8 6ca
2 6c7 6cc 1
6ce 1 6d0 2
6d7 6d8 3 6b2
6d1 6da 2 6dd
6dc 1 6de 1
6e0 2 6e3 6e4
1 6e8 2 6e6
6e8 2 6ec 6ed
1 6f1 2 6ef
6f1 2 6f7 6f8
1 6fc 2 6fa
6fc 2 709 70b
3 707 708 70d
2 716 718 2
71a 71c 2 71e
720 1 728 2
72a 72b 2 722
72d 2 715 72f
1 731 1 733
2 73d 73f 3
73b 73c 741 2
74a 74c 2 749
74e 1 750 1
752 2 759 75a
3 734 753 75c
1 75e 1 760
1 768 1 76c
2 76e 76f 2
772 773 1 779
2 775 779 1
77d 1 785 2
795 79a 2 7ab
7ad 3 7a9 7aa
7af 2 7b8 7ba
2 7bc 7be 2
7c0 7c2 2 7c4
7c6 2 7c8 7ca
3 7cf 7d0 7d1
2 7cc 7d3 2
7b7 7d5 1 7d7
1 7d9 2 7a2
7da 1 7de 1
79d 1 7e2 1
7ed 2 7e9 7ed
2 7f2 7f3 1
7f7 2 7f5 7f7
2 805 807 3
803 804 809 2
812 814 2 816
818 2 81a 81c
1 824 2 826
827 2 81e 829
2 811 82b 1
82d 1 82f 2
839 83b 3 837
838 83d 2 846
848 2 845 84a
1 84c 1 84e
2 855 856 3
830 84f 858 1
85a 3 7e5 85b
85e 1 860 1
862 1 868 2
873 878 2 889
88b 3 887 888
88d 2 896 898
2 89a 89c 2
89e 8a0 2 8a2
8a4 2 8a6 8a8
3 8ad 8ae 8af
2 8aa 8b1 2
895 8b3 1 8b5
1 8b7 2 880
8b8 1 8bc 1
87b 1 8c0 1
8c3 1 8c6 2
8d1 8d2 2 8d4
8d7 2 8da 8db
2 8e2 8e3 2
8e5 8e8 2 8f2
8f3 2 8f5 8f8
2 8fb 8fc 2
903 904 2 906
909 2 90f 910
1 916 2 912
916 1 918 2
91b 91d 2 921
922 1 926 2
924 926 2 931
936 2 947 949
3 945 946 94b
2 954 956 2
958 95a 2 95c
95e 2 960 962
2 964 966 3
96b 96c 96d 2
968 96f 2 953
971 1 973 1
975 2 93e 976
1 97a 1 939
1 97e 2 984
985 1 989 2
987 989 2 991
996 2 9a7 9a9
3 9a5 9a6 9ab
2 9b4 9b6 2
9b8 9ba 2 9bc
9be 2 9c0 9c2
2 9c4 9c6 3
9cb 9cc 9cd 2
9c8 9cf 2 9b3
9d1 1 9d3 1
9d5 2 99e 9d6
1 9da 1 999
1 9de 2 9e6
9e7 1 9eb 2
9e9 9eb 2 9f6
9f8 3 9f4 9f5
9fa 2 a03 a05
2 a07 a09 2
a0b a0d 1 a15
2 a17 a18 2
a0f a1a 2 a1c
a1e 2 a20 a22
2 a24 a26 2
a28 a2a 2 a02
a2c 1 a2e 1
a30 2 a3a a3c
3 a38 a39 a3e
2 a47 a49 2
a46 a4b 1 a4d
1 a4f 3 a56
a57 a58 3 a31
a50 a5a 1 a5c
2 9e1 a5d 1
a5f 2 a64 a65
1 a67 2 a6c
a6d 1 a71 2
a6f a71 2 a77
a78 1 a7a 2
a7f a80 1 a84
2 a82 a84 2
a8f a91 3 a8d
a8e a93 2 a9c
a9e 2 aa0 aa2
2 aa4 aa6 1
aae 2 ab0 ab1
2 aa8 ab3 2
a9b ab5 1 ab7
1 ab9 2 ac3
ac5 3 ac1 ac2
ac7 2 ad0 ad2
2 acf ad4 1
ad6 1 ad8 2
adf ae0 3 aba
ad9 ae2 1 ae4
3 a7d ae5 aea
1 aec 2 af2
af3 1 af7 2
af5 af7 1 afc
2 b06 b08 3
b04 b05 b0a 2
b13 b15 2 b17
b19 2 b1b b1d
1 b25 2 b27
b28 2 b1f b2a
2 b12 b2c 1
b2e 1 b30 2
b3a b3c 3 b38
b39 b3e 2 b47
b49 2 b46 b4b
1 b4d 1 b4f
2 b56 b57 3
b31 b50 b59 2
b5b b5c 6 b60
b61 b62 b63 b64
b65 2 b6a b6b
1 b6f 2 b6d
b6f 2 b7a b7c
3 b78 b79 b7e
2 b87 b89 2
b8b b8d 2 b8f
b91 1 b97 2
b99 b9a 2 b93
b9c 2 b9e ba0
2 ba2 ba4 2
ba6 ba8 2 baa
bac 2 b86 bae
1 bb0 1 bb2
2 bbc bbe 3
bba bbb bc0 2
bc9 bcb 2 bc8
bcd 1 bcf 1
bd1 2 bd7 bd8
3 bda bdb bdc
3 bb3 bd2 bde
1 be0 2 be3
be4 1 bea 2
be6 bea 2 bf5
bf7 3 bf3 bf4
bf9 2 c02 c04
2 c06 c08 2
c0a c0c 1 c14
2 c16 c17 2
c0e c19 2 c1b
c1d 2 c1f c21
2 c23 c25 2
c27 c29 2 c01
c2b 1 c2d 1
c2f 2 c39 c3b
3 c37 c38 c3d
2 c46 c48 2
c45 c4a 1 c4c
1 c4e 3 c55
c56 c57 3 c30
c4f c59 1 c5b
2 c5e c5f 1
c65 2 c61 c65
2 c6a c6b 1
c6d 1 c71 2
c6f c71 2 c81
c86 2 c97 c99
3 c95 c96 c9b
2 ca4 ca6 2
ca8 caa 2 cac
cae 2 cb0 cb2
2 cb4 cb6 3
cbb cbc cbd 2
cb8 cbf 2 ca3
cc1 1 cc3 1
cc5 2 c8e cc6
1 cca 1 c89
1 cce 1 cd1
2 cfb d00 2
d11 d13 3 d0f
d10 d15 2 d1e
d20 2 d22 d24
2 d26 d28 2
d2a d2c 2 d2e
d30 3 d35 d36
d37 2 d32 d39
2 d1d d3b 1
d3d 1 d3f 2
d08 d40 1 d44
1 d03 1 d48
1 d4b 2 d4e
d4f 1 d57 2
d53 d57 2 d63
d65 3 d61 d62
d67 2 d70 d72
2 d74 d76 2
d78 d7a 1 d82
2 d84 d85 2
d7c d87 2 d89
d8b 2 d8d d8f
2 d91 d93 2
d95 d97 2 d6f
d99 1 d9b 1
d9d 2 da7 da9
3 da5 da6 dab
2 db4 db6 2
db3 db8 1 dba
1 dbc 3 dc3
dc4 dc5 3 d9e
dbd dc7 1 dc9
2 d50 dca 2
dce dcf 1 dd5
2 dd1 dd5 2
de1 de6 2 df7
df9 3 df5 df6
dfb 2 e04 e06
2 e08 e0a 2
e0c e0e 2 e10
e12 2 e14 e16
3 e1b e1c e1d
2 e18 e1f 2
e03 e21 1 e23
1 e25 2 dee
e26 1 e2a 1
de9 1 e2e 1
e39 2 e35 e39
2 e45 e47 3
e43 e44 e49 2
e52 e54 2 e56
e58 2 e5a e5c
1 e64 2 e66
e67 2 e5e e69
2 e6b e6d 2
e6f e71 2 e73
e75 2 e77 e79
2 e51 e7b 1
e7d 1 e7f 2
e89 e8b 3 e87
e88 e8d 2 e96
e98 2 e95 e9a
1 e9c 1 e9e
3 ea5 ea6 ea7
3 e80 e9f ea9
1 eab 2 ec0
ec5 2 ed6 ed8
3 ed4 ed5 eda
2 ee3 ee5 2
ee7 ee9 2 eeb
eed 2 eef ef1
2 ef3 ef5 3
efa efb efc 2
ef7 efe 2 ee2
f00 1 f02 1
f04 2 ecd f05
1 f09 1 ec8
1 f0d 1 f18
2 f14 f18 2
f24 f26 3 f22
f23 f28 2 f31
f33 2 f35 f37
2 f39 f3b 1
f43 2 f45 f46
2 f3d f48 2
f4a f4c 2 f4e
f50 2 f52 f54
2 f56 f58 2
f30 f5a 1 f5c
1 f5e 2 f68
f6a 3 f66 f67
f6c 2 f75 f77
2 f74 f79 1
f7b 1 f7d 3
f84 f85 f86 3
f5f f7e f88 1
f8a 1 f8c 1
f98 2 f95 f9b
1 f9d 5 e31
eac f10 f8b f9e
2 fa9 fab 3
fa7 fa8 fad 2
fb6 fb8 2 fba
fbc 2 fbe fc0
1 fc8 2 fca
fcb 2 fc2 fcd
2 fcf fd1 2
fd3 fd5 2 fd7
fd9 2 fdb fdd
2 fb5 fdf 1
fe1 1 fe3 2
fed fef 3 feb
fec ff1 2 ffa
ffc 2 ff9 ffe
1 1000 1 1002
3 1009 100a 100b
3 fe4 1003 100d
3 100f fa0 1010
2 1013 1014 1
101a 2 1016 101a
2 1032 1037 2
1048 104a 3 1046
1047 104c 2 1055
1057 2 1059 105b
2 105d 105f 2
1061 1063 2 1065
1067 3 106c 106d
106e 2 1069 1070
2 1054 1072 1
1074 1 1076 2
103f 1077 1 107b
1 103a 1 107f
1 108a 2 1086
108a 2 1096 1098
3 1094 1095 109a
2 10a3 10a5 2
10a7 10a9 2 10ab
10ad 1 10b5 2
10b7 10b8 2 10af
10ba 2 10bc 10be
2 10c0 10c2 2
10c4 10c6 2 10c8
10ca 2 10a2 10cc
1 10ce 1 10d0
2 10da 10dc 3
10d8 10d9 10de 2
10e7 10e9 2 10e6
10eb 1 10ed 1
10ef 3 10f6 10f7
10f8 3 10d1 10f0
10fa 1 1103 2
10ff 1103 3 1108
1109 110a 1 110e
2 110c 110e 2
1112 1113 1 1117
2 1115 1117 2
111b 111c 2 1121
1122 1 1124 2
111e 1124 2 112d
112e 2 1133 1134
1 1136 2 1130
1136 2 1143 1145
3 1141 1142 1147
2 1150 1152 2
1154 1156 2 1158
115a 1 1162 2
1164 1165 2 115c
1167 2 1169 116b
2 116d 116f 2
1171 1173 2 1175
1177 2 114f 1179
1 117b 1 117d
2 1187 1189 3
1185 1186 118b 2
1194 1196 2 1193
1198 1 119a 1
119c 3 11a3 11a4
11a5 3 117e 119d
11a7 1 11a9 1
11aa 2 11ad 11ac
2 1082 11ae 1
11b0 c 92b 981
a60 a6a aed af0
b5d b68 be1 c5c
1011 11b1 1 11b3
2 11b6 11b7 1
11bb 2 11b9 11bb
2 11bf 11c0 1
11c6 2 11c2 11c6
1 11c9 2 11d1
11d2 1 11d6 2
11d4 11d6 2 11e3
11e5 3 11e1 11e2
11e7 2 11f0 11f2
2 11f4 11f6 2
11f8 11fa 1 1202
2 1204 1205 2
11fc 1207 2 1209
120b 2 120d 120f
2 1211 1213 2
1215 1217 2 11ef
1219 1 121b 1
121d 2 1227 1229
3 1225 1226 122b
2 1234 1236 2
1233 1238 1 123a
1 123c 3 1243
1244 1245 3 121e
123d 1247 1 1249
2 124c 124d 1
1253 2 124f 1253
2 1261 1266 2
1277 1279 3 1275
1276 127b 2 1284
1286 2 1288 128a
2 128c 128e 2
1290 1292 2 1294
1296 3 129b 129c
129d 2 1298 129f
2 1283 12a1 1
12a3 1 12a5 2
126e 12a6 1 12aa
1 1269 1 12ae
1 12b9 2 12b5
12b9 2 12c2 12c7
2 12d8 12da 3
12d6 12d7 12dc 2
12e5 12e7 2 12e9
12eb 2 12ed 12ef
2 12f1 12f3 2
12f5 12f7 3 12fc
12fd 12fe 2 12f9
1300 2 12e4 1302
1 1304 1 1306
2 12cf 1307 1
130b 1 12ca 1
130f 1 131a 2
1316 131a 2 1326
1328 3 1324 1325
132a 2 1333 1335
2 1337 1339 2
133b 133d 1 1345
2 1347 1348 2
133f 134a 2 134c
134e 2 1350 1352
2 1354 1356 2
1358 135a 2 1332
135c 1 135e 1
1360 2 136a 136c
3 1368 1369 136e
2 1377 1379 2
1376 137b 1 137d
1 137f 3 1386
1387 1388 3 1361
1380 138a 1 138c
2 1312 138d 1
138f 2 12b1 1390
1 1392 2 124a
1393 1 1395 2
1398 1399 1 139d
2 139b 139d 2
13a1 13a2 1 13a6
2 13a4 13a6 1
13ad 1 13af 2
13b2 13b3 1 13b9
2 13b5 13b9 1
13bc 2 13c3 13c6
2 13ca 13cd 2
13cf 13d0 2 13d1
13d4 1 13d8 2
13d6 13d8 2 13e3
13e4 2 13e8 13e9
2 13ed 13ee 2
13f2 13f3 2 13f7
13f8 2 13fc 13fd
2 1401 1402 2
1406 1407 d 13e0
13e1 13e6 13eb 13f0
13f5 13fa 13ff 1404
1409 140a 140b 140c
2 1411 1412 1
1418 2 1414 1418
2 1423 1425 3
1421 1422 1427 2
1430 1432 2 1434
1436 2 1438 143a
1 1442 2 1444
1445 2 143c 1447
2 142f 1449 1
144b 1 144d 2
1457 1459 3 1455
1456 145b 2 1464
1466 2 1463 1468
1 146a 1 146c
2 1473 1474 3
144e 146d 1476 2
147a 147b 1 147f
2 147d 147f 2
148a 148c 3 1488
1489 148e 2 1497
1499 2 149b 149d
2 149f 14a1 1
14a7 2 14a9 14aa
2 14a3 14ac 2
14ae 14b0 2 14b2
14b4 2 14b6 14b8
2 14ba 14bc 2
1496 14be 1 14c0
1 14c2 2 14cc
14ce 3 14ca 14cb
14d0 2 14d9 14db
2 14d8 14dd 1
14df 1 14e1 2
14e7 14e8 3 14ea
14eb 14ec 3 14c3
14e2 14ee 2 14f1
14f0 3 13dd 140f
14f2 1 14f6 2
14f8 14f9 2 14fc
14fd 1 1501 2
14ff 1501 2 1506
1507 1 150b 2
1509 150b 2 1512
1513 1 1517 2
1515 1517 2 151c
151d 1 1521 2
151f 1521 1 1529
2 152d 152e 1
1532 2 1530 1532
1 1537 2 153c
153d 1 1541 2
153f 1541 2 1546
1547 1 154b 2
1549 154b 1 1553
2 1558 1559 1
155d 2 155b 155d
1 1562 4 1565
153a 1556 1564 1
1566 1 1568 2
14fa 1569 2 156b
156c 2 156f 1570
1 1576 2 1572
1576 3 1584 1585
1586 2 158e 158f
1 1593 2 1591
1593 2 159a 159d
2 15a4 15a9 2
15ba 15bc 3 15b8
15b9 15be 2 15c7
15c9 2 15cb 15cd
2 15cf 15d1 2
15d3 15d5 2 15d7
15d9 3 15de 15df
15e0 2 15db 15e2
2 15c6 15e4 1
15e6 1 15e8 2
15b1 15e9 1 15ed
1 15ac 1 15f1
1 15fc 2 15f8
15fc 2 1601 1602
1 1606 2 1604
1606 2 1614 1619
2 162a 162c 3
1628 1629 162e 2
1637 1639 2 163b
163d 2 163f 1641
2 1643 1645 2
1647 1649 3 164e
164f 1650 2 164b
1652 2 1636 1654
1 1656 1 1658
2 1621 1659 1
165d 1 161c 1
1661 1 166c 2
1668 166c 1 1672
1 1674 2 1664
1675 1 1677 1
1678 1 167c 2
167e 167f 2 15f4
1680 2 1682 1683
1 1687 2 1685
1687 2 1693 1698
2 16a9 16ab 3
16a7 16a8 16ad 2
16b6 16b8 2 16ba
16bc 2 16be 16c0
2 16c2 16c4 2
16c6 16c8 3 16cd
16ce 16cf 2 16ca
16d1 2 16b5 16d3
1 16d5 1 16d7
2 16a0 16d8 1
16dc 1 169b 1
16e0 2 1704 1709
2 171a 171c 3
1718 1719 171e 2
1727 1729 2 172b
172d 2 172f 1731
2 1733 1735 2
1737 1739 3 173e
173f 1740 2 173b
1742 2 1726 1744
1 1746 1 1748
2 1711 1749 1
174d 1 170c 1
1751 1 175c 2
1758 175c 2 1768
176a 3 1766 1767
176c 2 1775 1777
2 1779 177b 2
177d 177f 1 1787
2 1789 178a 2
1781 178c 2 178e
1790 2 1792 1794
2 1796 1798 2
179a 179c 2 1774
179e 1 17a0 1
17a2 2 17ac 17ae
3 17aa 17ab 17b0
2 17b9 17bb 2
17b8 17bd 1 17bf
1 17c1 3 17c8
17c9 17ca 3 17a3
17c2 17cc 1 17ce
2 17d2 17d3 1
17d7 2 17d5 17d7
1 17d9 2 17dc
17de 1 17f7 2
17f6 17f7 1 17ff
1 1805 2 1807
1808 2 17f4 1809
2 181a 181c 3
1818 1819 181e 2
1827 1829 2 182b
182d 2 182f 1831
2 1833 1835 2
1837 1839 3 183e
183f 1840 2 183b
1842 2 1826 1844
1 1846 1 1848
2 1811 1849 1
184d 1 180c 1
1851 5 16e3 1754
17cf 17e0 1854 3
1859 185a 185b 1
185f 2 185d 185f
1 186f 2 186e
186f 1 1877 1
187d 2 187f 1880
2 186c 1881 2
1892 1894 3 1890
1891 1896 2 189f
18a1 2 18a3 18a5
2 18a7 18a9 2
18ab 18ad 2 18af
18b1 3 18b6 18b7
18b8 2 18b3 18ba
2 189e 18bc 1
18be 1 18c0 2
1889 18c1 1 18c5
1 1884 1 18c9
1 18cc 2 18d0
18cf 1 18de 2
18dd 18de 1 18e6
1 18ec 2 18ee
18ef 2 18db 18f0
2 1901 1903 3
18ff 1900 1905 2
190e 1910 2 1912
1914 2 1916 1918
2 191a 191c 2
191e 1920 3 1925
1926 1927 2 1922
1929 2 190d 192b
1 192d 1 192f
2 18f8 1930 1
1934 1 18f3 1
1938 1 1949 2
1948 1949 1 1951
1 1957 2 1959
195a 2 1946 195b
2 196c 196e 3
196a 196b 1970 2
1979 197b 2 197d
197f 2 1981 1983
2 1985 1987 2
1989 198b 3 1990
1991 1992 2 198d
1994 2 1978 1996
1 1998 1 199a
2 1963 199b 1
199f 1 195e 1
19a3 1 19b1 2
19b0 19b1 1 19b9
1 19bf 2 19c1
19c2 2 19ae 19c3
2 19d4 19d6 3
19d2 19d3 19d8 2
19e1 19e3 2 19e5
19e7 2 19e9 19eb
2 19ed 19ef 2
19f1 19f3 3 19f8
19f9 19fa 2 19f5
19fc 2 19e0 19fe
1 1a00 1 1a02
2 19cb 1a03 1
1a07 1 19c6 1
1a0b a 157b 157e
1581 1589 158c 1684
18d1 193b 19a6 1a0e
1 1a11 2 1a19
1a1a 1 1a1e 2
1a1c 1a1e 2 1a22
1a23 1 1a29 2
1a25 1a29 2 1a2f
1a30 1 1a36 2
1a32 1a36 1 1a3b
1 1a42 1 1a44
1 1a45 1 1a47
2 1a4a 1a4b 1
1a4f 2 1a4d 1a4f
1 1a56 1 1a58
1 1a5a 1 1a5f
1 1a66 1 1a6d
1 1a77 1 1a79
2 1a82 1a83 1
1a87 2 1a85 1a87
2 1a8b 1a8c 1
1a92 2 1a8e 1a92
2 1a96 1a98 2
1a9a 1a9c 2 1a9e
1aa0 2 1aa2 1aa4
2 1aa6 1aa8 2
1aaa 1aac 2 1aae
1ab0 1 1ab3 2
1ab7 1ab8 1 1abc
2 1aba 1abc 2
1ac0 1ac2 2 1ac4
1ac6 2 1ac8 1aca
2 1acc 1ace 2
1ad0 1ad2 2 1ad4
1ad6 2 1ad8 1ada
2 1adc 1ade 1
1ae1 2 1ae5 1ae7
2 1ae9 1aeb 2
1aed 1aef 2 1af1
1af3 2 1af5 1af7
1 1afa 3 1afc
1ae3 1afd 1 1afe
2 1b01 1b02 1
1b08 2 1b04 1b08
2 1b0c 1b0d 1
1b13 2 1b0f 1b13
2 1b19 1b1a 1
1b20 2 1b1c 1b20
1 1b2f 1 1b58
2 1b57 1b58 1
1b60 1 1b66 2
1b68 1b69 2 1b55
1b6a 2 1b7b 1b7d
3 1b79 1b7a 1b7f
2 1b88 1b8a 2
1b8c 1b8e 2 1b90
1b92 2 1b94 1b96
2 1b98 1b9a 3
1b9f 1ba0 1ba1 2
1b9c 1ba3 2 1b87
1ba5 1 1ba7 1
1ba9 2 1b72 1baa
1 1bae 1 1b6d
1 1bb2 1 1bcf
2 1bce 1bcf 1
1bd7 1 1bdd 2
1bdf 1be0 2 1bcc
1be1 2 1bf2 1bf4
3 1bf0 1bf1 1bf6
2 1bff 1c01 2
1c03 1c05 2 1c07
1c09 2 1c0b 1c0d
2 1c0f 1c11 3
1c16 1c17 1c18 2
1c13 1c1a 2 1bfe
1c1c 1 1c1e 1
1c20 2 1be9 1c21
1 1c25 1 1be4
1 1c29 4 1b38
1b3d 1bb5 1c2c 1
1c31 2 1c33 1c34
3 1b29 1b2e 1c35
1 1c37 1 1c39
1 1c41 2 1c43
1c44 1 1c48 2
1c46 1c48 1 1c4e
2 1c50 1c51 2
1c53 1c54 2 1c56
1c58 1 1c4a 1
1c60 2 1c62 1c63
2 1c65 1c66 2
1c5c 1c69 1 1c71
2 1c70 1c71 2
1c7b 1c7d 3 1c7a
1c7f 1c80 1 1c82
2 1c84 1c85 1
1c89 2 1c87 1c89
2 1c90 1c92 3
1c8f 1c94 1c95 1
1c97 2 1c99 1c9a
1 1c9e 2 1c9c
1c9e 1 1ca4 1
1ca6 2 1ca9 1cab
2 1ca7 1cae 1
1cb3 2 1cb2 1cb3
2 1cbf 1cc1 3
1cbd 1cbe 1cc3 2
1ccc 1cce 2 1cd0
1cd2 2 1cd4 1cd6
1 1cde 2 1ce0
1ce1 2 1cd8 1ce3
2 1ccb 1ce5 1
1ce7 1 1ce9 2
1cf3 1cf5 3 1cf1
1cf2 1cf7 2 1d00
1d02 2 1cff 1d04
1 1d06 1 1d08
2 1d0f 1d10 3
1cea 1d09 1d12 1
1d14 2 1d1a 1d1f
2 1d30 1d32 3
1d2e 1d2f 1d34 2
1d3d 1d3f 2 1d41
1d43 2 1d45 1d47
2 1d49 1d4b 2
1d4d 1d4f 3 1d54
1d55 1d56 2 1d51
1d58 2 1d3c 1d5a
1 1d5c 1 1d5e
2 1d27 1d5f 1
1d63 1 1d22 1
1d67 5 1c6b 1c6e
1cb1 1d15 1d6a 1
1d6d 2 1d70 1d71
1 1d77 2 1d73
1d77 2 1d81 1d83
2 1d88 1d8a 4
1d7c 1d7f 1d86 1d8d
2 1d91 1d92 1
1d98 2 1d94 1d98
2 1d9f 1da1 2
1da6 1da8 4 1d9d
1da4 1dab 1dae 2
1db2 1db3 1 1db9
2 1db5 1db9 1
1dc2 2 1dc8 1dca
2 1dcf 1dd1 2
1dd6 1dd8 3 1dcd
1dd4 1ddb 1 1ddd
2 1de0 1de2 1
1de6 2 1dec 1dee
2 1df3 1df5 2
1dfa 1dfc 3 1df1
1df8 1dff 1 1e01
5 1dbe 1dc1 1dde
1de5 1e02 1 1e04
2 1e0a 1e0c 2
1e0f 1e12 2 1e15
1e17 2 1e19 1e1b
1 1e22 2 1e28
1e2a 2 1e2f 1e31
2 1e36 1e38 3
1e2d 1e34 1e3b 1
1e3d 2 1e40 1e42
2 1e44 1e46 2
1e48 1e4a 2 1e4c
1e4e 2 1e50 1e52
2 1e54 1e56 4
1e1e 1e21 1e3e 1e59
2 1e5b 1e5c 1
1e5e 2 1e64 1e66
2 1e68 1e6a 2
1e6c 1e6e 1 1e71
1 1e73 2 1e5d
1e74 2 1e76 1e77
1 1e78 3 1e7a
1db0 1e7b 2 1e7e
1e7f 1 1e85 2
1e81 1e85 1 1e88
2 1e92 1e97 2
1ea8 1eaa 3 1ea6
1ea7 1eac 2 1eb5
1eb7 2 1eb9 1ebb
2 1ebd 1ebf 2
1ec1 1ec3 2 1ec5
1ec7 3 1ecc 1ecd
1ece 2 1ec9 1ed0
2 1eb4 1ed2 1
1ed4 1 1ed6 2
1e9f 1ed7 1 1edb
1 1e9a 1 1edf
1 1eea 2 1ee6
1eea 1 1ef1 2
1ef3 1ef4 2 1ef9
1efb 2 1f00 1f02
2 1f04 1f06 2
1f08 1f0a 2 1f0c
1f0e 3 1ef7 1efe
1f11 2 1f1b 1f1d
3 1f19 1f1a 1f1f
2 1f28 1f2a 2
1f2c 1f2e 2 1f30
1f32 1 1f3a 2
1f3c 1f3d 2 1f34
1f3f 2 1f41 1f43
2 1f45 1f47 2
1f49 1f4b 2 1f4d
1f4f 2 1f27 1f51
1 1f53 1 1f55
2 1f5f 1f61 3
1f5d 1f5e 1f63 2
1f6c 1f6e 2 1f6b
1f70 1 1f72 1
1f74 3 1f7b 1f7c
1f7d 3 1f56 1f75
1f7f 2 1f81 1f82
2 1ee2 1f83 1
1f85 1 1f87 2
1f91 1f96 2 1fa7
1fa9 3 1fa5 1fa6
1fab 2 1fb4 1fb6
2 1fb8 1fba 2
1fbc 1fbe 2 1fc0
1fc2 2 1fc4 1fc6
3 1fcb 1fcc 1fcd
2 1fc8 1fcf 2
1fb3 1fd1 1 1fd3
1 1fd5 2 1f9e
1fd6 1 1fda 1
1f99 1 1fde 1
1fe9 2 1fe5 1fe9
2 1fee 1ff0 2
1ff5 1ff7 2 1ff9
1ffb 2 1ffd 1fff
2 2001 2003 2
1ff3 2006 2 2010
2012 3 200e 200f
2014 2 201d 201f
2 2021 2023 2
2025 2027 1 202f
2 2031 2032 2
2029 2034 2 2036
2038 2 203a 203c
2 203e 2040 2
2042 2044 2 201c
2046 1 2048 1
204a 2 2054 2056
3 2052 2053 2058
2 2061 2063 2
2060 2065 1 2067
1 2069 3 2070
2071 2072 3 204b
206a 2074 2 2076
2077 2 1fe1 2078
1 207a 1 207c
2 2086 208b 2
209c 209e 3 209a
209b 20a0 2 20a9
20ab 2 20ad 20af
2 20b1 20b3 2
20b5 20b7 2 20b9
20bb 3 20c0 20c1
20c2 2 20bd 20c4
2 20a8 20c6 1
20c8 1 20ca 2
2093 20cb 1 20cf
1 208e 1 20d3
1 20de 2 20da
20de 2 20e3 20e5
2 20ea 20ec 2
20ee 20f0 2 20f2
20f4 2 20f6 20f8
2 20e8 20fb 2
2105 2107 3 2103
2104 2109 2 2112
2114 2 2116 2118
2 211a 211c 1
2124 2 2126 2127
2 211e 2129 2
212b 212d 2 212f
2131 2 2133 2135
2 2137 2139 2
2111 213b 1 213d
1 213f 2 2149
214b 3 2147 2148
214d 2 2156 2158
2 2155 215a 1
215c 1 215e 3
2165 2166 2167 3
2140 215f 2169 2
216b 216c 2 20d6
216d 1 216f 2
2172 2173 1 2177
2 2175 2177 2
217b 217c 1 2180
2 217e 2180 2
2186 2188 2 218e
218f 1 2191 2
218a 2193 2 2195
2197 1 219a 1
219c 4 1f86 207b
2170 219d 1 219f
1 21a1 1 21a9
2 21ab 21ac 1
21b5 2 21b4 21b5
2 21c1 21c3 4
21bf 21c0 21c5 21c6
2 21cf 21d4 2
21e5 21e7 3 21e3
21e4 21e9 2 21f2
21f4 2 21f6 21f8
2 21fa 21fc 2
21fe 2200 2 2202
2204 3 2209 220a
220b 2 2206 220d
2 21f1 220f 1
2211 1 2213 2
21dc 2214 1 2218
1 21d7 1 221c
1 2227 2 2223
2227 2 2233 2235
3 2231 2232 2237
2 2240 2242 2
2244 2246 2 2248
224a 1 2252 2
2254 2255 2 224c
2257 2 2259 225b
2 225d 225f 2
2261 2263 2 2265
2267 2 223f 2269
1 226b 1 226d
2 2277 2279 3
2275 2276 227b 2
2284 2286 2 2283
2288 1 228a 1
228c 3 2293 2294
2295 3 226e 228d
2297 1 2299 2
229c 229e 2 22a0
22a2 2 22a4 22a6
2 22a8 22aa 2
22ac 22ae 2 22b0
22b2 2 22b7 22b8
1 22be 2 22ba
22be 2 22c2 22c4
1 22c7 2 22ca
22cc 1 22cf 2
22d1 22d2 2 22d5
22d6 1 22dc 2
22d8 22dc 1 22e0
1 22e2 2 22e5
22e7 7 21c9 221f
229a 22b5 22d3 22e3
22ea 3 21af 21b2
22ed 1 22ef 2
22f2 22f3 1 22f9
2 22f5 22f9 1
22ff 2 2301 2302
1 230b 2 230a
230b 2 2317 2319
4 2315 2316 231b
231c 2 2325 232a
2 233b 233d 3
2339 233a 233f 2
2348 234a 2 234c
234e 2 2350 2352
2 2354 2356 2
2358 235a 3 235f
2360 2361 2 235c
2363 2 2347 2365
1 2367 1 2369
2 2332 236a 1
236e 1 232d 1
2372 1 237d 2
2379 237d 2 2389
238b 3 2387 2388
238d 2 2396 2398
2 239a 239c 2
239e 23a0 1 23a8
2 23aa 23ab 2
23a2 23ad 2 23af
23b1 2 23b3 23b5
2 23b7 23b9 2
23bb 23bd 2 2395
23bf 1 23c1 1
23c3 2 23cd 23cf
3 23cb 23cc 23d1
2 23da 23dc 2
23d9 23de 1 23e0
1 23e2 3 23e9
23ea 23eb 3 23c4
23e3 23ed 1 23ef
2 23f2 23f4 2
23f6 23f8 2 23fa
23fc 2 23fe 2400
2 2402 2404 2
2406 2408 2 240a
240c 2 2411 2413
5 231f 2375 23f0
240f 2416 3 2305
2308 2419 1 241b
2 241e 2420 7
1c38 1d6e 1e7c 21a0
22f0 241c 2423 2
2425 2426 2 2429
242b 1 2440 1
2446 2 2448 2449
1 2451 2 244d
2451 1 2456 1
2458 2 245b 245c
1 2460 2 245e
2460 2 2464 2465
1 246b 2 2467
246b 2 2471 2472
1 2478 2 2474
2478 2 247e 247f
1 2485 2 2481
2485 1 2488 1
24a2 1 24a8 2
24aa 24ab 1 24b3
2 24af 24b3 2
24b9 24bf 2 24d0
24d2 3 24ce 24cf
24d4 2 24dd 24df
2 24e1 24e3 2
24e5 24e7 2 24e9
24eb 2 24ed 24ef
3 24f4 24f5 24f6
2 24f1 24f8 2
24dc 24fa 1 24fc
1 24fe 2 24c7
24ff 1 2503 1
24c2 1 2507 2
250a 250d 2 2511
2517 2 2528 252a
3 2526 2527 252c
2 2535 2537 2
2539 253b 2 253d
253f 2 2541 2543
2 2545 2547 3
254c 254d 254e 2
2549 2550 2 2534
2552 1 2554 1
2556 2 251f 2557
1 255b 1 251a
1 255f 1 2562
2 2565 2566 4
2494 2499 24ac 2567
1 2569 2 2572
2573 1 2577 2
2575 2577 3 257b
257c 257d 1 2581
2 257f 2581 2
2588 258b 2 258f
2590 1 2592 1
2596 2 2594 2596
2 25a2 25a7 2
25b8 25ba 3 25b6
25b7 25bc 2 25c5
25c7 2 25c9 25cb
2 25cd 25cf 2
25d1 25d3 2 25d5
25d7 3 25dc 25dd
25de 2 25d9 25e0
2 25c4 25e2 1
25e4 1 25e6 2
25af 25e7 1 25eb
1 25aa 1 25ef
2 25f5 25f6 1
25fa 2 25f8 25fa
2 25ff 2605 2
2616 2618 3 2614
2615 261a 2 2623
2625 2 2627 2629
2 262b 262d 2
262f 2631 2 2633
2635 3 263a 263b
263c 2 2637 263e
2 2622 2640 1
2642 1 2644 2
260d 2645 1 2649
1 2608 1 264d
2 265a 265c 3
2658 2659 265e 2
2667 2669 2 266b
266d 2 266f 2671
1 2679 2 267b
267c 2 2673 267e
2 2680 2682 2
2684 2686 2 2688
268a 2 268c 268e
2 2666 2690 1
2692 1 2694 2
269e 26a0 3 269c
269d 26a2 2 26ab
26ad 2 26aa 26af
1 26b1 1 26b3
3 26ba 26bb 26bc
4 2650 2695 26b4
26be 1 26c0 2
25f2 26c1 1 26c3
1 26c4 2 26c6
26c7 2 26e8 26e9
20 26cb 26cc 26cd
26ce 26cf 26d0 26d1
26d2 26d3 26d4 26d5
26d6 26d7 26d8 26d9
26da 26db 26dc 26dd
26de 26df 26e0 26e1
26e2 26e3 26e4 26e5
26e6 26eb 26ec 26ed
26ee 1 26f4 2
26f2 26f4 2 26f9
26ff 2 2710 2712
3 270e 270f 2714
2 271d 271f 2
2721 2723 2 2725
2727 2 2729 272b
2 272d 272f 3
2734 2735 2736 2
2731 2738 2 271c
273a 1 273c 1
273e 2 2707 273f
1 2743 1 2702
1 2747 1 2750
2 274c 2750 1
2757 1 2759 2
2763 2765 3 2761
2762 2767 2 2770
2772 2 2774 2776
2 2778 277a 1
2780 2 2782 2783
2 277c 2785 2
2787 2789 2 278b
278d 2 278f 2791
2 2793 2795 2
276f 2797 1 2799
1 279b 2 27a5
27a7 3 27a3 27a4
27a9 2 27b2 27b4
2 27b1 27b6 1
27b8 1 27ba 3
27bf 27c0 27c1 5
274a 275a 279c 27bb
27c3 3 27c7 27c8
27c9 1 27cd 2
27cb 27cd 3 27d2
27d3 27d4 1 27d8
2 27d6 27d8 1
27e6 2 27e5 27e6
1 27ee 1 27f4
2 27f6 27f7 2
27e3 27f8 2 2809
280b 3 2807 2808
280d 2 2816 2818
2 281a 281c 2
281e 2820 2 2822
2824 2 2826 2828
3 282d 282e 282f
2 282a 2831 2
2815 2833 1 2835
1 2837 2 2800
2838 1 283c 1
27fb 1 2840 1
2843 2 2847 2846
4 26c8 26f1 2848
284a 2 284d 284e
1 2854 2 2850
2854 2 2859 285c
1 285e 20 2862
2863 2864 2865 2866
2867 2868 2869 286a
286b 286c 286d 286e
286f 2870 2871 2872
2873 2874 2875 2876
2877 2878 2879 287a
287b 287c 287d 287e
287f 2880 2881 1
2887 2 2885 2887
2 288b 288d 1
2890 1 2892 2
2897 2898 1 289a
2 2894 289a 1
289e 1 28a0 4
285f 2884 2893 28a1
2 28a3 28a4 1
28a6 8 2437 244a
2459 256a 256d 2570
28a5 28a9 2 28af
28b5 2 28c6 28c8
3 28c4 28c5 28ca
2 28d3 28d5 2
28d7 28d9 2 28db
28dd 2 28df 28e1
2 28e3 28e5 3
28ea 28eb 28ec 2
28e7 28ee 2 28d2
28f0 1 28f2 1
28f4 2 28bd 28f5
1 28f9 1 28b8
1 28fd 1 2906
2 2902 2906 1
290c 2 290a 290c
2 2911 2912 1
2916 2 2914 2916
2 2927 2929 3
2925 2926 292b 2
2934 2936 2 2938
293a 2 293c 293e
1 2944 2 2946
2947 2 2940 2949
2 294b 294d 2
294f 2951 2 2953
2955 2 2957 2959
2 2933 295b 1
295d 1 295f 2
2969 296b 3 2967
2968 296d 2 2976
2978 2 2975 297a
1 297c 1 297e
3 2983 2984 2985
3 2960 297f 2987
1 2989 1 298d
2 298b 298d 8
29a3 29a4 29a5 29a6
29a7 29a8 29a9 29aa
1 29b5 1 29bb
2 29bd 29be 1
29c6 2 29c2 29c6
1 29cb 1 29cd
1 29cf 2 29d7
29d8 1 29dc 2
29da 29dc 1 29e3
2 29e5 29e6 1
29ea 2 29e8 29ea
1 29f1 1 29f3
2 29f8 29f9 1
29fd 2 29fb 29fd
1 2a02 2 2a00
2a02 1 2a17 2
2a16 2a17 1 2a1f
1 2a25 2 2a27
2a28 2 2a14 2a29
2 2a3a 2a3c 3
2a38 2a39 2a3e 2
2a47 2a49 2 2a4b
2a4d 2 2a4f 2a51
2 2a53 2a55 2
2a57 2a59 3 2a5e
2a5f 2a60 2 2a5b
2a62 2 2a46 2a64
1 2a66 1 2a68
2 2a31 2a69 1
2a6d 1 2a2c 1
2a71 1 2a74 1
2a77 9 2a78 2a7b
2a7e 2a81 2a84 2a87
2a8a 2a8d 2a90 1
2a92 1 2a96 2
2a94 2a96 1 2a99
1 2aac 2 2aab
2aac 1 2ab4 1
2aba 2 2abc 2abd
2 2aa9 2abe 2
2acf 2ad1 3 2acd
2ace 2ad3 2 2adc
2ade 2 2ae0 2ae2
2 2ae4 2ae6 2
2ae8 2aea 2 2aec
2aee 3 2af3 2af4
2af5 2 2af0 2af7
2 2adb 2af9 1
2afb 1 2afd 2
2ac6 2afe 1 2b02
1 2ac1 1 2b06
1 2b09 1 2b0c
1 2b0e 1 2b13
2 2b1a 2b1c 3
2b1e 2b1f 2b20 1
2b23 1 2b25 2
2b29 2b2b 3 2b2d
2b2e 2b2f 2 2b26
2b32 1 2b34 1
2b36 2 2b3d 2b3f
3 2b41 2b42 2b43
1 2b46 1 2b48
1 2b4a 1 2b4f
2 2b56 2b58 3
2b5a 2b5b 2b5c 1
2b5f 1 2b61 2
2b65 2b67 3 2b69
2b6a 2b6b 2 2b62
2b6e 1 2b70 1
2b72 2 2b79 2b7b
3 2b7d 2b7e 2b7f
1 2b82 1 2b84
1 2b86 1 2b8b
2 2b92 2b94 3
2b96 2b97 2b98 1
2b9b 1 2b9d 2
2ba1 2ba3 3 2ba5
2ba6 2ba7 2 2b9e
2baa 1 2bac 1
2bae 1 2bb3 2
2bba 2bbc 3 2bbe
2bbf 2bc0 1 2bc3
1 2bc5 2 2bc9
2bcb 3 2bcd 2bce
2bcf 2 2bc6 2bd2
1 2bd4 2 2bd7
2bd9 e 29ab 29bf
29ce 29f4 2a93 2b0d
2b35 2b49 2b71 2b85
2bad 2bd5 2bdc 2bdf
2 2be5 2beb 2
2bfc 2bfe 3 2bfa
2bfb 2c00 2 2c09
2c0b 2 2c0d 2c0f
2 2c11 2c13 2
2c15 2c17 2 2c19
2c1b 3 2c20 2c21
2c22 2 2c1d 2c24
2 2c08 2c26 1
2c28 1 2c2a 2
2bf3 2c2b 1 2c2f
1 2bee 1 2c33
1 2c3a 2 2c38
2c3a 1 2c4f 2
2c4e 2c4f 1 2c57
1 2c5d 2 2c5f
2c60 2 2c4c 2c61
2 2c72 2c74 3
2c70 2c71 2c76 2
2c7f 2c81 2 2c83
2c85 2 2c87 2c89
2 2c8b 2c8d 2
2c8f 2c91 3 2c96
2c97 2c98 2 2c93
2c9a 2 2c7e 2c9c
1 2c9e 1 2ca0
2 2c69 2ca1 1
2ca5 1 2c64 1
2ca9 1 2cac 1
2caf 8 2992 2995
2998 299b 29a0 2be2
2c36 2cb0 1 2cb2
1 2cb4 2 2cba
2cbb 1 2cbf 2
2cbd 2cbf 2 2cd0
2cd5 2 2ce6 2ce8
3 2ce4 2ce5 2cea
2 2cf3 2cf5 2
2cf7 2cf9 2 2cfb
2cfd 2 2cff 2d01
2 2d03 2d05 3
2d0a 2d0b 2d0c 2
2d07 2d0e 2 2cf2
2d10 1 2d12 1
2d14 2 2cdd 2d15
1 2d19 1 2cd8
1 2d1d 1 2d20
2 2d25 2d26 2
2d28 2d29 1 2d2a
1 2d2c 2 2d41
2d46 2 2d57 2d59
3 2d55 2d56 2d5b
2 2d64 2d66 2
2d68 2d6a 2 2d6c
2d6e 2 2d70 2d72
2 2d74 2d76 3
2d7b 2d7c 2d7d 2
2d78 2d7f 2 2d63
2d81 1 2d83 1
2d85 2 2d4e 2d86
1 2d8a 1 2d49
1 2d8e 2 2d94
2d95 1 2d9b 2
2d97 2d9b 1 2db6
2 2db5 2db6 1
2dbe 1 2dc4 2
2dc6 2dc7 2 2db3
2dc8 2 2dd9 2ddb
3 2dd7 2dd8 2ddd
2 2de6 2de8 2
2dea 2dec 2 2dee
2df0 2 2df2 2df4
2 2df6 2df8 3
2dfd 2dfe 2dff 2
2dfa 2e01 2 2de5
2e03 1 2e05 1
2e07 2 2dd0 2e08
1 2e0c 1 2dcb
1 2e10 1 2e1b
2 2e17 2e1b 1
2e34 2 2e33 2e34
1 2e3c 1 2e42
2 2e44 2e45 2
2e31 2e46 2 2e57
2e59 3 2e55 2e56
2e5b 2 2e64 2e66
2 2e68 2e6a 2
2e6c 2e6e 2 2e70
2e72 2 2e74 2e76
3 2e7b 2e7c 2e7d
2 2e78 2e7f 2
2e63 2e81 1 2e83
1 2e85 2 2e4e
2e86 1 2e8a 1
2e49 1 2e8e 1
2e99 2 2e95 2e99
1 2ea6 2 2ea5
2ea6 1 2eae 1
2eb4 2 2eb6 2eb7
2 2ea3 2eb8 2
2ec9 2ecb 3 2ec7
2ec8 2ecd 2 2ed6
2ed8 2 2eda 2edc
2 2ede 2ee0 2
2ee2 2ee4 2 2ee6
2ee8 3 2eed 2eee
2eef 2 2eea 2ef1
2 2ed5 2ef3 1
2ef5 1 2ef7 2
2ec0 2ef8 1 2efc
1 2ebb 1 2f00
1 2f03 1 2f06
2 2e91 2f07 1
2f09 2 2fe2 2fe4
3 2fe0 2fe1 2fe6
2 2fef 2ff1 2
2fee 2ff3 1 2ff5
1 2ff7 7 2da2
2da7 2e13 2f0a 2fd8
2ff8 2ffb 1 2fff
2 2ffd 2fff 2
313a 313c 3 3138
3139 313e 2 3147
3149 2 3146 314b
1 314d 1 314f
3 3130 3150 3153
1 316a 2 3169
316a 1 3172 1
3178 2 317a 317b
2 3167 317c 2
318d 318f 3 318b
318c 3191 2 319a
319c 2 319e 31a0
2 31a2 31a4 2
31a6 31a8 2 31aa
31ac 3 31b1 31b2
31b3 2 31ae 31b5
2 3199 31b7 1
31b9 1 31bb 2
3184 31bc 1 31c0
1 317f 1 31c4
1 31e0 2 31df
31e0 1 31e8 1
31ee 2 31f0 31f1
2 31dd 31f2 2
3203 3205 3 3201
3202 3207 2 3210
3212 2 3214 3216
2 3218 321a 2
321c 321e 2 3220
3222 3 3227 3228
3229 2 3224 322b
2 320f 322d 1
322f 1 3231 2
31fa 3232 1 3236
1 31f5 1 323a
2 3401 3403 3
33ff 3400 3405 2
340e 3410 2 340d
3412 1 3414 1
3416 7 3159 315e
31c7 323d 33f7 3417
341a 2 341c 341d
1 341e 2 3420
3421 3b 4f8 517
51a 51d 520 523
526 529 52c 52f
532 535 538 53b
53e 541 544 547
54a 54d 550 553
556 559 55c 55f
5d2 6e1 75f 770
861 8c7 8ca 8de
8eb 8ff 90c 91f
11b4 1396 13b0 156d
1a12 1a17 1a48 1a59
1a7a 1a7d 1a80 2427
242e 2433 28ac 2900
298a 2cb3 2d2d 2d91
3422 2 342f 3431
3 342d 342e 3433
2 343c 343e 2
343b 3440 2 3447
344b 2 344d 344f
2 3451 3455 2
3446 3457 2 3442
3459 1 345b 3
345c 3467 346b 1
3426 2 347e 3480
3 347c 347d 3482
2 348b 348d 2
348a 348f 2 3496
3498 2 349a 349c
3 34a1 34a2 34a3
2 349e 34a5 2
3495 34a7 2 3491
34a9 1 34ab 4
3475 34ac 34b5 34b9
1 34bd 1 3470
2 346e 34c1 69
7b 82 89 90
97 9e a5 ac
b3 ba c1 c8
cf d6 dd e4
eb f2 f9 100
107 10c 113 11a
121 128 12f 136
13d 144 14b 152
159 15f 165 16b
171 177 17d 183
189 18f 195 19b
1a1 1a7 1ad 1b3
1b9 1bf 1c5 1cb
1d1 1d7 1dd 1e3
1e9 1ef 1f5 1fb
201 207 20d 213
219 21f 226 22c
232 238 23f 246
24d 253 259 260
267 26e 275 27c
283 289 28f 295
29b 2a1 2a7 2ad
2b3 2ba 2c0 2c5
2ca 2cf 2d4 2d9
2de 2e3 2ea 2fa
315 31f 326 32d
334 
1
4
0 
34c8
0
1
a0
65
86
0 1 1 1 4 1 6 1
8 1 a 1 c 1 e 1
10 1 12 1 14 1 16 1
18 1 1a 1 1c 1 1e 1
20 1 22 1 24 1 26 1
28 1 2a 1 2c 1 2e 1
1 31 1 33 1 35 1 37
1 39 3a 1 3c 3d 1 3f
40 3f 42 3f 44 3f 46 3f
48 3f 4a 1 4c 1 4e 4f
4e 51 1 53 1 55 1 57
1 59 1 5b 1 5d 1 5f
1 61 1 63 1 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0

2a3 1 0
6b 1 0
2b 1 0
e6 1 0
255 1 0
2a9 1 0
21b 1 0
bc 1 0
5f 1 0
270 1 0
4b 1 0
285 1 0
d8 1 0
2e5 1 0
2bc 1 0
1af 1 0
215 1 0
185 1 0
8b 1 0
29d 1 0
27 1 0
2cc 1 0
2ed 1 2
25b 1 0
1f 1 0
53 1 0
1fd 1 0
a7 1 0
1b 1 0
1f1 1 0
2f 1 0
2af 1 0
131 1 0
300 1 3
13f 1 0
fb 1 0
28a6 3f 4c
16d 1 0
d1 1 0
138 1 0
173 1 0
63 1 0
43 1 0
23a 1 0
67 1 0
234 1 0
109 1 0
2c2 1 0
291 1 0
4f 1 0
2d6 1 0
1d3 1 0
13 1 0
1a9 1 0
ed 1 0
b5 1 0
19d 1 0
123 1 0
115 1 0
154 1 0
3f 1 0
248 1 0
1d9 1 0
221 1 0
10e 1 0
ae 1 0
3b 1 0
37 1 0
33 1 0
f 1 0
197 1 0
31a 1 0
92 1 0
3 1 0
c3 1 0
27e 1 0
15b 1 0
5b 1 0
328 1 0
146 1 0
321 1 0
22e 1 0
209 1 0
12a 1 0
11c 1 0
28b 1 0
18b 1 0
1f7 1 0
2 0 1
1c7 1 0
1bb 1 0
23 1 0
84 1 0
102 1 0
297 1 0
20f 1 0
7 1 0
1eb 1 0
1a3 1 0
2d1 1 0
191 1 0
a0 1 0
241 1 0
1df 1 0
179 1 0
277 1 0
269 1 0
203 1 0
161 1 0
24f 1 0
228 1 0
167 1 0
57 1 0
f4 1 0
7d 1 0
1c1 1 0
ca 1 0
47 1 0
17f 1 0
df 1 0
2db 1 0
1e5 1 0
17 1 0
2e0 1 0
14d 1 0
2b5 1 0
1cd 1 0
99 1 0
2c7 1 0
76 1 0
1b5 1 0
b 1 0
32f 1 0
262 1 0
0

/
SHOW ERRORS FUNCTION SP_SEARCH_2;
ALTER FUNCTION SP_SEARCH_2 COMPILE DEBUG;
/*#################################################################################################*/
/*#################################################################################################*/
/*
#Stored Procedure  :SP_SEARCH_1
#Short Description :
#Description       :
#Table Name        :
#Parameters        :
#Returns           :
#Errors            :
*/
Prompt == FUNCTION SP_SEARCH_1 ==
CREATE OR REPLACE FUNCTION SP_SEARCH_1 wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
29c
2 :e:
1FUNCTION:
1SP_SEARCH_1:
1PRJ_ID:
1VARCHAR2:
1START_DATE001:
1FINISH_DATE001:
1EFFORT001:
1PLS_INTEGER:
1WORK001:
1BITFLAG001:
1EUNIT:
1UNIT:
1CONTOUR001:
1OCCURRENCE:
1CONSIDER_PLANNED_SCHED:
1WORK_TYPE:
1TYPE001:
1AND_ROLES:
1REC_USER001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_PROJECT_ID:
132:
1H_PRJ_ASSIGN_ID:
1H_TASK_ID:
1H_UNIQUEID:
1H_REC_USER:
1H_RES_ID:
1H_SECURITY_ID:
1H_START_DATE:
126:
1H_START_DT:
1H_FINISH_DT:
1H_DAYOFYEAR:
1DATE:
1H_FINISH_D:
1H_RES_TYPE:
11:
1H_ASSIGN_ID:
1H_AND_ROLES:
18000:
1H_SHW_ROLE:
1H_SHW_SKILL:
1H_FULL_NAME:
1255:
1H_COUNT:
10:
1H_BITFLAG:
1H_TYPE:
1H_WORK_TYPE:
1H_CRI:
1H_WORK:
1H_OCCURRENCE:
1H_EFFORT:
1H_EUNIT:
1H_UNIT:
1H_CONSIDER:
1H_CONTOUR:
1H_EVERY:
1H_PER_DAY:
1H_PER_WEEK:
1H_UPDATE:
1H_DAYS:
1H_DURATION:
1H_PARTICIPANT:
1H_PRIORITY:
1H_TOTAL:
1H_TOTPR:
1H_FROM_PRJ:
1H_SCHED_WORK:
1H_JULIAN_DAY:
1H_J_EFECTIVE_DATE:
1H_J_DISCONTI_DATE:
1H_WEEK:
1H_ACTIVE:
1H_REC_STATUS:
1H_RES_COST:
1NUMBER:
10.00:
1STMT:
17999:
1H_TEMP_PARTICIPANT:
1H_TEMP_SECURITY_ID:
1CHAR:
1H_TEMP2_SECURITY_ID:
1H_CRI_SECURITY_ID:
1H_TEMP_BITFLAG:
1H_TEMP_SC_STATE:
1H_TABLE_TYPE:
1H_TASK_START_DT:
1H_TASK_FINISH_DT:
1H_TASK_TYPE:
1H_TEMP_VAR:
1ID001:
1I:
1II:
1I_RETURN:
1ISF:
1NUMITEMS:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_SEARCH_1(:
1':
1, :
1COALESCE:
1TO_CHAR:
1NULL:
1);:
1CHECK_TRACE:
1109:
1+:
1FPUT:
1               ENTER:: SP_SEARCH_1(110) :: cplan.sql(2520) :: :
1:
1GETTABLE:
1IS NULL:
18:
1150:
1      RETURN_INVALID:: SP_SEARCH_1(151) :: cplan.sql(2561) :: :
1 :
1STATE:: :
1PMO_CNST:
1ELEMENT_ID_REQUIRED:
1153:
1                EXIT:: SP_SEARCH_1(154) :: cplan.sql(2564) :: :
1PMODEFINES:
1PMO_RETURN_INVALID_SP:
1TRUE:
1160:
1      RETURN_INVALID:: SP_SEARCH_1(161) :: cplan.sql(2571) :: :
1163:
1                EXIT:: SP_SEARCH_1(164) :: cplan.sql(2574) :: :
1=:
15:
1180:
1      RETURN_INVALID:: SP_SEARCH_1(181) :: cplan.sql(2591) :: :
1INVALID_PARAMS:
1183:
1                EXIT:: SP_SEARCH_1(184) :: cplan.sql(2594) :: :
1IS NOT NULL:
1PMO_ORASTD:
1DAYS:
1DUAL:
1SELECT PMO_ORASTD.DAYS(finish_date001) - PMO_ORASTD.DAYS(start_date001):n    +
1     INTO h_total:n         FROM DUAL:
1SC_STATE:
1SQLCODE:
1OTHERS:
116:
1199:
1           EXCEPTION:: SP_SEARCH_1(200) :: cplan.sql(2610) :: :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1SC_SQL_SUCCESS:
1<:
1206:
1      RETURN_INVALID:: SP_SEARCH_1(207) :: cplan.sql(2617) :: :
1F_DATE_EARLIER_THAN_S_DATE:
1209:
1                EXIT:: SP_SEARCH_1(210) :: cplan.sql(2620) :: :
1ELSIF:
1SELECT SYSTIMESTAMP INTO h_start_date:n         FROM DUAL:
1225:
1           EXCEPTION:: SP_SEARCH_1(226) :: cplan.sql(2636) :: :
1>:
1PMO_STPU:
1STRNPCPY:
133:
1ISPROJECTTYPE:
1!=:
1PROJECT_ID:
1MINUTE_PER_DAY:
1MINUTE_PER_WEEK:
1PRIORITY:
1TMT_WBS:
1ELEMENT_ID:
1SELECT PROJECT_ID, COALESCE(MINUTE_PER_DAY, 480), COALESCE(MINUTE_PER_WEEK, 2+
1400), PRIORITY:n            INTO h_project_id, h_per_day, h_per_week, h_prior+
1ity:n            FROM TMT_WBS WHERE ELEMENT_ID = h_task_id:
1256:
1           EXCEPTION:: SP_SEARCH_1(257) :: cplan.sql(2667) :: :
1B:
1TYPE_ID:
1TASK_TYPE:
1UNRESOLVED_START:
1UNRESOLVED_FINISH:
1A:
1SC_TASK:
1SC_TASK_TYPE1:
1SC_TASK_TYPE2:
1SC_TASK_TYPE3:
1SC_MILESTONE:
1SC_PERSONAL_TASK:
1SC_ACTIVE_ADM_TASK:
1SC_INACTIVE_ADM_TASK:
1SC_WBS_CHANGE_REQUEST_TASK:
1SC_WBS_ACTION_ITEM_TASK:
1SC_WBS_RISK_TASK:
1SC_WBS_ISSUE_TASK:
1SC_WBS_REQUIREMENT_TASK:
1SC_WBS_DEFECT_TASK:
1SC_WBS_SERVICE_REQUEST_TASK:
1SELECT B.TYPE_ID, B.TASK_TYPE, B.UNRESOLVED_START, B.UNRESOLVED_FINISH, B.PRO+
1JECT_ID,:n            COALESCE(A.MINUTE_PER_DAY, 480), COALESCE(A.MINUTE_PER_+
1WEEK, 2400), A.PRIORITY:n            INTO h_type, h_task_type, h_task_start_D+
1T, h_task_finish_DT, h_project_id,:n            h_per_day, h_per_week, h_prio+
1rity FROM TMT_WBS A, TMT_WBS B:n            WHERE B.ELEMENT_ID = h_task_id AN+
1D B.TYPE_ID IN (PMO_CNST.SC_TASK,PMO_CNST.SC_TASK_TYPE1,PMO_CNST.SC_TASK_TYPE+
12,PMO_CNST.SC_TASK_TYPE3,PMO_CNST.SC_MILESTONE,PMO_CNST.SC_PERSONAL_TASK,PMO_+
1CNST.SC_ACTIVE_ADM_TASK,PMO_CNST.SC_INACTIVE_ADM_TASK,PMO_CNST.SC_WBS_CHANGE_+
1REQUEST_TASK,PMO_CNST.SC_WBS_ACTION_ITEM_TASK,PMO_CNST.SC_WBS_RISK_TASK,PMO_C+
1NST.SC_WBS_ISSUE_TASK,PMO_CNST.SC_WBS_REQUIREMENT_TASK,PMO_CNST.SC_WBS_DEFECT+
1_TASK,PMO_CNST.SC_WBS_SERVICE_REQUEST_TASK) AND A.ELEMENT_ID = B.PROJECT_ID:
1273:
1           EXCEPTION:: SP_SEARCH_1(274) :: cplan.sql(2684) :: :
1SC_SQL_NO_DATA:
1WBS_ID:
1TMT_CRI:
1SELECT PROJECT_ID, WBS_ID INTO h_project_id, id001:n            FROM TMT_CRI +
1WHERE ELEMENT_ID = h_task_id:
1289:
1           EXCEPTION:: SP_SEARCH_1(290) :: cplan.sql(2700) :: :
1SELECT COALESCE(MINUTE_PER_DAY, 480), COALESCE(MINUTE_PER_WEEK, 2400), PRIORI+
1TY:n               INTO h_per_day, h_per_week, h_priority:n               FRO+
1M TMT_WBS WHERE ELEMENT_ID = h_project_id:
1308:
1           EXCEPTION:: SP_SEARCH_1(309) :: cplan.sql(2719) :: :
1314:
1        RETURN_ERROR:: SP_SEARCH_1(315) :: cplan.sql(2725) :: :
1RECORD_NOT_FOUND:
1 ID:: :
1317:
1                EXIT:: SP_SEARCH_1(318) :: cplan.sql(2728) :: :
1PMO_RETURN_ERROR_SP:
1LEVEL_LOCK:
1PROJECT_DETAILS:
1SELECT LEVEL_LOCK INTO h_temp_var:n         FROM PROJECT_DETAILS:n         WH+
1ERE PROJECT_ID = h_project_id:
1336:
1           EXCEPTION:: SP_SEARCH_1(337) :: cplan.sql(2747) :: :
1REC_STATUS:
1SELECT REC_STATUS INTO h_rec_status:n            FROM TMT_WBS:n            WH+
1ERE ELEMENT_ID = h_project_id:
1352:
1           EXCEPTION:: SP_SEARCH_1(353) :: cplan.sql(2763) :: :
1STRCMP:
1L:
1359:
1        RETURN_ERROR:: SP_SEARCH_1(360) :: cplan.sql(2770) :: :
1LEV_LOCKED_BY_COPY:
1362:
1                EXIT:: SP_SEARCH_1(363) :: cplan.sql(2773) :: :
1SELECT COALESCE(MINUTE_PER_DAY, 480), COALESCE(MINUTE_PER_WEEK, 2400), PRIORI+
1TY:n         INTO h_per_day, h_per_week, h_priority:n         FROM TMT_WBS WH+
1ERE ELEMENT_ID = h_project_id:
1378:
1           EXCEPTION:: SP_SEARCH_1(379) :: cplan.sql(2789) :: :
1TMT_POOLS:
1SELECT 480, 2400 INTO h_per_day, h_per_week FROM TMT_POOLS WHERE ELEMENT_ID =+
1 h_project_id:
1391:
1           EXCEPTION:: SP_SEARCH_1(392) :: cplan.sql(2802) :: :
1397:
1        RETURN_ERROR:: SP_SEARCH_1(398) :: cplan.sql(2808) :: :
1400:
1                EXIT:: SP_SEARCH_1(401) :: cplan.sql(2811) :: :
1FC_CALC_DURATION:
1431:
1      RETURN_INVALID:: SP_SEARCH_1(432) :: cplan.sql(2842) :: :
1434:
1                EXIT:: SP_SEARCH_1(435) :: cplan.sql(2845) :: :
1439:
1        RETURN_ERROR:: SP_SEARCH_1(440) :: cplan.sql(2850) :: :
1442:
1                EXIT:: SP_SEARCH_1(443) :: cplan.sql(2853) :: :
1100:
12:
13:
14:
1*:
1FC_DECLARE_PMO_TMP_SEARCH:
1PMO_FUNC:
1SHIFTRIGHT:
1BITAND:
1SC_C0000000:
130:
1SC_1FFFFFFF:
1ASSIGNRESOURCE:
1480:
1        RETURN_ERROR:: SP_SEARCH_1(481) :: cplan.sql(2891) :: :
1483:
1                EXIT:: SP_SEARCH_1(484) :: cplan.sql(2894) :: :
1MIN:
1BAK_START_DT:
1TASK_ASSIGNMENTS:
1TASK_ID:
1RESOURCE_ID:
1RESOURCE_TYPE:
1SELECT MIN(BAK_START_DT), PMO_ORASTD.DAYS(h_start_date) - PMO_ORASTD.DAYS(MIN+
1(BAK_START_DT)):n         INTO h_start_DT, h_total :n         FROM TASK_ASSIG+
1NMENTS:n         WHERE PROJECT_ID = h_project_id :n         AND TASK_ID = h_p+
1roject_id :n         AND RESOURCE_ID = h_res_id :n         AND RESOURCE_TYPE +
1= h_res_type:
1504:
1           EXCEPTION:: SP_SEARCH_1(505) :: cplan.sql(2915) :: :
1PROJECT_ASSIGNMENT_ID:
1SCHED_START:
1TO_DATE:
1SCHED_FINISH:
1SCHED_WORK:
1BIT_FLAG:
1SELECT PROJECT_ASSIGNMENT_ID, SCHED_START, CASE WHEN TO_DATE(SubStr(h_start_d+
1ate, 1, 10)) >= TO_DATE(SubStr(SCHED_START, 1, 10)) AND:n               TO_DA+
1TE(SubStr(h_finish_DT, 1, 10)) <= TO_DATE(SubStr(SCHED_FINISH, 1, 10)) AND SC+
1HED_WORK >= h_effort THEN 0 ELSE 1 END,SCHED_WORK:n               INTO h_prj_+
1assign_id, h_start_DT, h_total, h_sched_work:n               FROM TASK_ASSIGN+
1MENTS:n               WHERE TASK_ID=h_project_id AND RESOURCE_ID=h_res_id AND+
1 RESOURCE_TYPE='0' AND BIT_FLAG = '2':
1532:
1           EXCEPTION:: SP_SEARCH_1(533) :: cplan.sql(2943) :: :
1PLANNED_START:
1PLANNED_FINISH:
1PLANNED_WORK:
1SELECT PROJECT_ASSIGNMENT_ID, PLANNED_START, CASE WHEN TO_DATE(SubStr(h_start+
1_date, 1, 10)) >= TO_DATE(SubStr(PLANNED_START, 1, 10)) AND:n                +
1     TO_DATE(SubStr(h_finish_DT, 1, 10)) <= TO_DATE(SubStr(PLANNED_FINISH, 1,+
1 10)) AND PLANNED_WORK >= h_effort THEN 0 ELSE 1 END:n                     IN+
1TO h_prj_assign_id, h_start_DT, h_total :n                     FROM TASK_ASSI+
1GNMENTS:n                     WHERE TASK_ID=h_project_id AND RESOURCE_ID=h_re+
1s_id AND RESOURCE_TYPE='0' AND BIT_FLAG = '0':
1552:
1           EXCEPTION:: SP_SEARCH_1(553) :: cplan.sql(2963) :: :
1SELECT PROJECT_ASSIGNMENT_ID, PLANNED_START, CASE WHEN TO_DATE(SubStr(h_start+
1_date, 1, 10)) >= TO_DATE(SubStr(PLANNED_START, 1, 10)) AND:n                +
1  TO_DATE(SubStr(h_finish_DT, 1, 10)) <= TO_DATE(SubStr(PLANNED_FINISH, 1, 10+
1)) AND PLANNED_WORK >= h_effort THEN 0 ELSE 1 END:n                  INTO h_p+
1rj_assign_id, h_start_DT, h_total :n                  FROM TASK_ASSIGNMENTS:n+
1                  WHERE TASK_ID=h_project_id AND RESOURCE_ID=h_res_id AND RES+
1OURCE_TYPE='0' AND BIT_FLAG = '0':
1572:
1           EXCEPTION:: SP_SEARCH_1(573) :: cplan.sql(2983) :: :
1SELECT PROJECT_ASSIGNMENT_ID, PLANNED_START, CASE WHEN TO_DATE(SubStr(h_start+
1_date, 1, 10)) >= TO_DATE(SubStr(PLANNED_START, 1, 10)) AND:n               T+
1O_DATE(SubStr(h_finish_DT, 1, 10)) <= TO_DATE(SubStr(PLANNED_FINISH, 1, 10)) +
1AND PLANNED_WORK >= h_effort THEN 0 ELSE 1 END:n               INTO h_prj_ass+
1ign_id, h_start_DT, h_total :n               FROM TASK_ASSIGNMENTS:n         +
1      WHERE TASK_ID=h_project_id AND RESOURCE_ID=h_res_id AND RESOURCE_TYPE='+
11' AND BIT_FLAG = '0':
1590:
1           EXCEPTION:: SP_SEARCH_1(591) :: cplan.sql(3001) :: :
1SELECT PROJECT_ASSIGNMENT_ID, SCHED_START,CASE WHEN TO_DATE(SubStr(h_start_da+
1te, 1, 10)) BETWEEN TO_DATE(SubStr(SCHED_START, 1, 10)) AND TO_DATE(SubStr(SC+
1HED_FINISH, 1, 10)) AND h_effort <= SCHED_WORK THEN 0 ELSE 1 END, SCHED_WORK+
1:n               INTO h_prj_assign_id, h_start_DT,h_total, h_sched_work :n   +
1            FROM TASK_ASSIGNMENTS:n               WHERE TASK_ID=h_project_id +
1AND RESOURCE_ID=h_res_id AND RESOURCE_TYPE='0' AND BIT_FLAG='2':
1608:
1           EXCEPTION:: SP_SEARCH_1(609) :: cplan.sql(3019) :: :
1SELECT PROJECT_ASSIGNMENT_ID, PLANNED_START, CASE WHEN TO_DATE(SubStr(h_start+
1_date, 1, 10)) <= TO_DATE(SubStr(PLANNED_FINISH, 1, 10)) AND h_effort <= PLAN+
1NED_WORK THEN 0 ELSE 1 END:n                     INTO h_prj_assign_id, h_star+
1t_DT,h_total :n                     FROM TASK_ASSIGNMENTS:n                  +
1   WHERE TASK_ID=h_project_id AND RESOURCE_ID=h_res_id AND RESOURCE_TYPE='0' +
1AND BIT_FLAG = '0':
1627:
1           EXCEPTION:: SP_SEARCH_1(628) :: cplan.sql(3038) :: :
1SELECT PROJECT_ASSIGNMENT_ID, PLANNED_START,CASE WHEN TO_DATE(SubStr(h_start_+
1date, 1, 10)) BETWEEN TO_DATE(SubStr(PLANNED_START, 1, 10)) AND TO_DATE(SubSt+
1r(PLANNED_FINISH, 1, 10)) AND h_effort <= PLANNED_WORK THEN 0 ELSE 1 END:n   +
1               INTO h_prj_assign_id, h_start_DT,h_total :n                  F+
1ROM TASK_ASSIGNMENTS:n                  WHERE TASK_ID=h_project_id AND RESOUR+
1CE_ID=h_res_id AND RESOURCE_TYPE='0' AND BIT_FLAG = '0':
1647:
1           EXCEPTION:: SP_SEARCH_1(648) :: cplan.sql(3058) :: :
1SELECT PROJECT_ASSIGNMENT_ID, PLANNED_START,CASE WHEN TO_DATE(SubStr(h_start_+
1date, 1, 10)) BETWEEN TO_DATE(SubStr(PLANNED_START, 1, 10)) AND TO_DATE(SubSt+
1r(PLANNED_FINISH, 1, 10)) AND h_effort <= PLANNED_WORK THEN 0 ELSE 1 END:n   +
1            INTO h_prj_assign_id, h_start_DT,h_total :n               FROM TA+
1SK_ASSIGNMENTS:n               WHERE TASK_ID=h_project_id AND RESOURCE_ID=h_r+
1es_id AND RESOURCE_TYPE='1' AND BIT_FLAG = '0':
1664:
1           EXCEPTION:: SP_SEARCH_1(665) :: cplan.sql(3075) :: :
1674:
1        RETURN_ERROR:: SP_SEARCH_1(675) :: cplan.sql(3085) :: :
1TASK_ASSIGNMENT_ERROR:
1677:
1                EXIT:: SP_SEARCH_1(678) :: cplan.sql(3088) :: :
1SUM:
1SCHED_MIN:
1TASK_DAY_OF_YEAR:
1TSK_ASSIGNMENT_ID:
1DAY_YEAR:
1SELECT SUM(SCHED_MIN) INTO h_sched_work :n                  FROM TASK_DAY_OF_+
1YEAR:n                  WHERE PROJECT_ID = h_project_id AND TSK_ASSIGNMENT_ID+
1 = h_prj_assign_id :n                  AND DAY_YEAR BETWEEN TO_DATE(SubStr(h_+
1start_date, 1, 10)) AND TO_DATE(SubStr(h_finish_DT, 1, 10)):
1694:
1           EXCEPTION:: SP_SEARCH_1(695) :: cplan.sql(3105) :: :
1SELECT SUM(SCHED_MIN) INTO h_sched_work :n                  FROM TASK_DAY_OF_+
1YEAR:n                  WHERE PROJECT_ID = h_project_id AND TSK_ASSIGNMENT_ID+
1 = h_prj_assign_id :n                  AND DAY_YEAR >= TO_DATE(SubStr(h_start+
1_date, 1, 10)):
1711:
1           EXCEPTION:: SP_SEARCH_1(712) :: cplan.sql(3122) :: :
1719:
1        RETURN_ERROR:: SP_SEARCH_1(720) :: cplan.sql(3130) :: :
1722:
1                EXIT:: SP_SEARCH_1(723) :: cplan.sql(3133) :: :
1ISNOTPROJECTTYPE:
1730:
1        RETURN_ERROR:: SP_SEARCH_1(731) :: cplan.sql(3141) :: :
1733:
1                EXIT:: SP_SEARCH_1(734) :: cplan.sql(3144) :: :
1NICK_NAME:
1JULIAN_DAY:
1ACTIVE:
1EFFECTIVE_DATE:
1DISCONTINUE_DATE:
1RESOURCES:
1SELECT NICK_NAME, PMO_ORASTD.JULIAN_DAY(h_start_DT), ACTIVE, COALESCE(PMO_ORA+
1STD.JULIAN_DAY(EFFECTIVE_DATE),0),COALESCE(PMO_ORASTD.JULIAN_DAY(DISCONTINUE_+
1DATE),0):n            INTO h_full_name, h_julian_day, h_active, h_j_efective_+
1date, h_j_disconti_date:n            FROM RESOURCES :n            WHERE RESOU+
1RCE_ID = h_res_id:
1752:
1           EXCEPTION:: SP_SEARCH_1(753) :: cplan.sql(3163) :: :
1759:
1        RETURN_ERROR:: SP_SEARCH_1(760) :: cplan.sql(3170) :: :
1762:
1                EXIT:: SP_SEARCH_1(763) :: cplan.sql(3173) :: :
1770:
1        RETURN_ERROR:: SP_SEARCH_1(771) :: cplan.sql(3181) :: :
1RESOURCE_NOT_ACTIVE:
1773:
1                EXIT:: SP_SEARCH_1(774) :: cplan.sql(3184) :: :
1RES_ASSIGNMENT_ID:
1PARTICIPANT:
1SECURITY_ID:
1RESOURCE_ASSIGNMENTS:
1SELECT RES_ASSIGNMENT_ID, PARTICIPANT, SECURITY_ID INTO h_assign_id, h_partic+
1ipant, h_security_id:n            FROM RESOURCE_ASSIGNMENTS:n            WHER+
1E ELEMENT_ID = h_task_id AND RESOURCE_TYPE = '0' AND RESOURCE_ID = h_res_id:
1788:
1           EXCEPTION:: SP_SEARCH_1(789) :: cplan.sql(3199) :: :
1PROFILE_NAME:
1PROFILES:
1PROFILE_ID:
1SELECT PROFILE_NAME INTO h_full_name FROM PROFILES WHERE PROFILE_ID = h_res_i+
1d:
1803:
1           EXCEPTION:: SP_SEARCH_1(804) :: cplan.sql(3214) :: :
1810:
1        RETURN_ERROR:: SP_SEARCH_1(811) :: cplan.sql(3221) :: :
1813:
1                EXIT:: SP_SEARCH_1(814) :: cplan.sql(3224) :: :
1BAK_FINISH_DT:
1BAK_WORK:
1SELECT BAK_START_DT, CASE WHEN TO_DATE(SubStr(h_start_date, 1, 10)) BETWEEN T+
1O_DATE(SubStr(BAK_START_DT, 1, 10)) AND TO_DATE(SubStr(BAK_FINISH_DT, 1, 10))+
1 AND BAK_WORK >= h_effort THEN 0 ELSE 1 END:n            INTO h_start_DT, h_t+
1otal :n            FROM TASK_ASSIGNMENTS:n            WHERE TASK_ID=h_project+
1_id AND RESOURCE_ID=h_res_id AND RESOURCE_TYPE='1':
1829:
1           EXCEPTION:: SP_SEARCH_1(830) :: cplan.sql(3240) :: :
1836:
1        RETURN_ERROR:: SP_SEARCH_1(837) :: cplan.sql(3247) :: :
1839:
1                EXIT:: SP_SEARCH_1(840) :: cplan.sql(3250) :: :
1SELECT RES_ASSIGNMENT_ID, PARTICIPANT, SECURITY_ID INTO h_assign_id, h_partic+
1ipant, h_security_id:n            FROM RESOURCE_ASSIGNMENTS:n            WHER+
1E ELEMENT_ID = h_task_id AND RESOURCE_TYPE = '1' AND RESOURCE_ID = h_res_id:
1854:
1           EXCEPTION:: SP_SEARCH_1(855) :: cplan.sql(3265) :: :
1DB2TIMESTAMP:
1TIME:
1SELECT PMO_ORASTD.DB2TIMESTAMP(TO_DATE(SubStr(h_start_DT, 1, 10)), PMO_ORASTD+
1.TIME(h_start_date)) INTO h_start_DT:n            FROM DUAL:
1872:
1           EXCEPTION:: SP_SEARCH_1(873) :: cplan.sql(3283) :: :
1SELECT CASE WHEN TO_DATE(SubStr(h_start_date, 1, 10)) > TO_DATE(SubStr(h_star+
1t_DT, 1, 10)) THEN h_start_date:n            ELSE h_start_DT END:n           +
1 INTO h_start_DT:n            FROM DUAL:
1888:
1           EXCEPTION:: SP_SEARCH_1(889) :: cplan.sql(3299) :: :
110:
1FC_SEARCH_2:
1PMO_TMP_SEARCH:
1PLANNED_SCHED_FLAG:
1RES_ID:
1UPDATE PMO_TMP_SEARCH SET PLANNED_SCHED_FLAG='0' WHERE RES_ID=h_res_id:
1FOUND:
1919:
1           EXCEPTION:: SP_SEARCH_1(920) :: cplan.sql(3330) :: :
1UPDATE PMO_TMP_SEARCH SET PLANNED_SCHED_FLAG='1' WHERE RES_ID=h_res_id:
1936:
1           EXCEPTION:: SP_SEARCH_1(937) :: cplan.sql(3347) :: :
1SC_SRCH_PROFILE:
1972:
1           EXCEPTION:: SP_SEARCH_1(973) :: cplan.sql(3383) :: :
1LENGTH:
1TRUNC:
1/:
1WHILE:
1LOOP:
1COUNT:
1PROPOSED_START:
1SELECT COUNT(*), MIN(PROPOSED_START) INTO h_total, h_start_DT :n             +
1  FROM TASK_ASSIGNMENTS:n               WHERE PROJECT_ID = h_project_id AND T+
1ASK_ID = h_project_id:n               AND RESOURCE_ID = h_res_id AND RESOURCE+
1_TYPE = h_res_type:
11012:
1           EXCEPTION:: SP_SEARCH_1(1013) :: cplan.sql(3423) :: :
1',':
1SELECT PROJECT_ASSIGNMENT_ID, SCHED_START, CASE WHEN TO_DATE(SubStr(h_start_d+
1ate, 1, 10)) >= TO_DATE(SubStr(SCHED_START, 1, 10)) AND:n                    +
1    TO_DATE(SubStr(h_finish_DT, 1, 10)) <= TO_DATE(SubStr(SCHED_FINISH, 1, 10+
1)) AND SCHED_WORK >= h_effort THEN 0 ELSE 1 END,SCHED_WORK:n                 +
1       INTO h_prj_assign_id, h_start_DT, h_total, h_sched_work:n             +
1           FROM TASK_ASSIGNMENTS:n                        WHERE TASK_ID=h_pro+
1ject_id AND RESOURCE_ID=h_res_id AND RESOURCE_TYPE='0' AND BIT_FLAG = '2':
11059:
1           EXCEPTION:: SP_SEARCH_1(1060) :: cplan.sql(3470) :: :
1SELECT PROJECT_ASSIGNMENT_ID, PLANNED_START, CASE WHEN TO_DATE(SubStr(h_start+
1_date, 1, 10)) >= TO_DATE(SubStr(PLANNED_START, 1, 10)) AND:n                +
1              TO_DATE(SubStr(h_finish_DT, 1, 10)) <= TO_DATE(SubStr(PLANNED_F+
1INISH, 1, 10)) AND PLANNED_WORK >= h_effort THEN 0 ELSE 1 END:n              +
1                INTO h_prj_assign_id, h_start_DT, h_total :n                 +
1             FROM TASK_ASSIGNMENTS:n                              WHERE TASK_+
1ID=h_project_id AND RESOURCE_ID=h_res_id AND RESOURCE_TYPE='0' AND BIT_FLAG =+
1 '0':
11079:
1           EXCEPTION:: SP_SEARCH_1(1080) :: cplan.sql(3490) :: :
1SELECT PROJECT_ASSIGNMENT_ID, PLANNED_START, CASE WHEN TO_DATE(SubStr(h_start+
1_date, 1, 10)) >= TO_DATE(SubStr(PLANNED_START, 1, 10)) AND:n                +
1           TO_DATE(SubStr(h_finish_DT, 1, 10)) <= TO_DATE(SubStr(PLANNED_FINI+
1SH, 1, 10)) AND PLANNED_WORK >= h_effort THEN 0 ELSE 1 END:n                 +
1          INTO h_prj_assign_id, h_start_DT, h_total :n                       +
1    FROM TASK_ASSIGNMENTS:n                           WHERE TASK_ID=h_project+
1_id AND RESOURCE_ID=h_res_id AND RESOURCE_TYPE='0' AND BIT_FLAG = '0':
11099:
1           EXCEPTION:: SP_SEARCH_1(1100) :: cplan.sql(3510) :: :
1SELECT PROJECT_ASSIGNMENT_ID, PLANNED_START, CASE WHEN TO_DATE(SubStr(h_start+
1_date, 1, 10)) >= TO_DATE(SubStr(PLANNED_START, 1, 10)) AND:n                +
1        TO_DATE(SubStr(h_finish_DT, 1, 10)) <= TO_DATE(SubStr(PLANNED_FINISH,+
1 1, 10)) AND PLANNED_WORK >= h_effort THEN 0 ELSE 1 END:n                    +
1    INTO h_prj_assign_id, h_start_DT, h_total FROM TASK_ASSIGNMENTS:n        +
1                WHERE PROJECT_ID = h_project_id AND TASK_ID=h_project_id:n   +
1                     AND RESOURCE_ID=h_res_id AND RESOURCE_TYPE='1' AND BIT_F+
1LAG = '0':
11117:
1           EXCEPTION:: SP_SEARCH_1(1118) :: cplan.sql(3528) :: :
1SELECT PROJECT_ASSIGNMENT_ID, SCHED_START,CASE WHEN TO_DATE(SubStr(h_start_da+
1te, 1, 10)) BETWEEN TO_DATE(SubStr(SCHED_START, 1, 10)) AND TO_DATE(SubStr(SC+
1HED_FINISH, 1, 10)) AND h_effort <= SCHED_WORK THEN 0 ELSE 1 END, SCHED_WORK+
1:n                        INTO h_prj_assign_id, h_start_DT,h_total, h_sched_w+
1ork FROM TASK_ASSIGNMENTS:n                        WHERE PROJECT_ID = h_proje+
1ct_id AND TASK_ID=h_project_id:n                        AND RESOURCE_ID=h_res+
1_id AND RESOURCE_TYPE='0' AND BIT_FLAG='2':
11135:
1           EXCEPTION:: SP_SEARCH_1(1136) :: cplan.sql(3546) :: :
1SELECT PROJECT_ASSIGNMENT_ID, PLANNED_START, CASE WHEN TO_DATE(SubStr(h_start+
1_date, 1, 10)) <= TO_DATE(SubStr(PLANNED_FINISH, 1, 10)) AND h_effort <= PLAN+
1NED_WORK THEN 0 ELSE 1 END:n                              INTO h_prj_assign_i+
1d, h_start_DT,h_total FROM TASK_ASSIGNMENTS:n                              WH+
1ERE PROJECT_ID = h_project_id AND TASK_ID=h_project_id:n                     +
1         AND RESOURCE_ID=h_res_id AND RESOURCE_TYPE='0' AND BIT_FLAG = '0':
11153:
1           EXCEPTION:: SP_SEARCH_1(1154) :: cplan.sql(3564) :: :
1SELECT PROJECT_ASSIGNMENT_ID, PLANNED_START, CASE WHEN TO_DATE(SubStr(h_start+
1_date, 1, 10)) BETWEEN TO_DATE(SubStr(PLANNED_START, 1, 10)) AND TO_DATE(SubS+
1tr(PLANNED_FINISH, 1, 10)) AND h_effort <= PLANNED_WORK THEN 0 ELSE 1 END:n  +
1                         INTO h_prj_assign_id, h_start_DT,h_total FROM TASK_A+
1SSIGNMENTS:n                           WHERE PROJECT_ID = h_project_id AND TA+
1SK_ID=h_project_id:n                           AND RESOURCE_ID=h_res_id AND R+
1ESOURCE_TYPE='0' AND BIT_FLAG = '0':
11173:
1           EXCEPTION:: SP_SEARCH_1(1174) :: cplan.sql(3584) :: :
1SELECT PROJECT_ASSIGNMENT_ID, PLANNED_START,CASE WHEN TO_DATE(SubStr(h_start_+
1date, 1, 10)) BETWEEN TO_DATE(SubStr(PLANNED_START, 1, 10)) AND TO_DATE(SubSt+
1r(PLANNED_FINISH, 1, 10)) AND h_effort <= PLANNED_WORK THEN 0 ELSE 1 END:n   +
1                     INTO h_prj_assign_id, h_start_DT,h_total FROM TASK_ASSIG+
1NMENTS:n                        WHERE PROJECT_ID = h_project_id AND TASK_ID=h+
1_project_id:n                        AND RESOURCE_ID=h_res_id AND RESOURCE_TY+
1PE='1' AND BIT_FLAG = '0':
11190:
1           EXCEPTION:: SP_SEARCH_1(1191) :: cplan.sql(3601) :: :
1SELECT SUM(SCHED_MIN) INTO h_sched_work :n                              FROM +
1TASK_DAY_OF_YEAR:n                              WHERE PROJECT_ID = h_project_+
1id AND TSK_ASSIGNMENT_ID = h_prj_assign_id :n                              AN+
1D DAY_YEAR BETWEEN TO_DATE(SubStr(h_start_date, 1, 10)) AND TO_DATE(SubStr(h_+
1finish_DT, 1, 10)):
11215:
1           EXCEPTION:: SP_SEARCH_1(1216) :: cplan.sql(3626) :: :
1SELECT SUM(SCHED_MIN) INTO h_sched_work :n                              FROM +
1TASK_DAY_OF_YEAR:n                              WHERE PROJECT_ID = h_project_+
1id AND TSK_ASSIGNMENT_ID = h_prj_assign_id :n                              AN+
1D DAY_YEAR >= TO_DATE(SubStr(h_start_date, 1, 10)):
11232:
1           EXCEPTION:: SP_SEARCH_1(1233) :: cplan.sql(3643) :: :
1CONTINUE0000:
1SELECT PMO_ORASTD.DB2TIMESTAMP(TO_DATE(SubStr(h_start_DT, 1, 10)), PMO_ORASTD+
1.TIME(h_start_date)):n                  INTO h_start_DT:n                  FR+
1OM DUAL:
11262:
1           EXCEPTION:: SP_SEARCH_1(1263) :: cplan.sql(3673) :: :
1SELECT CASE WHEN TO_DATE(SubStr(h_start_date, 1, 10)) > TO_DATE(SubStr(h_star+
1t_DT, 1, 10)) THEN h_start_date ELSE h_start_DT END:n                  INTO h+
1_start_DT:n                  FROM DUAL:
11277:
1           EXCEPTION:: SP_SEARCH_1(1278) :: cplan.sql(3688) :: :
11308:
1           EXCEPTION:: SP_SEARCH_1(1309) :: cplan.sql(3719) :: :
11325:
1           EXCEPTION:: SP_SEARCH_1(1326) :: cplan.sql(3736) :: :
11359:
1           EXCEPTION:: SP_SEARCH_1(1360) :: cplan.sql(3770) :: :
1DELETE FROM RESOURCE_ASSIGNMENTS WHERE RES_ASSIGNMENT_ID = h_assign_id:
11387:
1           EXCEPTION:: SP_SEARCH_1(1388) :: cplan.sql(3798) :: :
1UPDATE RESOURCE_ASSIGNMENTS SET SECURITY_ID = h_security_id, PARTICIPANT = h_+
1participant:n            WHERE RES_ASSIGNMENT_ID = h_assign_id:
11405:
1           EXCEPTION:: SP_SEARCH_1(1406) :: cplan.sql(3816) :: :
11413:
1        RETURN_ERROR:: SP_SEARCH_1(1414) :: cplan.sql(3824) :: :
11416:
1                EXIT:: SP_SEARCH_1(1417) :: cplan.sql(3827) :: :
1CANNOT_ASSIGN_TO_DEFAULT_CRI:
11421:
1        RETURN_ERROR:: SP_SEARCH_1(1422) :: cplan.sql(3832) :: :
11424:
1                EXIT:: SP_SEARCH_1(1425) :: cplan.sql(3835) :: :
1CANNOT_CHANGE_OBJECT_TYPE:
11430:
1        RETURN_ERROR:: SP_SEARCH_1(1431) :: cplan.sql(3841) :: :
11433:
1                EXIT:: SP_SEARCH_1(1434) :: cplan.sql(3844) :: :
11439:
1        RETURN_ERROR:: SP_SEARCH_1(1440) :: cplan.sql(3850) :: :
11442:
1                EXIT:: SP_SEARCH_1(1443) :: cplan.sql(3853) :: :
1EXECUTE:
1IMMEDIATE:
1DELETE FROM PMO_TMP_CPLN_0003:
1INSERT INTO PMO_TMP_CPLN_0003 SELECT RESOURCE_ID, RESOURCE_TYPE, :
1 MIN(PLANNED_START) AS PLANNED_START,  MAX(PLANNED_FINISH) AS PLANNED_FINISH,+
1 :
1 SUM(PLANNED_WORK) AS PLANNED_EFFORT,  MIN(SCHED_START) AS START_DATE,  :
1 MAX(SCHED_FINISH) AS FINISH_DATE,     SUM(SCHED_WORK) AS WORK,  :
1 SUM(ETC) AS REMAINING :
1 FROM TASK_ASSIGNMENTS WHERE PROJECT_ID=':
1' AND :
1      (RESOURCE_ID IN (':
1') OR RESOURCE_ID IN (':
1')) GROUP BY RESOURCE_ID, RESOURCE_TYPE :
11474:
1           EXCEPTION:: SP_SEARCH_1(1475) :: cplan.sql(3885) :: :
1SQL :: :
1DELETE FROM PMO_TMP_CPLN_0002:
1INSERT INTO PMO_TMP_CPLN_0002 SELECT RESOURCE_ID AS PROJECT_ASSIGNMENT_ID,MIN+
1(PLANNED_START) AS PRJ_PLANNED_START, :
1 MAX(PLANNED_FINISH) AS PRJ_PLANNED_FINISH,  SUM(PLANNED_WORK) AS PLANNED_REM+
1AINING, :
1 MIN(SCHED_START) AS PRJ_SCHED_START,        MAX(SCHED_FINISH) AS PRJ_SCHED_F+
1INISH, :
1 SUM(SCHED_WORK) AS SCHED_REMAINING  :
1 FROM TASK_ASSIGNMENTS :
1 WHERE TASK_ID=':
1 (RESOURCE_ID IN (':
1')) GROUP BY RESOURCE_ID :
11506:
1           EXCEPTION:: SP_SEARCH_1(1507) :: cplan.sql(3917) :: :
1FC_U_CREATETMPTABLE:
1INSERT INTO PMO_TMP_CPLN01_TEMP(ELEMENT_ID,ELEMENT_NAME,RESOURCE_TYPE,TYPE_ID+
1,E_MAIL_ADDRESS,PLANNED_START,:
1PLANNED_FINISH,PLANNED_EFFORT,START_DATE,FINISH_DATE,WORK,REMAINING,BEST_STAR+
1T,BEST_FINISH,:
1ASSIGNABLE,PLANNED,SCHED,WORK_EFFORT,PERIOD_AVAILABILITY,PROJECT_ASSIGNMENT_I+
1D,PRJ_PLANNED_START,:
1PRJ_PLANNED_FINISH,PLANNED_REMAINING,PRJ_SCHED_START,PRJ_SCHED_FINISH,SCHED_R+
1EMAINING,REGULAR_COST,:
1REGULAR_RATE,SPECIAL_COST,SPECIAL_RATE) :
1SELECT DISTINCT r.RESOURCE_ID,r.FULL_NAME AS ELEMENT_NAME,'0',:
1CASE WHEN ta.TSK_ASSIGNMENT_ID IS NuLL THEN 185 ELSE 13 END AS TYPE_ID,:
1r.E_MAIL_ADDRESS, a.PLANNED_START, a.PLANNED_FINISH, a.PLANNED_EFFORT, a.STAR+
1T_DATE, a.FINISH_DATE, a.WORK, a.REMAINING,:
1rs.START_DATE, rs.FINISH_DATE, rs.ASSIGNABLE, rs.PLANNED, rs.SCHED, rs.PROPOS+
1ED, (rs.ASSIGNABLE - rs.PLANNED - rs.SCHED) ,:
1tb.PROJECT_ASSIGNMENT_ID,tb.PRJ_PLANNED_START, tb.PRJ_PLANNED_FINISH, tb.PLAN+
1NED_REMAINING,:
1tb.PRJ_SCHED_START, tb.PRJ_SCHED_FINISH, tb.SCHED_REMAINING, pa.REGULAR_COST,+
1 pa.REGULAR_RATE, pa.SPECIAL_COST, pa.SPECIAL_RATE :
1FROM RESOURCES r LEFT OUTER JOIN PMO_TMP_CPLN_0003 a ON a.RESOURCE_TYPE='0' A+
1ND a.RESOURCE_ID=r.RESOURCE_ID :
1LEFT OUTER JOIN PROJECT_ASSIGNMENTS pa ON pa.PROJECT_ID=':
1' AND r.RESOURCE_ID = pa.RESOURCE_ID :
1LEFT OUTER JOIN TASK_ASSIGNMENTS ta ON ta.PROJECT_ID=':
1' AND r.RESOURCE_ID = ta.RESOURCE_ID :
1LEFT OUTER JOIN PMO_TMP_CPLN_0002 tb ON r.RESOURCE_ID = tb.PROJECT_ASSIGNMENT+
1_ID :
1LEFT OUTER JOIN PMO_TMP_SEARCH rs ON r.RESOURCE_ID=rs.RES_ID WHERE r.RESOURCE+
1_ID IN (':
1') :
1UNION ALL :
1SELECT DISTINCT p.PROFILE_ID , p.PROFILE_NAME AS ELEMENT_NAME, '1', 41 AS TYP+
1E_ID,:
1'', a.PLANNED_START, a.PLANNED_FINISH, a.PLANNED_EFFORT, a.START_DATE, a.FINI+
1SH_DATE, a.WORK, a.REMAINING,:
1rs.START_DATE , rs.FINISH_DATE, rs.ASSIGNABLE ,rs.PLANNED,rs.SCHED, rs.PROPOS+
1ED,(rs.ASSIGNABLE - rs.PLANNED - rs.SCHED) ,:
1FROM PROFILES p LEFT OUTER JOIN PMO_TMP_CPLN_0003 a ON a.RESOURCE_TYPE='1' AN+
1D p.PROFILE_ID=a.RESOURCE_ID :
1LEFT OUTER JOIN PROJECT_ASSIGNMENTS pa ON pa.PROJECT_ID= ':
1' AND p.PROFILE_ID = pa.RESOURCE_ID :
1JOIN TMT_COMPETENCIES c ON c.ELEMENT_ID=p.ROLE_ID :
1JOIN TMT_COMPETENCIES d ON d.ELEMENT_ID=c.PARENT_ID LEFT OUTER JOIN PMO_TMP_S+
1EARCH rs ON a.RESOURCE_ID=rs.RES_ID :
1LEFT OUTER JOIN PMO_TMP_CPLN_0002 tb ON p.PROFILE_ID = tb.PROJECT_ASSIGNMENT_+
1ID :
1WHERE p.PROFILE_ID IN (':
1ORDER BY TYPE_ID,ELEMENT_NAME:
11561:
1           EXCEPTION:: SP_SEARCH_1(1562) :: cplan.sql(3972) :: :
1SELECT T.ELEMENT_ID, '' AS RES_ASSIGNMENT_ID, T.ELEMENT_NAME AS ELEMENT_NAME,+
1 T.TYPE_ID AS TYPE_ID, :
1 T.E_MAIL_ADDRESS, T.PLANNED_START, T.PLANNED_FINISH, T.PLANNED_EFFORT, T.STA+
1RT_DATE, T.FINISH_DATE, T.WORK, T.REMAINING, :
1 T.BEST_START, T.BEST_FINISH, T.ASSIGNABLE AS CALENDAR,T.PLANNED AS PLANNED_W+
1ORK,:
1 T.SCHED AS SCHED_WORK, T.WORK_EFFORT, :
1 AS UNIT_EFFORT,T.PERIOD_AVAILABILITY, :
1 AS MINUTE_PER_DAY, rs.CONTOUR AS ASSIGN_STRING, '' AS OBJECTIVES,'' AS RANK,+
1T.PROJECT_ASSIGNMENT_ID,T.PRJ_PLANNED_START, T.PRJ_PLANNED_FINISH, T.PLANNED_+
1REMAINING, :
1T.PRJ_SCHED_START, T.PRJ_SCHED_FINISH, T.SCHED_REMAINING, T.REGULAR_COST, T.R+
1EGULAR_RATE, T.SPECIAL_COST, T.SPECIAL_RATE :
1 FROM PMO_TMP_CPLN01_TEMP T:
1 LEFT OUTER JOIN PMO_TMP_SEARCH rs ON T.ELEMENT_ID=rs.RES_ID WHERE T.RESOURCE+
1_TYPE IN ('0') :
1 UNION ALL :
1 SELECT T.ELEMENT_ID, '' AS RES_ASSIGNMENT_ID, T.ELEMENT_NAME, T.TYPE_ID, :
1 '' AS E_MAIL_ADDRESS, T.PLANNED_START, T.PLANNED_FINISH, T.PLANNED_EFFORT, T+
1.START_DATE, T.FINISH_DATE, T.WORK, T.REMAINING, :
1 T.BEST_START, T.BEST_FINISH, T.ASSIGNABLE AS CALENDAR, :
1 T.PLANNED AS PLANNED_WORK,T.SCHED AS SCHED_WORK, T.WORK_EFFORT, :
1 AS UNIT_EFFORT, :
1 T.PERIOD_AVAILABILITY, :
1 AS MINUTE_PER_DAY, rs.CONTOUR AS ASSIGN_STRING,'' AS OBJECTIVES,'' AS RANK, :
1 T.PROJECT_ASSIGNMENT_ID,T.PRJ_PLANNED_START, T.PRJ_PLANNED_FINISH, T.PLANNED+
1_REMAINING, :
1  T.PRJ_SCHED_START, T.PRJ_SCHED_FINISH, T.SCHED_REMAINING, T.REGULAR_COST, T+
1.REGULAR_RATE, T.SPECIAL_COST, T.SPECIAL_RATE :
1 FROM PMO_TMP_CPLN01_TEMP T LEFT OUTER JOIN PMO_TMP_SEARCH rs ON T.ELEMENT_ID+
1=rs.RES_ID :
1 WHERE T.RESOURCE_TYPE = '1' ORDER BY TYPE_ID,ELEMENT_NAME:
1DELETE FROM PMO_TMP_CPLN_0001:
1INSERT INTO PMO_TMP_CPLN_0001 :
1SELECT  RESOURCE_ID, MIN(PLANNED_START) AS PLANNED_START, :
1 MAX(PLANNED_FINISH) AS PLANNED_FINISH,   SUM(PLANNED_WORK) AS PLANNED_EFFORT+
1, :
1 MIN(SCHED_START) AS START_DATE,          MAX(SCHED_FINISH) AS FINISH_DATE, :
1 SUM(SCHED_WORK) AS WORK,                 SUM(ETC) AS REMAINING :
1 RESOURCE_ID IN (':
1') AND PROJECT_ID<>TASK_ID GROUP BY RESOURCE_ID:
11615:
1           EXCEPTION:: SP_SEARCH_1(1616) :: cplan.sql(4026) :: :
1INSERT INTO PMO_TMP_CPLN_0002 :
1SELECT RESOURCE_ID AS PROJECT_ASSIGNMENT_ID,      MIN(PLANNED_START) AS PRJ_P+
1LANNED_START, :
1 MAX(PLANNED_FINISH) AS PRJ_PLANNED_FINISH, SUM(PLANNED_WORK) AS PLANNED_REMA+
1INING, :
1 MIN(SCHED_START) AS PRJ_SCHED_START,       MAX(SCHED_FINISH) AS PRJ_SCHED_FI+
1NISH, :
1 SUM(SCHED_WORK) AS SCHED_REMAINING :
1 FROM TASK_ASSIGNMENTS WHERE TASK_ID=':
1' AND RESOURCE_ID IN (':
1') GROUP BY RESOURCE_ID:
11645:
1           EXCEPTION:: SP_SEARCH_1(1646) :: cplan.sql(4056) :: :
1PLANNED_FINISH,PLANNED_EFFORT,START_DATE,FINISH_DATE,WORK,REMAINING,PROJECT_A+
1SSIGNMENT_ID,PRJ_PLANNED_START,:
1REGULAR_RATE,SPECIAL_COST,SPECIAL_RATE):
1SELECT DISTINCT r.RESOURCE_ID, r.FULL_NAME,'0',CASE WHEN ta.TSK_ASSIGNMENT_ID+
1 IS NuLL THEN 185 ELSE 13 END ,:
1tb.PROJECT_ASSIGNMENT_ID, tb.PRJ_PLANNED_START, tb.PRJ_PLANNED_FINISH, tb.PLA+
1NNED_REMAINING,:
1FROM RESOURCES r LEFT OUTER JOIN PMO_TMP_CPLN_0001 a ON a.RESOURCE_ID=r.RESOU+
1RCE_ID :
1WHERE r.RESOURCE_ID IN (':
1'):
11681:
1           EXCEPTION:: SP_SEARCH_1(1682) :: cplan.sql(4092) :: :
1SELECT T.ELEMENT_ID, '' AS RES_ASSIGNMENT_ID, T.ELEMENT_NAME AS ELEMENT_NAME,+
1 T.TYPE_ID, :
1T.E_MAIL_ADDRESS, T.PLANNED_START, T.PLANNED_FINISH, T.PLANNED_EFFORT, T.STAR+
1T_DATE, T.FINISH_DATE, T.WORK, T.REMAINING, :
1rs.START_DATE AS BEST_START, rs.FINISH_DATE AS BEST_FINISH, rs.ASSIGNABLE AS +
1CALENDAR,rs.PLANNED AS PLANNED_WORK, :
1rs.SCHED AS SCHED_WORK, rs.PROPOSED AS WORK_EFFORT, :
1 AS UNIT_EFFORT,(rs.ASSIGNABLE - rs.PLANNED - rs.SCHED) AS PERIOD_AVAILABILIT+
1Y, :
1 AS MINUTE_PER_DAY, rs.CONTOUR AS ASSIGN_STRING, '' AS OBJECTIVES,'' AS RANK,+
1T.PROJECT_ASSIGNMENT_ID, T.PRJ_PLANNED_START, T.PRJ_PLANNED_FINISH, T.PLANNED+
1_REMAINING, :
1FROM PMO_TMP_CPLN01_TEMP T :
1LEFT OUTER JOIN PMO_TMP_SEARCH rs ON T.ELEMENT_ID=rs.RES_ID :
1ORDER BY ELEMENT_NAME:
1SELECT RESOURCE_ID, MIN(PLANNED_START) AS PLANNED_START, :
1       MAX(PLANNED_FINISH) AS PLANNED_FINISH,    SUM(PLANNED_WORK) AS PLANNED+
1_EFFORT, :
1       MIN(SCHED_START) AS START_DATE,           MAX(SCHED_FINISH) AS FINISH_+
1DATE, :
1       SUM(SCHED_WORK) AS WORK,                  SUM(ETC) AS REMAINING :
1 WHERE PROJECT_ID=':
1'        AND :
1       RESOURCE_ID IN (':
1')   AND :
1       PROJECT_ID<>TASK_ID GROUP BY RESOURCE_ID :
11726:
1           EXCEPTION:: SP_SEARCH_1(1727) :: cplan.sql(4137) :: :
1SELECT    RESOURCE_ID AS PROJECT_ASSIGNMENT_ID,          MIN(PLANNED_START) A+
1S PRJ_PLANNED_START, :
1          MAX(PLANNED_FINISH) AS PRJ_PLANNED_FINISH,     SUM(PLANNED_WORK) AS+
1 PLANNED_REMAINING, :
1          MIN(SCHED_START) AS PRJ_SCHED_START,           MAX(SCHED_FINISH) AS+
1 PRJ_SCHED_FINISH, :
1          SUM(SCHED_WORK) AS SCHED_REMAINING  :
1') GROUP BY RESOURCE_ID :
11756:
1           EXCEPTION:: SP_SEARCH_1(1757) :: cplan.sql(4167) :: :
1SELECT DISTINCT p.PROFILE_ID , p.PROFILE_NAME ,'1', 41 ,:
1'' , a.PLANNED_START, a.PLANNED_FINISH, a.PLANNED_EFFORT, a.START_DATE, a.FIN+
1ISH_DATE, a.WORK, a.REMAINING,:
1FROM PROFILES p LEFT OUTER JOIN PMO_TMP_CPLN_0001 a ON p.PROFILE_ID=a.RESOURC+
1E_ID JOIN TMT_COMPETENCIES c ON c.ELEMENT_ID=p.ROLE_ID :
1JOIN TMT_COMPETENCIES d ON d.ELEMENT_ID=c.PARENT_ID :
11792:
1           EXCEPTION:: SP_SEARCH_1(1793) :: cplan.sql(4203) :: :
1SELECT T.ELEMENT_ID, '' AS RES_ASSIGNMENT_ID, T.ELEMENT_NAME, T.TYPE_ID, :
1rs.START_DATE AS BEST_START, rs.FINISH_DATE AS BEST_FINISH, rs.ASSIGNABLE AS +
1CALENDAR, :
1rs.PLANNED AS PLANNED_WORK,rs.SCHED AS SCHED_WORK, rs.PROPOSED AS WORK_EFFORT+
1, :
1(rs.ASSIGNABLE - rs.PLANNED - rs.SCHED) AS PERIOD_AVAILABILITY, :
1 AS MINUTE_PER_DAY, rs.CONTOUR AS ASSIGN_STRING, '' AS OBJECTIVES,'' AS RANK,+
1  :
1T.PROJECT_ASSIGNMENT_ID,T.PRJ_PLANNED_START, T.PRJ_PLANNED_FINISH, T.PLANNED_+
1REMAINING, :
1FROM PMO_TMP_CPLN01_TEMP T LEFT OUTER JOIN PMO_TMP_SEARCH rs ON T.ELEMENT_ID=+
1rs.RES_ID :
11814:
1                EXIT:: SP_SEARCH_1(1815) :: cplan.sql(4225) :: :
11817:
1                EXIT:: SP_SEARCH_1(1818) :: cplan.sql(4228) :: :
1PMO_SELECT_READ:
1RETURN_ERROR_EXCEPTION:
11825:
1           EXCEPTION:: SP_SEARCH_1(1826) :: cplan.sql(4236) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1ID:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
11837:
1           EXCEPTION:: SP_SEARCH_1(1838) :: cplan.sql(4248) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
2fe6
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 1c 81 b0 a3
a0 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 1c 51
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 1c 51 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 81 b0 a3 :2 a0 6b 1c
81 b0 :2 a0 6b :2 a0 6b 6e a5
b a 10 :2 a0 6b 6e :2 a0 6b
6e a5 b 6e 7e a0 b4 2e
6e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :3 a0 a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e :3 a0
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e :3 a0 a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e :3 a0 a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e :3 a0 a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
:3 a0 a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e :3 a0 a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e :3 a0 a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e :3 a0
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 d :2 a0 d :2 a0
d :2 a0 d :2 a0 d :2 a0 d :2 a0
d :2 a0 d :2 a0 d :2 a0 d :2 a0
d :2 a0 d :2 a0 d :2 a0 d :2 a0
d a0 6e d a0 4d d :4 a0
51 a5 b a5 b d a0 51
d a0 51 d a0 51 d a0
7e b4 2e 5a :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :4 a0 6b a5 b 6e
a5 b b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
a0 a5 57 b7 19 3c a0 7e
b4 2e 5a :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b a0
a5 57 b7 19 3c :2 a0 51 a5
b 7e 51 b4 2e :2 a0 51 a5
b 7e 51 b4 2e a 10 :2 a0
51 a5 b 7e 51 b4 2e a
10 :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b a0 a5 57
b7 19 3c a0 7e b4 2e :2 5a
a0 7e b4 2e :2 5a a 10 :8 a0
12a :2 a0 6b a0 d b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 6b a0 7e a0 6b
b4 2e 5a :2 a0 51 a5 b 7e
51 b4 2e 5a a 10 :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b a0 a5 57 b7 19 3c
a0 51 d a0 b7 a0 7e b4
2e :2 5a a0 7e b4 2e :2 5a a
10 :3 a0 12a :2 a0 6b a0 d b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 :2 19 3c :2 a0
d a0 7e b4 2e 5a a0 6e
d b7 19 3c :3 a0 :2 51 a5 b
d :3 a0 :2 51 a5 b d :2 a0 d
:2 a0 51 a5 b 7e 51 b4 2e
:4 a0 :2 51 a5 b :2 51 a5 b d
:3 a0 6b :3 51 a0 a5 b d :3 a0
51 a5 b a5 b 7e 51 b4
2e :d a0 12a :2 a0 6b a0 d b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 :45 a0 12a :2 a0
6b a0 d b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 :2 19 3c :2 a0 6b a0 7e a0
6b b4 2e 5a :7 a0 12a :2 a0 6b
a0 d b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
6b a0 7e a0 6b b4 2e 5a
a0 7e b4 2e 5a a0 51 d
b7 19 3c :b a0 12a :2 a0 6b a0
d b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b :2 a0 a5 57 b7 :2 19
3c b7 a0 51 d b7 :2 19 3c
a0 51 d :5 a0 12a :2 a0 6b a0
d b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 51
a5 b 7e 51 b4 2e :5 a0 12a
:2 a0 6b a0 d b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6b a0 6e a5 b 7e
51 b4 2e :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b :2 a0
a5 57 b7 19 3c b7 19 3c
b7 :b a0 12a :2 a0 6b a0 d b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 6b a0 7e
a0 6b b4 2e 5a :5 a0 12a :2 a0
6b a0 d b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 6b a0 7e a0 6b b4 2e
5a :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b :2 a0 a5 57
b7 19 3c b7 19 3c b7 :2 19
3c a0 7e 51 b4 2e :2 a0 d
:2 a0 d :6 a0 51 a5 b :2 a0 51
a5 b :2 a0 51 a5 b :2 a0 51
a5 b :2 a0 51 a5 b :2 a0 51
a5 b :2 a0 51 a5 b :2 a0 51
a5 b :3 a0 a5 b d :2 a0 51
a5 b a0 7e a0 6b b4 2e
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b a0 a5 57 a0
b7 :2 a0 51 a5 b 7e 51 b4
2e :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:3 a0 a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 51 a5 b :2 a0 a5
57 b7 :2 19 3c :2 a0 d a0 7e
b4 2e 5a a0 6e d b7 19
3c a0 b7 :2 a0 51 a5 b 7e
51 b4 2e 5a :2 a0 51 a5 b
7e 51 b4 2e 5a a 10 :2 a0
51 a5 b 7e 51 b4 2e 5a
:2 a0 51 a5 b 7e 51 b4 2e
5a 52 10 a0 51 d a0 b7
:2 a0 51 a5 b 7e 51 b4 2e
a0 51 d a0 b7 19 :2 a0 51
a5 b 7e 51 b4 2e 5a :2 a0
51 a5 b 7e 51 b4 2e 5a
52 10 a0 51 d a0 b7 19
:2 a0 51 a5 b 7e 51 b4 2e
:3 a0 51 a5 b 7e :2 a0 51 a5
b b4 2e d a0 51 d b7
:2 19 3c b7 :2 19 3c :2 a0 b4 2e
d a0 6e d a0 6e d :3 a0
6b :3 a0 51 a5 b :2 a0 6b a5
b 5a 51 a5 b d :4 a0 51
a5 b :2 a0 6b a5 b d :2 a0
51 a5 b 7e 51 b4 2e :8 a0
a5 b d :2 a0 51 a5 b 7e
51 b4 2e :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :3 a0 a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 51 a5 b
:2 a0 a5 57 b7 19 3c a0 4d
d :14 a0 12a :2 a0 6b a0 d b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 6b a0 7e
a0 6b b4 2e 5a a0 7e b4
2e :2 5a a 10 a0 51 d :2 a0
51 a5 b 7e 51 b4 2e :2 a0
d b7 19 3c b7 19 3c a0
51 d a0 51 d a0 7e 51
b4 2e :2 a0 :2 51 a5 b 7e 6e
b4 2e :1c a0 12a :2 a0 6b a0 d
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 6b a0
7e a0 6b b4 2e 5a a0 51
d :2 a0 51 a5 b 7e 51 b4
2e 5a :2 a0 51 a5 b 7e 51
b4 2e 5a 52 10 :1a a0 12a :2 a0
6b a0 d b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 a0 51 d b7 :2 19 3c a0
b7 :2 a0 6b a0 7e a0 6b b4
2e 5a :2 a0 51 a5 b 7e 51
b4 2e 5a 52 10 :1a a0 12a :2 a0
6b a0 d b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 :2 19 3c b7 :1a a0 12a :2 a0 6b
a0 d b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
:2 19 3c b7 :2 a0 :2 51 a5 b 7e
6e b4 2e :19 a0 12a :2 a0 6b a0
d b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
a0 7e a0 6b b4 2e 5a a0
51 d :2 a0 51 a5 b 7e 51
b4 2e 5a :2 a0 51 a5 b 7e
51 b4 2e 5a 52 10 :14 a0 12a
:2 a0 6b a0 d b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 a0 51 d 4f b7 :2 19
3c a0 b7 :2 a0 6b a0 7e a0
6b b4 2e 5a :17 a0 12a :2 a0 6b
a0 d b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
:2 19 3c b7 :17 a0 12a :2 a0 6b a0
d b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 :2 19
3c b7 :2 19 3c :2 a0 6b a0 7e
a0 6b b4 2e 5a :2 a0 51 a5
b 7e 51 b4 2e :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b :2 a0 a5 57 a0 b7 a0 7e
b4 2e 5a a0 7e 51 b4 2e
a0 51 d :f a0 12a :2 a0 6b a0
d b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 a0
51 d :c a0 12a :2 a0 6b a0 d
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 :2 19 3c
:2 a0 51 a5 b a0 7e a0 51
a5 b b4 2e :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :4 a0 6b a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
:2 a0 a5 57 b7 19 3c b7 :2 19
3c a0 51 d a0 b7 :2 a0 51
a5 b 7e 51 b4 2e 5a :3 a0
51 a5 b a5 b 5a 7e 51
b4 2e a 10 :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :4 a0 6b a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
:2 a0 a5 57 b7 :2 19 3c :2 a0 :2 51
a5 b 7e 6e b4 2e :3 a0 7e
a0 b4 2e :2 51 a5 b d :15 a0
12a :2 a0 6b a0 d b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 6b a0 7e a0 6b
b4 2e 5a :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b :2 a0
a5 57 b7 19 3c :2 a0 :2 51 a5
b 7e 6e b4 2e 5a :2 a0 51
a5 b 7e 51 b4 2e 5a :2 a0
51 a5 b a0 7e a0 51 a5
b b4 2e 5a a 10 5a 52
10 :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b :2 a0 a5 57
b7 19 3c :c a0 12a :2 a0 6b a0
d b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 :3 a0
7e a0 b4 2e :2 51 a5 b d
:5 a0 12a :2 a0 6b a0 d b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 6b a0 7e a0
6b b4 2e 5a :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :4 a0 6b a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
:2 a0 a5 57 b7 19 3c :14 a0 12a
:2 a0 6b a0 d b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6b a0 7e a0 6b b4
2e 5a :2 a0 51 a5 b 7e 51
b4 2e 5a a 10 :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b :2 a0 a5 57 b7 19 3c :c a0
12a :2 a0 6b a0 d b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 :2 19 3c :2 a0 d :2 a0
51 a5 b 7e 51 b4 2e :a a0
12a :2 a0 6b a0 d b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :a a0 12a :2 a0 6b a0 d
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f a0 51 d
:2 a0 d :2 a0 51 a5 b 7e 51
b4 2e a0 51 d b7 19 3c
:1e a0 :4 51 a5 b d a0 7e 51
b4 2e :2 a0 51 a5 b 7e 51
b4 2e :4 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 :4 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 :2 19 3c
b7 19 3c b7 :2 a0 d :2 a0 d
:2 a0 :2 51 a5 b 7e 6e b4 2e
:3 a0 6b d b7 :4 a0 51 a5 b
:2 a0 6b a5 b d b7 :2 19 3c
:1e a0 :4 51 a5 b d a0 7e 51
b4 2e :4 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 19 3c b7 :2 19
3c b7 :3 a0 a5 b 51 a5 b
7e 51 b4 2e a0 51 d b7
:5 a0 a5 b 51 a5 b 7e 51
b4 2e 5a 7e 51 b4 2e a5
b d b7 :2 19 3c a0 7e 51
b4 2e a0 51 d :3 a0 51 a5
b a0 7e a0 b4 2e 82 a0
51 d :3 a0 6b :2 51 :2 a0 51 a5
b 7e 51 b4 2e 7e 51 b4
2e a0 a5 b d :3 a0 6b :2 51
:2 a0 51 a5 b 7e 51 b4 2e
7e 51 b4 2e 7e 51 b4 2e
a0 a5 b d :2 a0 d a0 51
d a0 51 d :2 a0 d :e a0 12a
:2 a0 6b a0 d b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 51 a5 b 7e 51 b4
2e 5a a0 7e b4 2e :2 5a a
10 a0 51 d :2 a0 6b :2 a0 a5
b 7e 51 b4 2e :2 a0 d b7
19 3c b7 19 3c :2 a0 :2 51 a5
b 7e 6e b4 2e :3 a0 6b d
:3 a0 a5 b 51 a5 b 7e 51
b4 2e :2 a0 d b7 :3 a0 7e 6e
b4 2e :2 51 a5 b d :3 a0 7e
a0 b4 2e :2 51 a5 b d b7
:2 19 3c b7 :3 a0 a5 b 51 a5
b 7e 51 b4 2e :2 a0 d b7
:3 a0 7e 6e b4 2e :2 51 a5 b
d :3 a0 7e a0 b4 2e :2 51 a5
b d b7 :2 19 3c b7 :2 19 3c
a0 51 d a0 51 d :2 a0 51
a5 b 7e 51 b4 2e a0 7e
51 b4 2e :2 a0 :2 51 a5 b 7e
6e b4 2e :1c a0 12a :2 a0 6b a0
d b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
a0 7e a0 6b b4 2e 5a a0
51 d :2 a0 51 a5 b 7e 51
b4 2e 5a :2 a0 51 a5 b 7e
51 b4 2e 5a 52 10 :1a a0 12a
:2 a0 6b a0 d b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 a0 51 d b7 :2 19 3c
a0 b7 :2 a0 6b a0 7e a0 6b
b4 2e 5a :2 a0 51 a5 b 7e
51 b4 2e 5a 52 10 :1a a0 12a
:2 a0 6b a0 d b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 :2 19 3c b7 :1c a0 12a :2 a0
6b a0 d b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 :2 19 3c b7 :2 a0 :2 51 a5 b
7e 6e b4 2e :1b a0 12a :2 a0 6b
a0 d b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
6b a0 7e a0 6b b4 2e 5a
:2 a0 51 a5 b 7e 51 b4 2e
5a :2 a0 51 a5 b 7e 51 b4
2e 5a 52 10 :16 a0 12a :2 a0 6b
a0 d b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
a0 51 d 4f b7 :2 19 3c a0
b7 :2 a0 6b a0 7e a0 6b b4
2e 5a :19 a0 12a :2 a0 6b a0 d
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 :2 19 3c
b7 :19 a0 12a :2 a0 6b a0 d b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 :2 19 3c b7
:2 19 3c :2 a0 6b a0 7e a0 6b
b4 2e 5a :2 a0 51 a5 b 7e
51 b4 2e a0 51 d b7 a0
7e b4 2e 5a a0 7e 51 b4
2e a0 51 d :f a0 12a :2 a0 6b
a0 d b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
a0 51 d :c a0 12a :2 a0 6b a0
d b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 :2 19
3c :2 a0 51 a5 b a0 7e a0
51 a5 b b4 2e :3 a0 51 a5
b 7e 51 b4 2e d a0 3b
b7 19 3c b7 19 3c a0 51
d b7 :2 19 3c b7 :3 a0 51 a5
b 7e 51 b4 2e d a0 3b
b7 :2 19 3c :2 a0 d a0 51 d
:a a0 12a :2 a0 6b a0 d b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :a a0 12a :2 a0 6b a0
d b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f a0 51
d :2 a0 d :2 a0 51 a5 b 7e
51 b4 2e a0 51 d b7 19
3c :1e a0 :4 51 a5 b d a0 7e
51 b4 2e :2 a0 51 a5 b 7e
51 b4 2e :4 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 :4 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 :2 19
3c b7 19 3c a0 b7 :2 a0 51
a5 b 7e 51 b4 2e :2 a0 d
:2 a0 d :2 a0 :2 51 a5 b 7e 6e
b4 2e :3 a0 6b d b7 :3 a0 51
a5 b d b7 :2 19 3c :1e a0 :4 51
a5 b d a0 7e 51 b4 2e
:4 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 19 3c b7 :2 19 3c :3 a0
51 a5 b 7e 51 b4 2e d
93 4f b0 46 b7 a0 47 b7
19 3c b7 :2 19 3c a0 7e 51
b4 2e 5a :2 a0 51 a5 b 7e
51 b4 2e 5a a 10 :2 a0 51
a5 b 7e 51 b4 2e :3 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
:7 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 :2 19 3c a0 7e 51 b4
2e :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b :2 a0 a5 57
a0 b7 :2 a0 7e a0 6b b4 2e
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b :2 a0 a5 57 a0
b7 19 :2 a0 7e a0 6b b4 2e
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b :2 a0 a5 57 b7
19 :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b :2 a0 a5 57
b7 :2 19 3c b7 19 3c :3 a0 a5
b 51 a5 b 7e 51 b4 2e
5a :3 a0 a5 b 51 a5 b 7e
51 b4 2e 5a a 10 :2 a0 6e
11e 11d :2 a0 6b 51 d a0 6e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
d :3 a0 11e 11d a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 6e 11e 11d
:2 a0 6b 51 d a0 6e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e d :3 a0
11e 11d a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 6b a0 b4 2e d
a0 6e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e d :3 a0 11e 11d a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f a0 6e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :3 a0 51 a5
b a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :3 a0 51
a5 b a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :3 a0 51 a5 b a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :3 a0 51 a5 b
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
d a0 b7 :3 a0 a5 b 51 a5
b 7e 51 b4 2e :2 a0 6e 11e
11d :2 a0 6b 51 d a0 6e 7e
6e b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e d
:3 a0 11e 11d a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 6e 11e 11d :2 a0
6b 51 d a0 6e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e d :3 a0 11e 11d a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 6b a0
b4 2e d a0 6e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e d :3 a0 11e
11d a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f a0 6e 7e 6e b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:3 a0 51 a5 b a5 b b4 2e
7e 6e b4 2e 7e :3 a0 51 a5
b a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e d b7 19 :2 a0 6e 11e 11d
:2 a0 6b 51 d a0 6e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e d :3 a0
11e 11d a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 6e 11e 11d :2 a0 6b
51 d a0 6e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
d :3 a0 11e 11d a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 6b a0 b4
2e d a0 6e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e d :3 a0 11e 11d
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
a0 6e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :3 a0
51 a5 b a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:3 a0 51 a5 b a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e d b7 :2 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :3 a0 6b
a0 a5 b 65 b7 :2 a0 6b :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 :2 a0
6b :2 6e 7e :2 a0 6b b4 2e 7e
6e b4 2e 7e :2 a0 6b b4 2e
a5 57 b7 19 3c :9 a0 12a e9
dd :2 a0 65 b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c :7 a0 12a e9 dd :2 a0
65 b7 a4 b1 11 4f b7 a6
9 a4 b1 11 68 4f 1d 17
b5 
2fe6
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 5e
5a 30 66 6f 6b 59 77 84
80 56 8c 95 91 7f 9d aa
a6 7c b2 bb b7 a5 c3 d0
cc a2 d8 e1 dd cb e9 f6
f2 c8 fe 107 103 f1 10f 11c
118 ee 124 12d 129 117 135 114
13a 13e 142 146 149 14d 16a 155
159 15c 15d 165 154 187 175 151
179 17a 182 174 1a4 192 171 196
197 19f 191 1c1 1af 18e 1b3 1b4
1bc 1ae 1de 1cc 1ab 1d0 1d1 1d9
1cb 1fb 1e9 1c8 1ed 1ee 1f6 1e8
218 206 1e5 20a 20b 213 205 235
223 202 227 228 230 222 252 240
21f 244 245 24d 23f 26f 25d 23c
261 262 26a 25c 28b 27a 27e 286
259 2a3 292 296 29e 279 2c0 2ae
276 2b2 2b3 2bb 2ad 2dd 2cb 2aa
2cf 2d0 2d8 2ca 2fa 2e8 2c7 2ec
2ed 2f5 2e7 317 305 2e4 309 30a
312 304 334 322 301 326 327 32f
321 351 33f 31e 343 344 34c 33e
36d 35c 360 33b 368 35b 389 378
37c 358 384 377 3a5 394 398 374
3a0 393 3c1 3b0 3b4 390 3bc 3af
3dd 3cc 3d0 3ac 3d8 3cb 3f9 3e8
3ec 3c8 3f4 3e7 415 404 408 3e4
410 403 431 420 424 400 42c 41f
44d 43c 440 41c 448 43b 469 458
45c 438 464 457 485 474 478 454
480 473 4a1 490 494 470 49c 48f
4bd 4ac 4b0 48c 4b8 4ab 4d9 4c8
4cc 4a8 4d4 4c7 4f5 4e4 4e8 4c4
4f0 4e3 511 500 504 4e0 50c 4ff
52d 51c 520 4fc 528 51b 549 538
53c 518 544 537 565 554 558 534
560 553 581 570 574 550 57c 56f
59d 58c 590 56c 598 58b 5b9 5a8
5ac 588 5b4 5a7 5d5 5c4 5c8 5a4
5d0 5c3 5f1 5e0 5e4 5c0 5ec 5df
60d 5fc 600 5dc 608 5fb 629 618
61c 5f8 624 617 645 634 638 614
640 633 661 650 654 630 65c 64f
67e 66c 64c 670 671 679 66b 69b
689 668 68d 68e 696 688 6b7 6a6
6aa 685 6b2 6a5 6d4 6c2 6a2 6c6
6c7 6cf 6c1 6f0 6df 6e3 6be 6eb
6de 70d 6fb 6db 6ff 700 708 6fa
72a 718 6f7 71c 71d 725 717 747
735 714 739 73a 742 734 763 752
756 731 75e 751 77f 76e 772 74e
77a 76d 79b 78a 78e 76a 796 789
7b8 7a6 786 7aa 7ab 7b3 7a5 7d5
7c3 7a2 7c7 7c8 7d0 7c2 7f1 7e0
7e4 7bf 7ec 7df 80d 7fc 800 7dc
808 7fb 82a 818 7f8 81c 81d 825
817 846 835 839 814 841 834 862
851 855 831 85d 850 87e 86d 871
84d 879 86c 89a 889 88d 869 895
888 8b6 8a5 8a9 8b1 885 8d5 8bd
8c1 8c5 8c8 8d0 8a4 8dc 8e0 8a1
8e4 8e8 8ec 8ef 8f4 8f5 1 8f7
8fc 900 904 907 90c 910 914 917
91c 91d 91f 924 927 92b 92c 931
936 939 93e 93f 944 947 94b 94c
951 954 959 95a 95f 962 967 968
96d 970 975 976 97b 97e 982 983
988 98b 990 991 996 999 99e 99f
9a4 9a7 9ac 9ad 9b2 9b5 9b9 9ba
9bf 9c2 9c7 9c8 9cd 9d0 9d5 9d6
9db 9de 9e2 9e6 9ea 9eb 9ed 9f2
9f3 9f5 9f6 9fb 9fe a03 a04 a09
a0c a10 a14 a18 a19 a1b a20 a21
a23 a24 a29 a2c a31 a32 a37 a3a
a3e a42 a46 a47 a49 a4e a4f a51
a52 a57 a5a a5f a60 a65 a68 a6c
a70 a74 a75 a77 a7c a7d a7f a80
a85 a88 a8d a8e a93 a96 a9a a9e
aa2 aa3 aa5 aaa aab aad aae ab3
ab6 abb abc ac1 ac4 ac8 acc ad0
ad1 ad3 ad8 ad9 adb adc ae1 ae4
ae9 aea aef af2 af6 afa afe aff
b01 b06 b07 b09 b0a b0f b12 b17
b18 b1d b20 b24 b28 b2c b2d b2f
b34 b35 b37 b38 b3d b40 b45 b46
b4b b4e b52 b56 b5a b5b b5d b62
b63 b65 b66 b6b b6e b73 b74 b79
b7c b80 b84 b88 b89 b8b b90 b91
b93 b94 b99 b9c ba1 ba2 ba7 baa
baf bb0 bb5 bb8 bbc bbd bc2 bc5
bca bcb bd0 bd3 bd8 bd9 bde be1
be6 be7 bec bef bf3 bf4 bf9 bfc
c01 c02 c07 c0a c0f c10 c15 c16
c1b c1d c21 c24 c28 c2c c2f c33
c37 c3a c3d c42 c45 c48 c4b c4c
c51 c52 1 c54 c59 c5d c61 c64
c69 c6e c71 c75 c76 c7b c7c c81
c83 c87 c8a c8e c92 c96 c9a c9e
ca2 ca6 caa cae cb2 cb6 cba cbe
cc2 cc6 cca cce cd2 cd6 cda cde
ce2 ce6 cea cee cf2 cf6 cfa cfe
d02 d06 d0a d0e d12 d16 d1a d1e
d22 d26 d2a d2e d32 d36 d3a d3e
d42 d47 d4b d4f d50 d54 d58 d5c
d60 d64 d67 d68 d6a d6b d6d d71
d75 d78 d7c d80 d83 d87 d8b d8e
d92 d96 d99 d9a d9f da2 da6 daa
dad db1 db5 db8 dbb dc0 dc3 dc6
dc9 dca dcf dd0 1 dd2 dd7 ddb
ddf de2 de7 dec def df3 df4 df9
dfc e01 e02 e07 e0a e0f e10 e15
e18 e1c e20 e24 e28 e2b e2c e2e
e33 e34 e36 e37 e3c e3d e42 e44
e48 e4b e4f e53 e56 e5a e5e e61
e64 e69 e6c e6f e72 e73 e78 e79
1 e7b e80 e84 e88 e8b e90 e95
e98 e9c e9d ea2 ea3 ea8 eaa eae
eb1 eb5 eb9 ebc ec0 ec4 ec7 ecb
ecc ed1 ed3 ed7 eda ede ee1 ee2
ee7 eea eee ef2 ef5 ef9 efd f00
f03 f08 f0b f0e f11 f12 f17 f18
1 f1a f1f f23 f27 f2a f2f f34
f37 f3b f3c f41 f44 f49 f4a f4f
f52 f57 f58 f5d f60 f64 f68 f6c
f70 f73 f74 f76 f7b f7c f7e f7f
f84 f85 f8a f8c f90 f93 f97 f9b
f9e fa2 fa6 fa9 fac fb1 fb4 fb7
fba fbb fc0 fc1 1 fc3 fc8 fcc
fd0 fd3 fd8 fdd fe0 fe4 fe5 fea
feb ff0 ff2 ff6 ff9 ffd 1001 1004
1008 100c 100f 1013 1014 1019 101b 101f
1022 1026 102a 102d 102e 1030 1033 1036
1037 103c 1040 1044 1047 1048 104a 104d
1050 1051 1 1056 105b 105f 1063 1066
1067 1069 106c 106f 1070 1 1075 107a
107e 1082 1085 1089 108d 1090 1093 1098
109b 109e 10a1 10a2 10a7 10a8 1 10aa
10af 10b3 10b7 10ba 10bf 10c4 10c7 10cb
10cc 10d1 10d4 10d9 10da 10df 10e2 10e7
10e8 10ed 10f0 10f4 10f8 10fc 1100 1103
1104 1106 110b 110c 110e 110f 1114 1115
111a 111c 1120 1123 1127 112b 112e 1132
1136 1139 113c 1141 1144 1147 114a 114b
1150 1151 1 1153 1158 115c 1160 1163
1168 116d 1170 1174 1175 117a 117b 1180
1182 1186 1189 118d 1191 1194 1198 119c
119f 11a3 11a4 11a9 11ab 11af 11b2 11b6
11b9 11ba 11bf 11c2 11c5 11c9 11cc 11cd
11d2 11d5 1 11d8 11dd 11e1 11e5 11e9
11ed 11f1 11f5 11f9 11fd 1209 120d 1211
1214 1218 121c 121e 1 1222 1226 122a
122d 1231 1235 1239 123d 1240 1244 1248
124b 124e 1253 1256 1259 125c 125d 1262
1263 1 1265 126a 126e 1272 1275 127a
127f 1282 1286 1287 128c 128f 1294 1295
129a 129d 12a2 12a3 12a8 12ab 12af 12b0
12b5 12b8 12bd 12be 12c3 12c6 12ca 12ce
12d1 12d4 12d5 12d7 12d8 12dd 12de 12e3
12e5 12e9 12ec 12ee 12f2 12f4 1300 1302
1304 1305 130a 130e 1310 131c 131e 1322
1326 1329 132d 1330 1334 1337 1338 133d
1340 1344 1348 134b 134c 134e 1351 1354
1355 135a 1 135d 1362 1366 136a 136d
1371 1375 1378 137b 1380 1383 1386 1389
138a 138f 1390 1 1392 1397 139b 139f
13a2 13a7 13ac 13af 13b3 13b4 13b9 13bc
13c1 13c2 13c7 13ca 13cf 13d0 13d5 13d8
13dc 13e0 13e4 13e8 13eb 13ec 13ee 13f3
13f4 13f6 13f7 13fc 13fd 1402 1404 1408
140b 140f 1413 1416 141a 141e 1421 1424
1429 142c 142f 1432 1433 1438 1439 1
143b 1440 1444 1448 144b 1450 1455 1458
145c 145d 1462 1463 1468 146a 146e 1471
1475 1479 147c 1480 1484 1487 148b 148c
1491 1493 1497 149a 149e 14a1 14a5 14a9
14ab 14af 14b2 14b3 14b8 14bb 14be 14c2
14c5 14c6 14cb 14ce 1 14d1 14d6 14da
14de 14e2 14ee 14f2 14f6 14f9 14fd 1501
1503 1 1507 150b 150f 1512 1516 151a
151e 1522 1525 1529 152d 1530 1533 1538
153b 153e 1541 1542 1547 1548 1 154a
154f 1553 1557 155a 155f 1564 1567 156b
156c 1571 1574 1579 157a 157f 1582 1587
1588 158d 1590 1594 1595 159a 159d 15a2
15a3 15a8 15ab 15af 15b3 15b6 15b9 15ba
15bc 15bd 15c2 15c3 15c8 15ca 15ce 15d1
15d3 15d7 15d9 15e5 15e7 15e9 15ea 15ef
15f3 15f5 1601 1603 1605 1609 160d 1610
1614 1618 161c 1620 1623 1624 1629 162c
1630 1635 1639 163b 163f 1642 1646 164a
164e 1651 1654 1655 1657 165b 165f 1663
1667 166a 166d 166e 1670 1674 1678 167c
1680 1684 1688 168b 168c 168e 1691 1694
1695 169a 169e 16a2 16a6 16aa 16ad 16b0
16b1 16b3 16b6 16b9 16ba 16bc 16c0 16c4
16c8 16cc 16cf 16d2 16d5 16d8 16dc 16dd
16df 16e3 16e7 16eb 16ef 16f2 16f3 16f5
16f6 16f8 16fb 16fe 16ff 1704 1708 170c
1710 1714 1718 171c 1720 1724 1728 172c
1730 1734 1738 1744 1748 174c 174f 1753
1757 1759 1 175d 1761 1765 1768 176c
1770 1774 1778 177b 177f 1783 1786 1789
178e 1791 1794 1797 1798 179d 179e 1
17a0 17a5 17a9 17ad 17b0 17b5 17ba 17bd
17c1 17c2 17c7 17ca 17cf 17d0 17d5 17d8
17dd 17de 17e3 17e6 17ea 17eb 17f0 17f3
17f8 17f9 17fe 1801 1805 1809 180c 180f
1810 1812 1813 1818 1819 181e 1820 1824
1827 1829 182d 182f 183b 183d 183f 1840
1845 1849 184b 1857 1859 185b 185f 1863
1867 186b 186f 1873 1877 187b 187f 1883
1887 188b 188f 1893 1897 189b 189f 18a3
18a7 18ab 18af 18b3 18b7 18bb 18bf 18c3
18c7 18cb 18cf 18d3 18d7 18db 18df 18e3
18e7 18eb 18ef 18f3 18f7 18fb 18ff 1903
1907 190b 190f 1913 1917 191b 191f 1923
1927 192b 192f 1933 1937 193b 193f 1943
1947 194b 194f 1953 1957 195b 195f 1963
1967 196b 196f 197b 197f 1983 1986 198a
198e 1990 1 1994 1998 199c 199f 19a3
19a7 19ab 19af 19b2 19b6 19ba 19bd 19c0
19c5 19c8 19cb 19ce 19cf 19d4 19d5 1
19d7 19dc 19e0 19e4 19e7 19ec 19f1 19f4
19f8 19f9 19fe 1a01 1a06 1a07 1a0c 1a0f
1a14 1a15 1a1a 1a1d 1a21 1a22 1a27 1a2a
1a2f 1a30 1a35 1a38 1a3c 1a40 1a43 1a46
1a47 1a49 1a4a 1a4f 1a50 1a55 1a57 1a5b
1a5e 1a60 1a64 1a66 1a72 1a74 1a76 1a77
1a7c 1a80 1a82 1a8e 1a90 1a92 1a96 1a9a
1a9d 1aa1 1aa5 1aa8 1aac 1aaf 1ab3 1ab6
1ab7 1abc 1abf 1ac3 1ac7 1acb 1acf 1ad3
1ad7 1adb 1ae7 1aeb 1aef 1af2 1af6 1afa
1afc 1 1b00 1b04 1b08 1b0b 1b0f 1b13
1b17 1b1b 1b1e 1b22 1b26 1b29 1b2c 1b31
1b34 1b37 1b3a 1b3b 1b40 1b41 1 1b43
1b48 1b4c 1b50 1b53 1b58 1b5d 1b60 1b64
1b65 1b6a 1b6d 1b72 1b73 1b78 1b7b 1b80
1b81 1b86 1b89 1b8d 1b8e 1b93 1b96 1b9b
1b9c 1ba1 1ba4 1ba8 1bac 1baf 1bb2 1bb3
1bb5 1bb6 1bbb 1bbc 1bc1 1bc3 1bc7 1bca
1bcc 1bd0 1bd2 1bde 1be0 1be2 1be3 1be8
1bec 1bee 1bfa 1bfc 1c00 1c04 1c07 1c0b
1c0e 1c12 1c15 1c16 1c1b 1c1e 1c22 1c25
1c26 1c2b 1c2e 1c32 1c35 1c39 1c3b 1c3f
1c42 1c46 1c4a 1c4e 1c52 1c56 1c5a 1c5e
1c62 1c66 1c6a 1c6e 1c7a 1c7e 1c82 1c85
1c89 1c8d 1c8f 1 1c93 1c97 1c9b 1c9e
1ca2 1ca6 1caa 1cae 1cb1 1cb5 1cb9 1cbc
1cbf 1cc4 1cc7 1cca 1ccd 1cce 1cd3 1cd4
1 1cd6 1cdb 1cdf 1ce3 1ce6 1ceb 1cf0
1cf3 1cf7 1cf8 1cfd 1d00 1d05 1d06 1d0b
1d0e 1d13 1d14 1d19 1d1c 1d20 1d21 1d26
1d29 1d2e 1d2f 1d34 1d37 1d3b 1d3f 1d42
1d45 1d46 1d48 1d49 1d4e 1d4f 1d54 1d56
1d5a 1d5d 1d5f 1d63 1d65 1d71 1d73 1d75
1d76 1d7b 1d7f 1d81 1d8d 1d8f 1d91 1d95
1d99 1d9c 1da0 1da4 1da7 1daa 1daf 1db2
1db5 1db8 1db9 1dbe 1dbf 1 1dc1 1dc6
1dca 1dce 1dd1 1dd6 1ddb 1dde 1de2 1de3
1de8 1deb 1df0 1df1 1df6 1df9 1dfe 1dff
1e04 1e07 1e0b 1e0f 1e13 1e17 1e1a 1e1b
1e1d 1e22 1e23 1e25 1e26 1e2b 1e2e 1e33
1e34 1e39 1e3c 1e41 1e42 1e47 1e4a 1e4e
1e4f 1e54 1e57 1e5c 1e5d 1e62 1e63 1e68
1e6a 1e6e 1e71 1e75 1e79 1e7c 1e80 1e84
1e87 1e8a 1e8f 1e92 1e95 1e98 1e99 1e9e
1e9f 1 1ea1 1ea6 1eaa 1eae 1eb1 1eb6
1ebb 1ebe 1ec2 1ec3 1ec8 1ec9 1ece 1ed0
1ed4 1ed7 1edb 1edf 1ee2 1ee6 1eea 1eed
1ef1 1ef5 1ef6 1efb 1efd 1f01 1f05 1f08
1f0a 1f0e 1f11 1f15 1f17 1f1b 1f1f 1f22
1f26 1f29 1f2d 1f31 1f35 1f39 1f3d 1f41
1f4d 1f51 1f55 1f58 1f5c 1f60 1f62 1
1f66 1f6a 1f6e 1f71 1f75 1f79 1f7d 1f81
1f84 1f88 1f8c 1f8f 1f92 1f97 1f9a 1f9d
1fa0 1fa1 1fa6 1fa7 1 1fa9 1fae 1fb2
1fb6 1fb9 1fbe 1fc3 1fc6 1fca 1fcb 1fd0
1fd3 1fd8 1fd9 1fde 1fe1 1fe6 1fe7 1fec
1fef 1ff3 1ff4 1ff9 1ffc 2001 2002 2007
200a 200e 2012 2015 2018 2019 201b 201c
2021 2022 2027 2029 202d 2030 2032 2036
2038 2044 2046 2048 2049 204e 2052 2054
2060 2062 2066 206a 206d 206e 2070 2073
2076 2077 207c 2080 2084 2088 208c 2090
209c 20a0 20a4 20a7 20ab 20af 20b1 1
20b5 20b9 20bd 20c0 20c4 20c8 20cc 20d0
20d3 20d7 20db 20de 20e1 20e6 20e9 20ec
20ef 20f0 20f5 20f6 1 20f8 20fd 2101
2105 2108 210d 2112 2115 2119 211a 211f
2122 2127 2128 212d 2130 2135 2136 213b
213e 2142 2143 2148 214b 2150 2151 2156
2159 215d 2161 2164 2167 2168 216a 216b
2170 2171 2176 2178 217c 217f 2181 2185
2187 2193 2195 2197 2198 219d 21a1 21a3
21af 21b1 21b5 21b9 21bc 21c0 21c5 21c6
21c8 21cb 21ce 21cf 21d4 21d8 21dc 21df
21e3 21e7 21ea 21ed 21f2 21f5 21f8 21fb
21fc 2201 2202 1 2204 2209 220d 2211
2214 2219 221e 2221 2225 2226 222b 222e
2233 2234 2239 223c 2241 2242 2247 224a
224e 2252 2256 225a 225d 225e 2260 2265
2266 2268 2269 226e 2271 2276 2277 227c
227f 2284 2285 228a 228d 2291 2292 2297
229a 229f 22a0 22a5 22a6 22ab 22ad 22b1
22b4 22b8 22bc 22bf 22c3 22c7 22ca 22cd
22d2 22d5 22d8 22db 22dc 22e1 22e2 1
22e4 22e9 22ed 22f1 22f4 22f9 22fe 2301
2305 2306 230b 230c 2311 2313 2317 231a
231e 2322 2325 2329 232d 2330 2334 2338
2339 233e 2340 2344 2347 2349 234d 2350
2352 2356 235a 235e 2362 2366 236a 236e
2372 2376 237a 237e 238a 238e 2392 2395
2399 239d 239f 1 23a3 23a7 23ab 23ae
23b2 23b6 23ba 23be 23c1 23c5 23c9 23cc
23cf 23d4 23d7 23da 23dd 23de 23e3 23e4
1 23e6 23eb 23ef 23f3 23f6 23fb 2400
2403 2407 2408 240d 2410 2415 2416 241b
241e 2423 2424 2429 242c 2430 2431 2436
2439 243e 243f 2444 2447 244b 244f 2452
2455 2456 2458 2459 245e 245f 2464 2466
246a 246d 246f 2473 2475 2481 2483 2485
2486 248b 248f 2491 249d 249f 24a3 24a7
24aa 24ae 24b1 24b5 24b8 24b9 24be 24c1
24c5 24c9 24cd 24d1 24d5 24e1 24e5 24e9
24ec 24f0 24f4 24f6 1 24fa 24fe 2502
2505 2509 250d 2511 2515 2518 251c 2520
2523 2526 252b 252e 2531 2534 2535 253a
253b 1 253d 2542 2546 254a 254d 2552
2557 255a 255e 255f 2564 2567 256c 256d
2572 2575 257a 257b 2580 2583 2587 2588
258d 2590 2595 2596 259b 259e 25a2 25a6
25a9 25ac 25ad 25af 25b0 25b5 25b6 25bb
25bd 25c1 25c4 25c6 25ca 25cc 25d8 25da
25dc 25dd 25e2 25e6 25e8 25f4 25f6 25fa
25fe 2601 2605 2608 260c 260f 2610 2615
2618 261c 2620 2623 2627 262b 262e 2631
2636 2639 263c 263f 2640 2645 2646 1
2648 264d 2651 2655 2658 265d 2662 2665
2669 266a 266f 2672 2677 2678 267d 2680
2685 2686 268b 268e 2692 2696 269a 269e
26a1 26a2 26a4 26a9 26aa 26ac 26ad 26b2
26b5 26ba 26bb 26c0 26c3 26c8 26c9 26ce
26d1 26d5 26d6 26db 26de 26e3 26e4 26e9
26ea 26ef 26f1 26f5 26f8 26fc 2700 2703
2707 270b 270e 2711 2716 2719 271c 271f
2720 2725 2726 1 2728 272d 2731 2735
2738 273d 2742 2745 2749 274a 274f 2750
2755 2757 275b 275e 2762 2766 2769 276d
2771 2774 2778 277c 277d 2782 2784 2788
278b 278d 2791 2794 2796 279a 279e 27a1
27a5 27a8 27ab 27ac 27b1 27b5 27b9 27bd
27c1 27c5 27c9 27cd 27d1 27d5 27d9 27dd
27e1 27e4 27e5 27e7 27eb 27ef 27f2 27f3
27f5 27f9 27fd 2800 2801 2803 2807 280b
280e 280f 2811 2815 2819 281c 281d 281f
2823 2827 282a 282b 282d 2831 2835 2838
2839 283b 283f 2843 2846 2847 2849 284d
2851 2855 2856 2858 285c 2860 2864 2867
2868 286a 286e 2871 2875 2878 2879 287e
2882 2886 2889 288d 2891 2894 2897 289c
289f 28a2 28a5 28a6 28ab 28ac 1 28ae
28b3 28b7 28bb 28be 28c3 28c8 28cb 28cf
28d0 28d5 28d8 28dd 28de 28e3 28e6 28eb
28ec 28f1 28f4 28f8 28fc 2900 2904 2907
2908 290a 290f 2910 2912 2913 2918 2919
291e 2920 2924 2927 292b 292f 2932 2936
293a 293d 2940 2945 2948 294b 294e 294f
2954 2955 1 2957 295c 2960 2964 2967
296c 2971 2974 2978 2979 297e 297f 2984
2986 298a 298d 2991 2995 2998 299c 29a0
29a3 29a7 29a8 29ad 29b1 29b3 29b7 29bb
29be 29bf 29c1 29c4 29c7 29c8 29cd 29d1
29d5 29d8 29dc 29e0 29e3 29e6 29eb 29ee
29f1 29f4 29f5 29fa 29fb 1 29fd 2a02
2a06 2a0a 2a0d 2a12 2a17 2a1a 2a1e 2a1f
2a24 2a27 2a2c 2a2d 2a32 2a35 2a3a 2a3b
2a40 2a43 2a47 2a4b 2a4f 2a50 2a52 2a57
2a58 2a5a 2a5b 2a60 2a63 2a68 2a69 2a6e
2a71 2a76 2a77 2a7c 2a7f 2a83 2a84 2a89
2a8c 2a91 2a92 2a97 2a98 2a9d 2a9f 2aa3
2aa6 2aaa 2aae 2ab1 2ab5 2ab9 2abc 2abf
2ac4 2ac7 2aca 2acd 2ace 2ad3 2ad4 1
2ad6 2adb 2adf 2ae3 2ae6 2aeb 2af0 2af3
2af7 2af8 2afd 2afe 2b03 2b05 2b09 2b0c
2b10 2b14 2b17 2b1b 2b1f 2b22 2b23 2b25
2b29 2b2d 2b2e 2b33 2b35 2b39 2b3d 2b40
2b44 2b48 2b4c 2b50 2b53 2b54 2b59 2b5c
2b60 2b65 2b69 2b6b 2b6f 2b72 2b76 2b78
2b7c 2b80 2b83 2b84 2b86 2b89 2b8c 2b8d
2b92 2b95 2b99 2b9d 2ba0 2ba1 2ba3 2ba6
2ba9 2baa 2baf 1 2bb2 2bb7 2bbb 2bbf
2bc2 2bc3 2bc5 2bc8 2bcb 2bcc 2bd1 2bd4
2bd8 2bdc 2bdf 2be0 2be2 2be5 2be8 2be9
2bee 1 2bf1 2bf6 2bfa 2bfd 2c01 2c05
2c07 2c0b 2c0f 2c12 2c13 2c15 2c18 2c1b
2c1c 2c21 2c25 2c28 2c2c 2c30 2c32 2c36
2c3a 2c3e 2c41 2c42 2c44 2c47 2c4a 2c4b
2c50 2c53 2c57 2c5b 2c5e 2c5f 2c61 2c64
2c67 2c68 2c6d 1 2c70 2c75 2c79 2c7c
2c80 2c84 2c86 2c8a 2c8e 2c92 2c95 2c96
2c98 2c9b 2c9e 2c9f 2ca4 2ca8 2cac 2cb0
2cb3 2cb4 2cb6 2cb9 2cbd 2cc1 2cc4 2cc5
2cc7 2cc8 2ccd 2cd1 2cd5 2cd8 2cdc 2cde
2ce2 2ce6 2ce9 2ceb 2cef 2cf3 2cf6 2cfa
2cfe 2cff 2d04 2d08 2d0c 2d11 2d15 2d19
2d1e 2d22 2d26 2d2a 2d2e 2d31 2d35 2d39
2d3d 2d40 2d41 2d43 2d47 2d4b 2d4e 2d4f
2d51 2d54 2d57 2d58 2d5a 2d5e 2d62 2d66
2d6a 2d6e 2d71 2d72 2d74 2d78 2d7c 2d7f
2d80 2d82 2d86 2d8a 2d8e 2d91 2d92 2d94
2d97 2d9a 2d9b 2da0 2da4 2da8 2dac 2db0
2db4 2db8 2dbc 2dc0 2dc1 2dc3 2dc7 2dcb
2dcf 2dd2 2dd3 2dd5 2dd8 2ddb 2ddc 2de1
2de5 2de9 2dec 2df0 2df4 2df7 2dfa 2dff
2e02 2e05 2e08 2e09 2e0e 2e0f 1 2e11
2e16 2e1a 2e1e 2e21 2e26 2e2b 2e2e 2e32
2e33 2e38 2e3b 2e40 2e41 2e46 2e49 2e4e
2e4f 2e54 2e57 2e5b 2e5f 2e63 2e64 2e66
2e6b 2e6c 2e6e 2e6f 2e74 2e77 2e7c 2e7d
2e82 2e85 2e8a 2e8b 2e90 2e93 2e97 2e98
2e9d 2ea0 2ea5 2ea6 2eab 2eac 2eb1 2eb3
2eb7 2eba 2ebe 2ec2 2ec5 2ec9 2ecd 2ed0
2ed3 2ed8 2edb 2ede 2ee1 2ee2 2ee7 2ee8
1 2eea 2eef 2ef3 2ef7 2efa 2eff 2f04
2f07 2f0b 2f0c 2f11 2f12 2f17 2f19 2f1d
2f20 2f24 2f28 2f2b 2f2f 2f33 2f36 2f37
2f39 2f3d 2f41 2f42 2f47 2f49 2f4d 2f50
2f54 2f55 2f59 2f5d 2f61 2f65 2f69 2f6d
2f71 2f75 2f79 2f7d 2f81 2f85 2f89 2f8d
2f91 2f95 2f99 2f9d 2fa1 2fa5 2fa9 2fb5
2fb9 2fbd 2fc0 2fc4 2fc8 2fca 1 2fce
2fd2 2fd6 2fd9 2fdd 2fe1 2fe5 2fe9 2fec
2ff0 2ff4 2ff7 2ffa 2fff 3002 3005 3008
3009 300e 300f 1 3011 3016 301a 301e
3021 3026 302b 302e 3032 3033 3038 303b
3040 3041 3046 3049 304e 304f 3054 3057
305b 305c 3061 3064 3069 306a 306f 3072
3076 307a 307d 3080 3081 3083 3084 3089
308a 308f 3091 3095 3098 309a 309e 30a0
30ac 30ae 30b0 30b1 30b6 30ba 30bc 30c8
30ca 30ce 30d2 30d5 30d9 30dc 30e0 30e3
30e4 30e9 30ec 30f0 30f3 30f4 30f9 30fc
1 30ff 3104 3108 310b 310f 3113 3117
311a 311b 311d 3120 3123 3124 3129 312d
3131 3135 3137 313b 313e 3140 3144 3147
314b 314e 3152 3156 3159 315d 3161 3164
3167 3168 316d 3171 3175 3178 317b 317c
317e 3181 3186 3187 318c 3190 3194 3198
319c 31a0 31a4 31a8 31ac 31b0 31b4 31b8
31bc 31c0 31c4 31c8 31cc 31d0 31d4 31d8
31dc 31e0 31e4 31e8 31ec 31f0 31f4 31f8
31fc 3208 320c 3210 3213 3217 321b 321d
1 3221 3225 3229 322c 3230 3234 3238
323c 323f 3243 3247 324a 324d 3252 3255
3258 325b 325c 3261 3262 1 3264 3269
326d 3271 3274 3279 327e 3281 3285 3286
328b 328e 3293 3294 3299 329c 32a1 32a2
32a7 32aa 32ae 32af 32b4 32b7 32bc 32bd
32c2 32c5 32c9 32cd 32d0 32d3 32d4 32d6
32d7 32dc 32dd 32e2 32e4 32e8 32eb 32ed
32f1 32f3 32ff 3301 3303 3304 3309 330d
330f 331b 331d 3321 3325 3328 332c 332f
3333 3336 3337 333c 333f 3343 3346 334a
334e 3352 3355 3356 3358 335b 335e 335f
3364 3367 336b 336f 3372 3373 3375 3378
337b 337c 3381 1 3384 3389 338d 3391
3395 3399 339d 33a1 33a5 33a9 33ad 33b1
33b5 33b9 33bd 33c1 33c5 33c9 33cd 33d1
33d5 33d9 33dd 33e1 33e5 33e9 33ed 33f1
33fd 3401 3405 3408 340c 3410 3412 1
3416 341a 341e 3421 3425 3429 342d 3431
3434 3438 343c 343f 3442 3447 344a 344d
3450 3451 3456 3457 1 3459 345e 3462
3466 3469 346e 3473 3476 347a 347b 3480
3483 3488 3489 348e 3491 3496 3497 349c
349f 34a3 34a4 34a9 34ac 34b1 34b2 34b7
34ba 34be 34c2 34c5 34c8 34c9 34cb 34cc
34d1 34d2 34d7 34d9 34dd 34e0 34e2 34e6
34e8 34f4 34f6 34f8 34f9 34fe 3502 3504
3510 3512 3514 3518 351b 351f 3521 3525
3529 352c 3530 3532 3536 353a 353d 3541
3544 3548 354b 354c 3551 3554 3558 355c
355f 3560 3562 3565 3568 3569 356e 1
3571 3576 357a 357e 3582 3586 358a 358e
3592 3596 359a 359e 35a2 35a6 35aa 35ae
35b2 35b6 35ba 35be 35c2 35c6 35ca 35ce
35d2 35d6 35da 35de 35ea 35ee 35f2 35f5
35f9 35fd 35ff 1 3603 3607 360b 360e
3612 3616 361a 361e 3621 3625 3629 362c
362f 3634 3637 363a 363d 363e 3643 3644
1 3646 364b 364f 3653 3656 365b 3660
3663 3667 3668 366d 3670 3675 3676 367b
367e 3683 3684 3689 368c 3690 3691 3696
3699 369e 369f 36a4 36a7 36ab 36af 36b2
36b5 36b6 36b8 36b9 36be 36bf 36c4 36c6
36ca 36cd 36cf 36d3 36d5 36e1 36e3 36e5
36e6 36eb 36ef 36f1 36fd 36ff 3701 3705
3709 370c 370e 3712 3716 371a 371e 3722
3726 372a 372e 3732 3736 373a 373e 3742
3746 374a 374e 3752 3756 375a 375e 3762
3766 376a 376e 3772 3776 3782 3786 378a
378d 3791 3795 3797 1 379b 379f 37a3
37a6 37aa 37ae 37b2 37b6 37b9 37bd 37c1
37c4 37c7 37cc 37cf 37d2 37d5 37d6 37db
37dc 1 37de 37e3 37e7 37eb 37ee 37f3
37f8 37fb 37ff 3800 3805 3808 380d 380e
3813 3816 381b 381c 3821 3824 3828 3829
382e 3831 3836 3837 383c 383f 3843 3847
384a 384d 384e 3850 3851 3856 3857 385c
385e 3862 3865 3867 386b 386d 3879 387b
387d 387e 3883 3887 3889 3895 3897 3899
389d 38a1 38a4 38a6 38aa 38ae 38b1 38b4
38b5 38b7 38ba 38bf 38c0 38c5 38c9 38cd
38d1 38d5 38d9 38dd 38e1 38e5 38e9 38ed
38f1 38f5 38f9 38fd 3901 3905 3909 390d
3911 3915 3919 391d 3921 3925 3929 3935
3939 393d 3940 3944 3948 394a 1 394e
3952 3956 3959 395d 3961 3965 3969 396c
3970 3974 3977 397a 397f 3982 3985 3988
3989 398e 398f 1 3991 3996 399a 399e
39a1 39a6 39ab 39ae 39b2 39b3 39b8 39bb
39c0 39c1 39c6 39c9 39ce 39cf 39d4 39d7
39db 39dc 39e1 39e4 39e9 39ea 39ef 39f2
39f6 39fa 39fd 3a00 3a01 3a03 3a04 3a09
3a0a 3a0f 3a11 3a15 3a18 3a1a 3a1e 3a20
3a2c 3a2e 3a30 3a31 3a36 3a3a 3a3c 3a48
3a4a 3a4e 3a52 3a55 3a59 3a5c 3a60 3a63
3a64 3a69 3a6c 3a70 3a73 3a77 3a7b 3a7f
3a82 3a83 3a85 3a88 3a8b 3a8c 3a91 3a94
3a98 3a9c 3a9f 3aa0 3aa2 3aa5 3aa8 3aa9
3aae 1 3ab1 3ab6 3aba 3abe 3ac2 3ac6
3aca 3ace 3ad2 3ad6 3ada 3ade 3ae2 3ae6
3aea 3aee 3af2 3af6 3afa 3afe 3b02 3b06
3b12 3b16 3b1a 3b1d 3b21 3b25 3b27 1
3b2b 3b2f 3b33 3b36 3b3a 3b3e 3b42 3b46
3b49 3b4d 3b51 3b54 3b57 3b5c 3b5f 3b62
3b65 3b66 3b6b 3b6c 1 3b6e 3b73 3b77
3b7b 3b7e 3b83 3b88 3b8b 3b8f 3b90 3b95
3b98 3b9d 3b9e 3ba3 3ba6 3bab 3bac 3bb1
3bb4 3bb8 3bb9 3bbe 3bc1 3bc6 3bc7 3bcc
3bcf 3bd3 3bd7 3bda 3bdd 3bde 3be0 3be1
3be6 3be7 3bec 3bee 3bf2 3bf5 3bf7 3bfb
3bfd 3c09 3c0b 3c0d 3c0e 3c13 3c17 3c19
3c25 3c27 3c29 3c2d 3c30 3c34 3c36 3c38
3c3c 3c40 3c43 3c47 3c49 3c4d 3c51 3c54
3c58 3c5b 3c5f 3c62 3c63 3c68 3c6b 3c6f
3c73 3c77 3c7b 3c7f 3c83 3c87 3c8b 3c8f
3c93 3c97 3c9b 3c9f 3ca3 3ca7 3cab 3caf
3cb3 3cb7 3cbb 3cbf 3cc3 3cc7 3cd3 3cd7
3cdb 3cde 3ce2 3ce6 3ce8 1 3cec 3cf0
3cf4 3cf7 3cfb 3cff 3d03 3d07 3d0a 3d0e
3d12 3d15 3d18 3d1d 3d20 3d23 3d26 3d27
3d2c 3d2d 1 3d2f 3d34 3d38 3d3c 3d3f
3d44 3d49 3d4c 3d50 3d51 3d56 3d59 3d5e
3d5f 3d64 3d67 3d6c 3d6d 3d72 3d75 3d79
3d7a 3d7f 3d82 3d87 3d88 3d8d 3d90 3d94
3d98 3d9b 3d9e 3d9f 3da1 3da2 3da7 3da8
3dad 3daf 3db3 3db6 3db8 3dbc 3dbe 3dca
3dcc 3dce 3dcf 3dd4 3dd8 3dda 3de6 3de8
3dea 3dee 3df2 3df5 3df7 3dfb 3dff 3e03
3e07 3e0b 3e0f 3e13 3e17 3e1b 3e1f 3e23
3e27 3e2b 3e2f 3e33 3e37 3e3b 3e3f 3e43
3e47 3e4b 3e4f 3e53 3e5f 3e63 3e67 3e6a
3e6e 3e72 3e74 1 3e78 3e7c 3e80 3e83
3e87 3e8b 3e8f 3e93 3e96 3e9a 3e9e 3ea1
3ea4 3ea9 3eac 3eaf 3eb2 3eb3 3eb8 3eb9
1 3ebb 3ec0 3ec4 3ec8 3ecb 3ed0 3ed5
3ed8 3edc 3edd 3ee2 3ee5 3eea 3eeb 3ef0
3ef3 3ef8 3ef9 3efe 3f01 3f05 3f06 3f0b
3f0e 3f13 3f14 3f19 3f1c 3f20 3f24 3f27
3f2a 3f2b 3f2d 3f2e 3f33 3f34 3f39 3f3b
3f3f 3f42 3f44 3f48 3f4a 3f56 3f58 3f5a
3f5b 3f60 3f64 3f66 3f72 3f74 3f76 3f7a
3f7e 3f81 3f83 3f87 3f8b 3f8e 3f92 3f96
3f99 3f9d 3fa0 3fa4 3fa7 3fa8 3fad 3fb0
3fb4 3fb8 3fbb 3fbc 3fbe 3fc1 3fc4 3fc5
3fca 3fce 3fd2 3fd5 3fd9 3fdd 3fe0 3fe3
3fe8 3feb 3fee 3ff1 3ff2 3ff7 3ff8 1
3ffa 3fff 4003 4007 400a 400f 4014 4017
401b 401c 4021 4024 4029 402a 402f 4032
4037 4038 403d 4040 4044 4048 404c 4050
4053 4054 4056 405b 405c 405e 405f 4064
4067 406c 406d 4072 4075 407a 407b 4080
4083 4087 4088 408d 4090 4095 4096 409b
409c 40a1 40a3 40a7 40aa 40ae 40b2 40b5
40b9 40bd 40c0 40c3 40c8 40cb 40ce 40d1
40d2 40d7 40d8 1 40da 40df 40e3 40e7
40ea 40ef 40f4 40f7 40fb 40fc 4101 4102
4107 4109 410d 4110 4114 4118 411b 411f
4123 4126 412a 412e 412f 4134 4138 413a
413e 4141 4142 4147 414a 414e 4151 4154
4155 415a 415e 4161 4165 4169 416d 4171
4175 4179 417d 4181 4185 4189 418d 4191
4195 4199 419d 41a1 41ad 41b1 41b5 41b8
41bc 41c0 41c2 1 41c6 41ca 41ce 41d1
41d5 41d9 41dd 41e1 41e4 41e8 41ec 41ef
41f2 41f7 41fa 41fd 4200 4201 4206 4207
1 4209 420e 4212 4216 4219 421e 4223
4226 422a 422b 4230 4233 4238 4239 423e
4241 4246 4247 424c 424f 4253 4254 4259
425c 4261 4262 4267 426a 426e 4272 4275
4278 4279 427b 427c 4281 4282 4287 4289
428d 4290 4292 4296 4298 42a4 42a6 42a8
42a9 42ae 42b2 42b4 42c0 42c2 42c4 42c8
42cb 42cf 42d3 42d7 42db 42df 42e3 42e7
42eb 42ef 42f3 42f7 42fb 42ff 430b 430f
4313 4316 431a 431e 4320 1 4324 4328
432c 432f 4333 4337 433b 433f 4342 4346
434a 434d 4350 4355 4358 435b 435e 435f
4364 4365 1 4367 436c 4370 4374 4377
437c 4381 4384 4388 4389 438e 4391 4396
4397 439c 439f 43a4 43a5 43aa 43ad 43b1
43b2 43b7 43ba 43bf 43c0 43c5 43c8 43cc
43d0 43d3 43d6 43d7 43d9 43da 43df 43e0
43e5 43e7 43eb 43ee 43f0 43f4 43f6 4402
4404 4406 4407 440c 4410 4412 441e 4420
4422 4426 442a 442d 4431 4435 4438 4439
443b 443f 4442 4446 4449 444a 444c 444d
4452 4456 445a 445d 4461 4465 4468 446b
4470 4473 4476 4479 447a 447f 4480 1
4482 4487 448b 448f 4492 4497 449c 449f
44a3 44a4 44a9 44ac 44b1 44b2 44b7 44ba
44bf 44c0 44c5 44c8 44cc 44d0 44d4 44d8
44db 44dc 44de 44e3 44e4 44e6 44e7 44ec
44ef 44f4 44f5 44fa 44fd 4502 4503 4508
450b 450f 4510 4515 4518 451d 451e 4523
4524 4529 452b 452f 4532 4536 453a 453d
4541 4545 4548 454b 4550 4553 4556 4559
455a 455f 4560 1 4562 4567 456b 456f
4572 4577 457c 457f 4583 4584 4589 458a
458f 4591 4595 4598 459c 45a0 45a3 45a7
45ab 45ae 45b2 45b6 45b7 45bc 45be 45c2
45c5 45c7 45cb 45cf 45d2 45d6 45d9 45dd
45e1 45e3 45e7 45eb 45ee 45ef 45f1 45f4
45f7 45f8 45fd 4600 4604 4608 460c 460f
4610 4612 4613 4615 4618 461b 461e 461f
1 4624 4629 462d 4631 4634 4638 463c
463f 4642 4647 464a 464d 4650 4651 4656
4657 1 4659 465e 4662 4666 4669 466e
4673 4676 467a 467b 4680 4683 4688 4689
468e 4691 4696 4697 469c 469f 46a3 46a7
46ab 46af 46b2 46b3 46b5 46ba 46bb 46bd
46be 46c3 46c6 46cb 46cc 46d1 46d4 46d9
46da 46df 46e2 46e6 46e7 46ec 46ef 46f4
46f5 46fa 46fb 4700 4702 4706 4709 470d
4711 4714 4718 471c 471f 4722 4727 472a
472d 4730 4731 4736 4737 1 4739 473e
4742 4746 4749 474e 4753 4756 475a 475b
4760 4761 4766 4768 476c 476f 4773 4777
477a 477e 4782 4785 4789 478d 478e 4793
4795 4799 479d 47a0 47a4 47a8 47ab 47ae
47af 47b1 47b4 47b9 47ba 47bf 47c3 47c7
47cb 47ce 47d2 47d3 47d8 47db 47de 47df
47e1 47e5 47e9 47ed 47f1 47f5 47f9 47fd
4801 4805 4809 480d 4811 4815 4819 481d
4821 4825 4829 482d 4831 4835 4839 4845
4849 484d 4850 4854 4858 485a 1 485e
4862 4866 4869 486d 4871 4875 4879 487c
4880 4884 4887 488a 488f 4892 4895 4898
4899 489e 489f 1 48a1 48a6 48aa 48ae
48b1 48b6 48bb 48be 48c2 48c3 48c8 48cb
48d0 48d1 48d6 48d9 48de 48df 48e4 48e7
48eb 48ec 48f1 48f4 48f9 48fa 48ff 4902
4906 490a 490d 4910 4911 4913 4914 4919
491a 491f 4921 4925 4928 492a 492e 4930
493c 493e 4940 4941 4946 494a 494c 4958
495a 495e 4962 4965 4969 496c 4970 4973
4974 4979 497c 4980 4984 4987 498b 498f
4992 4995 499a 499d 49a0 49a3 49a4 49a9
49aa 1 49ac 49b1 49b5 49b9 49bc 49c1
49c6 49c9 49cd 49ce 49d3 49d6 49db 49dc
49e1 49e4 49e9 49ea 49ef 49f2 49f6 49fa
49fe 4a02 4a05 4a06 4a08 4a0d 4a0e 4a10
4a11 4a16 4a19 4a1e 4a1f 4a24 4a27 4a2c
4a2d 4a32 4a35 4a39 4a3a 4a3f 4a42 4a47
4a48 4a4d 4a4e 4a53 4a55 4a59 4a5c 4a60
4a64 4a67 4a6b 4a6f 4a72 4a75 4a7a 4a7d
4a80 4a83 4a84 4a89 4a8a 1 4a8c 4a91
4a95 4a99 4a9c 4aa1 4aa6 4aa9 4aad 4aae
4ab3 4ab4 4ab9 4abb 4abf 4ac2 4ac6 4aca
4acd 4ad1 4ad5 4ad8 4adc 4ae0 4ae1 4ae6
4ae8 4aec 4aef 4af3 4af7 4afa 4afd 4afe
4b00 4b03 4b08 4b09 4b0e 4b11 4b15 4b19
4b1c 4b1d 4b1f 4b22 4b25 4b26 4b2b 4b2e
4b32 4b36 4b39 4b3a 4b3c 4b40 4b43 4b47
4b4a 4b4b 4b4d 4b4e 4b53 1 4b56 4b5b
1 4b5e 4b63 4b67 4b6b 4b6e 4b72 4b76
4b79 4b7c 4b81 4b84 4b87 4b8a 4b8b 4b90
4b91 1 4b93 4b98 4b9c 4ba0 4ba3 4ba8
4bad 4bb0 4bb4 4bb5 4bba 4bbd 4bc2 4bc3
4bc8 4bcb 4bd0 4bd1 4bd6 4bd9 4bdd 4be1
4be5 4be9 4bec 4bed 4bef 4bf4 4bf5 4bf7
4bf8 4bfd 4c00 4c05 4c06 4c0b 4c0e 4c13
4c14 4c19 4c1c 4c20 4c21 4c26 4c29 4c2e
4c2f 4c34 4c35 4c3a 4c3c 4c40 4c43 4c47
4c4b 4c4e 4c52 4c56 4c59 4c5c 4c61 4c64
4c67 4c6a 4c6b 4c70 4c71 1 4c73 4c78
4c7c 4c80 4c83 4c88 4c8d 4c90 4c94 4c95
4c9a 4c9b 4ca0 4ca2 4ca6 4ca9 4cad 4cb1
4cb4 4cb8 4cbc 4cbf 4cc3 4cc7 4cc8 4ccd
4ccf 4cd3 4cd6 4cda 4cde 4ce2 4ce6 4cea
4cee 4cf2 4cf6 4cfa 4cfe 4d02 4d06 4d12
4d16 4d1a 4d1d 4d21 4d25 4d27 1 4d2b
4d2f 4d33 4d36 4d3a 4d3e 4d42 4d46 4d49
4d4d 4d51 4d54 4d57 4d5c 4d5f 4d62 4d65
4d66 4d6b 4d6c 1 4d6e 4d73 4d77 4d7b
4d7e 4d83 4d88 4d8b 4d8f 4d90 4d95 4d98
4d9d 4d9e 4da3 4da6 4dab 4dac 4db1 4db4
4db8 4db9 4dbe 4dc1 4dc6 4dc7 4dcc 4dcf
4dd3 4dd7 4dda 4ddd 4dde 4de0 4de1 4de6
4de7 4dec 4dee 4df2 4df5 4df7 4dfb 4dfd
4e09 4e0b 4e0d 4e0e 4e13 4e17 4e19 4e25
4e27 4e29 4e2d 4e31 4e35 4e38 4e3c 4e3d
4e42 4e45 4e48 4e49 4e4b 4e4f 4e53 4e57
4e5b 4e5f 4e63 4e6f 4e73 4e77 4e7a 4e7e
4e82 4e84 1 4e88 4e8c 4e90 4e93 4e97
4e9b 4e9f 4ea3 4ea6 4eaa 4eae 4eb1 4eb4
4eb9 4ebc 4ebf 4ec2 4ec3 4ec8 4ec9 1
4ecb 4ed0 4ed4 4ed8 4edb 4ee0 4ee5 4ee8
4eec 4eed 4ef2 4ef5 4efa 4efb 4f00 4f03
4f08 4f09 4f0e 4f11 4f15 4f16 4f1b 4f1e
4f23 4f24 4f29 4f2c 4f30 4f34 4f37 4f3a
4f3b 4f3d 4f3e 4f43 4f44 4f49 4f4b 4f4f
4f52 4f54 4f58 4f5a 4f66 4f68 4f6a 4f6b
4f70 4f74 4f76 4f82 4f84 4f88 4f8c 4f8f
4f93 4f96 4f9a 4f9d 4f9e 4fa3 4fa6 4faa
4fae 4fb1 4fb5 4fb9 4fbc 4fbf 4fc4 4fc7
4fca 4fcd 4fce 4fd3 4fd4 1 4fd6 4fdb
4fdf 4fe3 4fe6 4feb 4ff0 4ff3 4ff7 4ff8
4ffd 5000 5005 5006 500b 500e 5013 5014
5019 501c 5020 5024 5028 502c 502f 5030
5032 5037 5038 503a 503b 5040 5043 5048
5049 504e 5051 5056 5057 505c 505f 5063
5064 5069 506c 5071 5072 5077 5078 507d
507f 5083 5086 508a 508e 5091 5095 5099
509c 509f 50a4 50a7 50aa 50ad 50ae 50b3
50b4 1 50b6 50bb 50bf 50c3 50c6 50cb
50d0 50d3 50d7 50d8 50dd 50de 50e3 50e5
50e9 50ec 50f0 50f4 50f7 50fb 50ff 5102
5106 510a 510b 5110 5112 5116 5119 511d
5121 5125 5129 512d 5131 5135 5139 513d
5141 5145 5149 514d 5151 5155 5159 515d
5161 5165 5169 5175 5179 517d 5180 5184
5188 518a 1 518e 5192 5196 5199 519d
51a1 51a5 51a9 51ac 51b0 51b4 51b7 51ba
51bf 51c2 51c5 51c8 51c9 51ce 51cf 1
51d1 51d6 51da 51de 51e1 51e6 51eb 51ee
51f2 51f3 51f8 51fb 5200 5201 5206 5209
520e 520f 5214 5217 521b 521c 5221 5224
5229 522a 522f 5232 5236 523a 523d 5240
5241 5243 5244 5249 524a 524f 5251 5255
5258 525a 525e 5260 526c 526e 5270 5271
5276 527a 527c 5288 528a 528e 5292 5295
5299 529c 52a0 52a3 52a4 52a9 52ac 52b0
52b4 52b7 52b8 52ba 52bd 52c0 52c1 52c6
1 52c9 52ce 52d2 52d6 52d9 52dd 52e1
52e4 52e7 52ec 52ef 52f2 52f5 52f6 52fb
52fc 1 52fe 5303 5307 530b 530e 5313
5318 531b 531f 5320 5325 5328 532d 532e
5333 5336 533b 533c 5341 5344 5348 534c
5350 5354 5357 5358 535a 535f 5360 5362
5363 5368 536b 5370 5371 5376 5379 537e
537f 5384 5387 538b 538c 5391 5394 5399
539a 539f 53a0 53a5 53a7 53ab 53ae 53b2
53b6 53b9 53bd 53c1 53c4 53c7 53cc 53cf
53d2 53d5 53d6 53db 53dc 1 53de 53e3
53e7 53eb 53ee 53f3 53f8 53fb 53ff 5400
5405 5406 540b 540d 5411 5414 5418 541c
541f 5423 5427 542a 542e 5432 5433 5438
543a 543e 5441 5445 5449 544d 5451 5455
5459 545d 5461 5465 5469 546d 5471 547d
5481 5485 5488 548c 5490 5492 1 5496
549a 549e 54a1 54a5 54a9 54ad 54b1 54b4
54b8 54bc 54bf 54c2 54c7 54ca 54cd 54d0
54d1 54d6 54d7 1 54d9 54de 54e2 54e6
54e9 54ee 54f3 54f6 54fa 54fb 5500 5503
5508 5509 550e 5511 5516 5517 551c 551f
5523 5524 5529 552c 5531 5532 5537 553a
553e 5542 5545 5548 5549 554b 554c 5551
5552 5557 5559 555d 5560 5562 5566 5568
5574 5576 5578 5579 557e 5582 5584 5590
5592 5594 5598 559c 559f 55a3 55a7 55ab
55af 55b3 55b6 55b7 55b9 55bc 55bf 55c0
55c5 55c9 55cd 55d1 55d5 55d9 55dd 55e1
55e5 55e9 55ed 55f9 55fd 5601 5604 5608
560c 560e 1 5612 5616 561a 561d 5621
5625 5629 562d 5630 5634 5638 563b 563e
5643 5646 5649 564c 564d 5652 5653 1
5655 565a 565e 5662 5665 566a 566f 5672
5676 5677 567c 567f 5684 5685 568a 568d
5692 5693 5698 569b 569f 56a0 56a5 56a8
56ad 56ae 56b3 56b6 56ba 56be 56c1 56c4
56c5 56c7 56c8 56cd 56ce 56d3 56d5 56d9
56dc 56de 56e2 56e4 56f0 56f2 56f4 56f5
56fa 56fe 5700 570c 570e 5712 5716 571a
571e 5722 5726 572a 572e 5732 5736 5742
5746 574a 574d 5751 5755 5757 1 575b
575f 5763 5766 576a 576e 5772 5776 5779
577d 5781 5784 5787 578c 578f 5792 5795
5796 579b 579c 1 579e 57a3 57a7 57ab
57ae 57b3 57b8 57bb 57bf 57c0 57c5 57c8
57cd 57ce 57d3 57d6 57db 57dc 57e1 57e4
57e8 57e9 57ee 57f1 57f6 57f7 57fc 57ff
5803 5807 580a 580d 580e 5810 5811 5816
5817 581c 581e 5822 5825 5827 582b 582d
5839 583b 583d 583e 5843 5847 5849 5855
5857 585b 585e 5862 5866 586a 586e 5872
5876 5879 587a 587c 587f 5882 5883 5888
588c 588f 5893 5895 5899 589c 58a0 58a4
58a8 58ac 58b0 58b4 58b8 58bc 58c0 58c4
58c8 58cc 58d0 58d4 58d8 58dc 58e0 58e4
58e8 58ec 58f0 58f4 58f8 58fc 5900 5904
5908 590c 5910 5914 5917 591a 591d 5920
5921 5923 5927 592b 592e 5931 5932 5937
593b 593f 5942 5943 5945 5948 594b 594c
5951 5955 5959 595d 5961 596d 5971 5976
597a 597d 597e 5983 5987 598b 598e 5991
5995 5997 599b 599f 59a2 59a5 59a9 59ab
59af 59b3 59b6 59b8 1 59bc 59c0 59c4
59c7 59cb 59cf 59d3 59d7 59da 59de 59e2
59e5 59e8 59ed 59f0 59f3 59f6 59f7 59fc
59fd 1 59ff 5a04 5a08 5a0c 5a0f 5a14
5a19 5a1c 5a20 5a21 5a26 5a29 5a2e 5a2f
5a34 5a37 5a3c 5a3d 5a42 5a45 5a49 5a4a
5a4f 5a52 5a57 5a58 5a5d 5a60 5a64 5a68
5a6b 5a6e 5a6f 5a71 5a72 5a77 5a78 5a7d
5a7f 5a83 5a86 5a88 5a8c 5a8e 5a9a 5a9c
5a9e 5a9f 5aa4 5aa8 5aaa 5ab6 5ab8 5aba
5abe 5ac2 5ac6 5aca 5ad6 5ada 5adf 5ae3
5ae6 5ae7 5aec 5af0 5af4 5af7 5afa 5afe
5b00 5b04 5b08 5b0b 5b0e 5b12 5b14 5b18
5b1c 5b1f 5b21 1 5b25 5b29 5b2d 5b30
5b34 5b38 5b3c 5b40 5b43 5b47 5b4b 5b4e
5b51 5b56 5b59 5b5c 5b5f 5b60 5b65 5b66
1 5b68 5b6d 5b71 5b75 5b78 5b7d 5b82
5b85 5b89 5b8a 5b8f 5b92 5b97 5b98 5b9d
5ba0 5ba5 5ba6 5bab 5bae 5bb2 5bb3 5bb8
5bbb 5bc0 5bc1 5bc6 5bc9 5bcd 5bd1 5bd4
5bd7 5bd8 5bda 5bdb 5be0 5be1 5be6 5be8
5bec 5bef 5bf1 5bf5 5bf7 5c03 5c05 5c07
5c08 5c0d 5c11 5c13 5c1f 5c21 5c23 5c27
5c2b 5c2e 5c30 5c34 5c37 5c39 5c3d 5c41
5c45 5c49 5c4d 5c51 5c55 5c59 5c5c 5c5f
5c60 5c62 5c65 5c6a 5c6b 5c70 5c74 5c78
5c7c 5c7f 5c83 5c85 5c89 5c8d 5c91 5c95
5c98 5c99 5c9b 5c9f 5ca3 5ca6 5ca7 5ca9
5cad 5caf 5cb3 5cb7 5cba 5cbe 5cc2 5cc6
5cca 5cce 5cd2 5cd6 5cda 5cde 5ce2 5ce6
5cea 5cee 5cf2 5cf6 5cfa 5cfe 5d02 5d06
5d0a 5d0e 5d12 5d16 5d1a 5d1e 5d22 5d26
5d2a 5d2e 5d32 5d35 5d38 5d3b 5d3e 5d3f
5d41 5d45 5d49 5d4c 5d4f 5d50 5d55 5d59
5d5d 5d61 5d65 5d71 5d75 5d7a 5d7e 5d81
5d82 5d87 5d8b 5d8f 5d92 5d95 5d99 5d9b
5d9f 5da3 5da6 5da9 5dad 5daf 5db3 5db7
5dba 5dbc 1 5dc0 5dc4 5dc8 5dcb 5dcf
5dd3 5dd7 5ddb 5dde 5de2 5de6 5de9 5dec
5df1 5df4 5df7 5dfa 5dfb 5e00 5e01 1
5e03 5e08 5e0c 5e10 5e13 5e18 5e1d 5e20
5e24 5e25 5e2a 5e2d 5e32 5e33 5e38 5e3b
5e40 5e41 5e46 5e49 5e4d 5e4e 5e53 5e56
5e5b 5e5c 5e61 5e64 5e68 5e6c 5e6f 5e72
5e73 5e75 5e76 5e7b 5e7c 5e81 5e83 5e87
5e8a 5e8c 5e90 5e92 5e9e 5ea0 5ea2 5ea3
5ea8 5eac 5eae 5eba 5ebc 5ebe 5ec2 5ec5
5ec7 5ecb 5ecf 5ed2 5ed4 5ed8 5edc 5ee0
5ee1 5ee3 5ee6 5ee7 5ee9 5eec 5eef 5ef0
5ef5 5ef9 5efc 5f00 5f02 5f06 5f0a 5f0e
5f12 5f16 5f17 5f19 5f1c 5f1d 5f1f 5f22
5f25 5f26 5f2b 5f2e 5f31 5f34 5f35 5f3a
5f3b 5f3d 5f41 5f43 5f47 5f4b 5f4e 5f52
5f55 5f58 5f59 5f5e 5f62 5f65 5f69 5f6d
5f71 5f75 5f78 5f79 5f7b 5f7f 5f82 5f86
5f87 5f8c 5f8e 5f92 5f95 5f99 5f9d 5fa1
5fa5 5fa8 5fab 5fae 5fb2 5fb6 5fb9 5fba
5fbc 5fbf 5fc2 5fc3 5fc8 5fcb 5fce 5fcf
5fd4 5fd8 5fd9 5fdb 5fdf 5fe3 5fe7 5feb
5fee 5ff1 5ff4 5ff8 5ffc 5fff 6000 6002
6005 6008 6009 600e 6011 6014 6015 601a
601d 6020 6021 6026 602a 602b 602d 6031
6035 6039 603d 6041 6044 6048 604c 604f
6053 6057 605b 605f 6063 6067 606b 606f
6073 6077 607b 607f 6083 6087 608b 608f
6093 6097 60a3 60a7 60ab 60ae 60b2 60b6
60b8 1 60bc 60c0 60c4 60c7 60cb 60cf
60d3 60d7 60da 60de 60e2 60e5 60e8 60ed
60f0 60f3 60f6 60f7 60fc 60fd 1 60ff
6104 6108 610c 610f 6114 6119 611c 6120
6121 6126 6129 612e 612f 6134 6137 613c
613d 6142 6145 6149 614a 614f 6152 6157
6158 615d 6160 6164 6168 616b 616e 616f
6171 6172 6177 6178 617d 617f 6183 6186
6188 618c 618e 619a 619c 619e 619f 61a4
61a8 61aa 61b6 61b8 61bc 61c0 61c3 61c4
61c6 61c9 61cc 61cd 61d2 61d5 61d9 61dc
61dd 61e2 61e5 1 61e8 61ed 61f1 61f4
61f8 61fc 6200 6203 6207 620b 620c 620e
6211 6214 6215 621a 621e 6222 6226 6228
622c 622f 6231 6235 6238 623c 6240 6243
6246 6247 6249 624c 6251 6252 6257 625b
625f 6263 6266 626a 626e 6272 6276 6277
6279 627c 627d 627f 6282 6285 6286 628b
628f 6293 6297 6299 629d 62a1 62a5 62a8
62ad 62ae 62b3 62b6 62b9 62ba 62bc 62c0
62c4 62c8 62cc 62cf 62d3 62d4 62d9 62dc
62df 62e0 62e2 62e6 62e8 62ec 62f0 62f3
62f5 62f9 62fd 6301 6302 6304 6307 6308
630a 630d 6310 6311 6316 631a 631e 6322
6324 6328 632c 6330 6333 6338 6339 633e
6341 6344 6345 6347 634b 634f 6353 6357
635a 635e 635f 6364 6367 636a 636b 636d
6371 6373 6377 637b 637e 6380 6384 6388
638b 638f 6392 6396 639a 639d 63a1 63a5
63a9 63ac 63ad 63af 63b2 63b5 63b6 63bb
63bf 63c2 63c5 63c6 63cb 63cf 63d3 63d6
63d9 63da 63dc 63df 63e4 63e5 63ea 63ee
63f2 63f6 63fa 63fe 6402 6406 640a 640e
6412 6416 641a 641e 6422 6426 642a 642e
6432 6436 643a 643e 6442 6446 644a 644e
6452 6456 645a 6466 646a 646e 6471 6475
6479 647b 1 647f 6483 6487 648a 648e
6492 6496 649a 649d 64a1 64a5 64a8 64ab
64b0 64b3 64b6 64b9 64ba 64bf 64c0 1
64c2 64c7 64cb 64cf 64d2 64d7 64dc 64df
64e3 64e4 64e9 64ec 64f1 64f2 64f7 64fa
64ff 6500 6505 6508 650c 650d 6512 6515
651a 651b 6520 6523 6527 652b 652e 6531
6532 6534 6535 653a 653b 6540 6542 6546
6549 654b 654f 6551 655d 655f 6561 6562
6567 656b 656d 6579 657b 657f 6583 6586
658a 658d 6591 6594 6595 659a 659d 65a1
65a4 65a8 65ac 65b0 65b3 65b4 65b6 65b9
65bc 65bd 65c2 65c5 65c9 65cd 65d0 65d1
65d3 65d6 65d9 65da 65df 1 65e2 65e7
65eb 65ef 65f3 65f7 65fb 65ff 6603 6607
660b 660f 6613 6617 661b 661f 6623 6627
662b 662f 6633 6637 663b 663f 6643 6647
664b 664f 665b 665f 6663 6666 666a 666e
6670 1 6674 6678 667c 667f 6683 6687
668b 668f 6692 6696 669a 669d 66a0 66a5
66a8 66ab 66ae 66af 66b4 66b5 1 66b7
66bc 66c0 66c4 66c7 66cc 66d1 66d4 66d8
66d9 66de 66e1 66e6 66e7 66ec 66ef 66f4
66f5 66fa 66fd 6701 6702 6707 670a 670f
6710 6715 6718 671c 6720 6723 6726 6727
6729 672a 672f 6730 6735 6737 673b 673e
6740 6744 6746 6752 6754 6756 6757 675c
6760 6762 676e 6770 6772 6776 6779 677d
677f 6783 6787 678a 678e 6790 6794 6798
679b 679f 67a2 67a6 67a9 67aa 67af 67b2
67b6 67ba 67bd 67be 67c0 67c3 67c6 67c7
67cc 1 67cf 67d4 67d8 67dc 67e0 67e4
67e8 67ec 67f0 67f4 67f8 67fc 6800 6804
6808 680c 6810 6814 6818 681c 6820 6824
6828 682c 6830 6834 6838 683c 6848 684c
6850 6853 6857 685b 685d 1 6861 6865
6869 686c 6870 6874 6878 687c 687f 6883
6887 688a 688d 6892 6895 6898 689b 689c
68a1 68a2 1 68a4 68a9 68ad 68b1 68b4
68b9 68be 68c1 68c5 68c6 68cb 68ce 68d3
68d4 68d9 68dc 68e1 68e2 68e7 68ea 68ee
68ef 68f4 68f7 68fc 68fd 6902 6905 6909
690d 6910 6913 6914 6916 6917 691c 691d
6922 6924 6928 692b 692d 6931 6933 693f
6941 6943 6944 6949 694d 694f 695b 695d
695f 6963 6967 696a 696c 6970 6974 6978
697c 6980 6984 6988 698c 6990 6994 6998
699c 69a0 69a4 69a8 69ac 69b0 69b4 69b8
69bc 69c0 69c4 69c8 69cc 69d0 69d4 69d8
69dc 69e8 69ec 69f0 69f3 69f7 69fb 69fd
1 6a01 6a05 6a09 6a0c 6a10 6a14 6a18
6a1c 6a1f 6a23 6a27 6a2a 6a2d 6a32 6a35
6a38 6a3b 6a3c 6a41 6a42 1 6a44 6a49
6a4d 6a51 6a54 6a59 6a5e 6a61 6a65 6a66
6a6b 6a6e 6a73 6a74 6a79 6a7c 6a81 6a82
6a87 6a8a 6a8e 6a8f 6a94 6a97 6a9c 6a9d
6aa2 6aa5 6aa9 6aad 6ab0 6ab3 6ab4 6ab6
6ab7 6abc 6abd 6ac2 6ac4 6ac8 6acb 6acd
6ad1 6ad3 6adf 6ae1 6ae3 6ae4 6ae9 6aed
6aef 6afb 6afd 6aff 6b03 6b07 6b0a 6b0c
6b10 6b14 6b17 6b1a 6b1b 6b1d 6b20 6b25
6b26 6b2b 6b2f 6b33 6b37 6b3b 6b3f 6b43
6b47 6b4b 6b4f 6b53 6b57 6b5b 6b5f 6b63
6b67 6b6b 6b6f 6b73 6b77 6b7b 6b7f 6b83
6b87 6b8b 6b8f 6b93 6b97 6ba3 6ba7 6bab
6bae 6bb2 6bb6 6bb8 1 6bbc 6bc0 6bc4
6bc7 6bcb 6bcf 6bd3 6bd7 6bda 6bde 6be2
6be5 6be8 6bed 6bf0 6bf3 6bf6 6bf7 6bfc
6bfd 1 6bff 6c04 6c08 6c0c 6c0f 6c14
6c19 6c1c 6c20 6c21 6c26 6c29 6c2e 6c2f
6c34 6c37 6c3c 6c3d 6c42 6c45 6c49 6c4a
6c4f 6c52 6c57 6c58 6c5d 6c60 6c64 6c68
6c6b 6c6e 6c6f 6c71 6c72 6c77 6c78 6c7d
6c7f 6c83 6c86 6c88 6c8c 6c8e 6c9a 6c9c
6c9e 6c9f 6ca4 6ca8 6caa 6cb6 6cb8 6cbc
6cc0 6cc3 6cc7 6cca 6cce 6cd1 6cd2 6cd7
6cda 6cde 6ce2 6ce5 6ce6 6ce8 6ceb 6cee
6cef 6cf4 6cf7 6cfb 6cff 6d02 6d03 6d05
6d08 6d0b 6d0c 6d11 1 6d14 6d19 6d1d
6d21 6d25 6d29 6d2d 6d31 6d35 6d39 6d3d
6d41 6d45 6d49 6d4d 6d51 6d55 6d59 6d5d
6d61 6d65 6d69 6d6d 6d71 6d7d 6d81 6d85
6d88 6d8c 6d90 6d92 1 6d96 6d9a 6d9e
6da1 6da5 6da9 6dad 6db1 6db4 6db8 6dbc
6dbf 6dc2 6dc7 6dca 6dcd 6dd0 6dd1 6dd6
6dd7 1 6dd9 6dde 6de2 6de6 6de9 6dee
6df3 6df6 6dfa 6dfb 6e00 6e03 6e08 6e09
6e0e 6e11 6e16 6e17 6e1c 6e1f 6e23 6e24
6e29 6e2c 6e31 6e32 6e37 6e3a 6e3e 6e42
6e45 6e48 6e49 6e4b 6e4c 6e51 6e52 6e57
6e59 6e5d 6e60 6e62 6e66 6e68 6e74 6e76
6e78 6e79 6e7e 6e82 6e84 6e90 6e92 6e94
6e98 6e9b 6e9f 6ea1 6ea3 6ea7 6eab 6eae
6eb2 6eb4 6eb8 6ebc 6ebf 6ec3 6ec6 6eca
6ecd 6ece 6ed3 6ed6 6eda 6ede 6ee2 6ee6
6eea 6eee 6ef2 6ef6 6efa 6efe 6f02 6f06
6f0a 6f0e 6f12 6f16 6f1a 6f1e 6f22 6f26
6f2a 6f2e 6f32 6f36 6f3a 6f46 6f4a 6f4e
6f51 6f55 6f59 6f5b 1 6f5f 6f63 6f67
6f6a 6f6e 6f72 6f76 6f7a 6f7d 6f81 6f85
6f88 6f8b 6f90 6f93 6f96 6f99 6f9a 6f9f
6fa0 1 6fa2 6fa7 6fab 6faf 6fb2 6fb7
6fbc 6fbf 6fc3 6fc4 6fc9 6fcc 6fd1 6fd2
6fd7 6fda 6fdf 6fe0 6fe5 6fe8 6fec 6fed
6ff2 6ff5 6ffa 6ffb 7000 7003 7007 700b
700e 7011 7012 7014 7015 701a 701b 7020
7022 7026 7029 702b 702f 7031 703d 703f
7041 7042 7047 704b 704d 7059 705b 705d
7061 7065 7068 706a 706e 7072 7076 707a
707e 7082 7086 708a 708e 7092 7096 709a
709e 70a2 70a6 70aa 70ae 70b2 70b6 70ba
70be 70c2 70c6 70ca 70ce 70da 70de 70e2
70e5 70e9 70ed 70ef 1 70f3 70f7 70fb
70fe 7102 7106 710a 710e 7111 7115 7119
711c 711f 7124 7127 712a 712d 712e 7133
7134 1 7136 713b 713f 7143 7146 714b
7150 7153 7157 7158 715d 7160 7165 7166
716b 716e 7173 7174 7179 717c 7180 7181
7186 7189 718e 718f 7194 7197 719b 719f
71a2 71a5 71a6 71a8 71a9 71ae 71af 71b4
71b6 71ba 71bd 71bf 71c3 71c5 71d1 71d3
71d5 71d6 71db 71df 71e1 71ed 71ef 71f1
71f5 71f9 71fc 71fe 7202 7206 7209 720d
7211 7214 7218 721b 721f 7222 7223 7228
722b 722f 7233 7236 7237 7239 723c 723f
7240 7245 7249 724c 7250 7252 7256 7259
725a 725f 7262 7266 7269 726c 726d 7272
7276 7279 727d 7281 7285 7289 728d 7291
7295 7299 729d 72a1 72a5 72a9 72ad 72b1
72b5 72b9 72c5 72c9 72cd 72d0 72d4 72d8
72da 1 72de 72e2 72e6 72e9 72ed 72f1
72f5 72f9 72fc 7300 7304 7307 730a 730f
7312 7315 7318 7319 731e 731f 1 7321
7326 732a 732e 7331 7336 733b 733e 7342
7343 7348 734b 7350 7351 7356 7359 735e
735f 7364 7367 736b 736c 7371 7374 7379
737a 737f 7382 7386 738a 738d 7390 7391
7393 7394 7399 739a 739f 73a1 73a5 73a8
73aa 73ae 73b0 73bc 73be 73c0 73c1 73c6
73ca 73cc 73d8 73da 73dc 73e0 73e3 73e7
73eb 73ef 73f3 73f7 73fb 73ff 7403 7407
740b 740f 7413 7417 7423 7427 742b 742e
7432 7436 7438 1 743c 7440 7444 7447
744b 744f 7453 7457 745a 745e 7462 7465
7468 746d 7470 7473 7476 7477 747c 747d
1 747f 7484 7488 748c 748f 7494 7499
749c 74a0 74a1 74a6 74a9 74ae 74af 74b4
74b7 74bc 74bd 74c2 74c5 74c9 74ca 74cf
74d2 74d7 74d8 74dd 74e0 74e4 74e8 74eb
74ee 74ef 74f1 74f2 74f7 74f8 74fd 74ff
7503 7506 7508 750c 750e 751a 751c 751e
751f 7524 7528 752a 7536 7538 753a 753e
7542 7545 7549 754d 7550 7551 7553 7557
755a 755e 7561 7562 7564 7565 756a 756e
7572 7576 7579 757a 757c 757f 7582 7583
7588 758c 7590 7596 7598 759c 759f 75a1
75a5 75a8 75ac 75af 75b3 75b5 75b9 75bd
75c0 75c2 75c6 75ca 75ce 75d1 75d2 75d4
75d7 75da 75db 75e0 75e4 75e8 75ee 75f0
75f4 75f8 75fb 75ff 7603 7607 760b 760e
7612 7616 761a 761e 7622 7626 762a 762e
7632 7636 763a 7646 764a 764e 7651 7655
7659 765b 1 765f 7663 7667 766a 766e
7672 7676 767a 767d 7681 7685 7688 768b
7690 7693 7696 7699 769a 769f 76a0 1
76a2 76a7 76ab 76af 76b2 76b7 76bc 76bf
76c3 76c4 76c9 76cc 76d1 76d2 76d7 76da
76df 76e0 76e5 76e8 76ec 76ed 76f2 76f5
76fa 76fb 7700 7703 7707 770b 770e 7711
7712 7714 7715 771a 771b 7720 7722 7726
7729 772b 772f 7731 773d 773f 7741 7742
7747 774b 774d 7759 775b 775f 7763 7767
776b 776f 7773 7777 777b 777f 7783 778f
7793 7797 779a 779e 77a2 77a4 1 77a8
77ac 77b0 77b3 77b7 77bb 77bf 77c3 77c6
77ca 77ce 77d1 77d4 77d9 77dc 77df 77e2
77e3 77e8 77e9 1 77eb 77f0 77f4 77f8
77fb 7800 7805 7808 780c 780d 7812 7815
781a 781b 7820 7823 7828 7829 782e 7831
7835 7836 783b 783e 7843 7844 7849 784c
7850 7854 7857 785a 785b 785d 785e 7863
7864 7869 786b 786f 7872 7874 7878 787a
7886 7888 788a 788b 7890 7894 7896 78a2
78a4 78a8 78ab 78af 78b3 78b7 78bb 78bf
78c3 78c6 78c7 78c9 78cc 78cf 78d0 78d5
78d9 78dc 78e0 78e2 78e6 78e9 78ed 78f1
78f5 78f9 78fd 7901 7905 7909 790d 7911
7915 7919 791d 7921 7925 7929 792d 7931
7935 7939 793d 7941 7945 7949 794d 7951
7955 7959 795d 7961 7964 7967 796a 796d
796e 7970 7974 7978 797b 797e 797f 7984
7988 798c 798f 7990 7992 7995 7998 7999
799e 79a2 79a6 79aa 79ae 79ba 79be 79c3
79c7 79ca 79cb 79d0 79d4 79d8 79db 79de
79e2 79e4 79e8 79ec 79ef 79f2 79f6 79f8
79fc 7a00 7a03 7a05 1 7a09 7a0d 7a11
7a14 7a18 7a1c 7a20 7a24 7a27 7a2b 7a2f
7a32 7a35 7a3a 7a3d 7a40 7a43 7a44 7a49
7a4a 1 7a4c 7a51 7a55 7a59 7a5c 7a61
7a66 7a69 7a6d 7a6e 7a73 7a76 7a7b 7a7c
7a81 7a84 7a89 7a8a 7a8f 7a92 7a96 7a97
7a9c 7a9f 7aa4 7aa5 7aaa 7aad 7ab1 7ab5
7ab8 7abb 7abc 7abe 7abf 7ac4 7ac5 7aca
7acc 7ad0 7ad3 7ad5 7ad9 7adb 7ae7 7ae9
7aeb 7aec 7af1 7af5 7af7 7b03 7b05 7b07
7b0b 7b0f 7b13 7b17 7b23 7b27 7b2c 7b30
7b33 7b34 7b39 7b3d 7b41 7b44 7b47 7b4b
7b4d 7b51 7b55 7b58 7b5b 7b5f 7b61 7b65
7b69 7b6c 7b6e 1 7b72 7b76 7b7a 7b7d
7b81 7b85 7b89 7b8d 7b90 7b94 7b98 7b9b
7b9e 7ba3 7ba6 7ba9 7bac 7bad 7bb2 7bb3
1 7bb5 7bba 7bbe 7bc2 7bc5 7bca 7bcf
7bd2 7bd6 7bd7 7bdc 7bdf 7be4 7be5 7bea
7bed 7bf2 7bf3 7bf8 7bfb 7bff 7c00 7c05
7c08 7c0d 7c0e 7c13 7c16 7c1a 7c1e 7c21
7c24 7c25 7c27 7c28 7c2d 7c2e 7c33 7c35
7c39 7c3c 7c3e 7c42 7c44 7c50 7c52 7c54
7c55 7c5a 7c5e 7c60 7c6c 7c6e 7c70 7c74
7c78 7c7b 7c7d 7c81 7c84 7c88 7c8a 7c8e
7c92 7c95 7c96 7c98 7c9b 7c9e 7c9f 7ca4
7ca8 7cac 7cb0 7cb4 7cb8 7cbc 7cc0 7cc4
7cc7 7cca 7ccb 7ccd 7cd0 7cd5 7cd6 7cdb
7cdf 7ce3 7ce7 7cea 7cee 7cf0 7cf4 7cf8
7cfc 7cff 7d00 7d02 7d06 7d08 7d0c 7d10
7d13 7d17 7d1b 7d1f 7d23 7d27 7d2b 7d2f
7d33 7d37 7d3b 7d3f 7d43 7d47 7d4b 7d4f
7d53 7d57 7d5b 7d5f 7d63 7d67 7d6b 7d6f
7d73 7d77 7d7b 7d7f 7d83 7d87 7d8b 7d8e
7d91 7d94 7d97 7d98 7d9a 7d9e 7da2 7da5
7da8 7da9 7dae 7db2 7db6 7dba 7dbe 7dca
7dce 7dd3 7dd7 7dda 7ddb 7de0 7de4 7de8
7deb 7dee 7df2 7df4 7df8 7dfc 7dff 7e02
7e06 7e08 7e0c 7e10 7e13 7e15 1 7e19
7e1d 7e21 7e24 7e28 7e2c 7e30 7e34 7e37
7e3b 7e3f 7e42 7e45 7e4a 7e4d 7e50 7e53
7e54 7e59 7e5a 1 7e5c 7e61 7e65 7e69
7e6c 7e71 7e76 7e79 7e7d 7e7e 7e83 7e86
7e8b 7e8c 7e91 7e94 7e99 7e9a 7e9f 7ea2
7ea6 7ea7 7eac 7eaf 7eb4 7eb5 7eba 7ebd
7ec1 7ec5 7ec8 7ecb 7ecc 7ece 7ecf 7ed4
7ed5 7eda 7edc 7ee0 7ee3 7ee5 7ee9 7eeb
7ef7 7ef9 7efb 7efc 7f01 7f05 7f07 7f13
7f15 7f17 7f1b 7f1e 7f20 7f24 7f28 7f2b
7f2f 7f33 7f37 7f3a 7f3b 7f3d 7f40 7f43
7f44 7f49 7f4d 7f55 7f57 7f58 7f5b 7f5d
7f61 7f68 7f6a 7f6e 7f71 7f73 7f77 7f7b
7f7e 7f82 7f85 7f88 7f89 7f8e 7f91 7f95
7f99 7f9c 7f9d 7f9f 7fa2 7fa5 7fa6 7fab
1 7fae 7fb3 7fb7 7fbb 7fbe 7fbf 7fc1
7fc4 7fc7 7fc8 7fcd 7fd1 7fd5 7fd9 7fe5
7fe9 7fee 7ff2 7ff5 7ff6 7ffb 7fff 8003
8006 8009 800d 800f 8013 8017 801a 801d
8021 8023 8027 802b 802e 8030 1 8034
8038 803c 803f 8043 8047 804b 804f 8052
8056 805a 805d 8060 8065 8068 806b 806e
806f 8074 8075 1 8077 807c 8080 8084
8087 808c 8091 8094 8098 8099 809e 80a1
80a6 80a7 80ac 80af 80b4 80b5 80ba 80bd
80c1 80c2 80c7 80ca 80cf 80d0 80d5 80d8
80dc 80e0 80e3 80e6 80e7 80e9 80ea 80ef
80f0 80f5 80f7 80fb 80fe 8100 8104 8106
8112 8114 8116 8117 811c 8120 8122 812e
8130 8132 8136 813a 813e 8142 8146 814a
814e 815a 815e 8163 8167 816a 816b 8170
8174 8178 817b 817e 8182 8184 8188 818c
818f 8192 8196 8198 819c 81a0 81a3 81a5
1 81a9 81ad 81b1 81b4 81b8 81bc 81c0
81c4 81c7 81cb 81cf 81d2 81d5 81da 81dd
81e0 81e3 81e4 81e9 81ea 1 81ec 81f1
81f5 81f9 81fc 8201 8206 8209 820d 820e
8213 8216 821b 821c 8221 8224 8229 822a
822f 8232 8236 8237 823c 823f 8244 8245
824a 824d 8251 8255 8258 825b 825c 825e
825f 8264 8265 826a 826c 8270 8273 8275
8279 827b 8287 8289 828b 828c 8291 8295
8297 82a3 82a5 82a7 82ab 82af 82b2 82b6
82b9 82bc 82bd 82c2 82c6 82ca 82cd 82d1
82d5 82d8 82db 82e0 82e3 82e6 82e9 82ea
82ef 82f0 1 82f2 82f7 82fb 82ff 8302
8307 830c 830f 8313 8314 8319 831c 8321
8322 8327 832a 832f 8330 8335 8338 833c
8340 8344 8348 834b 834c 834e 8353 8354
8356 8357 835c 835f 8364 8365 836a 836d
8372 8373 8378 837b 837f 8380 8385 8388
838d 838e 8393 8394 8399 839b 839f 83a2
83a6 83aa 83ad 83b1 83b5 83b8 83bb 83c0
83c3 83c6 83c9 83ca 83cf 83d0 1 83d2
83d7 83db 83df 83e2 83e7 83ec 83ef 83f3
83f4 83f9 83fa 83ff 8401 8405 8408 840c
8410 8413 8417 841b 841e 8422 8426 8427
842c 8430 8432 8436 843a 843d 8441 8444
8445 844a 844e 8452 8455 8459 845d 8460
8463 8468 846b 846e 8471 8472 8477 8478
1 847a 847f 8483 8487 848a 848f 8494
8497 849b 849c 84a1 84a4 84a9 84aa 84af
84b2 84b7 84b8 84bd 84c0 84c4 84c8 84cc
84d0 84d3 84d4 84d6 84db 84dc 84de 84df
84e4 84e7 84ec 84ed 84f2 84f5 84fa 84fb
8500 8503 8507 8508 850d 8510 8515 8516
851b 851c 8521 8523 8527 852a 852e 8532
8535 8539 853d 8540 8543 8548 854b 854e
8551 8552 8557 8558 1 855a 855f 8563
8567 856a 856f 8574 8577 857b 857c 8581
8582 8587 8589 858d 8590 8594 8598 859b
859f 85a3 85a6 85aa 85ae 85af 85b4 85b8
85ba 85be 85c2 85c6 85c9 85cd 85d0 85d1
85d6 85da 85de 85e1 85e5 85e9 85ec 85ef
85f4 85f7 85fa 85fd 85fe 8603 8604 1
8606 860b 860f 8613 8616 861b 8620 8623
8627 8628 862d 8630 8635 8636 863b 863e
8643 8644 8649 864c 8650 8654 8658 865c
865f 8660 8662 8667 8668 866a 866b 8670
8673 8678 8679 867e 8681 8686 8687 868c
868f 8693 8694 8699 869c 86a1 86a2 86a7
86a8 86ad 86af 86b3 86b6 86ba 86be 86c1
86c5 86c9 86cc 86cf 86d4 86d7 86da 86dd
86de 86e3 86e4 1 86e6 86eb 86ef 86f3
86f6 86fb 8700 8703 8707 8708 870d 870e
8713 8715 8719 871c 8720 8724 8727 872b
872f 8732 8736 873a 873b 8740 8742 8746
874a 874e 8751 8755 8759 875c 875f 8764
8767 876a 876d 876e 8773 8774 1 8776
877b 877f 8783 8786 878b 8790 8793 8797
8798 879d 87a0 87a5 87a6 87ab 87ae 87b3
87b4 87b9 87bc 87c0 87c4 87c8 87cc 87cf
87d0 87d2 87d7 87d8 87da 87db 87e0 87e3
87e8 87e9 87ee 87f1 87f6 87f7 87fc 87ff
8803 8804 8809 880c 8811 8812 8817 8818
881d 881f 8823 8826 882a 882e 8831 8835
8839 883c 883f 8844 8847 884a 884d 884e
8853 8854 1 8856 885b 885f 8863 8866
886b 8870 8873 8877 8878 887d 887e 8883
8885 8889 888c 8890 8894 8897 889b 889f
88a2 88a6 88aa 88ab 88b0 88b2 88b6 88ba
88bd 88bf 88c3 88c6 88ca 88ce 88d2 88d3
88d5 88d8 88d9 88db 88de 88e1 88e2 88e7
88ea 88ee 88f2 88f6 88f7 88f9 88fc 88fd
88ff 8902 8905 8906 890b 1 890e 8913
8917 891b 8920 8925 8929 892d 8931 8934
8937 893b 893f 8944 8947 894c 894d 8952
8955 895a 895b 8960 8963 8968 8969 896e
8971 8976 8977 897c 897f 8984 8985 898a
898d 8991 8992 8997 899a 899f 89a0 89a5
89a8 89ad 89ae 89b3 89b6 89ba 89bb 89c0
89c3 89c8 89c9 89ce 89d1 89d5 89d6 89db
89de 89e3 89e4 89e9 89ed 89f1 89f5 89f9
89fe 8a02 8a06 8a0b 8a0f 8a12 8a13 8a18
8a1c 8a20 8a23 8a26 8a2a 8a2c 8a30 8a34
8a37 8a3a 8a3e 8a40 8a44 8a48 8a4b 8a4d
1 8a51 8a55 8a59 8a5c 8a60 8a64 8a68
8a6c 8a6f 8a73 8a77 8a7a 8a7d 8a82 8a85
8a88 8a8b 8a8c 8a91 8a92 1 8a94 8a99
8a9d 8aa1 8aa4 8aa9 8aae 8ab1 8ab5 8ab6
8abb 8abe 8ac3 8ac4 8ac9 8acc 8ad1 8ad2
8ad7 8ada 8ade 8adf 8ae4 8ae7 8aec 8aed
8af2 8af5 8af9 8afd 8b00 8b03 8b04 8b06
8b07 8b0c 8b0d 8b12 8b16 8b1a 8b1d 8b22
8b27 8b2a 8b2e 8b2f 8b34 8b35 8b3a 8b3c
8b40 8b43 8b45 8b49 8b4b 8b57 8b59 8b5b
8b5c 8b61 8b65 8b67 8b73 8b75 8b79 8b7d
8b82 8b87 8b8b 8b8f 8b93 8b96 8b99 8b9d
8ba1 8ba6 8ba9 8bae 8baf 8bb4 8bb7 8bbc
8bbd 8bc2 8bc5 8bca 8bcb 8bd0 8bd3 8bd8
8bd9 8bde 8be1 8be6 8be7 8bec 8bef 8bf3
8bf4 8bf9 8bfc 8c01 8c02 8c07 8c0a 8c0f
8c10 8c15 8c18 8c1c 8c1d 8c22 8c25 8c2a
8c2b 8c30 8c33 8c37 8c38 8c3d 8c40 8c45
8c46 8c4b 8c4f 8c53 8c57 8c5b 8c60 8c64
8c68 8c6d 8c71 8c74 8c75 8c7a 8c7e 8c82
8c85 8c88 8c8c 8c8e 8c92 8c96 8c99 8c9c
8ca0 8ca2 8ca6 8caa 8cad 8caf 1 8cb3
8cb7 8cbb 8cbe 8cc2 8cc6 8cca 8cce 8cd1
8cd5 8cd9 8cdc 8cdf 8ce4 8ce7 8cea 8ced
8cee 8cf3 8cf4 1 8cf6 8cfb 8cff 8d03
8d06 8d0b 8d10 8d13 8d17 8d18 8d1d 8d20
8d25 8d26 8d2b 8d2e 8d33 8d34 8d39 8d3c
8d40 8d41 8d46 8d49 8d4e 8d4f 8d54 8d57
8d5b 8d5f 8d62 8d65 8d66 8d68 8d69 8d6e
8d6f 8d74 8d78 8d7c 8d7f 8d84 8d89 8d8c
8d90 8d91 8d96 8d97 8d9c 8d9e 8da2 8da5
8da7 8dab 8dad 8db9 8dbb 8dbd 8dbe 8dc3
8dc7 8dc9 8dd5 8dd7 8ddb 8ddf 8de2 8de6
8de7 8dec 8df0 8df4 8df9 8dfc 8e01 8e02
8e07 8e0a 8e0f 8e10 8e15 8e18 8e1d 8e1e
8e23 8e26 8e2b 8e2c 8e31 8e34 8e39 8e3a
8e3f 8e42 8e47 8e48 8e4d 8e50 8e55 8e56
8e5b 8e5e 8e63 8e64 8e69 8e6c 8e71 8e72
8e77 8e7a 8e7f 8e80 8e85 8e88 8e8d 8e8e
8e93 8e96 8e9b 8e9c 8ea1 8ea4 8ea8 8ea9
8eae 8eb1 8eb6 8eb7 8ebc 8ebf 8ec4 8ec5
8eca 8ecd 8ed1 8ed2 8ed7 8eda 8edf 8ee0
8ee5 8ee8 8eed 8eee 8ef3 8ef6 8efb 8efc
8f01 8f04 8f08 8f09 8f0e 8f11 8f16 8f17
8f1c 8f1f 8f24 8f25 8f2a 8f2d 8f32 8f33
8f38 8f3b 8f40 8f41 8f46 8f49 8f4e 8f4f
8f54 8f57 8f5c 8f5d 8f62 8f65 8f6a 8f6b
8f70 8f73 8f78 8f79 8f7e 8f81 8f86 8f87
8f8c 8f8f 8f93 8f94 8f99 8f9c 8fa1 8fa2
8fa7 8faa 8faf 8fb0 8fb5 8fb8 8fbd 8fbe
8fc3 8fc6 8fcb 8fcc 8fd1 8fd4 8fd9 8fda
8fdf 8fe2 8fe6 8fe7 8fec 8fef 8ff4 8ff5
8ffa 8ffd 9002 9003 9008 900c 9010 9014
9018 901d 9021 9025 902a 902e 9031 9032
9037 903b 903f 9042 9045 9049 904b 904f
9053 9056 9059 905d 905f 9063 9067 906a
906c 1 9070 9074 9078 907b 907f 9083
9087 908b 908e 9092 9096 9099 909c 90a1
90a4 90a7 90aa 90ab 90b0 90b1 1 90b3
90b8 90bc 90c0 90c3 90c8 90cd 90d0 90d4
90d5 90da 90dd 90e2 90e3 90e8 90eb 90f0
90f1 90f6 90f9 90fd 90fe 9103 9106 910b
910c 9111 9114 9118 911c 911f 9122 9123
9125 9126 912b 912c 9131 9135 9139 913c
9141 9146 9149 914d 914e 9153 9154 9159
915b 915f 9162 9164 9168 916a 9176 9178
917a 917b 9180 9184 9186 9192 9194 9198
919d 91a0 91a5 91a6 91ab 91ae 91b3 91b4
91b9 91bc 91c1 91c2 91c7 91ca 91ce 91d2
91d6 91d9 91da 91dc 91dd 91df 91e0 91e5
91e8 91ed 91ee 91f3 91f6 91fb 91fc 9201
9204 9208 920c 9210 9213 9214 9216 9217
9219 921a 921f 9222 9227 9228 922d 9230
9235 9236 923b 923e 9243 9244 9249 924c
9251 9252 9257 925a 925f 9260 9265 9268
926d 926e 9273 9276 927b 927c 9281 9284
9289 928a 928f 9292 9297 9298 929d 92a0
92a4 92a8 92ac 92af 92b0 92b2 92b3 92b5
92b6 92bb 92be 92c3 92c4 92c9 92cc 92d1
92d2 92d7 92da 92de 92e2 92e6 92e9 92ea
92ec 92ed 92ef 92f0 92f5 92f8 92fd 92fe
9303 9306 930b 930c 9311 9314 9319 931a
931f 9322 9327 9328 932d 9330 9335 9336
933b 933f 9343 9345 9349 934d 9351 9352
9354 9357 9358 935a 935d 9360 9361 9366
936a 936e 9373 9378 937c 9380 9384 9387
938a 938e 9392 9397 939a 939f 93a0 93a5
93a8 93ad 93ae 93b3 93b6 93bb 93bc 93c1
93c4 93c9 93ca 93cf 93d2 93d7 93d8 93dd
93e0 93e4 93e5 93ea 93ed 93f2 93f3 93f8
93fb 9400 9401 9406 9409 940d 940e 9413
9416 941b 941c 9421 9425 9429 942d 9431
9436 943a 943e 9443 9447 944a 944b 9450
9454 9458 945b 945e 9462 9464 9468 946c
946f 9472 9476 9478 947c 9480 9483 9485
1 9489 948d 9491 9494 9498 949c 94a0
94a4 94a7 94ab 94af 94b2 94b5 94ba 94bd
94c0 94c3 94c4 94c9 94ca 1 94cc 94d1
94d5 94d9 94dc 94e1 94e6 94e9 94ed 94ee
94f3 94f6 94fb 94fc 9501 9504 9509 950a
950f 9512 9516 9517 951c 951f 9524 9525
952a 952d 9531 9535 9538 953b 953c 953e
953f 9544 9545 954a 954e 9552 9555 955a
955f 9562 9566 9567 956c 956d 9572 9574
9578 957b 957d 9581 9583 958f 9591 9593
9594 9599 959d 959f 95ab 95ad 95b1 95b5
95ba 95bf 95c3 95c7 95cb 95ce 95d1 95d5
95d9 95de 95e1 95e6 95e7 95ec 95ef 95f4
95f5 95fa 95fd 9602 9603 9608 960b 9610
9611 9616 9619 961e 961f 9624 9627 962b
962c 9631 9634 9639 963a 963f 9642 9646
9647 964c 964f 9654 9655 965a 965e 9662
9666 966a 966f 9673 9677 967c 9680 9683
9684 9689 968d 9691 9694 9697 969b 969d
96a1 96a5 96a8 96ab 96af 96b1 96b5 96b9
96bc 96be 1 96c2 96c6 96ca 96cd 96d1
96d5 96d9 96dd 96e0 96e4 96e8 96eb 96ee
96f3 96f6 96f9 96fc 96fd 9702 9703 1
9705 970a 970e 9712 9715 971a 971f 9722
9726 9727 972c 972f 9734 9735 973a 973d
9742 9743 9748 974b 974f 9750 9755 9758
975d 975e 9763 9766 976a 976e 9771 9774
9775 9777 9778 977d 977e 9783 9787 978b
978e 9793 9798 979b 979f 97a0 97a5 97a6
97ab 97ad 97b1 97b4 97b6 97ba 97bc 97c8
97ca 97cc 97cd 97d2 97d6 97d8 97e4 97e6
97ea 97ee 97f1 97f5 97f6 97fb 97ff 9803
9808 980b 9810 9811 9816 9819 981e 981f
9824 9827 982c 982d 9832 9835 983a 983b
9840 9843 9848 9849 984e 9851 9856 9857
985c 985f 9864 9865 986a 986d 9872 9873
9878 987b 9880 9881 9886 9889 988d 988e
9893 9896 989b 989c 98a1 98a4 98a9 98aa
98af 98b2 98b6 98b7 98bc 98bf 98c4 98c5
98ca 98cd 98d2 98d3 98d8 98db 98e0 98e1
98e6 98e9 98ed 98ee 98f3 98f6 98fb 98fc
9901 9905 9909 990d 9911 9916 991a 991e
9923 9927 992a 992b 9930 9934 9938 993b
993e 9942 9944 9948 994c 994f 9952 9956
9958 995c 9960 9963 9965 1 9969 996d
9971 9974 9978 997c 9980 9984 9987 998b
998f 9992 9995 999a 999d 99a0 99a3 99a4
99a9 99aa 1 99ac 99b1 99b5 99b9 99bc
99c1 99c6 99c9 99cd 99ce 99d3 99d6 99db
99dc 99e1 99e4 99e9 99ea 99ef 99f2 99f6
99f7 99fc 99ff 9a04 9a05 9a0a 9a0d 9a11
9a15 9a18 9a1b 9a1c 9a1e 9a1f 9a24 9a25
9a2a 9a2e 9a32 9a35 9a3a 9a3f 9a42 9a46
9a47 9a4c 9a4d 9a52 9a54 9a58 9a5b 9a5d
9a61 9a63 9a6f 9a71 9a73 9a74 9a79 9a7d
9a7f 9a8b 9a8d 9a91 9a96 9a99 9a9e 9a9f
9aa4 9aa7 9aac 9aad 9ab2 9ab5 9aba 9abb
9ac0 9ac3 9ac7 9acb 9acf 9ad2 9ad3 9ad5
9ad6 9ad8 9ad9 9ade 9ae1 9ae6 9ae7 9aec
9aef 9af3 9af7 9afb 9afe 9aff 9b01 9b02
9b04 9b05 9b0a 9b0d 9b12 9b13 9b18 9b1b
9b20 9b21 9b26 9b29 9b2e 9b2f 9b34 9b37
9b3c 9b3d 9b42 9b45 9b4a 9b4b 9b50 9b54
9b56 9b5a 9b5e 9b62 9b67 9b6c 9b70 9b74
9b78 9b7b 9b7e 9b82 9b86 9b8b 9b8e 9b93
9b94 9b99 9b9c 9ba1 9ba2 9ba7 9baa 9baf
9bb0 9bb5 9bb8 9bbd 9bbe 9bc3 9bc6 9bcb
9bcc 9bd1 9bd4 9bd9 9bda 9bdf 9be2 9be6
9be7 9bec 9bef 9bf4 9bf5 9bfa 9bfd 9c02
9c03 9c08 9c0b 9c0f 9c10 9c15 9c18 9c1d
9c1e 9c23 9c26 9c2b 9c2c 9c31 9c35 9c39
9c3d 9c41 9c46 9c4a 9c4e 9c53 9c57 9c5a
9c5b 9c60 9c64 9c68 9c6b 9c6e 9c72 9c74
9c78 9c7c 9c7f 9c82 9c86 9c88 9c8c 9c90
9c93 9c95 1 9c99 9c9d 9ca1 9ca4 9ca8
9cac 9cb0 9cb4 9cb7 9cbb 9cbf 9cc2 9cc5
9cca 9ccd 9cd0 9cd3 9cd4 9cd9 9cda 1
9cdc 9ce1 9ce5 9ce9 9cec 9cf1 9cf6 9cf9
9cfd 9cfe 9d03 9d06 9d0b 9d0c 9d11 9d14
9d19 9d1a 9d1f 9d22 9d26 9d27 9d2c 9d2f
9d34 9d35 9d3a 9d3d 9d41 9d45 9d48 9d4b
9d4c 9d4e 9d4f 9d54 9d55 9d5a 9d5e 9d62
9d65 9d6a 9d6f 9d72 9d76 9d77 9d7c 9d7d
9d82 9d84 9d88 9d8b 9d8d 9d91 9d93 9d9f
9da1 9da3 9da4 9da9 9dad 9daf 9dbb 9dbd
9dc1 9dc5 9dca 9dcf 9dd3 9dd7 9ddb 9dde
9de1 9de5 9de9 9dee 9df1 9df6 9df7 9dfc
9dff 9e04 9e05 9e0a 9e0d 9e12 9e13 9e18
9e1b 9e20 9e21 9e26 9e29 9e2e 9e2f 9e34
9e37 9e3b 9e3c 9e41 9e44 9e49 9e4a 9e4f
9e52 9e56 9e57 9e5c 9e5f 9e64 9e65 9e6a
9e6e 9e72 9e76 9e7a 9e7f 9e83 9e87 9e8c
9e90 9e93 9e94 9e99 9e9d 9ea1 9ea4 9ea7
9eab 9ead 9eb1 9eb5 9eb8 9ebb 9ebf 9ec1
9ec5 9ec9 9ecc 9ece 1 9ed2 9ed6 9eda
9edd 9ee1 9ee5 9ee9 9eed 9ef0 9ef4 9ef8
9efb 9efe 9f03 9f06 9f09 9f0c 9f0d 9f12
9f13 1 9f15 9f1a 9f1e 9f22 9f25 9f2a
9f2f 9f32 9f36 9f37 9f3c 9f3f 9f44 9f45
9f4a 9f4d 9f52 9f53 9f58 9f5b 9f5f 9f60
9f65 9f68 9f6d 9f6e 9f73 9f76 9f7a 9f7e
9f81 9f84 9f85 9f87 9f88 9f8d 9f8e 9f93
9f97 9f9b 9f9e 9fa3 9fa8 9fab 9faf 9fb0
9fb5 9fb6 9fbb 9fbd 9fc1 9fc4 9fc6 9fca
9fcc 9fd8 9fda 9fdc 9fdd 9fe2 9fe6 9fe8
9ff4 9ff6 9ffa 9ffe a001 a005 a006 a00b
a00f a013 a018 a01b a020 a021 a026 a029
a02e a02f a034 a037 a03c a03d a042 a045
a04a a04b a050 a053 a058 a059 a05e a061
a066 a067 a06c a06f a074 a075 a07a a07d
a082 a083 a088 a08b a090 a091 a096 a099
a09d a09e a0a3 a0a6 a0ab a0ac a0b1 a0b4
a0b9 a0ba a0bf a0c2 a0c7 a0c8 a0cd a0d0
a0d5 a0d6 a0db a0de a0e2 a0e3 a0e8 a0eb
a0f0 a0f1 a0f6 a0fa a0fe a102 a106 a10b
a10f a113 a118 a11c a11f a120 a125 a129
a12d a130 a133 a137 a139 a13d a141 a144
a147 a14b a14d a151 a155 a158 a15a 1
a15e a162 a166 a169 a16d a171 a175 a179
a17c a180 a184 a187 a18a a18f a192 a195
a198 a199 a19e a19f 1 a1a1 a1a6 a1aa
a1ae a1b1 a1b6 a1bb a1be a1c2 a1c3 a1c8
a1cb a1d0 a1d1 a1d6 a1d9 a1de a1df a1e4
a1e7 a1eb a1ec a1f1 a1f4 a1f9 a1fa a1ff
a202 a206 a20a a20d a210 a211 a213 a214
a219 a21a a21f a223 a227 a22a a22f a234
a237 a23b a23c a241 a242 a247 a249 a24d
a250 a252 a256 a258 a264 a266 a268 a269
a26e a272 a274 a280 a282 a286 a28b a28e
a293 a294 a299 a29c a2a1 a2a2 a2a7 a2aa
a2af a2b0 a2b5 a2b8 a2bc a2c0 a2c4 a2c7
a2c8 a2ca a2cb a2cd a2ce a2d3 a2d6 a2db
a2dc a2e1 a2e4 a2e9 a2ea a2ef a2f2 a2f6
a2fa a2fe a301 a302 a304 a305 a307 a308
a30d a310 a315 a316 a31b a31e a323 a324
a329 a32c a331 a332 a337 a33a a33f a340
a345 a348 a34d a34e a353 a357 a359 a35d
a361 a364 a368 a36c a36f a373 a377 a37a
a37d a382 a385 a388 a38b a38c a391 a392
1 a394 a399 a39d a3a1 a3a4 a3a9 a3ae
a3b1 a3b5 a3b6 a3bb a3bc a3c1 a3c3 a3c7
a3ca a3ce a3d2 a3d5 a3d9 a3dd a3e0 a3e3
a3e8 a3eb a3ee a3f1 a3f2 a3f7 a3f8 1
a3fa a3ff a403 a407 a40a a40f a414 a417
a41b a41c a421 a422 a427 a429 a42d a430
a434 a438 a43c a43f a443 a444 a446 a44a
a44c a450 a454 a457 a45b a45f a462 a466
a46a a46d a470 a475 a478 a47b a47e a47f
a484 a485 1 a487 a48c a490 a494 a497
a49c a4a1 a4a4 a4a8 a4a9 a4ae a4af a4b4
a4b8 a4bc a4bf a4c4 a4c9 a4cc a4d0 a4d4
a4d7 a4d8 a4dd a4e0 a4e5 a4e6 a4eb a4ee
a4f2 a4f6 a4f9 a4fa a4ff a500 a505 a507
a50b a50e a512 a516 a51a a51e a522 a526
a52a a52e a532 a53e a543 a547 a54b a54f
a553 a555 a556 a55b 1 a55f a563 a567
a56a a56e a572 a576 a57a a57d a581 a585
a588 a58b a590 a593 a596 a599 a59a a59f
a5a0 1 a5a2 a5a7 a5ab a5af a5b2 a5b7
a5bc a5bf a5c3 a5c4 a5c9 a5ca a5cf a5d3
a5d7 a5da a5df a5e4 a5e7 a5eb a5ec a5f1
a5f4 a5f9 a5fa a5ff a602 a606 a60a a60d
a610 a611 a613 a614 a619 a61a a61f a621
a625 a628 a62c a630 a634 a638 a63c a640
a644 a650 a655 a659 a65d a661 a665 a667
a66b a66d a679 a67b a67d a67e a683 a687
a689 a695 a699 a69b a69c a6a5 
2fe6
2
0 1 a 6 d :3 6 14 :3 6
15 :3 6 10 :3 6 e :3 6 11 :3 6
c :3 6 b :3 6 11 :3 6 11 :3 6
1d :3 6 10 :3 6 e :3 6 10 :3 6
12 :2 6 1 3 a 13 a :2 1
4 11 1a 19 :2 11 :2 4 14 1d
1c :2 14 :2 4 e 17 16 :2 e :2 4
f 18 17 :2 f :2 4 f 18 17
:2 f :2 4 d 16 15 :2 d :2 4 12
1b 1a :2 12 :2 4 11 1a 19 :2 11
:2 4 f 18 17 :2 f :2 4 10 19
18 :2 10 :2 4 :3 10 :2 4 :3 f :2 4 f
18 17 :2 f :2 4 10 19 18 :2 10
:2 4 10 19 18 :2 10 :2 4 f 18
17 :2 f :2 4 10 19 18 :2 10 :2 4
10 19 18 :2 10 :2 4 :2 c 1b c
:2 4 :2 e 1d e :2 4 :2 b 1a b
:2 4 :2 10 1f 10 :2 4 :2 a 19 a
:2 4 :2 b 1a b :2 4 :2 11 20 11
:2 4 :2 d 1c d :2 4 :2 c 1b c
:2 4 :2 b 1a b :2 4 :2 f 1e f
:2 4 :2 e 1d e :2 4 :2 c 1b c
:2 4 :2 e 1d e :2 4 :2 f 1e f
:2 4 :2 d 1c d :2 4 :2 b 1a b
:2 4 :2 f 1e f :2 4 :2 12 21 12
:2 4 :2 f 1e f :2 4 :2 c 1b c
:2 4 :2 c 1b c :2 4 :2 f 1e f
:2 4 :2 11 20 11 :2 4 :2 11 20 11
:2 4 :2 16 25 16 :2 4 :2 16 25 16
:2 4 :2 b 1a b :2 4 d 16 15
:2 d :2 4 11 1a 19 :2 11 :2 4 :2 f
19 f :2 4 9 12 11 :2 9 :2 4
:2 17 26 17 :2 4 17 1c 1b :2 17
:2 4 18 1d 1c :2 18 :2 4 16 1f
1e :2 16 :2 4 :2 13 22 13 :2 4 :2 14
23 14 :2 4 :2 11 20 11 :2 4 14
1d 1c :2 14 :2 4 15 1e 1d :2 15
:2 4 :2 10 1f 10 :2 4 :2 f 1e f
:2 4 a 13 12 :2 a :2 4 :2 6 1e
6 :2 4 :2 7 1f 7 :2 4 :2 d 25
d :2 4 :2 8 20 8 :2 4 :3 d :2 4
e 17 :3 e 4 7 :2 11 23 :2 2d
3a :2 23 :3 7 :2 d 19 25 :2 2f 43
:2 25 53 59 5c :2 53 6a 7f 8
:2 6a d 10 :2 6a 17 1a :2 6a b
e :2 6a 13 16 :2 6a 1b 1e :2 6a
2c 2f :2 6a b e :2 6a 13 16
:2 6a 1b 1e :2 6a 2d 30 :2 6a b
e :2 6a 13 16 1f 27 :2 1f 33
:2 16 :2 6a b e :2 6a 13 16 1f
27 :2 1f 31 :2 16 :2 6a b e :2 6a
13 16 1f 27 :2 1f 34 :2 16 :2 6a
b e :2 6a 13 16 1f 27 :2 1f
2f :2 16 :2 6a b e :2 6a 13 16
1f 27 :2 1f 2e :2 16 :2 6a b e
:2 6a 13 16 1f 27 :2 1f 34 :2 16
:2 6a b e :2 6a 13 16 1f 27
:2 1f 34 :2 16 :2 6a b e :2 6a 13
16 1f 27 :2 1f 40 :2 16 :2 6a b
e :2 6a 13 16 1f 27 :2 1f 33
:2 16 :2 6a b e :2 6a 13 16 1f
27 :2 1f 31 :2 16 :2 6a b e :2 6a
13 16 :2 6a 1b 1e :2 6a 28 2b
:2 6a b e :2 6a 13 16 :2 6a 1b
1e :2 6a 2a 2d :2 6a 32 35 :2 6a
:2 7 49 :2 4 7 :2 11 23 :2 2d 39
3c 4b 4e 4f :2 4b :2 23 :3 7 :2 d
12 1e 5c 5f :2 1e :2 7 52 :3 4
14 :2 4 14 :2 4 13 :2 4 12 :2 4
10 :2 4 e :2 4 14 :2 4 f :2 4
12 :2 4 e :2 4 e :2 4 11 :2 4
11 :2 4 13 :2 4 11 :2 4 13 :2 4
17 :2 4 14 1d 26 2e :2 1d :2 14
:2 4 13 :2 4 12 :2 4 10 4 :4 8
7 a :2 14 26 :2 30 3c 3f 4e
51 52 :2 4e :2 26 :3 a :2 10 15 21
5f 62 :2 21 6f 72 :2 21 76 79
:2 21 83 86 8f 97 :2 a0 :2 8f b6
:2 86 :2 21 :2 a 55 :2 7 a :2 14 26
:2 30 3c 3f 4e 51 52 :2 4e :2 26
:3 a :2 10 15 21 5f 62 :2 21 :2 a
55 :3 7 :2 12 28 :2 31 46 :2 7 18
:2 4 :4 8 7 a :2 14 26 :2 30 3c
3f 4e 51 52 :2 4e :2 26 :3 a :2 10
15 21 5f 62 :2 21 6f 72 :2 21
76 79 :2 21 83 86 8f 97 :2 a0
:2 8f b6 :2 86 :2 21 :2 a 55 :2 7 a
:2 14 26 :2 30 3c 3f 4e 51 52
:2 4e :2 26 :3 a :2 10 15 21 5f 62
:2 21 :2 a 55 :3 7 :2 12 28 :2 31 46
:2 7 1b :2 4 7 10 1b :2 7 1e
20 :2 1e 26 2f 37 :2 26 3a 3c
:2 3a :2 7 42 4b 53 :2 42 56 58
:2 56 :2 7 a :2 14 26 :2 30 3c 3f
4e 51 52 :2 4e :2 26 :3 a :2 10 15
21 5f 62 :2 21 6f 72 :2 21 76
79 :2 21 83 86 8f 97 :2 a0 :2 8f
b1 :2 86 :2 21 :2 a 55 :2 7 a :2 14
26 :2 30 3c 3f 4e 51 52 :2 4e
:2 26 :3 a :2 10 15 21 5f 62 :2 21
:2 a 55 :3 7 :2 12 28 :2 31 41 :2 7
5a :2 4 :4 9 8 7 :4 2b 2a 29
:2 7 11 1c 21 33 3e 43 :2 f
:2 a :2 13 1f a 7 :2 f d :2 16
22 d 10 :2 1a 2c :2 36 42 46
55 58 59 :2 55 :2 2c :3 10 :2 16 1b
27 65 68 :2 27 75 78 :2 27 7c
7f :2 27 8b 8e :2 27 96 99 :2 27
a5 a8 af b8 bb :2 a8 :2 27 :2 10
5c :2 d :2 a :4 16 :2 a 7 :3 48 b
:2 14 1f 1d :2 28 :2 1d a 3d 46
4f :2 3d 52 54 :2 52 3c :2 a d
:2 17 29 :2 33 3f 42 51 54 55
:2 51 :2 29 :3 d :2 13 18 24 62 65
:2 24 72 75 :2 24 79 7c :2 24 86
89 92 9a :2 a3 :2 92 c0 :2 89 :2 24
:2 d 58 :2 a d :2 17 29 :2 33 3f
42 51 54 55 :2 51 :2 29 :3 d :2 13
18 24 62 65 :2 24 :2 d 58 :3 a
:2 15 2b :2 34 50 :2 a 57 :3 7 e
7 4 48 :4 c b a :4 2a 29
28 :2 a 11 23 f :2 a :2 13 1f
a 7 :2 f d :2 16 22 d 10
:2 1a 2c :2 36 42 46 55 58 59
:2 55 :2 2c :3 10 :2 16 1b 27 65 68
:2 27 75 78 :2 27 7c 7f :2 27 8b
8e :2 27 96 99 :2 27 a5 a8 af
b8 bb :2 a8 :2 27 :2 10 5c :2 d :2 a
:4 16 :2 a 7 :4 43 48 :3 4 12 4
:4 8 :2 7 16 7 20 :3 4 10 17
21 24 :2 10 :2 4 12 19 25 28
:2 12 :2 4 13 4 7 10 18 :2 7
1b 1d :2 1b 7 13 1a 21 2e
31 :2 1a 36 39 :2 13 :2 7 15 :2 1e
27 2a 2d 31 :2 15 7 a 18
21 29 :2 18 :2 a 2d 30 :2 2d 14
20 29 3f 48 60 12 20 2b
37 12 20 2d :2 d :2 16 22 d
a :2 12 10 :2 19 25 10 13 :2 1d
2f :2 39 45 49 58 5b 5c :2 58
:2 2f :3 13 :2 19 1e 2a 68 6b :2 2a
78 7b :2 2a 7f 82 :2 2a 8e 91
:2 2a 99 9c :2 2a a8 ab b2 bb
be :2 ab :2 2a :2 13 5f :2 10 :2 d :4 19
:2 d a :4 32 14 16 1f 21 2c
2e 40 42 55 57 d 16 18
2e 37 39 51 53 12 1a 27
38 4a d 18 24 34 3c 3f
47 13 15 22 30 32 3e 47
4f 58 66 6f 7d 86 94 9d
aa b3 c4 cd e0 e9 fe 107
122 12b 143 14c 15d 166 178 181
199 1a2 1b5 1be 1df 1e1 1ee 1f0
:2 d :2 16 22 d a :2 12 10 :2 19
25 10 13 :2 1d 2f :2 39 45 49
58 5b 5c :2 58 :2 2f :3 13 :2 19 1e
2a 68 6b :2 2a 78 7b :2 2a 7f
82 :2 2a 8e 91 :2 2a 99 9c :2 2a
a8 ab b2 bb be :2 ab :2 2a :2 13
5f :2 10 :2 d :4 19 :2 d a :7 7 b
:2 14 1f 1d :2 28 :2 1d a 14 20
2c 3a 12 20 2d :2 d :2 16 22
d a :2 12 10 :2 19 25 10 13
:2 1d 2f :2 39 45 49 58 5b 5c
:2 58 :2 2f :3 13 :2 19 1e 2a 68 6b
:2 2a 78 7b :2 2a 7f 82 :2 2a 8e
91 :2 2a 99 9c :2 2a a8 ab b2
bb be :2 ab :2 2a :2 13 5f :2 10 :2 d
:4 19 :2 d a :3 38 e :2 17 22 20
:2 2b :2 20 d :4 11 :2 10 20 10 24
:2 d 17 20 36 3f 57 15 20
2c 15 23 30 :2 10 :2 19 25 10
d :2 15 13 :2 1c 28 13 16 :2 20
32 :2 3c 48 4c 5b 5e 5f :2 5b
:2 32 :3 16 :2 1c 21 2d 6b 6e :2 2d
7b 7e :2 2d 82 85 :2 2d 91 94
:2 2d 9c 9f :2 2d ab ae b5 be
c1 :2 ae :2 2d :2 16 62 :2 13 :2 10 :4 1c
:2 10 d :4 3b 10 :2 1a 2c :2 36 42
46 55 58 59 :2 55 :2 2c :3 10 :2 16
1b 27 65 68 :2 27 75 78 :2 27
7c 7f :2 27 89 8c 95 9d :2 a6
:2 95 b9 :2 8c :2 27 c1 c4 :2 27 cc
cf :2 27 d4 d7 :2 27 e1 e4 :2 27
:2 10 5c :2 d 10 :2 1a 2c :2 36 42
45 54 57 58 :2 54 :2 2c :3 10 :2 16
1b 27 65 68 :2 27 :2 10 5b :3 d
:2 18 2c :2 35 47 52 :2 d :4 a 38
a 1a a :5 7 15 7 11 21
f 10 1d :2 a :2 13 1f a 7
:2 f d :2 16 22 d 10 :2 1a 2c
:2 36 42 46 55 58 59 :2 55 :2 2c
:3 10 :2 16 1b 27 65 68 :2 27 75
78 :2 27 7c 7f :2 27 8b 8e :2 27
96 99 :2 27 a5 a8 af b8 bb
:2 a8 :2 27 :2 10 5c :2 d :2 a :4 16 :2 a
7 :3 1f a 13 1f :2 a 22 24
:2 22 14 24 12 13 20 :2 d :2 16
22 d a :2 12 10 :2 19 25 10
13 :2 1d 2f :2 39 45 49 58 5b
5c :2 58 :2 2f :3 13 :2 19 1e 2a 68
6b :2 2a 78 7b :2 2a 7f 82 :2 2a
8e 91 :2 2a 99 9c :2 2a a8 ab
b2 bb be :2 ab :2 2a :2 13 5f :2 10
:2 d :4 19 :2 d a :3 26 d :2 18 1f
2d :2 d 32 34 :2 32 10 :2 1a 2c
:2 36 42 46 55 58 59 :2 55 :2 2c
:3 10 :2 16 1b 27 65 68 :2 27 75
78 :2 27 7c 7f :2 27 89 8c 95
9d :2 a6 :2 95 bb :2 8c :2 27 c3 c6
:2 27 ce d1 :2 27 d6 d9 :2 27 e6
e9 :2 27 :2 10 5c :2 d 10 :2 1a 2c
:2 36 42 45 54 57 58 :2 54 :2 2c
:3 10 :2 16 1b 27 65 68 :2 27 :2 10
5b :3 d :2 18 2c :2 35 49 57 :2 d
36 :2 a 26 :2 7 1f 11 1a 30
39 51 f 1a 26 f 1d 2a
:2 a :2 13 1f a 7 :2 f d :2 16
22 d 10 :2 1a 2c :2 36 42 46
55 58 59 :2 55 :2 2c :3 10 :2 16 1b
27 65 68 :2 27 75 78 :2 27 7c
7f :2 27 8b 8e :2 27 96 99 :2 27
a5 a8 af b8 bb :2 a8 :2 27 :2 10
5c :2 d :2 a :4 16 :2 a 7 :3 4 b
:2 14 1f 1d :2 28 :2 1d a 23 2e
3e 4e 5b :2 d :2 16 22 d a
:2 12 10 :2 19 25 10 13 :2 1d 2f
:2 39 45 49 58 5b 5c :2 58 :2 2f
:3 13 :2 19 1e 2a 68 6b :2 2a 78
7b :2 2a 7f 82 :2 2a 8e 91 :2 2a
99 9c :2 2a a8 ab b2 bb be
:2 ab :2 2a :2 13 5f :2 10 :2 d :4 19 :2 d
a :3 38 e :2 17 22 20 :2 2b :2 20
d 10 :2 1a 2c :2 36 42 46 55
58 59 :2 55 :2 2c :3 10 :2 16 1b 27
65 68 :2 27 75 78 :2 27 7c 7f
:2 27 89 8c 95 9d :2 a6 :2 95 b7
:2 8c :2 27 bf c2 :2 27 ca cd :2 27
d2 d5 :2 27 e2 e5 :2 27 :2 10 5c
:2 d 10 :2 1a 2c :2 36 42 45 54
57 58 :2 54 :2 2c :3 10 :2 16 1b 27
65 68 :2 27 :2 10 5b :3 d :2 18 2c
:2 35 45 53 :2 d 3b :2 a 38 :2 7
:4 4 7 b d :2 b 7 15 :2 7
16 :2 7 15 26 32 3f 48 51
:2 3f 55 5e 66 :2 55 22 2b 37
:2 22 3b 44 4f :2 3b 53 20 2b
:2 53 2f 38 46 :2 2f 4a 53 5e
:2 4a 22 2b 37 :2 22 3b 43 4d
:2 15 7 a 13 1f :2 a 24 22
:2 2d :2 22 d :2 17 29 :2 33 3f 42
51 54 55 :2 51 :2 29 :3 d :2 13 18
24 62 65 :2 24 72 75 :2 24 79
7c :2 24 86 89 92 9a :2 a3 :2 92
b4 :2 89 :2 24 :2 d 58 :2 a d :2 17
29 :2 33 3f 42 51 54 55 :2 51
:2 29 :3 d :2 13 18 24 62 65 :2 24
:2 d 58 :3 a :2 15 2b :2 34 44 :2 a
7 3c d 16 22 :2 d 25 28
:2 25 d :2 17 29 :2 33 3f 43 52
55 56 :2 52 :2 29 :3 d :2 13 18 24
62 65 :2 24 72 75 :2 24 79 7c
:2 24 86 89 92 9a :2 92 a7 :2 89
:2 24 af b2 :2 24 ba bd :2 24 c2
c5 :2 24 d2 d5 :2 24 :2 d 59 :2 a
d :2 17 29 :2 33 3f 42 51 54
55 :2 51 :2 29 :3 d :2 13 18 24 62
65 :2 24 :2 d 58 :3 a :2 15 29 32
3e :2 29 42 50 :2 a 2a 3c :3 7
16 7 :4 b :2 a 19 a 20 :2 7
4 f b 14 1c :2 b 1f 21
:2 1f a 29 32 3a :2 29 3d 40
:2 3d 28 :2 a b 14 1c :2 b 1f
21 :2 1f a 28 31 39 :2 28 3c
3e :2 3c 27 :3 a 15 a 7 41
d 16 1e :2 d 21 23 :2 21 a
15 a 7 25 41 e 17 1f
:2 e 22 24 :2 22 d 2b 34 3c
:2 2b 3f 41 :2 3f 2a :2 d a 15
a 7 44 41 d 16 1e :2 d
21 23 :2 21 a 14 1d 29 :2 14
2c 2e 37 3f :2 2e :2 14 :2 a 15
a 25 41 :2 7 45 f :3 4 :3 17
:2 4 12 :2 4 13 :2 4 d :2 16 22
29 32 3e :2 29 42 :2 4b :2 22 21
5a :2 d :2 4 12 19 22 2e :2 19
32 :2 3b :2 12 4 7 10 18 :2 7
1b 1d :2 1b 7 1a 29 37 3f
4a 54 25 :2 1a 7 a 13 24
:2 a 27 2a :2 27 d :2 17 29 :2 33
3f 43 52 55 56 :2 52 :2 29 :3 d
:2 13 18 24 62 65 :2 24 72 75
:2 24 79 7c :2 24 86 89 92 9a
:2 92 ac :2 89 :2 24 b4 b7 :2 24 bf
c2 :2 24 c7 ca :2 24 d6 d9 :2 24
:2 d 59 :2 a d :2 17 29 :2 33 3f
42 51 54 55 :2 51 :2 29 :3 d :2 13
18 24 62 65 :2 24 :2 d 58 :3 a
:2 15 29 32 43 :2 29 47 54 :2 a
2c :3 7 15 7 11 15 24 2f
34 44 4f 54 58 f 1b f
10 1d e 18 e 1c e 1e
:2 a :2 13 1f a 7 :2 f d :2 16
22 d 10 :2 1a 2c :2 36 42 46
55 58 59 :2 55 :2 2c :3 10 :2 16 1b
27 65 68 :2 27 75 78 :2 27 7c
7f :2 27 8b 8e :2 27 96 99 :2 27
a5 a8 af b8 bb :2 a8 :2 27 :2 10
5c :2 d :2 a :4 16 :2 a 7 :3 1f b
:2 14 1f 1d :2 28 :2 1d a :4 3e 3d
3c :3 a 18 a d 16 1f :2 d
22 24 :2 22 d 1d d 26 :2 a
57 :3 7 16 :2 7 12 7 a e
10 :2 e d 14 20 23 :2 d 26
28 :2 26 17 2e 45 4d 54 6d
75 7c 10 18 1f 37 3f 46
60 6e 89 15 26 32 3b 15
16 1e 2f 3b 48 5e :2 10 :2 19
25 10 d :2 15 13 :2 1c 28 13
16 :2 20 32 :2 3c 48 4c 5b 5e
5f :2 5b :2 32 :3 16 :2 1c 21 2d 6b
6e :2 2d 7b 7e :2 2d 82 85 :2 2d
91 94 :2 2d 9c 9f :2 2d ab ae
b5 be c1 :2 ae :2 2d :2 16 62 :2 13
:2 10 :4 1c :2 10 d :3 2c 11 :2 1a 25
23 :2 2e :2 23 :2 10 1e 10 14 1d
2b :2 14 2e 30 :2 2e 13 37 40
49 :2 37 4c 4e :2 4c 36 :2 13 1d
34 4d 55 5c 75 7d 84 16
1e 25 3d 45 4c 68 78 1b
2c 38 1b 1c 24 35 41 4e
64 :2 16 :2 1f 2b 16 13 :2 1b 19
:2 22 2e 19 1c :2 26 38 :2 42 4e
52 61 64 65 :2 61 :2 38 :3 1c :2 22
27 33 71 74 :2 33 81 84 :2 33
88 8b :2 33 97 9a :2 33 a2 a5
:2 33 b1 b4 bb c4 c7 :2 b4 :2 33
:2 1c 68 :2 19 :2 16 :4 22 :2 16 13 :4 51
13 22 13 :4 10 d 3e 14 :2 1d
28 26 :2 31 :2 26 13 45 4e 57
:2 45 5a 5c :2 5a 44 :2 13 1a 31
4a 52 59 72 7a 81 13 1b
22 3a 42 49 65 75 18 29
35 18 19 21 32 3e 4b 61
:2 13 :2 1c 28 13 10 :2 18 16 :2 1f
2b 16 19 :2 23 35 :2 3f 4b 4f
5e 61 62 :2 5e :2 35 :3 19 :2 1f 24
30 6e 71 :2 30 7e 81 :2 30 85
88 :2 30 94 97 :2 30 9f a2 :2 30
ae b1 b8 c1 c4 :2 b1 :2 30 :2 19
65 :2 16 :2 13 :4 1f :2 13 10 :4 5f 3e
:2 d 2c 17 2e 47 4f 56 6f
77 7e 10 18 1f 37 3f 46
62 72 15 26 32 15 16 1e
2f 3b 48 5e :2 10 :2 19 25 10
d :2 15 13 :2 1c 28 13 16 :2 20
32 :2 3c 48 4c 5b 5e 5f :2 5b
:2 32 :3 16 :2 1c 21 2d 6b 6e :2 2d
7b 7e :2 2d 82 85 :2 2d 91 94
:2 2d 9c 9f :2 2d ab ae b5 be
c1 :2 ae :2 2d :2 16 62 :2 13 :2 10 :4 1c
:2 10 d :7 a 12 d 14 20 23
:2 d 26 28 :2 26 17 2e 44 4c
53 71 79 80 99 a1 a8 c2
ce ec 15 26 31 3a 15 16
1e 2f 3b 48 5e :2 10 :2 19 25
10 d :2 15 13 :2 1c 28 13 16
:2 20 32 :2 3c 48 4c 5b 5e 5f
:2 5b :2 32 :3 16 :2 1c 21 2d 6b 6e
:2 2d 7b 7e :2 2d 82 85 :2 2d 91
94 :2 2d 9c 9f :2 2d ab ae b5
be c1 :2 ae :2 2d :2 16 62 :2 13 :2 10
:4 1c :2 10 d :3 2c 11 :2 1a 25 23
:2 2e :2 23 :2 10 1e 10 14 1d 2b
:2 14 2e 30 :2 2e 13 37 40 49
:2 37 4c 4e :2 4c 36 :2 13 1d 34
4d 55 5c 75 7d 84 a0 ac
1b 2c 37 1b 1c 24 35 41
4e 64 :2 16 :2 1f 2b 16 13 :2 1b
19 :2 22 2e 19 1c :2 26 38 :2 42
4e 52 61 64 65 :2 61 :2 38 :3 1c
:2 22 27 33 71 74 :2 33 81 84
:2 33 88 8b :2 33 97 9a :2 33 a2
a5 :2 33 b1 b4 bb c4 c7 :2 b4
:2 33 :2 1c 68 :2 19 :2 16 :4 22 :2 16 13
:4 51 13 22 :2 13 :4 10 d 3e 14
:2 1d 28 26 :2 31 :2 26 13 1a 31
49 51 58 76 7e 85 a0 a8
af cb d7 18 29 34 18 19
21 32 3e 4b 61 :2 13 :2 1c 28
13 10 :2 18 16 :2 1f 2b 16 19
:2 23 35 :2 3f 4b 4f 5e 61 62
:2 5e :2 35 :3 19 :2 1f 24 30 6e 71
:2 30 7e 81 :2 30 85 88 :2 30 94
97 :2 30 9f a2 :2 30 ae b1 b8
c1 c4 :2 b1 :2 30 :2 19 65 :2 16 :2 13
:4 1f :2 13 10 :4 41 3e :2 d 2c 17
2e 46 4e 55 73 7b 82 9d
a5 ac c8 d4 15 26 31 15
16 1e 2f 3b 48 5e :2 10 :2 19
25 10 d :2 15 13 :2 1c 28 13
16 :2 20 32 :2 3c 48 4c 5b 5e
5f :2 5b :2 32 :3 16 :2 1c 21 2d 6b
6e :2 2d 7b 7e :2 2d 82 85 :2 2d
91 94 :2 2d 9c 9f :2 2d ab ae
b5 be c1 :2 ae :2 2d :2 16 62 :2 13
:2 10 :4 1c :2 10 d :7 a :4 7 b :2 14
1f 1d :2 28 :2 1d a d 16 1f
:2 d 22 24 :2 22 10 :2 1a 2c :2 36
42 46 55 58 59 :2 55 :2 2c :3 10
:2 16 1b 27 65 68 :2 27 75 78
:2 27 7c 7f :2 27 89 8c 95 9d
:2 a6 :2 95 be :2 8c :2 27 c6 c9 :2 27
d1 d4 :2 27 d9 dc :2 27 e5 e8
:2 27 :2 10 5c :2 d 10 :2 1a 2c :2 36
42 45 54 57 58 :2 54 :2 2c :3 10
:2 16 1b 27 65 68 :2 27 :2 10 5b
:3 d :2 18 2c :2 35 4c 56 :2 d a
26 :4 11 :2 10 14 16 :2 14 10 20
10 1a 1e 2e 18 19 26 37
4b 17 28 30 37 51 59 60
:2 13 :2 1c 28 13 10 :2 18 16 :2 1f
2b 16 19 :2 23 35 :2 3f 4b 4f
5e 61 62 :2 5e :2 35 :3 19 :2 1f 24
30 6e 71 :2 30 7e 81 :2 30 85
88 :2 30 94 97 :2 30 9f a2 :2 30
ae b1 b8 c1 c4 :2 b1 :2 30 :2 19
65 :2 16 :2 13 :4 1f :2 13 10 :4 18 10
20 10 1a 1e 2e 18 19 26
37 4b 17 23 2b 32 :2 13 :2 1c
28 13 10 :2 18 16 :2 1f 2b 16
19 :2 23 35 :2 3f 4b 4f 5e 61
62 :2 5e :2 35 :3 19 :2 1f 24 30 6e
71 :2 30 7e 81 :2 30 85 88 :2 30
94 97 :2 30 9f a2 :2 30 ae b1
b8 c1 c4 :2 b1 :2 30 :2 19 65 :2 16
:2 13 :4 1f :2 13 10 :7 d 10 19 27
:2 10 2c 2a 35 3f :2 2c :2 2a 13
:2 1d 2f :2 39 45 49 58 5b 5c
:2 58 :2 2f :3 13 :2 19 1e 2a 68 6b
:2 2a 78 7b :2 2a 7f 82 :2 2a 8c
8f 98 a0 :2 a9 :2 98 c1 :2 8f :2 2a
c9 cc :2 2a d4 d7 :2 2a dc df
:2 2a e8 eb :2 2a :2 13 5f :2 10 13
:2 1d 2f :2 39 45 48 57 5a 5b
:2 57 :2 2f :3 13 :2 19 1e 2a 68 6b
:2 2a :2 13 5e :3 10 :2 1b 2f :2 38 4f
59 :2 10 42 :2 d 2e 26 :3 a 18
a 7 38 e 17 23 :2 e 26
28 :2 26 d 30 41 4a 52 :2 41
:2 30 2f 57 5a :2 57 :3 d :2 17 29
:2 33 3f 43 52 55 56 :2 52 :2 29
:3 d :2 13 18 24 62 65 :2 24 72
75 :2 24 79 7c :2 24 86 89 92
9a :2 a3 :2 92 bb :2 89 :2 24 c3 c6
:2 24 ce d1 :2 24 d6 d9 :2 24 e2
e5 :2 24 :2 d 59 :2 a d :2 17 29
:2 33 3f 42 51 54 55 :2 51 :2 29
:3 d :2 13 18 24 62 65 :2 24 :2 d
58 :3 a :2 15 29 :2 32 49 53 :2 a
5c 38 :2 7 a 11 1d 20 :2 a
23 25 :2 23 a 18 1f 2a 2d
:2 1f 37 3a :2 18 a 14 1f 2a
35 42 4a 53 5e 69 7c 85
90 9b 12 1f 2d 37 4a 12
13 21 :2 d :2 16 22 d a :2 12
10 :2 19 25 10 13 :2 1d 2f :2 39
45 49 58 5b 5c :2 58 :2 2f :3 13
:2 19 1e 2a 68 6b :2 2a 78 7b
:2 2a 7f 82 :2 2a 8e 91 :2 2a 99
9c :2 2a a8 ab b2 bb be :2 ab
:2 2a :2 13 5f :2 10 :2 d :4 19 :2 d a
:3 29 e :2 17 22 20 :2 2b :2 20 d
10 :2 1a 2c :2 36 42 46 55 58
59 :2 55 :2 2c :3 10 :2 16 1b 27 65
68 :2 27 75 78 :2 27 7c 7f :2 27
89 8c 95 9d :2 a6 :2 95 b9 :2 8c
:2 27 c1 c4 :2 27 cc cf :2 27 d4
d7 :2 27 e0 e3 :2 27 :2 10 5c :2 d
10 :2 1a 2c :2 36 42 45 54 57
58 :2 54 :2 2c :3 10 :2 16 1b 27 65
68 :2 27 :2 10 5b :3 d :2 18 2c :2 35
47 51 :2 d 3b :2 a e 15 1f
22 :2 e 25 27 :2 25 d 31 3a
4d :2 31 50 52 :2 50 30 5a 10
1e :2 5a 23 21 2c 3f :2 23 :2 21
59 :2 30 2f :2 d 10 :2 1a 2c :2 36
42 46 55 58 59 :2 55 :2 2c :3 10
:2 16 1b 27 65 68 :2 27 75 78
:2 27 7c 7f :2 27 89 8c 95 9d
:2 a6 :2 95 bc :2 8c :2 27 c4 c7 :2 27
cf d2 :2 27 d7 da :2 27 e3 e6
:2 27 :2 10 5c :2 d 10 :2 1a 2c :2 36
42 45 54 57 58 :2 54 :2 2c :3 10
:2 16 1b 27 65 68 :2 27 :2 10 5b
:3 d :2 18 2c :2 35 4a 54 :2 d 44
:2 a 14 27 34 45 52 61 12
13 20 2e 46 54 :2 d :2 16 22
d a :2 12 10 :2 19 25 10 13
:2 1d 2f :2 39 45 49 58 5b 5c
:2 58 :2 2f :3 13 :2 19 1e 2a 68 6b
:2 2a 78 7b :2 2a 7f 82 :2 2a 8e
91 :2 2a 99 9c :2 2a a8 ab b2
bb be :2 ab :2 2a :2 13 5f :2 10 :2 d
:4 19 :2 d a :4 29 a 19 20 2c
2f :2 20 39 3c :2 19 a 14 26
37 46 53 :2 d :2 16 22 d a
:2 12 10 :2 19 25 10 13 :2 1d 2f
:2 39 45 49 58 5b 5c :2 58 :2 2f
:3 13 :2 19 1e 2a 68 6b :2 2a 78
7b :2 2a 7f 82 :2 2a 8e 91 :2 2a
99 9c :2 2a a8 ab b2 bb be
:2 ab :2 2a :2 13 5f :2 10 :2 d :4 19 :2 d
a :3 7 e :2 17 22 20 :2 2b :2 20
d 10 :2 1a 2c :2 36 42 46 55
58 59 :2 55 :2 2c :3 10 :2 16 1b 27
65 68 :2 27 75 78 :2 27 7c 7f
:2 27 89 8c 95 9d :2 a6 :2 95 b9
:2 8c :2 27 c1 c4 :2 27 cc cf :2 27
d4 d7 :2 27 e0 e3 :2 27 :2 10 5c
:2 d 10 :2 1a 2c :2 36 42 45 54
57 58 :2 54 :2 2c :3 10 :2 16 1b 27
65 68 :2 27 :2 10 5b :3 d :2 18 2c
:2 35 47 51 :2 d 3b :2 a 14 2c
34 3b 59 61 68 82 8a 91
ac b8 12 1e 12 13 1b 2c
38 45 :2 d :2 16 22 d a :2 12
10 :2 19 25 10 13 :2 1d 2f :2 39
45 49 58 5b 5c :2 58 :2 2f :3 13
:2 19 1e 2a 68 6b :2 2a 78 7b
:2 2a 7f 82 :2 2a 8e 91 :2 2a 99
9c :2 2a a8 ab b2 bb be :2 ab
:2 2a :2 13 5f :2 10 :2 d :4 19 :2 d a
:3 7 e :2 17 22 20 :2 2b :2 20 d
40 49 52 :2 40 55 57 :2 55 3f
:2 d 10 :2 1a 2c :2 36 42 46 55
58 59 :2 55 :2 2c :3 10 :2 16 1b 27
65 68 :2 27 75 78 :2 27 7c 7f
:2 27 89 8c 95 9d :2 a6 :2 95 be
:2 8c :2 27 c6 c9 :2 27 d1 d4 :2 27
d9 dc :2 27 e5 e8 :2 27 :2 10 5c
:2 d 10 :2 1a 2c :2 36 42 45 54
57 58 :2 54 :2 2c :3 10 :2 16 1b 27
65 68 :2 27 :2 10 5b :3 d :2 18 2c
:2 35 4c 56 :2 d 5a :2 a 14 27
34 45 52 61 12 13 20 2e
46 54 :2 d :2 16 22 d a :2 12
10 :2 19 25 10 13 :2 1d 2f :2 39
45 49 58 5b 5c :2 58 :2 2f :3 13
:2 19 1e 2a 68 6b :2 2a 78 7b
:2 2a 7f 82 :2 2a 8e 91 :2 2a 99
9c :2 2a a8 ab b2 bb be :2 ab
:2 2a :2 13 5f :2 10 :2 d :4 19 :2 d a
:8 7 15 7 a 13 1f :2 a 22
24 :2 22 14 1f 2c 34 3b 50
5b 60 74 12 :2 d :2 16 22 d
a :2 12 10 :2 19 25 10 13 :2 1d
2f :2 39 45 49 58 5b 5c :2 58
:2 2f :3 13 :2 19 1e 2a 68 6b :2 2a
78 7b :2 2a 7f 82 :2 2a 8e 91
:2 2a 99 9c :2 2a a8 ab b2 bb
be :2 ab :2 2a :2 13 5f :2 10 :2 d :4 19
:2 d a :3 26 1e 26 2d 45 4d
54 6d :3 12 :2 d :2 16 22 d a
:2 12 10 :2 19 25 10 13 :2 1d 2f
:2 39 45 49 58 5b 5c :2 58 :2 2f
:3 13 :2 19 1e 2a 68 6b :2 2a 78
7b :2 2a 7f 82 :2 2a 8e 91 :2 2a
99 9c :2 2a a8 ab b2 bb be
:2 ab :2 2a :2 13 5f :2 10 :2 d :4 19 :2 d
a :3 26 a 15 :2 a 19 a d
16 23 :2 d 26 28 :2 26 d 19
d 2a :3 a 16 22 2f 3d 48
52 5e 1b 28 35 42 4f 1b
28 34 3e 46 4f 57 5e 1b
27 34 3f 4a 58 1b 26 32
3e 41 44 4a :2 16 a d 16
18 :2 16 10 19 26 :2 10 29 2b
:2 29 1a 2d 4a 51 13 1a 16
22 :3 20 16 :2 1f 2b 16 27 16
:2 1f 2b 16 :4 13 10 :2 18 16 :2 1f
2b 16 19 :2 23 35 :2 3f 4b 4f
5e 61 62 :2 5e :2 35 :3 19 :2 1f 24
30 6e 71 :2 30 7e 81 :2 30 85
88 :2 30 94 97 :2 30 9f a2 :2 30
ae b1 b8 c1 c4 :2 b1 :2 30 :2 19
65 :2 16 :2 13 :4 1f :2 13 10 :4 2d 1a
2d 4a 51 13 1a 16 22 :3 20
16 :2 1f 2b 16 27 16 :2 1f 2b
16 :4 13 10 :2 18 16 :2 1f 2b 16
19 :2 23 35 :2 3f 4b 4f 5e 61
62 :2 5e :2 35 :3 19 :2 1f 24 30 6e
71 :2 30 7e 81 :2 30 85 88 :2 30
94 97 :2 30 9f a2 :2 30 ae b1
b8 c1 c4 :2 b1 :2 30 :2 19 65 :2 16
:2 13 :4 1f :2 13 10 :7 d 1a :2 a 26
a 18 :2 a 19 a d 14 20
23 :2 d 26 28 :2 26 d 18 :2 21
d 2c d 18 1f 28 34 :2 1f
38 :2 41 :2 18 d :5 a 16 22 2f
3d 48 52 5e 1b 28 35 42
4f 1b 28 34 3e 46 4f 57
5e 1b 27 34 3f 4a 58 1b
26 32 3e 41 44 4a :2 16 a
d 16 18 :2 16 17 2a 47 4e
10 17 13 1f :3 1d 13 :2 1c 28
13 24 13 :2 1c 28 13 :4 10 d
:2 15 13 :2 1c 28 13 16 :2 20 32
:2 3c 48 4c 5b 5e 5f :2 5b :2 32
:3 16 :2 1c 21 2d 6b 6e :2 2d 7b
7e :2 2d 82 85 :2 2d 91 94 :2 2d
9c 9f :2 2d ab ae b5 be c1
:2 ae :2 2d :2 16 62 :2 13 :2 10 :4 1c :2 10
d :4 1a :2 a :4 7 1f a 13 1a
:2 13 28 :2 a 2b 2d :2 2b a 16
a 30 a 16 1d 26 2d :2 26
3b :2 1d 3e 40 :2 1d 1c 43 45
:2 1c :2 16 a :4 7 a 13 15 :2 13
a 15 :2 a 10 19 22 :2 10 27
25 30 :2 25 a d 1b :2 d 19
:2 22 2b 2f 33 3c 45 :2 33 48
4a :2 33 4c 4d :2 33 50 :2 19 :2 d
1b :2 24 2d 30 33 3c 45 :2 33
48 4a :2 33 4d 4f :2 33 51 52
:2 33 55 :2 1b :2 d 1d :2 d 1b :2 d
18 :2 d 1b d 17 21 25 3a
43 15 16 23 34 3e 14 22
2f 3f :2 10 :2 19 25 10 d :2 15
13 :2 1c 28 13 16 :2 20 32 :2 3c
48 4c 5b 5f 60 :2 5b :2 32 :3 16
:2 1c 21 2d 6c 6f :2 2d 7c 7f
:2 2d 83 86 :2 2d 92 95 :2 2d 9d
a0 :2 2d ac af b6 bf c2 :2 af
:2 2d :2 16 63 :2 13 :2 10 :4 1c :2 10 d
:3 30 11 1a 23 :2 11 26 28 :2 26
10 :4 31 30 2f :3 10 1e 10 13
:2 1e 25 33 :2 13 3f 41 :2 3f 13
23 13 43 :2 10 4a :2 d 10 17
23 26 :2 10 29 2b :2 29 10 1e
:2 27 10 13 1c 23 :2 1c 31 :2 13
34 36 :2 34 13 22 13 38 13
22 29 35 38 :2 29 41 44 :2 22
:2 13 22 29 35 38 :2 29 42 45
:2 22 13 :4 10 2f 13 1c 23 :2 1c
30 :2 13 33 35 :2 33 13 21 13
37 13 21 28 33 36 :2 28 3f
42 :2 21 :2 13 21 28 33 36 :2 28
40 43 :2 21 13 :4 10 :5 d 1c :2 d
18 d 10 19 25 :2 10 28 2a
:2 28 13 17 19 :2 17 16 1d 29
2c :2 16 2f 31 :2 2f 20 37 4e
56 5d 76 7e 85 19 21 28
40 48 4f 69 77 92 1e 2f
3b 44 1e 1f 27 38 44 51
67 :2 19 :2 22 2e 19 16 :2 1e 1c
:2 25 31 1c 1f :2 29 3b :2 45 51
55 64 68 69 :2 64 :2 3b :3 1f :2 25
2a 36 75 78 :2 36 85 88 :2 36
8c 8f :2 36 9b 9e :2 36 a6 a9
:2 36 b5 b8 bf c8 cb :2 b8 :2 36
:2 1f 6c :2 1c :2 19 :4 25 :2 19 16 :3 35
1a :2 23 2e 2c :2 37 :2 2c :2 19 27
19 1d 26 34 :2 1d 37 39 :2 37
1c 40 49 52 :2 40 55 57 :2 55
3f :2 1c 26 3d 56 5e 65 7e
86 8d 1f 27 2e 46 4e 55
71 81 24 35 41 24 25 2d
3e 4a 57 6d :2 1f :2 28 34 1f
1c :2 24 22 :2 2b 37 22 25 :2 2f
41 :2 4b 57 5b 6a 6e 6f :2 6a
:2 41 :3 25 :2 2b 30 3c 7b 7e :2 3c
8b 8e :2 3c 92 95 :2 3c a1 a4
:2 3c ac af :2 3c bb be c5 ce
d1 :2 be :2 3c :2 25 72 :2 22 :2 1f :4 2b
:2 1f 1c :4 5a 1c 2b 1c :4 19 16
47 1d :2 26 31 2f :2 3a :2 2f 1c
4e 57 60 :2 4e 63 65 :2 63 4d
:2 1c 23 3a 53 5b 62 7b 83
8a 1c 24 2b 43 4b 52 6e
7e 21 32 3e 21 22 2a 3b
47 54 6a :2 1c :2 25 31 1c 19
:2 21 1f :2 28 34 1f 22 :2 2c 3e
:2 48 54 58 67 6b 6c :2 67 :2 3e
:3 22 :2 28 2d 39 78 7b :2 39 88
8b :2 39 8f 92 :2 39 9e a1 :2 39
a9 ac :2 39 b8 bb c2 cb ce
:2 bb :2 39 :2 22 6f :2 1f :2 1c :4 28 :2 1c
19 :4 68 47 :2 16 35 20 37 50
58 5f 78 80 87 19 21 28
40 48 4f 6b 7b 1e 2f 3b
48 1f 2c 3d 45 1d 29 36
4c :2 19 :2 22 2e 19 16 :2 1e 1c
:2 25 31 1c 1f :2 29 3b :2 45 51
55 64 68 69 :2 64 :2 3b :3 1f :2 25
2a 36 75 78 :2 36 85 88 :2 36
8c 8f :2 36 9b 9e :2 36 a6 a9
:2 36 b5 b8 bf c8 cb :2 b8 :2 36
:2 1f 6c :2 1c :2 19 :4 25 :2 19 16 :7 13
1b 16 1d 29 2c :2 16 2f 31
:2 2f 20 37 4d 55 5c 7a 82
89 a2 aa b1 cb d7 f5 1e
2f 3a 43 55 1f 2c 3d 45
1d 29 36 4c :2 19 :2 22 2e 19
16 :2 1e 1c :2 25 31 1c 1f :2 29
3b :2 45 51 55 64 68 69 :2 64
:2 3b :3 1f :2 25 2a 36 75 78 :2 36
85 88 :2 36 8c 8f :2 36 9b 9e
:2 36 a6 a9 :2 36 b5 b8 bf c8
cb :2 b8 :2 36 :2 1f 6c :2 1c :2 19 :4 25
:2 19 16 :3 35 1a :2 23 2e 2c :2 37
:2 2c 19 1d 26 34 :2 1d 37 39
:2 37 1c 40 49 52 :2 40 55 57
:2 55 3f :2 1c 26 3d 56 5e 65
7e 86 8d a9 b5 24 35 40
4d 25 32 43 4b 23 2f 3c
52 :2 1f :2 28 34 1f 1c :2 24 22
:2 2b 37 22 25 :2 2f 41 :2 4b 57
5b 6a 6e 6f :2 6a :2 41 :3 25 :2 2b
30 3c 7b 7e :2 3c 8b 8e :2 3c
92 95 :2 3c a1 a4 :2 3c ac af
:2 3c bb be c5 ce d1 :2 be :2 3c
:2 25 72 :2 22 :2 1f :4 2b :2 1f 1c :4 5a
1c 2b :2 1c :4 19 16 47 1d :2 26
31 2f :2 3a :2 2f 1c 23 3a 53
5b 62 80 88 8f aa b2 b9
d5 e1 21 32 3d 4a 22 2f
40 48 20 2c 39 4f :2 1c :2 25
31 1c 19 :2 21 1f :2 28 34 1f
22 :2 2c 3e :2 48 54 58 67 6b
6c :2 67 :2 3e :3 22 :2 28 2d 39 78
7b :2 39 88 8b :2 39 8f 92 :2 39
9e a1 :2 39 a9 ac :2 39 b8 bb
c2 cb ce :2 bb :2 39 :2 22 6f :2 1f
:2 1c :4 28 :2 1c 19 :4 4a 47 :2 16 35
20 37 4f 57 5e 7c 84 8b
a6 ae b5 d1 dd 1e 2f 3a
47 1f 2c 3d 45 1d 29 36
4c :2 19 :2 22 2e 19 16 :2 1e 1c
:2 25 31 1c 1f :2 29 3b :2 45 51
55 64 68 69 :2 64 :2 3b :3 1f :2 25
2a 36 75 78 :2 36 85 88 :2 36
8c 8f :2 36 9b 9e :2 36 a6 a9
:2 36 b5 b8 bf c8 cb :2 b8 :2 36
:2 1f 6c :2 1c :2 19 :4 25 :2 19 16 :7 13
:4 10 14 :2 1d 28 26 :2 31 :2 26 13
16 1f 28 :2 16 2b 2d :2 2b 16
24 16 2f :4 1a 19 1c 20 22
:2 20 1c 2c 1c 26 2a 3a 24
25 32 43 57 23 34 3c 43
5d 65 6c :2 1f :2 28 34 1f 1c
:2 24 22 :2 2b 37 22 25 :2 2f 41
:2 4b 57 5b 6a 6e 6f :2 6a :2 41
:3 25 :2 2b 30 3c 7b 7e :2 3c 8b
8e :2 3c 92 95 :2 3c a1 a4 :2 3c
ac af :2 3c bb be c5 ce d1
:2 be :2 3c :2 25 72 :2 22 :2 1f :4 2b :2 1f
1c :4 24 1c 2c 1c 26 2a 3a
24 25 32 43 57 23 2f 37
3e :2 1f :2 28 34 1f 1c :2 24 22
:2 2b 37 22 25 :2 2f 41 :2 4b 57
5b 6a 6e 6f :2 6a :2 41 :3 25 :2 2b
30 3c 7b 7e :2 3c 8b 8e :2 3c
92 95 :2 3c a1 a4 :2 3c ac af
:2 3c bb be c5 ce d1 :2 be :2 3c
:2 25 72 :2 22 :2 1f :4 2b :2 1f 1c :7 19
1c 25 33 :2 1c 38 36 41 4b
:2 38 :2 36 1c 27 30 39 :2 27 3c
3e :2 27 1c 21 1c 4e :2 19 37
:3 16 24 16 :4 13 41 13 1e 27
30 :2 1e 33 35 :2 1e 13 18 13
:5 10 1e :2 10 1c 10 1a 25 32
3a 41 56 61 66 :2 18 :2 13 :2 1c
28 13 10 :2 18 16 :2 1f 2b 16
19 :2 23 35 :2 3f 4b 4f 5e 62
63 :2 5e :2 35 :3 19 :2 1f 24 30 6f
72 :2 30 7f 82 :2 30 86 89 :2 30
95 98 :2 30 a0 a3 :2 30 af b2
b9 c2 c5 :2 b2 :2 30 :2 19 66 :2 16
:2 13 :4 1f :2 13 10 :3 2c 24 2c 33
4b 53 5a 73 85 :2 18 :2 13 :2 1c
28 13 10 :2 18 16 :2 1f 2b 16
19 :2 23 35 :2 3f 4b 4f 5e 62
63 :2 5e :2 35 :3 19 :2 1f 24 30 6f
72 :2 30 7f 82 :2 30 86 89 :2 30
95 98 :2 30 a0 a3 :2 30 af b2
b9 c2 c5 :2 b2 :2 30 :2 19 66 :2 16
:2 13 :4 1f :2 13 10 :3 2c 10 1b :2 10
1f 10 13 1c 29 :2 13 2c 2e
:2 2c 13 1f 13 30 :3 10 1c 28
35 43 4e 58 64 1b 28 35
42 4f 1b 28 34 3e 46 4f
57 5e 1b 27 34 3f 4a 58
1b 26 32 3e 41 44 4a :2 1c
10 13 1c 1e :2 1c 16 1f 2c
:2 16 2f 31 :2 2f 20 33 50 57
19 20 1c 28 :3 26 1c :2 25 31
1c 2d 1c :2 25 31 1c :4 19 16
:2 1e 1c :2 25 31 1c 1f :2 29 3b
:2 45 51 55 64 68 69 :2 64 :2 3b
:3 1f :2 25 2a 36 75 78 :2 36 85
88 :2 36 8c 8f :2 36 9b 9e :2 36
a6 a9 :2 36 b5 b8 bf c8 cb
:2 b8 :2 36 :2 1f 6c :2 1c :2 19 :4 25 :2 19
16 :4 33 20 33 50 57 19 20
1c 28 :3 26 1c :2 25 31 1c 2d
1c :2 25 31 1c :4 19 16 :2 1e 1c
:2 25 31 1c 1f :2 29 3b :2 45 51
55 64 68 69 :2 64 :2 3b :3 1f :2 25
2a 36 75 78 :2 36 85 88 :2 36
8c 8f :2 36 9b 9e :2 36 a6 a9
:2 36 b5 b8 bf c8 cb :2 b8 :2 36
:2 1f 6c :2 1c :2 19 :4 25 :2 19 16 :7 13
20 :2 10 d 2c 13 1c 28 :2 13
2b 2d :2 2b 10 1e :2 10 1f 10
13 1a 26 29 :2 13 2c 2e :2 2c
13 1e :2 27 13 32 13 1e 27
33 :2 1e 13 :5 10 1c 28 35 43
4e 58 64 1b 28 35 42 4f
1b 28 34 3e 46 4f 57 5e
1b 27 34 3f 4a 58 1b 26
32 3e 41 44 4a :2 1c 10 13
1c 1e :2 1c 1d 30 4d 54 16
1d 19 25 :3 23 19 :2 22 2e 19
2a 19 :2 22 2e 19 :4 16 13 :2 1b
19 :2 22 2e 19 1c :2 26 38 :2 42
4e 52 61 65 66 :2 61 :2 38 :3 1c
:2 22 27 33 72 75 :2 33 82 85
:2 33 89 8c :2 33 98 9b :2 33 a3
a6 :2 33 b2 b5 bc c5 c8 :2 b5
:2 33 :2 1c 69 :2 19 :2 16 :4 22 :2 16 13
:4 20 :2 10 2f 2c :3 d 18 21 2a
:2 18 2d 2f :2 18 d f d :3 30
e a 17 :2 7 :4 4 8 11 14
:2 11 7 1c 25 2d :2 1c 30 32
:2 30 1b :2 7 a 13 22 :2 a 25
27 :2 25 19 34 48 d 14 10
1c :3 1a 10 :2 19 25 10 21 10
:2 19 25 10 :4 d a :2 12 10 :2 19
25 10 13 :2 1d 2f :2 39 45 49
58 5c 5d :2 58 :2 2f :3 13 :2 19 1e
2a 69 6c :2 2a 79 7c :2 2a 80
83 :2 2a 8f 92 :2 2a 9a 9d :2 2a
a9 ac b3 bc bf :2 ac :2 2a :2 13
60 :2 10 :2 d :4 19 :2 d a :4 29 14
2d 3b 4a 58 13 27 d 14
10 1c :3 1a 10 :2 19 25 10 21
10 :2 19 25 10 :4 d a :2 12 10
:2 19 25 10 13 :2 1d 2f :2 39 45
49 58 5c 5d :2 58 :2 2f :3 13 :2 19
1e 2a 69 6c :2 2a 79 7c :2 2a
80 83 :2 2a 8f 92 :2 2a 9a 9d
:2 2a a9 ac b3 bc bf :2 ac :2 2a
:2 13 60 :2 10 :2 d :4 19 :2 d a :7 7
a 13 15 :2 13 d :2 17 29 :2 33
3f 43 52 56 57 :2 52 :2 29 :3 d
:2 13 18 24 63 66 :2 24 73 76
:2 24 7a 7d :2 24 87 8a 93 9b
:2 a4 :2 93 ba :2 8a :2 24 c2 c5 :2 24
cd d0 :2 24 d5 d8 :2 24 e1 e4
:2 24 :2 d 5a :2 a d :2 17 29 :2 33
3f 42 51 55 56 :2 51 :2 29 :3 d
:2 13 18 24 63 66 :2 24 :2 d 59
:3 a :2 15 29 :2 32 47 51 :2 a 7
19 d 18 16 :2 21 :2 16 d :2 17
29 :2 33 3f 43 52 56 57 :2 52
:2 29 :3 d :2 13 18 24 63 66 :2 24
73 76 :2 24 7a 7d :2 24 87 8a
93 9b :2 a4 :2 93 c3 :2 8a :2 24 cb
ce :2 24 d6 d9 :2 24 de e1 :2 24
ea ed :2 24 :2 d 5a :2 a d :2 17
29 :2 33 3f 42 51 55 56 :2 51
:2 29 :3 d :2 13 18 24 63 66 :2 24
:2 d 59 :3 a :2 15 29 :2 32 50 12
:2 a 7 3e 19 d 18 16 :2 21
:2 16 d :2 17 29 :2 33 3f 43 52
56 57 :2 52 :2 29 :3 d :2 13 18 24
63 66 :2 24 73 76 :2 24 7a 7d
:2 24 87 8a 93 9b :2 a4 :2 93 c0
:2 8a :2 24 c8 cb :2 24 d3 d6 :2 24
db de :2 24 e7 ea :2 24 :2 d 5a
:2 a d :2 17 29 :2 33 3f 42 51
55 56 :2 51 :2 29 :3 d :2 13 18 24
63 66 :2 24 :2 d 59 :3 a :2 15 29
:2 32 4d 12 :2 a 3b 19 d :2 17
29 :2 33 3f 43 52 56 57 :2 52
:2 29 :3 d :2 13 18 24 63 66 :2 24
73 76 :2 24 7a 7d :2 24 87 8a
93 9b :2 a4 :2 93 bc :2 8a :2 24 c4
c7 :2 24 cf d2 :2 24 d7 da :2 24
e6 e9 :2 24 :2 d 5a :2 a d :2 17
29 :2 33 3f 42 51 55 56 :2 51
:2 29 :3 d :2 13 18 24 63 66 :2 24
:2 d 59 :3 a :2 15 29 :2 32 49 56
:2 a :4 7 35 :2 4 8 11 18 :2 11
25 :2 8 28 2a :2 28 7 32 3b
42 :2 3b 50 :2 32 53 55 :2 53 31
:3 7 f 19 :3 7 :2 10 1c :2 7 f
e 11 :2 f e 11 :2 f e 11
:2 f e 11 :2 f e 11 :2 f 3e
41 :2 f 4e 51 :2 f e 11 :2 f
2d 30 :2 f 3b 3e :2 f 5a 5d
:2 f 13 16 :2 f 7 a 12 1c
:2 a 11 d 19 :3 17 d :2 16 22
d 1e d :2 16 22 d :4 a 7
:2 f d :2 16 22 d 10 :2 1a 2c
:2 36 42 46 55 59 5a :2 55 :2 2c
:3 10 :2 16 1b 27 66 69 :2 27 76
79 :2 27 7d 80 :2 27 8c 8f :2 27
97 9a :2 27 a6 a9 b0 b9 bc
:2 a9 :2 27 :3 10 :2 16 1b 3f 48 4b
:2 3f :2 10 5d :2 d :2 a :4 16 :2 a 7
:3 58 7 f 19 :3 7 :2 10 1c :2 7
d e 11 :2 d e 11 :2 d e
11 :2 d e 11 :2 d e 11 :2 d
25 28 :2 d 35 38 :2 d e 11
:2 d 28 2b :2 d 36 39 :2 d 55
58 :2 d 13 16 :2 d 7 a 12
1c :2 a 11 d 19 :3 17 d :2 16
22 d 1e d :2 16 22 d :4 a
7 :2 f d :2 16 22 d 10 :2 1a
2c :2 36 42 46 55 59 5a :2 55
:2 2c :3 10 :2 16 1b 27 66 69 :2 27
76 79 :2 27 7d 80 :2 27 8c 8f
:2 27 97 9a :2 27 a6 a9 b0 b9
bc :2 a9 :2 27 :3 10 :2 16 1b 3f 48
4b :2 3f :2 10 5d :2 d :2 a :4 16 :2 a
7 :3 58 7 :2 10 :3 1c :2 7 d e
11 :2 d e 11 :2 d e 11 :2 d
e 11 :2 d e 11 :2 d e 11
:2 d e 11 :2 d e 11 :2 d e
11 :2 d e 11 :2 d e 11 :2 d
e 11 :2 d 4e 51 :2 d 13 16
:2 d e 11 :2 d 4b 4e :2 d 13
16 :2 d e 11 :2 d e 11 :2 d
13 16 :2 d 21 24 :2 d e 11
:2 d e 11 :2 d e 11 :2 d e
11 :2 d e 11 :2 d e 11 :2 d
e 11 :2 d e 11 :2 d 4f 52
:2 d 13 16 :2 d e 11 :2 d e
11 :2 d e 11 :2 d e 11 :2 d
2d 30 :2 d 3c 3f :2 d e 11
:2 d 7 a 12 1c :2 a 11 d
19 :3 17 d :2 16 22 d 1e d
:2 16 22 d :4 a 7 :2 f d :2 16
22 d 10 :2 1a 2c :2 36 42 46
55 59 5a :2 55 :2 2c :3 10 :2 16 1b
27 66 69 :2 27 76 79 :2 27 7d
80 :2 27 8c 8f :2 27 97 9a :2 27
a6 a9 b0 b9 bc :2 a9 :2 27 :3 10
:2 16 1b 3f 48 4b :2 3f :2 10 5d
:2 d :2 a :4 16 :2 a 7 :3 58 7 d
e 11 :2 d e 11 :2 d e 11
:2 d 3b 3e 46 4f 58 :2 46 :2 3e
:2 d 13 16 :2 d e 11 :2 d 15
18 20 29 34 :2 20 :2 18 :2 d 13
16 :2 d e 11 :2 d e 11 :2 d
e 11 :2 d e 11 :2 d e 11
:2 d e 11 :2 d e 11 :2 d e
11 :2 d 55 58 60 13 1c :2 60
:2 58 :2 d 20 23 :2 d e 11 :2 d
2c 2f 37 40 4b :2 37 :2 2f :2 d
13 16 :2 d e 11 :2 d e 11
:2 d e 11 :2 d e 11 :2 d 7
4 58 a 13 1a :2 13 28 :2 a
2b 2d :2 2b 7 f 19 :3 7 :2 10
1c :2 7 f e 11 :2 f e 11
:2 f e 11 :2 f e 11 :2 f e
11 :2 f 3e 41 :2 f 4e 51 :2 f
e 11 :2 f 27 2a :2 f 35 38
:2 f 7 a 12 1c :2 a 11 d
19 :3 17 d :2 16 22 d 1e d
:2 16 22 d :4 a 7 :2 f d :2 16
22 d 10 :2 1a 2c :2 36 42 46
55 59 5a :2 55 :2 2c :3 10 :2 16 1b
27 66 69 :2 27 76 79 :2 27 7d
80 :2 27 8c 8f :2 27 97 9a :2 27
a6 a9 b0 b9 bc :2 a9 :2 27 :3 10
:2 16 1b 3f 48 4b :2 3f :2 10 5d
:2 d :2 a :4 16 :2 a 7 :3 2f 7 f
19 :3 7 :2 10 1c :2 7 f e 11
:2 f e 11 :2 f e 11 :2 f e
11 :2 f e 11 :2 f 3b 3e :2 f
4b 4e :2 f 13 16 :2 f 21 24
:2 f 7 a 12 1c :2 a 11 d
19 :3 17 d :2 16 22 d 1e d
:2 16 22 d :4 a 7 :2 f d :2 16
22 d 10 :2 1a 2c :2 36 42 46
55 59 5a :2 55 :2 2c :3 10 :2 16 1b
27 66 69 :2 27 76 79 :2 27 7d
80 :2 27 8c 8f :2 27 97 9a :2 27
a6 a9 b0 b9 bc :2 a9 :2 27 :3 10
:2 16 1b 3f 48 4b :2 3f :2 10 5d
:2 d :2 a :4 16 :2 a 7 :3 2f 7 :2 10
:3 1c :2 7 d e 11 :2 d e 11
:2 d e 11 :2 d e 11 :2 d e
11 :2 d e 11 :2 d e 11 :2 d
e 11 :2 d e 11 :2 d 4e 51
:2 d 13 16 :2 d e 11 :2 d 4b
4e :2 d 13 16 :2 d e 11 :2 d
e 11 :2 d 2e 31 :2 d 3c 3f
:2 d 7 a 12 1c :2 a 11 d
19 :3 17 d :2 16 22 d 1e d
:2 16 22 d :4 a 7 :2 f d :2 16
22 d 10 :2 1a 2c :2 36 42 46
55 59 5a :2 55 :2 2c :3 10 :2 16 1b
27 66 69 :2 27 76 79 :2 27 7d
80 :2 27 8c 8f :2 27 97 9a :2 27
a6 a9 b0 b9 bc :2 a9 :2 27 :3 10
:2 16 1b 3f 48 4b :2 3f :2 10 5d
:2 d :2 a :4 16 :2 a 7 :3 2f 7 d
e 11 :2 d e 11 :2 d e 11
:2 d 48 4b 53 5c 65 :2 53 :2 4b
:2 d 13 16 :2 d e 11 19 22
2d :2 19 :2 11 :2 d 13 16 :2 d e
11 :2 d e 11 :2 d e 11 :2 d
e 11 :2 d 7 2f 58 7 f
19 :3 7 :2 10 1c :2 7 f e 11
:2 f e 11 :2 f e 11 :2 f e
11 :2 f e 11 :2 f e 11 :2 f
28 2b :2 f 38 3b :2 f e 11
:2 f 2d 30 :2 f 3c 3f :2 f e
11 :2 f 7 a 12 1c :2 a 11
d 19 :3 17 d :2 16 22 d 1e
d :2 16 22 d :4 a 7 :2 f d
:2 16 22 d 10 :2 1a 2c :2 36 42
46 55 59 5a :2 55 :2 2c :3 10 :2 16
1b 27 66 69 :2 27 76 79 :2 27
7d 80 :2 27 8c 8f :2 27 97 9a
:2 27 a6 a9 b0 b9 bc :2 a9 :2 27
:3 10 :2 16 1b 3f 48 4b :2 3f :2 10
5d :2 d :2 a :4 16 :2 a 7 :3 4 7
f 19 :3 7 :2 10 1c :2 7 f e
11 :2 f e 11 :2 f e 11 :2 f
e 11 :2 f e 11 :2 f 3b 3e
:2 f 4b 4e :2 f 13 16 :2 f 22
25 :2 f 7 a 12 1c :2 a 11
d 19 :3 17 d :2 16 22 d 1e
d :2 16 22 d :4 a 7 :2 f d
:2 16 22 d 10 :2 1a 2c :2 36 42
46 55 59 5a :2 55 :2 2c :3 10 :2 16
1b 27 66 69 :2 27 76 79 :2 27
7d 80 :2 27 8c 8f :2 27 97 9a
:2 27 a6 a9 b0 b9 bc :2 a9 :2 27
:3 10 :2 16 1b 3f 48 4b :2 3f :2 10
5d :2 d :2 a :4 16 :2 a 7 :3 4 7
:2 10 :3 1c :2 7 d e 11 :2 d e
11 :2 d e 11 :2 d e 11 :2 d
e 11 :2 d e 11 :2 d e 11
:2 d e 11 :2 d e 11 :2 d 4e
51 :2 d 13 16 :2 d e 11 :2 d
e 11 :2 d e 11 :2 d 2d 30
:2 d 3c 3f :2 d 7 a 12 1c
:2 a 11 d 19 :3 17 d :2 16 22
d 1e d :2 16 22 d :4 a 7
:2 f d :2 16 22 d 10 :2 1a 2c
:2 36 42 46 55 59 5a :2 55 :2 2c
:3 10 :2 16 1b 27 66 69 :2 27 76
79 :2 27 7d 80 :2 27 8c 8f :2 27
97 9a :2 27 a6 a9 b0 b9 bc
:2 a9 :2 27 :3 10 :2 16 1b 3f 48 4b
:2 3f :2 10 5d :2 d :2 a :4 16 :2 a 7
:3 4 7 f e 11 :2 f e 11
:2 f e 11 :2 f 13 16 1e 27
30 :2 1e :2 16 :2 f 34 37 :2 f e
11 :2 f 54 57 5f 13 1e :2 5f
:2 57 :2 f 13 16 :2 f e 11 :2 f
e 11 :2 f e 11 :2 f e 11
:2 f 7 :4 4 7 :2 11 23 :2 2d 39
3c 4b 4f 50 :2 4b :2 23 :3 7 :2 d
12 1e 5d 60 :2 1e :2 7 53 :2 4
7 :2 11 23 :2 2d 39 3c 4b 4f
50 :2 4b :2 23 :3 7 :2 d 12 1e 5d
60 :2 1e :2 7 53 :3 4 b :2 16 26
:2 b 4 1 9 12 9 a :2 14
26 :2 30 3c 40 4f 53 54 :2 4f
:2 26 :3 a :2 10 15 21 60 63 :2 21
:3 a :2 10 15 39 5c 5f :2 68 :2 39
76 79 :2 39 81 84 :2 8d :2 39 :2 a
57 :3 7 c 15 1e 2c a 13
1e f e 7 e 7 e 7
29 :2 4 :2 9 7 :2 10 1c :2 7 :2 11
23 :2 2d 39 3d 4c 50 51 :2 4c
:2 23 :3 7 :2 d 12 1e 5d 60 :2 1e
:3 7 :2 d 12 36 42 45 :2 36 4d
50 :2 36 5c 5f 66 6f 72 :2 5f
:2 36 :2 7 54 :2 4 7 c 1b a
13 1e f e 7 e 7 e
7 :2 4 :4 10 :2 4 :8 1 
2fe6
4
0 :2 1 :4 3 :4 4
:4 5 :4 6 :4 7 :4 8
:4 9 :4 a :4 b :4 c
:4 d :4 e :4 f :4 10
:4 11 2 :4 12 :2 1
:7 14 :7 15 :7 16 :7 17
:7 18 :7 19 :7 1a :7 1b
:7 1c :7 1d :5 1e :5 1f
:7 20 :7 21 :7 22 :7 23
:7 24 :7 25 :6 26 :6 27
:6 28 :6 29 :6 2a :6 2b
:6 2c :6 2d :6 2e :6 2f
:6 30 :6 31 :6 32 :6 33
:6 34 :6 35 :6 36 :6 37
:6 38 :6 39 :6 3a :6 3b
:6 3c :6 3d :6 3e :6 3f
:6 40 :6 41 :7 42 :7 43
:6 44 :7 45 :6 46 :7 47
:7 48 :7 49 :6 4a :6 4b
:6 4c :7 4d :7 4e :6 4f
:6 50 :7 51 :6 52 :6 53
:6 54 :6 55 :5 56 :7 58
:b 5a :11 5b 5c :2 5b
:2 5c :2 5b :2 5c :2 5b
:2 5d :2 5b :2 5d :2 5b
:2 5d :2 5b :2 5d :2 5b
:2 5e :2 5b :2 5e :2 5b
:2 5e :2 5b :2 5e :2 5b
:2 5f :2 5b :9 5f :2 5b
:2 60 :2 5b :9 60 :2 5b
:2 61 :2 5b :9 61 :2 5b
:2 62 :2 5b :9 62 :2 5b
:2 63 :2 5b :9 63 :2 5b
:2 64 :2 5b :9 64 :2 5b
:2 65 :2 5b :9 65 :2 5b
:2 66 :2 5b :9 66 :2 5b
:2 67 :2 5b :9 67 :2 5b
:2 68 :2 5b :9 68 :2 5b
:2 69 :2 5b :2 69 :2 5b
:2 69 :2 5b :2 69 :2 5b
:2 6a :2 5b :2 6a :2 5b
:2 6a :2 5b :2 6a :2 5b
:2 6a :4 5b :3 5a :11 6d
:b 6e :3 6d :3 76 :3 77
:3 78 :3 79 :3 7b :3 7d
:3 7f :3 81 :3 82 :3 83
:3 84 :3 85 :3 86 :3 87
:3 89 :3 8a :3 8b :a 8c
:3 8d :3 92 :3 93 :5 95
:11 96 :20 97 :3 96 :11 99
:b 9a :3 99 :9 9c :3 95
:5 9f :11 a0 :20 a1 :3 a0
:11 a3 :b a4 :3 a3 :9 a6
:3 9f :1f b3 :11 b4 :20 b5
:3 b4 :11 b7 :b b8 :3 b7
:9 ba :3 b3 :e bd :6 bf
c0 c1 bf :5 c2
be :2 c4 :5 c6 :11 c7
:24 c8 :3 c7 :2 c5 :6 c4
c3 :3 bd :16 cd :11 ce
:20 cf :3 ce :11 d1 :b d2
:3 d1 :9 d4 :3 cd :3 d7
d8 bd :e d8 :2 da
db da :5 dc d9
:2 de :5 e0 :11 e1 :24 e2
:3 e1 :2 df :6 de dd
:4 d8 :3 bd :3 e8 :5 e9
:3 ea :3 e9 :8 ed :8 ee
:3 ef :9 f1 :d f3 :b f4
:c f6 :6 f8 :4 f9 :3 fa
f8 :5 fb f7 :2 fd
:5 ff :11 100 :24 101 :3 100
:2 fe :6 fd fc :4 f6
:a 107 :8 108 :5 109 :7 10a
:27 10b 107 :5 10c 106
:2 10e :5 110 :11 111 :24 112
:3 111 :2 10f :6 10e 10d
:4 105 :3 f6 :a 118 :4 11a
:3 11b 11a :5 11c 119
:2 11e :5 120 :11 121 :24 122
:3 121 :2 11f :6 11e 11d
:3 118 :a 127 :5 128 :3 129
:3 128 :5 12c :3 12d :3 12e
12c :5 12f 12b :2 131
:5 133 :11 134 :24 135 :3 134
:2 132 :6 131 130 :4 127
:11 13a :30 13b :3 13a :11 13d
:b 13e :3 13d :a 140 139
:3 127 118 :3 143 142
:3 118 :3 146 :2 148 149
:2 14a 148 :5 14b 147
:2 14d :5 14f :11 150 :24 151
:3 150 :2 14e :6 14d 14c
:3 f1 :9 156 :2 158 159
:2 15a 158 :5 15b 157
:2 15d :5 15f :11 160 :24 161
:3 160 :2 15e :6 15d 15c
:3 156 :b 166 :11 167 :30 168
:3 167 :11 16a :b 16b :3 16a
:a 16d :3 166 :3 156 f1
:5 172 :3 173 :3 174 172
:5 175 171 :2 177 :5 179
:11 17a :24 17b :3 17a :2 178
:6 177 176 :3 170 :a 17f
:6 181 :5 182 180 :2 184
:5 186 :11 187 :24 188 :3 187
:2 185 :6 184 183 :3 17f
:a 18c :11 18d :30 18e :3 18d
:11 190 :b 191 :3 190 :a 193
:3 18c :3 17f 170 :3 f1
:5 1a6 :3 1a7 :3 1a8 :e 1a9
:b 1aa :2 1ab :2 1aa :a 1ab
:8 1ac :3 1a9 :b 1ae :11 1af
:20 1b0 :3 1af :11 1b2 :b 1b3
:3 1b2 :9 1b5 1b6 1ae
:9 1b6 :11 1b7 :2e 1b8 :3 1b7
:11 1ba :b 1bb :3 1ba :c 1bd
1b6 :3 1ae :3 1c0 :5 1c1
:3 1c2 :3 1c1 1c4 1a6
:16 1c4 :16 1c5 :3 1c6 1c7
1c5 :9 1c7 :3 1c8 1c9
1c7 1c5 :16 1c9 :3 1ca
1cb 1c9 1c5 :9 1cb
:f 1cc :3 1cd 1cb :3 1c5
1c4 :3 1a6 :5 1d2 :3 1d4
:3 1d5 :14 1d7 :d 1d9 :9 1db
:7 1dc 1dd :3 1dc :9 1df
:11 1e0 :2e 1e1 :3 1e0 :11 1e3
:b 1e4 :3 1e3 :c 1e6 :3 1df
:3 1e9 :9 1ec :2 1ed 1ee
:2 1ef :2 1f0 :2 1f1 :2 1f2
1ec :5 1f3 1eb :2 1f5
:5 1f7 :11 1f8 :24 1f9 :3 1f8
:2 1f6 :6 1f5 1f4 :3 1db
:12 1fe :3 1ff :9 200 :3 201
:3 200 :3 1fe :3 205 :3 206
:5 207 :a 208 :8 20a :9 20b
:4 20c 20d :6 20e 20a
:5 20f 209 :2 211 :5 213
:11 214 :24 215 :3 214 :2 212
:6 211 210 :3 208 :a 21a
:3 21b :16 21c :8 21e :8 21f
:3 220 221 :6 222 21e
:5 223 21d :2 225 :5 227
:11 228 :24 229 :3 228 :2 226
:6 225 224 :4 21c :3 22e
22d :3 21c 230 21a
:16 230 :8 232 :8 233 :3 234
235 :6 236 232 :5 237
231 :2 239 :5 23b :11 23c
:24 23d :3 23c :2 23a :6 239
238 :4 230 :3 21a 208
:8 244 :8 245 :3 246 247
:6 248 244 :5 249 243
:2 24b :5 24d :11 24e :24 24f
:3 24e :2 24c :6 24b 24a
:4 242 :3 208 207 :a 255
:e 257 :4 258 259 :6 25a
257 :5 25b 256 :2 25d
:5 25f :11 260 :24 261 :3 260
:2 25e :6 25d 25c :3 255
:a 266 :3 267 :16 268 :a 26a
:3 26b 26c :6 26d 26a
:5 26e 269 :2 270 :5 272
:11 273 :24 274 :3 273 :2 271
:6 270 26f :4 268 :3 279
27a 278 :3 268 27c
266 :a 27c :d 27e :3 27f
280 :6 281 27e :5 282
27d :2 284 :5 286 :11 287
:24 288 :3 287 :2 285 :6 284
283 :4 27c :3 266 255
:d 28f :3 290 291 :6 292
28f :5 293 28e :2 295
:5 297 :11 298 :24 299 :3 298
:2 296 :6 295 294 :4 28d
:3 255 254 :3 207 :a 2a0
:9 2a1 :11 2a2 :30 2a3 :3 2a2
:11 2a5 :b 2a6 :3 2a5 :a 2a8
2a9 2a1 :5 2a9 :5 2aa
:3 2ab :3 2ad 2ae :4 2af
:7 2b0 2ad :5 2b1 2ac
:2 2b3 :5 2b5 :11 2b6 :24 2b7
:3 2b6 :2 2b4 :6 2b3 2b2
:4 2aa :3 2bc :3 2be 2bf
:4 2c0 :4 2c1 2be :5 2c2
2bd :2 2c4 :5 2c6 :11 2c7
:24 2c8 :3 2c7 :2 2c5 :6 2c4
2c3 :4 2bb :3 2aa :d 2ce
:11 2cf :30 2d0 :3 2cf :11 2d2
:b 2d3 :3 2d2 :a 2d5 :3 2ce
2a9 :3 2a1 :3 2d8 2d9
2a0 :19 2d9 :11 2da :30 2db
:3 2da :11 2dd :b 2de :3 2dd
:a 2e0 2d9 :3 2a0 :a 2e3
:c 2e4 :d 2e7 :5 2e8 2e9
:2 2ea 2e7 :5 2eb 2e6
:2 2ed :5 2ef :11 2f0 :24 2f1
:3 2f0 :2 2ee :6 2ed 2ec
:3 2e3 :a 2f6 :11 2f7 :30 2f8
:3 2f7 :11 2fa :b 2fb :3 2fa
:a 2fd :3 2f6 :16 300 :2 301
:2 300 :8 301 :6 300 :11 302
:30 303 :3 302 :11 305 :b 306
:3 305 :a 308 301 :2 300
:6 30c 30d :5 30e 30c
:5 30f 30b :2 311 :5 313
:11 314 :24 315 :3 314 :2 312
:6 311 310 :4 2e3 :c 31a
:6 31d :5 31e 31c :2 320
:5 322 :11 323 :24 324 :3 323
:2 321 :6 320 31f :3 319
:a 329 :11 32a :30 32b :3 32a
:11 32d :b 32e :3 32d :a 330
:3 329 :c 334 :2 335 336
:5 337 334 :5 338 333
:2 33a :5 33c :11 33d :24 33e
:3 33d :2 33b :6 33a 339
:3 319 :16 343 :11 344 :30 345
:3 344 :11 347 :b 348 :3 347
:a 34a :3 343 :6 34e 34f
:5 350 34e :5 351 34d
:2 353 :5 355 :11 356 :24 357
:3 356 :2 354 :6 353 352
:4 319 :3 2e3 :3 35d :9 35f
:9 361 362 361 :5 363
360 :2 365 :5 367 :11 368
:24 369 :3 368 :2 366 :6 365
364 :3 35f :7 36f 370
371 372 36f :5 373
36e :2 375 :5 377 :11 378
:24 379 :3 378 :2 376 :6 375
374 :3 35f :3 37e :3 37f
:9 380 :3 381 :3 380 :8 384
:5 385 :8 386 :6 387 :7 388
:3 384 :5 38a :9 38b :5 38d
:6 38e :5 38f 38e :5 391
390 :3 38e 38c :2 394
:5 396 :11 397 :24 398 :3 397
:2 395 :6 394 393 :4 38b
:5 39e :6 39f :5 3a0 39f
:5 3a2 3a1 :3 39f 39d
:2 3a5 :5 3a7 :11 3a8 :24 3a9
:3 3a8 :2 3a6 :6 3a5 3a4
:4 39c :3 38b :3 38a 35f
:3 3b1 :3 3b2 :a 3b4 :5 3b5
3b4 :d 3b7 3b6 :3 3b4
:8 3ba :5 3bb :8 3bc :6 3bd
:7 3be :3 3ba :5 3c0 :5 3c2
:6 3c3 :5 3c4 3c3 :5 3c6
3c5 :3 3c3 3c1 :2 3c9
:5 3cb :11 3cc :24 3cd :3 3cc
:2 3ca :6 3c9 3c8 :6 3c0
3af :3 35f 1db :c 3d6
:3 3d7 3d6 :16 3d9 3d8
:3 3d6 :5 3db :3 3dc :c 3dd
:3 3de :17 3e1 :1b 3e3 :3 3e5
:3 3e6 :3 3e7 :3 3e8 :5 3eb
3ec :4 3ed :4 3ee 3eb
:5 3ef 3ea :2 3f1 :5 3f3
:11 3f4 :24 3f5 :3 3f4 :2 3f2
:6 3f1 3f0 :3 3dd :12 3fa
:3 3fb :b 3fc :3 3fd :3 3fc
:3 3fa :a 401 :5 402 :c 403
:3 404 403 :c 406 :c 407
405 :3 403 401 :c 40a
:3 40b 40a :c 40d :c 40e
40c :3 40a 409 :3 401
:3 412 :3 413 :9 415 :5 416
:a 417 :8 419 :9 41a :4 41b
41c :6 41d 419 :5 41e
418 :2 420 :5 422 :11 423
:24 424 :3 423 :2 421 :6 420
41f :3 417 :a 429 :3 42a
:16 42b :8 42d :8 42e :3 42f
430 :6 431 42d :5 432
42c :2 434 :5 436 :11 437
:24 438 :3 437 :2 435 :6 434
433 :4 42b :3 43d 43c
:3 42b 43f 429 :16 43f
:8 441 :8 442 :3 443 444
:6 445 441 :5 446 440
:2 448 :5 44a :11 44b :24 44c
:3 44b :2 449 :6 448 447
:4 43f :3 429 417 :8 453
:8 454 :4 455 :4 456 :4 457
453 :5 458 452 :2 45a
:5 45c :11 45d :24 45e :3 45d
:2 45b :6 45a 459 :4 451
:3 417 416 :a 464 :e 466
:5 467 :4 468 :4 469 466
:5 46a 465 :2 46c :5 46e
:11 46f :24 470 :3 46f :2 46d
:6 46c 46b :3 464 :a 475
:16 476 :a 478 :4 479 :4 47a
:4 47b 478 :5 47c 477
:2 47e :5 480 :11 481 :24 482
:3 481 :2 47f :6 47e 47d
:4 476 :3 487 488 486
:3 476 48a 475 :a 48a
:d 48c :4 48d :4 48e :4 48f
48c :5 490 48b :2 492
:5 494 :11 495 :24 496 :3 495
:2 493 :6 492 491 :4 48a
:3 475 464 :d 49d :4 49e
:4 49f :4 4a0 49d :5 4a1
49c :2 4a3 :5 4a5 :11 4a6
:24 4a7 :3 4a6 :2 4a4 :6 4a3
4a2 :4 49b :3 464 463
:3 416 :a 4ae :9 4af :3 4b0
4af :5 4b2 :5 4b3 :3 4b4
:3 4b6 4b7 :4 4b8 :7 4b9
4b6 :5 4ba 4b5 :2 4bc
:5 4be :11 4bf :24 4c0 :3 4bf
:2 4bd :6 4bc 4bb :4 4b3
:3 4c5 :3 4c7 4c8 :4 4c9
:4 4ca 4c7 :5 4cb 4c6
:2 4cd :5 4cf :11 4d0 :24 4d1
:3 4d0 :2 4ce :6 4cd 4cc
:4 4c4 :3 4b3 :d 4d6 :b 4d7
:2 4d8 :3 4d6 :3 4b2 :3 4db
4b1 :3 4af 4ae :b 4de
:2 4df 4dd :3 4ae :3 4e2
:3 4e3 :8 4e6 4e7 4e8
4e6 :5 4e9 4e5 :2 4eb
:5 4ed :11 4ee :24 4ef :3 4ee
:2 4ec :6 4eb 4ea :3 415
:8 4f5 4f6 4f7 4f5
:5 4f8 4f4 :2 4fa :5 4fc
:11 4fd :24 4fe :3 4fd :2 4fb
:6 4fa 4f9 :3 415 :3 503
:3 504 :9 505 :3 506 :3 505
:8 509 :5 50a :8 50b :6 50c
:7 50d :3 509 :5 50f :9 510
:5 512 :6 513 :5 514 513
:5 516 515 :3 513 511
:2 519 :5 51b :11 51c :24 51d
:3 51c :2 51a :6 519 518
:4 510 :5 523 :6 524 :5 525
524 :5 527 526 :3 524
522 :2 52a :5 52c :11 52d
:24 52e :3 52d :2 52b :6 52a
529 :4 521 :3 510 :3 50f
534 415 :9 534 :3 535
:3 536 :a 538 :5 539 538
:7 53b 53a :3 538 :8 53e
:5 53f :8 540 :6 541 :7 542
:3 53e :5 543 :5 545 :6 546
:5 547 546 :5 549 548
:3 546 544 :2 54c :5 54e
:11 54f :24 550 :3 54f :2 54d
:6 54c 54b :6 543 534
:3 415 :b 556 557 558
:3 3dd 559 3dd :3 3db
3d3 :3 1db :12 55e :9 55f
:4 561 :6 562 :5 563 562
:5 565 564 :3 562 560
:2 568 :5 56a :11 56b :24 56c
:3 56b :2 569 :6 568 567
:4 55f :5 572 :2 573 572
:6 574 :5 575 574 :5 577
576 :3 574 571 :2 57a
:5 57c :11 57d :24 57e :3 57d
:2 57b :6 57a 579 :4 570
:3 55f :5 584 :11 585 :30 586
:3 585 :11 588 :b 589 :3 588
:a 58b 58c 584 :7 58c
:11 58d :30 58e :3 58d :11 590
:b 591 :3 590 :7 593 594
:2 593 595 58c 584
:7 595 :11 596 :30 597 :3 596
:11 599 :b 59a :3 599 :7 59c
59d :2 59c 595 584
:11 59f :30 5a0 :3 59f :11 5a2
:b 5a3 :3 5a2 :a 5a5 59e
:3 584 :3 55e :1c 5a9 :5 5ab
:5 5ac :2 5ae :2 5af :2 5ae
:2 5b0 :2 5ae :2 5b1 :2 5ae
:2 5b2 :2 5ae :2 5b3 :2 5ae
:2 5b3 :2 5ae :2 5b3 :2 5ae
:2 5b4 :2 5ae :2 5b4 :2 5ae
:2 5b4 :2 5ae :2 5b4 :2 5ae
:2 5b5 :3 5ae :5 5b8 :6 5b9
:5 5ba 5b9 :5 5bc 5bb
:3 5b9 5b7 :2 5bf :5 5c1
:11 5c2 :24 5c3 :b 5c4 :3 5c2
:2 5c0 :6 5bf 5be :3 5a9
:5 5ca :5 5cb 5cd 5ce
:2 5cf :2 5ce :2 5d0 :2 5ce
:2 5d1 :2 5ce :2 5d2 :2 5ce
:2 5d3 :2 5ce :2 5d3 :2 5ce
:2 5d3 :2 5ce :2 5d4 :2 5ce
:2 5d4 :2 5ce :2 5d4 :2 5ce
:2 5d4 :2 5ce :2 5d5 :2 5ce
5cd :5 5d8 :6 5d9 :5 5da
5d9 :5 5dc 5db :3 5d9
5d7 :2 5df :5 5e1 :11 5e2
:24 5e3 :b 5e4 :3 5e2 :2 5e0
:6 5df 5de :3 5a9 :7 5e9
5eb 5ec :2 5ed :2 5ec
:2 5ee :2 5ec :2 5ef :2 5ec
:2 5f0 :2 5ec :2 5f1 :2 5ec
:2 5f2 :2 5ec :2 5f3 :2 5ec
:2 5f4 :2 5ec :2 5f5 :2 5ec
:2 5f6 :2 5ec :2 5f7 :2 5ec
:2 5f8 :2 5ec :2 5f8 :2 5ec
:2 5f9 :2 5ec :2 5fa :2 5ec
:2 5fa :2 5ec :2 5fb :2 5ec
:2 5fc :2 5ec :2 5fd :2 5ec
:2 5fe :2 5ec :2 5fe :2 5ec
:2 5ff :2 5ec :2 600 :2 5ec
:2 601 :2 5ec :2 602 :2 5ec
:2 603 :2 5ec :2 604 :2 5ec
:2 605 :2 5ec :2 606 :2 5ec
:2 606 :2 5ec :2 607 :2 5ec
:2 608 :2 5ec :2 609 :2 5ec
:2 60a :2 5ec :2 60b :2 5ec
:2 60b :2 5ec :2 60b :2 5ec
:2 60c :2 5ec 5eb :5 60f
:6 610 :5 611 610 :5 613
612 :3 610 60e :2 616
:5 618 :11 619 :24 61a :b 61b
:3 619 :2 617 :6 616 615
:3 5a9 620 621 :2 622
:2 621 :2 623 :2 621 :2 624
:2 621 :9 624 :2 621 :2 625
:2 621 :2 626 :2 621 :9 626
:2 621 :2 627 :2 621 :2 628
:2 621 :2 629 :2 621 :2 62a
:2 621 :2 62b :2 621 :2 62c
:2 621 :2 62d :2 621 :2 62e
:2 621 :2 62f :2 621 :3 62f
:2 630 :4 62f :2 621 :2 630
:2 621 :2 631 :2 621 :9 631
:2 621 :2 632 :2 621 :2 633
:2 621 :2 634 :2 621 :2 635
:2 621 :2 636 :2 621 620
637 5a9 :c 637 :5 639
:5 63a :2 63c :2 63d :2 63c
:2 63e :2 63c :2 63f :2 63c
:2 640 :2 63c :2 641 :2 63c
:2 641 :2 63c :2 641 :2 63c
:2 642 :2 63c :2 642 :2 63c
:2 642 :3 63c :5 645 :6 646
:5 647 646 :5 649 648
:3 646 644 :2 64c :5 64e
:11 64f :24 650 :b 651 :3 64f
:2 64d :6 64c 64b :3 637
:5 657 :5 658 :2 65a :2 65b
:2 65a :2 65c :2 65a :2 65d
:2 65a :2 65e :2 65a :2 65f
:2 65a :2 65f :2 65a :2 65f
:2 65a :2 660 :2 65a :2 660
:3 65a :5 663 :6 664 :5 665
664 :5 667 666 :3 664
662 :2 66a :5 66c :11 66d
:24 66e :b 66f :3 66d :2 66b
:6 66a 669 :3 637 :7 674
675 676 :2 677 :2 676
:2 678 :2 676 :2 679 :2 676
:2 67a :2 676 :2 67b :2 676
:2 67c :2 676 :2 67d :2 676
:2 67e :2 676 :2 67f :2 676
:2 67f :2 676 :2 680 :2 676
:2 681 :2 676 :2 681 :2 676
:2 682 :2 676 :2 683 :2 676
:2 684 :2 676 :2 684 :2 676
:2 684 :2 676 675 :5 687
:6 688 :5 689 688 :5 68b
68a :3 688 686 :2 68e
:5 690 :11 691 :24 692 :b 693
:3 691 :2 68f :6 68e 68d
:3 637 698 699 :2 69a
:2 699 :2 69b :2 699 :2 69c
:2 699 :9 69c :2 699 :2 69d
:2 699 :9 69e :2 699 :2 69f
:2 699 :2 6a0 :2 699 :2 6a1
:2 699 :2 6a2 :2 699 :2 6a3
:2 699 698 637 5a9
:5 6a6 :5 6a7 :2 6a9 :2 6aa
:2 6a9 :2 6ab :2 6a9 :2 6ac
:2 6a9 :2 6ad :2 6a9 :2 6ae
:2 6a9 :2 6af :2 6a9 :2 6af
:2 6a9 :2 6af :2 6a9 :2 6b0
:2 6a9 :2 6b0 :2 6a9 :2 6b0
:2 6a9 :2 6b1 :3 6a9 :5 6b4
:6 6b5 :5 6b6 6b5 :5 6b8
6b7 :3 6b5 6b3 :2 6bb
:5 6bd :11 6be :24 6bf :b 6c0
:3 6be :2 6bc :6 6bb 6ba
:3 6a4 :5 6c6 :5 6c7 :2 6c9
:2 6ca :2 6c9 :2 6cb :2 6c9
:2 6cc :2 6c9 :2 6cd :2 6c9
:2 6ce :2 6c9 :2 6ce :2 6c9
:2 6ce :2 6c9 :2 6cf :2 6c9
:2 6cf :3 6c9 :5 6d2 :6 6d3
:5 6d4 6d3 :5 6d6 6d5
:3 6d3 6d1 :2 6d9 :5 6db
:11 6dc :24 6dd :b 6de :3 6dc
:2 6da :6 6d9 6d8 :3 6a4
:7 6e3 6e5 6e6 :2 6e7
:2 6e6 :2 6e8 :2 6e6 :2 6e9
:2 6e6 :2 6ea :2 6e6 :2 6eb
:2 6e6 :2 6ec :2 6e6 :2 6ed
:2 6e6 :2 6ee :2 6e6 :2 6ef
:2 6e6 :2 6ef :2 6e6 :2 6f0
:2 6e6 :2 6f1 :2 6e6 :2 6f2
:2 6e6 :2 6f3 :2 6e6 :2 6f3
:2 6e6 :2 6f3 :2 6e6 6e5
:5 6f6 :6 6f7 :5 6f8 6f7
:5 6fa 6f9 :3 6f7 6f5
:2 6fd :5 6ff :11 700 :24 701
:b 702 :3 700 :2 6fe :6 6fd
6fc :3 6a4 :2 707 :2 708
:2 707 :2 709 :2 707 :2 70a
:2 707 :9 70b :2 707 :2 70b
:2 707 :2 70c :2 707 :3 70c
:2 70d :4 70c :2 707 :2 70e
:2 707 :2 70f :2 707 :2 710
:2 707 :2 711 :2 707 :2 712
:3 707 6a4 :3 5a9 :11 716
:b 717 :3 716 :11 719 :b 71a
:3 719 :8 71c 59 :3 720
:11 721 :b 722 :17 723 :3 721
:2 725 :3 726 :3 727 728
726 725 726 :3 729
:3 720 :2 72a :5 72c :11 72d
:b 72e :18 72f :3 72d :2 731
732 :3 733 734 732
731 732 :3 735 :2 72b
:6 72a 71f :7 1 
a6a7
4
:3 0 1 :3 0 2
:a 0 2fe1 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
56 0 7 4
:3 0 5 :7 0 9
8 :3 0 4 :3 0
6 :7 0 d c
:3 0 d 7c 0
b 8 :3 0 7
:7 0 11 10 :3 0
8 :3 0 9 :7 0
15 14 :3 0 11
a2 0 f 8
:3 0 a :7 0 19
18 :3 0 8 :3 0
b :7 0 1d 1c
:3 0 15 c8 0
13 8 :3 0 c
:7 0 21 20 :3 0
8 :3 0 d :7 0
25 24 :3 0 19
ee 0 17 8
:3 0 e :7 0 29
28 :3 0 8 :3 0
f :7 0 2d 2c
:3 0 1d 114 0
1b 8 :3 0 10
:7 0 31 30 :3 0
8 :3 0 11 :7 0
35 34 :3 0 21
:2 0 1f 4 :3 0
12 :7 0 39 38
:3 0 4 :3 0 13
:7 0 3d 3c :3 0
14 :3 0 15 :3 0
16 :2 0 4 41
42 0 3f 43
0 2fe1 2 44
:2 0 18 :2 0 33
4 :3 0 18 :2 0
31 47 49 :6 0
4c 4a 0 2fdf
0 17 :6 0 18
:2 0 37 4 :3 0
35 4e 50 :6 0
53 51 0 2fdf
0 19 :6 0 18
:2 0 3b 4 :3 0
39 55 57 :6 0
5a 58 0 2fdf
0 1a :6 0 18
:2 0 3f 4 :3 0
3d 5c 5e :6 0
61 5f 0 2fdf
0 1b :6 0 18
:2 0 43 4 :3 0
41 63 65 :6 0
68 66 0 2fdf
0 1c :6 0 18
:2 0 47 4 :3 0
45 6a 6c :6 0
6f 6d 0 2fdf
0 1d :6 0 20
:2 0 4b 4 :3 0
49 71 73 :6 0
76 74 0 2fdf
0 1e :6 0 20
:2 0 4f 4 :3 0
4d 78 7a :6 0
7d 7b 0 2fdf
0 1f :6 0 20
:2 0 53 4 :3 0
51 7f 81 :6 0
84 82 0 2fdf
0 21 :6 0 59
276 0 57 4
:3 0 55 86 88
:6 0 8b 89 0
2fdf 0 22 :6 0
27 :2 0 5b 24
:3 0 8d :7 0 90
8e 0 2fdf 0
23 :6 0 24 :3 0
92 :7 0 95 93
0 2fdf 0 25
:6 0 18 :2 0 5f
4 :3 0 5d 97
99 :6 0 9c 9a
0 2fdf 0 26
:6 0 2a :2 0 63
4 :3 0 61 9e
a0 :6 0 a3 a1
0 2fdf 0 28
:6 0 2a :2 0 67
4 :3 0 65 a5
a7 :6 0 aa a8
0 2fdf 0 29
:6 0 2a :2 0 6b
4 :3 0 69 ac
ae :6 0 b1 af
0 2fdf 0 2b
:6 0 2e :2 0 6f
4 :3 0 6d b3
b5 :6 0 b8 b6
0 2fdf 0 2c
:6 0 30 :2 0 73
4 :3 0 71 ba
bc :6 0 bf bd
0 2fdf 0 2d
:6 0 30 :2 0 75
8 :3 0 c1 :7 0
c5 c2 c3 2fdf
0 2f :6 0 30
:2 0 77 8 :3 0
c7 :7 0 cb c8
c9 2fdf 0 31
:6 0 30 :2 0 79
8 :3 0 cd :7 0
d1 ce cf 2fdf
0 32 :6 0 30
:2 0 7b 8 :3 0
d3 :7 0 d7 d4
d5 2fdf 0 33
:6 0 30 :2 0 7d
8 :3 0 d9 :7 0
dd da db 2fdf
0 34 :6 0 30
:2 0 7f 8 :3 0
df :7 0 e3 e0
e1 2fdf 0 35
:6 0 30 :2 0 81
8 :3 0 e5 :7 0
e9 e6 e7 2fdf
0 36 :6 0 30
:2 0 83 8 :3 0
eb :7 0 ef ec
ed 2fdf 0 37
:6 0 30 :2 0 85
8 :3 0 f1 :7 0
f5 f2 f3 2fdf
0 38 :6 0 30
:2 0 87 8 :3 0
f7 :7 0 fb f8
f9 2fdf 0 39
:6 0 30 :2 0 89
8 :3 0 fd :7 0
101 fe ff 2fdf
0 3a :6 0 30
:2 0 8b 8 :3 0
103 :7 0 107 104
105 2fdf 0 3b
:6 0 30 :2 0 8d
8 :3 0 109 :7 0
10d 10a 10b 2fdf
0 3c :6 0 30
:2 0 8f 8 :3 0
10f :7 0 113 110
111 2fdf 0 3d
:6 0 30 :2 0 91
8 :3 0 115 :7 0
119 116 117 2fdf
0 3e :6 0 30
:2 0 93 8 :3 0
11b :7 0 11f 11c
11d 2fdf 0 3f
:6 0 30 :2 0 95
8 :3 0 121 :7 0
125 122 123 2fdf
0 40 :6 0 30
:2 0 97 8 :3 0
127 :7 0 12b 128
129 2fdf 0 41
:6 0 30 :2 0 99
8 :3 0 12d :7 0
131 12e 12f 2fdf
0 42 :6 0 30
:2 0 9b 8 :3 0
133 :7 0 137 134
135 2fdf 0 43
:6 0 30 :2 0 9d
8 :3 0 139 :7 0
13d 13a 13b 2fdf
0 44 :6 0 30
:2 0 9f 8 :3 0
13f :7 0 143 140
141 2fdf 0 45
:6 0 30 :2 0 a1
8 :3 0 145 :7 0
149 146 147 2fdf
0 46 :6 0 30
:2 0 a3 8 :3 0
14b :7 0 14f 14c
14d 2fdf 0 47
:6 0 30 :2 0 a5
8 :3 0 151 :7 0
155 152 153 2fdf
0 48 :6 0 30
:2 0 a7 8 :3 0
157 :7 0 15b 158
159 2fdf 0 49
:6 0 30 :2 0 a9
8 :3 0 15d :7 0
161 15e 15f 2fdf
0 4a :6 0 27
:2 0 ab 8 :3 0
163 :7 0 167 164
165 2fdf 0 4b
:6 0 27 :2 0 af
4 :3 0 ad 169
16b :6 0 16e 16c
0 2fdf 0 4c
:6 0 50 :2 0 b3
4 :3 0 b1 170
172 :6 0 175 173
0 2fdf 0 4d
:6 0 52 :2 0 b5
4f :3 0 177 :7 0
17b 178 179 2fdf
0 4e :6 0 30
:2 0 b9 4 :3 0
b7 17d 17f :6 0
182 180 0 2fdf
0 51 :6 0 18
:2 0 bb 8 :3 0
184 :7 0 188 185
186 2fdf 0 53
:6 0 18 :2 0 bf
55 :3 0 bd 18a
18c :6 0 18f 18d
0 2fdf 0 54
:6 0 18 :2 0 c3
55 :3 0 c1 191
193 :6 0 196 194
0 2fdf 0 56
:6 0 30 :2 0 c7
4 :3 0 c5 198
19a :6 0 19d 19b
0 2fdf 0 57
:6 0 30 :2 0 c9
8 :3 0 19f :7 0
1a3 1a0 1a1 2fdf
0 58 :6 0 30
:2 0 cb 8 :3 0
1a5 :7 0 1a9 1a6
1a7 2fdf 0 59
:6 0 20 :2 0 cd
8 :3 0 1ab :7 0
1af 1ac 1ad 2fdf
0 5a :6 0 20
:2 0 d1 4 :3 0
cf 1b1 1b3 :6 0
1b6 1b4 0 2fdf
0 5b :6 0 30
:2 0 d5 4 :3 0
d3 1b8 1ba :6 0
1bd 1bb 0 2fdf
0 5c :6 0 30
:2 0 d7 8 :3 0
1bf :7 0 1c3 1c0
1c1 2fdf 0 5d
:6 0 18 :2 0 d9
8 :3 0 1c5 :7 0
1c9 1c6 1c7 2fdf
0 5e :6 0 27
:2 0 dd 4 :3 0
db 1cb 1cd :6 0
1d0 1ce 0 2fdf
0 5f :6 0 27
:2 0 df 8 :3 0
1d2 0 2 :5 0
1d6 1d3 1d4 2fdf
0 60 :6 0 30
:2 0 e1 8 :3 0
1d8 0 2 :5 0
1dc 1d9 1da 2fdf
0 61 :6 0 30
:2 0 e3 8 :3 0
1de 0 2 :5 0
1e2 1df 1e0 2fdf
0 62 :6 0 e7
8a1 0 e5 8
:3 0 1e4 0 2
:5 0 1e8 1e5 1e6
2fdf 0 63 :6 0
1f5 1f6 0 e9
8 :3 0 1ea :7 0
1ed 1eb 0 2fdf
0 64 :6 0 15
:3 0 16 :2 0 4
1ef 1f0 0 1f1
:7 0 1f4 1f2 0
2fdf 0 65 :6 0
66 :3 0 67 :3 0
66 :3 0 68 :3 0
1f8 1f9 0 2
:4 0 eb 1fa 1fc
1f7 1fe 1fd :2 0
69 :3 0 6a :3 0
200 201 0 6b
:4 0 66 :3 0 6c
:3 0 204 205 0
2 :4 0 ed 206
208 6d :4 0 6e
:2 0 6f :3 0 ef
20b 20d :3 0 70
:4 0 6e :2 0 71
:4 0 f2 210 212
:3 0 6e :2 0 3
:3 0 f5 214 216
:3 0 6e :2 0 71
:4 0 f8 218 21a
:3 0 6e :2 0 72
:4 0 fb 21c 21e
:3 0 6e :2 0 71
:4 0 fe 220 222
:3 0 6e :2 0 5
:3 0 101 224 226
:3 0 6e :2 0 71
:4 0 104 228 22a
:3 0 6e :2 0 72
:4 0 107 22c 22e
:3 0 6e :2 0 71
:4 0 10a 230 232
:3 0 6e :2 0 6
:3 0 10d 234 236
:3 0 6e :2 0 71
:4 0 110 238 23a
:3 0 6e :2 0 72
:4 0 113 23c 23e
:3 0 6e :2 0 73
:3 0 74 :3 0 7
:3 0 116 242 244
75 :4 0 118 241
247 11b 240 249
:3 0 6e :2 0 72
:4 0 11e 24b 24d
:3 0 6e :2 0 73
:3 0 74 :3 0 9
:3 0 121 251 253
75 :4 0 123 250
256 126 24f 258
:3 0 6e :2 0 72
:4 0 129 25a 25c
:3 0 6e :2 0 73
:3 0 74 :3 0 a
:3 0 12c 260 262
75 :4 0 12e 25f
265 131 25e 267
:3 0 6e :2 0 72
:4 0 134 269 26b
:3 0 6e :2 0 73
:3 0 74 :3 0 b
:3 0 137 26f 271
75 :4 0 139 26e
274 13c 26d 276
:3 0 6e :2 0 72
:4 0 13f 278 27a
:3 0 6e :2 0 73
:3 0 74 :3 0 c
:3 0 142 27e 280
75 :4 0 144 27d
283 147 27c 285
:3 0 6e :2 0 72
:4 0 14a 287 289
:3 0 6e :2 0 73
:3 0 74 :3 0 d
:3 0 14d 28d 28f
75 :4 0 14f 28c
292 152 28b 294
:3 0 6e :2 0 72
:4 0 155 296 298
:3 0 6e :2 0 73
:3 0 74 :3 0 e
:3 0 158 29c 29e
75 :4 0 15a 29b
2a1 15d 29a 2a3
:3 0 6e :2 0 72
:4 0 160 2a5 2a7
:3 0 6e :2 0 73
:3 0 74 :3 0 f
:3 0 163 2ab 2ad
75 :4 0 165 2aa
2b0 168 2a9 2b2
:3 0 6e :2 0 72
:4 0 16b 2b4 2b6
:3 0 6e :2 0 73
:3 0 74 :3 0 10
:3 0 16e 2ba 2bc
75 :4 0 170 2b9
2bf 173 2b8 2c1
:3 0 6e :2 0 72
:4 0 176 2c3 2c5
:3 0 6e :2 0 73
:3 0 74 :3 0 11
:3 0 179 2c9 2cb
75 :4 0 17b 2c8
2ce 17e 2c7 2d0
:3 0 6e :2 0 72
:4 0 181 2d2 2d4
:3 0 6e :2 0 71
:4 0 184 2d6 2d8
:3 0 6e :2 0 12
:3 0 187 2da 2dc
:3 0 6e :2 0 71
:4 0 18a 2de 2e0
:3 0 6e :2 0 72
:4 0 18d 2e2 2e4
:3 0 6e :2 0 71
:4 0 190 2e6 2e8
:3 0 6e :2 0 13
:3 0 193 2ea 2ec
:3 0 6e :2 0 71
:4 0 196 2ee 2f0
:3 0 6e :2 0 76
:4 0 199 2f2 2f4
:3 0 19c 202 2f6
:2 0 2f8 1a1 2f9
1ff 2f8 0 2fa
1a3 0 2f3f 66
:3 0 67 :3 0 2fb
2fc 0 66 :3 0
77 :3 0 2fe 2ff
0 27 :2 0 2
:4 0 78 :2 0 79
:2 0 27 :2 0 1a5
304 306 :3 0 1a8
300 308 2fd 30a
309 :2 0 69 :3 0
7a :3 0 30c 30d
0 6b :4 0 7b
:4 0 6e :2 0 6f
:3 0 1ac 311 313
:3 0 1af 30e 315
:2 0 317 1b2 318
30b 317 0 319
1b4 0 2f3f 17
:3 0 3 :3 0 31a
31b 0 2f3f 1f
:3 0 5 :3 0 31d
31e 0 2f3f 22
:3 0 6 :3 0 320
321 0 2f3f 1c
:3 0 13 :3 0 323
324 0 2f3f 37
:3 0 7 :3 0 326
327 0 2f3f 35
:3 0 9 :3 0 329
32a 0 2f3f 36
:3 0 e :3 0 32c
32d 0 2f3f 38
:3 0 b :3 0 32f
330 0 2f3f 3a
:3 0 f :3 0 332
333 0 2f3f 39
:3 0 c :3 0 335
336 0 2f3f 32
:3 0 11 :3 0 338
339 0 2f3f 31
:3 0 a :3 0 33b
33c 0 2f3f 3b
:3 0 d :3 0 33e
33f 0 2f3f 33
:3 0 10 :3 0 341
342 0 2f3f 1a
:3 0 17 :3 0 344
345 0 2f3f 23
:3 0 7c :4 0 347
348 0 2f3f 19
:4 0 34a 34b 0
2f3f 5a :3 0 7d
:3 0 73 :3 0 32
:3 0 30 :2 0 1b6
34f 352 1b9 34e
354 34d 355 0
2f3f 5d :3 0 30
:2 0 357 358 0
2f3f 4e :3 0 50
:2 0 35a 35b 0
2f3f 3f :3 0 30
:2 0 35d 35e 0
2f3f 3 :3 0 7e
:2 0 1bb 361 362
:3 0 363 :2 0 66
:3 0 67 :3 0 365
366 0 66 :3 0
77 :3 0 368 369
0 7f :2 0 2
:4 0 80 :2 0 79
:2 0 27 :2 0 1bd
36e 370 :3 0 1c0
36a 372 367 374
373 :2 0 69 :3 0
7a :3 0 376 377
0 6b :4 0 81
:4 0 6e :2 0 6f
:3 0 1c4 37b 37d
:3 0 6e :2 0 82
:4 0 1c7 37f 381
:3 0 6e :2 0 83
:4 0 1ca 383 385
:3 0 6e :2 0 73
:3 0 74 :3 0 84
:3 0 85 :3 0 38a
38b 0 1cd 389
38d 75 :4 0 1cf
388 390 1d2 387
392 :3 0 1d5 378
394 :2 0 396 1d8
397 375 396 0
398 1da 0 3c1
66 :3 0 67 :3 0
399 39a 0 66
:3 0 77 :3 0 39c
39d 0 27 :2 0
2 :4 0 86 :2 0
79 :2 0 27 :2 0
1dc 3a2 3a4 :3 0
1df 39e 3a6 39b
3a8 3a7 :2 0 69
:3 0 7a :3 0 3aa
3ab 0 6b :4 0
87 :4 0 6e :2 0
6f :3 0 1e3 3af
3b1 :3 0 1e6 3ac
3b3 :2 0 3b5 1e9
3b6 3a9 3b5 0
3b7 1eb 0 3c1
88 :3 0 89 :3 0
3b8 3b9 0 84
:3 0 85 :3 0 3bb
3bc 0 8a :3 0
1ed 3ba 3bf :2 0
3c1 1f0 3c2 364
3c1 0 3c3 1f4
0 2f3f 12 :3 0
7e :2 0 1f6 3c5
3c6 :3 0 3c7 :2 0
66 :3 0 67 :3 0
3c9 3ca 0 66
:3 0 77 :3 0 3cc
3cd 0 7f :2 0
2 :4 0 8b :2 0
79 :2 0 27 :2 0
1f8 3d2 3d4 :3 0
1fb 3ce 3d6 3cb
3d8 3d7 :2 0 69
:3 0 7a :3 0 3da
3db 0 6b :4 0
8c :4 0 6e :2 0
6f :3 0 1ff 3df
3e1 :3 0 6e :2 0
82 :4 0 202 3e3
3e5 :3 0 6e :2 0
83 :4 0 205 3e7
3e9 :3 0 6e :2 0
73 :3 0 74 :3 0
84 :3 0 85 :3 0
3ee 3ef 0 208
3ed 3f1 75 :4 0
20a 3ec 3f4 20d
3eb 3f6 :3 0 210
3dc 3f8 :2 0 3fa
213 3fb 3d9 3fa
0 3fc 215 0
425 66 :3 0 67
:3 0 3fd 3fe 0
66 :3 0 77 :3 0
400 401 0 27
:2 0 2 :4 0 8d
:2 0 79 :2 0 27
:2 0 217 406 408
:3 0 21a 402 40a
3ff 40c 40b :2 0
69 :3 0 7a :3 0
40e 40f 0 6b
:4 0 8e :4 0 6e
:2 0 6f :3 0 21e
413 415 :3 0 221
410 417 :2 0 419
224 41a 40d 419
0 41b 226 0
425 88 :3 0 89
:3 0 41c 41d 0
84 :3 0 85 :3 0
41f 420 0 8a
:3 0 228 41e 423
:2 0 425 22b 426
3c8 425 0 427
22f 0 2f3f 73
:3 0 31 :3 0 30
:2 0 231 428 42b
8f :2 0 90 :2 0
236 42d 42f :3 0
73 :3 0 39 :3 0
30 :2 0 239 431
434 8f :2 0 90
:2 0 23e 436 438
:3 0 430 43a 439
:2 0 73 :3 0 35
:3 0 30 :2 0 241
43c 43f 8f :2 0
90 :2 0 246 441
443 :3 0 43b 445
444 :2 0 66 :3 0
67 :3 0 447 448
0 66 :3 0 77
:3 0 44a 44b 0
7f :2 0 2 :4 0
91 :2 0 79 :2 0
27 :2 0 249 450
452 :3 0 24c 44c
454 449 456 455
:2 0 69 :3 0 7a
:3 0 458 459 0
6b :4 0 92 :4 0
6e :2 0 6f :3 0
250 45d 45f :3 0
6e :2 0 82 :4 0
253 461 463 :3 0
6e :2 0 83 :4 0
256 465 467 :3 0
6e :2 0 73 :3 0
74 :3 0 84 :3 0
93 :3 0 46c 46d
0 259 46b 46f
75 :4 0 25b 46a
472 25e 469 474
:3 0 261 45a 476
:2 0 478 264 479
457 478 0 47a
266 0 4a3 66
:3 0 67 :3 0 47b
47c 0 66 :3 0
77 :3 0 47e 47f
0 27 :2 0 2
:4 0 94 :2 0 79
:2 0 27 :2 0 268
484 486 :3 0 26b
480 488 47d 48a
489 :2 0 69 :3 0
7a :3 0 48c 48d
0 6b :4 0 95
:4 0 6e :2 0 6f
:3 0 26f 491 493
:3 0 272 48e 495
:2 0 497 275 498
48b 497 0 499
277 0 4a3 88
:3 0 89 :3 0 49a
49b 0 84 :3 0
93 :3 0 49d 49e
0 8a :3 0 279
49c 4a1 :2 0 4a3
27c 4a4 446 4a3
0 4a5 280 0
2f3f 5 :3 0 96
:2 0 282 4a7 4a8
:3 0 4a9 :2 0 4aa
:2 0 6 :3 0 96
:2 0 284 4ad 4ae
:3 0 4af :2 0 4b0
:2 0 4ab 4b2 4b1
:2 0 97 :3 0 98
:3 0 6 :3 0 97
:3 0 98 :3 0 5
:3 0 44 :3 0 99
:4 0 9a 1 :8 0
4c2 15 :3 0 9b
:3 0 4bd 4be 0
9c :3 0 4bf 4c0
0 4c2 286 50c
9d :3 0 15 :3 0
9b :3 0 4c5 4c6
0 9c :3 0 4c7
4c8 0 502 66
:3 0 67 :3 0 4ca
4cb 0 66 :3 0
77 :3 0 4cd 4ce
0 9e :2 0 2
:4 0 9f :2 0 79
:2 0 27 :2 0 289
4d3 4d5 :3 0 28c
4cf 4d7 4cc 4d9
4d8 :2 0 69 :3 0
7a :3 0 4db 4dc
0 6b :4 0 a0
:4 0 6e :2 0 6f
:3 0 290 4e0 4e2
:3 0 6e :2 0 82
:4 0 293 4e4 4e6
:3 0 6e :2 0 a1
:4 0 296 4e8 4ea
:3 0 6e :2 0 9c
:3 0 299 4ec 4ee
:3 0 6e :2 0 a2
:4 0 29c 4f0 4f2
:3 0 6e :2 0 a3
:3 0 a4 :3 0 27
:2 0 a5 :2 0 29f
4f5 4f9 2a3 4f4
4fb :3 0 2a6 4dd
4fd :2 0 4ff 2a9
500 4da 4ff 0
501 2ab 0 502
2ad 505 :3 0 505
0 505 504 502
503 :6 0 507 2
:3 0 2b0 509 2b2
508 507 :2 0 50a
2b4 :2 0 50c 0
50c 50b 4c2 50a
:6 0 587 1 :3 0
15 :3 0 9b :3 0
50e 50f 0 15
:3 0 8f :2 0 a6
:3 0 511 513 0
2b8 512 515 :3 0
516 :2 0 73 :3 0
44 :3 0 30 :2 0
2bb 518 51b a7
:2 0 30 :2 0 2c0
51d 51f :3 0 520
:2 0 517 522 521
:2 0 66 :3 0 67
:3 0 524 525 0
66 :3 0 77 :3 0
527 528 0 7f
:2 0 2 :4 0 a8
:2 0 79 :2 0 27
:2 0 2c3 52d 52f
:3 0 2c6 529 531
526 533 532 :2 0
69 :3 0 7a :3 0
535 536 0 6b
:4 0 a9 :4 0 6e
:2 0 6f :3 0 2ca
53a 53c :3 0 6e
:2 0 82 :4 0 2cd
53e 540 :3 0 6e
:2 0 83 :4 0 2d0
542 544 :3 0 6e
:2 0 73 :3 0 74
:3 0 84 :3 0 aa
:3 0 549 54a 0
2d3 548 54c 75
:4 0 2d5 547 54f
2d8 546 551 :3 0
2db 537 553 :2 0
555 2de 556 534
555 0 557 2e0
0 580 66 :3 0
67 :3 0 558 559
0 66 :3 0 77
:3 0 55b 55c 0
27 :2 0 2 :4 0
ab :2 0 79 :2 0
27 :2 0 2e2 561
563 :3 0 2e5 55d
565 55a 567 566
:2 0 69 :3 0 7a
:3 0 569 56a 0
6b :4 0 ac :4 0
6e :2 0 6f :3 0
2e9 56e 570 :3 0
2ec 56b 572 :2 0
574 2ef 575 568
574 0 576 2f1
0 580 88 :3 0
89 :3 0 577 578
0 84 :3 0 aa
:3 0 57a 57b 0
8a :3 0 2f3 579
57e :2 0 580 2f6
581 523 580 0
582 2fa 0 587
63 :3 0 27 :2 0
583 584 0 587
ad :3 0 2fc 5ed
5 :3 0 7e :2 0
300 589 58a :3 0
58b :2 0 58c :2 0
6 :3 0 7e :2 0
302 58f 590 :3 0
591 :2 0 592 :2 0
58d 594 593 :2 0
6f :3 0 1f :3 0
99 :4 0 ae 1
:8 0 59f 15 :3 0
9b :3 0 59a 59b
0 9c :3 0 59c
59d 0 59f 304
5e9 9d :3 0 15
:3 0 9b :3 0 5a2
5a3 0 9c :3 0
5a4 5a5 0 5df
66 :3 0 67 :3 0
5a7 5a8 0 66
:3 0 77 :3 0 5aa
5ab 0 9e :2 0
2 :4 0 af :2 0
79 :2 0 27 :2 0
307 5b0 5b2 :3 0
30a 5ac 5b4 5a9
5b6 5b5 :2 0 69
:3 0 7a :3 0 5b8
5b9 0 6b :4 0
b0 :4 0 6e :2 0
6f :3 0 30e 5bd
5bf :3 0 6e :2 0
82 :4 0 311 5c1
5c3 :3 0 6e :2 0
a1 :4 0 314 5c5
5c7 :3 0 6e :2 0
9c :3 0 317 5c9
5cb :3 0 6e :2 0
a2 :4 0 31a 5cd
5cf :3 0 6e :2 0
a3 :3 0 a4 :3 0
27 :2 0 a5 :2 0
31d 5d2 5d6 321
5d1 5d8 :3 0 324
5ba 5da :2 0 5dc
327 5dd 5b7 5dc
0 5de 329 0
5df 32b 5e2 :3 0
5e2 0 5e2 5e1
5df 5e0 :6 0 5e4
4 :3 0 32e 5e6
330 5e5 5e4 :2 0
5e7 332 :2 0 5e9
0 5e9 5e8 59f
5e7 :6 0 5eb 1
:3 0 334 5ec 595
5eb 0 5ee 4b3
587 0 5ee 336
0 2f3f 21 :3 0
1f :3 0 5ef 5f0
0 2f3f 6 :3 0
7e :2 0 339 5f3
5f4 :3 0 5f5 :2 0
22 :3 0 7c :4 0
5f7 5f8 0 5fa
33b 5fb 5f6 5fa
0 5fc 33d 0
2f3f 1d :3 0 a3
:3 0 1d :3 0 27
:2 0 18 :2 0 33f
5fe 602 5fd 603
0 2f3f 26 :3 0
a3 :3 0 26 :3 0
27 :2 0 27 :2 0
343 606 60a 605
60b 0 2f3f 29
:3 0 12 :3 0 60d
60e 0 2f3f 73
:3 0 32 :3 0 30
:2 0 347 610 613
b1 :2 0 30 :2 0
34c 615 617 :3 0
1d :3 0 a3 :3 0
a3 :3 0 29 :3 0
27 :2 0 18 :2 0
34f 61b 61f 27
:2 0 18 :2 0 353
61a 623 619 624
0 9bf 26 :3 0
b2 :3 0 b3 :3 0
627 628 0 27
:2 0 27 :2 0 b4
:2 0 29 :3 0 357
629 62e 626 62f
0 9bf b5 :3 0
73 :3 0 32 :3 0
30 :2 0 35c 632
635 35f 631 637
b6 :2 0 30 :2 0
363 639 63b :3 0
b7 :3 0 73 :3 0
b8 :3 0 73 :3 0
b9 :3 0 ba :3 0
17 :3 0 3d :3 0
3e :3 0 43 :3 0
bb :3 0 bc :3 0
1a :4 0 bd 1
:8 0 650 15 :3 0
9b :3 0 64b 64c
0 9c :3 0 64d
64e 0 650 366
69a 9d :3 0 15
:3 0 9b :3 0 653
654 0 9c :3 0
655 656 0 690
66 :3 0 67 :3 0
658 659 0 66
:3 0 77 :3 0 65b
65c 0 9e :2 0
2 :4 0 be :2 0
79 :2 0 27 :2 0
369 661 663 :3 0
36c 65d 665 65a
667 666 :2 0 69
:3 0 7a :3 0 669
66a 0 6b :4 0
bf :4 0 6e :2 0
6f :3 0 370 66e
670 :3 0 6e :2 0
82 :4 0 373 672
674 :3 0 6e :2 0
a1 :4 0 376 676
678 :3 0 6e :2 0
9c :3 0 379 67a
67c :3 0 6e :2 0
a2 :4 0 37c 67e
680 :3 0 6e :2 0
a3 :3 0 a4 :3 0
27 :2 0 a5 :2 0
37f 683 687 383
682 689 :3 0 386
66b 68b :2 0 68d
389 68e 668 68d
0 68f 38b 0
690 38d 693 :3 0
693 0 693 692
690 691 :6 0 695
6 :3 0 390 697
392 696 695 :2 0
698 394 :2 0 69a
0 69a 699 650
698 :6 0 69c 1
:3 0 396 735 c0
:3 0 c1 :3 0 c0
:3 0 c2 :3 0 c0
:3 0 c3 :3 0 c0
:3 0 c4 :3 0 c0
:3 0 b7 :3 0 73
:3 0 c5 :3 0 b8
:3 0 73 :3 0 c5
:3 0 b9 :3 0 c5
:3 0 ba :3 0 32
:3 0 5d :3 0 5b
:3 0 5c :3 0 17
:3 0 3d :3 0 3e
:3 0 43 :3 0 bb
:3 0 c5 :3 0 bb
:3 0 c0 :3 0 c0
:3 0 bc :3 0 1a
:3 0 c0 :3 0 c1
:3 0 84 :3 0 c6
:3 0 84 :3 0 c7
:3 0 84 :3 0 c8
:3 0 84 :3 0 c9
:3 0 84 :3 0 ca
:3 0 84 :3 0 cb
:3 0 84 :3 0 cc
:3 0 84 :3 0 cd
:3 0 84 :3 0 ce
:3 0 84 :3 0 cf
:3 0 84 :3 0 d0
:3 0 84 :3 0 d1
:3 0 84 :3 0 d2
:3 0 84 :3 0 d3
:3 0 84 :3 0 d4
:3 0 c5 :3 0 bc
:3 0 c0 :3 0 b7
:4 0 d5 1 :8 0
6e8 15 :3 0 9b
:3 0 6e3 6e4 0
9c :3 0 6e5 6e6
0 6e8 398 732
9d :3 0 15 :3 0
9b :3 0 6eb 6ec
0 9c :3 0 6ed
6ee 0 728 66
:3 0 67 :3 0 6f0
6f1 0 66 :3 0
77 :3 0 6f3 6f4
0 9e :2 0 2
:4 0 d6 :2 0 79
:2 0 27 :2 0 39b
6f9 6fb :3 0 39e
6f5 6fd 6f2 6ff
6fe :2 0 69 :3 0
7a :3 0 701 702
0 6b :4 0 d7
:4 0 6e :2 0 6f
:3 0 3a2 706 708
:3 0 6e :2 0 82
:4 0 3a5 70a 70c
:3 0 6e :2 0 a1
:4 0 3a8 70e 710
:3 0 6e :2 0 9c
:3 0 3ab 712 714
:3 0 6e :2 0 a2
:4 0 3ae 716 718
:3 0 6e :2 0 a3
:3 0 a4 :3 0 27
:2 0 a5 :2 0 3b1
71b 71f 3b5 71a
721 :3 0 3b8 703
723 :2 0 725 3bb
726 700 725 0
727 3bd 0 728
3bf 72b :3 0 72b
0 72b 72a 728
729 :6 0 72d 8
:3 0 3c2 72f 3c4
72e 72d :2 0 730
3c6 :2 0 732 0
732 731 6e8 730
:6 0 734 1 :3 0
3c8 736 63c 69c
0 737 0 734
0 737 3ca 0
9bf 15 :3 0 9b
:3 0 738 739 0
15 :3 0 8f :2 0
d8 :3 0 73b 73d
0 3cf 73c 73f
:3 0 740 :2 0 b7
:3 0 d9 :3 0 17
:3 0 5f :3 0 da
:3 0 bc :3 0 1a
:4 0 db 1 :8 0
74f 15 :3 0 9b
:3 0 74a 74b 0
9c :3 0 74c 74d
0 74f 3d2 799
9d :3 0 15 :3 0
9b :3 0 752 753
0 9c :3 0 754
755 0 78f 66
:3 0 67 :3 0 757
758 0 66 :3 0
77 :3 0 75a 75b
0 9e :2 0 2
:4 0 dc :2 0 79
:2 0 27 :2 0 3d5
760 762 :3 0 3d8
75c 764 759 766
765 :2 0 69 :3 0
7a :3 0 768 769
0 6b :4 0 dd
:4 0 6e :2 0 6f
:3 0 3dc 76d 76f
:3 0 6e :2 0 82
:4 0 3df 771 773
:3 0 6e :2 0 a1
:4 0 3e2 775 777
:3 0 6e :2 0 9c
:3 0 3e5 779 77b
:3 0 6e :2 0 a2
:4 0 3e8 77d 77f
:3 0 6e :2 0 a3
:3 0 a4 :3 0 27
:2 0 a5 :2 0 3eb
782 786 3ef 781
788 :3 0 3f2 76a
78a :2 0 78c 3f5
78d 767 78c 0
78e 3f7 0 78f
3f9 792 :3 0 792
0 792 791 78f
790 :6 0 794 a
:3 0 3fc 796 3fe
795 794 :2 0 797
400 :2 0 799 0
799 798 74f 797
:6 0 87f 1 :3 0
15 :3 0 9b :3 0
79b 79c 0 15
:3 0 8f :2 0 a6
:3 0 79e 7a0 0
404 79f 7a2 :3 0
7a3 :2 0 5f :3 0
96 :2 0 407 7a6
7a7 :3 0 7a8 :2 0
5a :3 0 27 :2 0
7aa 7ab 0 7ad
409 7ae 7a9 7ad
0 7af 40b 0
80d 73 :3 0 b8
:3 0 73 :3 0 b9
:3 0 ba :3 0 3d
:3 0 3e :3 0 43
:3 0 bb :3 0 bc
:3 0 17 :4 0 de
1 :8 0 7c1 15
:3 0 9b :3 0 7bc
7bd 0 9c :3 0
7be 7bf 0 7c1
40d 80b 9d :3 0
15 :3 0 9b :3 0
7c4 7c5 0 9c
:3 0 7c6 7c7 0
801 66 :3 0 67
:3 0 7c9 7ca 0
66 :3 0 77 :3 0
7cc 7cd 0 9e
:2 0 2 :4 0 df
:2 0 79 :2 0 27
:2 0 410 7d2 7d4
:3 0 413 7ce 7d6
7cb 7d8 7d7 :2 0
69 :3 0 7a :3 0
7da 7db 0 6b
:4 0 e0 :4 0 6e
:2 0 6f :3 0 417
7df 7e1 :3 0 6e
:2 0 82 :4 0 41a
7e3 7e5 :3 0 6e
:2 0 a1 :4 0 41d
7e7 7e9 :3 0 6e
:2 0 9c :3 0 420
7eb 7ed :3 0 6e
:2 0 a2 :4 0 423
7ef 7f1 :3 0 6e
:2 0 a3 :3 0 a4
:3 0 27 :2 0 a5
:2 0 426 7f4 7f8
42a 7f3 7fa :3 0
42d 7dc 7fc :2 0
7fe 430 7ff 7d9
7fe 0 800 432
0 801 434 804
:3 0 804 0 804
803 801 802 :6 0
806 c :3 0 437
808 439 807 806
:2 0 809 43b :2 0
80b 0 80b 80a
7c1 809 :6 0 80d
1 :3 0 43d 87c
66 :3 0 67 :3 0
80e 80f 0 66
:3 0 77 :3 0 811
812 0 18 :2 0
2 :4 0 e1 :2 0
79 :2 0 27 :2 0
440 817 819 :3 0
443 813 81b 810
81d 81c :2 0 69
:3 0 7a :3 0 81f
820 0 6b :4 0
e2 :4 0 6e :2 0
6f :3 0 447 824
826 :3 0 6e :2 0
82 :4 0 44a 828
82a :3 0 6e :2 0
83 :4 0 44d 82c
82e :3 0 6e :2 0
73 :3 0 74 :3 0
84 :3 0 e3 :3 0
833 834 0 450
832 836 75 :4 0
452 831 839 455
830 83b :3 0 6e
:2 0 e4 :4 0 458
83d 83f :3 0 6e
:2 0 71 :4 0 45b
841 843 :3 0 6e
:2 0 1a :3 0 45e
845 847 :3 0 6e
:2 0 71 :4 0 461
849 84b :3 0 464
821 84d :2 0 84f
467 850 81e 84f
0 851 469 0
87b 66 :3 0 67
:3 0 852 853 0
66 :3 0 77 :3 0
855 856 0 27
:2 0 2 :4 0 e5
:2 0 79 :2 0 27
:2 0 46b 85b 85d
:3 0 46e 857 85f
854 861 860 :2 0
69 :3 0 7a :3 0
863 864 0 6b
:4 0 e6 :4 0 6e
:2 0 6f :3 0 472
868 86a :3 0 475
865 86c :2 0 86e
478 86f 862 86e
0 870 47a 0
87b 88 :3 0 e7
:3 0 871 872 0
84 :3 0 e3 :3 0
874 875 0 1a
:3 0 8a :3 0 47c
873 879 :2 0 87b
480 87d 7a4 80d
0 87e 0 87b
0 87e 484 0
87f 487 884 5a
:3 0 27 :2 0 880
881 0 883 48a
885 741 87f 0
886 0 883 0
886 48c 0 9bf
5e :3 0 30 :2 0
887 888 0 9bf
e8 :3 0 5e :3 0
e9 :3 0 b7 :3 0
17 :4 0 ea 1
:8 0 895 15 :3 0
9b :3 0 890 891
0 9c :3 0 892
893 0 895 48f
8df 9d :3 0 15
:3 0 9b :3 0 898
899 0 9c :3 0
89a 89b 0 8d5
66 :3 0 67 :3 0
89d 89e 0 66
:3 0 77 :3 0 8a0
8a1 0 9e :2 0
2 :4 0 eb :2 0
79 :2 0 27 :2 0
492 8a6 8a8 :3 0
495 8a2 8aa 89f
8ac 8ab :2 0 69
:3 0 7a :3 0 8ae
8af 0 6b :4 0
ec :4 0 6e :2 0
6f :3 0 499 8b3
8b5 :3 0 6e :2 0
82 :4 0 49c 8b7
8b9 :3 0 6e :2 0
a1 :4 0 49f 8bb
8bd :3 0 6e :2 0
9c :3 0 4a2 8bf
8c1 :3 0 6e :2 0
a2 :4 0 4a5 8c3
8c5 :3 0 6e :2 0
a3 :3 0 a4 :3 0
27 :2 0 a5 :2 0
4a8 8c8 8cc 4ac
8c7 8ce :3 0 4af
8b0 8d0 :2 0 8d2
4b2 8d3 8ad 8d2
0 8d4 4b4 0
8d5 4b6 8d8 :3 0
8d8 0 8d8 8d7
8d5 8d6 :6 0 8da
e :3 0 4b9 8dc
4bb 8db 8da :2 0
8dd 4bd :2 0 8df
0 8df 8de 895
8dd :6 0 9bf 1
:3 0 73 :3 0 5e
:3 0 30 :2 0 4bf
8e1 8e4 b1 :2 0
30 :2 0 4c4 8e6
8e8 :3 0 ed :3 0
4d :3 0 bb :3 0
bc :3 0 17 :4 0
ee 1 :8 0 8f5
15 :3 0 9b :3 0
8f0 8f1 0 9c
:3 0 8f2 8f3 0
8f5 4c7 93f 9d
:3 0 15 :3 0 9b
:3 0 8f8 8f9 0
9c :3 0 8fa 8fb
0 935 66 :3 0
67 :3 0 8fd 8fe
0 66 :3 0 77
:3 0 900 901 0
9e :2 0 2 :4 0
ef :2 0 79 :2 0
27 :2 0 4ca 906
908 :3 0 4cd 902
90a 8ff 90c 90b
:2 0 69 :3 0 7a
:3 0 90e 90f 0
6b :4 0 f0 :4 0
6e :2 0 6f :3 0
4d1 913 915 :3 0
6e :2 0 82 :4 0
4d4 917 919 :3 0
6e :2 0 a1 :4 0
4d7 91b 91d :3 0
6e :2 0 9c :3 0
4da 91f 921 :3 0
6e :2 0 a2 :4 0
4dd 923 925 :3 0
6e :2 0 a3 :3 0
a4 :3 0 27 :2 0
a5 :2 0 4e0 928
92c 4e4 927 92e
:3 0 4e7 910 930
:2 0 932 4ea 933
90d 932 0 934
4ec 0 935 4ee
938 :3 0 938 0
938 937 935 936
:6 0 93a 10 :3 0
4f1 93c 4f3 93b
93a :2 0 93d 4f5
:2 0 93f 0 93f
93e 8f5 93d :6 0
9bc 1 :3 0 97
:3 0 f1 :3 0 941
942 0 4d :3 0
f2 :4 0 4f7 943
946 8f :2 0 30
:2 0 4fc 948 94a
:3 0 66 :3 0 67
:3 0 94c 94d 0
66 :3 0 77 :3 0
94f 950 0 18
:2 0 2 :4 0 f3
:2 0 79 :2 0 27
:2 0 4ff 955 957
:3 0 502 951 959
94e 95b 95a :2 0
69 :3 0 7a :3 0
95d 95e 0 6b
:4 0 f4 :4 0 6e
:2 0 6f :3 0 506
962 964 :3 0 6e
:2 0 82 :4 0 509
966 968 :3 0 6e
:2 0 83 :4 0 50c
96a 96c :3 0 6e
:2 0 73 :3 0 74
:3 0 84 :3 0 f5
:3 0 971 972 0
50f 970 974 75
:4 0 511 96f 977
514 96e 979 :3 0
6e :2 0 e4 :4 0
517 97b 97d :3 0
6e :2 0 71 :4 0
51a 97f 981 :3 0
6e :2 0 17 :3 0
51d 983 985 :3 0
6e :2 0 71 :4 0
520 987 989 :3 0
523 95f 98b :2 0
98d 526 98e 95c
98d 0 98f 528
0 9b9 66 :3 0
67 :3 0 990 991
0 66 :3 0 77
:3 0 993 994 0
27 :2 0 2 :4 0
f6 :2 0 79 :2 0
27 :2 0 52a 999
99b :3 0 52d 995
99d 992 99f 99e
:2 0 69 :3 0 7a
:3 0 9a1 9a2 0
6b :4 0 f7 :4 0
6e :2 0 6f :3 0
531 9a6 9a8 :3 0
534 9a3 9aa :2 0
9ac 537 9ad 9a0
9ac 0 9ae 539
0 9b9 88 :3 0
e7 :3 0 9af 9b0
0 84 :3 0 f5
:3 0 9b2 9b3 0
17 :3 0 8a :3 0
53b 9b1 9b7 :2 0
9b9 53f 9ba 94b
9b9 0 9bb 543
0 9bc 545 9bd
8e9 9bc 0 9be
548 0 9bf 54a
afc 73 :3 0 b8
:3 0 73 :3 0 b9
:3 0 ba :3 0 3d
:3 0 3e :3 0 43
:3 0 bb :3 0 bc
:3 0 17 :4 0 f8
1 :8 0 9d1 15
:3 0 9b :3 0 9cc
9cd 0 9c :3 0
9ce 9cf 0 9d1
552 a1b 9d :3 0
15 :3 0 9b :3 0
9d4 9d5 0 9c
:3 0 9d6 9d7 0
a11 66 :3 0 67
:3 0 9d9 9da 0
66 :3 0 77 :3 0
9dc 9dd 0 9e
:2 0 2 :4 0 f9
:2 0 79 :2 0 27
:2 0 555 9e2 9e4
:3 0 558 9de 9e6
9db 9e8 9e7 :2 0
69 :3 0 7a :3 0
9ea 9eb 0 6b
:4 0 fa :4 0 6e
:2 0 6f :3 0 55c
9ef 9f1 :3 0 6e
:2 0 82 :4 0 55f
9f3 9f5 :3 0 6e
:2 0 a1 :4 0 562
9f7 9f9 :3 0 6e
:2 0 9c :3 0 565
9fb 9fd :3 0 6e
:2 0 a2 :4 0 568
9ff a01 :3 0 6e
:2 0 a3 :3 0 a4
:3 0 27 :2 0 a5
:2 0 56b a04 a08
56f a03 a0a :3 0
572 9ec a0c :2 0
a0e 575 a0f 9e9
a0e 0 a10 577
0 a11 579 a14
:3 0 a14 0 a14
a13 a11 a12 :6 0
a16 12 :3 0 57c
a18 57e a17 a16
:2 0 a19 580 :2 0
a1b 0 a1b a1a
9d1 a19 :6 0 afb
1 :3 0 15 :3 0
9b :3 0 a1d a1e
0 15 :3 0 8f
:2 0 d8 :3 0 a20
a22 0 584 a21
a24 :3 0 a25 :2 0
3d :3 0 3e :3 0
fb :3 0 bc :3 0
17 :4 0 fc 1
:8 0 a32 15 :3 0
9b :3 0 a2d a2e
0 9c :3 0 a2f
a30 0 a32 587
a7c 9d :3 0 15
:3 0 9b :3 0 a35
a36 0 9c :3 0
a37 a38 0 a72
66 :3 0 67 :3 0
a3a a3b 0 66
:3 0 77 :3 0 a3d
a3e 0 9e :2 0
2 :4 0 fd :2 0
79 :2 0 27 :2 0
58a a43 a45 :3 0
58d a3f a47 a3c
a49 a48 :2 0 69
:3 0 7a :3 0 a4b
a4c 0 6b :4 0
fe :4 0 6e :2 0
6f :3 0 591 a50
a52 :3 0 6e :2 0
82 :4 0 594 a54
a56 :3 0 6e :2 0
a1 :4 0 597 a58
a5a :3 0 6e :2 0
9c :3 0 59a a5c
a5e :3 0 6e :2 0
a2 :4 0 59d a60
a62 :3 0 6e :2 0
a3 :3 0 a4 :3 0
27 :2 0 a5 :2 0
5a0 a65 a69 5a4
a64 a6b :3 0 5a7
a4d a6d :2 0 a6f
5aa a70 a4a a6f
0 a71 5ac 0
a72 5ae a75 :3 0
a75 0 a75 a74
a72 a73 :6 0 a77
14 :3 0 5b1 a79
5b3 a78 a77 :2 0
a7a 5b5 :2 0 a7c
0 a7c a7b a32
a7a :6 0 af8 1
:3 0 15 :3 0 9b
:3 0 a7e a7f 0
15 :3 0 8f :2 0
d8 :3 0 a81 a83
0 5b9 a82 a85
:3 0 a86 :2 0 66
:3 0 67 :3 0 a88
a89 0 66 :3 0
77 :3 0 a8b a8c
0 18 :2 0 2
:4 0 ff :2 0 79
:2 0 27 :2 0 5bc
a91 a93 :3 0 5bf
a8d a95 a8a a97
a96 :2 0 69 :3 0
7a :3 0 a99 a9a
0 6b :4 0 100
:4 0 6e :2 0 6f
:3 0 5c3 a9e aa0
:3 0 6e :2 0 82
:4 0 5c6 aa2 aa4
:3 0 6e :2 0 83
:4 0 5c9 aa6 aa8
:3 0 6e :2 0 73
:3 0 74 :3 0 84
:3 0 93 :3 0 aad
aae 0 5cc aac
ab0 75 :4 0 5ce
aab ab3 5d1 aaa
ab5 :3 0 6e :2 0
e4 :4 0 5d4 ab7
ab9 :3 0 6e :2 0
71 :4 0 5d7 abb
abd :3 0 6e :2 0
17 :3 0 5da abf
ac1 :3 0 6e :2 0
71 :4 0 5dd ac3
ac5 :3 0 5e0 a9b
ac7 :2 0 ac9 5e3
aca a98 ac9 0
acb 5e5 0 af5
66 :3 0 67 :3 0
acc acd 0 66
:3 0 77 :3 0 acf
ad0 0 27 :2 0
2 :4 0 101 :2 0
79 :2 0 27 :2 0
5e7 ad5 ad7 :3 0
5ea ad1 ad9 ace
adb ada :2 0 69
:3 0 7a :3 0 add
ade 0 6b :4 0
102 :4 0 6e :2 0
6f :3 0 5ee ae2
ae4 :3 0 5f1 adf
ae6 :2 0 ae8 5f4
ae9 adc ae8 0
aea 5f6 0 af5
88 :3 0 e7 :3 0
aeb aec 0 84
:3 0 93 :3 0 aee
aef 0 17 :3 0
8a :3 0 5f8 aed
af3 :2 0 af5 5fc
af6 a87 af5 0
af7 600 0 af8
602 af9 a26 af8
0 afa 605 0
afb 607 afd 618
9bf 0 afe 0
afb 0 afe 60a
0 2f3f 63 :3 0
8f :2 0 30 :2 0
60f b00 b02 :3 0
21 :3 0 5 :3 0
b04 b05 0 c2e
22 :3 0 6 :3 0
b07 b08 0 c2e
5e :3 0 103 :3 0
21 :3 0 22 :3 0
73 :3 0 38 :3 0
30 :2 0 612 b0e
b11 73 :3 0 39
:3 0 30 :2 0 615
b13 b16 73 :3 0
3a :3 0 30 :2 0
618 b18 b1b 73
:3 0 31 :3 0 30
:2 0 61b b1d b20
73 :3 0 3b :3 0
30 :2 0 61e b22
b25 73 :3 0 36
:3 0 30 :2 0 621
b27 b2a 73 :3 0
3d :3 0 30 :2 0
624 b2c b2f 73
:3 0 3e :3 0 30
:2 0 627 b31 b34
35 :3 0 37 :3 0
41 :3 0 62a b0b
b39 b0a b3a 0
c2e 73 :3 0 5e
:3 0 30 :2 0 638
b3c b3f 84 :3 0
8f :2 0 93 :3 0
b41 b43 0 63d
b42 b45 :3 0 66
:3 0 67 :3 0 b47
b48 0 66 :3 0
77 :3 0 b4a b4b
0 7f :2 0 2
:4 0 104 :2 0 79
:2 0 27 :2 0 640
b50 b52 :3 0 643
b4c b54 b49 b56
b55 :2 0 69 :3 0
7a :3 0 b58 b59
0 6b :4 0 105
:4 0 6e :2 0 6f
:3 0 647 b5d b5f
:3 0 6e :2 0 82
:4 0 64a b61 b63
:3 0 6e :2 0 83
:4 0 64d b65 b67
:3 0 6e :2 0 73
:3 0 74 :3 0 84
:3 0 93 :3 0 b6c
b6d 0 650 b6b
b6f 75 :4 0 652
b6a b72 655 b69
b74 :3 0 658 b5a
b76 :2 0 b78 65b
b79 b57 b78 0
b7a 65d 0 ba4
66 :3 0 67 :3 0
b7b b7c 0 66
:3 0 77 :3 0 b7e
b7f 0 27 :2 0
2 :4 0 106 :2 0
79 :2 0 27 :2 0
65f b84 b86 :3 0
662 b80 b88 b7d
b8a b89 :2 0 69
:3 0 7a :3 0 b8c
b8d 0 6b :4 0
107 :4 0 6e :2 0
6f :3 0 666 b91
b93 :3 0 669 b8e
b95 :2 0 b97 66c
b98 b8b b97 0
b99 66e 0 ba4
88 :3 0 89 :3 0
b9a b9b 0 84
:3 0 93 :3 0 b9d
b9e 0 8a :3 0
670 b9c ba1 :2 0
ba4 ad :3 0 673
c1d 73 :3 0 5e
:3 0 30 :2 0 677
ba5 ba8 b6 :2 0
30 :2 0 67c baa
bac :3 0 66 :3 0
67 :3 0 bae baf
0 66 :3 0 77
:3 0 bb1 bb2 0
18 :2 0 2 :4 0
108 :2 0 79 :2 0
27 :2 0 67f bb7
bb9 :3 0 682 bb3
bbb bb0 bbd bbc
:2 0 69 :3 0 7a
:3 0 bbf bc0 0
6b :4 0 109 :4 0
6e :2 0 6f :3 0
686 bc4 bc6 :3 0
6e :2 0 82 :4 0
689 bc8 bca :3 0
6e :2 0 83 :4 0
68c bcc bce :3 0
6e :2 0 73 :3 0
74 :3 0 5e :3 0
68f bd2 bd4 75
:4 0 691 bd1 bd7
694 bd0 bd9 :3 0
6e :2 0 e4 :4 0
697 bdb bdd :3 0
6e :2 0 71 :4 0
69a bdf be1 :3 0
6e :2 0 17 :3 0
69d be3 be5 :3 0
6e :2 0 71 :4 0
6a0 be7 be9 :3 0
6a3 bc1 beb :2 0
bed 6a6 bee bbe
bed 0 bef 6a8
0 c1b 66 :3 0
67 :3 0 bf0 bf1
0 66 :3 0 77
:3 0 bf3 bf4 0
27 :2 0 2 :4 0
10a :2 0 79 :2 0
27 :2 0 6aa bf9
bfb :3 0 6ad bf5
bfd bf2 bff bfe
:2 0 69 :3 0 7a
:3 0 c01 c02 0
6b :4 0 10b :4 0
6e :2 0 6f :3 0
6b1 c06 c08 :3 0
6b4 c03 c0a :2 0
c0c 6b7 c0d c00
c0c 0 c0e 6b9
0 c1b 88 :3 0
e7 :3 0 c0f c10
0 73 :3 0 5e
:3 0 30 :2 0 6bb
c12 c15 17 :3 0
8a :3 0 6be c11
c19 :2 0 c1b 6c2
c1c bad c1b 0
c1e b46 ba4 0
c1e 6c6 0 c2e
22 :3 0 22 :3 0
c1f c20 0 c2e
22 :3 0 7e :2 0
6c9 c23 c24 :3 0
c25 :2 0 22 :3 0
7c :4 0 c27 c28
0 c2a 6cb c2b
c26 c2a 0 c2c
6cd 0 c2e ad
:3 0 6cf cac 73
:3 0 35 :3 0 30
:2 0 6d6 c2f c32
b1 :2 0 30 :2 0
6db c34 c36 :3 0
c37 :2 0 73 :3 0
39 :3 0 30 :2 0
6de c39 c3c b6
:2 0 10c :2 0 6e3
c3e c40 :3 0 c41
:2 0 c38 c43 c42
:2 0 73 :3 0 39
:3 0 30 :2 0 6e6
c45 c48 8f :2 0
27 :2 0 6eb c4a
c4c :3 0 c4d :2 0
73 :3 0 39 :3 0
30 :2 0 6ee c4f
c52 8f :2 0 10d
:2 0 6f3 c54 c56
:3 0 c57 :2 0 c4e
c59 c58 :2 0 38
:3 0 10d :2 0 c5b
c5c 0 c5f ad
:3 0 6f6 ca8 73
:3 0 39 :3 0 30
:2 0 6f8 c60 c63
8f :2 0 30 :2 0
6fd c65 c67 :3 0
38 :3 0 27 :2 0
c69 c6a 0 c6d
ad :3 0 700 c6e
c68 c6d 0 ca9
73 :3 0 39 :3 0
30 :2 0 702 c6f
c72 8f :2 0 10e
:2 0 707 c74 c76
:3 0 c77 :2 0 73
:3 0 39 :3 0 30
:2 0 70a c79 c7c
8f :2 0 10f :2 0
70f c7e c80 :3 0
c81 :2 0 c78 c83
c82 :2 0 38 :3 0
27 :2 0 c85 c86
0 c89 ad :3 0
712 c8a c84 c89
0 ca9 73 :3 0
39 :3 0 30 :2 0
714 c8b c8e 8f
:2 0 90 :2 0 719
c90 c92 :3 0 35
:3 0 73 :3 0 3e
:3 0 30 :2 0 71c
c95 c98 110 :2 0
73 :3 0 35 :3 0
30 :2 0 71f c9b
c9e 722 c9a ca0
:3 0 c94 ca1 0
ca6 38 :3 0 10e
:2 0 ca3 ca4 0
ca6 725 ca7 c93
ca6 0 ca9 c5a
c5f 0 ca9 728
0 caa 72d cab
c44 caa 0 cad
b03 c2e 0 cad
72f 0 2f3f 59
:3 0 111 :4 0 caf
cb0 :3 0 cae cb1
0 2f3f 2b :3 0
7c :4 0 cb3 cb4
0 2f3f 2c :3 0
7c :4 0 cb6 cb7
0 2f3f 34 :3 0
112 :3 0 113 :3 0
cba cbb 0 114
:3 0 73 :3 0 3a
:3 0 30 :2 0 732
cbe cc1 84 :3 0
115 :3 0 cc3 cc4
0 735 cbd cc6
cc7 :2 0 116 :2 0
738 cbc cca cb9
ccb 0 2f3f 3a
:3 0 114 :3 0 73
:3 0 3a :3 0 30
:2 0 73b ccf cd2
84 :3 0 117 :3 0
cd4 cd5 0 73e
cce cd7 ccd cd8
0 2f3f 73 :3 0
32 :3 0 30 :2 0
741 cda cdd b1
:2 0 30 :2 0 746
cdf ce1 :3 0 59
:3 0 118 :3 0 5a
:3 0 32 :3 0 1a
:3 0 1d :3 0 1c
:3 0 28 :3 0 749
ce4 ceb ce3 cec
0 1b1b 73 :3 0
59 :3 0 30 :2 0
750 cee cf1 b6
:2 0 30 :2 0 755
cf3 cf5 :3 0 66
:3 0 67 :3 0 cf7
cf8 0 66 :3 0
77 :3 0 cfa cfb
0 18 :2 0 2
:4 0 119 :2 0 79
:2 0 27 :2 0 758
d00 d02 :3 0 75b
cfc d04 cf9 d06
d05 :2 0 69 :3 0
7a :3 0 d08 d09
0 6b :4 0 11a
:4 0 6e :2 0 6f
:3 0 75f d0d d0f
:3 0 6e :2 0 82
:4 0 762 d11 d13
:3 0 6e :2 0 83
:4 0 765 d15 d17
:3 0 6e :2 0 73
:3 0 74 :3 0 59
:3 0 768 d1b d1d
75 :4 0 76a d1a
d20 76d d19 d22
:3 0 6e :2 0 e4
:4 0 770 d24 d26
:3 0 6e :2 0 71
:4 0 773 d28 d2a
:3 0 6e :2 0 28
:3 0 776 d2c d2e
:3 0 6e :2 0 71
:4 0 779 d30 d32
:3 0 77c d0a d34
:2 0 d36 77f d37
d07 d36 0 d38
781 0 d64 66
:3 0 67 :3 0 d39
d3a 0 66 :3 0
77 :3 0 d3c d3d
0 27 :2 0 2
:4 0 11b :2 0 79
:2 0 27 :2 0 783
d42 d44 :3 0 786
d3e d46 d3b d48
d47 :2 0 69 :3 0
7a :3 0 d4a d4b
0 6b :4 0 11c
:4 0 6e :2 0 6f
:3 0 78a d4f d51
:3 0 78d d4c d53
:2 0 d55 790 d56
d49 d55 0 d57
792 0 d64 88
:3 0 e7 :3 0 d58
d59 0 73 :3 0
59 :3 0 30 :2 0
794 d5b d5e 28
:3 0 8a :3 0 797
d5a d62 :2 0 d64
79b d65 cf6 d64
0 d66 79f 0
1b1b 21 :4 0 d67
d68 0 1b1b 11d
:3 0 11e :3 0 97
:3 0 98 :3 0 1f
:3 0 97 :3 0 98
:3 0 11d :3 0 11e
:3 0 21 :3 0 44
:3 0 11f :3 0 b7
:3 0 17 :3 0 120
:3 0 17 :3 0 121
:3 0 1d :3 0 122
:3 0 26 :4 0 123
1 :8 0 d84 15
:3 0 9b :3 0 d7f
d80 0 9c :3 0
d81 d82 0 d84
7a1 dce 9d :3 0
15 :3 0 9b :3 0
d87 d88 0 9c
:3 0 d89 d8a 0
dc4 66 :3 0 67
:3 0 d8c d8d 0
66 :3 0 77 :3 0
d8f d90 0 9e
:2 0 2 :4 0 124
:2 0 79 :2 0 27
:2 0 7a4 d95 d97
:3 0 7a7 d91 d99
d8e d9b d9a :2 0
69 :3 0 7a :3 0
d9d d9e 0 6b
:4 0 125 :4 0 6e
:2 0 6f :3 0 7ab
da2 da4 :3 0 6e
:2 0 82 :4 0 7ae
da6 da8 :3 0 6e
:2 0 a1 :4 0 7b1
daa dac :3 0 6e
:2 0 9c :3 0 7b4
dae db0 :3 0 6e
:2 0 a2 :4 0 7b7
db2 db4 :3 0 6e
:2 0 a3 :3 0 a4
:3 0 27 :2 0 a5
:2 0 7ba db7 dbb
7be db6 dbd :3 0
7c1 d9f dbf :2 0
dc1 7c4 dc2 d9c
dc1 0 dc3 7c6
0 dc4 7c8 dc7
:3 0 dc7 0 dc7
dc6 dc4 dc5 :6 0
dc9 16 :3 0 7cb
dcb 7cd dca dc9
:2 0 dcc 7cf :2 0
dce 0 dce dcd
d84 dcc :6 0 1b1b
1 :3 0 15 :3 0
9b :3 0 dd0 dd1
0 15 :3 0 8f
:2 0 a6 :3 0 dd3
dd5 0 7d3 dd4
dd7 :3 0 dd8 :2 0
21 :3 0 96 :2 0
7d6 ddb ddc :3 0
ddd :2 0 dde :2 0
dd9 de0 ddf :2 0
46 :3 0 27 :2 0
de2 de3 0 df4
73 :3 0 44 :3 0
30 :2 0 7d8 de5
de8 a7 :2 0 30
:2 0 7dd dea dec
:3 0 1f :3 0 21
:3 0 dee def 0
df1 7e0 df2 ded
df1 0 df3 7e2
0 df4 7e4 df5
de1 df4 0 df6
7e7 0 1b1b 33
:3 0 30 :2 0 df7
df8 0 1b1b 44
:3 0 30 :2 0 dfa
dfb 0 1b1b 63
:3 0 8f :2 0 27
:2 0 7eb dfe e00
:3 0 a3 :3 0 26
:3 0 27 :2 0 27
:2 0 7ee e02 e06
8f :2 0 30 :4 0
7f4 e08 e0a :3 0
126 :3 0 127 :3 0
128 :3 0 a3 :3 0
1f :3 0 128 :3 0
a3 :3 0 127 :3 0
128 :3 0 a3 :3 0
22 :3 0 128 :3 0
a3 :3 0 129 :3 0
12a :3 0 37 :3 0
12a :3 0 19 :3 0
21 :3 0 44 :3 0
47 :3 0 11f :3 0
120 :3 0 17 :3 0
121 :3 0 1d :3 0
122 :3 0 12b :4 0
12c 1 :8 0 e2e
15 :3 0 9b :3 0
e29 e2a 0 9c
:3 0 e2b e2c 0
e2e 7f7 e78 9d
:3 0 15 :3 0 9b
:3 0 e31 e32 0
9c :3 0 e33 e34
0 e6e 66 :3 0
67 :3 0 e36 e37
0 66 :3 0 77
:3 0 e39 e3a 0
9e :2 0 2 :4 0
12d :2 0 79 :2 0
27 :2 0 7fa e3f
e41 :3 0 7fd e3b
e43 e38 e45 e44
:2 0 69 :3 0 7a
:3 0 e47 e48 0
6b :4 0 12e :4 0
6e :2 0 6f :3 0
801 e4c e4e :3 0
6e :2 0 82 :4 0
804 e50 e52 :3 0
6e :2 0 a1 :4 0
807 e54 e56 :3 0
6e :2 0 9c :3 0
80a e58 e5a :3 0
6e :2 0 a2 :4 0
80d e5c e5e :3 0
6e :2 0 a3 :3 0
a4 :3 0 27 :2 0
a5 :2 0 810 e61
e65 814 e60 e67
:3 0 817 e49 e69
:2 0 e6b 81a e6c
e46 e6b 0 e6d
81c 0 e6e 81e
e71 :3 0 e71 0
e71 e70 e6e e6f
:6 0 e73 18 :3 0
821 e75 823 e74
e73 :2 0 e76 825
:2 0 e78 0 e78
e77 e2e e76 :6 0
f99 1 :3 0 15
:3 0 9b :3 0 e7a
e7b 0 15 :3 0
8f :2 0 a6 :3 0
e7d e7f 0 829
e7e e81 :3 0 e82
:2 0 46 :3 0 27
:2 0 e84 e85 0
f12 73 :3 0 47
:3 0 30 :2 0 82c
e87 e8a 8f :2 0
30 :2 0 831 e8c
e8e :3 0 e8f :2 0
73 :3 0 44 :3 0
30 :2 0 834 e91
e94 8f :2 0 27
:2 0 839 e96 e98
:3 0 e99 :2 0 e90
e9b e9a :2 0 126
:3 0 12f :3 0 128
:3 0 a3 :3 0 1f
:3 0 128 :3 0 a3
:3 0 12f :3 0 128
:3 0 a3 :3 0 22
:3 0 128 :3 0 a3
:3 0 130 :3 0 131
:3 0 37 :3 0 19
:3 0 21 :3 0 44
:3 0 11f :3 0 120
:3 0 17 :3 0 121
:3 0 1d :3 0 122
:3 0 12b :4 0 132
1 :8 0 ebd 15
:3 0 9b :3 0 eb8
eb9 0 9c :3 0
eba ebb 0 ebd
83c f07 9d :3 0
15 :3 0 9b :3 0
ec0 ec1 0 9c
:3 0 ec2 ec3 0
efd 66 :3 0 67
:3 0 ec5 ec6 0
66 :3 0 77 :3 0
ec8 ec9 0 9e
:2 0 2 :4 0 133
:2 0 79 :2 0 27
:2 0 83f ece ed0
:3 0 842 eca ed2
ec7 ed4 ed3 :2 0
69 :3 0 7a :3 0
ed6 ed7 0 6b
:4 0 134 :4 0 6e
:2 0 6f :3 0 846
edb edd :3 0 6e
:2 0 82 :4 0 849
edf ee1 :3 0 6e
:2 0 a1 :4 0 84c
ee3 ee5 :3 0 6e
:2 0 9c :3 0 84f
ee7 ee9 :3 0 6e
:2 0 a2 :4 0 852
eeb eed :3 0 6e
:2 0 a3 :3 0 a4
:3 0 27 :2 0 a5
:2 0 855 ef0 ef4
859 eef ef6 :3 0
85c ed8 ef8 :2 0
efa 85f efb ed5
efa 0 efc 861
0 efd 863 f00
:3 0 f00 0 f00
eff efd efe :6 0
f02 1a :3 0 866
f04 868 f03 f02
:2 0 f05 86a :2 0
f07 0 f07 f06
ebd f05 :6 0 f09
1 :3 0 86c f0e
33 :3 0 10d :2 0
f0a f0b 0 f0d
86e f0f e9c f09
0 f10 0 f0d
0 f10 870 0
f12 ad :3 0 873
f97 15 :3 0 9b
:3 0 f13 f14 0
15 :3 0 8f :2 0
d8 :3 0 f16 f18
0 878 f17 f1a
:3 0 f1b :2 0 73
:3 0 44 :3 0 30
:2 0 87b f1d f20
8f :2 0 27 :2 0
880 f22 f24 :3 0
f25 :2 0 f1c f27
f26 :2 0 126 :3 0
12f :3 0 128 :3 0
a3 :3 0 1f :3 0
128 :3 0 a3 :3 0
12f :3 0 128 :3 0
a3 :3 0 22 :3 0
128 :3 0 a3 :3 0
130 :3 0 131 :3 0
37 :3 0 19 :3 0
21 :3 0 44 :3 0
11f :3 0 120 :3 0
17 :3 0 121 :3 0
1d :3 0 122 :3 0
12b :4 0 135 1
:8 0 f49 15 :3 0
9b :3 0 f44 f45
0 9c :3 0 f46
f47 0 f49 883
f93 9d :3 0 15
:3 0 9b :3 0 f4c
f4d 0 9c :3 0
f4e f4f 0 f89
66 :3 0 67 :3 0
f51 f52 0 66
:3 0 77 :3 0 f54
f55 0 9e :2 0
2 :4 0 136 :2 0
79 :2 0 27 :2 0
886 f5a f5c :3 0
889 f56 f5e f53
f60 f5f :2 0 69
:3 0 7a :3 0 f62
f63 0 6b :4 0
137 :4 0 6e :2 0
6f :3 0 88d f67
f69 :3 0 6e :2 0
82 :4 0 890 f6b
f6d :3 0 6e :2 0
a1 :4 0 893 f6f
f71 :3 0 6e :2 0
9c :3 0 896 f73
f75 :3 0 6e :2 0
a2 :4 0 899 f77
f79 :3 0 6e :2 0
a3 :3 0 a4 :3 0
27 :2 0 a5 :2 0
89c f7c f80 8a0
f7b f82 :3 0 8a3
f64 f84 :2 0 f86
8a6 f87 f61 f86
0 f88 8a8 0
f89 8aa f8c :3 0
f8c 0 f8c f8b
f89 f8a :6 0 f8e
1c :3 0 8ad f90
8af f8f f8e :2 0
f91 8b1 :2 0 f93
0 f93 f92 f49
f91 :6 0 f95 1
:3 0 8b3 f96 f28
f95 0 f98 e83
f12 0 f98 8b5
0 f99 8b8 1007
126 :3 0 12f :3 0
128 :3 0 a3 :3 0
1f :3 0 128 :3 0
a3 :3 0 12f :3 0
128 :3 0 a3 :3 0
22 :3 0 128 :3 0
a3 :3 0 130 :3 0
131 :3 0 37 :3 0
19 :3 0 21 :3 0
44 :3 0 11f :3 0
120 :3 0 17 :3 0
121 :3 0 1d :3 0
122 :3 0 12b :4 0
138 1 :8 0 fba
15 :3 0 9b :3 0
fb5 fb6 0 9c
:3 0 fb7 fb8 0
fba 8bb 1004 9d
:3 0 15 :3 0 9b
:3 0 fbd fbe 0
9c :3 0 fbf fc0
0 ffa 66 :3 0
67 :3 0 fc2 fc3
0 66 :3 0 77
:3 0 fc5 fc6 0
9e :2 0 2 :4 0
139 :2 0 79 :2 0
27 :2 0 8be fcb
fcd :3 0 8c1 fc7
fcf fc4 fd1 fd0
:2 0 69 :3 0 7a
:3 0 fd3 fd4 0
6b :4 0 13a :4 0
6e :2 0 6f :3 0
8c5 fd8 fda :3 0
6e :2 0 82 :4 0
8c8 fdc fde :3 0
6e :2 0 a1 :4 0
8cb fe0 fe2 :3 0
6e :2 0 9c :3 0
8ce fe4 fe6 :3 0
6e :2 0 a2 :4 0
8d1 fe8 fea :3 0
6e :2 0 a3 :3 0
a4 :3 0 27 :2 0
a5 :2 0 8d4 fed
ff1 8d8 fec ff3
:3 0 8db fd5 ff5
:2 0 ff7 8de ff8
fd2 ff7 0 ff9
8e0 0 ffa 8e2
ffd :3 0 ffd 0
ffd ffc ffa ffb
:6 0 fff 1e :3 0
8e5 1001 8e7 1000
fff :2 0 1002 8e9
:2 0 1004 0 1004
1003 fba 1002 :6 0
1006 1 :3 0 8eb
1008 e0b f99 0
1009 0 1006 0
1009 8ed 0 100a
8f0 11fa a3 :3 0
26 :3 0 27 :2 0
27 :2 0 8f2 100b
100f 8f :2 0 30
:4 0 8f8 1011 1013
:3 0 126 :3 0 127
:3 0 128 :3 0 a3
:3 0 1f :3 0 128
:3 0 a3 :3 0 127
:3 0 128 :3 0 a3
:3 0 129 :3 0 37
:3 0 12a :3 0 12a
:3 0 19 :3 0 21
:3 0 44 :3 0 47
:3 0 11f :3 0 120
:3 0 17 :3 0 121
:3 0 1d :3 0 122
:3 0 12b :4 0 13b
1 :8 0 1034 15
:3 0 9b :3 0 102f
1030 0 9c :3 0
1031 1032 0 1034
8fb 107e 9d :3 0
15 :3 0 9b :3 0
1037 1038 0 9c
:3 0 1039 103a 0
1074 66 :3 0 67
:3 0 103c 103d 0
66 :3 0 77 :3 0
103f 1040 0 9e
:2 0 2 :4 0 13c
:2 0 79 :2 0 27
:2 0 8fe 1045 1047
:3 0 901 1041 1049
103e 104b 104a :2 0
69 :3 0 7a :3 0
104d 104e 0 6b
:4 0 13d :4 0 6e
:2 0 6f :3 0 905
1052 1054 :3 0 6e
:2 0 82 :4 0 908
1056 1058 :3 0 6e
:2 0 a1 :4 0 90b
105a 105c :3 0 6e
:2 0 9c :3 0 90e
105e 1060 :3 0 6e
:2 0 a2 :4 0 911
1062 1064 :3 0 6e
:2 0 a3 :3 0 a4
:3 0 27 :2 0 a5
:2 0 914 1067 106b
918 1066 106d :3 0
91b 104f 106f :2 0
1071 91e 1072 104c
1071 0 1073 920
0 1074 922 1077
:3 0 1077 0 1077
1076 1074 1075 :6 0
1079 20 :3 0 925
107b 927 107a 1079
:2 0 107c 929 :2 0
107e 0 107e 107d
1034 107c :6 0 118b
1 :3 0 15 :3 0
9b :3 0 1080 1081
0 15 :3 0 8f
:2 0 a6 :3 0 1083
1085 0 92d 1084
1087 :3 0 1088 :2 0
46 :3 0 27 :2 0
108a 108b 0 1113
73 :3 0 47 :3 0
30 :2 0 930 108d
1090 8f :2 0 30
:2 0 935 1092 1094
:3 0 1095 :2 0 73
:3 0 44 :3 0 30
:2 0 938 1097 109a
8f :2 0 27 :2 0
93d 109c 109e :3 0
109f :2 0 1096 10a1
10a0 :2 0 126 :3 0
12f :3 0 128 :3 0
a3 :3 0 1f :3 0
128 :3 0 a3 :3 0
130 :3 0 37 :3 0
131 :3 0 19 :3 0
21 :3 0 44 :3 0
11f :3 0 120 :3 0
17 :3 0 121 :3 0
1d :3 0 122 :3 0
12b :4 0 13e 1
:8 0 10bd 15 :3 0
9b :3 0 10b8 10b9
0 9c :3 0 10ba
10bb 0 10bd 940
1107 9d :3 0 15
:3 0 9b :3 0 10c0
10c1 0 9c :3 0
10c2 10c3 0 10fd
66 :3 0 67 :3 0
10c5 10c6 0 66
:3 0 77 :3 0 10c8
10c9 0 9e :2 0
2 :4 0 13f :2 0
79 :2 0 27 :2 0
943 10ce 10d0 :3 0
946 10ca 10d2 10c7
10d4 10d3 :2 0 69
:3 0 7a :3 0 10d6
10d7 0 6b :4 0
140 :4 0 6e :2 0
6f :3 0 94a 10db
10dd :3 0 6e :2 0
82 :4 0 94d 10df
10e1 :3 0 6e :2 0
a1 :4 0 950 10e3
10e5 :3 0 6e :2 0
9c :3 0 953 10e7
10e9 :3 0 6e :2 0
a2 :4 0 956 10eb
10ed :3 0 6e :2 0
a3 :3 0 a4 :3 0
27 :2 0 a5 :2 0
959 10f0 10f4 95d
10ef 10f6 :3 0 960
10d8 10f8 :2 0 10fa
963 10fb 10d5 10fa
0 10fc 965 0
10fd 967 1100 :3 0
1100 0 1100 10ff
10fd 10fe :6 0 1102
22 :3 0 96a 1104
96c 1103 1102 :2 0
1105 96e :2 0 1107
0 1107 1106 10bd
1105 :6 0 1109 1
:3 0 970 110f 33
:3 0 10d :2 0 110a
110b 0 110e 0
110e 972 1110 10a2
1109 0 1111 0
110e 0 1111 975
0 1113 ad :3 0
978 1189 15 :3 0
9b :3 0 1114 1115
0 15 :3 0 8f
:2 0 d8 :3 0 1117
1119 0 97d 1118
111b :3 0 111c :2 0
126 :3 0 12f :3 0
128 :3 0 a3 :3 0
1f :3 0 128 :3 0
a3 :3 0 12f :3 0
128 :3 0 a3 :3 0
130 :3 0 37 :3 0
131 :3 0 19 :3 0
21 :3 0 44 :3 0
11f :3 0 120 :3 0
17 :3 0 121 :3 0
1d :3 0 122 :3 0
12b :4 0 141 1
:8 0 113b 15 :3 0
9b :3 0 1136 1137
0 9c :3 0 1138
1139 0 113b 980
1185 9d :3 0 15
:3 0 9b :3 0 113e
113f 0 9c :3 0
1140 1141 0 117b
66 :3 0 67 :3 0
1143 1144 0 66
:3 0 77 :3 0 1146
1147 0 9e :2 0
2 :4 0 142 :2 0
79 :2 0 27 :2 0
983 114c 114e :3 0
986 1148 1150 1145
1152 1151 :2 0 69
:3 0 7a :3 0 1154
1155 0 6b :4 0
143 :4 0 6e :2 0
6f :3 0 98a 1159
115b :3 0 6e :2 0
82 :4 0 98d 115d
115f :3 0 6e :2 0
a1 :4 0 990 1161
1163 :3 0 6e :2 0
9c :3 0 993 1165
1167 :3 0 6e :2 0
a2 :4 0 996 1169
116b :3 0 6e :2 0
a3 :3 0 a4 :3 0
27 :2 0 a5 :2 0
999 116e 1172 99d
116d 1174 :3 0 9a0
1156 1176 :2 0 1178
9a3 1179 1153 1178
0 117a 9a5 0
117b 9a7 117e :3 0
117e 0 117e 117d
117b 117c :6 0 1180
24 :3 0 9aa 1182
9ac 1181 1180 :2 0
1183 9ae :2 0 1185
0 1185 1184 113b
1183 :6 0 1187 1
:3 0 9b0 1188 111d
1187 0 118a 1089
1113 0 118a 9b2
0 118b 9b5 11f6
126 :3 0 12f :3 0
128 :3 0 a3 :3 0
1f :3 0 128 :3 0
a3 :3 0 12f :3 0
128 :3 0 a3 :3 0
130 :3 0 37 :3 0
131 :3 0 19 :3 0
21 :3 0 44 :3 0
11f :3 0 120 :3 0
17 :3 0 121 :3 0
1d :3 0 122 :3 0
12b :4 0 144 1
:8 0 11a9 15 :3 0
9b :3 0 11a4 11a5
0 9c :3 0 11a6
11a7 0 11a9 9b8
11f3 9d :3 0 15
:3 0 9b :3 0 11ac
11ad 0 9c :3 0
11ae 11af 0 11e9
66 :3 0 67 :3 0
11b1 11b2 0 66
:3 0 77 :3 0 11b4
11b5 0 9e :2 0
2 :4 0 145 :2 0
79 :2 0 27 :2 0
9bb 11ba 11bc :3 0
9be 11b6 11be 11b3
11c0 11bf :2 0 69
:3 0 7a :3 0 11c2
11c3 0 6b :4 0
146 :4 0 6e :2 0
6f :3 0 9c2 11c7
11c9 :3 0 6e :2 0
82 :4 0 9c5 11cb
11cd :3 0 6e :2 0
a1 :4 0 9c8 11cf
11d1 :3 0 6e :2 0
9c :3 0 9cb 11d3
11d5 :3 0 6e :2 0
a2 :4 0 9ce 11d7
11d9 :3 0 6e :2 0
a3 :3 0 a4 :3 0
27 :2 0 a5 :2 0
9d1 11dc 11e0 9d5
11db 11e2 :3 0 9d8
11c4 11e4 :2 0 11e6
9db 11e7 11c1 11e6
0 11e8 9dd 0
11e9 9df 11ec :3 0
11ec 0 11ec 11eb
11e9 11ea :6 0 11ee
26 :3 0 9e2 11f0
9e4 11ef 11ee :2 0
11f1 9e6 :2 0 11f3
0 11f3 11f2 11a9
11f1 :6 0 11f5 1
:3 0 9e8 11f7 1014
118b 0 11f8 0
11f5 0 11f8 9ea
0 11f9 9ed 11fb
e01 100a 0 11fc
0 11f9 0 11fc
9ef 0 1b1b 15
:3 0 9b :3 0 11fd
11fe 0 15 :3 0
8f :2 0 a6 :3 0
1200 1202 0 9f4
1201 1204 :3 0 1205
:2 0 73 :3 0 44
:3 0 30 :2 0 9f7
1207 120a 8f :2 0
27 :2 0 9fc 120c
120e :3 0 66 :3 0
67 :3 0 1210 1211
0 66 :3 0 77
:3 0 1213 1214 0
18 :2 0 2 :4 0
147 :2 0 79 :2 0
27 :2 0 9ff 1219
121b :3 0 a02 1215
121d 1212 121f 121e
:2 0 69 :3 0 7a
:3 0 1221 1222 0
6b :4 0 148 :4 0
6e :2 0 6f :3 0
a06 1226 1228 :3 0
6e :2 0 82 :4 0
a09 122a 122c :3 0
6e :2 0 83 :4 0
a0c 122e 1230 :3 0
6e :2 0 73 :3 0
74 :3 0 84 :3 0
149 :3 0 1235 1236
0 a0f 1234 1238
75 :4 0 a11 1233
123b a14 1232 123d
:3 0 6e :2 0 e4
:4 0 a17 123f 1241
:3 0 6e :2 0 71
:4 0 a1a 1243 1245
:3 0 6e :2 0 1d
:3 0 a1d 1247 1249
:3 0 6e :2 0 71
:4 0 a20 124b 124d
:3 0 a23 1223 124f
:2 0 1251 a26 1252
1220 1251 0 1253
a28 0 127e 66
:3 0 67 :3 0 1254
1255 0 66 :3 0
77 :3 0 1257 1258
0 27 :2 0 2
:4 0 14a :2 0 79
:2 0 27 :2 0 a2a
125d 125f :3 0 a2d
1259 1261 1256 1263
1262 :2 0 69 :3 0
7a :3 0 1265 1266
0 6b :4 0 14b
:4 0 6e :2 0 6f
:3 0 a31 126a 126c
:3 0 a34 1267 126e
:2 0 1270 a37 1271
1264 1270 0 1272
a39 0 127e 88
:3 0 e7 :3 0 1273
1274 0 84 :3 0
149 :3 0 1276 1277
0 1d :3 0 8a
:3 0 a3b 1275 127b
:2 0 127e ad :3 0
a3f 13d2 19 :3 0
96 :2 0 a43 1280
1281 :3 0 1282 :2 0
63 :3 0 8f :2 0
27 :2 0 a47 1285
1287 :3 0 47 :3 0
30 :2 0 1289 128a
0 12ed 14c :3 0
14d :3 0 47 :3 0
14e :3 0 b7 :3 0
17 :3 0 14f :3 0
19 :3 0 150 :3 0
128 :3 0 a3 :3 0
1f :3 0 128 :3 0
a3 :3 0 22 :4 0
151 1 :8 0 12a1
15 :3 0 9b :3 0
129c 129d 0 9c
:3 0 129e 129f 0
12a1 a4a 12eb 9d
:3 0 15 :3 0 9b
:3 0 12a4 12a5 0
9c :3 0 12a6 12a7
0 12e1 66 :3 0
67 :3 0 12a9 12aa
0 66 :3 0 77
:3 0 12ac 12ad 0
9e :2 0 2 :4 0
152 :2 0 79 :2 0
27 :2 0 a4d 12b2
12b4 :3 0 a50 12ae
12b6 12ab 12b8 12b7
:2 0 69 :3 0 7a
:3 0 12ba 12bb 0
6b :4 0 153 :4 0
6e :2 0 6f :3 0
a54 12bf 12c1 :3 0
6e :2 0 82 :4 0
a57 12c3 12c5 :3 0
6e :2 0 a1 :4 0
a5a 12c7 12c9 :3 0
6e :2 0 9c :3 0
a5d 12cb 12cd :3 0
6e :2 0 a2 :4 0
a60 12cf 12d1 :3 0
6e :2 0 a3 :3 0
a4 :3 0 27 :2 0
a5 :2 0 a63 12d4
12d8 a67 12d3 12da
:3 0 a6a 12bc 12dc
:2 0 12de a6d 12df
12b9 12de 0 12e0
a6f 0 12e1 a71
12e4 :3 0 12e4 0
12e4 12e3 12e1 12e2
:6 0 12e6 28 :3 0
a74 12e8 a76 12e7
12e6 :2 0 12e9 a78
:2 0 12eb 0 12eb
12ea 12a1 12e9 :6 0
12ed 1 :3 0 a7a
1350 47 :3 0 30
:2 0 12ee 12ef 0
134f 14c :3 0 14d
:3 0 47 :3 0 14e
:3 0 b7 :3 0 17
:3 0 14f :3 0 19
:3 0 150 :3 0 128
:3 0 a3 :3 0 1f
:4 0 154 1 :8 0
1303 15 :3 0 9b
:3 0 12fe 12ff 0
9c :3 0 1300 1301
0 1303 a7d 134d
9d :3 0 15 :3 0
9b :3 0 1306 1307
0 9c :3 0 1308
1309 0 1343 66
:3 0 67 :3 0 130b
130c 0 66 :3 0
77 :3 0 130e 130f
0 9e :2 0 2
:4 0 155 :2 0 79
:2 0 27 :2 0 a80
1314 1316 :3 0 a83
1310 1318 130d 131a
1319 :2 0 69 :3 0
7a :3 0 131c 131d
0 6b :4 0 156
:4 0 6e :2 0 6f
:3 0 a87 1321 1323
:3 0 6e :2 0 82
:4 0 a8a 1325 1327
:3 0 6e :2 0 a1
:4 0 a8d 1329 132b
:3 0 6e :2 0 9c
:3 0 a90 132d 132f
:3 0 6e :2 0 a2
:4 0 a93 1331 1333
:3 0 6e :2 0 a3
:3 0 a4 :3 0 27
:2 0 a5 :2 0 a96
1336 133a a9a 1335
133c :3 0 a9d 131e
133e :2 0 1340 aa0
1341 131b 1340 0
1342 aa2 0 1343
aa4 1346 :3 0 1346
0 1346 1345 1343
1344 :6 0 1348 2a
:3 0 aa7 134a aa9
1349 1348 :2 0 134b
aab :2 0 134d 0
134d 134c 1303 134b
:6 0 134f 1 :3 0
aad 1351 1288 12ed
0 1352 0 134f
0 1352 ab0 0
13d0 73 :3 0 47
:3 0 30 :2 0 ab3
1353 1356 73 :3 0
a7 :2 0 37 :3 0
30 :2 0 ab6 1358
135c abb 1359 135e
:3 0 66 :3 0 67
:3 0 1360 1361 0
66 :3 0 77 :3 0
1363 1364 0 18
:2 0 2 :4 0 157
:2 0 79 :2 0 27
:2 0 abe 1369 136b
:3 0 ac1 1365 136d
1362 136f 136e :2 0
69 :3 0 7a :3 0
1371 1372 0 6b
:4 0 158 :4 0 6e
:2 0 6f :3 0 ac5
1376 1378 :3 0 6e
:2 0 82 :4 0 ac8
137a 137c :3 0 6e
:2 0 83 :4 0 acb
137e 1380 :3 0 6e
:2 0 73 :3 0 74
:3 0 84 :3 0 149
:3 0 1385 1386 0
ace 1384 1388 75
:4 0 ad0 1383 138b
ad3 1382 138d :3 0
6e :2 0 e4 :4 0
ad6 138f 1391 :3 0
6e :2 0 71 :4 0
ad9 1393 1395 :3 0
6e :2 0 1d :3 0
adc 1397 1399 :3 0
6e :2 0 71 :4 0
adf 139b 139d :3 0
ae2 1373 139f :2 0
13a1 ae5 13a2 1370
13a1 0 13a3 ae7
0 13cd 66 :3 0
67 :3 0 13a4 13a5
0 66 :3 0 77
:3 0 13a7 13a8 0
27 :2 0 2 :4 0
159 :2 0 79 :2 0
27 :2 0 ae9 13ad
13af :3 0 aec 13a9
13b1 13a6 13b3 13b2
:2 0 69 :3 0 7a
:3 0 13b5 13b6 0
6b :4 0 15a :4 0
6e :2 0 6f :3 0
af0 13ba 13bc :3 0
af3 13b7 13be :2 0
13c0 af6 13c1 13b4
13c0 0 13c2 af8
0 13cd 88 :3 0
e7 :3 0 13c3 13c4
0 84 :3 0 149
:3 0 13c6 13c7 0
1d :3 0 8a :3 0
afa 13c5 13cb :2 0
13cd afe 13ce 135f
13cd 0 13cf b02
0 13d0 b04 13d1
1283 13d0 0 13d3
120f 127e 0 13d3
b07 0 13d8 46
:3 0 27 :2 0 13d4
13d5 0 13d8 ad
:3 0 b0a 1461 73
:3 0 46 :3 0 30
:2 0 b0d 13d9 13dc
8f :2 0 27 :2 0
b12 13de 13e0 :3 0
13e1 :2 0 15b :3 0
73 :3 0 32 :3 0
30 :2 0 b15 13e4
13e7 b18 13e3 13e9
13ea :2 0 b6 :2 0
30 :2 0 b1c 13ec
13ee :3 0 13e2 13f0
13ef :2 0 66 :3 0
67 :3 0 13f2 13f3
0 66 :3 0 77
:3 0 13f5 13f6 0
18 :2 0 2 :4 0
15c :2 0 79 :2 0
27 :2 0 b1f 13fb
13fd :3 0 b22 13f7
13ff 13f4 1401 1400
:2 0 69 :3 0 7a
:3 0 1403 1404 0
6b :4 0 15d :4 0
6e :2 0 6f :3 0
b26 1408 140a :3 0
6e :2 0 82 :4 0
b29 140c 140e :3 0
6e :2 0 83 :4 0
b2c 1410 1412 :3 0
6e :2 0 73 :3 0
74 :3 0 84 :3 0
149 :3 0 1417 1418
0 b2f 1416 141a
75 :4 0 b31 1415
141d b34 1414 141f
:3 0 6e :2 0 e4
:4 0 b37 1421 1423
:3 0 6e :2 0 71
:4 0 b3a 1425 1427
:3 0 6e :2 0 1d
:3 0 b3d 1429 142b
:3 0 6e :2 0 71
:4 0 b40 142d 142f
:3 0 b43 1405 1431
:2 0 1433 b46 1434
1402 1433 0 1435
b48 0 145f 66
:3 0 67 :3 0 1436
1437 0 66 :3 0
77 :3 0 1439 143a
0 27 :2 0 2
:4 0 15e :2 0 79
:2 0 27 :2 0 b4a
143f 1441 :3 0 b4d
143b 1443 1438 1445
1444 :2 0 69 :3 0
7a :3 0 1447 1448
0 6b :4 0 15f
:4 0 6e :2 0 6f
:3 0 b51 144c 144e
:3 0 b54 1449 1450
:2 0 1452 b57 1453
1446 1452 0 1454
b59 0 145f 88
:3 0 e7 :3 0 1455
1456 0 84 :3 0
149 :3 0 1458 1459
0 1d :3 0 8a
:3 0 b5b 1457 145d
:2 0 145f b5f 1460
13f1 145f 0 1462
1206 13d8 0 1462
b63 0 1b1b a3
:3 0 26 :3 0 27
:2 0 27 :2 0 b66
1463 1467 8f :2 0
30 :4 0 b6c 1469
146b :3 0 2b :3 0
a3 :3 0 2b :3 0
6e :2 0 1d :3 0
b6f 1470 1472 :3 0
27 :2 0 2a :2 0
b72 146e 1476 146d
1477 0 1650 160
:3 0 97 :3 0 161
:3 0 21 :3 0 162
:3 0 73 :3 0 97
:3 0 161 :3 0 163
:3 0 73 :3 0 97
:3 0 161 :3 0 164
:3 0 2d :3 0 48
:3 0 4c :3 0 49
:3 0 4a :3 0 165
:3 0 121 :3 0 1d
:4 0 166 1 :8 0
1494 15 :3 0 9b
:3 0 148f 1490 0
9c :3 0 1491 1492
0 1494 b76 14de
9d :3 0 15 :3 0
9b :3 0 1497 1498
0 9c :3 0 1499
149a 0 14d4 66
:3 0 67 :3 0 149c
149d 0 66 :3 0
77 :3 0 149f 14a0
0 9e :2 0 2
:4 0 167 :2 0 79
:2 0 27 :2 0 b79
14a5 14a7 :3 0 b7c
14a1 14a9 149e 14ab
14aa :2 0 69 :3 0
7a :3 0 14ad 14ae
0 6b :4 0 168
:4 0 6e :2 0 6f
:3 0 b80 14b2 14b4
:3 0 6e :2 0 82
:4 0 b83 14b6 14b8
:3 0 6e :2 0 a1
:4 0 b86 14ba 14bc
:3 0 6e :2 0 9c
:3 0 b89 14be 14c0
:3 0 6e :2 0 a2
:4 0 b8c 14c2 14c4
:3 0 6e :2 0 a3
:3 0 a4 :3 0 27
:2 0 a5 :2 0 b8f
14c7 14cb b93 14c6
14cd :3 0 b96 14af
14cf :2 0 14d1 b99
14d2 14ac 14d1 0
14d3 b9b 0 14d4
b9d 14d7 :3 0 14d7
0 14d7 14d6 14d4
14d5 :6 0 14d9 2c
:3 0 ba0 14db ba2
14da 14d9 :2 0 14dc
ba4 :2 0 14de 0
14de 14dd 1494 14dc
:6 0 1650 1 :3 0
15 :3 0 9b :3 0
14e0 14e1 0 15
:3 0 8f :2 0 d8
:3 0 14e3 14e5 0
ba8 14e4 14e7 :3 0
14e8 :2 0 66 :3 0
67 :3 0 14ea 14eb
0 66 :3 0 77
:3 0 14ed 14ee 0
18 :2 0 2 :4 0
169 :2 0 79 :2 0
27 :2 0 bab 14f3
14f5 :3 0 bae 14ef
14f7 14ec 14f9 14f8
:2 0 69 :3 0 7a
:3 0 14fb 14fc 0
6b :4 0 16a :4 0
6e :2 0 6f :3 0
bb2 1500 1502 :3 0
6e :2 0 82 :4 0
bb5 1504 1506 :3 0
6e :2 0 83 :4 0
bb8 1508 150a :3 0
6e :2 0 73 :3 0
74 :3 0 84 :3 0
e3 :3 0 150f 1510
0 bbb 150e 1512
75 :4 0 bbd 150d
1515 bc0 150c 1517
:3 0 6e :2 0 e4
:4 0 bc3 1519 151b
:3 0 6e :2 0 71
:4 0 bc6 151d 151f
:3 0 6e :2 0 1d
:3 0 bc9 1521 1523
:3 0 6e :2 0 71
:4 0 bcc 1525 1527
:3 0 bcf 14fd 1529
:2 0 152b bd2 152c
14fa 152b 0 152d
bd4 0 1557 66
:3 0 67 :3 0 152e
152f 0 66 :3 0
77 :3 0 1531 1532
0 27 :2 0 2
:4 0 16b :2 0 79
:2 0 27 :2 0 bd6
1537 1539 :3 0 bd9
1533 153b 1530 153d
153c :2 0 69 :3 0
7a :3 0 153f 1540
0 6b :4 0 16c
:4 0 6e :2 0 6f
:3 0 bdd 1544 1546
:3 0 be0 1541 1548
:2 0 154a be3 154b
153e 154a 0 154c
be5 0 1557 88
:3 0 e7 :3 0 154d
154e 0 84 :3 0
e3 :3 0 1550 1551
0 1d :3 0 8a
:3 0 be7 154f 1555
:2 0 1557 beb 1558
14e9 1557 0 1559
bef 0 1650 a3
:3 0 4c :3 0 27
:2 0 27 :2 0 bf1
155a 155e 8f :2 0
30 :4 0 bf7 1560
1562 :3 0 1563 :2 0
73 :3 0 4a :3 0
30 :2 0 bfa 1565
1568 b1 :2 0 30
:2 0 bff 156a 156c
:3 0 156d :2 0 73
:3 0 48 :3 0 30
:2 0 c02 156f 1572
73 :3 0 b1 :2 0
4a :3 0 30 :2 0
c05 1574 1578 c0a
1575 157a :3 0 157b
:2 0 156e 157d 157c
:2 0 157e :2 0 1564
1580 157f :2 0 66
:3 0 67 :3 0 1582
1583 0 66 :3 0
77 :3 0 1585 1586
0 18 :2 0 2
:4 0 16d :2 0 79
:2 0 27 :2 0 c0d
158b 158d :3 0 c10
1587 158f 1584 1591
1590 :2 0 69 :3 0
7a :3 0 1593 1594
0 6b :4 0 16e
:4 0 6e :2 0 6f
:3 0 c14 1598 159a
:3 0 6e :2 0 82
:4 0 c17 159c 159e
:3 0 6e :2 0 83
:4 0 c1a 15a0 15a2
:3 0 6e :2 0 73
:3 0 74 :3 0 84
:3 0 16f :3 0 15a7
15a8 0 c1d 15a6
15aa 75 :4 0 c1f
15a5 15ad c22 15a4
15af :3 0 6e :2 0
e4 :4 0 c25 15b1
15b3 :3 0 6e :2 0
71 :4 0 c28 15b5
15b7 :3 0 6e :2 0
1d :3 0 c2b 15b9
15bb :3 0 6e :2 0
71 :4 0 c2e 15bd
15bf :3 0 c31 1595
15c1 :2 0 15c3 c34
15c4 1592 15c3 0
15c5 c36 0 15ef
66 :3 0 67 :3 0
15c6 15c7 0 66
:3 0 77 :3 0 15c9
15ca 0 27 :2 0
2 :4 0 170 :2 0
79 :2 0 27 :2 0
c38 15cf 15d1 :3 0
c3b 15cb 15d3 15c8
15d5 15d4 :2 0 69
:3 0 7a :3 0 15d7
15d8 0 6b :4 0
171 :4 0 6e :2 0
6f :3 0 c3f 15dc
15de :3 0 c42 15d9
15e0 :2 0 15e2 c45
15e3 15d6 15e2 0
15e4 c47 0 15ef
88 :3 0 e7 :3 0
15e5 15e6 0 84
:3 0 16f :3 0 15e8
15e9 0 1d :3 0
8a :3 0 c49 15e7
15ed :2 0 15ef c4d
15f0 1581 15ef 0
15f1 c51 0 1650
172 :3 0 173 :3 0
174 :3 0 28 :3 0
42 :3 0 1e :3 0
175 :3 0 bc :3 0
1a :3 0 122 :3 0
121 :3 0 1d :4 0
176 1 :8 0 1604
15 :3 0 9b :3 0
15ff 1600 0 9c
:3 0 1601 1602 0
1604 c53 164e 9d
:3 0 15 :3 0 9b
:3 0 1607 1608 0
9c :3 0 1609 160a
0 1644 66 :3 0
67 :3 0 160c 160d
0 66 :3 0 77
:3 0 160f 1610 0
9e :2 0 2 :4 0
177 :2 0 79 :2 0
27 :2 0 c56 1615
1617 :3 0 c59 1611
1619 160e 161b 161a
:2 0 69 :3 0 7a
:3 0 161d 161e 0
6b :4 0 178 :4 0
6e :2 0 6f :3 0
c5d 1622 1624 :3 0
6e :2 0 82 :4 0
c60 1626 1628 :3 0
6e :2 0 a1 :4 0
c63 162a 162c :3 0
6e :2 0 9c :3 0
c66 162e 1630 :3 0
6e :2 0 a2 :4 0
c69 1632 1634 :3 0
6e :2 0 a3 :3 0
a4 :3 0 27 :2 0
a5 :2 0 c6c 1637
163b c70 1636 163d
:3 0 c73 161f 163f
:2 0 1641 c76 1642
161c 1641 0 1643
c78 0 1644 c7a
1647 :3 0 1647 0
1647 1646 1644 1645
:6 0 1649 2e :3 0
c7d 164b c7f 164a
1649 :2 0 164c c81
:2 0 164e 0 164e
164d 1604 164c :6 0
1650 1 :3 0 c83
1879 2c :3 0 a3
:3 0 2c :3 0 6e
:2 0 1d :3 0 c89
1654 1656 :3 0 27
:2 0 2a :2 0 c8c
1652 165a 1651 165b
0 1878 179 :3 0
2d :3 0 17a :3 0
17b :3 0 1d :4 0
17c 1 :8 0 1668
15 :3 0 9b :3 0
1663 1664 0 9c
:3 0 1665 1666 0
1668 c90 16b2 9d
:3 0 15 :3 0 9b
:3 0 166b 166c 0
9c :3 0 166d 166e
0 16a8 66 :3 0
67 :3 0 1670 1671
0 66 :3 0 77
:3 0 1673 1674 0
9e :2 0 2 :4 0
17d :2 0 79 :2 0
27 :2 0 c93 1679
167b :3 0 c96 1675
167d 1672 167f 167e
:2 0 69 :3 0 7a
:3 0 1681 1682 0
6b :4 0 17e :4 0
6e :2 0 6f :3 0
c9a 1686 1688 :3 0
6e :2 0 82 :4 0
c9d 168a 168c :3 0
6e :2 0 a1 :4 0
ca0 168e 1690 :3 0
6e :2 0 9c :3 0
ca3 1692 1694 :3 0
6e :2 0 a2 :4 0
ca6 1696 1698 :3 0
6e :2 0 a3 :3 0
a4 :3 0 27 :2 0
a5 :2 0 ca9 169b
169f cad 169a 16a1
:3 0 cb0 1683 16a3
:2 0 16a5 cb3 16a6
1680 16a5 0 16a7
cb5 0 16a8 cb7
16ab :3 0 16ab 0
16ab 16aa 16a8 16a9
:6 0 16ad 30 :3 0
cba 16af cbc 16ae
16ad :2 0 16b0 cbe
:2 0 16b2 0 16b2
16b1 1668 16b0 :6 0
1878 1 :3 0 15
:3 0 9b :3 0 16b4
16b5 0 15 :3 0
8f :2 0 d8 :3 0
16b7 16b9 0 cc2
16b8 16bb :3 0 16bc
:2 0 66 :3 0 67
:3 0 16be 16bf 0
66 :3 0 77 :3 0
16c1 16c2 0 18
:2 0 2 :4 0 17f
:2 0 79 :2 0 27
:2 0 cc5 16c7 16c9
:3 0 cc8 16c3 16cb
16c0 16cd 16cc :2 0
69 :3 0 7a :3 0
16cf 16d0 0 6b
:4 0 180 :4 0 6e
:2 0 6f :3 0 ccc
16d4 16d6 :3 0 6e
:2 0 82 :4 0 ccf
16d8 16da :3 0 6e
:2 0 83 :4 0 cd2
16dc 16de :3 0 6e
:2 0 73 :3 0 74
:3 0 84 :3 0 e3
:3 0 16e3 16e4 0
cd5 16e2 16e6 75
:4 0 cd7 16e1 16e9
cda 16e0 16eb :3 0
6e :2 0 e4 :4 0
cdd 16ed 16ef :3 0
6e :2 0 71 :4 0
ce0 16f1 16f3 :3 0
6e :2 0 1d :3 0
ce3 16f5 16f7 :3 0
6e :2 0 71 :4 0
ce6 16f9 16fb :3 0
ce9 16d1 16fd :2 0
16ff cec 1700 16ce
16ff 0 1701 cee
0 172b 66 :3 0
67 :3 0 1702 1703
0 66 :3 0 77
:3 0 1705 1706 0
27 :2 0 2 :4 0
181 :2 0 79 :2 0
27 :2 0 cf0 170b
170d :3 0 cf3 1707
170f 1704 1711 1710
:2 0 69 :3 0 7a
:3 0 1713 1714 0
6b :4 0 182 :4 0
6e :2 0 6f :3 0
cf7 1718 171a :3 0
cfa 1715 171c :2 0
171e cfd 171f 1712
171e 0 1720 cff
0 172b 88 :3 0
e7 :3 0 1721 1722
0 84 :3 0 e3
:3 0 1724 1725 0
1d :3 0 8a :3 0
d01 1723 1729 :2 0
172b d05 172c 16bd
172b 0 172d d09
0 1878 11e :3 0
128 :3 0 a3 :3 0
1f :3 0 128 :3 0
a3 :3 0 11e :3 0
128 :3 0 a3 :3 0
183 :3 0 184 :3 0
37 :3 0 21 :3 0
44 :3 0 11f :3 0
120 :3 0 17 :3 0
121 :3 0 1d :3 0
122 :4 0 185 1
:8 0 1748 15 :3 0
9b :3 0 1743 1744
0 9c :3 0 1745
1746 0 1748 d0b
1792 9d :3 0 15
:3 0 9b :3 0 174b
174c 0 9c :3 0
174d 174e 0 1788
66 :3 0 67 :3 0
1750 1751 0 66
:3 0 77 :3 0 1753
1754 0 9e :2 0
2 :4 0 186 :2 0
79 :2 0 27 :2 0
d0e 1759 175b :3 0
d11 1755 175d 1752
175f 175e :2 0 69
:3 0 7a :3 0 1761
1762 0 6b :4 0
187 :4 0 6e :2 0
6f :3 0 d15 1766
1768 :3 0 6e :2 0
82 :4 0 d18 176a
176c :3 0 6e :2 0
a1 :4 0 d1b 176e
1770 :3 0 6e :2 0
9c :3 0 d1e 1772
1774 :3 0 6e :2 0
a2 :4 0 d21 1776
1778 :3 0 6e :2 0
a3 :3 0 a4 :3 0
27 :2 0 a5 :2 0
d24 177b 177f d28
177a 1781 :3 0 d2b
1763 1783 :2 0 1785
d2e 1786 1760 1785
0 1787 d30 0
1788 d32 178b :3 0
178b 0 178b 178a
1788 1789 :6 0 178d
32 :3 0 d35 178f
d37 178e 178d :2 0
1790 d39 :2 0 1792
0 1792 1791 1748
1790 :6 0 1878 1
:3 0 15 :3 0 9b
:3 0 1794 1795 0
15 :3 0 8f :2 0
a6 :3 0 1797 1799
0 d3d 1798 179b
:3 0 179c :2 0 73
:3 0 44 :3 0 30
:2 0 d40 179e 17a1
8f :2 0 27 :2 0
d45 17a3 17a5 :3 0
17a6 :2 0 179d 17a8
17a7 :2 0 66 :3 0
67 :3 0 17aa 17ab
0 66 :3 0 77
:3 0 17ad 17ae 0
18 :2 0 2 :4 0
188 :2 0 79 :2 0
27 :2 0 d48 17b3
17b5 :3 0 d4b 17af
17b7 17ac 17b9 17b8
:2 0 69 :3 0 7a
:3 0 17bb 17bc 0
6b :4 0 189 :4 0
6e :2 0 6f :3 0
d4f 17c0 17c2 :3 0
6e :2 0 82 :4 0
d52 17c4 17c6 :3 0
6e :2 0 83 :4 0
d55 17c8 17ca :3 0
6e :2 0 73 :3 0
74 :3 0 84 :3 0
149 :3 0 17cf 17d0
0 d58 17ce 17d2
75 :4 0 d5a 17cd
17d5 d5d 17cc 17d7
:3 0 6e :2 0 e4
:4 0 d60 17d9 17db
:3 0 6e :2 0 71
:4 0 d63 17dd 17df
:3 0 6e :2 0 1d
:3 0 d66 17e1 17e3
:3 0 6e :2 0 71
:4 0 d69 17e5 17e7
:3 0 d6c 17bd 17e9
:2 0 17eb d6f 17ec
17ba 17eb 0 17ed
d71 0 1817 66
:3 0 67 :3 0 17ee
17ef 0 66 :3 0
77 :3 0 17f1 17f2
0 27 :2 0 2
:4 0 18a :2 0 79
:2 0 27 :2 0 d73
17f7 17f9 :3 0 d76
17f3 17fb 17f0 17fd
17fc :2 0 69 :3 0
7a :3 0 17ff 1800
0 6b :4 0 18b
:4 0 6e :2 0 6f
:3 0 d7a 1804 1806
:3 0 d7d 1801 1808
:2 0 180a d80 180b
17fe 180a 0 180c
d82 0 1817 88
:3 0 e7 :3 0 180d
180e 0 84 :3 0
149 :3 0 1810 1811
0 1d :3 0 8a
:3 0 d84 180f 1815
:2 0 1817 d88 1818
17a9 1817 0 1819
d8c 0 1878 172
:3 0 173 :3 0 174
:3 0 28 :3 0 42
:3 0 1e :3 0 175
:3 0 bc :3 0 1a
:3 0 122 :3 0 121
:3 0 1d :4 0 18c
1 :8 0 182c 15
:3 0 9b :3 0 1827
1828 0 9c :3 0
1829 182a 0 182c
d8e 1876 9d :3 0
15 :3 0 9b :3 0
182f 1830 0 9c
:3 0 1831 1832 0
186c 66 :3 0 67
:3 0 1834 1835 0
66 :3 0 77 :3 0
1837 1838 0 9e
:2 0 2 :4 0 18d
:2 0 79 :2 0 27
:2 0 d91 183d 183f
:3 0 d94 1839 1841
1836 1843 1842 :2 0
69 :3 0 7a :3 0
1845 1846 0 6b
:4 0 18e :4 0 6e
:2 0 6f :3 0 d98
184a 184c :3 0 6e
:2 0 82 :4 0 d9b
184e 1850 :3 0 6e
:2 0 a1 :4 0 d9e
1852 1854 :3 0 6e
:2 0 9c :3 0 da1
1856 1858 :3 0 6e
:2 0 a2 :4 0 da4
185a 185c :3 0 6e
:2 0 a3 :3 0 a4
:3 0 27 :2 0 a5
:2 0 da7 185f 1863
dab 185e 1865 :3 0
dae 1847 1867 :2 0
1869 db1 186a 1844
1869 0 186b db3
0 186c db5 186f
:3 0 186f 0 186f
186e 186c 186d :6 0
1871 34 :3 0 db8
1873 dba 1872 1871
:2 0 1874 dbc :2 0
1876 0 1876 1875
182c 1874 :6 0 1878
1 :3 0 dbe 187a
146c 1650 0 187b
0 1878 0 187b
dc5 0 1b1b 21
:3 0 21 :3 0 187c
187d 0 1b1b 73
:3 0 46 :3 0 30
:2 0 dc8 187f 1882
8f :2 0 27 :2 0
dcd 1884 1886 :3 0
97 :3 0 18f :3 0
128 :3 0 a3 :3 0
21 :3 0 97 :3 0
190 :3 0 1f :3 0
21 :3 0 99 :4 0
191 1 :8 0 1898
15 :3 0 9b :3 0
1893 1894 0 9c
:3 0 1895 1896 0
1898 dd0 18e2 9d
:3 0 15 :3 0 9b
:3 0 189b 189c 0
9c :3 0 189d 189e
0 18d8 66 :3 0
67 :3 0 18a0 18a1
0 66 :3 0 77
:3 0 18a3 18a4 0
9e :2 0 2 :4 0
192 :2 0 79 :2 0
27 :2 0 dd3 18a9
18ab :3 0 dd6 18a5
18ad 18a2 18af 18ae
:2 0 69 :3 0 7a
:3 0 18b1 18b2 0
6b :4 0 193 :4 0
6e :2 0 6f :3 0
dda 18b6 18b8 :3 0
6e :2 0 82 :4 0
ddd 18ba 18bc :3 0
6e :2 0 a1 :4 0
de0 18be 18c0 :3 0
6e :2 0 9c :3 0
de3 18c2 18c4 :3 0
6e :2 0 a2 :4 0
de6 18c6 18c8 :3 0
6e :2 0 a3 :3 0
a4 :3 0 27 :2 0
a5 :2 0 de9 18cb
18cf ded 18ca 18d1
:3 0 df0 18b3 18d3
:2 0 18d5 df3 18d6
18b0 18d5 0 18d7
df5 0 18d8 df7
18db :3 0 18db 0
18db 18da 18d8 18d9
:6 0 18dd 36 :3 0
dfa 18df dfc 18de
18dd :2 0 18e0 dfe
:2 0 18e2 0 18e2
18e1 1898 18e0 :6 0
1a5c 1 :3 0 128
:3 0 a3 :3 0 1f
:3 0 128 :3 0 a3
:3 0 21 :3 0 1f
:3 0 21 :3 0 21
:3 0 99 :4 0 194
1 :8 0 18f4 15
:3 0 9b :3 0 18ef
18f0 0 9c :3 0
18f1 18f2 0 18f4
e00 193e 9d :3 0
15 :3 0 9b :3 0
18f7 18f8 0 9c
:3 0 18f9 18fa 0
1934 66 :3 0 67
:3 0 18fc 18fd 0
66 :3 0 77 :3 0
18ff 1900 0 9e
:2 0 2 :4 0 195
:2 0 79 :2 0 27
:2 0 e03 1905 1907
:3 0 e06 1901 1909
18fe 190b 190a :2 0
69 :3 0 7a :3 0
190d 190e 0 6b
:4 0 196 :4 0 6e
:2 0 6f :3 0 e0a
1912 1914 :3 0 6e
:2 0 82 :4 0 e0d
1916 1918 :3 0 6e
:2 0 a1 :4 0 e10
191a 191c :3 0 6e
:2 0 9c :3 0 e13
191e 1920 :3 0 6e
:2 0 a2 :4 0 e16
1922 1924 :3 0 6e
:2 0 a3 :3 0 a4
:3 0 27 :2 0 a5
:2 0 e19 1927 192b
e1d 1926 192d :3 0
e20 190f 192f :2 0
1931 e23 1932 190c
1931 0 1933 e25
0 1934 e27 1937
:3 0 1937 0 1937
1936 1934 1935 :6 0
1939 38 :3 0 e2a
193b e2c 193a 1939
:2 0 193c e2e :2 0
193e 0 193e 193d
18f4 193c :6 0 1a5c
1 :3 0 45 :3 0
197 :2 0 1940 1941
0 1a5c 22 :3 0
6 :3 0 1943 1944
0 1a5c 73 :3 0
33 :3 0 30 :2 0
e30 1946 1949 8f
:2 0 30 :2 0 e35
194b 194d :3 0 3f
:3 0 10e :2 0 194f
1950 0 1952 e38
1953 194e 1952 0
1954 e3a 0 1a5c
62 :3 0 198 :3 0
28 :3 0 17 :3 0
1a :3 0 1d :3 0
4e :3 0 32 :3 0
23 :3 0 23 :3 0
23 :3 0 23 :3 0
21 :3 0 22 :3 0
41 :3 0 37 :3 0
35 :3 0 38 :3 0
39 :3 0 34 :3 0
45 :3 0 26 :3 0
33 :3 0 31 :3 0
3b :3 0 36 :3 0
3f :3 0 3d :3 0
43 :3 0 1c :3 0
30 :2 0 30 :2 0
50 :2 0 50 :2 0
e3c 1956 1977 1955
1978 0 1a5c 62
:3 0 8f :2 0 30
:2 0 e5f 197b 197d
:3 0 73 :3 0 33
:3 0 30 :2 0 e62
197f 1982 8f :2 0
30 :2 0 e67 1984
1986 :3 0 199 :3 0
19a :3 0 19b :3 0
1d :4 0 19c 1
:8 0 19a2 19d :4 0
198d :3 0 8a :3 0
8f :2 0 e6c 1990
1991 :3 0 15 :3 0
9b :3 0 1993 1994
0 30 :2 0 1995
1996 0 1998 e6f
199f 15 :3 0 9b
:3 0 1999 199a 0
10c :2 0 199b 199c
0 199e e71 19a0
1992 1998 0 19a1
0 199e 0 19a1
e73 0 19a2 e76
19ec 9d :3 0 15
:3 0 9b :3 0 19a5
19a6 0 9c :3 0
19a7 19a8 0 19e2
66 :3 0 67 :3 0
19aa 19ab 0 66
:3 0 77 :3 0 19ad
19ae 0 9e :2 0
2 :4 0 19e :2 0
79 :2 0 27 :2 0
e79 19b3 19b5 :3 0
e7c 19af 19b7 19ac
19b9 19b8 :2 0 69
:3 0 7a :3 0 19bb
19bc 0 6b :4 0
19f :4 0 6e :2 0
6f :3 0 e80 19c0
19c2 :3 0 6e :2 0
82 :4 0 e83 19c4
19c6 :3 0 6e :2 0
a1 :4 0 e86 19c8
19ca :3 0 6e :2 0
9c :3 0 e89 19cc
19ce :3 0 6e :2 0
a2 :4 0 e8c 19d0
19d2 :3 0 6e :2 0
a3 :3 0 a4 :3 0
27 :2 0 a5 :2 0
e8f 19d5 19d9 e93
19d4 19db :3 0 e96
19bd 19dd :2 0 19df
e99 19e0 19ba 19df
0 19e1 e9b 0
19e2 e9d 19e5 :3 0
19e5 0 19e5 19e4
19e2 19e3 :6 0 19e7
3a :3 0 ea0 19e9
ea2 19e8 19e7 :2 0
19ea ea4 :2 0 19ec
0 19ec 19eb 19a2
19ea :6 0 19ee 1
:3 0 ea6 1a56 199
:3 0 19a :3 0 19b
:3 0 1d :4 0 1a0
1 :8 0 1a09 19d
:4 0 19f4 :3 0 8a
:3 0 8f :2 0 eaa
19f7 19f8 :3 0 15
:3 0 9b :3 0 19fa
19fb 0 30 :2 0
19fc 19fd 0 19ff
ead 1a06 15 :3 0
9b :3 0 1a00 1a01
0 10c :2 0 1a02
1a03 0 1a05 eaf
1a07 19f9 19ff 0
1a08 0 1a05 0
1a08 eb1 0 1a09
eb4 1a53 9d :3 0
15 :3 0 9b :3 0
1a0c 1a0d 0 9c
:3 0 1a0e 1a0f 0
1a49 66 :3 0 67
:3 0 1a11 1a12 0
66 :3 0 77 :3 0
1a14 1a15 0 9e
:2 0 2 :4 0 1a1
:2 0 79 :2 0 27
:2 0 eb7 1a1a 1a1c
:3 0 eba 1a16 1a1e
1a13 1a20 1a1f :2 0
69 :3 0 7a :3 0
1a22 1a23 0 6b
:4 0 1a2 :4 0 6e
:2 0 6f :3 0 ebe
1a27 1a29 :3 0 6e
:2 0 82 :4 0 ec1
1a2b 1a2d :3 0 6e
:2 0 a1 :4 0 ec4
1a2f 1a31 :3 0 6e
:2 0 9c :3 0 ec7
1a33 1a35 :3 0 6e
:2 0 a2 :4 0 eca
1a37 1a39 :3 0 6e
:2 0 a3 :3 0 a4
:3 0 27 :2 0 a5
:2 0 ecd 1a3c 1a40
ed1 1a3b 1a42 :3 0
ed4 1a24 1a44 :2 0
1a46 ed7 1a47 1a21
1a46 0 1a48 ed9
0 1a49 edb 1a4c
:3 0 1a4c 0 1a4c
1a4b 1a49 1a4a :6 0
1a4e 3c :3 0 ede
1a50 ee0 1a4f 1a4e
:2 0 1a51 ee2 :2 0
1a53 0 1a53 1a52
1a09 1a51 :6 0 1a55
1 :3 0 ee4 1a57
1987 19ee 0 1a58
0 1a55 0 1a58
ee6 0 1a59 ee9
1a5a 197e 1a59 0
1a5b eeb 0 1a5c
eed 1b18 21 :3 0
1f :3 0 1a5d 1a5e
0 1b17 22 :3 0
6 :3 0 1a60 1a61
0 1b17 a3 :3 0
26 :3 0 27 :2 0
27 :2 0 ef5 1a63
1a67 8f :2 0 27
:4 0 efb 1a69 1a6b
:3 0 45 :3 0 84
:3 0 1a3 :3 0 1a6e
1a6f 0 1a6d 1a70
0 1a72 efe 1a81
45 :3 0 114 :3 0
73 :3 0 3a :3 0
30 :2 0 f00 1a75
1a78 84 :3 0 117
:3 0 1a7a 1a7b 0
f03 1a74 1a7d 1a73
1a7e 0 1a80 f06
1a82 1a6c 1a72 0
1a83 0 1a80 0
1a83 f08 0 1b17
62 :3 0 198 :3 0
28 :3 0 17 :3 0
1a :3 0 1d :3 0
4e :3 0 32 :3 0
23 :3 0 23 :3 0
23 :3 0 23 :3 0
21 :3 0 22 :3 0
41 :3 0 37 :3 0
35 :3 0 38 :3 0
39 :3 0 34 :3 0
45 :3 0 26 :3 0
33 :3 0 31 :3 0
3b :3 0 36 :3 0
3f :3 0 3d :3 0
43 :3 0 1c :3 0
30 :2 0 30 :2 0
50 :2 0 50 :2 0
f0b 1a85 1aa6 1a84
1aa7 0 1b17 62
:3 0 8f :2 0 30
:2 0 f2e 1aaa 1aac
:3 0 199 :3 0 19a
:3 0 19b :3 0 1d
:4 0 19c 1 :8 0
1ac8 19d :4 0 1ab3
:3 0 8a :3 0 8f
:2 0 f33 1ab6 1ab7
:3 0 15 :3 0 9b
:3 0 1ab9 1aba 0
30 :2 0 1abb 1abc
0 1abe f36 1ac5
15 :3 0 9b :3 0
1abf 1ac0 0 10c
:2 0 1ac1 1ac2 0
1ac4 f38 1ac6 1ab8
1abe 0 1ac7 0
1ac4 0 1ac7 f3a
0 1ac8 f3d 1b12
9d :3 0 15 :3 0
9b :3 0 1acb 1acc
0 9c :3 0 1acd
1ace 0 1b08 66
:3 0 67 :3 0 1ad0
1ad1 0 66 :3 0
77 :3 0 1ad3 1ad4
0 9e :2 0 2
:4 0 1a4 :2 0 79
:2 0 27 :2 0 f40
1ad9 1adb :3 0 f43
1ad5 1add 1ad2 1adf
1ade :2 0 69 :3 0
7a :3 0 1ae1 1ae2
0 6b :4 0 1a5
:4 0 6e :2 0 6f
:3 0 f47 1ae6 1ae8
:3 0 6e :2 0 82
:4 0 f4a 1aea 1aec
:3 0 6e :2 0 a1
:4 0 f4d 1aee 1af0
:3 0 6e :2 0 9c
:3 0 f50 1af2 1af4
:3 0 6e :2 0 a2
:4 0 f53 1af6 1af8
:3 0 6e :2 0 a3
:3 0 a4 :3 0 27
:2 0 a5 :2 0 f56
1afb 1aff f5a 1afa
1b01 :3 0 f5d 1ae3
1b03 :2 0 1b05 f60
1b06 1ae0 1b05 0
1b07 f62 0 1b08
f64 1b0b :3 0 1b0b
0 1b0b 1b0a 1b08
1b09 :6 0 1b0d 3e
:3 0 f67 1b0f f69
1b0e 1b0d :2 0 1b10
f6b :2 0 1b12 0
1b12 1b11 1ac8 1b10
:6 0 1b14 1 :3 0
f6d 1b15 1aad 1b14
0 1b16 f6f 0
1b17 f71 1b19 1887
1a5c 0 1b1a 0
1b17 0 1b1a f77
0 1b1b f7a 247d
73 :3 0 1a6 :3 0
29 :3 0 f87 1b1d
1b1f 30 :2 0 f89
1b1c 1b22 a7 :2 0
18 :2 0 f8e 1b24
1b26 :3 0 64 :3 0
30 :2 0 1b28 1b29
0 1b2b f91 1b43
64 :3 0 1a7 :3 0
73 :3 0 1a6 :3 0
29 :3 0 f93 1b2f
1b31 30 :2 0 f95
1b2e 1b34 79 :2 0
27 :2 0 f98 1b36
1b38 :3 0 1b39 :2 0
1a8 :2 0 b4 :2 0
f9b 1b3b 1b3d :3 0
f9e 1b2d 1b3f 1b2c
1b40 0 1b42 fa0
1b44 1b27 1b2b 0
1b45 0 1b42 0
1b45 fa2 0 247c
64 :3 0 b1 :2 0
30 :2 0 fa7 1b47
1b49 :3 0 2f :3 0
30 :2 0 1b4b 1b4c
0 2479 1a9 :3 0
73 :3 0 2f :3 0
30 :2 0 faa 1b4f
1b52 64 :3 0 a7
:2 0 1aa :3 0 faf
1b55 1b57 :3 0 1b58
2478 46 :3 0 30
:2 0 1b5a 1b5b 0
2476 1d :3 0 b2
:3 0 b3 :3 0 1b5e
1b5f 0 18 :2 0
18 :2 0 73 :3 0
2f :3 0 30 :2 0
fb2 1b63 1b66 110
:2 0 b4 :2 0 fb5
1b68 1b6a :3 0 79
:2 0 27 :2 0 fb8
1b6c 1b6e :3 0 29
:3 0 fbb 1b60 1b71
1b5d 1b72 0 2476
26 :3 0 b2 :3 0
b3 :3 0 1b75 1b76
0 27 :2 0 27
:2 0 73 :3 0 2f
:3 0 30 :2 0 fc0
1b7a 1b7d 110 :2 0
b4 :2 0 fc3 1b7f
1b81 :3 0 79 :2 0
18 :2 0 fc6 1b83
1b85 :3 0 79 :2 0
27 :2 0 fc9 1b87
1b89 :3 0 29 :3 0
fcc 1b77 1b8c 1b74
1b8d 0 2476 1f
:3 0 5 :3 0 1b8f
1b90 0 2476 46
:3 0 30 :2 0 1b92
1b93 0 2476 44
:3 0 30 :2 0 1b95
1b96 0 2476 21
:3 0 1f :3 0 1b98
1b99 0 2476 1ab
:3 0 11d :3 0 1ac
:3 0 44 :3 0 21
:3 0 11f :3 0 b7
:3 0 17 :3 0 120
:3 0 17 :3 0 121
:3 0 1d :3 0 122
:3 0 26 :4 0 1ad
1 :8 0 1baf 15
:3 0 9b :3 0 1baa
1bab 0 9c :3 0
1bac 1bad 0 1baf
fd1 1bf9 9d :3 0
15 :3 0 9b :3 0
1bb2 1bb3 0 9c
:3 0 1bb4 1bb5 0
1bef 66 :3 0 67
:3 0 1bb7 1bb8 0
66 :3 0 77 :3 0
1bba 1bbb 0 9e
:2 0 2 :4 0 1ae
:2 0 79 :2 0 27
:2 0 fd4 1bc0 1bc2
:3 0 fd7 1bbc 1bc4
1bb9 1bc6 1bc5 :2 0
69 :3 0 7a :3 0
1bc8 1bc9 0 6b
:4 0 1af :4 0 6e
:2 0 6f :3 0 fdb
1bcd 1bcf :3 0 6e
:2 0 82 :4 0 fde
1bd1 1bd3 :3 0 6e
:2 0 a1 :4 0 fe1
1bd5 1bd7 :3 0 6e
:2 0 9c :3 0 fe4
1bd9 1bdb :3 0 6e
:2 0 a2 :4 0 fe7
1bdd 1bdf :3 0 6e
:2 0 a3 :3 0 a4
:3 0 27 :2 0 a5
:2 0 fea 1be2 1be6
fee 1be1 1be8 :3 0
ff1 1bca 1bea :2 0
1bec ff4 1bed 1bc7
1bec 0 1bee ff6
0 1bef ff8 1bf2
:3 0 1bf2 0 1bf2
1bf1 1bef 1bf0 :6 0
1bf4 41 :3 0 ffb
1bf6 ffd 1bf5 1bf4
:2 0 1bf7 fff :2 0
1bf9 0 1bf9 1bf8
1baf 1bf7 :6 0 2476
40 :3 0 73 :3 0
44 :3 0 30 :2 0
1001 1bfb 1bfe b1
:2 0 30 :2 0 1006
1c00 1c02 :3 0 1c03
:2 0 21 :3 0 96
:2 0 1009 1c06 1c07
:3 0 1c08 :2 0 1c09
:2 0 1c04 1c0b 1c0a
:2 0 46 :3 0 27
:2 0 1c0d 1c0e 0
1c21 97 :3 0 f1
:3 0 1c10 1c11 0
1f :3 0 21 :3 0
100b 1c12 1c15 a7
:2 0 30 :2 0 1010
1c17 1c19 :3 0 1f
:3 0 21 :3 0 1c1b
1c1c 0 1c1e 1013
1c1f 1c1a 1c1e 0
1c20 1015 0 1c21
1017 1c22 1c0c 1c21
0 1c23 101a 0
2476 a3 :3 0 26
:3 0 27 :2 0 27
:2 0 101c 1c24 1c28
8f :2 0 27 :4 0
1022 1c2a 1c2c :3 0
3a :3 0 84 :3 0
1a3 :3 0 1c2f 1c30
0 1c2e 1c31 0
1c5f 73 :3 0 1a6
:3 0 2c :3 0 1025
1c34 1c36 30 :2 0
1027 1c33 1c39 8f
:2 0 30 :2 0 102c
1c3b 1c3d :3 0 2c
:3 0 1d :3 0 1c3f
1c40 0 1c42 102f
1c5c 2c :3 0 a3
:3 0 2c :3 0 6e
:2 0 1b0 :4 0 1031
1c46 1c48 :3 0 27
:2 0 2a :2 0 1034
1c44 1c4c 1c43 1c4d
0 1c5b 2c :3 0
a3 :3 0 2c :3 0
6e :2 0 1d :3 0
1038 1c52 1c54 :3 0
27 :2 0 2a :2 0
103b 1c50 1c58 1c4f
1c59 0 1c5b 103f
1c5d 1c3e 1c42 0
1c5e 0 1c5b 0
1c5e 1042 0 1c5f
1045 1c8d 73 :3 0
1a6 :3 0 2b :3 0
1048 1c61 1c63 30
:2 0 104a 1c60 1c66
8f :2 0 30 :2 0
104f 1c68 1c6a :3 0
2b :3 0 1d :3 0
1c6c 1c6d 0 1c6f
1052 1c89 2b :3 0
a3 :3 0 2b :3 0
6e :2 0 1b0 :4 0
1054 1c73 1c75 :3 0
27 :2 0 2a :2 0
1057 1c71 1c79 1c70
1c7a 0 1c88 2b
:3 0 a3 :3 0 2b
:3 0 6e :2 0 1d
:3 0 105b 1c7f 1c81
:3 0 27 :2 0 2a
:2 0 105e 1c7d 1c85
1c7c 1c86 0 1c88
1062 1c8a 1c6b 1c6f
0 1c8b 0 1c88
0 1c8b 1065 0
1c8c 1068 1c8e 1c2d
1c5f 0 1c8f 0
1c8c 0 1c8f 106a
0 2476 33 :3 0
30 :2 0 1c90 1c91
0 2476 44 :3 0
30 :2 0 1c93 1c94
0 2476 73 :3 0
46 :3 0 30 :2 0
106d 1c96 1c99 8f
:2 0 27 :2 0 1072
1c9b 1c9d :3 0 63
:3 0 8f :2 0 27
:2 0 1077 1ca0 1ca2
:3 0 a3 :3 0 26
:3 0 27 :2 0 27
:2 0 107a 1ca4 1ca8
8f :2 0 30 :4 0
1080 1caa 1cac :3 0
126 :3 0 127 :3 0
128 :3 0 a3 :3 0
1f :3 0 128 :3 0
a3 :3 0 127 :3 0
128 :3 0 a3 :3 0
22 :3 0 128 :3 0
a3 :3 0 129 :3 0
12a :3 0 37 :3 0
12a :3 0 19 :3 0
21 :3 0 44 :3 0
47 :3 0 11f :3 0
120 :3 0 17 :3 0
121 :3 0 1d :3 0
122 :3 0 12b :4 0
1b1 1 :8 0 1cd0
15 :3 0 9b :3 0
1ccb 1ccc 0 9c
:3 0 1ccd 1cce 0
1cd0 1083 1d1a 9d
:3 0 15 :3 0 9b
:3 0 1cd3 1cd4 0
9c :3 0 1cd5 1cd6
0 1d10 66 :3 0
67 :3 0 1cd8 1cd9
0 66 :3 0 77
:3 0 1cdb 1cdc 0
9e :2 0 2 :4 0
1b2 :2 0 79 :2 0
27 :2 0 1086 1ce1
1ce3 :3 0 1089 1cdd
1ce5 1cda 1ce7 1ce6
:2 0 69 :3 0 7a
:3 0 1ce9 1cea 0
6b :4 0 1b3 :4 0
6e :2 0 6f :3 0
108d 1cee 1cf0 :3 0
6e :2 0 82 :4 0
1090 1cf2 1cf4 :3 0
6e :2 0 a1 :4 0
1093 1cf6 1cf8 :3 0
6e :2 0 9c :3 0
1096 1cfa 1cfc :3 0
6e :2 0 a2 :4 0
1099 1cfe 1d00 :3 0
6e :2 0 a3 :3 0
a4 :3 0 27 :2 0
a5 :2 0 109c 1d03
1d07 10a0 1d02 1d09
:3 0 10a3 1ceb 1d0b
:2 0 1d0d 10a6 1d0e
1ce8 1d0d 0 1d0f
10a8 0 1d10 10aa
1d13 :3 0 1d13 0
1d13 1d12 1d10 1d11
:6 0 1d15 43 :3 0
10ad 1d17 10af 1d16
1d15 :2 0 1d18 10b1
:2 0 1d1a 0 1d1a
1d19 1cd0 1d18 :6 0
1e3b 40 :3 0 15
:3 0 9b :3 0 1d1c
1d1d 0 15 :3 0
8f :2 0 a6 :3 0
1d1f 1d21 0 10b5
1d20 1d23 :3 0 1d24
:2 0 46 :3 0 27
:2 0 1d26 1d27 0
1db4 73 :3 0 47
:3 0 30 :2 0 10b8
1d29 1d2c 8f :2 0
30 :2 0 10bd 1d2e
1d30 :3 0 1d31 :2 0
73 :3 0 44 :3 0
30 :2 0 10c0 1d33
1d36 8f :2 0 27
:2 0 10c5 1d38 1d3a
:3 0 1d3b :2 0 1d32
1d3d 1d3c :2 0 126
:3 0 12f :3 0 128
:3 0 a3 :3 0 1f
:3 0 128 :3 0 a3
:3 0 12f :3 0 128
:3 0 a3 :3 0 22
:3 0 128 :3 0 a3
:3 0 130 :3 0 131
:3 0 37 :3 0 19
:3 0 21 :3 0 44
:3 0 11f :3 0 120
:3 0 17 :3 0 121
:3 0 1d :3 0 122
:3 0 12b :4 0 1b4
1 :8 0 1d5f 15
:3 0 9b :3 0 1d5a
1d5b 0 9c :3 0
1d5c 1d5d 0 1d5f
10c8 1da9 9d :3 0
15 :3 0 9b :3 0
1d62 1d63 0 9c
:3 0 1d64 1d65 0
1d9f 66 :3 0 67
:3 0 1d67 1d68 0
66 :3 0 77 :3 0
1d6a 1d6b 0 9e
:2 0 2 :4 0 1b5
:2 0 79 :2 0 27
:2 0 10cb 1d70 1d72
:3 0 10ce 1d6c 1d74
1d69 1d76 1d75 :2 0
69 :3 0 7a :3 0
1d78 1d79 0 6b
:4 0 1b6 :4 0 6e
:2 0 6f :3 0 10d2
1d7d 1d7f :3 0 6e
:2 0 82 :4 0 10d5
1d81 1d83 :3 0 6e
:2 0 a1 :4 0 10d8
1d85 1d87 :3 0 6e
:2 0 9c :3 0 10db
1d89 1d8b :3 0 6e
:2 0 a2 :4 0 10de
1d8d 1d8f :3 0 6e
:2 0 a3 :3 0 a4
:3 0 27 :2 0 a5
:2 0 10e1 1d92 1d96
10e5 1d91 1d98 :3 0
10e8 1d7a 1d9a :2 0
1d9c 10eb 1d9d 1d77
1d9c 0 1d9e 10ed
0 1d9f 10ef 1da2
:3 0 1da2 0 1da2
1da1 1d9f 1da0 :6 0
1da4 45 :3 0 10f2
1da6 10f4 1da5 1da4
:2 0 1da7 10f6 :2 0
1da9 0 1da9 1da8
1d5f 1da7 :6 0 1dab
40 :3 0 10f8 1db0
33 :3 0 10d :2 0
1dac 1dad 0 1daf
10fa 1db1 1d3e 1dab
0 1db2 0 1daf
0 1db2 10fc 0
1db4 ad :3 0 10ff
1e39 15 :3 0 9b
:3 0 1db5 1db6 0
15 :3 0 8f :2 0
d8 :3 0 1db8 1dba
0 1104 1db9 1dbc
:3 0 1dbd :2 0 73
:3 0 44 :3 0 30
:2 0 1107 1dbf 1dc2
8f :2 0 27 :2 0
110c 1dc4 1dc6 :3 0
1dc7 :2 0 1dbe 1dc9
1dc8 :2 0 126 :3 0
12f :3 0 128 :3 0
a3 :3 0 1f :3 0
128 :3 0 a3 :3 0
12f :3 0 128 :3 0
a3 :3 0 22 :3 0
128 :3 0 a3 :3 0
130 :3 0 131 :3 0
37 :3 0 19 :3 0
21 :3 0 44 :3 0
11f :3 0 120 :3 0
17 :3 0 121 :3 0
1d :3 0 122 :3 0
12b :4 0 1b7 1
:8 0 1deb 15 :3 0
9b :3 0 1de6 1de7
0 9c :3 0 1de8
1de9 0 1deb 110f
1e35 9d :3 0 15
:3 0 9b :3 0 1dee
1def 0 9c :3 0
1df0 1df1 0 1e2b
66 :3 0 67 :3 0
1df3 1df4 0 66
:3 0 77 :3 0 1df6
1df7 0 9e :2 0
2 :4 0 1b8 :2 0
79 :2 0 27 :2 0
1112 1dfc 1dfe :3 0
1115 1df8 1e00 1df5
1e02 1e01 :2 0 69
:3 0 7a :3 0 1e04
1e05 0 6b :4 0
1b9 :4 0 6e :2 0
6f :3 0 1119 1e09
1e0b :3 0 6e :2 0
82 :4 0 111c 1e0d
1e0f :3 0 6e :2 0
a1 :4 0 111f 1e11
1e13 :3 0 6e :2 0
9c :3 0 1122 1e15
1e17 :3 0 6e :2 0
a2 :4 0 1125 1e19
1e1b :3 0 6e :2 0
a3 :3 0 a4 :3 0
27 :2 0 a5 :2 0
1128 1e1e 1e22 112c
1e1d 1e24 :3 0 112f
1e06 1e26 :2 0 1e28
1132 1e29 1e03 1e28
0 1e2a 1134 0
1e2b 1136 1e2e :3 0
1e2e 0 1e2e 1e2d
1e2b 1e2c :6 0 1e30
47 :3 0 1139 1e32
113b 1e31 1e30 :2 0
1e33 113d :2 0 1e35
0 1e35 1e34 1deb
1e33 :6 0 1e37 40
:3 0 113f 1e38 1dca
1e37 0 1e3a 1d25
1db4 0 1e3a 1141
0 1e3b 1144 1eab
126 :3 0 12f :3 0
128 :3 0 a3 :3 0
1f :3 0 128 :3 0
a3 :3 0 12f :3 0
128 :3 0 a3 :3 0
22 :3 0 128 :3 0
a3 :3 0 130 :3 0
131 :3 0 37 :3 0
19 :3 0 21 :3 0
44 :3 0 11f :3 0
b7 :3 0 17 :3 0
120 :3 0 17 :3 0
121 :3 0 1d :3 0
122 :3 0 12b :4 0
1ba 1 :8 0 1e5e
15 :3 0 9b :3 0
1e59 1e5a 0 9c
:3 0 1e5b 1e5c 0
1e5e 1147 1ea8 9d
:3 0 15 :3 0 9b
:3 0 1e61 1e62 0
9c :3 0 1e63 1e64
0 1e9e 66 :3 0
67 :3 0 1e66 1e67
0 66 :3 0 77
:3 0 1e69 1e6a 0
9e :2 0 2 :4 0
1bb :2 0 79 :2 0
27 :2 0 114a 1e6f
1e71 :3 0 114d 1e6b
1e73 1e68 1e75 1e74
:2 0 69 :3 0 7a
:3 0 1e77 1e78 0
6b :4 0 1bc :4 0
6e :2 0 6f :3 0
1151 1e7c 1e7e :3 0
6e :2 0 82 :4 0
1154 1e80 1e82 :3 0
6e :2 0 a1 :4 0
1157 1e84 1e86 :3 0
6e :2 0 9c :3 0
115a 1e88 1e8a :3 0
6e :2 0 a2 :4 0
115d 1e8c 1e8e :3 0
6e :2 0 a3 :3 0
a4 :3 0 27 :2 0
a5 :2 0 1160 1e91
1e95 1164 1e90 1e97
:3 0 1167 1e79 1e99
:2 0 1e9b 116a 1e9c
1e76 1e9b 0 1e9d
116c 0 1e9e 116e
1ea1 :3 0 1ea1 0
1ea1 1ea0 1e9e 1e9f
:6 0 1ea3 49 :3 0
1171 1ea5 1173 1ea4
1ea3 :2 0 1ea6 1175
:2 0 1ea8 0 1ea8
1ea7 1e5e 1ea6 :6 0
1eaa 40 :3 0 1177
1eac 1cad 1e3b 0
1ead 0 1eaa 0
1ead 1179 0 1eae
117c 20a3 a3 :3 0
26 :3 0 27 :2 0
27 :2 0 117e 1eaf
1eb3 8f :2 0 30
:4 0 1184 1eb5 1eb7
:3 0 126 :3 0 127
:3 0 128 :3 0 a3
:3 0 1f :3 0 128
:3 0 a3 :3 0 127
:3 0 128 :3 0 a3
:3 0 129 :3 0 37
:3 0 12a :3 0 12a
:3 0 19 :3 0 21
:3 0 44 :3 0 47
:3 0 11f :3 0 b7
:3 0 17 :3 0 120
:3 0 17 :3 0 121
:3 0 1d :3 0 122
:3 0 12b :4 0 1bd
1 :8 0 1eda 15
:3 0 9b :3 0 1ed5
1ed6 0 9c :3 0
1ed7 1ed8 0 1eda
1187 1f24 9d :3 0
15 :3 0 9b :3 0
1edd 1ede 0 9c
:3 0 1edf 1ee0 0
1f1a 66 :3 0 67
:3 0 1ee2 1ee3 0
66 :3 0 77 :3 0
1ee5 1ee6 0 9e
:2 0 2 :4 0 1be
:2 0 79 :2 0 27
:2 0 118a 1eeb 1eed
:3 0 118d 1ee7 1eef
1ee4 1ef1 1ef0 :2 0
69 :3 0 7a :3 0
1ef3 1ef4 0 6b
:4 0 1bf :4 0 6e
:2 0 6f :3 0 1191
1ef8 1efa :3 0 6e
:2 0 82 :4 0 1194
1efc 1efe :3 0 6e
:2 0 a1 :4 0 1197
1f00 1f02 :3 0 6e
:2 0 9c :3 0 119a
1f04 1f06 :3 0 6e
:2 0 a2 :4 0 119d
1f08 1f0a :3 0 6e
:2 0 a3 :3 0 a4
:3 0 27 :2 0 a5
:2 0 11a0 1f0d 1f11
11a4 1f0c 1f13 :3 0
11a7 1ef5 1f15 :2 0
1f17 11aa 1f18 1ef2
1f17 0 1f19 11ac
0 1f1a 11ae 1f1d
:3 0 1f1d 0 1f1d
1f1c 1f1a 1f1b :6 0
1f1f 4b :3 0 11b1
1f21 11b3 1f20 1f1f
:2 0 1f22 11b5 :2 0
1f24 0 1f24 1f23
1eda 1f22 :6 0 2032
40 :3 0 15 :3 0
9b :3 0 1f26 1f27
0 15 :3 0 8f
:2 0 a6 :3 0 1f29
1f2b 0 11b9 1f2a
1f2d :3 0 1f2e :2 0
73 :3 0 47 :3 0
30 :2 0 11bc 1f30
1f33 8f :2 0 30
:2 0 11c1 1f35 1f37
:3 0 1f38 :2 0 73
:3 0 44 :3 0 30
:2 0 11c4 1f3a 1f3d
8f :2 0 27 :2 0
11c9 1f3f 1f41 :3 0
1f42 :2 0 1f39 1f44
1f43 :2 0 126 :3 0
12f :3 0 128 :3 0
a3 :3 0 1f :3 0
128 :3 0 a3 :3 0
130 :3 0 37 :3 0
131 :3 0 19 :3 0
21 :3 0 44 :3 0
11f :3 0 b7 :3 0
17 :3 0 120 :3 0
17 :3 0 121 :3 0
1d :3 0 122 :3 0
12b :4 0 1c0 1
:8 0 1f62 15 :3 0
9b :3 0 1f5d 1f5e
0 9c :3 0 1f5f
1f60 0 1f62 11cc
1fac 9d :3 0 15
:3 0 9b :3 0 1f65
1f66 0 9c :3 0
1f67 1f68 0 1fa2
66 :3 0 67 :3 0
1f6a 1f6b 0 66
:3 0 77 :3 0 1f6d
1f6e 0 9e :2 0
2 :4 0 1c1 :2 0
79 :2 0 27 :2 0
11cf 1f73 1f75 :3 0
11d2 1f6f 1f77 1f6c
1f79 1f78 :2 0 69
:3 0 7a :3 0 1f7b
1f7c 0 6b :4 0
1c2 :4 0 6e :2 0
6f :3 0 11d6 1f80
1f82 :3 0 6e :2 0
82 :4 0 11d9 1f84
1f86 :3 0 6e :2 0
a1 :4 0 11dc 1f88
1f8a :3 0 6e :2 0
9c :3 0 11df 1f8c
1f8e :3 0 6e :2 0
a2 :4 0 11e2 1f90
1f92 :3 0 6e :2 0
a3 :3 0 a4 :3 0
27 :2 0 a5 :2 0
11e5 1f95 1f99 11e9
1f94 1f9b :3 0 11ec
1f7d 1f9d :2 0 1f9f
11ef 1fa0 1f7a 1f9f
0 1fa1 11f1 0
1fa2 11f3 1fa5 :3 0
1fa5 0 1fa5 1fa4
1fa2 1fa3 :6 0 1fa7
4d :3 0 11f6 1fa9
11f8 1fa8 1fa7 :2 0
1faa 11fa :2 0 1fac
0 1fac 1fab 1f62
1faa :6 0 1fae 40
:3 0 11fc 1fb4 33
:3 0 10d :2 0 1faf
1fb0 0 1fb3 0
1fb3 11fe 1fb5 1f45
1fae 0 1fb6 0
1fb3 0 1fb6 1201
0 1fb8 ad :3 0
1204 2030 15 :3 0
9b :3 0 1fb9 1fba
0 15 :3 0 8f
:2 0 d8 :3 0 1fbc
1fbe 0 1208 1fbd
1fc0 :3 0 1fc1 :2 0
126 :3 0 12f :3 0
128 :3 0 a3 :3 0
1f :3 0 128 :3 0
a3 :3 0 12f :3 0
128 :3 0 a3 :3 0
130 :3 0 37 :3 0
131 :3 0 19 :3 0
21 :3 0 44 :3 0
11f :3 0 b7 :3 0
17 :3 0 120 :3 0
17 :3 0 121 :3 0
1d :3 0 122 :3 0
12b :4 0 1c3 1
:8 0 1fe2 15 :3 0
9b :3 0 1fdd 1fde
0 9c :3 0 1fdf
1fe0 0 1fe2 120b
202c 9d :3 0 15
:3 0 9b :3 0 1fe5
1fe6 0 9c :3 0
1fe7 1fe8 0 2022
66 :3 0 67 :3 0
1fea 1feb 0 66
:3 0 77 :3 0 1fed
1fee 0 9e :2 0
2 :4 0 1c4 :2 0
79 :2 0 27 :2 0
120e 1ff3 1ff5 :3 0
1211 1fef 1ff7 1fec
1ff9 1ff8 :2 0 69
:3 0 7a :3 0 1ffb
1ffc 0 6b :4 0
1c5 :4 0 6e :2 0
6f :3 0 1215 2000
2002 :3 0 6e :2 0
82 :4 0 1218 2004
2006 :3 0 6e :2 0
a1 :4 0 121b 2008
200a :3 0 6e :2 0
9c :3 0 121e 200c
200e :3 0 6e :2 0
a2 :4 0 1221 2010
2012 :3 0 6e :2 0
a3 :3 0 a4 :3 0
27 :2 0 a5 :2 0
1224 2015 2019 1228
2014 201b :3 0 122b
1ffd 201d :2 0 201f
122e 2020 1ffa 201f
0 2021 1230 0
2022 1232 2025 :3 0
2025 0 2025 2024
2022 2023 :6 0 2027
4f :3 0 1235 2029
1237 2028 2027 :2 0
202a 1239 :2 0 202c
0 202c 202b 1fe2
202a :6 0 202e 40
:3 0 123b 202f 1fc2
202e 0 2031 1f2f
1fb8 0 2031 123d
0 2032 1240 209f
126 :3 0 12f :3 0
128 :3 0 a3 :3 0
1f :3 0 128 :3 0
a3 :3 0 12f :3 0
128 :3 0 a3 :3 0
130 :3 0 37 :3 0
131 :3 0 19 :3 0
21 :3 0 44 :3 0
11f :3 0 b7 :3 0
17 :3 0 120 :3 0
17 :3 0 121 :3 0
1d :3 0 122 :3 0
12b :4 0 1c6 1
:8 0 2052 15 :3 0
9b :3 0 204d 204e
0 9c :3 0 204f
2050 0 2052 1243
209c 9d :3 0 15
:3 0 9b :3 0 2055
2056 0 9c :3 0
2057 2058 0 2092
66 :3 0 67 :3 0
205a 205b 0 66
:3 0 77 :3 0 205d
205e 0 9e :2 0
2 :4 0 1c7 :2 0
79 :2 0 27 :2 0
1246 2063 2065 :3 0
1249 205f 2067 205c
2069 2068 :2 0 69
:3 0 7a :3 0 206b
206c 0 6b :4 0
1c8 :4 0 6e :2 0
6f :3 0 124d 2070
2072 :3 0 6e :2 0
82 :4 0 1250 2074
2076 :3 0 6e :2 0
a1 :4 0 1253 2078
207a :3 0 6e :2 0
9c :3 0 1256 207c
207e :3 0 6e :2 0
a2 :4 0 1259 2080
2082 :3 0 6e :2 0
a3 :3 0 a4 :3 0
27 :2 0 a5 :2 0
125c 2085 2089 1260
2084 208b :3 0 1263
206d 208d :2 0 208f
1266 2090 206a 208f
0 2091 1268 0
2092 126a 2095 :3 0
2095 0 2095 2094
2092 2093 :6 0 2097
51 :3 0 126d 2099
126f 2098 2097 :2 0
209a 1271 :2 0 209c
0 209c 209b 2052
209a :6 0 209e 40
:3 0 1273 20a0 1eb8
2032 0 20a1 0
209e 0 20a1 1275
0 20a2 1278 20a4
1ca3 1eae 0 20a5
0 20a2 0 20a5
127a 0 23a5 15
:3 0 9b :3 0 20a6
20a7 0 15 :3 0
8f :2 0 a6 :3 0
20a9 20ab 0 127f
20aa 20ad :3 0 20ae
:2 0 73 :3 0 44
:3 0 30 :2 0 1282
20b0 20b3 8f :2 0
27 :2 0 1287 20b5
20b7 :3 0 46 :3 0
10d :2 0 20b9 20ba
0 20bc 128a 21b5
19 :3 0 96 :2 0
128c 20be 20bf :3 0
20c0 :2 0 63 :3 0
8f :2 0 27 :2 0
1290 20c3 20c5 :3 0
47 :3 0 30 :2 0
20c7 20c8 0 212b
14c :3 0 14d :3 0
47 :3 0 14e :3 0
b7 :3 0 17 :3 0
14f :3 0 19 :3 0
150 :3 0 128 :3 0
a3 :3 0 1f :3 0
128 :3 0 a3 :3 0
22 :4 0 1c9 1
:8 0 20df 15 :3 0
9b :3 0 20da 20db
0 9c :3 0 20dc
20dd 0 20df 1293
2129 9d :3 0 15
:3 0 9b :3 0 20e2
20e3 0 9c :3 0
20e4 20e5 0 211f
66 :3 0 67 :3 0
20e7 20e8 0 66
:3 0 77 :3 0 20ea
20eb 0 9e :2 0
2 :4 0 1ca :2 0
79 :2 0 27 :2 0
1296 20f0 20f2 :3 0
1299 20ec 20f4 20e9
20f6 20f5 :2 0 69
:3 0 7a :3 0 20f8
20f9 0 6b :4 0
1cb :4 0 6e :2 0
6f :3 0 129d 20fd
20ff :3 0 6e :2 0
82 :4 0 12a0 2101
2103 :3 0 6e :2 0
a1 :4 0 12a3 2105
2107 :3 0 6e :2 0
9c :3 0 12a6 2109
210b :3 0 6e :2 0
a2 :4 0 12a9 210d
210f :3 0 6e :2 0
a3 :3 0 a4 :3 0
27 :2 0 a5 :2 0
12ac 2112 2116 12b0
2111 2118 :3 0 12b3
20fa 211a :2 0 211c
12b6 211d 20f7 211c
0 211e 12b8 0
211f 12ba 2122 :3 0
2122 0 2122 2121
211f 2120 :6 0 2124
53 :3 0 12bd 2126
12bf 2125 2124 :2 0
2127 12c1 :2 0 2129
0 2129 2128 20df
2127 :6 0 212b 40
:3 0 12c3 218e 47
:3 0 30 :2 0 212c
212d 0 218d 14c
:3 0 14d :3 0 47
:3 0 14e :3 0 b7
:3 0 17 :3 0 14f
:3 0 19 :3 0 150
:3 0 128 :3 0 a3
:3 0 1f :4 0 1cc
1 :8 0 2141 15
:3 0 9b :3 0 213c
213d 0 9c :3 0
213e 213f 0 2141
12c6 218b 9d :3 0
15 :3 0 9b :3 0
2144 2145 0 9c
:3 0 2146 2147 0
2181 66 :3 0 67
:3 0 2149 214a 0
66 :3 0 77 :3 0
214c 214d 0 9e
:2 0 2 :4 0 1cd
:2 0 79 :2 0 27
:2 0 12c9 2152 2154
:3 0 12cc 214e 2156
214b 2158 2157 :2 0
69 :3 0 7a :3 0
215a 215b 0 6b
:4 0 1ce :4 0 6e
:2 0 6f :3 0 12d0
215f 2161 :3 0 6e
:2 0 82 :4 0 12d3
2163 2165 :3 0 6e
:2 0 a1 :4 0 12d6
2167 2169 :3 0 6e
:2 0 9c :3 0 12d9
216b 216d :3 0 6e
:2 0 a2 :4 0 12dc
216f 2171 :3 0 6e
:2 0 a3 :3 0 a4
:3 0 27 :2 0 a5
:2 0 12df 2174 2178
12e3 2173 217a :3 0
12e6 215c 217c :2 0
217e 12e9 217f 2159
217e 0 2180 12eb
0 2181 12ed 2184
:3 0 2184 0 2184
2183 2181 2182 :6 0
2186 55 :3 0 12f0
2188 12f2 2187 2186
:2 0 2189 12f4 :2 0
218b 0 218b 218a
2141 2189 :6 0 218d
40 :3 0 12f6 218f
20c6 212b 0 2190
0 218d 0 2190
12f9 0 21ae 73
:3 0 47 :3 0 30
:2 0 12fc 2191 2194
73 :3 0 a7 :2 0
37 :3 0 30 :2 0
12ff 2196 219a 1304
2197 219c :3 0 2f
:3 0 73 :3 0 2f
:3 0 30 :2 0 1307
219f 21a2 79 :2 0
27 :2 0 130a 21a4
21a6 :3 0 219e 21a7
0 21ab 1cf :3 0
21a9 :4 0 21ab 130d
21ac 219d 21ab 0
21ad 1310 0 21ae
1312 21af 20c1 21ae
0 21b0 1315 0
21b4 46 :3 0 27
:2 0 21b1 21b2 0
21b4 1317 21b6 20b8
20bc 0 21b7 0
21b4 0 21b7 131a
0 21b8 131d 21c7
2f :3 0 73 :3 0
2f :3 0 30 :2 0
131f 21ba 21bd 79
:2 0 27 :2 0 1322
21bf 21c1 :3 0 21b9
21c2 0 21c6 1cf
:3 0 21c4 :4 0 21c6
1325 21c8 20af 21b8
0 21c9 0 21c6
0 21c9 1328 0
23a5 21 :3 0 21
:3 0 21ca 21cb 0
23a5 3f :3 0 30
:2 0 21cd 21ce 0
23a5 97 :3 0 18f
:3 0 128 :3 0 a3
:3 0 21 :3 0 97
:3 0 190 :3 0 1f
:3 0 21 :3 0 99
:4 0 1d0 1 :8 0
21e0 15 :3 0 9b
:3 0 21db 21dc 0
9c :3 0 21dd 21de
0 21e0 132b 222a
9d :3 0 15 :3 0
9b :3 0 21e3 21e4
0 9c :3 0 21e5
21e6 0 2220 66
:3 0 67 :3 0 21e8
21e9 0 66 :3 0
77 :3 0 21eb 21ec
0 9e :2 0 2
:4 0 1d1 :2 0 79
:2 0 27 :2 0 132e
21f1 21f3 :3 0 1331
21ed 21f5 21ea 21f7
21f6 :2 0 69 :3 0
7a :3 0 21f9 21fa
0 6b :4 0 1d2
:4 0 6e :2 0 6f
:3 0 1335 21fe 2200
:3 0 6e :2 0 82
:4 0 1338 2202 2204
:3 0 6e :2 0 a1
:4 0 133b 2206 2208
:3 0 6e :2 0 9c
:3 0 133e 220a 220c
:3 0 6e :2 0 a2
:4 0 1341 220e 2210
:3 0 6e :2 0 a3
:3 0 a4 :3 0 27
:2 0 a5 :2 0 1344
2213 2217 1348 2212
2219 :3 0 134b 21fb
221b :2 0 221d 134e
221e 21f8 221d 0
221f 1350 0 2220
1352 2223 :3 0 2223
0 2223 2222 2220
2221 :6 0 2225 57
:3 0 1355 2227 1357
2226 2225 :2 0 2228
1359 :2 0 222a 0
222a 2229 21e0 2228
:6 0 23a5 40 :3 0
128 :3 0 a3 :3 0
1f :3 0 128 :3 0
a3 :3 0 21 :3 0
1f :3 0 21 :3 0
21 :3 0 99 :4 0
1d3 1 :8 0 223c
15 :3 0 9b :3 0
2237 2238 0 9c
:3 0 2239 223a 0
223c 135b 2286 9d
:3 0 15 :3 0 9b
:3 0 223f 2240 0
9c :3 0 2241 2242
0 227c 66 :3 0
67 :3 0 2244 2245
0 66 :3 0 77
:3 0 2247 2248 0
9e :2 0 2 :4 0
1d4 :2 0 79 :2 0
27 :2 0 135e 224d
224f :3 0 1361 2249
2251 2246 2253 2252
:2 0 69 :3 0 7a
:3 0 2255 2256 0
6b :4 0 1d5 :4 0
6e :2 0 6f :3 0
1365 225a 225c :3 0
6e :2 0 82 :4 0
1368 225e 2260 :3 0
6e :2 0 a1 :4 0
136b 2262 2264 :3 0
6e :2 0 9c :3 0
136e 2266 2268 :3 0
6e :2 0 a2 :4 0
1371 226a 226c :3 0
6e :2 0 a3 :3 0
a4 :3 0 27 :2 0
a5 :2 0 1374 226f
2273 1378 226e 2275
:3 0 137b 2257 2277
:2 0 2279 137e 227a
2254 2279 0 227b
1380 0 227c 1382
227f :3 0 227f 0
227f 227e 227c 227d
:6 0 2281 59 :3 0
1385 2283 1387 2282
2281 :2 0 2284 1389
:2 0 2286 0 2286
2285 223c 2284 :6 0
23a5 40 :3 0 45
:3 0 197 :2 0 2288
2289 0 23a5 22
:3 0 6 :3 0 228b
228c 0 23a5 73
:3 0 33 :3 0 30
:2 0 138b 228e 2291
8f :2 0 30 :2 0
1390 2293 2295 :3 0
3f :3 0 10e :2 0
2297 2298 0 229a
1393 229b 2296 229a
0 229c 1395 0
23a5 62 :3 0 198
:3 0 28 :3 0 17
:3 0 1a :3 0 1d
:3 0 4e :3 0 32
:3 0 23 :3 0 23
:3 0 23 :3 0 23
:3 0 21 :3 0 22
:3 0 41 :3 0 37
:3 0 35 :3 0 38
:3 0 39 :3 0 34
:3 0 45 :3 0 26
:3 0 33 :3 0 31
:3 0 3b :3 0 36
:3 0 3f :3 0 3d
:3 0 43 :3 0 1c
:3 0 30 :2 0 30
:2 0 50 :2 0 50
:2 0 1397 229e 22bf
229d 22c0 0 23a5
62 :3 0 8f :2 0
30 :2 0 13ba 22c3
22c5 :3 0 73 :3 0
33 :3 0 30 :2 0
13bd 22c7 22ca 8f
:2 0 30 :2 0 13c2
22cc 22ce :3 0 199
:3 0 19a :3 0 19b
:3 0 1d :4 0 19c
1 :8 0 22ea 19d
:4 0 22d5 :3 0 8a
:3 0 8f :2 0 13c7
22d8 22d9 :3 0 15
:3 0 9b :3 0 22db
22dc 0 30 :2 0
22dd 22de 0 22e0
13ca 22e7 15 :3 0
9b :3 0 22e1 22e2
0 10c :2 0 22e3
22e4 0 22e6 13cc
22e8 22da 22e0 0
22e9 0 22e6 0
22e9 13ce 0 22ea
13d1 2334 9d :3 0
15 :3 0 9b :3 0
22ed 22ee 0 9c
:3 0 22ef 22f0 0
232a 66 :3 0 67
:3 0 22f2 22f3 0
66 :3 0 77 :3 0
22f5 22f6 0 9e
:2 0 2 :4 0 1d6
:2 0 79 :2 0 27
:2 0 13d4 22fb 22fd
:3 0 13d7 22f7 22ff
22f4 2301 2300 :2 0
69 :3 0 7a :3 0
2303 2304 0 6b
:4 0 1d7 :4 0 6e
:2 0 6f :3 0 13db
2308 230a :3 0 6e
:2 0 82 :4 0 13de
230c 230e :3 0 6e
:2 0 a1 :4 0 13e1
2310 2312 :3 0 6e
:2 0 9c :3 0 13e4
2314 2316 :3 0 6e
:2 0 a2 :4 0 13e7
2318 231a :3 0 6e
:2 0 a3 :3 0 a4
:3 0 27 :2 0 a5
:2 0 13ea 231d 2321
13ee 231c 2323 :3 0
13f1 2305 2325 :2 0
2327 13f4 2328 2302
2327 0 2329 13f6
0 232a 13f8 232d
:3 0 232d 0 232d
232c 232a 232b :6 0
232f 5b :3 0 13fb
2331 13fd 2330 232f
:2 0 2332 13ff :2 0
2334 0 2334 2333
22ea 2332 :6 0 2336
40 :3 0 1401 239e
199 :3 0 19a :3 0
19b :3 0 1d :4 0
1a0 1 :8 0 2351
19d :4 0 233c :3 0
8a :3 0 8f :2 0
1405 233f 2340 :3 0
15 :3 0 9b :3 0
2342 2343 0 30
:2 0 2344 2345 0
2347 1408 234e 15
:3 0 9b :3 0 2348
2349 0 10c :2 0
234a 234b 0 234d
140a 234f 2341 2347
0 2350 0 234d
0 2350 140c 0
2351 140f 239b 9d
:3 0 15 :3 0 9b
:3 0 2354 2355 0
9c :3 0 2356 2357
0 2391 66 :3 0
67 :3 0 2359 235a
0 66 :3 0 77
:3 0 235c 235d 0
9e :2 0 2 :4 0
1d8 :2 0 79 :2 0
27 :2 0 1412 2362
2364 :3 0 1415 235e
2366 235b 2368 2367
:2 0 69 :3 0 7a
:3 0 236a 236b 0
6b :4 0 1d9 :4 0
6e :2 0 6f :3 0
1419 236f 2371 :3 0
6e :2 0 82 :4 0
141c 2373 2375 :3 0
6e :2 0 a1 :4 0
141f 2377 2379 :3 0
6e :2 0 9c :3 0
1422 237b 237d :3 0
6e :2 0 a2 :4 0
1425 237f 2381 :3 0
6e :2 0 a3 :3 0
a4 :3 0 27 :2 0
a5 :2 0 1428 2384
2388 142c 2383 238a
:3 0 142f 236c 238c
:2 0 238e 1432 238f
2369 238e 0 2390
1434 0 2391 1436
2394 :3 0 2394 0
2394 2393 2391 2392
:6 0 2396 5d :3 0
1439 2398 143b 2397
2396 :2 0 2399 143d
:2 0 239b 0 239b
239a 2351 2399 :6 0
239d 40 :3 0 143f
239f 22cf 2336 0
23a0 0 239d 0
23a0 1441 0 23a1
1444 23a2 22c6 23a1
0 23a3 1446 0
23a5 ad :3 0 1448
2465 73 :3 0 46
:3 0 30 :2 0 1454
23a6 23a9 8f :2 0
30 :2 0 1459 23ab
23ad :3 0 21 :3 0
1f :3 0 23af 23b0
0 2463 22 :3 0
6 :3 0 23b2 23b3
0 2463 a3 :3 0
26 :3 0 27 :2 0
27 :2 0 145c 23b5
23b9 8f :2 0 27
:4 0 1462 23bb 23bd
:3 0 45 :3 0 84
:3 0 1a3 :3 0 23c0
23c1 0 23bf 23c2
0 23c4 1465 23cd
45 :3 0 73 :3 0
3a :3 0 30 :2 0
1467 23c6 23c9 23c5
23ca 0 23cc 146a
23ce 23be 23c4 0
23cf 0 23cc 0
23cf 146c 0 2463
62 :3 0 198 :3 0
28 :3 0 17 :3 0
1a :3 0 1d :3 0
4e :3 0 32 :3 0
23 :3 0 23 :3 0
23 :3 0 23 :3 0
21 :3 0 22 :3 0
41 :3 0 37 :3 0
35 :3 0 38 :3 0
39 :3 0 34 :3 0
45 :3 0 26 :3 0
33 :3 0 31 :3 0
3b :3 0 36 :3 0
3f :3 0 3d :3 0
43 :3 0 1c :3 0
30 :2 0 30 :2 0
50 :2 0 50 :2 0
146f 23d1 23f2 23d0
23f3 0 2463 62
:3 0 8f :2 0 30
:2 0 1492 23f6 23f8
:3 0 199 :3 0 19a
:3 0 19b :3 0 1d
:4 0 19c 1 :8 0
2414 19d :4 0 23ff
:3 0 8a :3 0 8f
:2 0 1497 2402 2403
:3 0 15 :3 0 9b
:3 0 2405 2406 0
30 :2 0 2407 2408
0 240a 149a 2411
15 :3 0 9b :3 0
240b 240c 0 10c
:2 0 240d 240e 0
2410 149c 2412 2404
240a 0 2413 0
2410 0 2413 149e
0 2414 14a1 245e
9d :3 0 15 :3 0
9b :3 0 2417 2418
0 9c :3 0 2419
241a 0 2454 66
:3 0 67 :3 0 241c
241d 0 66 :3 0
77 :3 0 241f 2420
0 9e :2 0 2
:4 0 1da :2 0 79
:2 0 27 :2 0 14a4
2425 2427 :3 0 14a7
2421 2429 241e 242b
242a :2 0 69 :3 0
7a :3 0 242d 242e
0 6b :4 0 1db
:4 0 6e :2 0 6f
:3 0 14ab 2432 2434
:3 0 6e :2 0 82
:4 0 14ae 2436 2438
:3 0 6e :2 0 a1
:4 0 14b1 243a 243c
:3 0 6e :2 0 9c
:3 0 14b4 243e 2440
:3 0 6e :2 0 a2
:4 0 14b7 2442 2444
:3 0 6e :2 0 a3
:3 0 a4 :3 0 27
:2 0 a5 :2 0 14ba
2447 244b 14be 2446
244d :3 0 14c1 242f
244f :2 0 2451 14c4
2452 242c 2451 0
2453 14c6 0 2454
14c8 2457 :3 0 2457
0 2457 2456 2454
2455 :6 0 2459 5f
:3 0 14cb 245b 14cd
245a 2459 :2 0 245c
14cf :2 0 245e 0
245e 245d 2414 245c
:6 0 2460 40 :3 0
14d1 2461 23f9 2460
0 2462 14d3 0
2463 14d5 2464 23ae
2463 0 2466 1c9e
23a5 0 2466 14db
0 2476 2f :3 0
73 :3 0 2f :3 0
30 :2 0 14de 2468
246b 79 :2 0 27
:2 0 14e1 246d 246f
:3 0 2467 2470 0
2476 1cf :5 0 2474
61 0 2475 14e4
2474 2473 2476 14e6
2478 1aa :3 0 1b59
2476 :4 0 2479 14f6
247a 1b4a 2479 0
247b 14f9 0 247c
14fb 247e ce2 1b1b
0 247f 0 247c
0 247f 14fe 0
2f3f 62 :3 0 b6
:2 0 30 :2 0 1503
2481 2483 :3 0 2484
:2 0 73 :3 0 32
:3 0 30 :2 0 1506
2486 2489 b1 :2 0
30 :2 0 150b 248b
248d :3 0 248e :2 0
2485 2490 248f :2 0
73 :3 0 42 :3 0
30 :2 0 150e 2492
2495 8f :2 0 30
:2 0 1513 2497 2499
:3 0 175 :3 0 172
:3 0 28 :4 0 1dc
1 :8 0 24b4 19d
:4 0 249f :3 0 8a
:3 0 8f :2 0 1518
24a2 24a3 :3 0 15
:3 0 9b :3 0 24a5
24a6 0 30 :2 0
24a7 24a8 0 24aa
151b 24b1 15 :3 0
9b :3 0 24ab 24ac
0 10c :2 0 24ad
24ae 0 24b0 151d
24b2 24a4 24aa 0
24b3 0 24b0 0
24b3 151f 0 24b4
1522 24fe 9d :3 0
15 :3 0 9b :3 0
24b7 24b8 0 9c
:3 0 24b9 24ba 0
24f4 66 :3 0 67
:3 0 24bc 24bd 0
66 :3 0 77 :3 0
24bf 24c0 0 9e
:2 0 2 :4 0 1dd
:2 0 79 :2 0 27
:2 0 1525 24c5 24c7
:3 0 1528 24c1 24c9
24be 24cb 24ca :2 0
69 :3 0 7a :3 0
24cd 24ce 0 6b
:4 0 1de :4 0 6e
:2 0 6f :3 0 152c
24d2 24d4 :3 0 6e
:2 0 82 :4 0 152f
24d6 24d8 :3 0 6e
:2 0 a1 :4 0 1532
24da 24dc :3 0 6e
:2 0 9c :3 0 1535
24de 24e0 :3 0 6e
:2 0 a2 :4 0 1538
24e2 24e4 :3 0 6e
:2 0 a3 :3 0 a4
:3 0 27 :2 0 a5
:2 0 153b 24e7 24eb
153f 24e6 24ed :3 0
1542 24cf 24ef :2 0
24f1 1545 24f2 24cc
24f1 0 24f3 1547
0 24f4 1549 24f7
:3 0 24f7 0 24f7
24f6 24f4 24f5 :6 0
24f9 61 :3 0 154c
24fb 154e 24fa 24f9
:2 0 24fc 1550 :2 0
24fe 0 24fe 24fd
24b4 24fc :6 0 2500
1 :3 0 1552 256b
175 :3 0 174 :3 0
1e :3 0 173 :3 0
42 :3 0 172 :3 0
28 :4 0 1df 1
:8 0 251e 19d :4 0
2509 :3 0 8a :3 0
8f :2 0 1556 250c
250d :3 0 15 :3 0
9b :3 0 250f 2510
0 30 :2 0 2511
2512 0 2514 1559
251b 15 :3 0 9b
:3 0 2515 2516 0
10c :2 0 2517 2518
0 251a 155b 251c
250e 2514 0 251d
0 251a 0 251d
155d 0 251e 1560
2568 9d :3 0 15
:3 0 9b :3 0 2521
2522 0 9c :3 0
2523 2524 0 255e
66 :3 0 67 :3 0
2526 2527 0 66
:3 0 77 :3 0 2529
252a 0 9e :2 0
2 :4 0 1e0 :2 0
79 :2 0 27 :2 0
1563 252f 2531 :3 0
1566 252b 2533 2528
2535 2534 :2 0 69
:3 0 7a :3 0 2537
2538 0 6b :4 0
1e1 :4 0 6e :2 0
6f :3 0 156a 253c
253e :3 0 6e :2 0
82 :4 0 156d 2540
2542 :3 0 6e :2 0
a1 :4 0 1570 2544
2546 :3 0 6e :2 0
9c :3 0 1573 2548
254a :3 0 6e :2 0
a2 :4 0 1576 254c
254e :3 0 6e :2 0
a3 :3 0 a4 :3 0
27 :2 0 a5 :2 0
1579 2551 2555 157d
2550 2557 :3 0 1580
2539 2559 :2 0 255b
1583 255c 2536 255b
0 255d 1585 0
255e 1587 2561 :3 0
2561 0 2561 2560
255e 255f :6 0 2563
63 :3 0 158a 2565
158c 2564 2563 :2 0
2566 158e :2 0 2568
0 2568 2567 251e
2566 :6 0 256a 1
:3 0 1590 256c 249a
2500 0 256d 0
256a 0 256d 1592
0 2740 62 :3 0
8f :2 0 10c :2 0
1597 256f 2571 :3 0
66 :3 0 67 :3 0
2573 2574 0 66
:3 0 77 :3 0 2576
2577 0 18 :2 0
2 :4 0 1e2 :2 0
79 :2 0 27 :2 0
159a 257c 257e :3 0
159d 2578 2580 2575
2582 2581 :2 0 69
:3 0 7a :3 0 2584
2585 0 6b :4 0
1e3 :4 0 6e :2 0
6f :3 0 15a1 2589
258b :3 0 6e :2 0
82 :4 0 15a4 258d
258f :3 0 6e :2 0
83 :4 0 15a7 2591
2593 :3 0 6e :2 0
73 :3 0 74 :3 0
84 :3 0 16f :3 0
2598 2599 0 15aa
2597 259b 75 :4 0
15ac 2596 259e 15af
2595 25a0 :3 0 6e
:2 0 e4 :4 0 15b2
25a2 25a4 :3 0 6e
:2 0 71 :4 0 15b5
25a6 25a8 :3 0 6e
:2 0 1d :3 0 15b8
25aa 25ac :3 0 6e
:2 0 71 :4 0 15bb
25ae 25b0 :3 0 15be
2586 25b2 :2 0 25b4
15c1 25b5 2583 25b4
0 25b6 15c3 0
25e1 66 :3 0 67
:3 0 25b7 25b8 0
66 :3 0 77 :3 0
25ba 25bb 0 27
:2 0 2 :4 0 1e4
:2 0 79 :2 0 27
:2 0 15c5 25c0 25c2
:3 0 15c8 25bc 25c4
25b9 25c6 25c5 :2 0
69 :3 0 7a :3 0
25c8 25c9 0 6b
:4 0 1e5 :4 0 6e
:2 0 6f :3 0 15cc
25cd 25cf :3 0 15cf
25ca 25d1 :2 0 25d3
15d2 25d4 25c7 25d3
0 25d5 15d4 0
25e1 88 :3 0 e7
:3 0 25d6 25d7 0
84 :3 0 16f :3 0
25d9 25da 0 1d
:3 0 8a :3 0 15d6
25d8 25de :2 0 25e1
ad :3 0 15da 273d
62 :3 0 84 :3 0
8f :2 0 1e6 :3 0
25e3 25e5 0 15e0
25e4 25e7 :3 0 66
:3 0 67 :3 0 25e9
25ea 0 66 :3 0
77 :3 0 25ec 25ed
0 18 :2 0 2
:4 0 1e7 :2 0 79
:2 0 27 :2 0 15e3
25f2 25f4 :3 0 15e6
25ee 25f6 25eb 25f8
25f7 :2 0 69 :3 0
7a :3 0 25fa 25fb
0 6b :4 0 1e8
:4 0 6e :2 0 6f
:3 0 15ea 25ff 2601
:3 0 6e :2 0 82
:4 0 15ed 2603 2605
:3 0 6e :2 0 83
:4 0 15f0 2607 2609
:3 0 6e :2 0 73
:3 0 74 :3 0 84
:3 0 1e6 :3 0 260e
260f 0 15f3 260d
2611 75 :4 0 15f5
260c 2614 15f8 260b
2616 :3 0 6e :2 0
e4 :4 0 15fb 2618
261a :3 0 6e :2 0
71 :4 0 15fe 261c
261e :3 0 6e :2 0
1d :3 0 1601 2620
2622 :3 0 6e :2 0
71 :4 0 1604 2624
2626 :3 0 1607 25fc
2628 :2 0 262a 160a
262b 25f9 262a 0
262c 160c 0 2657
66 :3 0 67 :3 0
262d 262e 0 66
:3 0 77 :3 0 2630
2631 0 27 :2 0
2 :4 0 1e9 :2 0
79 :2 0 27 :2 0
160e 2636 2638 :3 0
1611 2632 263a 262f
263c 263b :2 0 69
:3 0 7a :3 0 263e
263f 0 6b :4 0
1ea :4 0 6e :2 0
6f :3 0 1615 2643
2645 :3 0 1618 2640
2647 :2 0 2649 161b
264a 263d 2649 0
264b 161d 0 2657
88 :3 0 e7 :3 0
264c 264d 0 84
:3 0 1e6 :3 0 264f
2650 0 1d :3 0
8a :3 0 161f 264e
2654 :2 0 2657 ad
:3 0 1623 2658 25e8
2657 0 273f 62
:3 0 84 :3 0 8f
:2 0 1eb :3 0 265a
265c 0 1629 265b
265e :3 0 66 :3 0
67 :3 0 2660 2661
0 66 :3 0 77
:3 0 2663 2664 0
18 :2 0 2 :4 0
1ec :2 0 79 :2 0
27 :2 0 162c 2669
266b :3 0 162f 2665
266d 2662 266f 266e
:2 0 69 :3 0 7a
:3 0 2671 2672 0
6b :4 0 1ed :4 0
6e :2 0 6f :3 0
1633 2676 2678 :3 0
6e :2 0 82 :4 0
1636 267a 267c :3 0
6e :2 0 83 :4 0
1639 267e 2680 :3 0
6e :2 0 73 :3 0
74 :3 0 84 :3 0
1eb :3 0 2685 2686
0 163c 2684 2688
75 :4 0 163e 2683
268b 1641 2682 268d
:3 0 6e :2 0 e4
:4 0 1644 268f 2691
:3 0 6e :2 0 71
:4 0 1647 2693 2695
:3 0 6e :2 0 1d
:3 0 164a 2697 2699
:3 0 6e :2 0 71
:4 0 164d 269b 269d
:3 0 1650 2673 269f
:2 0 26a1 1653 26a2
2670 26a1 0 26a3
1655 0 26cd 66
:3 0 67 :3 0 26a4
26a5 0 66 :3 0
77 :3 0 26a7 26a8
0 27 :2 0 2
:4 0 1ee :2 0 79
:2 0 27 :2 0 1657
26ad 26af :3 0 165a
26a9 26b1 26a6 26b3
26b2 :2 0 69 :3 0
7a :3 0 26b5 26b6
0 6b :4 0 1ef
:4 0 6e :2 0 6f
:3 0 165e 26ba 26bc
:3 0 1661 26b7 26be
:2 0 26c0 1664 26c1
26b4 26c0 0 26c2
1666 0 26cd 88
:3 0 e7 :3 0 26c3
26c4 0 84 :3 0
1eb :3 0 26c6 26c7
0 1d :3 0 8a
:3 0 1668 26c5 26cb
:2 0 26cd 166c 26ce
265f 26cd 0 273f
66 :3 0 67 :3 0
26cf 26d0 0 66
:3 0 77 :3 0 26d2
26d3 0 18 :2 0
2 :4 0 1f0 :2 0
79 :2 0 27 :2 0
1670 26d8 26da :3 0
1673 26d4 26dc 26d1
26de 26dd :2 0 69
:3 0 7a :3 0 26e0
26e1 0 6b :4 0
1f1 :4 0 6e :2 0
6f :3 0 1677 26e5
26e7 :3 0 6e :2 0
82 :4 0 167a 26e9
26eb :3 0 6e :2 0
83 :4 0 167d 26ed
26ef :3 0 6e :2 0
73 :3 0 74 :3 0
84 :3 0 149 :3 0
26f4 26f5 0 1680
26f3 26f7 75 :4 0
1682 26f2 26fa 1685
26f1 26fc :3 0 6e
:2 0 e4 :4 0 1688
26fe 2700 :3 0 6e
:2 0 71 :4 0 168b
2702 2704 :3 0 6e
:2 0 28 :3 0 168e
2706 2708 :3 0 6e
:2 0 71 :4 0 1691
270a 270c :3 0 1694
26e2 270e :2 0 2710
1697 2711 26df 2710
0 2712 1699 0
273c 66 :3 0 67
:3 0 2713 2714 0
66 :3 0 77 :3 0
2716 2717 0 27
:2 0 2 :4 0 1f2
:2 0 79 :2 0 27
:2 0 169b 271c 271e
:3 0 169e 2718 2720
2715 2722 2721 :2 0
69 :3 0 7a :3 0
2724 2725 0 6b
:4 0 1f3 :4 0 6e
:2 0 6f :3 0 16a2
2729 272b :3 0 16a5
2726 272d :2 0 272f
16a8 2730 2723 272f
0 2731 16aa 0
273c 88 :3 0 e7
:3 0 2732 2733 0
84 :3 0 149 :3 0
2735 2736 0 28
:3 0 8a :3 0 16ac
2734 273a :2 0 273c
16b0 273e 2572 25e1
0 273f 0 273c
0 273f 16b4 0
2740 16b9 2741 2491
2740 0 2742 16bc
0 2f3f 73 :3 0
1a6 :3 0 2b :3 0
16be 2744 2746 30
:2 0 16c0 2743 2749
b1 :2 0 30 :2 0
16c5 274b 274d :3 0
274e :2 0 73 :3 0
1a6 :3 0 2c :3 0
16c8 2751 2753 30
:2 0 16ca 2750 2756
b1 :2 0 30 :2 0
16cf 2758 275a :3 0
275b :2 0 274f 275d
275c :2 0 1f4 :3 0
1f5 :3 0 1f6 :4 0
2761 :4 0 2762 :2 0
2a52 15 :3 0 9b
:3 0 2764 2765 0
30 :2 0 2766 2767
0 2a52 51 :3 0
1f7 :4 0 6e :2 0
1f8 :4 0 16d2 276b
276d :3 0 6e :2 0
1f9 :4 0 16d5 276f
2771 :3 0 6e :2 0
1fa :4 0 16d8 2773
2775 :3 0 6e :2 0
1fb :4 0 16db 2777
2779 :3 0 6e :2 0
1fc :4 0 16de 277b
277d :3 0 6e :2 0
17 :3 0 16e1 277f
2781 :3 0 6e :2 0
1fd :4 0 16e4 2783
2785 :3 0 6e :2 0
1fe :4 0 16e7 2787
2789 :3 0 6e :2 0
2b :3 0 16ea 278b
278d :3 0 6e :2 0
1ff :4 0 16ed 278f
2791 :3 0 6e :2 0
2c :3 0 16f0 2793
2795 :3 0 6e :2 0
200 :4 0 16f3 2797
2799 :3 0 2769 279a
0 2a52 1f4 :3 0
1f5 :3 0 51 :3 0
279e :4 0 279f :2 0
27b6 19d :4 0 27a1
:3 0 8a :3 0 8f
:2 0 16f8 27a4 27a5
:3 0 15 :3 0 9b
:3 0 27a7 27a8 0
30 :2 0 27a9 27aa
0 27ac 16fb 27b3
15 :3 0 9b :3 0
27ad 27ae 0 10c
:2 0 27af 27b0 0
27b2 16fd 27b4 27a6
27ac 0 27b5 0
27b2 0 27b5 16ff
0 27b6 1702 280b
9d :3 0 15 :3 0
9b :3 0 27b9 27ba
0 9c :3 0 27bb
27bc 0 2801 66
:3 0 67 :3 0 27be
27bf 0 66 :3 0
77 :3 0 27c1 27c2
0 9e :2 0 2
:4 0 201 :2 0 79
:2 0 27 :2 0 1705
27c7 27c9 :3 0 1708
27c3 27cb 27c0 27cd
27cc :2 0 69 :3 0
7a :3 0 27cf 27d0
0 6b :4 0 202
:4 0 6e :2 0 6f
:3 0 170c 27d4 27d6
:3 0 6e :2 0 82
:4 0 170f 27d8 27da
:3 0 6e :2 0 a1
:4 0 1712 27dc 27de
:3 0 6e :2 0 9c
:3 0 1715 27e0 27e2
:3 0 6e :2 0 a2
:4 0 1718 27e4 27e6
:3 0 6e :2 0 a3
:3 0 a4 :3 0 27
:2 0 a5 :2 0 171b
27e9 27ed 171f 27e8
27ef :3 0 1722 27d1
27f1 :2 0 27fe 69
:3 0 7a :3 0 27f3
27f4 0 6b :4 0
203 :4 0 6e :2 0
51 :3 0 1725 27f8
27fa :3 0 1728 27f5
27fc :2 0 27fe 172b
27ff 27ce 27fe 0
2800 172e 0 2801
1730 2804 :3 0 2804
0 2804 2803 2801
2802 :6 0 2806 65
:3 0 1733 2808 1735
2807 2806 :2 0 2809
1737 :2 0 280b 0
280b 280a 27b6 2809
:6 0 2a52 1 :3 0
1f4 :3 0 1f5 :3 0
204 :4 0 280f :4 0
2810 :2 0 2a52 15
:3 0 9b :3 0 2812
2813 0 30 :2 0
2814 2815 0 2a52
51 :3 0 205 :4 0
6e :2 0 206 :4 0
1739 2819 281b :3 0
6e :2 0 207 :4 0
173c 281d 281f :3 0
6e :2 0 208 :4 0
173f 2821 2823 :3 0
6e :2 0 209 :4 0
1742 2825 2827 :3 0
6e :2 0 20a :4 0
1745 2829 282b :3 0
6e :2 0 17 :3 0
1748 282d 282f :3 0
6e :2 0 1fd :4 0
174b 2831 2833 :3 0
6e :2 0 20b :4 0
174e 2835 2837 :3 0
6e :2 0 2b :3 0
1751 2839 283b :3 0
6e :2 0 1ff :4 0
1754 283d 283f :3 0
6e :2 0 2c :3 0
1757 2841 2843 :3 0
6e :2 0 20c :4 0
175a 2845 2847 :3 0
2817 2848 0 2a52
1f4 :3 0 1f5 :3 0
51 :3 0 284c :4 0
284d :2 0 2864 19d
:4 0 284f :3 0 8a
:3 0 8f :2 0 175f
2852 2853 :3 0 15
:3 0 9b :3 0 2855
2856 0 30 :2 0
2857 2858 0 285a
1762 2861 15 :3 0
9b :3 0 285b 285c
0 10c :2 0 285d
285e 0 2860 1764
2862 2854 285a 0
2863 0 2860 0
2863 1766 0 2864
1769 28b9 9d :3 0
15 :3 0 9b :3 0
2867 2868 0 9c
:3 0 2869 286a 0
28af 66 :3 0 67
:3 0 286c 286d 0
66 :3 0 77 :3 0
286f 2870 0 9e
:2 0 2 :4 0 20d
:2 0 79 :2 0 27
:2 0 176c 2875 2877
:3 0 176f 2871 2879
286e 287b 287a :2 0
69 :3 0 7a :3 0
287d 287e 0 6b
:4 0 20e :4 0 6e
:2 0 6f :3 0 1773
2882 2884 :3 0 6e
:2 0 82 :4 0 1776
2886 2888 :3 0 6e
:2 0 a1 :4 0 1779
288a 288c :3 0 6e
:2 0 9c :3 0 177c
288e 2890 :3 0 6e
:2 0 a2 :4 0 177f
2892 2894 :3 0 6e
:2 0 a3 :3 0 a4
:3 0 27 :2 0 a5
:2 0 1782 2897 289b
1786 2896 289d :3 0
1789 287f 289f :2 0
28ac 69 :3 0 7a
:3 0 28a1 28a2 0
6b :4 0 203 :4 0
6e :2 0 51 :3 0
178c 28a6 28a8 :3 0
178f 28a3 28aa :2 0
28ac 1792 28ad 287c
28ac 0 28ae 1795
0 28af 1797 28b2
:3 0 28b2 0 28b2
28b1 28af 28b0 :6 0
28b4 67 :3 0 179a
28b6 179c 28b5 28b4
:2 0 28b7 179e :2 0
28b9 0 28b9 28b8
2864 28b7 :6 0 2a52
1 :3 0 15 :3 0
9b :3 0 28bb 28bc
0 20f :4 0 28be
28bf :3 0 28bd 28c0
0 2a52 51 :3 0
210 :4 0 6e :2 0
211 :4 0 17a0 28c4
28c6 :3 0 6e :2 0
212 :4 0 17a3 28c8
28ca :3 0 6e :2 0
213 :4 0 17a6 28cc
28ce :3 0 6e :2 0
214 :4 0 17a9 28d0
28d2 :3 0 6e :2 0
215 :4 0 17ac 28d4
28d6 :3 0 6e :2 0
216 :4 0 17af 28d8
28da :3 0 6e :2 0
217 :4 0 17b2 28dc
28de :3 0 6e :2 0
218 :4 0 17b5 28e0
28e2 :3 0 6e :2 0
219 :4 0 17b8 28e4
28e6 :3 0 6e :2 0
21a :4 0 17bb 28e8
28ea :3 0 6e :2 0
21b :4 0 17be 28ec
28ee :3 0 6e :2 0
21c :4 0 17c1 28f0
28f2 :3 0 6e :2 0
17 :3 0 17c4 28f4
28f6 :3 0 6e :2 0
21d :4 0 17c7 28f8
28fa :3 0 6e :2 0
21e :4 0 17ca 28fc
28fe :3 0 6e :2 0
17 :3 0 17cd 2900
2902 :3 0 6e :2 0
21f :4 0 17d0 2904
2906 :3 0 6e :2 0
220 :4 0 17d3 2908
290a :3 0 6e :2 0
221 :4 0 17d6 290c
290e :3 0 6e :2 0
2b :3 0 17d9 2910
2912 :3 0 6e :2 0
222 :4 0 17dc 2914
2916 :3 0 6e :2 0
223 :4 0 17df 2918
291a :3 0 6e :2 0
224 :4 0 17e2 291c
291e :3 0 6e :2 0
225 :4 0 17e5 2920
2922 :3 0 6e :2 0
226 :4 0 17e8 2924
2926 :3 0 6e :2 0
219 :4 0 17eb 2928
292a :3 0 6e :2 0
21a :4 0 17ee 292c
292e :3 0 6e :2 0
227 :4 0 17f1 2930
2932 :3 0 6e :2 0
228 :4 0 17f4 2934
2936 :3 0 6e :2 0
17 :3 0 17f7 2938
293a :3 0 6e :2 0
229 :4 0 17fa 293c
293e :3 0 6e :2 0
22a :4 0 17fd 2940
2942 :3 0 6e :2 0
22b :4 0 1800 2944
2946 :3 0 6e :2 0
22c :4 0 1803 2948
294a :3 0 6e :2 0
22d :4 0 1806 294c
294e :3 0 6e :2 0
2c :3 0 1809 2950
2952 :3 0 6e :2 0
222 :4 0 180c 2954
2956 :3 0 6e :2 0
22e :4 0 180f 2958
295a :3 0 28c2 295b
0 2a52 1f4 :3 0
1f5 :3 0 51 :3 0
295f :4 0 2960 :2 0
2977 19d :4 0 2962
:3 0 8a :3 0 8f
:2 0 1814 2965 2966
:3 0 15 :3 0 9b
:3 0 2968 2969 0
30 :2 0 296a 296b
0 296d 1817 2974
15 :3 0 9b :3 0
296e 296f 0 10c
:2 0 2970 2971 0
2973 1819 2975 2967
296d 0 2976 0
2973 0 2976 181b
0 2977 181e 29cc
9d :3 0 15 :3 0
9b :3 0 297a 297b
0 9c :3 0 297c
297d 0 29c2 66
:3 0 67 :3 0 297f
2980 0 66 :3 0
77 :3 0 2982 2983
0 9e :2 0 2
:4 0 22f :2 0 79
:2 0 27 :2 0 1821
2988 298a :3 0 1824
2984 298c 2981 298e
298d :2 0 69 :3 0
7a :3 0 2990 2991
0 6b :4 0 230
:4 0 6e :2 0 6f
:3 0 1828 2995 2997
:3 0 6e :2 0 82
:4 0 182b 2999 299b
:3 0 6e :2 0 a1
:4 0 182e 299d 299f
:3 0 6e :2 0 9c
:3 0 1831 29a1 29a3
:3 0 6e :2 0 a2
:4 0 1834 29a5 29a7
:3 0 6e :2 0 a3
:3 0 a4 :3 0 27
:2 0 a5 :2 0 1837
29aa 29ae 183b 29a9
29b0 :3 0 183e 2992
29b2 :2 0 29bf 69
:3 0 7a :3 0 29b4
29b5 0 6b :4 0
203 :4 0 6e :2 0
51 :3 0 1841 29b9
29bb :3 0 1844 29b6
29bd :2 0 29bf 1847
29c0 298f 29bf 0
29c1 184a 0 29c2
184c 29c5 :3 0 29c5
0 29c5 29c4 29c2
29c3 :6 0 29c7 69
:3 0 184f 29c9 1851
29c8 29c7 :2 0 29ca
1853 :2 0 29cc 0
29cc 29cb 2977 29ca
:6 0 2a52 1 :3 0
51 :3 0 231 :4 0
6e :2 0 232 :4 0
1855 29d0 29d2 :3 0
6e :2 0 233 :4 0
1858 29d4 29d6 :3 0
6e :2 0 234 :4 0
185b 29d8 29da :3 0
6e :2 0 74 :3 0
73 :3 0 38 :3 0
30 :2 0 185e 29de
29e1 1861 29dd 29e3
1863 29dc 29e5 :3 0
6e :2 0 235 :4 0
1866 29e7 29e9 :3 0
6e :2 0 82 :4 0
1869 29eb 29ed :3 0
6e :2 0 74 :3 0
73 :3 0 3d :3 0
30 :2 0 186c 29f1
29f4 186f 29f0 29f6
1871 29ef 29f8 :3 0
6e :2 0 236 :4 0
1874 29fa 29fc :3 0
6e :2 0 237 :4 0
1877 29fe 2a00 :3 0
6e :2 0 238 :4 0
187a 2a02 2a04 :3 0
6e :2 0 239 :4 0
187d 2a06 2a08 :3 0
6e :2 0 23a :4 0
1880 2a0a 2a0c :3 0
6e :2 0 23b :4 0
1883 2a0e 2a10 :3 0
6e :2 0 23c :4 0
1886 2a12 2a14 :3 0
6e :2 0 23d :4 0
1889 2a16 2a18 :3 0
6e :2 0 23e :4 0
188c 2a1a 2a1c :3 0
6e :2 0 74 :3 0
73 :3 0 38 :3 0
30 :2 0 188f 2a20
2a23 1892 2a1f 2a25
1894 2a1e 2a27 :3 0
6e :2 0 23f :4 0
1897 2a29 2a2b :3 0
6e :2 0 240 :4 0
189a 2a2d 2a2f :3 0
6e :2 0 74 :3 0
73 :3 0 3d :3 0
30 :2 0 189d 2a33
2a36 18a0 2a32 2a38
18a2 2a31 2a3a :3 0
6e :2 0 241 :4 0
18a5 2a3c 2a3e :3 0
6e :2 0 242 :4 0
18a8 2a40 2a42 :3 0
6e :2 0 243 :4 0
18ab 2a44 2a46 :3 0
6e :2 0 244 :4 0
18ae 2a48 2a4a :3 0
6e :2 0 245 :4 0
18b1 2a4c 2a4e :3 0
29ce 2a4f 0 2a52
ad :3 0 18b4 2ef6
73 :3 0 1a6 :3 0
2c :3 0 18c1 2a54
2a56 30 :2 0 18c3
2a53 2a59 8f :2 0
30 :2 0 18c8 2a5b
2a5d :3 0 1f4 :3 0
1f5 :3 0 246 :4 0
2a61 :4 0 2a62 :2 0
2ca7 15 :3 0 9b
:3 0 2a64 2a65 0
30 :2 0 2a66 2a67
0 2ca7 51 :3 0
247 :4 0 6e :2 0
248 :4 0 18cb 2a6b
2a6d :3 0 6e :2 0
249 :4 0 18ce 2a6f
2a71 :3 0 6e :2 0
24a :4 0 18d1 2a73
2a75 :3 0 6e :2 0
24b :4 0 18d4 2a77
2a79 :3 0 6e :2 0
1fc :4 0 18d7 2a7b
2a7d :3 0 6e :2 0
17 :3 0 18da 2a7f
2a81 :3 0 6e :2 0
1fd :4 0 18dd 2a83
2a85 :3 0 6e :2 0
24c :4 0 18e0 2a87
2a89 :3 0 6e :2 0
2b :3 0 18e3 2a8b
2a8d :3 0 6e :2 0
24d :4 0 18e6 2a8f
2a91 :3 0 2a69 2a92
0 2ca7 1f4 :3 0
1f5 :3 0 51 :3 0
2a96 :4 0 2a97 :2 0
2aae 19d :4 0 2a99
:3 0 8a :3 0 8f
:2 0 18eb 2a9c 2a9d
:3 0 15 :3 0 9b
:3 0 2a9f 2aa0 0
30 :2 0 2aa1 2aa2
0 2aa4 18ee 2aab
15 :3 0 9b :3 0
2aa5 2aa6 0 10c
:2 0 2aa7 2aa8 0
2aaa 18f0 2aac 2a9e
2aa4 0 2aad 0
2aaa 0 2aad 18f2
0 2aae 18f5 2b03
9d :3 0 15 :3 0
9b :3 0 2ab1 2ab2
0 9c :3 0 2ab3
2ab4 0 2af9 66
:3 0 67 :3 0 2ab6
2ab7 0 66 :3 0
77 :3 0 2ab9 2aba
0 9e :2 0 2
:4 0 24e :2 0 79
:2 0 27 :2 0 18f8
2abf 2ac1 :3 0 18fb
2abb 2ac3 2ab8 2ac5
2ac4 :2 0 69 :3 0
7a :3 0 2ac7 2ac8
0 6b :4 0 24f
:4 0 6e :2 0 6f
:3 0 18ff 2acc 2ace
:3 0 6e :2 0 82
:4 0 1902 2ad0 2ad2
:3 0 6e :2 0 a1
:4 0 1905 2ad4 2ad6
:3 0 6e :2 0 9c
:3 0 1908 2ad8 2ada
:3 0 6e :2 0 a2
:4 0 190b 2adc 2ade
:3 0 6e :2 0 a3
:3 0 a4 :3 0 27
:2 0 a5 :2 0 190e
2ae1 2ae5 1912 2ae0
2ae7 :3 0 1915 2ac9
2ae9 :2 0 2af6 69
:3 0 7a :3 0 2aeb
2aec 0 6b :4 0
203 :4 0 6e :2 0
51 :3 0 1918 2af0
2af2 :3 0 191b 2aed
2af4 :2 0 2af6 191e
2af7 2ac6 2af6 0
2af8 1921 0 2af9
1923 2afc :3 0 2afc
0 2afc 2afb 2af9
2afa :6 0 2afe 6b
:3 0 1926 2b00 1928
2aff 2afe :2 0 2b01
192a :2 0 2b03 0
2b03 2b02 2aae 2b01
:6 0 2ca7 1 :3 0
1f4 :3 0 1f5 :3 0
204 :4 0 2b07 :4 0
2b08 :2 0 2ca7 15
:3 0 9b :3 0 2b0a
2b0b 0 30 :2 0
2b0c 2b0d 0 2ca7
51 :3 0 250 :4 0
6e :2 0 251 :4 0
192c 2b11 2b13 :3 0
6e :2 0 252 :4 0
192f 2b15 2b17 :3 0
6e :2 0 253 :4 0
1932 2b19 2b1b :3 0
6e :2 0 254 :4 0
1935 2b1d 2b1f :3 0
6e :2 0 255 :4 0
1938 2b21 2b23 :3 0
6e :2 0 17 :3 0
193b 2b25 2b27 :3 0
6e :2 0 256 :4 0
193e 2b29 2b2b :3 0
6e :2 0 2b :3 0
1941 2b2d 2b2f :3 0
6e :2 0 257 :4 0
1944 2b31 2b33 :3 0
2b0f 2b34 0 2ca7
1f4 :3 0 1f5 :3 0
51 :3 0 2b38 :4 0
2b39 :2 0 2b50 19d
:4 0 2b3b :3 0 8a
:3 0 8f :2 0 1949
2b3e 2b3f :3 0 15
:3 0 9b :3 0 2b41
2b42 0 30 :2 0
2b43 2b44 0 2b46
194c 2b4d 15 :3 0
9b :3 0 2b47 2b48
0 10c :2 0 2b49
2b4a 0 2b4c 194e
2b4e 2b40 2b46 0
2b4f 0 2b4c 0
2b4f 1950 0 2b50
1953 2ba5 9d :3 0
15 :3 0 9b :3 0
2b53 2b54 0 9c
:3 0 2b55 2b56 0
2b9b 66 :3 0 67
:3 0 2b58 2b59 0
66 :3 0 77 :3 0
2b5b 2b5c 0 9e
:2 0 2 :4 0 258
:2 0 79 :2 0 27
:2 0 1956 2b61 2b63
:3 0 1959 2b5d 2b65
2b5a 2b67 2b66 :2 0
69 :3 0 7a :3 0
2b69 2b6a 0 6b
:4 0 259 :4 0 6e
:2 0 6f :3 0 195d
2b6e 2b70 :3 0 6e
:2 0 82 :4 0 1960
2b72 2b74 :3 0 6e
:2 0 a1 :4 0 1963
2b76 2b78 :3 0 6e
:2 0 9c :3 0 1966
2b7a 2b7c :3 0 6e
:2 0 a2 :4 0 1969
2b7e 2b80 :3 0 6e
:2 0 a3 :3 0 a4
:3 0 27 :2 0 a5
:2 0 196c 2b83 2b87
1970 2b82 2b89 :3 0
1973 2b6b 2b8b :2 0
2b98 69 :3 0 7a
:3 0 2b8d 2b8e 0
6b :4 0 203 :4 0
6e :2 0 51 :3 0
1976 2b92 2b94 :3 0
1979 2b8f 2b96 :2 0
2b98 197c 2b99 2b68
2b98 0 2b9a 197f
0 2b9b 1981 2b9e
:3 0 2b9e 0 2b9e
2b9d 2b9b 2b9c :6 0
2ba0 6d :3 0 1984
2ba2 1986 2ba1 2ba0
:2 0 2ba3 1988 :2 0
2ba5 0 2ba5 2ba4
2b50 2ba3 :6 0 2ca7
1 :3 0 15 :3 0
9b :3 0 2ba7 2ba8
0 20f :4 0 2baa
2bab :3 0 2ba9 2bac
0 2ca7 51 :3 0
210 :4 0 6e :2 0
25a :4 0 198a 2bb0
2bb2 :3 0 6e :2 0
213 :4 0 198d 2bb4
2bb6 :3 0 6e :2 0
25b :4 0 1990 2bb8
2bba :3 0 6e :2 0
25c :4 0 1993 2bbc
2bbe :3 0 6e :2 0
217 :4 0 1996 2bc0
2bc2 :3 0 6e :2 0
25d :4 0 1999 2bc4
2bc6 :3 0 6e :2 0
21a :4 0 199c 2bc8
2bca :3 0 6e :2 0
25e :4 0 199f 2bcc
2bce :3 0 6e :2 0
21c :4 0 19a2 2bd0
2bd2 :3 0 6e :2 0
17 :3 0 19a5 2bd4
2bd6 :3 0 6e :2 0
21d :4 0 19a8 2bd8
2bda :3 0 6e :2 0
21e :4 0 19ab 2bdc
2bde :3 0 6e :2 0
17 :3 0 19ae 2be0
2be2 :3 0 6e :2 0
21f :4 0 19b1 2be4
2be6 :3 0 6e :2 0
220 :4 0 19b4 2be8
2bea :3 0 6e :2 0
25f :4 0 19b7 2bec
2bee :3 0 6e :2 0
2b :3 0 19ba 2bf0
2bf2 :3 0 6e :2 0
260 :4 0 19bd 2bf4
2bf6 :3 0 2bae 2bf7
0 2ca7 1f4 :3 0
1f5 :3 0 51 :3 0
2bfb :4 0 2bfc :2 0
2c13 19d :4 0 2bfe
:3 0 8a :3 0 8f
:2 0 19c2 2c01 2c02
:3 0 15 :3 0 9b
:3 0 2c04 2c05 0
30 :2 0 2c06 2c07
0 2c09 19c5 2c10
15 :3 0 9b :3 0
2c0a 2c0b 0 10c
:2 0 2c0c 2c0d 0
2c0f 19c7 2c11 2c03
2c09 0 2c12 0
2c0f 0 2c12 19c9
0 2c13 19cc 2c68
9d :3 0 15 :3 0
9b :3 0 2c16 2c17
0 9c :3 0 2c18
2c19 0 2c5e 66
:3 0 67 :3 0 2c1b
2c1c 0 66 :3 0
77 :3 0 2c1e 2c1f
0 9e :2 0 2
:4 0 261 :2 0 79
:2 0 27 :2 0 19cf
2c24 2c26 :3 0 19d2
2c20 2c28 2c1d 2c2a
2c29 :2 0 69 :3 0
7a :3 0 2c2c 2c2d
0 6b :4 0 262
:4 0 6e :2 0 6f
:3 0 19d6 2c31 2c33
:3 0 6e :2 0 82
:4 0 19d9 2c35 2c37
:3 0 6e :2 0 a1
:4 0 19dc 2c39 2c3b
:3 0 6e :2 0 9c
:3 0 19df 2c3d 2c3f
:3 0 6e :2 0 a2
:4 0 19e2 2c41 2c43
:3 0 6e :2 0 a3
:3 0 a4 :3 0 27
:2 0 a5 :2 0 19e5
2c46 2c4a 19e9 2c45
2c4c :3 0 19ec 2c2e
2c4e :2 0 2c5b 69
:3 0 7a :3 0 2c50
2c51 0 6b :4 0
203 :4 0 6e :2 0
51 :3 0 19ef 2c55
2c57 :3 0 19f2 2c52
2c59 :2 0 2c5b 19f5
2c5c 2c2b 2c5b 0
2c5d 19f8 0 2c5e
19fa 2c61 :3 0 2c61
0 2c61 2c60 2c5e
2c5f :6 0 2c63 6f
:3 0 19fd 2c65 19ff
2c64 2c63 :2 0 2c66
1a01 :2 0 2c68 0
2c68 2c67 2c13 2c66
:6 0 2ca7 1 :3 0
51 :3 0 263 :4 0
6e :2 0 264 :4 0
1a03 2c6c 2c6e :3 0
6e :2 0 265 :4 0
1a06 2c70 2c72 :3 0
6e :2 0 266 :4 0
1a09 2c74 2c76 :3 0
6e :2 0 74 :3 0
73 :3 0 38 :3 0
30 :2 0 1a0c 2c7a
2c7d 1a0f 2c79 2c7f
1a11 2c78 2c81 :3 0
6e :2 0 267 :4 0
1a14 2c83 2c85 :3 0
6e :2 0 74 :3 0
73 :3 0 3d :3 0
30 :2 0 1a17 2c89
2c8c 1a1a 2c88 2c8e
1a1c 2c87 2c90 :3 0
6e :2 0 268 :4 0
1a1f 2c92 2c94 :3 0
6e :2 0 237 :4 0
1a22 2c96 2c98 :3 0
6e :2 0 269 :4 0
1a25 2c9a 2c9c :3 0
6e :2 0 26a :4 0
1a28 2c9e 2ca0 :3 0
6e :2 0 26b :4 0
1a2b 2ca2 2ca4 :3 0
2c6a 2ca5 0 2ca7
1a2e 2ca8 2a5e 2ca7
0 2ef8 1f4 :3 0
1f5 :3 0 246 :4 0
2cab :4 0 2cac :2 0
2ef5 15 :3 0 9b
:3 0 2cae 2caf 0
30 :2 0 2cb0 2cb1
0 2ef5 51 :3 0
247 :4 0 6e :2 0
26c :4 0 1a3b 2cb5
2cb7 :3 0 6e :2 0
26d :4 0 1a3e 2cb9
2cbb :3 0 6e :2 0
26e :4 0 1a41 2cbd
2cbf :3 0 6e :2 0
26f :4 0 1a44 2cc1
2cc3 :3 0 6e :2 0
209 :4 0 1a47 2cc5
2cc7 :3 0 6e :2 0
270 :4 0 1a4a 2cc9
2ccb :3 0 6e :2 0
17 :3 0 1a4d 2ccd
2ccf :3 0 6e :2 0
271 :4 0 1a50 2cd1
2cd3 :3 0 6e :2 0
272 :4 0 1a53 2cd5
2cd7 :3 0 6e :2 0
2c :3 0 1a56 2cd9
2cdb :3 0 6e :2 0
273 :4 0 1a59 2cdd
2cdf :3 0 6e :2 0
274 :4 0 1a5c 2ce1
2ce3 :3 0 2cb3 2ce4
0 2ef5 1f4 :3 0
1f5 :3 0 51 :3 0
2ce8 :4 0 2ce9 :2 0
2d00 19d :4 0 2ceb
:3 0 8a :3 0 8f
:2 0 1a61 2cee 2cef
:3 0 15 :3 0 9b
:3 0 2cf1 2cf2 0
30 :2 0 2cf3 2cf4
0 2cf6 1a64 2cfd
15 :3 0 9b :3 0
2cf7 2cf8 0 10c
:2 0 2cf9 2cfa 0
2cfc 1a66 2cfe 2cf0
2cf6 0 2cff 0
2cfc 0 2cff 1a68
0 2d00 1a6b 2d55
9d :3 0 15 :3 0
9b :3 0 2d03 2d04
0 9c :3 0 2d05
2d06 0 2d4b 66
:3 0 67 :3 0 2d08
2d09 0 66 :3 0
77 :3 0 2d0b 2d0c
0 9e :2 0 2
:4 0 275 :2 0 79
:2 0 27 :2 0 1a6e
2d11 2d13 :3 0 1a71
2d0d 2d15 2d0a 2d17
2d16 :2 0 69 :3 0
7a :3 0 2d19 2d1a
0 6b :4 0 276
:4 0 6e :2 0 6f
:3 0 1a75 2d1e 2d20
:3 0 6e :2 0 82
:4 0 1a78 2d22 2d24
:3 0 6e :2 0 a1
:4 0 1a7b 2d26 2d28
:3 0 6e :2 0 9c
:3 0 1a7e 2d2a 2d2c
:3 0 6e :2 0 a2
:4 0 1a81 2d2e 2d30
:3 0 6e :2 0 a3
:3 0 a4 :3 0 27
:2 0 a5 :2 0 1a84
2d33 2d37 1a88 2d32
2d39 :3 0 1a8b 2d1b
2d3b :2 0 2d48 69
:3 0 7a :3 0 2d3d
2d3e 0 6b :4 0
203 :4 0 6e :2 0
51 :3 0 1a8e 2d42
2d44 :3 0 1a91 2d3f
2d46 :2 0 2d48 1a94
2d49 2d18 2d48 0
2d4a 1a97 0 2d4b
1a99 2d4e :3 0 2d4e
0 2d4e 2d4d 2d4b
2d4c :6 0 2d50 71
:3 0 1a9c 2d52 1a9e
2d51 2d50 :2 0 2d53
1aa0 :2 0 2d55 0
2d55 2d54 2d00 2d53
:6 0 2ef5 1 :3 0
1f4 :3 0 1f5 :3 0
204 :4 0 2d59 :4 0
2d5a :2 0 2ef5 15
:3 0 9b :3 0 2d5c
2d5d 0 30 :2 0
2d5e 2d5f 0 2ef5
51 :3 0 250 :4 0
6e :2 0 277 :4 0
1aa2 2d63 2d65 :3 0
6e :2 0 278 :4 0
1aa5 2d67 2d69 :3 0
6e :2 0 279 :4 0
1aa8 2d6b 2d6d :3 0
6e :2 0 27a :4 0
1aab 2d6f 2d71 :3 0
6e :2 0 255 :4 0
1aae 2d73 2d75 :3 0
6e :2 0 17 :3 0
1ab1 2d77 2d79 :3 0
6e :2 0 256 :4 0
1ab4 2d7b 2d7d :3 0
6e :2 0 2c :3 0
1ab7 2d7f 2d81 :3 0
6e :2 0 27b :4 0
1aba 2d83 2d85 :3 0
2d61 2d86 0 2ef5
1f4 :3 0 1f5 :3 0
51 :3 0 2d8a :4 0
2d8b :2 0 2da2 19d
:4 0 2d8d :3 0 8a
:3 0 8f :2 0 1abf
2d90 2d91 :3 0 15
:3 0 9b :3 0 2d93
2d94 0 30 :2 0
2d95 2d96 0 2d98
1ac2 2d9f 15 :3 0
9b :3 0 2d99 2d9a
0 10c :2 0 2d9b
2d9c 0 2d9e 1ac4
2da0 2d92 2d98 0
2da1 0 2d9e 0
2da1 1ac6 0 2da2
1ac9 2df7 9d :3 0
15 :3 0 9b :3 0
2da5 2da6 0 9c
:3 0 2da7 2da8 0
2ded 66 :3 0 67
:3 0 2daa 2dab 0
66 :3 0 77 :3 0
2dad 2dae 0 9e
:2 0 2 :4 0 27c
:2 0 79 :2 0 27
:2 0 1acc 2db3 2db5
:3 0 1acf 2daf 2db7
2dac 2db9 2db8 :2 0
69 :3 0 7a :3 0
2dbb 2dbc 0 6b
:4 0 27d :4 0 6e
:2 0 6f :3 0 1ad3
2dc0 2dc2 :3 0 6e
:2 0 82 :4 0 1ad6
2dc4 2dc6 :3 0 6e
:2 0 a1 :4 0 1ad9
2dc8 2dca :3 0 6e
:2 0 9c :3 0 1adc
2dcc 2dce :3 0 6e
:2 0 a2 :4 0 1adf
2dd0 2dd2 :3 0 6e
:2 0 a3 :3 0 a4
:3 0 27 :2 0 a5
:2 0 1ae2 2dd5 2dd9
1ae6 2dd4 2ddb :3 0
1ae9 2dbd 2ddd :2 0
2dea 69 :3 0 7a
:3 0 2ddf 2de0 0
6b :4 0 203 :4 0
6e :2 0 51 :3 0
1aec 2de4 2de6 :3 0
1aef 2de1 2de8 :2 0
2dea 1af2 2deb 2dba
2dea 0 2dec 1af5
0 2ded 1af7 2df0
:3 0 2df0 0 2df0
2def 2ded 2dee :6 0
2df2 73 :3 0 1afa
2df4 1afc 2df3 2df2
:2 0 2df5 1afe :2 0
2df7 0 2df7 2df6
2da2 2df5 :6 0 2ef5
1 :3 0 15 :3 0
9b :3 0 2df9 2dfa
0 20f :4 0 2dfc
2dfd :3 0 2dfb 2dfe
0 2ef5 51 :3 0
210 :4 0 6e :2 0
25a :4 0 1b00 2e02
2e04 :3 0 6e :2 0
213 :4 0 1b03 2e06
2e08 :3 0 6e :2 0
214 :4 0 1b06 2e0a
2e0c :3 0 6e :2 0
27e :4 0 1b09 2e0e
2e10 :3 0 6e :2 0
27f :4 0 1b0c 2e12
2e14 :3 0 6e :2 0
219 :4 0 1b0f 2e16
2e18 :3 0 6e :2 0
21a :4 0 1b12 2e1a
2e1c :3 0 6e :2 0
280 :4 0 1b15 2e1e
2e20 :3 0 6e :2 0
21c :4 0 1b18 2e22
2e24 :3 0 6e :2 0
17 :3 0 1b1b 2e26
2e28 :3 0 6e :2 0
229 :4 0 1b1e 2e2a
2e2c :3 0 6e :2 0
281 :4 0 1b21 2e2e
2e30 :3 0 6e :2 0
22c :4 0 1b24 2e32
2e34 :3 0 6e :2 0
22d :4 0 1b27 2e36
2e38 :3 0 6e :2 0
2c :3 0 1b2a 2e3a
2e3c :3 0 6e :2 0
260 :4 0 1b2d 2e3e
2e40 :3 0 2e00 2e41
0 2ef5 1f4 :3 0
1f5 :3 0 51 :3 0
2e45 :4 0 2e46 :2 0
2e5d 19d :4 0 2e48
:3 0 8a :3 0 8f
:2 0 1b32 2e4b 2e4c
:3 0 15 :3 0 9b
:3 0 2e4e 2e4f 0
30 :2 0 2e50 2e51
0 2e53 1b35 2e5a
15 :3 0 9b :3 0
2e54 2e55 0 10c
:2 0 2e56 2e57 0
2e59 1b37 2e5b 2e4d
2e53 0 2e5c 0
2e59 0 2e5c 1b39
0 2e5d 1b3c 2eb2
9d :3 0 15 :3 0
9b :3 0 2e60 2e61
0 9c :3 0 2e62
2e63 0 2ea8 66
:3 0 67 :3 0 2e65
2e66 0 66 :3 0
77 :3 0 2e68 2e69
0 9e :2 0 2
:4 0 282 :2 0 79
:2 0 27 :2 0 1b3f
2e6e 2e70 :3 0 1b42
2e6a 2e72 2e67 2e74
2e73 :2 0 69 :3 0
7a :3 0 2e76 2e77
0 6b :4 0 283
:4 0 6e :2 0 6f
:3 0 1b46 2e7b 2e7d
:3 0 6e :2 0 82
:4 0 1b49 2e7f 2e81
:3 0 6e :2 0 a1
:4 0 1b4c 2e83 2e85
:3 0 6e :2 0 9c
:3 0 1b4f 2e87 2e89
:3 0 6e :2 0 a2
:4 0 1b52 2e8b 2e8d
:3 0 6e :2 0 a3
:3 0 a4 :3 0 27
:2 0 a5 :2 0 1b55
2e90 2e94 1b59 2e8f
2e96 :3 0 1b5c 2e78
2e98 :2 0 2ea5 69
:3 0 7a :3 0 2e9a
2e9b 0 6b :4 0
203 :4 0 6e :2 0
51 :3 0 1b5f 2e9f
2ea1 :3 0 1b62 2e9c
2ea3 :2 0 2ea5 1b65
2ea6 2e75 2ea5 0
2ea7 1b68 0 2ea8
1b6a 2eab :3 0 2eab
0 2eab 2eaa 2ea8
2ea9 :6 0 2ead 75
:3 0 1b6d 2eaf 1b6f
2eae 2ead :2 0 2eb0
1b71 :2 0 2eb2 0
2eb2 2eb1 2e5d 2eb0
:6 0 2ef5 1 :3 0
51 :3 0 284 :4 0
6e :2 0 264 :4 0
1b73 2eb6 2eb8 :3 0
6e :2 0 285 :4 0
1b76 2eba 2ebc :3 0
6e :2 0 286 :4 0
1b79 2ebe 2ec0 :3 0
6e :2 0 74 :3 0
73 :3 0 38 :3 0
30 :2 0 1b7c 2ec4
2ec7 1b7f 2ec3 2ec9
1b81 2ec2 2ecb :3 0
6e :2 0 23f :4 0
1b84 2ecd 2ecf :3 0
6e :2 0 287 :4 0
1b87 2ed1 2ed3 :3 0
6e :2 0 74 :3 0
73 :3 0 3d :3 0
30 :2 0 1b8a 2ed7
2eda 1b8d 2ed6 2edc
1b8f 2ed5 2ede :3 0
6e :2 0 288 :4 0
1b92 2ee0 2ee2 :3 0
6e :2 0 289 :4 0
1b95 2ee4 2ee6 :3 0
6e :2 0 237 :4 0
1b98 2ee8 2eea :3 0
6e :2 0 28a :4 0
1b9b 2eec 2eee :3 0
6e :2 0 26b :4 0
1b9e 2ef0 2ef2 :3 0
2eb4 2ef3 0 2ef5
1ba1 2ef7 275e 2a52
0 2ef8 0 2ef5
0 2ef8 1bae 0
2f3f 66 :3 0 67
:3 0 2ef9 2efa 0
66 :3 0 77 :3 0
2efc 2efd 0 27
:2 0 2 :4 0 28b
:2 0 79 :2 0 27
:2 0 1bb2 2f02 2f04
:3 0 1bb5 2efe 2f06
2efb 2f08 2f07 :2 0
69 :3 0 7a :3 0
2f0a 2f0b 0 6b
:4 0 28c :4 0 6e
:2 0 6f :3 0 1bb9
2f0f 2f11 :3 0 1bbc
2f0c 2f13 :2 0 2f15
1bbf 2f16 2f09 2f15
0 2f17 1bc1 0
2f3f 66 :3 0 67
:3 0 2f18 2f19 0
66 :3 0 77 :3 0
2f1b 2f1c 0 27
:2 0 2 :4 0 28d
:2 0 79 :2 0 27
:2 0 1bc3 2f21 2f23
:3 0 1bc6 2f1d 2f25
2f1a 2f27 2f26 :2 0
69 :3 0 7a :3 0
2f29 2f2a 0 6b
:4 0 28e :4 0 6e
:2 0 6f :3 0 1bca
2f2e 2f30 :3 0 1bcd
2f2b 2f32 :2 0 2f34
1bd0 2f35 2f28 2f34
0 2f36 1bd2 0
2f3f 14 :3 0 88
:3 0 28f :3 0 2f38
2f39 0 51 :3 0
1bd4 2f3a 2f3c 2f3d
:2 0 2f3f 1bd6 2fe0
15 :3 0 290 :2 0
4 2f40 2f41 0
66 :3 0 67 :3 0
2f43 2f44 0 66
:3 0 77 :3 0 2f46
2f47 0 9e :2 0
2 :4 0 291 :2 0
79 :2 0 27 :2 0
1c04 2f4c 2f4e :3 0
1c07 2f48 2f50 2f45
2f52 2f51 :2 0 69
:3 0 7a :3 0 2f54
2f55 0 6b :4 0
292 :4 0 6e :2 0
6f :3 0 1c0b 2f59
2f5b :3 0 1c0e 2f56
2f5d :2 0 2f76 69
:3 0 7a :3 0 2f5f
2f60 0 6b :4 0
293 :4 0 6e :2 0
15 :3 0 294 :3 0
2f65 2f66 0 1c11
2f64 2f68 :3 0 6e
:2 0 e4 :4 0 1c14
2f6a 2f6c :3 0 6e
:2 0 15 :3 0 295
:3 0 2f6f 2f70 0
1c17 2f6e 2f72 :3 0
1c1a 2f61 2f74 :2 0
2f76 1c1d 2f77 2f53
2f76 0 2f78 1c20
0 2f88 296 :3 0
65 :3 0 15 :3 0
294 :3 0 297 :3 0
15 :3 0 295 :3 0
298 :3 0 99 :4 0
299 1 :a 0 2f84
:2 0 2f88 2f7a 2f82
:2 0 14 :3 0 65
:3 0 2f86 :2 0 2f88
1c22 2f8a 1c26 2f89
2f88 :2 0 2fde 9d
:3 0 15 :3 0 9b
:3 0 2f8d 2f8e 0
9c :3 0 2f8f 2f90
0 2fd6 66 :3 0
67 :3 0 2f92 2f93
0 66 :3 0 77
:3 0 2f95 2f96 0
9e :2 0 2 :4 0
29a :2 0 79 :2 0
27 :2 0 1c28 2f9b
2f9d :3 0 1c2b 2f97
2f9f 2f94 2fa1 2fa0
:2 0 69 :3 0 7a
:3 0 2fa3 2fa4 0
6b :4 0 29b :4 0
6e :2 0 6f :3 0
1c2f 2fa8 2faa :3 0
1c32 2fa5 2fac :2 0
2fc6 69 :3 0 7a
:3 0 2fae 2faf 0
6b :4 0 a1 :4 0
6e :2 0 9c :3 0
1c35 2fb3 2fb5 :3 0
6e :2 0 a2 :4 0
1c38 2fb7 2fb9 :3 0
6e :2 0 a3 :3 0
a4 :3 0 27 :2 0
a5 :2 0 1c3b 2fbc
2fc0 1c3f 2fbb 2fc2
:3 0 1c42 2fb0 2fc4
:2 0 2fc6 1c45 2fc7
2fa2 2fc6 0 2fc8
1c48 0 2fd6 296
:3 0 65 :3 0 297
:3 0 15 :3 0 295
:3 0 298 :3 0 99
:4 0 29c 1 :a 0
2fd2 :2 0 2fd6 2fca
2fd0 :2 0 14 :3 0
65 :3 0 2fd4 :2 0
2fd6 1c4a 2fd9 :3 0
2fd9 0 2fd9 2fd8
2fd6 2fd7 :6 0 2fdb
1 :3 0 1c4f 2fdd
1c51 2fdc 2fdb :2 0
2fde 1c53 :2 0 2fe0
1c56 2fe0 2fdf 2f3f
2fde :6 0 2fe1 :2 0
2 44 2fe0 2fe4
:3 0 2fe3 2fe1 2fe5
:8 0 
1c9b
4
:3 0 1 3 1
7 1 b 1
f 1 13 1
17 1 1b 1
1f 1 23 1
27 1 2b 1
2f 1 33 1
37 1 3b f
6 a e 12
16 1a 1e 22
26 2a 2e 32
36 3a 3e 1
48 1 46 1
4f 1 4d 1
56 1 54 1
5d 1 5b 1
64 1 62 1
6b 1 69 1
72 1 70 1
79 1 77 1
80 1 7e 1
87 1 85 1
8c 1 91 1
98 1 96 1
9f 1 9d 1
a6 1 a4 1
ad 1 ab 1
b4 1 b2 1
bb 1 b9 1
c0 1 c6 1
cc 1 d2 1
d8 1 de 1
e4 1 ea 1
f0 1 f6 1
fc 1 102 1
108 1 10e 1
114 1 11a 1
120 1 126 1
12c 1 132 1
138 1 13e 1
144 1 14a 1
150 1 156 1
15c 1 162 1
16a 1 168 1
171 1 16f 1
176 1 17e 1
17c 1 183 1
18b 1 189 1
192 1 190 1
199 1 197 1
19e 1 1a4 1
1aa 1 1b2 1
1b0 1 1b9 1
1b7 1 1be 1
1c4 1 1cc 1
1ca 1 1d1 1
1d7 1 1dd 1
1e3 1 1e9 1
1ee 1 1fb 1
207 2 20a 20c
2 20f 211 2
213 215 2 217
219 2 21b 21d
2 21f 221 2
223 225 2 227
229 2 22b 22d
2 22f 231 2
233 235 2 237
239 2 23b 23d
1 243 2 245
246 2 23f 248
2 24a 24c 1
252 2 254 255
2 24e 257 2
259 25b 1 261
2 263 264 2
25d 266 2 268
26a 1 270 2
272 273 2 26c
275 2 277 279
1 27f 2 281
282 2 27b 284
2 286 288 1
28e 2 290 291
2 28a 293 2
295 297 1 29d
2 29f 2a0 2
299 2a2 2 2a4
2a6 1 2ac 2
2ae 2af 2 2a8
2b1 2 2b3 2b5
1 2bb 2 2bd
2be 2 2b7 2c0
2 2c2 2c4 1
2ca 2 2cc 2cd
2 2c6 2cf 2
2d1 2d3 2 2d5
2d7 2 2d9 2db
2 2dd 2df 2
2e1 2e3 2 2e5
2e7 2 2e9 2eb
2 2ed 2ef 2
2f1 2f3 4 203
209 20e 2f5 1
2f7 1 2f9 2
303 305 3 301
302 307 2 310
312 2 30f 314
1 316 1 318
2 350 351 1
353 1 360 2
36d 36f 3 36b
36c 371 2 37a
37c 2 37e 380
2 382 384 1
38c 2 38e 38f
2 386 391 2
379 393 1 395
1 397 2 3a1
3a3 3 39f 3a0
3a5 2 3ae 3b0
2 3ad 3b2 1
3b4 1 3b6 2
3bd 3be 3 398
3b7 3c0 1 3c2
1 3c4 2 3d1
3d3 3 3cf 3d0
3d5 2 3de 3e0
2 3e2 3e4 2
3e6 3e8 1 3f0
2 3f2 3f3 2
3ea 3f5 2 3dd
3f7 1 3f9 1
3fb 2 405 407
3 403 404 409
2 412 414 2
411 416 1 418
1 41a 2 421
422 3 3fc 41b
424 1 426 2
429 42a 1 42e
2 42c 42e 2
432 433 1 437
2 435 437 2
43d 43e 1 442
2 440 442 2
44f 451 3 44d
44e 453 2 45c
45e 2 460 462
2 464 466 1
46e 2 470 471
2 468 473 2
45b 475 1 477
1 479 2 483
485 3 481 482
487 2 490 492
2 48f 494 1
496 1 498 2
49f 4a0 3 47a
499 4a2 1 4a4
1 4a6 1 4ac
2 4bc 4c1 2
4d2 4d4 3 4d0
4d1 4d6 2 4df
4e1 2 4e3 4e5
2 4e7 4e9 2
4eb 4ed 2 4ef
4f1 3 4f6 4f7
4f8 2 4f3 4fa
2 4de 4fc 1
4fe 1 500 2
4c9 501 1 505
1 4c4 1 509
1 514 2 510
514 2 519 51a
1 51e 2 51c
51e 2 52c 52e
3 52a 52b 530
2 539 53b 2
53d 53f 2 541
543 1 54b 2
54d 54e 2 545
550 2 538 552
1 554 1 556
2 560 562 3
55e 55f 564 2
56d 56f 2 56c
571 1 573 1
575 2 57c 57d
3 557 576 57f
1 581 3 50c
582 585 1 588
1 58e 2 599
59e 2 5af 5b1
3 5ad 5ae 5b3
2 5bc 5be 2
5c0 5c2 2 5c4
5c6 2 5c8 5ca
2 5cc 5ce 3
5d3 5d4 5d5 2
5d0 5d7 2 5bb
5d9 1 5db 1
5dd 2 5a6 5de
1 5e2 1 5a1
1 5e6 1 5e9
2 5ed 5ec 1
5f2 1 5f9 1
5fb 3 5ff 600
601 3 607 608
609 2 611 612
1 616 2 614
616 3 61c 61d
61e 3 620 621
622 4 62a 62b
62c 62d 2 633
634 1 636 1
63a 2 638 63a
2 64a 64f 2
660 662 3 65e
65f 664 2 66d
66f 2 671 673
2 675 677 2
679 67b 2 67d
67f 3 684 685
686 2 681 688
2 66c 68a 1
68c 1 68e 2
657 68f 1 693
1 652 1 697
1 69a 2 6e2
6e7 2 6f8 6fa
3 6f6 6f7 6fc
2 705 707 2
709 70b 2 70d
70f 2 711 713
2 715 717 3
71c 71d 71e 2
719 720 2 704
722 1 724 1
726 2 6ef 727
1 72b 1 6ea
1 72f 1 732
2 735 736 1
73e 2 73a 73e
2 749 74e 2
75f 761 3 75d
75e 763 2 76c
76e 2 770 772
2 774 776 2
778 77a 2 77c
77e 3 783 784
785 2 780 787
2 76b 789 1
78b 1 78d 2
756 78e 1 792
1 751 1 796
1 7a1 2 79d
7a1 1 7a5 1
7ac 1 7ae 2
7bb 7c0 2 7d1
7d3 3 7cf 7d0
7d5 2 7de 7e0
2 7e2 7e4 2
7e6 7e8 2 7ea
7ec 2 7ee 7f0
3 7f5 7f6 7f7
2 7f2 7f9 2
7dd 7fb 1 7fd
1 7ff 2 7c8
800 1 804 1
7c3 1 808 2
7af 80b 2 816
818 3 814 815
81a 2 823 825
2 827 829 2
82b 82d 1 835
2 837 838 2
82f 83a 2 83c
83e 2 840 842
2 844 846 2
848 84a 2 822
84c 1 84e 1
850 2 85a 85c
3 858 859 85e
2 867 869 2
866 86b 1 86d
1 86f 3 876
877 878 3 851
870 87a 2 87c
87d 2 799 87e
1 882 2 884
885 2 88f 894
2 8a5 8a7 3
8a3 8a4 8a9 2
8b2 8b4 2 8b6
8b8 2 8ba 8bc
2 8be 8c0 2
8c2 8c4 3 8c9
8ca 8cb 2 8c6
8cd 2 8b1 8cf
1 8d1 1 8d3
2 89c 8d4 1
8d8 1 897 1
8dc 2 8e2 8e3
1 8e7 2 8e5
8e7 2 8ef 8f4
2 905 907 3
903 904 909 2
912 914 2 916
918 2 91a 91c
2 91e 920 2
922 924 3 929
92a 92b 2 926
92d 2 911 92f
1 931 1 933
2 8fc 934 1
938 1 8f7 1
93c 2 944 945
1 949 2 947
949 2 954 956
3 952 953 958
2 961 963 2
965 967 2 969
96b 1 973 2
975 976 2 96d
978 2 97a 97c
2 97e 980 2
982 984 2 986
988 2 960 98a
1 98c 1 98e
2 998 99a 3
996 997 99c 2
9a5 9a7 2 9a4
9a9 1 9ab 1
9ad 3 9b4 9b5
9b6 3 98f 9ae
9b8 1 9ba 2
93f 9bb 1 9bd
7 625 630 737
886 889 8df 9be
2 9cb 9d0 2
9e1 9e3 3 9df
9e0 9e5 2 9ee
9f0 2 9f2 9f4
2 9f6 9f8 2
9fa 9fc 2 9fe
a00 3 a05 a06
a07 2 a02 a09
2 9ed a0b 1
a0d 1 a0f 2
9d8 a10 1 a14
1 9d3 1 a18
1 a23 2 a1f
a23 2 a2c a31
2 a42 a44 3
a40 a41 a46 2
a4f a51 2 a53
a55 2 a57 a59
2 a5b a5d 2
a5f a61 3 a66
a67 a68 2 a63
a6a 2 a4e a6c
1 a6e 1 a70
2 a39 a71 1
a75 1 a34 1
a79 1 a84 2
a80 a84 2 a90
a92 3 a8e a8f
a94 2 a9d a9f
2 aa1 aa3 2
aa5 aa7 1 aaf
2 ab1 ab2 2
aa9 ab4 2 ab6
ab8 2 aba abc
2 abe ac0 2
ac2 ac4 2 a9c
ac6 1 ac8 1
aca 2 ad4 ad6
3 ad2 ad3 ad8
2 ae1 ae3 2
ae0 ae5 1 ae7
1 ae9 3 af0
af1 af2 3 acb
aea af4 1 af6
2 a7c af7 1
af9 2 a1b afa
2 afc afd 1
b01 2 aff b01
2 b0f b10 2
b14 b15 2 b19
b1a 2 b1e b1f
2 b23 b24 2
b28 b29 2 b2d
b2e 2 b32 b33
d b0c b0d b12
b17 b1c b21 b26
b2b b30 b35 b36
b37 b38 2 b3d
b3e 1 b44 2
b40 b44 2 b4f
b51 3 b4d b4e
b53 2 b5c b5e
2 b60 b62 2
b64 b66 1 b6e
2 b70 b71 2
b68 b73 2 b5b
b75 1 b77 1
b79 2 b83 b85
3 b81 b82 b87
2 b90 b92 2
b8f b94 1 b96
1 b98 2 b9f
ba0 3 b7a b99
ba2 2 ba6 ba7
1 bab 2 ba9
bab 2 bb6 bb8
3 bb4 bb5 bba
2 bc3 bc5 2
bc7 bc9 2 bcb
bcd 1 bd3 2
bd5 bd6 2 bcf
bd8 2 bda bdc
2 bde be0 2
be2 be4 2 be6
be8 2 bc2 bea
1 bec 1 bee
2 bf8 bfa 3
bf6 bf7 bfc 2
c05 c07 2 c04
c09 1 c0b 1
c0d 2 c13 c14
3 c16 c17 c18
3 bef c0e c1a
2 c1d c1c 1
c22 1 c29 1
c2b 6 b06 b09
b3b c1e c21 c2c
2 c30 c31 1
c35 2 c33 c35
2 c3a c3b 1
c3f 2 c3d c3f
2 c46 c47 1
c4b 2 c49 c4b
2 c50 c51 1
c55 2 c53 c55
1 c5d 2 c61
c62 1 c66 2
c64 c66 1 c6b
2 c70 c71 1
c75 2 c73 c75
2 c7a c7b 1
c7f 2 c7d c7f
1 c87 2 c8c
c8d 1 c91 2
c8f c91 2 c96
c97 2 c9c c9d
2 c99 c9f 2
ca2 ca5 4 ca8
c6e c8a ca7 1
ca9 2 cac cab
2 cbf cc0 2
cc2 cc5 2 cc8
cc9 2 cd0 cd1
2 cd3 cd6 2
cdb cdc 1 ce0
2 cde ce0 6
ce5 ce6 ce7 ce8
ce9 cea 2 cef
cf0 1 cf4 2
cf2 cf4 2 cff
d01 3 cfd cfe
d03 2 d0c d0e
2 d10 d12 2
d14 d16 1 d1c
2 d1e d1f 2
d18 d21 2 d23
d25 2 d27 d29
2 d2b d2d 2
d2f d31 2 d0b
d33 1 d35 1
d37 2 d41 d43
3 d3f d40 d45
2 d4e d50 2
d4d d52 1 d54
1 d56 2 d5c
d5d 3 d5f d60
d61 3 d38 d57
d63 1 d65 2
d7e d83 2 d94
d96 3 d92 d93
d98 2 da1 da3
2 da5 da7 2
da9 dab 2 dad
daf 2 db1 db3
3 db8 db9 dba
2 db5 dbc 2
da0 dbe 1 dc0
1 dc2 2 d8b
dc3 1 dc7 1
d86 1 dcb 1
dd6 2 dd2 dd6
1 dda 2 de6
de7 1 deb 2
de9 deb 1 df0
1 df2 2 de4
df3 1 df5 1
dff 2 dfd dff
3 e03 e04 e05
1 e09 2 e07
e09 2 e28 e2d
2 e3e e40 3
e3c e3d e42 2
e4b e4d 2 e4f
e51 2 e53 e55
2 e57 e59 2
e5b e5d 3 e62
e63 e64 2 e5f
e66 2 e4a e68
1 e6a 1 e6c
2 e35 e6d 1
e71 1 e30 1
e75 1 e80 2
e7c e80 2 e88
e89 1 e8d 2
e8b e8d 2 e92
e93 1 e97 2
e95 e97 2 eb7
ebc 2 ecd ecf
3 ecb ecc ed1
2 eda edc 2
ede ee0 2 ee2
ee4 2 ee6 ee8
2 eea eec 3
ef1 ef2 ef3 2
eee ef5 2 ed9
ef7 1 ef9 1
efb 2 ec4 efc
1 f00 1 ebf
1 f04 1 f07
1 f0c 2 f0e
f0f 2 e86 f10
1 f19 2 f15
f19 2 f1e f1f
1 f23 2 f21
f23 2 f43 f48
2 f59 f5b 3
f57 f58 f5d 2
f66 f68 2 f6a
f6c 2 f6e f70
2 f72 f74 2
f76 f78 3 f7d
f7e f7f 2 f7a
f81 2 f65 f83
1 f85 1 f87
2 f50 f88 1
f8c 1 f4b 1
f90 1 f93 2
f97 f96 2 e78
f98 2 fb4 fb9
2 fca fcc 3
fc8 fc9 fce 2
fd7 fd9 2 fdb
fdd 2 fdf fe1
2 fe3 fe5 2
fe7 fe9 3 fee
fef ff0 2 feb
ff2 2 fd6 ff4
1 ff6 1 ff8
2 fc1 ff9 1
ffd 1 fbc 1
1001 1 1004 2
1007 1008 1 1009
3 100c 100d 100e
1 1012 2 1010
1012 2 102e 1033
2 1044 1046 3
1042 1043 1048 2
1051 1053 2 1055
1057 2 1059 105b
2 105d 105f 2
1061 1063 3 1068
1069 106a 2 1065
106c 2 1050 106e
1 1070 1 1072
2 103b 1073 1
1077 1 1036 1
107b 1 1086 2
1082 1086 2 108e
108f 1 1093 2
1091 1093 2 1098
1099 1 109d 2
109b 109d 2 10b7
10bc 2 10cd 10cf
3 10cb 10cc 10d1
2 10da 10dc 2
10de 10e0 2 10e2
10e4 2 10e6 10e8
2 10ea 10ec 3
10f1 10f2 10f3 2
10ee 10f5 2 10d9
10f7 1 10f9 1
10fb 2 10c4 10fc
1 1100 1 10bf
1 1104 1 1107
2 110c 110d 2
110f 1110 2 108c
1111 1 111a 2
1116 111a 2 1135
113a 2 114b 114d
3 1149 114a 114f
2 1158 115a 2
115c 115e 2 1160
1162 2 1164 1166
2 1168 116a 3
116f 1170 1171 2
116c 1173 2 1157
1175 1 1177 1
1179 2 1142 117a
1 117e 1 113d
1 1182 1 1185
2 1189 1188 2
107e 118a 2 11a3
11a8 2 11b9 11bb
3 11b7 11b8 11bd
2 11c6 11c8 2
11ca 11cc 2 11ce
11d0 2 11d2 11d4
2 11d6 11d8 3
11dd 11de 11df 2
11da 11e1 2 11c5
11e3 1 11e5 1
11e7 2 11b0 11e8
1 11ec 1 11ab
1 11f0 1 11f3
2 11f6 11f7 1
11f8 2 11fa 11fb
1 1203 2 11ff
1203 2 1208 1209
1 120d 2 120b
120d 2 1218 121a
3 1216 1217 121c
2 1225 1227 2
1229 122b 2 122d
122f 1 1237 2
1239 123a 2 1231
123c 2 123e 1240
2 1242 1244 2
1246 1248 2 124a
124c 2 1224 124e
1 1250 1 1252
2 125c 125e 3
125a 125b 1260 2
1269 126b 2 1268
126d 1 126f 1
1271 3 1278 1279
127a 3 1253 1272
127c 1 127f 1
1286 2 1284 1286
2 129b 12a0 2
12b1 12b3 3 12af
12b0 12b5 2 12be
12c0 2 12c2 12c4
2 12c6 12c8 2
12ca 12cc 2 12ce
12d0 3 12d5 12d6
12d7 2 12d2 12d9
2 12bd 12db 1
12dd 1 12df 2
12a8 12e0 1 12e4
1 12a3 1 12e8
2 128b 12eb 2
12fd 1302 2 1313
1315 3 1311 1312
1317 2 1320 1322
2 1324 1326 2
1328 132a 2 132c
132e 2 1330 1332
3 1337 1338 1339
2 1334 133b 2
131f 133d 1 133f
1 1341 2 130a
1342 1 1346 1
1305 1 134a 2
12f0 134d 2 1350
1351 2 1354 1355
2 135a 135b 1
135d 2 1357 135d
2 1368 136a 3
1366 1367 136c 2
1375 1377 2 1379
137b 2 137d 137f
1 1387 2 1389
138a 2 1381 138c
2 138e 1390 2
1392 1394 2 1396
1398 2 139a 139c
2 1374 139e 1
13a0 1 13a2 2
13ac 13ae 3 13aa
13ab 13b0 2 13b9
13bb 2 13b8 13bd
1 13bf 1 13c1
3 13c8 13c9 13ca
3 13a3 13c2 13cc
1 13ce 2 1352
13cf 2 13d2 13d1
2 13d3 13d6 2
13da 13db 1 13df
2 13dd 13df 2
13e5 13e6 1 13e8
1 13ed 2 13eb
13ed 2 13fa 13fc
3 13f8 13f9 13fe
2 1407 1409 2
140b 140d 2 140f
1411 1 1419 2
141b 141c 2 1413
141e 2 1420 1422
2 1424 1426 2
1428 142a 2 142c
142e 2 1406 1430
1 1432 1 1434
2 143e 1440 3
143c 143d 1442 2
144b 144d 2 144a
144f 1 1451 1
1453 3 145a 145b
145c 3 1435 1454
145e 2 1461 1460
3 1464 1465 1466
1 146a 2 1468
146a 2 146f 1471
3 1473 1474 1475
2 148e 1493 2
14a4 14a6 3 14a2
14a3 14a8 2 14b1
14b3 2 14b5 14b7
2 14b9 14bb 2
14bd 14bf 2 14c1
14c3 3 14c8 14c9
14ca 2 14c5 14cc
2 14b0 14ce 1
14d0 1 14d2 2
149b 14d3 1 14d7
1 1496 1 14db
1 14e6 2 14e2
14e6 2 14f2 14f4
3 14f0 14f1 14f6
2 14ff 1501 2
1503 1505 2 1507
1509 1 1511 2
1513 1514 2 150b
1516 2 1518 151a
2 151c 151e 2
1520 1522 2 1524
1526 2 14fe 1528
1 152a 1 152c
2 1536 1538 3
1534 1535 153a 2
1543 1545 2 1542
1547 1 1549 1
154b 3 1552 1553
1554 3 152d 154c
1556 1 1558 3
155b 155c 155d 1
1561 2 155f 1561
2 1566 1567 1
156b 2 1569 156b
2 1570 1571 2
1576 1577 1 1579
2 1573 1579 2
158a 158c 3 1588
1589 158e 2 1597
1599 2 159b 159d
2 159f 15a1 1
15a9 2 15ab 15ac
2 15a3 15ae 2
15b0 15b2 2 15b4
15b6 2 15b8 15ba
2 15bc 15be 2
1596 15c0 1 15c2
1 15c4 2 15ce
15d0 3 15cc 15cd
15d2 2 15db 15dd
2 15da 15df 1
15e1 1 15e3 3
15ea 15eb 15ec 3
15c5 15e4 15ee 1
15f0 2 15fe 1603
2 1614 1616 3
1612 1613 1618 2
1621 1623 2 1625
1627 2 1629 162b
2 162d 162f 2
1631 1633 3 1638
1639 163a 2 1635
163c 2 1620 163e
1 1640 1 1642
2 160b 1643 1
1647 1 1606 1
164b 5 1478 14de
1559 15f1 164e 2
1653 1655 3 1657
1658 1659 2 1662
1667 2 1678 167a
3 1676 1677 167c
2 1685 1687 2
1689 168b 2 168d
168f 2 1691 1693
2 1695 1697 3
169c 169d 169e 2
1699 16a0 2 1684
16a2 1 16a4 1
16a6 2 166f 16a7
1 16ab 1 166a
1 16af 1 16ba
2 16b6 16ba 2
16c6 16c8 3 16c4
16c5 16ca 2 16d3
16d5 2 16d7 16d9
2 16db 16dd 1
16e5 2 16e7 16e8
2 16df 16ea 2
16ec 16ee 2 16f0
16f2 2 16f4 16f6
2 16f8 16fa 2
16d2 16fc 1 16fe
1 1700 2 170a
170c 3 1708 1709
170e 2 1717 1719
2 1716 171b 1
171d 1 171f 3
1726 1727 1728 3
1701 1720 172a 1
172c 2 1742 1747
2 1758 175a 3
1756 1757 175c 2
1765 1767 2 1769
176b 2 176d 176f
2 1771 1773 2
1775 1777 3 177c
177d 177e 2 1779
1780 2 1764 1782
1 1784 1 1786
2 174f 1787 1
178b 1 174a 1
178f 1 179a 2
1796 179a 2 179f
17a0 1 17a4 2
17a2 17a4 2 17b2
17b4 3 17b0 17b1
17b6 2 17bf 17c1
2 17c3 17c5 2
17c7 17c9 1 17d1
2 17d3 17d4 2
17cb 17d6 2 17d8
17da 2 17dc 17de
2 17e0 17e2 2
17e4 17e6 2 17be
17e8 1 17ea 1
17ec 2 17f6 17f8
3 17f4 17f5 17fa
2 1803 1805 2
1802 1807 1 1809
1 180b 3 1812
1813 1814 3 17ed
180c 1816 1 1818
2 1826 182b 2
183c 183e 3 183a
183b 1840 2 1849
184b 2 184d 184f
2 1851 1853 2
1855 1857 2 1859
185b 3 1860 1861
1862 2 185d 1864
2 1848 1866 1
1868 1 186a 2
1833 186b 1 186f
1 182e 1 1873
6 165c 16b2 172d
1792 1819 1876 2
1879 187a 2 1880
1881 1 1885 2
1883 1885 2 1892
1897 2 18a8 18aa
3 18a6 18a7 18ac
2 18b5 18b7 2
18b9 18bb 2 18bd
18bf 2 18c1 18c3
2 18c5 18c7 3
18cc 18cd 18ce 2
18c9 18d0 2 18b4
18d2 1 18d4 1
18d6 2 189f 18d7
1 18db 1 189a
1 18df 2 18ee
18f3 2 1904 1906
3 1902 1903 1908
2 1911 1913 2
1915 1917 2 1919
191b 2 191d 191f
2 1921 1923 3
1928 1929 192a 2
1925 192c 2 1910
192e 1 1930 1
1932 2 18fb 1933
1 1937 1 18f6
1 193b 2 1947
1948 1 194c 2
194a 194c 1 1951
1 1953 20 1957
1958 1959 195a 195b
195c 195d 195e 195f
1960 1961 1962 1963
1964 1965 1966 1967
1968 1969 196a 196b
196c 196d 196e 196f
1970 1971 1972 1973
1974 1975 1976 1
197c 2 197a 197c
2 1980 1981 1
1985 2 1983 1985
1 198f 2 198e
198f 1 1997 1
199d 2 199f 19a0
2 198c 19a1 2
19b2 19b4 3 19b0
19b1 19b6 2 19bf
19c1 2 19c3 19c5
2 19c7 19c9 2
19cb 19cd 2 19cf
19d1 3 19d6 19d7
19d8 2 19d3 19da
2 19be 19dc 1
19de 1 19e0 2
19a9 19e1 1 19e5
1 19a4 1 19e9
1 19ec 1 19f6
2 19f5 19f6 1
19fe 1 1a04 2
1a06 1a07 2 19f3
1a08 2 1a19 1a1b
3 1a17 1a18 1a1d
2 1a26 1a28 2
1a2a 1a2c 2 1a2e
1a30 2 1a32 1a34
2 1a36 1a38 3
1a3d 1a3e 1a3f 2
1a3a 1a41 2 1a25
1a43 1 1a45 1
1a47 2 1a10 1a48
1 1a4c 1 1a0b
1 1a50 1 1a53
2 1a56 1a57 1
1a58 1 1a5a 7
18e2 193e 1942 1945
1954 1979 1a5b 3
1a64 1a65 1a66 1
1a6a 2 1a68 1a6a
1 1a71 2 1a76
1a77 2 1a79 1a7c
1 1a7f 2 1a81
1a82 20 1a86 1a87
1a88 1a89 1a8a 1a8b
1a8c 1a8d 1a8e 1a8f
1a90 1a91 1a92 1a93
1a94 1a95 1a96 1a97
1a98 1a99 1a9a 1a9b
1a9c 1a9d 1a9e 1a9f
1aa0 1aa1 1aa2 1aa3
1aa4 1aa5 1 1aab
2 1aa9 1aab 1
1ab5 2 1ab4 1ab5
1 1abd 1 1ac3
2 1ac5 1ac6 2
1ab2 1ac7 2 1ad8
1ada 3 1ad6 1ad7
1adc 2 1ae5 1ae7
2 1ae9 1aeb 2
1aed 1aef 2 1af1
1af3 2 1af5 1af7
3 1afc 1afd 1afe
2 1af9 1b00 2
1ae4 1b02 1 1b04
1 1b06 2 1acf
1b07 1 1b0b 1
1aca 1 1b0f 1
1b12 1 1b15 5
1a5f 1a62 1a83 1aa8
1b16 2 1b18 1b19
c ced d66 d69
dce df6 df9 dfc
11fc 1462 187b 187e
1b1a 1 1b1e 2
1b20 1b21 1 1b25
2 1b23 1b25 1
1b2a 1 1b30 2
1b32 1b33 2 1b35
1b37 2 1b3a 1b3c
1 1b3e 1 1b41
2 1b43 1b44 1
1b48 2 1b46 1b48
2 1b50 1b51 1
1b54 2 1b53 1b54
2 1b64 1b65 2
1b67 1b69 2 1b6b
1b6d 4 1b61 1b62
1b6f 1b70 2 1b7b
1b7c 2 1b7e 1b80
2 1b82 1b84 2
1b86 1b88 4 1b78
1b79 1b8a 1b8b 2
1ba9 1bae 2 1bbf
1bc1 3 1bbd 1bbe
1bc3 2 1bcc 1bce
2 1bd0 1bd2 2
1bd4 1bd6 2 1bd8
1bda 2 1bdc 1bde
3 1be3 1be4 1be5
2 1be0 1be7 2
1bcb 1be9 1 1beb
1 1bed 2 1bb6
1bee 1 1bf2 1
1bb1 1 1bf6 2
1bfc 1bfd 1 1c01
2 1bff 1c01 1
1c05 2 1c13 1c14
1 1c18 2 1c16
1c18 1 1c1d 1
1c1f 2 1c0f 1c20
1 1c22 3 1c25
1c26 1c27 1 1c2b
2 1c29 1c2b 1
1c35 2 1c37 1c38
1 1c3c 2 1c3a
1c3c 1 1c41 2
1c45 1c47 3 1c49
1c4a 1c4b 2 1c51
1c53 3 1c55 1c56
1c57 2 1c4e 1c5a
2 1c5c 1c5d 2
1c32 1c5e 1 1c62
2 1c64 1c65 1
1c69 2 1c67 1c69
1 1c6e 2 1c72
1c74 3 1c76 1c77
1c78 2 1c7e 1c80
3 1c82 1c83 1c84
2 1c7b 1c87 2
1c89 1c8a 1 1c8b
2 1c8d 1c8e 2
1c97 1c98 1 1c9c
2 1c9a 1c9c 1
1ca1 2 1c9f 1ca1
3 1ca5 1ca6 1ca7
1 1cab 2 1ca9
1cab 2 1cca 1ccf
2 1ce0 1ce2 3
1cde 1cdf 1ce4 2
1ced 1cef 2 1cf1
1cf3 2 1cf5 1cf7
2 1cf9 1cfb 2
1cfd 1cff 3 1d04
1d05 1d06 2 1d01
1d08 2 1cec 1d0a
1 1d0c 1 1d0e
2 1cd7 1d0f 1
1d13 1 1cd2 1
1d17 1 1d22 2
1d1e 1d22 2 1d2a
1d2b 1 1d2f 2
1d2d 1d2f 2 1d34
1d35 1 1d39 2
1d37 1d39 2 1d59
1d5e 2 1d6f 1d71
3 1d6d 1d6e 1d73
2 1d7c 1d7e 2
1d80 1d82 2 1d84
1d86 2 1d88 1d8a
2 1d8c 1d8e 3
1d93 1d94 1d95 2
1d90 1d97 2 1d7b
1d99 1 1d9b 1
1d9d 2 1d66 1d9e
1 1da2 1 1d61
1 1da6 1 1da9
1 1dae 2 1db0
1db1 2 1d28 1db2
1 1dbb 2 1db7
1dbb 2 1dc0 1dc1
1 1dc5 2 1dc3
1dc5 2 1de5 1dea
2 1dfb 1dfd 3
1df9 1dfa 1dff 2
1e08 1e0a 2 1e0c
1e0e 2 1e10 1e12
2 1e14 1e16 2
1e18 1e1a 3 1e1f
1e20 1e21 2 1e1c
1e23 2 1e07 1e25
1 1e27 1 1e29
2 1df2 1e2a 1
1e2e 1 1ded 1
1e32 1 1e35 2
1e39 1e38 2 1d1a
1e3a 2 1e58 1e5d
2 1e6e 1e70 3
1e6c 1e6d 1e72 2
1e7b 1e7d 2 1e7f
1e81 2 1e83 1e85
2 1e87 1e89 2
1e8b 1e8d 3 1e92
1e93 1e94 2 1e8f
1e96 2 1e7a 1e98
1 1e9a 1 1e9c
2 1e65 1e9d 1
1ea1 1 1e60 1
1ea5 1 1ea8 2
1eab 1eac 1 1ead
3 1eb0 1eb1 1eb2
1 1eb6 2 1eb4
1eb6 2 1ed4 1ed9
2 1eea 1eec 3
1ee8 1ee9 1eee 2
1ef7 1ef9 2 1efb
1efd 2 1eff 1f01
2 1f03 1f05 2
1f07 1f09 3 1f0e
1f0f 1f10 2 1f0b
1f12 2 1ef6 1f14
1 1f16 1 1f18
2 1ee1 1f19 1
1f1d 1 1edc 1
1f21 1 1f2c 2
1f28 1f2c 2 1f31
1f32 1 1f36 2
1f34 1f36 2 1f3b
1f3c 1 1f40 2
1f3e 1f40 2 1f5c
1f61 2 1f72 1f74
3 1f70 1f71 1f76
2 1f7f 1f81 2
1f83 1f85 2 1f87
1f89 2 1f8b 1f8d
2 1f8f 1f91 3
1f96 1f97 1f98 2
1f93 1f9a 2 1f7e
1f9c 1 1f9e 1
1fa0 2 1f69 1fa1
1 1fa5 1 1f64
1 1fa9 1 1fac
2 1fb1 1fb2 2
1fb4 1fb5 1 1fb6
1 1fbf 2 1fbb
1fbf 2 1fdc 1fe1
2 1ff2 1ff4 3
1ff0 1ff1 1ff6 2
1fff 2001 2 2003
2005 2 2007 2009
2 200b 200d 2
200f 2011 3 2016
2017 2018 2 2013
201a 2 1ffe 201c
1 201e 1 2020
2 1fe9 2021 1
2025 1 1fe4 1
2029 1 202c 2
2030 202f 2 1f24
2031 2 204c 2051
2 2062 2064 3
2060 2061 2066 2
206f 2071 2 2073
2075 2 2077 2079
2 207b 207d 2
207f 2081 3 2086
2087 2088 2 2083
208a 2 206e 208c
1 208e 1 2090
2 2059 2091 1
2095 1 2054 1
2099 1 209c 2
209f 20a0 1 20a1
2 20a3 20a4 1
20ac 2 20a8 20ac
2 20b1 20b2 1
20b6 2 20b4 20b6
1 20bb 1 20bd
1 20c4 2 20c2
20c4 2 20d9 20de
2 20ef 20f1 3
20ed 20ee 20f3 2
20fc 20fe 2 2100
2102 2 2104 2106
2 2108 210a 2
210c 210e 3 2113
2114 2115 2 2110
2117 2 20fb 2119
1 211b 1 211d
2 20e6 211e 1
2122 1 20e1 1
2126 2 20c9 2129
2 213b 2140 2
2151 2153 3 214f
2150 2155 2 215e
2160 2 2162 2164
2 2166 2168 2
216a 216c 2 216e
2170 3 2175 2176
2177 2 2172 2179
2 215d 217b 1
217d 1 217f 2
2148 2180 1 2184
1 2143 1 2188
2 212e 218b 2
218e 218f 2 2192
2193 2 2198 2199
1 219b 2 2195
219b 2 21a0 21a1
2 21a3 21a5 2
21a8 21aa 1 21ac
2 2190 21ad 1
21af 2 21b0 21b3
2 21b5 21b6 1
21b7 2 21bb 21bc
2 21be 21c0 2
21c3 21c5 2 21c7
21c8 2 21da 21df
2 21f0 21f2 3
21ee 21ef 21f4 2
21fd 21ff 2 2201
2203 2 2205 2207
2 2209 220b 2
220d 220f 3 2214
2215 2216 2 2211
2218 2 21fc 221a
1 221c 1 221e
2 21e7 221f 1
2223 1 21e2 1
2227 2 2236 223b
2 224c 224e 3
224a 224b 2250 2
2259 225b 2 225d
225f 2 2261 2263
2 2265 2267 2
2269 226b 3 2270
2271 2272 2 226d
2274 2 2258 2276
1 2278 1 227a
2 2243 227b 1
227f 1 223e 1
2283 2 228f 2290
1 2294 2 2292
2294 1 2299 1
229b 20 229f 22a0
22a1 22a2 22a3 22a4
22a5 22a6 22a7 22a8
22a9 22aa 22ab 22ac
22ad 22ae 22af 22b0
22b1 22b2 22b3 22b4
22b5 22b6 22b7 22b8
22b9 22ba 22bb 22bc
22bd 22be 1 22c4
2 22c2 22c4 2
22c8 22c9 1 22cd
2 22cb 22cd 1
22d7 2 22d6 22d7
1 22df 1 22e5
2 22e7 22e8 2
22d4 22e9 2 22fa
22fc 3 22f8 22f9
22fe 2 2307 2309
2 230b 230d 2
230f 2311 2 2313
2315 2 2317 2319
3 231e 231f 2320
2 231b 2322 2
2306 2324 1 2326
1 2328 2 22f1
2329 1 232d 1
22ec 1 2331 1
2334 1 233e 2
233d 233e 1 2346
1 234c 2 234e
234f 2 233b 2350
2 2361 2363 3
235f 2360 2365 2
236e 2370 2 2372
2374 2 2376 2378
2 237a 237c 2
237e 2380 3 2385
2386 2387 2 2382
2389 2 236d 238b
1 238d 1 238f
2 2358 2390 1
2394 1 2353 1
2398 1 239b 2
239e 239f 1 23a0
1 23a2 b 20a5
21c9 21cc 21cf 222a
2286 228a 228d 229c
22c1 23a3 2 23a7
23a8 1 23ac 2
23aa 23ac 3 23b6
23b7 23b8 1 23bc
2 23ba 23bc 1
23c3 2 23c7 23c8
1 23cb 2 23cd
23ce 20 23d2 23d3
23d4 23d5 23d6 23d7
23d8 23d9 23da 23db
23dc 23dd 23de 23df
23e0 23e1 23e2 23e3
23e4 23e5 23e6 23e7
23e8 23e9 23ea 23eb
23ec 23ed 23ee 23ef
23f0 23f1 1 23f7
2 23f5 23f7 1
2401 2 2400 2401
1 2409 1 240f
2 2411 2412 2
23fe 2413 2 2424
2426 3 2422 2423
2428 2 2431 2433
2 2435 2437 2
2439 243b 2 243d
243f 2 2441 2443
3 2448 2449 244a
2 2445 244c 2
2430 244e 1 2450
1 2452 2 241b
2453 1 2457 1
2416 1 245b 1
245e 1 2461 5
23b1 23b4 23cf 23f4
2462 2 2465 2464
2 2469 246a 2
246c 246e 1 2472
f 1b5c 1b73 1b8e
1b91 1b94 1b97 1b9a
1bf9 1c23 1c8f 1c92
1c95 2466 2471 2475
2 1b4d 2478 1
247a 2 1b45 247b
2 247d 247e 1
2482 2 2480 2482
2 2487 2488 1
248c 2 248a 248c
2 2493 2494 1
2498 2 2496 2498
1 24a1 2 24a0
24a1 1 24a9 1
24af 2 24b1 24b2
2 249e 24b3 2
24c4 24c6 3 24c2
24c3 24c8 2 24d1
24d3 2 24d5 24d7
2 24d9 24db 2
24dd 24df 2 24e1
24e3 3 24e8 24e9
24ea 2 24e5 24ec
2 24d0 24ee 1
24f0 1 24f2 2
24bb 24f3 1 24f7
1 24b6 1 24fb
1 24fe 1 250b
2 250a 250b 1
2513 1 2519 2
251b 251c 2 2508
251d 2 252e 2530
3 252c 252d 2532
2 253b 253d 2
253f 2541 2 2543
2545 2 2547 2549
2 254b 254d 3
2552 2553 2554 2
254f 2556 2 253a
2558 1 255a 1
255c 2 2525 255d
1 2561 1 2520
1 2565 1 2568
2 256b 256c 1
2570 2 256e 2570
2 257b 257d 3
2579 257a 257f 2
2588 258a 2 258c
258e 2 2590 2592
1 259a 2 259c
259d 2 2594 259f
2 25a1 25a3 2
25a5 25a7 2 25a9
25ab 2 25ad 25af
2 2587 25b1 1
25b3 1 25b5 2
25bf 25c1 3 25bd
25be 25c3 2 25cc
25ce 2 25cb 25d0
1 25d2 1 25d4
3 25db 25dc 25dd
3 25b6 25d5 25df
1 25e6 2 25e2
25e6 2 25f1 25f3
3 25ef 25f0 25f5
2 25fe 2600 2
2602 2604 2 2606
2608 1 2610 2
2612 2613 2 260a
2615 2 2617 2619
2 261b 261d 2
261f 2621 2 2623
2625 2 25fd 2627
1 2629 1 262b
2 2635 2637 3
2633 2634 2639 2
2642 2644 2 2641
2646 1 2648 1
264a 3 2651 2652
2653 3 262c 264b
2655 1 265d 2
2659 265d 2 2668
266a 3 2666 2667
266c 2 2675 2677
2 2679 267b 2
267d 267f 1 2687
2 2689 268a 2
2681 268c 2 268e
2690 2 2692 2694
2 2696 2698 2
269a 269c 2 2674
269e 1 26a0 1
26a2 2 26ac 26ae
3 26aa 26ab 26b0
2 26b9 26bb 2
26b8 26bd 1 26bf
1 26c1 3 26c8
26c9 26ca 3 26a3
26c2 26cc 2 26d7
26d9 3 26d5 26d6
26db 2 26e4 26e6
2 26e8 26ea 2
26ec 26ee 1 26f6
2 26f8 26f9 2
26f0 26fb 2 26fd
26ff 2 2701 2703
2 2705 2707 2
2709 270b 2 26e3
270d 1 270f 1
2711 2 271b 271d
3 2719 271a 271f
2 2728 272a 2
2727 272c 1 272e
1 2730 3 2737
2738 2739 3 2712
2731 273b 4 273d
2658 26ce 273e 2
256d 273f 1 2741
1 2745 2 2747
2748 1 274c 2
274a 274c 1 2752
2 2754 2755 1
2759 2 2757 2759
2 276a 276c 2
276e 2770 2 2772
2774 2 2776 2778
2 277a 277c 2
277e 2780 2 2782
2784 2 2786 2788
2 278a 278c 2
278e 2790 2 2792
2794 2 2796 2798
1 27a3 2 27a2
27a3 1 27ab 1
27b1 2 27b3 27b4
2 27a0 27b5 2
27c6 27c8 3 27c4
27c5 27ca 2 27d3
27d5 2 27d7 27d9
2 27db 27dd 2
27df 27e1 2 27e3
27e5 3 27ea 27eb
27ec 2 27e7 27ee
2 27d2 27f0 2
27f7 27f9 2 27f6
27fb 2 27f2 27fd
1 27ff 2 27bd
2800 1 2804 1
27b8 1 2808 2
2818 281a 2 281c
281e 2 2820 2822
2 2824 2826 2
2828 282a 2 282c
282e 2 2830 2832
2 2834 2836 2
2838 283a 2 283c
283e 2 2840 2842
2 2844 2846 1
2851 2 2850 2851
1 2859 1 285f
2 2861 2862 2
284e 2863 2 2874
2876 3 2872 2873
2878 2 2881 2883
2 2885 2887 2
2889 288b 2 288d
288f 2 2891 2893
3 2898 2899 289a
2 2895 289c 2
2880 289e 2 28a5
28a7 2 28a4 28a9
2 28a0 28ab 1
28ad 2 286b 28ae
1 28b2 1 2866
1 28b6 2 28c3
28c5 2 28c7 28c9
2 28cb 28cd 2
28cf 28d1 2 28d3
28d5 2 28d7 28d9
2 28db 28dd 2
28df 28e1 2 28e3
28e5 2 28e7 28e9
2 28eb 28ed 2
28ef 28f1 2 28f3
28f5 2 28f7 28f9
2 28fb 28fd 2
28ff 2901 2 2903
2905 2 2907 2909
2 290b 290d 2
290f 2911 2 2913
2915 2 2917 2919
2 291b 291d 2
291f 2921 2 2923
2925 2 2927 2929
2 292b 292d 2
292f 2931 2 2933
2935 2 2937 2939
2 293b 293d 2
293f 2941 2 2943
2945 2 2947 2949
2 294b 294d 2
294f 2951 2 2953
2955 2 2957 2959
1 2964 2 2963
2964 1 296c 1
2972 2 2974 2975
2 2961 2976 2
2987 2989 3 2985
2986 298b 2 2994
2996 2 2998 299a
2 299c 299e 2
29a0 29a2 2 29a4
29a6 3 29ab 29ac
29ad 2 29a8 29af
2 2993 29b1 2
29b8 29ba 2 29b7
29bc 2 29b3 29be
1 29c0 2 297e
29c1 1 29c5 1
2979 1 29c9 2
29cf 29d1 2 29d3
29d5 2 29d7 29d9
2 29df 29e0 1
29e2 2 29db 29e4
2 29e6 29e8 2
29ea 29ec 2 29f2
29f3 1 29f5 2
29ee 29f7 2 29f9
29fb 2 29fd 29ff
2 2a01 2a03 2
2a05 2a07 2 2a09
2a0b 2 2a0d 2a0f
2 2a11 2a13 2
2a15 2a17 2 2a19
2a1b 2 2a21 2a22
1 2a24 2 2a1d
2a26 2 2a28 2a2a
2 2a2c 2a2e 2
2a34 2a35 1 2a37
2 2a30 2a39 2
2a3b 2a3d 2 2a3f
2a41 2 2a43 2a45
2 2a47 2a49 2
2a4b 2a4d c 2763
2768 279b 280b 2811
2816 2849 28b9 28c1
295c 29cc 2a50 1
2a55 2 2a57 2a58
1 2a5c 2 2a5a
2a5c 2 2a6a 2a6c
2 2a6e 2a70 2
2a72 2a74 2 2a76
2a78 2 2a7a 2a7c
2 2a7e 2a80 2
2a82 2a84 2 2a86
2a88 2 2a8a 2a8c
2 2a8e 2a90 1
2a9b 2 2a9a 2a9b
1 2aa3 1 2aa9
2 2aab 2aac 2
2a98 2aad 2 2abe
2ac0 3 2abc 2abd
2ac2 2 2acb 2acd
2 2acf 2ad1 2
2ad3 2ad5 2 2ad7
2ad9 2 2adb 2add
3 2ae2 2ae3 2ae4
2 2adf 2ae6 2
2aca 2ae8 2 2aef
2af1 2 2aee 2af3
2 2aea 2af5 1
2af7 2 2ab5 2af8
1 2afc 1 2ab0
1 2b00 2 2b10
2b12 2 2b14 2b16
2 2b18 2b1a 2
2b1c 2b1e 2 2b20
2b22 2 2b24 2b26
2 2b28 2b2a 2
2b2c 2b2e 2 2b30
2b32 1 2b3d 2
2b3c 2b3d 1 2b45
1 2b4b 2 2b4d
2b4e 2 2b3a 2b4f
2 2b60 2b62 3
2b5e 2b5f 2b64 2
2b6d 2b6f 2 2b71
2b73 2 2b75 2b77
2 2b79 2b7b 2
2b7d 2b7f 3 2b84
2b85 2b86 2 2b81
2b88 2 2b6c 2b8a
2 2b91 2b93 2
2b90 2b95 2 2b8c
2b97 1 2b99 2
2b57 2b9a 1 2b9e
1 2b52 1 2ba2
2 2baf 2bb1 2
2bb3 2bb5 2 2bb7
2bb9 2 2bbb 2bbd
2 2bbf 2bc1 2
2bc3 2bc5 2 2bc7
2bc9 2 2bcb 2bcd
2 2bcf 2bd1 2
2bd3 2bd5 2 2bd7
2bd9 2 2bdb 2bdd
2 2bdf 2be1 2
2be3 2be5 2 2be7
2be9 2 2beb 2bed
2 2bef 2bf1 2
2bf3 2bf5 1 2c00
2 2bff 2c00 1
2c08 1 2c0e 2
2c10 2c11 2 2bfd
2c12 2 2c23 2c25
3 2c21 2c22 2c27
2 2c30 2c32 2
2c34 2c36 2 2c38
2c3a 2 2c3c 2c3e
2 2c40 2c42 3
2c47 2c48 2c49 2
2c44 2c4b 2 2c2f
2c4d 2 2c54 2c56
2 2c53 2c58 2
2c4f 2c5a 1 2c5c
2 2c1a 2c5d 1
2c61 1 2c15 1
2c65 2 2c6b 2c6d
2 2c6f 2c71 2
2c73 2c75 2 2c7b
2c7c 1 2c7e 2
2c77 2c80 2 2c82
2c84 2 2c8a 2c8b
1 2c8d 2 2c86
2c8f 2 2c91 2c93
2 2c95 2c97 2
2c99 2c9b 2 2c9d
2c9f 2 2ca1 2ca3
c 2a63 2a68 2a93
2b03 2b09 2b0e 2b35
2ba5 2bad 2bf8 2c68
2ca6 2 2cb4 2cb6
2 2cb8 2cba 2
2cbc 2cbe 2 2cc0
2cc2 2 2cc4 2cc6
2 2cc8 2cca 2
2ccc 2cce 2 2cd0
2cd2 2 2cd4 2cd6
2 2cd8 2cda 2
2cdc 2cde 2 2ce0
2ce2 1 2ced 2
2cec 2ced 1 2cf5
1 2cfb 2 2cfd
2cfe 2 2cea 2cff
2 2d10 2d12 3
2d0e 2d0f 2d14 2
2d1d 2d1f 2 2d21
2d23 2 2d25 2d27
2 2d29 2d2b 2
2d2d 2d2f 3 2d34
2d35 2d36 2 2d31
2d38 2 2d1c 2d3a
2 2d41 2d43 2
2d40 2d45 2 2d3c
2d47 1 2d49 2
2d07 2d4a 1 2d4e
1 2d02 1 2d52
2 2d62 2d64 2
2d66 2d68 2 2d6a
2d6c 2 2d6e 2d70
2 2d72 2d74 2
2d76 2d78 2 2d7a
2d7c 2 2d7e 2d80
2 2d82 2d84 1
2d8f 2 2d8e 2d8f
1 2d97 1 2d9d
2 2d9f 2da0 2
2d8c 2da1 2 2db2
2db4 3 2db0 2db1
2db6 2 2dbf 2dc1
2 2dc3 2dc5 2
2dc7 2dc9 2 2dcb
2dcd 2 2dcf 2dd1
3 2dd6 2dd7 2dd8
2 2dd3 2dda 2
2dbe 2ddc 2 2de3
2de5 2 2de2 2de7
2 2dde 2de9 1
2deb 2 2da9 2dec
1 2df0 1 2da4
1 2df4 2 2e01
2e03 2 2e05 2e07
2 2e09 2e0b 2
2e0d 2e0f 2 2e11
2e13 2 2e15 2e17
2 2e19 2e1b 2
2e1d 2e1f 2 2e21
2e23 2 2e25 2e27
2 2e29 2e2b 2
2e2d 2e2f 2 2e31
2e33 2 2e35 2e37
2 2e39 2e3b 2
2e3d 2e3f 1 2e4a
2 2e49 2e4a 1
2e52 1 2e58 2
2e5a 2e5b 2 2e47
2e5c 2 2e6d 2e6f
3 2e6b 2e6c 2e71
2 2e7a 2e7c 2
2e7e 2e80 2 2e82
2e84 2 2e86 2e88
2 2e8a 2e8c 3
2e91 2e92 2e93 2
2e8e 2e95 2 2e79
2e97 2 2e9e 2ea0
2 2e9d 2ea2 2
2e99 2ea4 1 2ea6
2 2e64 2ea7 1
2eab 1 2e5f 1
2eaf 2 2eb5 2eb7
2 2eb9 2ebb 2
2ebd 2ebf 2 2ec5
2ec6 1 2ec8 2
2ec1 2eca 2 2ecc
2ece 2 2ed0 2ed2
2 2ed8 2ed9 1
2edb 2 2ed4 2edd
2 2edf 2ee1 2
2ee3 2ee5 2 2ee7
2ee9 2 2eeb 2eed
2 2eef 2ef1 c
2cad 2cb2 2ce5 2d55
2d5b 2d60 2d87 2df7
2dff 2e42 2eb2 2ef4
3 2ef6 2ca8 2ef7
2 2f01 2f03 3
2eff 2f00 2f05 2
2f0e 2f10 2 2f0d
2f12 1 2f14 1
2f16 2 2f20 2f22
3 2f1e 2f1f 2f24
2 2f2d 2f2f 2
2f2c 2f31 1 2f33
1 2f35 1 2f3b
2d 2fa 319 31c
31f 322 325 328
32b 32e 331 334
337 33a 33d 340
343 346 349 34c
356 359 35c 35f
3c3 427 4a5 5ee
5f1 5fc 604 60c
60f afe cad cb2
cb5 cb8 ccc cd9
247f 2742 2ef8 2f17
2f36 2f3e 2 2f4b
2f4d 3 2f49 2f4a
2f4f 2 2f58 2f5a
2 2f57 2f5c 2
2f63 2f67 2 2f69
2f6b 2 2f6d 2f71
2 2f62 2f73 2
2f5e 2f75 1 2f77
3 2f78 2f83 2f87
1 2f42 2 2f9a
2f9c 3 2f98 2f99
2f9e 2 2fa7 2fa9
2 2fa6 2fab 2
2fb2 2fb4 2 2fb6
2fb8 3 2fbd 2fbe
2fbf 2 2fba 2fc1
2 2fb1 2fc3 2
2fad 2fc5 1 2fc7
4 2f91 2fc8 2fd1
2fd5 1 2fd9 1
2f8c 2 2f8a 2fdd
44 4b 52 59
60 67 6e 75
7c 83 8a 8f
94 9b a2 a9
b0 b7 be c4
ca d0 d6 dc
e2 e8 ee f4
fa 100 106 10c
112 118 11e 124
12a 130 136 13c
142 148 14e 154
15a 160 166 16d
174 17a 181 187
18e 195 19c 1a2
1a8 1ae 1b5 1bc
1c2 1c8 1cf 1d5
1db 1e1 1e7 1ec
1f3 
1
4
0 
2fe4
0
1
a0
77
55
0 1 2 1 4 1 6 1
8 1 a 1 c 1 e 1
10 1 12 1 14 1 16 1
18 1 1a 1 1c 1 1e 1
20 1 22 1 24 1 26 1
28 1 2a 1 2c 1 2e 1
30 1 32 1 34 1 36 1
38 1 3a 1 3c 1 3e 1
40 41 40 43 40 45 40 47
40 49 40 4b 40 4d 40 4f
40 51 40 53 40 55 40 57
40 59 40 5b 40 5d 40 5f
1 61 1 63 1 65 1 67
1 69 1 6b 1 6d 1 6f
1 71 1 73 1 75 1 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0

3b 1 0
13e 1 0
2b 1 0
183 1 0
1dd 1 0
162 1 0
2f 1 0
1c4 1 0
ab 1 0
fc 1 0
15c 1 0
d8 1 0
1d7 1 0
27 1 0
189 1 0
1f 1 0
1b 1 0
1e3 1 0
96 1 0
2472 40 61
c0 1 0
9d 1 0
11a 1 0
17c 1 0
12c 1 0
8c 1 0
1e9 1 0
1a4 1 0
13 1 0
f6 1 0
1b0 1 0
ea 1 0
7e 1 0
1ca 1 0
16f 1 0
168 1 0
a4 1 0
77 1 0
f 1 0
e4 1 0
70 1 0
5b 1 0
3 1 0
c6 1 0
150 1 0
14a 1 0
1b7 1 0
85 1 0
19e 1 0
138 1 0
2 0 1
114 1 0
108 1 0
23 1 0
144 1 0
54 1 0
1d1 1 0
156 1 0
7 1 0
176 1 0
f0 1 0
de 1 0
132 1 0
d2 1 0
197 1 0
1be 1 0
1aa 1 0
cc 1 0
69 1 0
46 1 0
10e 1 0
37 1 0
4d 1 0
b2 1 0
120 1 0
17 1 0
91 1 0
b9 1 0
126 1 0
62 1 0
33 1 0
102 1 0
b 1 0
1ee 1 0
190 1 0
0

/
SHOW ERRORS FUNCTION SP_SEARCH_1;
ALTER FUNCTION SP_SEARCH_1 COMPILE DEBUG;
/*######################################################################################*/
/*######################################################################################*/
/*
#Stored Procedure  :SP_SEARCH_3
#Short Description :
#Description       :
#Table Name        :
#Parameters        :
#Returns           :
#Errors            :
*/
Prompt == FUNCTION SP_SEARCH_3 ==
CREATE OR REPLACE FUNCTION SP_SEARCH_3 wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
1a9
2 :e:
1FUNCTION:
1SP_SEARCH_3:
1PRJ_ID:
1VARCHAR2:
1START_DATE001:
1FINISH_DATE001:
1EFFORT001:
1PLS_INTEGER:
1WORK001:
1BITFLAG001:
1EUNIT:
1UNIT:
1CONTOUR001:
1OCCURRENCE:
1CONSIDER_PLANNED_SCHED:
1WORK_TYPE:
1TYPE001:
1AND_ROLES:
1REC_USER001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_PROJECT_ID:
132:
1H_TASK_ID:
1H_REC_USER:
1H_RES_ID:
1H_START_DATE:
126:
1H_START_DT:
1H_FINISH_DT:
1H_DAYOFYEAR:
1DATE:
1H_REC_STATUS:
11:
1H_RES_TYPE:
1H_PA_TIMEPHASE:
1H_ASSIGN_ID:
1H_PRJ_ASSIGNMENT_ID:
1H_AND_ROLES:
18000:
1H_SHW_ROLE:
1H_SHW_SKILL:
1H_SD:
1H_FD:
1H_FULL_NAME:
1255:
1H_COUNT:
10:
1H_BITFLAG:
1H_TYPE:
1H_UPDATE:
1H_WORK_TYPE:
1H_CRI:
1H_WORK:
1H_OCCURRENCE:
1H_EFFORT:
1H_EUNIT:
1H_UNIT:
1H_CONSIDER:
1H_CONTOUR:
1H_EVERY:
1H_PER_DAY:
1H_PER_WEEK:
1H_DAYS:
1H_DURATION:
1H_NUMBER:
1H_TOTAL:
1H_TOTPR:
1H_PRIORITY:
1H_WEEK:
1H_RES_COST:
1NUMBER:
1H_BILLABLE:
1H_CAPITAL_EXPENSE:
1H_TPH_DELETE:
1H_REG_COST:
10.00:
1H_REG_SALE:
1H_TEMP_PARTICIPANT:
1H_TEMP_SECURITY_ID:
1CHAR:
1H_TEMP2_SECURITY_ID:
1H_TEMP_BITFLAG:
1H_TEMP_SC_STATE:
1STMT:
17999:
1H_TABLE_TYPE:
1H_TEMP_VAR:
1I:
1II:
1I_RETURN:
1ISF:
1NUMITEMS:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_SEARCH_3(:
1':
1, :
1COALESCE:
1TO_CHAR:
1NULL:
1);:
1CHECK_TRACE:
1103:
1+:
1FPUT:
1               ENTER:: SP_SEARCH_3(104) :: cplan.sql(4382) :: :
1GETTABLE:
1IS NULL:
18:
1140:
1      RETURN_INVALID:: SP_SEARCH_3(141) :: cplan.sql(4419) :: :
1 :
1STATE:: :
1PMO_CNST:
1ELEMENT_ID_REQUIRED:
1143:
1                EXIT:: SP_SEARCH_3(144) :: cplan.sql(4422) :: :
1PMODEFINES:
1PMO_RETURN_INVALID_SP:
1TRUE:
1=:
15:
1160:
1      RETURN_INVALID:: SP_SEARCH_3(161) :: cplan.sql(4439) :: :
1INVALID_PARAMS:
1163:
1                EXIT:: SP_SEARCH_3(164) :: cplan.sql(4442) :: :
1!=:
1SC_SRCH_PARTICIPANT:
1IS NOT NULL:
1PMO_ORASTD:
1DAYS:
1DUAL:
1SELECT PMO_ORASTD.DAYS(finish_date001) - PMO_ORASTD.DAYS(start_date001):n    +
1     INTO h_total:n         FROM DUAL:
1SC_STATE:
1SQLCODE:
1OTHERS:
116:
1180:
1           EXCEPTION:: SP_SEARCH_3(181) :: cplan.sql(4459) :: :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1SC_SQL_SUCCESS:
1<:
1187:
1      RETURN_INVALID:: SP_SEARCH_3(188) :: cplan.sql(4466) :: :
1F_DATE_EARLIER_THAN_S_DATE:
1190:
1                EXIT:: SP_SEARCH_3(191) :: cplan.sql(4469) :: :
1ELSIF:
1SELECT SYSTIMESTAMP INTO h_start_date:n         FROM DUAL:
1206:
1           EXCEPTION:: SP_SEARCH_3(207) :: cplan.sql(4485) :: :
1PMO_FUNC:
1SHIFTRIGHT:
1BITAND:
1SC_C0000000:
130:
1SC_1FFFFFFF:
1MINUTE_PER_DAY:
1MINUTE_PER_WEEK:
1PRIORITY:
1TMT_WBS:
1ELEMENT_ID:
1SELECT COALESCE(MINUTE_PER_DAY, 480), COALESCE(MINUTE_PER_WEEK, 2400), PRIORI+
1TY:n         INTO h_per_day, h_per_week, h_priority:n         FROM TMT_WBS WH+
1ERE ELEMENT_ID = h_project_id:
1230:
1           EXCEPTION:: SP_SEARCH_3(231) :: cplan.sql(4509) :: :
1SC_SQL_NO_DATA:
1TMT_POOLS:
1SELECT 480, 2400, 0 INTO h_per_day, h_per_week, h_priority FROM TMT_POOLS WHE+
1RE ELEMENT_ID = h_project_id:
1244:
1           EXCEPTION:: SP_SEARCH_3(245) :: cplan.sql(4523) :: :
1250:
1        RETURN_ERROR:: SP_SEARCH_3(251) :: cplan.sql(4529) :: :
1 ID:: :
1253:
1                EXIT:: SP_SEARCH_3(254) :: cplan.sql(4532) :: :
1PMO_RETURN_ERROR_SP:
1LEVEL_LOCK:
1PROJECT_DETAILS:
1PROJECT_ID:
1SELECT LEVEL_LOCK INTO h_temp_var:n         FROM PROJECT_DETAILS:n         WH+
1ERE PROJECT_ID = h_project_id:
1270:
1           EXCEPTION:: SP_SEARCH_3(271) :: cplan.sql(4549) :: :
1>:
1REC_STATUS:
1SELECT REC_STATUS INTO h_rec_status:n            FROM TMT_WBS:n            WH+
1ERE ELEMENT_ID = h_project_id:
1286:
1           EXCEPTION:: SP_SEARCH_3(287) :: cplan.sql(4565) :: :
1STRCMP:
1L:
1293:
1        RETURN_ERROR:: SP_SEARCH_3(294) :: cplan.sql(4572) :: :
1LEV_LOCKED_BY_COPY:
1296:
1                EXIT:: SP_SEARCH_3(297) :: cplan.sql(4575) :: :
1304:
1      RETURN_INVALID:: SP_SEARCH_3(305) :: cplan.sql(4583) :: :
1307:
1                EXIT:: SP_SEARCH_3(308) :: cplan.sql(4586) :: :
1PMO_STPU:
1STRNPCPY:
133:
1ISPROJECTTYPE:
1TYPE_ID:
1SC_PROJECT:
1SC_PROPOSAL:
1SC_PROJ_TYPE1:
1SC_PROJ_TYPE2:
1SC_PROJ_TYPE3:
1SELECT PROJECT_ID, COALESCE(MINUTE_PER_DAY, 480), COALESCE(MINUTE_PER_WEEK, 2+
1400), PRIORITY:n            INTO h_project_id, h_per_day, h_per_week, h_prior+
1ity:n            FROM TMT_WBS WHERE ELEMENT_ID = h_task_id AND TYPE_ID IN (PM+
1O_CNST.SC_PROJECT,PMO_CNST.SC_PROPOSAL,PMO_CNST.SC_PROJ_TYPE1,PMO_CNST.SC_PRO+
1J_TYPE2,PMO_CNST.SC_PROJ_TYPE3):
1333:
1           EXCEPTION:: SP_SEARCH_3(334) :: cplan.sql(4612) :: :
1340:
1        RETURN_ERROR:: SP_SEARCH_3(341) :: cplan.sql(4619) :: :
1RECORD_NOT_FOUND:
1343:
1                EXIT:: SP_SEARCH_3(344) :: cplan.sql(4622) :: :
1349:
1        RETURN_ERROR:: SP_SEARCH_3(350) :: cplan.sql(4628) :: :
1352:
1                EXIT:: SP_SEARCH_3(353) :: cplan.sql(4631) :: :
1100:
1:
1FC_CALC_DURATION:
1375:
1      RETURN_INVALID:: SP_SEARCH_3(376) :: cplan.sql(4654) :: :
1378:
1                EXIT:: SP_SEARCH_3(379) :: cplan.sql(4657) :: :
1383:
1        RETURN_ERROR:: SP_SEARCH_3(384) :: cplan.sql(4662) :: :
1386:
1                EXIT:: SP_SEARCH_3(387) :: cplan.sql(4665) :: :
12:
13:
14:
1*:
15000:
1408:
1        RETURN_ERROR:: SP_SEARCH_3(409) :: cplan.sql(4687) :: :
1CANNOT_SEARCH_ASSIGN:
1411:
1                EXIT:: SP_SEARCH_3(412) :: cplan.sql(4690) :: :
150:
1TRUNC:
1TO_NUMBER:
11.5:
1FC_DECLARE_PMO_TMP_SEARCH:
1TSK_ASSIGNMENT_ID:
1TO_DATE:
1UNRESOLVED_START:
1UNRESOLVED_FINISH:
1BILLABLE:
1CAPITAL_EXPENSE:
1REGULAR_COST:
1REGULAR_RATE:
1TASK_ASSIGNMENTS:
1TASK_ID:
1RESOURCE_ID:
1RESOURCE_TYPE:
1BIT_FLAG:
1SELECT TSK_ASSIGNMENT_ID, TO_DATE(SubStr(UNRESOLVED_START, 1, 10)), TO_DATE(S+
1ubStr(UNRESOLVED_FINISH, 1, 10)), BILLABLE, CAPITAL_EXPENSE,:n            REG+
1ULAR_COST, REGULAR_RATE:n            INTO h_prj_assignment_id, h_SD, h_FD, h_+
1billable, h_capital_expense,:n            h_reg_cost, h_reg_sale:n           +
1 FROM TASK_ASSIGNMENTS:n            WHERE TASK_ID=h_project_id AND RESOURCE_I+
1D=h_res_id AND RESOURCE_TYPE='1' AND BIT_FLAG='0':
1462:
1           EXCEPTION:: SP_SEARCH_3(463) :: cplan.sql(4741) :: :
1PROFILE_NAME:
1PROFILES:
1PROFILE_ID:
1SELECT PROFILE_NAME INTO h_full_name FROM PROFILES WHERE PROFILE_ID = h_res_i+
1d:
1475:
1           EXCEPTION:: SP_SEARCH_3(476) :: cplan.sql(4754) :: :
1482:
1        RETURN_ERROR:: SP_SEARCH_3(483) :: cplan.sql(4761) :: :
1485:
1                EXIT:: SP_SEARCH_3(486) :: cplan.sql(4764) :: :
1RES_ASSIGNMENT_ID:
1PARTICIPANT:
1RESOURCE_ASSIGNMENTS:
1SELECT RES_ASSIGNMENT_ID, PARTICIPANT INTO h_assign_id, h_number:n           +
1 FROM RESOURCE_ASSIGNMENTS:n            WHERE ELEMENT_ID = h_task_id AND RESO+
1URCE_TYPE = '1' AND RESOURCE_ID = h_res_id:
1502:
1           EXCEPTION:: SP_SEARCH_3(503) :: cplan.sql(4781) :: :
1NICK_NAME:
1RESOURCES:
1SELECT NICK_NAME INTO h_full_name FROM RESOURCES WHERE RESOURCE_ID = h_res_id:
1515:
1           EXCEPTION:: SP_SEARCH_3(516) :: cplan.sql(4794) :: :
1522:
1        RETURN_ERROR:: SP_SEARCH_3(523) :: cplan.sql(4801) :: :
1525:
1                EXIT:: SP_SEARCH_3(526) :: cplan.sql(4804) :: :
1SELECT TSK_ASSIGNMENT_ID, TO_DATE(SubStr(UNRESOLVED_START, 1, 10)), TO_DATE(S+
1ubStr(UNRESOLVED_FINISH, 1, 10)), BILLABLE, CAPITAL_EXPENSE,:n            REG+
1ULAR_COST, REGULAR_RATE:n            INTO h_prj_assignment_id, h_SD, h_FD, h_+
1billable, h_capital_expense,:n            h_reg_cost, h_reg_sale:n           +
1 FROM TASK_ASSIGNMENTS:n            WHERE TASK_ID=h_project_id AND RESOURCE_I+
1D=h_res_id AND RESOURCE_TYPE='0' AND BIT_FLAG='0':
1545:
1           EXCEPTION:: SP_SEARCH_3(546) :: cplan.sql(4824) :: :
1SELECT TSK_ASSIGNMENT_ID, TO_DATE(SubStr(UNRESOLVED_START, 1, 10)), TO_DATE(S+
1ubStr(UNRESOLVED_FINISH, 1, 10)), BILLABLE, CAPITAL_EXPENSE,:n               +
1REGULAR_COST, REGULAR_RATE:n               INTO h_prj_assignment_id, h_SD, h_+
1FD, h_billable, h_capital_expense,:n               h_reg_cost, h_reg_sale:n  +
1             FROM TASK_ASSIGNMENTS:n               WHERE TASK_ID=h_project_id+
1 AND RESOURCE_ID=h_res_id AND RESOURCE_TYPE='0' AND BIT_FLAG='2':
1576:
1           EXCEPTION:: SP_SEARCH_3(577) :: cplan.sql(4855) :: :
1SELECT RES_ASSIGNMENT_ID, PARTICIPANT INTO h_assign_id, h_number:n           +
1 FROM RESOURCE_ASSIGNMENTS:n            WHERE ELEMENT_ID = h_task_id AND RESO+
1URCE_TYPE = '0' AND RESOURCE_ID = h_res_id:
1593:
1           EXCEPTION:: SP_SEARCH_3(594) :: cplan.sql(4872) :: :
1599:
1      RETURN_INVALID:: SP_SEARCH_3(600) :: cplan.sql(4878) :: :
1602:
1                EXIT:: SP_SEARCH_3(603) :: cplan.sql(4881) :: :
1GETSECURITYID:
1SC_TEAMMEMBER_GROUP:
1SC_PARTICIPANT_GROUP:
1SECURITY_ID:
1ELEMENT_TYPE:
1SC_AFFECTED:
1SC_TEAMMEMBER:
1BIT_OR:
1UPDATE RESOURCE_ASSIGNMENTS SET PARTICIPANT =:n            CASE:n            +
1WHEN SECURITY_ID = h_temp2_security_id AND ELEMENT_TYPE IN (PMO_CNST.SC_PROJE+
1CT,PMO_CNST.SC_PROPOSAL,PMO_CNST.SC_PROJ_TYPE1,PMO_CNST.SC_PROJ_TYPE2,PMO_CNS+
1T.SC_PROJ_TYPE3) THEN PMO_CNST.SC_AFFECTED:n            WHEN SECURITY_ID = h_+
1temp2_security_id THEN PMO_CNST.SC_TEAMMEMBER:n            WHEN SECURITY_ID =+
1 h_temp_security_id THEN PMO_CNST.SC_AFFECTED:n            ELSE PMO_STPU.BIT_+
1OR( PARTICIPANT, PMO_CNST.SC_TEAMMEMBER):n            END, SECURITY_ID =:n   +
1         CASE:n            WHEN SECURITY_ID = h_temp2_security_id THEN  h_tem+
1p_security_id:n            ELSE SECURITY_ID:n            END:n            WHE+
1RE RES_ASSIGNMENT_ID = h_assign_id:
1FOUND:
1637:
1           EXCEPTION:: SP_SEARCH_3(638) :: cplan.sql(4916) :: :
1FC_AFTER_U_RES_ASSIGN:
1SYS_GUID:
1FC_BEFORE_I_RES_ASSIGN:
1TABLE_TYPE:
1REC_USER:
1REC_DATETIME:
1INSERT INTO RESOURCE_ASSIGNMENTS(RES_ASSIGNMENT_ID, PROJECT_ID, ELEMENT_ID, E+
1LEMENT_TYPE, TABLE_TYPE,:n            RESOURCE_TYPE, RESOURCE_ID, PARTICIPANT+
1, SECURITY_ID, REC_USER, REC_DATETIME):n            VALUES (h_assign_id, h_pr+
1oject_id, h_task_id, h_type, h_table_type,:n            h_res_type, h_res_id,+
1 PMO_CNST.SC_AFFECTED, h_temp_security_id, rec_user001, SYSTIMESTAMP):
1671:
1           EXCEPTION:: SP_SEARCH_3(672) :: cplan.sql(4950) :: :
1TIMEPHASE_PROJECT_ASSIGNMENT:
1SELECT TIMEPHASE_PROJECT_ASSIGNMENT INTO h_pa_timephase FROM PROJECT_DETAILS +
1WHERE PROJECT_ID = h_project_id:
1687:
1           EXCEPTION:: SP_SEARCH_3(688) :: cplan.sql(4966) :: :
1Y:
1-:
1FC_TPHASE_SCHED_ASSIGN:
1SC_SRCH_PROFILE:
1FC_SEARCH_2:
1PMO_TMP_SEARCH:
1PLANNED_SCHED_FLAG:
1RES_ID:
1UPDATE PMO_TMP_SEARCH SET PLANNED_SCHED_FLAG='0' WHERE RES_ID=h_res_id:
1734:
1           EXCEPTION:: SP_SEARCH_3(735) :: cplan.sql(5013) :: :
1LENGTH:
1/:
1WHILE:
1LOOP:
1',':
1BAK_START_DT:
1BAK_FINISH_DT:
1TO_TIMESTAMP:
1SELECT CASE WHEN TO_DATE(SubStr(h_start_date, 1, 10)) BETWEEN TO_DATE(SubStr(+
1BAK_START_DT, 1, 10)) AND TO_DATE(SubStr(BAK_FINISH_DT, 1, 10)):n            +
1      THEN BAK_START_DT + 1      ELSE TO_TIMESTAMP(h_start_date) END:n       +
1           INTO h_start_DT FROM TASK_ASSIGNMENTS:n                  WHERE TAS+
1K_ID=h_project_id AND RESOURCE_ID=h_res_id AND RESOURCE_TYPE='1':
1792:
1           EXCEPTION:: SP_SEARCH_3(793) :: cplan.sql(5071) :: :
1SELECT CASE WHEN TO_DATE(SubStr(h_start_date, 1, 10)) BETWEEN TO_DATE(SubStr(+
1BAK_START_DT, 1, 10)) AND TO_DATE(SubStr(BAK_FINISH_DT, 1, 10)):n            +
1      THEN BAK_START_DT + 1      ELSE TO_TIMESTAMP(h_start_date) END:n       +
1           INTO h_start_DT FROM TASK_ASSIGNMENTS:n                  WHERE TAS+
1K_ID=h_project_id AND RESOURCE_ID=h_res_id AND RESOURCE_TYPE='0' AND BIT_FLAG+
1='0':
1812:
1           EXCEPTION:: SP_SEARCH_3(813) :: cplan.sql(5091) :: :
1SELECT CASE WHEN TO_DATE(SubStr(h_start_date, 1, 10)) BETWEEN TO_DATE(SubStr(+
1BAK_START_DT, 1, 10)) AND TO_DATE(SubStr(BAK_FINISH_DT, 1, 10)):n            +
1         THEN BAK_START_DT + 1      ELSE TO_TIMESTAMP(h_start_date) END:n    +
1                 INTO h_start_DT FROM TASK_ASSIGNMENTS:n                     +
1WHERE TASK_ID=h_project_id AND RESOURCE_ID=h_res_id AND RESOURCE_TYPE='0' AND+
1 BIT_FLAG='2':
1829:
1           EXCEPTION:: SP_SEARCH_3(830) :: cplan.sql(5108) :: :
1867:
1           EXCEPTION:: SP_SEARCH_3(868) :: cplan.sql(5146) :: :
1881:
1        RETURN_ERROR:: SP_SEARCH_3(882) :: cplan.sql(5160) :: :
1CANNOT_ASSIGN_FROM_PROJECT_AFF:
1884:
1                EXIT:: SP_SEARCH_3(885) :: cplan.sql(5163) :: :
1SELECT t.RESOURCE_ID AS ELEMENT_ID, t.RES_ASSIGNMENT_ID, p.FULL_NAME AS ELEME+
1NT_NAME, 13 AS TYPE_ID, :
1p.E_MAIL_ADDRESS,b.PLANNED_START,b.PLANNED_FINISH,b.BEST AS PLANNED_EFFORT, :
1a.SCHED_START AS START_DATE, a.SCHED_FINISH AS FINISH_DATE, a.BEST AS WORK, a+
1.SCHED_WORK AS REMAINING, :
1rs.START_DATE AS BEST_START, rs.FINISH_DATE AS BEST_FINISH, rs.ASSIGNABLE AS +
1CALENDAR,rs.PLANNED AS PLANNED_WORK,:
1rs.SCHED AS SCHED_WORK, :
1 AS WORK_EFFORT, :
1 AS UNIT_EFFORT,(rs.ASSIGNABLE - rs.PLANNED - rs.SCHED) AS PERIOD_AVAILABILIT+
1Y,:
1 AS MINUTE_PER_DAY, rs.CONTOUR AS ASSIGN_STRING, rs.PLANNED_SCHED_FLAG, '' AS+
1 OBJECTIVES,'' AS RANK :
1FROM RESOURCE_ASSIGNMENTS t LEFT JOIN TASK_ASSIGNMENTS a ON a.RES_ASSIGNMENT_+
1ID=t.RES_ASSIGNMENT_ID AND a.BIT_FLAG='2' :
1LEFT JOIN TASK_ASSIGNMENTS b ON b.RES_ASSIGNMENT_ID=t.RES_ASSIGNMENT_ID AND b+
1.BIT_FLAG='0' :
1JOIN RESOURCES p ON t.RESOURCE_ID=p.RESOURCE_ID :
1LEFT OUTER JOIN PMO_TMP_SEARCH rs ON t.RESOURCE_ID=rs.RES_ID :
1WHERE t.ELEMENT_ID=':
1' AND t.RESOURCE_TYPE='0' AND t.RESOURCE_ID IN (':
1') AND BITAND(t.PARTICIPANT, 4112) > 0 :
1UNION ALL :
1SELECT r.PROFILE_ID AS ELEMENT_ID, ta.RES_ASSIGNMENT_ID, r.PROFILE_NAME AS EL+
1EMENT_NAME, 41 AS TYPE_ID, :
1'' AS E_MAIL_ADDRESS,ta.PLANNED_START,ta.PLANNED_FINISH,ta.BEST AS PLANNED_EF+
1FORT,:
1STR_1899_12_31_00_00_00:
1 AS START_DATE, :
1 AS FINISH_DATE, 0 AS WORK, 0 AS REMAINING, :
1rs.START_DATE AS BEST_START, rs.FINISH_DATE AS BEST_FINISH, rs.ASSIGNABLE AS +
1CALENDAR, :
1rs.PLANNED AS PLANNED_WORK,rs.SCHED AS SCHED_WORK, :
1 AS UNIT_EFFORT,:
1(rs.ASSIGNABLE - rs.PLANNED - rs.SCHED) AS PERIOD_AVAILABILITY, :
1 AS MINUTE_PER_DAY , rs.CONTOUR AS ASSIGN_STRING, rs.PLANNED_SCHED_FLAG, '' A+
1S OBJECTIVES,'' AS RANK :
1FROM TASK_ASSIGNMENTS ta JOIN PROFILES r ON ta.TASK_ID=':
1' AND ta.RESOURCE_TYPE='1' AND ta.RESOURCE_ID IN (':
1') AND r.PROFILE_ID=ta.RESOURCE_ID :
1LEFT OUTER JOIN PMO_TMP_SEARCH rs ON ta.RESOURCE_ID=rs.RES_ID :
1ORDER BY TYPE_ID:
1970:
1                EXIT:: SP_SEARCH_3(971) :: cplan.sql(5249) :: :
1973:
1                EXIT:: SP_SEARCH_3(974) :: cplan.sql(5252) :: :
1PMO_SELECT_READ:
1RETURN_ERROR_EXCEPTION:
1981:
1           EXCEPTION:: SP_SEARCH_3(982) :: cplan.sql(5260) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1ID:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
1993:
1           EXCEPTION:: SP_SEARCH_3(994) :: cplan.sql(5272) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
19b9
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 1c 81 b0 a3
a0 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 81
b0 a3 :2 a0 6b 1c 81 b0 :2 a0
6b :2 a0 6b 6e a5 b a 10
:2 a0 6b 6e :2 a0 6b 6e a5 b
6e 7e a0 b4 2e 6e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :3 a0
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e :3 a0 a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e :3 a0 a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e :3 a0 a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
:3 a0 a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e :3 a0 a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e :3 a0 a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e :3 a0
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e :3 a0 a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 d :2 a0 d :2 a0 d :2 a0 d
:2 a0 d :2 a0 d :2 a0 d :2 a0 d
:2 a0 d :2 a0 d :2 a0 d :2 a0 d
:2 a0 d :2 a0 d :2 a0 d :4 a0 51
a5 b a5 b d a0 51 d
a0 51 d a0 7e b4 2e 5a
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b a0 a5 57 b7
19 3c :2 a0 51 a5 b 7e 51
b4 2e :2 a0 51 a5 b 7e 51
b4 2e a 10 :2 a0 51 a5 b
7e 51 b4 2e a 10 :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b a0 a5 57 b7 19 3c
:2 a0 51 a5 b a0 7e a0 6b
b4 2e 5a a0 7e b4 2e :2 5a
a 10 a0 7e b4 2e :2 5a a
10 :8 a0 12a :2 a0 6b a0 d b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 6b a0 7e
a0 6b b4 2e 5a :2 a0 51 a5
b 7e 51 b4 2e 5a a 10
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b a0 a5 57 b7
19 3c a0 51 d a0 b7 a0
7e b4 2e :2 5a a0 7e b4 2e
:2 5a a 10 :3 a0 12a :2 a0 6b a0
d b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 :2 19
3c :2 a0 d :3 a0 6b :3 a0 51 a5
b :2 a0 6b a5 b 5a 51 a5
b d :4 a0 51 a5 b :2 a0 6b
a5 b 5a d :2 a0 51 a5 b
7e 51 b4 2e :b a0 12a :2 a0 6b
a0 d b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
6b a0 7e a0 6b b4 2e 5a
:6 a0 12a :2 a0 6b a0 d b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 6b a0 7e a0
6b b4 2e 5a :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :4 a0 6b a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
:2 a0 a5 57 b7 19 3c b7 19
3c a0 51 d :5 a0 12a :2 a0 6b
a0 d b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
51 a5 b 7e 51 b4 2e :5 a0
12a :2 a0 6b a0 d b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 6b a0 6e a5 b
7e 51 b4 2e :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :4 a0 6b a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
:2 a0 a5 57 b7 19 3c b7 19
3c b7 a0 7e b4 2e 5a :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b a0 a5 57 b7 19
3c :2 a0 d :4 a0 :2 51 a5 b :2 51
a5 b d :3 a0 6b :3 51 a0 a5
b d :3 a0 51 a5 b a5 b
7e 51 b4 2e :18 a0 12a :2 a0 6b
a0 d b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
6b a0 7e a0 6b b4 2e 5a
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b :2 a0 a5 57 b7
19 3c b7 :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b :2 a0
a5 57 b7 :2 19 3c b7 :2 19 3c
:2 a0 51 a5 b 7e 51 b4 2e
5a :2 a0 51 a5 b 7e 51 b4
2e 5a a 10 a0 51 d b7
19 3c a0 7e 51 b4 2e :2 a0
d a0 6e d :6 a0 51 a5 b
:2 a0 51 a5 b :2 a0 51 a5 b
:2 a0 51 a5 b :2 a0 51 a5 b
:2 a0 51 a5 b :2 a0 51 a5 b
:2 a0 51 a5 b :3 a0 a5 b d
:2 a0 51 a5 b a0 7e a0 6b
b4 2e :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b a0 a5
57 a0 b7 :2 a0 51 a5 b 7e
51 b4 2e :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :3 a0 a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 51 a5 b
:2 a0 a5 57 b7 :2 19 3c b7 19
3c :2 a0 51 a5 b 7e 51 b4
2e 5a :2 a0 51 a5 b 7e 51
b4 2e 5a a 10 :2 a0 51 a5
b 7e 51 b4 2e 5a :2 a0 51
a5 b 7e 51 b4 2e 5a 52
10 a0 51 d a0 b7 :2 a0 51
a5 b 7e 51 b4 2e a0 51
d a0 b7 19 :2 a0 51 a5 b
7e 51 b4 2e 5a :2 a0 51 a5
b 7e 51 b4 2e 5a 52 10
a0 51 d a0 b7 19 :2 a0 51
a5 b 7e 51 b4 2e :3 a0 51
a5 b 7e :2 a0 51 a5 b b4
2e d a0 51 d b7 :2 19 3c
b7 19 3c :2 a0 51 a5 b 7e
51 b4 2e :2 a0 51 a5 b 7e
51 b4 2e :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b :2 a0
a5 57 b7 19 3c :2 a0 51 a5
b 7e 51 b4 2e a0 51 d
b7 :5 a0 51 a5 b a5 b 7e
51 b4 2e a5 b d b7 :2 19
3c b7 19 3c :2 a0 b4 2e d
a0 6e d a0 6e d a0 6e
d a0 6e d :3 a0 :2 51 a5 b
d :3 a0 :2 51 a5 b d :2 a0 51
a5 b 7e 51 b4 2e a0 4d
d :2 a0 d :2 a0 :2 51 a5 b 7e
6e b4 2e :19 a0 12a :2 a0 6b a0
d b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :5 a0 12a
:2 a0 6b a0 d b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6b a0 7e a0 6b b4
2e 5a :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b :2 a0 a5
57 b7 19 3c :2 a0 d :a a0 12a
:2 a0 6b a0 d b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f a0 b7 :2 a0 :2 51 a5 b 7e
6e b4 2e :5 a0 12a :2 a0 6b a0
d b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
a0 7e a0 6b b4 2e 5a :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b :2 a0 a5 57 b7 19
3c :2 a0 d :19 a0 12a :2 a0 6b a0
d b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
a0 7e a0 6b b4 2e 5a :19 a0
12a :2 a0 6b a0 d b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 19 3c :a a0 12a :2 a0
6b a0 d b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 19 :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b a0 a5
57 b7 :2 19 3c :2 a0 6b a0 7e
a0 6b b4 2e 5a :2 a0 51 :2 a0
51 a5 b :2 a0 6b a0 a5 b
d :2 a0 51 :2 a0 51 a5 b :2 a0
6b a0 a5 b d :25 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :3 a0 a5
b d b7 :2 a0 b4 2e d :2 a0
51 :2 a0 51 a5 b :2 a0 6b a0
a5 b d :3 a0 6b d a0 51
d :9 a0 a5 b d :18 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 :2 19
3c :2 a0 51 a5 b 7e 51 b4
2e 5a a0 7e b4 2e :2 5a a
10 :5 a0 12a :2 a0 6b a0 d b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 :2 51 a5 b
7e 6e b4 2e a0 7e 51 b4
2e d :2 a0 6b :b a0 a5 b d
b7 19 3c b7 19 3c :2 a0 d
:2 a0 :2 51 a5 b 7e 6e b4 2e
:3 a0 6b d b7 :3 a0 51 a5 b
d b7 :2 19 3c :1e a0 :4 51 a5 b
d a0 7e 51 b4 2e :4 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
19 3c b7 a0 6e d a0 6e
d :2 a0 d :3 a0 a5 b 51 a5
b 7e 51 b4 2e a0 51 d
b7 :5 a0 a5 b 51 a5 b 7e
51 b4 2e 5a 7e 51 b4 2e
a5 b d b7 :2 19 3c a0 7e
51 b4 2e a0 51 d :3 a0 51
a5 b a0 7e a0 b4 2e 82
:3 a0 6b :2 51 :2 a0 51 a5 b 7e
51 b4 2e 7e 51 b4 2e a0
a5 b d :3 a0 6b :2 51 :2 a0 51
a5 b 7e 51 b4 2e 7e 51
b4 2e 7e 51 b4 2e a0 a5
b d :2 a0 :2 51 a5 b 7e 6e
b4 2e :3 a0 6b d :3 a0 a5 b
51 a5 b 7e 51 b4 2e :2 a0
d b7 :3 a0 7e 6e b4 2e :2 51
a5 b d :3 a0 7e a0 b4 2e
:2 51 a5 b d b7 :2 19 3c b7
:3 a0 51 a5 b d :3 a0 a5 b
51 a5 b 7e 51 b4 2e :2 a0
d b7 :3 a0 7e 6e b4 2e :2 51
a5 b d :3 a0 7e a0 b4 2e
:2 51 a5 b d b7 :2 19 3c b7
:2 19 3c :2 a0 :2 51 a5 b 7e 6e
b4 2e :13 a0 12a :2 a0 6b a0 d
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f a0 51 d
a0 51 d b7 :14 a0 12a :2 a0 6b
a0 d b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
6b a0 7e a0 6b b4 2e 5a
:14 a0 12a :2 a0 6b a0 d b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 19 3c b7 :2 19
3c :2 a0 d :2 a0 :2 51 a5 b 7e
6e b4 2e :3 a0 6b d b7 :3 a0
51 a5 b d b7 :2 19 3c :2 a0
d :1e a0 :4 51 a5 b d a0 7e
51 b4 2e :4 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 19 3c :3 a0
51 a5 b 7e 51 b4 2e d
b7 a0 47 b7 19 3c b7 :2 19
3c a0 7e 51 b4 2e 5a :2 a0
51 a5 b 7e 51 b4 2e 5a
a 10 :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b :2 a0 a5
57 b7 19 3c :2 a0 51 a5 b
7e 51 b4 2e :2 a0 d b7 19
3c :3 a0 a5 b 51 a5 b 7e
51 b4 2e 5a :3 a0 a5 b 51
a5 b 7e 51 b4 2e 5a a
10 a0 6e 7e 6e b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :3 a0 51 a5 b
a5 b b4 2e 7e 6e b4 2e
7e :3 a0 51 a5 b a5 b b4
2e 7e 6e b4 2e 7e :3 a0 51
a5 b a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :2 a0 6b b4 2e 7e
6e b4 2e 7e :2 a0 6b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :3 a0 51 a5
b a5 b b4 2e 7e 6e b4
2e 7e :3 a0 51 a5 b a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :3 a0 51 a5 b a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
6e b4 2e d a0 b7 :3 a0 a5
b 51 a5 b 7e 51 b4 2e
a0 6e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :3 a0 51 a5 b a5
b b4 2e 7e 6e b4 2e 7e
:3 a0 51 a5 b a5 b b4 2e
7e 6e b4 2e 7e :3 a0 51 a5
b a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e d a0 b7 19 :3 a0 a5 b
51 a5 b 7e 51 b4 2e a0
6e 7e 6e b4 2e 7e :2 a0 6b
b4 2e 7e 6e b4 2e 7e :2 a0
6b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:3 a0 51 a5 b a5 b b4 2e
7e 6e b4 2e 7e :3 a0 51 a5
b a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :3 a0 51
a5 b a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e d b7
:2 19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:3 a0 6b a0 a5 b 65 b7 :2 a0
6b :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 :2 a0 6b :2 6e 7e :2 a0 6b b4
2e 7e 6e b4 2e 7e :2 a0 6b
b4 2e a5 57 b7 19 3c :9 a0
12a e9 dd :2 a0 65 b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c :7 a0 12a e9
dd :2 a0 65 b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 68 4f
1d 17 b5 
19b9
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 5e
5a 30 66 6f 6b 59 77 84
80 56 8c 95 91 7f 9d aa
a6 7c b2 bb b7 a5 c3 d0
cc a2 d8 e1 dd cb e9 f6
f2 c8 fe 107 103 f1 10f 11c
118 ee 124 12d 129 117 135 114
13a 13e 142 146 149 14d 16a 155
159 15c 15d 165 154 187 175 151
179 17a 182 174 1a4 192 171 196
197 19f 191 1c1 1af 18e 1b3 1b4
1bc 1ae 1de 1cc 1ab 1d0 1d1 1d9
1cb 1fb 1e9 1c8 1ed 1ee 1f6 1e8
218 206 1e5 20a 20b 213 205 234
223 227 22f 202 250 23b 23f 242
243 24b 222 26d 25b 21f 25f 260
268 25a 28a 278 257 27c 27d 285
277 2a7 295 274 299 29a 2a2 294
2c4 2b2 291 2b6 2b7 2bf 2b1 2e1
2cf 2ae 2d3 2d4 2dc 2ce 2fe 2ec
2cb 2f0 2f1 2f9 2eb 31b 309 2e8
30d 30e 316 308 337 326 32a 332
305 34f 33e 342 34a 325 36c 35a
322 35e 35f 367 359 388 377 37b
356 383 376 3a4 393 397 373 39f
392 3c0 3af 3b3 38f 3bb 3ae 3dc
3cb 3cf 3ab 3d7 3ca 3f8 3e7 3eb
3c7 3f3 3e6 414 403 407 3e3 40f
402 430 41f 423 3ff 42b 41e 44c
43b 43f 41b 447 43a 468 457 45b
437 463 456 484 473 477 453 47f
472 4a0 48f 493 46f 49b 48e 4bc
4ab 4af 48b 4b7 4aa 4d8 4c7 4cb
4a7 4d3 4c6 4f4 4e3 4e7 4c3 4ef
4e2 510 4ff 503 4df 50b 4fe 52c
51b 51f 4fb 527 51a 548 537 53b
517 543 536 564 553 557 533 55f
552 580 56f 573 54f 57b 56e 59c
58b 58f 56b 597 58a 5b8 5a7 5ab
587 5b3 5a6 5d4 5c3 5c7 5a3 5cf
5c2 5f0 5df 5e3 5bf 5eb 5de 60c
5fb 5ff 5db 607 5fa 628 617 61b
5f7 623 616 644 633 637 613 63f
632 660 64f 653 62f 65b 64e 67c
66b 66f 64b 677 66a 698 687 68b
667 693 686 6b4 6a3 6a7 683 6af
6a2 6d1 6bf 69f 6c3 6c4 6cc 6be
6ee 6dc 6bb 6e0 6e1 6e9 6db 70a
6f9 6fd 6d8 705 6f8 726 715 719
6f5 721 714 743 731 711 735 736
73e 730 75f 74e 752 72d 75a 74d
77b 76a 76e 74a 776 769 797 786
78a 766 792 785 7b3 7a2 7a6 782
7ae 7a1 7cf 7be 7c2 79e 7ca 7bd
7eb 7da 7de 7ba 7e6 7d9 807 7f6
7fa 802 7d6 826 80e 812 816 819
821 7f5 82d 831 7f2 835 839 83d
840 845 846 1 848 84d 851 855
858 85d 861 865 868 86d 86e 870
875 878 87c 87d 882 887 88a 88f
890 895 898 89c 89d 8a2 8a5 8aa
8ab 8b0 8b3 8b8 8b9 8be 8c1 8c6
8c7 8cc 8cf 8d3 8d4 8d9 8dc 8e1
8e2 8e7 8ea 8ef 8f0 8f5 8f8 8fd
8fe 903 906 90a 90b 910 913 918
919 91e 921 926 927 92c 92f 933
937 93b 93c 93e 943 944 946 947
94c 94f 954 955 95a 95d 961 965
969 96a 96c 971 972 974 975 97a
97d 982 983 988 98b 98f 993 997
998 99a 99f 9a0 9a2 9a3 9a8 9ab
9b0 9b1 9b6 9b9 9bd 9c1 9c5 9c6
9c8 9cd 9ce 9d0 9d1 9d6 9d9 9de
9df 9e4 9e7 9eb 9ef 9f3 9f4 9f6
9fb 9fc 9fe 9ff a04 a07 a0c a0d
a12 a15 a19 a1d a21 a22 a24 a29
a2a a2c a2d a32 a35 a3a a3b a40
a43 a47 a4b a4f a50 a52 a57 a58
a5a a5b a60 a63 a68 a69 a6e a71
a75 a79 a7d a7e a80 a85 a86 a88
a89 a8e a91 a96 a97 a9c a9f aa3
aa7 aab aac aae ab3 ab4 ab6 ab7
abc abf ac4 ac5 aca acd ad1 ad5
ad9 ada adc ae1 ae2 ae4 ae5 aea
aed af2 af3 af8 afb b00 b01 b06
b09 b0d b0e b13 b16 b1b b1c b21
b24 b29 b2a b2f b32 b37 b38 b3d
b40 b44 b45 b4a b4d b52 b53 b58
b5b b60 b61 b66 b67 b6c b6e b72
b75 b79 b7d b80 b84 b88 b8b b8e
b93 b96 b99 b9c b9d ba2 ba3 1
ba5 baa bae bb2 bb5 bba bbf bc2
bc6 bc7 bcc bcd bd2 bd4 bd8 bdb
bdf be3 be7 beb bef bf3 bf7 bfb
bff c03 c07 c0b c0f c13 c17 c1b
c1f c23 c27 c2b c2f c33 c37 c3b
c3f c43 c47 c4b c4f c53 c57 c5b
c5f c63 c67 c6b c6f c73 c77 c7b
c7f c83 c87 c8b c8f c93 c97 c9b
c9f ca2 ca3 ca5 ca6 ca8 cac cb0
cb3 cb7 cbb cbe cc2 cc6 cc9 cca
ccf cd2 cd6 cda cdd ce1 ce5 ce8
ceb cf0 cf3 cf6 cf9 cfa cff d00
1 d02 d07 d0b d0f d12 d17 d1c
d1f d23 d24 d29 d2c d31 d32 d37
d3a d3f d40 d45 d48 d4c d50 d54
d58 d5b d5c d5e d63 d64 d66 d67
d6c d6d d72 d74 d78 d7b d7f d83
d86 d8a d8e d91 d94 d99 d9c d9f
da2 da3 da8 da9 1 dab db0 db4
db8 dbb dc0 dc5 dc8 dcc dcd dd2
dd3 dd8 dda dde de1 de5 de9 dec
df0 df4 df7 dfb dfc e01 e03 e07
e0a e0e e12 e15 e16 e18 e1b e1e
e1f e24 e28 e2c e2f e30 e32 e35
e38 e39 1 e3e e43 e47 e4b e4e
e4f e51 e54 e57 e58 1 e5d e62
e66 e6a e6d e71 e75 e78 e7b e80
e83 e86 e89 e8a e8f e90 1 e92
e97 e9b e9f ea2 ea7 eac eaf eb3
eb4 eb9 ebc ec1 ec2 ec7 eca ecf
ed0 ed5 ed8 edc ee0 ee4 ee8 eeb
eec eee ef3 ef4 ef6 ef7 efc efd
f02 f04 f08 f0b f0f f13 f16 f1a
f1e f21 f24 f29 f2c f2f f32 f33
f38 f39 1 f3b f40 f44 f48 f4b
f50 f55 f58 f5c f5d f62 f63 f68
f6a f6e f71 f75 f79 f7c f80 f84
f87 f8b f8c f91 f93 f97 f9a f9e
fa2 fa5 fa6 fa8 fac faf fb3 fb6
fb7 fbc fbf fc3 fc6 fc7 fcc fcf
1 fd2 fd7 fdb fde fdf fe4 fe7
1 fea fef ff3 ff7 ffb fff 1003
1007 100b 100f 101b 101f 1023 1026 102a
102e 1030 1 1034 1038 103c 103f 1043
1047 104b 104f 1052 1056 105a 105d 1060
1065 1068 106b 106e 106f 1074 1075 1
1077 107c 1080 1084 1087 108c 1091 1094
1098 1099 109e 10a1 10a6 10a7 10ac 10af
10b4 10b5 10ba 10bd 10c1 10c2 10c7 10ca
10cf 10d0 10d5 10d8 10dc 10e0 10e3 10e6
10e7 10e9 10ea 10ef 10f0 10f5 10f7 10fb
10fe 1100 1104 1106 1112 1114 1116 1117
111c 1120 1122 112e 1130 1134 1138 113b
113f 1142 1146 1149 114a 114f 1152 1156
115a 115d 115e 1160 1163 1166 1167 116c
1 116f 1174 1178 117c 117f 1183 1187
118a 118d 1192 1195 1198 119b 119c 11a1
11a2 1 11a4 11a9 11ad 11b1 11b4 11b9
11be 11c1 11c5 11c6 11cb 11ce 11d3 11d4
11d9 11dc 11e1 11e2 11e7 11ea 11ee 11f2
11f6 11fa 11fd 11fe 1200 1205 1206 1208
1209 120e 120f 1214 1216 121a 121d 1221
1225 1228 122c 1230 1233 1236 123b 123e
1241 1244 1245 124a 124b 1 124d 1252
1256 125a 125d 1262 1267 126a 126e 126f
1274 1275 127a 127c 1280 1283 1287 128b
128e 1292 1296 1299 129d 129e 12a3 12a5
12a9 12ac 12b0 12b3 12b7 12bb 12bd 12c1
12c4 12c5 12ca 12cd 12d0 12d4 12d7 12d8
12dd 12e0 1 12e3 12e8 12ec 12f0 12f4
1300 1304 1308 130b 130f 1313 1315 1
1319 131d 1321 1324 1328 132c 1330 1334
1337 133b 133f 1342 1345 134a 134d 1350
1353 1354 1359 135a 1 135c 1361 1365
1369 136c 1371 1376 1379 137d 137e 1383
1386 138b 138c 1391 1394 1399 139a 139f
13a2 13a6 13a7 13ac 13af 13b4 13b5 13ba
13bd 13c1 13c5 13c8 13cb 13cc 13ce 13cf
13d4 13d5 13da 13dc 13e0 13e3 13e5 13e9
13eb 13f7 13f9 13fb 13fc 1401 1405 1407
1413 1415 1417 141b 141f 1422 1426 142a
142e 1432 1436 143a 143d 1441 1445 1449
144c 144d 144f 1453 1457 145a 145b 145d
1460 1463 1464 1466 146a 146e 1472 1476
147a 147d 147e 1480 1484 1488 148b 148c
148e 1491 1495 1499 149d 14a0 14a1 14a3
14a6 14a9 14aa 14af 14b3 14b7 14bb 14bf
14c3 14c7 14cb 14cf 14d3 14d7 14db 14e7
14eb 14ef 14f2 14f6 14fa 14fc 1 1500
1504 1508 150b 150f 1513 1517 151b 151e
1522 1526 1529 152c 1531 1534 1537 153a
153b 1540 1541 1 1543 1548 154c 1550
1553 1558 155d 1560 1564 1565 156a 156d
1572 1573 1578 157b 1580 1581 1586 1589
158d 158e 1593 1596 159b 159c 15a1 15a4
15a8 15ac 15af 15b2 15b3 15b5 15b6 15bb
15bc 15c1 15c3 15c7 15ca 15cc 15d0 15d2
15de 15e0 15e2 15e3 15e8 15ec 15ee 15fa
15fc 1600 1604 1607 160b 160e 1612 1615
1616 161b 161e 1622 1626 162a 162e 1632
1636 1642 1646 164a 164d 1651 1655 1657
1 165b 165f 1663 1666 166a 166e 1672
1676 1679 167d 1681 1684 1687 168c 168f
1692 1695 1696 169b 169c 1 169e 16a3
16a7 16ab 16ae 16b3 16b8 16bb 16bf 16c0
16c5 16c8 16cd 16ce 16d3 16d6 16db 16dc
16e1 16e4 16e8 16e9 16ee 16f1 16f6 16f7
16fc 16ff 1703 1707 170a 170d 170e 1710
1711 1716 1717 171c 171e 1722 1725 1727
172b 172d 1739 173b 173d 173e 1743 1747
1749 1755 1757 175b 175f 1762 1766 1769
176d 1770 1771 1776 1779 177d 1781 1784
1788 178c 178f 1792 1797 179a 179d 17a0
17a1 17a6 17a7 1 17a9 17ae 17b2 17b6
17b9 17be 17c3 17c6 17ca 17cb 17d0 17d3
17d8 17d9 17de 17e1 17e6 17e7 17ec 17ef
17f3 17f7 17fb 17ff 1802 1803 1805 180a
180b 180d 180e 1813 1816 181b 181c 1821
1824 1829 182a 182f 1832 1836 1837 183c
183f 1844 1845 184a 184b 1850 1852 1856
1859 185d 1861 1864 1868 186c 186f 1872
1877 187a 187d 1880 1881 1886 1887 1
1889 188e 1892 1896 1899 189e 18a3 18a6
18aa 18ab 18b0 18b1 18b6 18b8 18bc 18bf
18c3 18c7 18ca 18ce 18d2 18d5 18d9 18dd
18de 18e3 18e5 18e9 18ec 18ee 18f2 18f5
18f9 18fc 1900 1904 1908 190c 1910 1914
1920 1924 1928 192b 192f 1933 1935 1
1939 193d 1941 1944 1948 194c 1950 1954
1957 195b 195f 1962 1965 196a 196d 1970
1973 1974 1979 197a 1 197c 1981 1985
1989 198c 1991 1996 1999 199d 199e 19a3
19a6 19ab 19ac 19b1 19b4 19b9 19ba 19bf
19c2 19c6 19c7 19cc 19cf 19d4 19d5 19da
19dd 19e1 19e5 19e8 19eb 19ec 19ee 19ef
19f4 19f5 19fa 19fc 1a00 1a03 1a05 1a09
1a0b 1a17 1a19 1a1b 1a1c 1a21 1a25 1a27
1a33 1a35 1a39 1a3d 1a40 1a41 1a43 1a46
1a49 1a4a 1a4f 1a53 1a57 1a5b 1a5f 1a63
1a6f 1a73 1a77 1a7a 1a7e 1a82 1a84 1
1a88 1a8c 1a90 1a93 1a97 1a9b 1a9f 1aa3
1aa6 1aaa 1aae 1ab1 1ab4 1ab9 1abc 1abf
1ac2 1ac3 1ac8 1ac9 1 1acb 1ad0 1ad4
1ad8 1adb 1ae0 1ae5 1ae8 1aec 1aed 1af2
1af5 1afa 1afb 1b00 1b03 1b08 1b09 1b0e
1b11 1b15 1b16 1b1b 1b1e 1b23 1b24 1b29
1b2c 1b30 1b34 1b37 1b3a 1b3b 1b3d 1b3e
1b43 1b44 1b49 1b4b 1b4f 1b52 1b54 1b58
1b5a 1b66 1b68 1b6a 1b6b 1b70 1b74 1b76
1b82 1b84 1b88 1b8c 1b8f 1b93 1b98 1b99
1b9b 1b9e 1ba1 1ba2 1ba7 1bab 1baf 1bb2
1bb6 1bba 1bbd 1bc0 1bc5 1bc8 1bcb 1bce
1bcf 1bd4 1bd5 1 1bd7 1bdc 1be0 1be4
1be7 1bec 1bf1 1bf4 1bf8 1bf9 1bfe 1c01
1c06 1c07 1c0c 1c0f 1c14 1c15 1c1a 1c1d
1c21 1c25 1c29 1c2d 1c30 1c31 1c33 1c38
1c39 1c3b 1c3c 1c41 1c44 1c49 1c4a 1c4f
1c52 1c57 1c58 1c5d 1c60 1c64 1c65 1c6a
1c6d 1c72 1c73 1c78 1c79 1c7e 1c80 1c84
1c87 1c8b 1c8f 1c92 1c96 1c9a 1c9d 1ca0
1ca5 1ca8 1cab 1cae 1caf 1cb4 1cb5 1
1cb7 1cbc 1cc0 1cc4 1cc7 1ccc 1cd1 1cd4
1cd8 1cd9 1cde 1cdf 1ce4 1ce6 1cea 1ced
1cf1 1cf5 1cf8 1cfc 1d00 1d03 1d07 1d0b
1d0c 1d11 1d13 1d17 1d1a 1d1c 1d20 1d23
1d25 1d29 1d2c 1d2d 1d32 1d35 1d39 1d3d
1d40 1d44 1d48 1d4b 1d4e 1d53 1d56 1d59
1d5c 1d5d 1d62 1d63 1 1d65 1d6a 1d6e
1d72 1d75 1d7a 1d7f 1d82 1d86 1d87 1d8c
1d8f 1d94 1d95 1d9a 1d9d 1da2 1da3 1da8
1dab 1daf 1db3 1db7 1dbb 1dbe 1dbf 1dc1
1dc6 1dc7 1dc9 1dca 1dcf 1dd0 1dd5 1dd7
1ddb 1dde 1de2 1de6 1de9 1ded 1df1 1df4
1df7 1dfc 1dff 1e02 1e05 1e06 1e0b 1e0c
1 1e0e 1e13 1e17 1e1b 1e1e 1e23 1e28
1e2b 1e2f 1e30 1e35 1e36 1e3b 1e3d 1e41
1e44 1e48 1e4c 1e4f 1e53 1e57 1e5a 1e5e
1e5f 1e64 1e66 1e6a 1e6d 1e71 1e75 1e79
1e7d 1e81 1e85 1e89 1e8c 1e8f 1e90 1e92
1e95 1e98 1e99 1e9b 1e9f 1ea3 1ea7 1eab
1eae 1eb1 1eb4 1eb7 1ebb 1ebc 1ebe 1ec2
1ec6 1eca 1ece 1ed1 1ed2 1ed4 1ed5 1ed7
1eda 1edd 1ede 1ee3 1ee7 1eeb 1eef 1ef3
1ef7 1efb 1eff 1f03 1f07 1f0b 1f0f 1f13
1f17 1f1b 1f1f 1f23 1f27 1f2b 1f2f 1f33
1f37 1f3b 1f3f 1f43 1f4f 1f53 1f57 1f5a
1f5e 1f62 1f64 1 1f68 1f6c 1f70 1f73
1f77 1f7b 1f7f 1f83 1f86 1f8a 1f8e 1f91
1f94 1f99 1f9c 1f9f 1fa2 1fa3 1fa8 1fa9
1 1fab 1fb0 1fb4 1fb8 1fbb 1fc0 1fc5
1fc8 1fcc 1fcd 1fd2 1fd5 1fda 1fdb 1fe0
1fe3 1fe8 1fe9 1fee 1ff1 1ff5 1ff6 1ffb
1ffe 2003 2004 2009 200c 2010 2014 2017
201a 201b 201d 201e 2023 2024 2029 202b
202f 2032 2034 2038 203a 2046 2048 204a
204b 2050 2054 2056 2062 2064 2068 206c
206f 2073 2076 207a 207d 207e 2083 2086
208a 208e 2091 2095 2099 209c 209f 20a4
20a7 20aa 20ad 20ae 20b3 20b4 1 20b6
20bb 20bf 20c3 20c6 20cb 20d0 20d3 20d7
20d8 20dd 20e0 20e5 20e6 20eb 20ee 20f3
20f4 20f9 20fc 2100 2104 2108 210c 210f
2110 2112 2117 2118 211a 211b 2120 2123
2128 2129 212e 2131 2136 2137 213c 213f
2143 2144 2149 214c 2151 2152 2157 2158
215d 215f 2163 2166 216a 216e 2171 2175
2179 217c 217f 2184 2187 218a 218d 218e
2193 2194 1 2196 219b 219f 21a3 21a6
21ab 21b0 21b3 21b7 21b8 21bd 21be 21c3
21c5 21c9 21cc 21d0 21d4 21d7 21db 21df
21e2 21e6 21ea 21eb 21f0 21f2 21f6 21f9
21fb 21ff 2203 2206 220a 220e 2211 2214
2219 221c 221f 2222 2223 2228 2229 1
222b 2230 2234 2238 223b 2240 2245 2248
224c 224d 2252 2255 225a 225b 2260 2263
2268 2269 226e 2271 2275 2279 227d 2281
2284 2285 2287 228c 228d 228f 2290 2295
2298 229d 229e 22a3 22a6 22ab 22ac 22b1
22b4 22b8 22b9 22be 22c1 22c6 22c7 22cc
22cd 22d2 22d4 22d8 22db 22df 22e3 22e6
22ea 22ee 22f1 22f4 22f9 22fc 22ff 2302
2303 2308 2309 1 230b 2310 2314 2318
231b 2320 2325 2328 232c 232d 2332 2333
2338 233a 233e 2341 2345 2349 234c 2350
2354 2357 235b 235f 2360 2365 2367 236b
236f 2372 2374 2378 237c 237f 2383 2387
238a 238b 238d 2390 2393 2394 2399 239c
23a0 23a4 23a7 23a8 23aa 23ad 23b0 23b1
23b6 1 23b9 23be 23c2 23c5 23c9 23cb
23cf 23d2 23d6 23d9 23dc 23dd 23e2 23e6
23ea 23ee 23f2 23f7 23fb 23ff 2403 2407
240b 240f 2413 2416 2417 2419 241d 2421
2424 2425 2427 242b 242f 2432 2433 2435
2439 243d 2440 2441 2443 2447 244b 244e
244f 2451 2455 2459 245c 245d 245f 2463
2467 246a 246b 246d 2471 2475 2478 2479
247b 247f 2483 2487 2488 248a 248e 2492
2496 2499 249a 249c 24a0 24a3 24a7 24aa
24ab 24b0 24b4 24b8 24bb 24bf 24c3 24c6
24c9 24ce 24d1 24d4 24d7 24d8 24dd 24de
1 24e0 24e5 24e9 24ed 24f0 24f5 24fa
24fd 2501 2502 2507 250a 250f 2510 2515
2518 251d 251e 2523 2526 252a 252e 2532
2536 2539 253a 253c 2541 2542 2544 2545
254a 254b 2550 2552 2556 2559 255d 2561
2564 2568 256c 256f 2572 2577 257a 257d
2580 2581 2586 2587 1 2589 258e 2592
2596 2599 259e 25a3 25a6 25aa 25ab 25b0
25b1 25b6 25b8 25bc 25bf 25c3 25c7 25ca
25ce 25d2 25d5 25d9 25da 25df 25e3 25e5
25e9 25ed 25f0 25f1 25f3 25f6 25f9 25fa
25ff 2603 2607 260a 260e 2612 2615 2618
261d 2620 2623 2626 2627 262c 262d 1
262f 2634 2638 263c 263f 2644 2649 264c
2650 2651 2656 2659 265e 265f 2664 2667
266c 266d 2672 2675 2679 267d 2681 2682
2684 2689 268a 268c 268d 2692 2695 269a
269b 26a0 26a3 26a8 26a9 26ae 26b1 26b5
26b6 26bb 26be 26c3 26c4 26c9 26ca 26cf
26d1 26d5 26d8 26dc 26e0 26e3 26e7 26eb
26ee 26f1 26f6 26f9 26fc 26ff 2700 2705
2706 1 2708 270d 2711 2715 2718 271d
2722 2725 2729 272a 272f 2730 2735 2737
273b 273e 2742 2746 2749 274d 2751 2754
2755 2757 275b 275f 2760 2765 2767 276b
276f 2772 2774 2778 277b 277f 2783 2786
2787 2789 278c 278f 2790 2795 2798 279c
27a0 27a3 27a4 27a6 27a9 27ac 27ad 27b2
1 27b5 27ba 27be 27c2 27c5 27c6 27c8
27cb 27ce 27cf 27d4 27d7 27db 27df 27e2
27e3 27e5 27e8 27eb 27ec 27f1 1 27f4
27f9 27fd 2800 2804 2808 280a 280e 2812
2815 2816 2818 281b 281e 281f 2824 2828
282b 282f 2833 2835 2839 283d 2841 2844
2845 2847 284a 284d 284e 2853 2856 285a
285e 2861 2862 2864 2867 286a 286b 2870
1 2873 2878 287c 287f 2883 2887 2889
288d 2891 2895 2898 2899 289b 289e 28a1
28a2 28a7 28ab 28af 28b3 28b6 28b7 28b9
28bc 28c0 28c4 28c7 28c8 28ca 28cb 28d0
28d4 28d8 28db 28df 28e1 28e5 28e9 28ec
28ee 28f2 28f5 28f9 28fd 2900 2901 2903
2906 2909 290a 290f 2913 2917 291a 291b
291d 2920 2923 2924 2929 292d 2931 2934
2938 293c 293f 2942 2947 294a 294d 2950
2951 2956 2957 1 2959 295e 2962 2966
2969 296e 2973 2976 297a 297b 2980 2983
2988 2989 298e 2991 2996 2997 299c 299f
29a3 29a7 29ab 29af 29b2 29b3 29b5 29ba
29bb 29bd 29be 29c3 29c6 29cb 29cc 29d1
29d4 29d9 29da 29df 29e2 29e6 29e7 29ec
29ef 29f4 29f5 29fa 29fb 2a00 2a02 2a06
2a09 2a0d 2a11 2a14 2a18 2a1c 2a1f 2a22
2a27 2a2a 2a2d 2a30 2a31 2a36 2a37 1
2a39 2a3e 2a42 2a46 2a49 2a4e 2a53 2a56
2a5a 2a5b 2a60 2a61 2a66 2a68 2a6c 2a6f
2a73 2a77 2a7a 2a7e 2a82 2a85 2a89 2a8d
2a8e 2a93 2a95 2a99 2a9c 2aa0 2aa4 2aa7
2aa8 2aaa 2aad 2ab0 2ab1 2ab6 2aba 2abd
2ac1 2ac3 2ac7 2acb 2acf 2ad3 2ad7 2ada
2adb 2add 2ade 2ae0 2ae3 2ae6 2ae7 2aec
2aed 2aef 2af3 2af5 2af9 2afd 2b00 2b02
2b06 2b09 2b0d 2b11 2b12 2b17 2b1b 2b1f
2b24 2b28 2b2c 2b31 2b35 2b39 2b3e 2b42
2b46 2b4b 2b4f 2b53 2b57 2b5b 2b5e 2b61
2b62 2b64 2b68 2b6c 2b70 2b74 2b77 2b7a
2b7b 2b7d 2b81 2b85 2b89 2b8c 2b8d 2b8f
2b92 2b95 2b96 2b9b 2b9f 2ba0 2ba4 2ba8
2bac 2bb0 2bb4 2bb8 2bbb 2bbe 2bbf 2bc1
2bc4 2bc9 2bca 2bcf 2bd3 2bd7 2bdb 2bdf
2be3 2be7 2beb 2bef 2bf3 2bf7 2bfb 2bff
2c03 2c07 2c0b 2c0f 2c13 2c17 2c1b 2c1f
2c23 2c27 2c2b 2c2f 2c33 2c3f 2c43 2c47
2c4a 2c4e 2c52 2c54 1 2c58 2c5c 2c60
2c63 2c67 2c6b 2c6f 2c73 2c76 2c7a 2c7e
2c81 2c84 2c89 2c8c 2c8f 2c92 2c93 2c98
2c99 1 2c9b 2ca0 2ca4 2ca8 2cab 2cb0
2cb5 2cb8 2cbc 2cbd 2cc2 2cc5 2cca 2ccb
2cd0 2cd3 2cd8 2cd9 2cde 2ce1 2ce5 2ce6
2ceb 2cee 2cf3 2cf4 2cf9 2cfc 2d00 2d04
2d07 2d0a 2d0b 2d0d 2d0e 2d13 2d14 2d19
2d1b 2d1f 2d22 2d24 2d28 2d2a 2d36 2d38
2d3a 2d3b 2d40 2d44 2d46 2d52 2d54 2d58
2d5c 2d60 2d64 2d68 2d74 2d78 2d7c 2d7f
2d83 2d87 2d89 1 2d8d 2d91 2d95 2d98
2d9c 2da0 2da4 2da8 2dab 2daf 2db3 2db6
2db9 2dbe 2dc1 2dc4 2dc7 2dc8 2dcd 2dce
1 2dd0 2dd5 2dd9 2ddd 2de0 2de5 2dea
2ded 2df1 2df2 2df7 2dfa 2dff 2e00 2e05
2e08 2e0d 2e0e 2e13 2e16 2e1a 2e1b 2e20
2e23 2e28 2e29 2e2e 2e31 2e35 2e39 2e3c
2e3f 2e40 2e42 2e43 2e48 2e49 2e4e 2e50
2e54 2e57 2e59 2e5d 2e5f 2e6b 2e6d 2e6f
2e70 2e75 2e79 2e7b 2e87 2e89 2e8d 2e91
2e94 2e98 2e9b 2e9f 2ea2 2ea3 2ea8 2eab
2eaf 2eb3 2eb6 2eba 2ebe 2ec1 2ec4 2ec9
2ecc 2ecf 2ed2 2ed3 2ed8 2ed9 1 2edb
2ee0 2ee4 2ee8 2eeb 2ef0 2ef5 2ef8 2efc
2efd 2f02 2f05 2f0a 2f0b 2f10 2f13 2f18
2f19 2f1e 2f21 2f25 2f29 2f2d 2f31 2f34
2f35 2f37 2f3c 2f3d 2f3f 2f40 2f45 2f48
2f4d 2f4e 2f53 2f56 2f5b 2f5c 2f61 2f64
2f68 2f69 2f6e 2f71 2f76 2f77 2f7c 2f7d
2f82 2f84 2f88 2f8b 2f8f 2f93 2f96 2f9a
2f9e 2fa1 2fa4 2fa9 2fac 2faf 2fb2 2fb3
2fb8 2fb9 1 2fbb 2fc0 2fc4 2fc8 2fcb
2fd0 2fd5 2fd8 2fdc 2fdd 2fe2 2fe3 2fe8
2fea 2fee 2ff1 2ff5 2ff9 2ffc 3000 3004
3007 300b 300f 3010 3015 3017 301b 301e
3022 3026 302a 302e 3032 3036 303a 303e
3042 3046 304a 304e 3052 305e 3062 3066
3069 306d 3071 3073 1 3077 307b 307f
3082 3086 308a 308e 3092 3095 3099 309d
30a0 30a3 30a8 30ab 30ae 30b1 30b2 30b7
30b8 1 30ba 30bf 30c3 30c7 30ca 30cf
30d4 30d7 30db 30dc 30e1 30e4 30e9 30ea
30ef 30f2 30f7 30f8 30fd 3100 3104 3105
310a 310d 3112 3113 3118 311b 311f 3123
3126 3129 312a 312c 312d 3132 3133 3138
313a 313e 3141 3143 3147 3149 3155 3157
3159 315a 315f 3163 3165 3171 3173 3177
3179 317d 3181 3184 3187 3188 318a 318d
3192 3193 3198 319c 31a0 31a4 31a8 31ac
31b8 31bc 31c0 31c3 31c7 31cb 31cd 1
31d1 31d5 31d9 31dc 31e0 31e4 31e8 31ec
31ef 31f3 31f7 31fa 31fd 3202 3205 3208
320b 320c 3211 3212 1 3214 3219 321d
3221 3224 3229 322e 3231 3235 3236 323b
323e 3243 3244 3249 324c 3251 3252 3257
325a 325e 325f 3264 3267 326c 326d 3272
3275 3279 327d 3280 3283 3284 3286 3287
328c 328d 3292 3294 3298 329b 329d 32a1
32a3 32af 32b1 32b3 32b4 32b9 32bd 32bf
32cb 32cd 32d1 32d5 32d8 32dc 32df 32e3
32e6 32e7 32ec 32ef 32f3 32f7 32fa 32fe
3302 3305 3308 330d 3310 3313 3316 3317
331c 331d 1 331f 3324 3328 332c 332f
3334 3339 333c 3340 3341 3346 3349 334e
334f 3354 3357 335c 335d 3362 3365 3369
336d 3371 3375 3378 3379 337b 3380 3381
3383 3384 3389 338c 3391 3392 3397 339a
339f 33a0 33a5 33a8 33ac 33ad 33b2 33b5
33ba 33bb 33c0 33c1 33c6 33c8 33cc 33cf
33d3 33d7 33da 33de 33e2 33e5 33e8 33ed
33f0 33f3 33f6 33f7 33fc 33fd 1 33ff
3404 3408 340c 340f 3414 3419 341c 3420
3421 3426 3427 342c 342e 3432 3435 3439
343d 3440 3444 3448 344b 344f 3453 3454
3459 345b 345f 3462 3466 346a 346e 3472
3476 347a 347e 3482 3486 348a 348e 3492
3496 349a 349e 34a2 34a6 34aa 34ae 34b2
34b6 34ba 34be 34c2 34c6 34ca 34ce 34d2
34de 34e2 34e6 34e9 34ed 34f1 34f3 1
34f7 34fb 34ff 3502 3506 350a 350e 3512
3515 3519 351d 3520 3523 3528 352b 352e
3531 3532 3537 3538 1 353a 353f 3543
3547 354a 354f 3554 3557 355b 355c 3561
3564 3569 356a 356f 3572 3577 3578 357d
3580 3584 3585 358a 358d 3592 3593 3598
359b 359f 35a3 35a6 35a9 35aa 35ac 35ad
35b2 35b3 35b8 35ba 35be 35c1 35c3 35c7
35c9 35d5 35d7 35d9 35da 35df 35e3 35e5
35f1 35f3 35f7 35fb 35fe 3602 3605 3609
360c 360d 3612 3615 3619 361d 3621 3625
3629 362d 3631 3635 3639 363d 3641 3645
3649 364d 3651 3655 3659 365d 3661 3665
3669 366d 3671 3675 3679 3685 3689 368d
3690 3694 3698 369a 1 369e 36a2 36a6
36a9 36ad 36b1 36b5 36b9 36bc 36c0 36c4
36c7 36ca 36cf 36d2 36d5 36d8 36d9 36de
36df 1 36e1 36e6 36ea 36ee 36f1 36f6
36fb 36fe 3702 3703 3708 370b 3710 3711
3716 3719 371e 371f 3724 3727 372b 372c
3731 3734 3739 373a 373f 3742 3746 374a
374d 3750 3751 3753 3754 3759 375a 375f
3761 3765 3768 376a 376e 3770 377c 377e
3780 3781 3786 378a 378c 3798 379a 379c
37a0 37a3 37a7 37ab 37af 37b3 37b7 37bb
37bf 37c3 37c7 37cb 37d7 37db 37df 37e2
37e6 37ea 37ec 1 37f0 37f4 37f8 37fb
37ff 3803 3807 380b 380e 3812 3816 3819
381c 3821 3824 3827 382a 382b 3830 3831
1 3833 3838 383c 3840 3843 3848 384d
3850 3854 3855 385a 385d 3862 3863 3868
386b 3870 3871 3876 3879 387d 387e 3883
3886 388b 388c 3891 3894 3898 389c 389f
38a2 38a3 38a5 38a6 38ab 38ac 38b1 38b3
38b7 38ba 38bc 38c0 38c2 38ce 38d0 38d2
38d3 38d8 38dc 38de 38ea 38ec 38ee 38f2
38f6 38fa 38fd 3901 3905 3908 390b 3910
3913 3916 3919 391a 391f 3920 1 3922
3927 392b 392f 3932 3937 393c 393f 3943
3944 3949 394c 3951 3952 3957 395a 395f
3960 3965 3968 396c 3970 3974 3978 397b
397c 397e 3983 3984 3986 3987 398c 398d
3992 3994 3998 399b 399f 39a3 39a6 39aa
39ae 39b1 39b4 39b9 39bc 39bf 39c2 39c3
39c8 39c9 1 39cb 39d0 39d4 39d8 39db
39e0 39e5 39e8 39ec 39ed 39f2 39f3 39f8
39fa 39fe 3a01 3a05 3a09 3a0c 3a10 3a14
3a17 3a1b 3a1c 3a21 3a23 3a27 3a2b 3a2e
3a32 3a36 3a39 3a3d 3a40 3a44 3a47 3a48
3a4d 3a50 3a54 3a58 3a5b 3a5f 3a63 3a66
3a67 3a69 3a6d 3a71 3a74 3a78 3a79 3a7b
3a7f 3a83 3a87 3a8a 3a8e 3a92 3a95 3a96
3a98 3a9c 3aa0 3aa3 3aa7 3aa8 3aaa 3aae
3ab2 3ab6 3aba 3abe 3ac2 3ac6 3aca 3ace
3ad2 3ad6 3ada 3ade 3ae2 3ae6 3aea 3aee
3af2 3af6 3afa 3afe 3b02 3b06 3b0a 3b0e
3b12 3b16 3b1a 3b1e 3b22 3b26 3b2a 3b2e
3b32 3b36 3b3a 3b3e 3b42 3b4e 3b52 3b57
3b5b 3b5e 3b5f 3b64 3b68 3b6c 3b6f 3b72
3b76 3b78 3b7c 3b80 3b83 3b86 3b8a 3b8c
3b90 3b94 3b97 3b99 1 3b9d 3ba1 3ba5
3ba8 3bac 3bb0 3bb4 3bb8 3bbb 3bbf 3bc3
3bc6 3bc9 3bce 3bd1 3bd4 3bd7 3bd8 3bdd
3bde 1 3be0 3be5 3be9 3bed 3bf0 3bf5
3bfa 3bfd 3c01 3c02 3c07 3c0a 3c0f 3c10
3c15 3c18 3c1d 3c1e 3c23 3c26 3c2a 3c2b
3c30 3c33 3c38 3c39 3c3e 3c41 3c45 3c49
3c4c 3c4f 3c50 3c52 3c53 3c58 3c59 3c5e
3c60 3c64 3c67 3c69 3c6d 3c6f 3c7b 3c7d
3c7f 3c80 3c85 3c89 3c8b 3c97 3c99 3c9d
3ca1 3ca5 3ca6 3ca8 3cac 3cae 3cb2 3cb6
3cb7 3cbc 3cc0 3cc4 3cc8 3ccb 3ccf 3cd3
3cd6 3cd7 3cd9 3cdd 3ce1 3ce4 3ce8 3ce9
3ceb 3cef 3cf3 3cf7 3cfb 3cfe 3d02 3d06
3d09 3d0d 3d11 3d15 3d19 3d1d 3d21 3d25
3d29 3d2d 3d31 3d32 3d34 3d38 3d3c 3d40
3d44 3d48 3d4c 3d50 3d54 3d58 3d5c 3d60
3d64 3d68 3d6c 3d70 3d74 3d78 3d7c 3d80
3d84 3d88 3d8c 3d90 3d94 3d98 3da4 3da8
3dad 3db1 3db4 3db5 3dba 3dbe 3dc2 3dc5
3dc8 3dcc 3dce 3dd2 3dd6 3dd9 3ddc 3de0
3de2 3de6 3dea 3ded 3def 1 3df3 3df7
3dfb 3dfe 3e02 3e06 3e0a 3e0e 3e11 3e15
3e19 3e1c 3e1f 3e24 3e27 3e2a 3e2d 3e2e
3e33 3e34 1 3e36 3e3b 3e3f 3e43 3e46
3e4b 3e50 3e53 3e57 3e58 3e5d 3e60 3e65
3e66 3e6b 3e6e 3e73 3e74 3e79 3e7c 3e80
3e81 3e86 3e89 3e8e 3e8f 3e94 3e97 3e9b
3e9f 3ea2 3ea5 3ea6 3ea8 3ea9 3eae 3eaf
3eb4 3eb6 3eba 3ebd 3ebf 3ec3 3ec5 3ed1
3ed3 3ed5 3ed6 3edb 3edf 3ee1 3eed 3eef
3ef1 3ef5 3ef9 3efc 3f00 3f04 3f07 3f08
3f0a 3f0d 3f10 3f11 3f16 3f19 3f1d 3f20
3f21 3f26 3f29 1 3f2c 3f31 3f35 3f39
3f3d 3f41 3f45 3f51 3f55 3f59 3f5c 3f60
3f64 3f66 1 3f6a 3f6e 3f72 3f75 3f79
3f7d 3f81 3f85 3f88 3f8c 3f90 3f93 3f96
3f9b 3f9e 3fa1 3fa4 3fa5 3faa 3fab 1
3fad 3fb2 3fb6 3fba 3fbd 3fc2 3fc7 3fca
3fce 3fcf 3fd4 3fd7 3fdc 3fdd 3fe2 3fe5
3fea 3feb 3ff0 3ff3 3ff7 3ff8 3ffd 4000
4005 4006 400b 400e 4012 4016 4019 401c
401d 401f 4020 4025 4026 402b 402d 4031
4034 4036 403a 403c 4048 404a 404c 404d
4052 4056 4058 4064 4066 406a 406e 4071
4074 4075 4077 407a 407f 4080 4085 4089
408c 408f 4090 4095 4099 409d 40a1 40a4
40a8 40ac 40b0 40b4 40b8 40bc 40c0 40c4
40c8 40cc 40d0 40d1 40d3 40d7 40d9 40dd
40e0 40e2 40e6 40e9 40ed 40f1 40f5 40f9
40fd 4100 4103 4104 4106 4109 410e 410f
4114 4118 411c 4120 4123 4127 4129 412d
4131 4135 4138 4139 413b 413f 4141 4145
4149 414c 4150 4154 4158 415c 4160 4164
4168 416c 4170 4174 4178 417c 4180 4184
4188 418c 4190 4194 4198 419c 41a0 41a4
41a8 41ac 41b0 41b4 41b8 41bc 41c0 41c4
41c7 41ca 41cd 41d0 41d1 41d3 41d7 41db
41de 41e1 41e2 41e7 41eb 41ef 41f3 41f7
4203 4207 420c 4210 4213 4214 4219 421d
4221 4224 4227 422b 422d 4231 4235 4238
423b 423f 4241 4245 4249 424c 424e 1
4252 4256 425a 425d 4261 4265 4269 426d
4270 4274 4278 427b 427e 4283 4286 4289
428c 428d 4292 4293 1 4295 429a 429e
42a2 42a5 42aa 42af 42b2 42b6 42b7 42bc
42bf 42c4 42c5 42ca 42cd 42d2 42d3 42d8
42db 42df 42e0 42e5 42e8 42ed 42ee 42f3
42f6 42fa 42fe 4301 4304 4305 4307 4308
430d 430e 4313 4315 4319 431c 431e 4322
4324 4330 4332 4334 4335 433a 433e 4340
434c 434e 4350 4354 4357 4359 435d 4362
4366 436a 436f 4373 4377 437b 437f 4383
4387 438b 438c 438e 4391 4392 4394 4397
439a 439b 43a0 43a4 43a7 43ab 43ad 43b1
43b5 43b9 43bd 43c1 43c2 43c4 43c7 43c8
43ca 43cd 43d0 43d1 43d6 43d9 43dc 43df
43e0 43e5 43e6 43e8 43ec 43ee 43f2 43f6
43f9 43fd 4400 4403 4404 4409 440d 4410
4414 4418 441c 4420 4423 4424 4426 442a
442d 4431 4432 4437 4439 443d 4441 4445
4448 444b 444e 4452 4456 4459 445a 445c
445f 4462 4463 4468 446b 446e 446f 4474
4478 4479 447b 447f 4483 4487 448b 448e
4491 4494 4498 449c 449f 44a0 44a2 44a5
44a8 44a9 44ae 44b1 44b4 44b5 44ba 44bd
44c0 44c1 44c6 44ca 44cb 44cd 44d1 44d5
44d9 44dc 44df 44e0 44e2 44e5 44ea 44eb
44f0 44f4 44f8 44fc 44ff 4503 4507 450b
450f 4510 4512 4515 4516 4518 451b 451e
451f 4524 4528 452c 4530 4532 4536 453a
453e 4541 4546 4547 454c 454f 4552 4553
4555 4559 455d 4561 4565 4568 456c 456d
4572 4575 4578 4579 457b 457f 4581 4585
4589 458c 458e 4592 4596 459a 459d 459e
45a0 45a4 45a8 45ac 45b0 45b1 45b3 45b6
45b7 45b9 45bc 45bf 45c0 45c5 45c9 45cd
45d1 45d3 45d7 45db 45df 45e2 45e7 45e8
45ed 45f0 45f3 45f4 45f6 45fa 45fe 4602
4606 4609 460d 460e 4613 4616 4619 461a
461c 4620 4622 4626 462a 462d 462f 4633
4637 463a 463e 4642 4645 4648 4649 464b
464e 4653 4654 4659 465d 4661 4665 4669
466d 4671 4675 4679 467d 4681 4685 4689
468d 4691 4695 4699 469d 46a1 46a5 46b1
46b5 46b9 46bc 46c0 46c4 46c6 1 46ca
46ce 46d2 46d5 46d9 46dd 46e1 46e5 46e8
46ec 46f0 46f3 46f6 46fb 46fe 4701 4704
4705 470a 470b 1 470d 4712 4716 471a
471d 4722 4727 472a 472e 472f 4734 4737
473c 473d 4742 4745 474a 474b 4750 4753
4757 4758 475d 4760 4765 4766 476b 476e
4772 4776 4779 477c 477d 477f 4780 4785
4786 478b 478d 4791 4794 4796 479a 479c
47a8 47aa 47ac 47ad 47b2 47b6 47b8 47c4
47c6 47ca 47cd 47d1 47d5 47d8 47dc 47de
47e2 47e6 47ea 47ee 47f2 47f6 47fa 47fe
4802 4806 480a 480e 4812 4816 481a 481e
4822 4826 482a 482e 483a 483e 4842 4845
4849 484d 484f 1 4853 4857 485b 485e
4862 4866 486a 486e 4871 4875 4879 487c
487f 4884 4887 488a 488d 488e 4893 4894
1 4896 489b 489f 48a3 48a6 48ab 48b0
48b3 48b7 48b8 48bd 48c0 48c5 48c6 48cb
48ce 48d3 48d4 48d9 48dc 48e0 48e1 48e6
48e9 48ee 48ef 48f4 48f7 48fb 48ff 4902
4905 4906 4908 4909 490e 490f 4914 4916
491a 491d 491f 4923 4925 4931 4933 4935
4936 493b 493f 4941 494d 494f 4953 4957
495a 495e 4961 4965 4968 4969 496e 4971
4975 4979 497d 4981 4985 4989 498d 4991
4995 4999 499d 49a1 49a5 49a9 49ad 49b1
49b5 49b9 49bd 49c1 49cd 49d1 49d5 49d8
49dc 49e0 49e2 1 49e6 49ea 49ee 49f1
49f5 49f9 49fd 4a01 4a04 4a08 4a0c 4a0f
4a12 4a17 4a1a 4a1d 4a20 4a21 4a26 4a27
1 4a29 4a2e 4a32 4a36 4a39 4a3e 4a43
4a46 4a4a 4a4b 4a50 4a53 4a58 4a59 4a5e
4a61 4a66 4a67 4a6c 4a6f 4a73 4a74 4a79
4a7c 4a81 4a82 4a87 4a8a 4a8e 4a92 4a95
4a98 4a99 4a9b 4a9c 4aa1 4aa2 4aa7 4aa9
4aad 4ab0 4ab2 4ab6 4ab8 4ac4 4ac6 4ac8
4ac9 4ace 4ad2 4ad4 4ae0 4ae2 4ae4 4ae8
4aeb 4aed 4af1 4af5 4af8 4afc 4b00 4b04
4b08 4b0c 4b0f 4b12 4b13 4b15 4b18 4b1d
4b1e 4b23 4b27 4b2b 4b2f 4b32 4b36 4b38
4b3c 4b40 4b44 4b47 4b48 4b4a 4b4e 4b50
4b54 4b58 4b5b 4b5f 4b63 4b67 4b6b 4b6f
4b73 4b77 4b7b 4b7f 4b83 4b87 4b8b 4b8f
4b93 4b97 4b9b 4b9f 4ba3 4ba7 4bab 4baf
4bb3 4bb7 4bbb 4bbf 4bc3 4bc7 4bcb 4bcf
4bd3 4bd7 4bdb 4bdf 4be2 4be5 4be8 4beb
4bec 4bee 4bf2 4bf6 4bf9 4bfc 4bfd 4c02
4c06 4c0a 4c0e 4c12 4c1e 4c22 4c27 4c2b
4c2e 4c2f 4c34 4c38 4c3c 4c3f 4c42 4c46
4c48 4c4c 4c50 4c53 4c56 4c5a 4c5c 4c60
4c64 4c67 4c69 1 4c6d 4c71 4c75 4c78
4c7c 4c80 4c84 4c88 4c8b 4c8f 4c93 4c96
4c99 4c9e 4ca1 4ca4 4ca7 4ca8 4cad 4cae
1 4cb0 4cb5 4cb9 4cbd 4cc0 4cc5 4cca
4ccd 4cd1 4cd2 4cd7 4cda 4cdf 4ce0 4ce5
4ce8 4ced 4cee 4cf3 4cf6 4cfa 4cfb 4d00
4d03 4d08 4d09 4d0e 4d11 4d15 4d19 4d1c
4d1f 4d20 4d22 4d23 4d28 4d29 4d2e 4d30
4d34 4d37 4d39 4d3d 4d3f 4d4b 4d4d 4d4f
4d50 4d55 4d59 4d5b 4d67 4d69 4d6b 4d6f
4d72 4d76 4d7a 4d7e 4d81 4d82 4d84 4d87
4d8a 4d8b 4d90 4d94 4d96 4d9a 4da1 4da3
4da7 4daa 4dac 4db0 4db4 4db7 4dbb 4dbe
4dc1 4dc2 4dc7 4dca 4dce 4dd2 4dd5 4dd6
4dd8 4ddb 4dde 4ddf 4de4 1 4de7 4dec
4df0 4df4 4df7 4dfb 4dff 4e02 4e05 4e0a
4e0d 4e10 4e13 4e14 4e19 4e1a 1 4e1c
4e21 4e25 4e29 4e2c 4e31 4e36 4e39 4e3d
4e3e 4e43 4e46 4e4b 4e4c 4e51 4e54 4e59
4e5a 4e5f 4e62 4e66 4e6a 4e6e 4e72 4e75
4e76 4e78 4e7d 4e7e 4e80 4e81 4e86 4e89
4e8e 4e8f 4e94 4e97 4e9c 4e9d 4ea2 4ea5
4ea9 4eaa 4eaf 4eb2 4eb7 4eb8 4ebd 4ebe
4ec3 4ec5 4ec9 4ecc 4ed0 4ed4 4ed7 4edb
4edf 4ee2 4ee5 4eea 4eed 4ef0 4ef3 4ef4
4ef9 4efa 1 4efc 4f01 4f05 4f09 4f0c
4f11 4f16 4f19 4f1d 4f1e 4f23 4f24 4f29
4f2b 4f2f 4f32 4f36 4f3a 4f3d 4f41 4f45
4f48 4f4c 4f50 4f51 4f56 4f58 4f5c 4f5f
4f63 4f67 4f6a 4f6b 4f6d 4f70 4f73 4f74
4f79 4f7d 4f81 4f85 4f87 4f8b 4f8e 4f92
4f96 4f9a 4f9b 4f9d 4fa0 4fa1 4fa3 4fa6
4fa9 4faa 4faf 4fb2 4fb6 4fba 4fbe 4fbf
4fc1 4fc4 4fc5 4fc7 4fca 4fcd 4fce 4fd3
1 4fd6 4fdb 4fdf 4fe4 4fe7 4fec 4fed
4ff2 4ff5 4ffa 4ffb 5000 5003 5008 5009
500e 5011 5016 5017 501c 501f 5023 5027
502b 502e 502f 5031 5032 5034 5035 503a
503d 5042 5043 5048 504b 504f 5053 5057
505a 505b 505d 505e 5060 5061 5066 5069
506e 506f 5074 5077 507b 507f 5083 5086
5087 5089 508a 508c 508d 5092 5095 509a
509b 50a0 50a3 50a8 50a9 50ae 50b1 50b6
50b7 50bc 50bf 50c4 50c5 50ca 50cd 50d2
50d3 50d8 50db 50e0 50e1 50e6 50e9 50ed
50ee 50f3 50f6 50fb 50fc 5101 5104 5108
5109 510e 5111 5116 5117 511c 511f 5124
5125 512a 512d 5132 5133 5138 513b 5140
5141 5146 5149 514d 5151 5154 5155 515a
515d 5162 5163 5168 516b 516f 5173 5176
5177 517c 517f 5184 5185 518a 518d 5192
5193 5198 519b 51a0 51a1 51a6 51a9 51ad
51b1 51b5 51b8 51b9 51bb 51bc 51be 51bf
51c4 51c7 51cc 51cd 51d2 51d5 51d9 51dd
51e1 51e4 51e5 51e7 51e8 51ea 51eb 51f0
51f3 51f8 51f9 51fe 5201 5206 5207 520c
520f 5213 5217 521b 521e 521f 5221 5222
5224 5225 522a 522d 5232 5233 5238 523b
5240 5241 5246 5249 524d 524e 5253 5256
525b 525c 5261 5264 5268 5269 526e 5271
5276 5277 527c 527f 5284 5285 528a 528d
5292 5293 5298 529c 52a0 52a2 52a6 52aa
52ae 52af 52b1 52b4 52b5 52b7 52ba 52bd
52be 52c3 52c7 52cc 52cf 52d4 52d5 52da
52dd 52e2 52e3 52e8 52eb 52f0 52f1 52f6
52f9 52fe 52ff 5304 5307 530b 530f 5313
5316 5317 5319 531a 531c 531d 5322 5325
532a 532b 5330 5333 5337 533b 533f 5342
5343 5345 5346 5348 5349 534e 5351 5356
5357 535c 535f 5363 5367 536b 536e 536f
5371 5372 5374 5375 537a 537d 5382 5383
5388 538b 5390 5391 5396 5399 539e 539f
53a4 53a7 53ac 53ad 53b2 53b5 53ba 53bb
53c0 53c3 53c8 53c9 53ce 53d1 53d5 53d6
53db 53de 53e3 53e4 53e9 53ec 53f0 53f1
53f6 53f9 53fe 53ff 5404 5407 540c 540d
5412 5416 541a 541c 5420 5424 5428 542c
542d 542f 5432 5433 5435 5438 543b 543c
5441 5445 544a 544d 5452 5453 5458 545b
545f 5463 5466 5467 546c 546f 5474 5475
547a 547d 5481 5485 5488 5489 548e 5491
5496 5497 549c 549f 54a4 54a5 54aa 54ad
54b2 54b3 54b8 54bb 54bf 54c3 54c7 54ca
54cb 54cd 54ce 54d0 54d1 54d6 54d9 54de
54df 54e4 54e7 54eb 54ef 54f3 54f6 54f7
54f9 54fa 54fc 54fd 5502 5505 550a 550b
5510 5513 5518 5519 551e 5521 5525 5529
552d 5530 5531 5533 5534 5536 5537 553c
553f 5544 5545 554a 554d 5552 5553 5558
555b 555f 5560 5565 5568 556d 556e 5573
5576 557a 557b 5580 5583 5588 5589 558e
5591 5596 5597 559c 559f 55a4 55a5 55aa
55ae 55b0 55b4 55b8 55bb 55bf 55c3 55c6
55ca 55ce 55d1 55d4 55d9 55dc 55df 55e2
55e3 55e8 55e9 1 55eb 55f0 55f4 55f8
55fb 5600 5605 5608 560c 560d 5612 5613
5618 561a 561e 5621 5625 5629 562c 5630
5634 5637 563a 563f 5642 5645 5648 5649
564e 564f 1 5651 5656 565a 565e 5661
5666 566b 566e 5672 5673 5678 5679 567e
5680 5684 5687 568b 568f 5693 5696 569a
569b 569d 56a1 56a3 56a7 56ab 56ae 56b2
56b6 56b9 56bd 56c1 56c4 56c7 56cc 56cf
56d2 56d5 56d6 56db 56dc 1 56de 56e3
56e7 56eb 56ee 56f3 56f8 56fb 56ff 5700
5705 5706 570b 570f 5713 5716 571b 5720
5723 5727 572b 572e 572f 5734 5737 573c
573d 5742 5745 5749 574d 5750 5751 5756
5757 575c 575e 5762 5765 5769 576d 5771
5775 5779 577d 5781 5785 5789 5795 579a
579e 57a2 57a6 57aa 57ac 57ad 57b2 1
57b6 57ba 57be 57c1 57c5 57c9 57cd 57d1
57d4 57d8 57dc 57df 57e2 57e7 57ea 57ed
57f0 57f1 57f6 57f7 1 57f9 57fe 5802
5806 5809 580e 5813 5816 581a 581b 5820
5821 5826 582a 582e 5831 5836 583b 583e
5842 5843 5848 584b 5850 5851 5856 5859
585d 5861 5864 5867 5868 586a 586b 5870
5871 5876 5878 587c 587f 5883 5887 588b
588f 5893 5897 589b 58a7 58ac 58b0 58b4
58b8 58bc 58be 58c2 58c4 58d0 58d2 58d4
58d5 58da 58de 58e0 58ec 58f0 58f2 58f3
58fc 
19b9
2
0 1 a 6 d :3 6 14 :3 6
15 :3 6 10 :3 6 e :3 6 11 :3 6
c :3 6 b :3 6 11 :3 6 11 :3 6
1d :3 6 10 :3 6 e :3 6 10 :3 6
12 :2 6 1 3 a 13 a :2 1
4 11 1a 19 :2 11 :2 4 e 17
16 :2 e :2 4 f 18 17 :2 f :2 4
d 16 15 :2 d :2 4 11 1a 19
:2 11 :2 4 f 18 17 :2 f :2 4 10
19 18 :2 10 :2 4 :3 10 :2 4 11 1a
19 :2 11 :2 4 f 18 17 :2 f :2 4
13 1c 1b :2 13 :2 4 10 19 18
:2 10 :2 4 18 21 20 :2 18 :2 4 10
19 18 :2 10 :2 4 f 18 17 :2 f
:2 4 10 19 18 :2 10 :2 4 :3 9 :2 4
:3 9 :2 4 10 19 18 :2 10 :2 4 :2 c
1b c :2 4 :2 e 1d e :2 4 :2 b
1a b :2 4 :2 d 1c d :2 4 :2 10
1f 10 :2 4 :2 a 19 a :2 4 :2 b
1a b :2 4 :2 11 20 11 :2 4 :2 d
1c d :2 4 :2 c 1b c :2 4 :2 b
1a b :2 4 :2 f 1e f :2 4 :2 e
1d e :2 4 :2 c 1b c :2 4 :2 e
1d e :2 4 :2 f 1e f :2 4 :2 b
1a b :2 4 :2 f 1e f :2 4 :2 d
1c d :2 4 :2 c 1b c :2 4 :2 c
1b c :2 4 :2 f 1e f :2 4 :2 b
1a b :2 4 :2 f 19 f :2 4 :2 f
1e f :2 4 :2 16 25 16 :2 4 :2 11
20 11 :2 4 :2 f 19 f :2 4 :2 f
19 f :2 4 :2 17 26 17 :2 4 17
1c 1b :2 17 :2 4 18 1d 1c :2 18
:2 4 :2 13 22 13 :2 4 :2 14 23 14
:2 4 9 12 11 :2 9 :2 4 :2 11 20
11 :2 4 :2 f 1e f :2 4 :2 6 1e
6 :2 4 :2 7 1f 7 :2 4 :2 d 25
d :2 4 :2 8 20 8 :2 4 :3 d :2 4
e 17 :3 e 4 7 :2 11 23 :2 2d
3a :2 23 :3 7 :2 d 19 25 :2 2f 43
:2 25 53 59 5c :2 53 6a 7f 8
:2 6a d 10 :2 6a 17 1a :2 6a b
e :2 6a 13 16 :2 6a 1b 1e :2 6a
2c 2f :2 6a b e :2 6a 13 16
:2 6a 1b 1e :2 6a 2d 30 :2 6a b
e :2 6a 13 16 1f 27 :2 1f 33
:2 16 :2 6a b e :2 6a 13 16 1f
27 :2 1f 31 :2 16 :2 6a b e :2 6a
13 16 1f 27 :2 1f 34 :2 16 :2 6a
b e :2 6a 13 16 1f 27 :2 1f
2f :2 16 :2 6a b e :2 6a 13 16
1f 27 :2 1f 2e :2 16 :2 6a b e
:2 6a 13 16 1f 27 :2 1f 34 :2 16
:2 6a b e :2 6a 13 16 1f 27
:2 1f 34 :2 16 :2 6a b e :2 6a 13
16 1f 27 :2 1f 40 :2 16 :2 6a b
e :2 6a 13 16 1f 27 :2 1f 33
:2 16 :2 6a b e :2 6a 13 16 1f
27 :2 1f 31 :2 16 :2 6a b e :2 6a
13 16 :2 6a 1b 1e :2 6a 28 2b
:2 6a b e :2 6a 13 16 :2 6a 1b
1e :2 6a 2a 2d :2 6a 32 35 :2 6a
:2 7 49 :2 4 7 :2 11 23 :2 2d 39
3c 4b 4e 4f :2 4b :2 23 :3 7 :2 d
12 1e 5c 5f :2 1e :2 7 52 :3 4
14 :2 4 14 :2 4 13 :2 4 12 :2 4
10 :2 4 e :2 4 14 :2 4 f :2 4
12 :2 4 e :2 4 e :2 4 11 :2 4
11 :2 4 13 :2 4 11 :2 4 14 1d
26 2e :2 1d :2 14 :2 4 12 :2 4 10
4 :4 8 7 a :2 14 26 :2 30 3c
3f 4e 51 52 :2 4e :2 26 :3 a :2 10
15 21 5f 62 :2 21 6f 72 :2 21
76 79 :2 21 83 86 8f 97 :2 a0
:2 8f b6 :2 86 :2 21 :2 a 55 :2 7 a
:2 14 26 :2 30 3c 3f 4e 51 52
:2 4e :2 26 :3 a :2 10 15 21 5f 62
:2 21 :2 a 55 :3 7 :2 12 28 :2 31 46
:2 7 18 :2 4 7 10 1b :2 7 1e
20 :2 1e 26 2f 37 :2 26 3a 3c
:2 3a :2 7 42 4b 53 :2 42 56 58
:2 56 :2 7 a :2 14 26 :2 30 3c 3f
4e 51 52 :2 4e :2 26 :3 a :2 10 15
21 5f 62 :2 21 6f 72 :2 21 76
79 :2 21 83 86 8f 97 :2 a0 :2 8f
b1 :2 86 :2 21 :2 a 55 :2 7 a :2 14
26 :2 30 3c 3f 4e 51 52 :2 4e
:2 26 :3 a :2 10 15 21 5f 62 :2 21
:2 a 55 :3 7 :2 12 28 :2 31 41 :2 7
5a :2 4 8 11 1c :2 8 22 1f
:2 2b :2 1f 7 :4 46 45 44 :2 7 :4 14
13 12 :2 7 11 1c 21 33 3e
43 :2 f :2 a :2 13 1f a 7 :2 f
d :2 16 22 d 10 :2 1a 2c :2 36
42 46 55 58 59 :2 55 :2 2c :3 10
:2 16 1b 27 65 68 :2 27 75 78
:2 27 7c 7f :2 27 8b 8e :2 27 96
99 :2 27 a5 a8 af b8 bb :2 a8
:2 27 :2 10 5c :2 d :2 a :4 16 :2 a 7
:3 31 b :2 14 1f 1d :2 28 :2 1d a
3d 46 4f :2 3d 52 54 :2 52 3c
:2 a d :2 17 29 :2 33 3f 42 51
54 55 :2 51 :2 29 :3 d :2 13 18 24
62 65 :2 24 72 75 :2 24 79 7c
:2 24 86 89 92 9a :2 a3 :2 92 c0
:2 89 :2 24 :2 d 58 :2 a d :2 17 29
:2 33 3f 42 51 54 55 :2 51 :2 29
:3 d :2 13 18 24 62 65 :2 24 :2 d
58 :3 a :2 15 2b :2 34 50 :2 a 57
:3 7 e 7 4 31 :4 c b a
:4 2a 29 28 :2 a 11 23 f :2 a
:2 13 1f a 7 :2 f d :2 16 22
d 10 :2 1a 2c :2 36 42 46 55
58 59 :2 55 :2 2c :3 10 :2 16 1b 27
65 68 :2 27 75 78 :2 27 7c 7f
:2 27 8b 8e :2 27 96 99 :2 27 a5
a8 af b8 bb :2 a8 :2 27 :2 10 5c
:2 d :2 a :4 16 :2 a 7 :4 43 31 :3 4
12 :2 4 d :2 16 22 29 32 3e
:2 29 42 :2 4b :2 22 21 5a :2 d :2 4
13 1a 23 2f :2 1a 33 :2 3c :2 13
12 4 7 10 18 :2 7 1b 1d
:2 1b 11 1a 30 39 51 f 1a
26 f 1d 2a :2 a :2 13 1f a
7 :2 f d :2 16 22 d 10 :2 1a
2c :2 36 42 46 55 58 59 :2 55
:2 2c :3 10 :2 16 1b 27 65 68 :2 27
75 78 :2 27 7c 7f :2 27 8b 8e
:2 27 96 99 :2 27 a5 a8 af b8
bb :2 a8 :2 27 :2 10 5c :2 d :2 a :4 16
:2 a 7 :3 1f b :2 14 1f 1d :2 28
:2 1d a 26 31 3d 4d 5d 6a
:2 d :2 16 22 d a :2 12 10 :2 19
25 10 13 :2 1d 2f :2 39 45 49
58 5b 5c :2 58 :2 2f :3 13 :2 19 1e
2a 68 6b :2 2a 78 7b :2 2a 7f
82 :2 2a 8e 91 :2 2a 99 9c :2 2a
a8 ab b2 bb be :2 ab :2 2a :2 13
5f :2 10 :2 d :4 19 :2 d a :3 38 e
:2 17 22 20 :2 2b :2 20 d 10 :2 1a
2c :2 36 42 46 55 58 59 :2 55
:2 2c :3 10 :2 16 1b 27 65 68 :2 27
75 78 :2 27 7c 7f :2 27 89 8c
95 9d :2 a6 :2 95 b7 :2 8c :2 27 bf
c2 :2 27 ca cd :2 27 d2 d5 :2 27
e2 e5 :2 27 :2 10 5c :2 d 10 :2 1a
2c :2 36 42 45 54 57 58 :2 54
:2 2c :3 10 :2 16 1b 27 65 68 :2 27
:2 10 5b :3 d :2 18 2c :2 35 45 53
:2 d 3b :2 a 38 :3 7 15 7 11
21 f 10 1d :2 a :2 13 1f a
7 :2 f d :2 16 22 d 10 :2 1a
2c :2 36 42 46 55 58 59 :2 55
:2 2c :3 10 :2 16 1b 27 65 68 :2 27
75 78 :2 27 7c 7f :2 27 8b 8e
:2 27 96 99 :2 27 a5 a8 af b8
bb :2 a8 :2 27 :2 10 5c :2 d :2 a :4 16
:2 a 7 :3 1f a 13 1f :2 a 22
24 :2 22 14 24 12 13 20 :2 d
:2 16 22 d a :2 12 10 :2 19 25
10 13 :2 1d 2f :2 39 45 49 58
5b 5c :2 58 :2 2f :3 13 :2 19 1e 2a
68 6b :2 2a 78 7b :2 2a 7f 82
:2 2a 8e 91 :2 2a 99 9c :2 2a a8
ab b2 bb be :2 ab :2 2a :2 13 5f
:2 10 :2 d :4 19 :2 d a :3 26 d :2 18
1f 2d :2 d 32 34 :2 32 10 :2 1a
2c :2 36 42 46 55 58 59 :2 55
:2 2c :3 10 :2 16 1b 27 65 68 :2 27
75 78 :2 27 7c 7f :2 27 89 8c
95 9d :2 a6 :2 95 bb :2 8c :2 27 c3
c6 :2 27 ce d1 :2 27 d6 d9 :2 27
e6 e9 :2 27 :2 10 5c :2 d 10 :2 1a
2c :2 36 42 45 54 57 58 :2 54
:2 2c :3 10 :2 16 1b 27 65 68 :2 27
:2 10 5b :3 d :2 18 2c :2 35 49 57
:2 d 36 :2 a 26 :2 7 1f :4 b a
d :2 17 29 :2 33 3f 42 51 54
55 :2 51 :2 29 :3 d :2 13 18 24 62
65 :2 24 72 75 :2 24 79 7c :2 24
86 89 92 9a :2 a3 :2 92 b9 :2 89
:2 24 :2 d 58 :2 a d :2 17 29 :2 33
3f 42 51 54 55 :2 51 :2 29 :3 d
:2 13 18 24 62 65 :2 24 :2 d 58
:3 a :2 15 2b :2 34 49 :2 a 1e :3 7
16 :2 7 13 1a 21 2e 31 :2 1a
36 39 :2 13 :2 7 15 :2 1e 27 2a
2d 31 :2 15 7 a 18 21 29
:2 18 :2 a 2d 30 :2 2d 14 20 29
3f 48 60 12 20 2b 37 12
20 2d 3b 47 50 5b 64 70
79 87 90 9e a7 :2 d :2 16 22
d a :2 12 10 :2 19 25 10 13
:2 1d 2f :2 39 45 49 58 5b 5c
:2 58 :2 2f :3 13 :2 19 1e 2a 68 6b
:2 2a 78 7b :2 2a 7f 82 :2 2a 8e
91 :2 2a 99 9c :2 2a a8 ab b2
bb be :2 ab :2 2a :2 13 5f :2 10 :2 d
:4 19 :2 d a :3 32 e :2 17 22 20
:2 2b :2 20 d 10 :2 1a 2c :2 36 42
46 55 58 59 :2 55 :2 2c :3 10 :2 16
1b 27 65 68 :2 27 75 78 :2 27
7c 7f :2 27 89 8c 95 9d :2 a6
:2 95 b9 :2 8c :2 27 c1 c4 :2 27 cc
cf :2 27 d4 d7 :2 27 e1 e4 :2 27
:2 10 5c :2 d 10 :2 1a 2c :2 36 42
45 54 57 58 :2 54 :2 2c :3 10 :2 16
1b 27 65 68 :2 27 :2 10 5b :3 d
:2 18 2c :2 35 47 52 :2 d 3b :2 a
32 d :2 17 29 :2 33 3f 43 52
55 56 :2 52 :2 29 :3 d :2 13 18 24
62 65 :2 24 72 75 :2 24 79 7c
:2 24 86 89 92 9a :2 a3 :2 92 b6
:2 89 :2 24 be c1 :2 24 c9 cc :2 24
d1 d4 :2 24 de e1 :2 24 :2 d 59
:2 a d :2 17 29 :2 33 3f 42 51
54 55 :2 51 :2 29 :3 d :2 13 18 24
62 65 :2 24 :2 d 58 :3 a :2 15 29
:2 32 44 4f :2 a :4 7 :4 4 8 11
1d :2 8 20 22 :2 20 7 2a 33
3b :2 2a 3e 41 :2 3e 29 :3 7 11
7 46 :2 4 7 b d :2 b 7
15 :2 7 16 :2 7 15 26 32 3f
48 51 :2 3f 55 5e 66 :2 55 22
2b 37 :2 22 3b 44 4f :2 3b 53
20 2b :2 53 2f 38 46 :2 2f 4a
53 5e :2 4a 22 2b 37 :2 22 3b
43 4d :2 15 7 a 13 1f :2 a
24 22 :2 2d :2 22 d :2 17 29 :2 33
3f 42 51 54 55 :2 51 :2 29 :3 d
:2 13 18 24 62 65 :2 24 72 75
:2 24 79 7c :2 24 86 89 92 9a
:2 a3 :2 92 b4 :2 89 :2 24 :2 d 58 :2 a
d :2 17 29 :2 33 3f 42 51 54
55 :2 51 :2 29 :3 d :2 13 18 24 62
65 :2 24 :2 d 58 :3 a :2 15 2b :2 34
44 :2 a 7 3c d 16 22 :2 d
25 28 :2 25 d :2 17 29 :2 33 3f
43 52 55 56 :2 52 :2 29 :3 d :2 13
18 24 62 65 :2 24 72 75 :2 24
79 7c :2 24 86 89 92 9a :2 92
a7 :2 89 :2 24 af b2 :2 24 ba bd
:2 24 c2 c5 :2 24 d2 d5 :2 24 :2 d
59 :2 a d :2 17 29 :2 33 3f 42
51 54 55 :2 51 :2 29 :3 d :2 13 18
24 62 65 :2 24 :2 d 58 :3 a :2 15
29 32 3e :2 29 42 50 :2 a 2a
3c :2 7 f :2 4 8 11 19 :2 8
1c 1e :2 1c 7 26 2f 37 :2 26
3a 3d :2 3a 25 :2 7 b 14 1c
:2 b 1f 21 :2 1f a 28 31 39
:2 28 3c 3e :2 3c 27 :3 a 15 a
7 41 d 16 1e :2 d 21 23
:2 21 a 15 a 7 25 41 e
17 1f :2 e 22 24 :2 22 d 2b
34 3c :2 2b 3f 41 :2 3f 2a :2 d
a 15 a 7 44 41 d 16
1e :2 d 21 23 :2 21 a 14 1d
29 :2 14 2c 2e 37 3f :2 2e :2 14
:2 a 15 a 25 41 :2 7 42 :2 4
7 10 1a :2 7 1d 1f :2 1d a
13 1f :2 a 22 24 :2 22 d :2 17
29 :2 33 3f 43 52 55 56 :2 52
:2 29 :3 d :2 13 18 24 62 65 :2 24
72 75 :2 24 79 7c :2 24 86 89
92 9a :2 a3 :2 92 ba :2 89 :2 24 c2
c5 :2 24 cd d0 :2 24 d5 d8 :2 24
e5 e8 :2 24 :2 d 59 :2 a d :2 17
29 :2 33 3f 42 51 54 55 :2 51
:2 29 :3 d :2 13 18 24 62 65 :2 24
:2 d 58 :3 a :2 15 29 :2 32 48 56
:2 a 29 :2 7 a 13 1f :2 a 22
24 :2 22 a 18 a 27 a 18
1e 28 31 3d :2 28 :2 1e 41 43
:2 1e :2 18 a :4 7 21 :3 4 :3 17 :2 4
12 :2 4 13 :2 4 13 :2 4 13 :2 4
10 17 21 24 :2 10 :2 4 12 19
25 28 :2 12 4 7 10 18 :2 7
1b 1d :2 1b 7 f :2 7 15 7
a 11 1d 20 :2 a 23 25 :2 23
14 27 2f 36 51 59 60 7c
86 d 1b 12 27 2d 33 3f
d 19 12 13 1b 2c 38 45
5b :2 d :2 16 22 d a :2 12 10
:2 19 25 10 13 :2 1d 2f :2 39 45
49 58 5b 5c :2 58 :2 2f :3 13 :2 19
1e 2a 68 6b :2 2a 78 7b :2 2a
7f 82 :2 2a 8e 91 :2 2a 99 9c
:2 2a a8 ab b2 bb be :2 ab :2 2a
:2 13 5f :2 10 :2 d :4 19 :2 d a :3 29
14 26 37 46 53 :2 d :2 16 22
d a :2 12 10 :2 19 25 10 13
:2 1d 2f :2 39 45 49 58 5b 5c
:2 58 :2 2f :3 13 :2 19 1e 2a 68 6b
:2 2a 78 7b :2 2a 7f 82 :2 2a 8e
91 :2 2a 99 9c :2 2a a8 ab b2
bb be :2 ab :2 2a :2 13 5f :2 10 :2 d
:4 19 :2 d a :3 29 e :2 17 22 20
:2 2b :2 20 d 10 :2 1a 2c :2 36 42
46 55 58 59 :2 55 :2 2c :3 10 :2 16
1b 27 65 68 :2 27 75 78 :2 27
7c 7f :2 27 89 8c 95 9d :2 a6
:2 95 b9 :2 8c :2 27 c1 c4 :2 27 cc
cf :2 27 d4 d7 :2 27 e0 e3 :2 27
:2 10 5c :2 d 10 :2 1a 2c :2 36 42
45 54 57 58 :2 54 :2 2c :3 10 :2 16
1b 27 65 68 :2 27 :2 10 5b :3 d
:2 18 2c :2 35 47 51 :2 d 3b :3 a
19 a 14 27 38 45 12 13
20 2e 46 54 :2 d :2 16 22 d
a :2 12 10 :2 19 25 10 13 :2 1d
2f :2 39 45 49 58 5b 5c :2 58
:2 2f :3 13 :2 19 1e 2a 68 6b :2 2a
78 7b :2 2a 7f 82 :2 2a 8e 91
:2 2a 99 9c :2 2a a8 ab b2 bb
be :2 ab :2 2a :2 13 5f :2 10 :2 d :4 19
:2 d a :3 29 7 29 d 14 20
23 :2 d 26 28 :2 26 14 23 34
44 52 :2 d :2 16 22 d a :2 12
10 :2 19 25 10 13 :2 1d 2f :2 39
45 49 58 5b 5c :2 58 :2 2f :3 13
:2 19 1e 2a 68 6b :2 2a 78 7b
:2 2a 7f 82 :2 2a 8e 91 :2 2a 99
9c :2 2a a8 ab b2 bb be :2 ab
:2 2a :2 13 5f :2 10 :2 d :4 19 :2 d a
:3 2c e :2 17 22 20 :2 2b :2 20 d
10 :2 1a 2c :2 36 42 46 55 58
59 :2 55 :2 2c :3 10 :2 16 1b 27 65
68 :2 27 75 78 :2 27 7c 7f :2 27
89 8c 95 9d :2 a6 :2 95 b9 :2 8c
:2 27 c1 c4 :2 27 cc cf :2 27 d4
d7 :2 27 e0 e3 :2 27 :2 10 5c :2 d
10 :2 1a 2c :2 36 42 45 54 57
58 :2 54 :2 2c :3 10 :2 16 1b 27 65
68 :2 27 :2 10 5b :3 d :2 18 2c :2 35
47 51 :2 d 3b :3 a 18 a 14
27 2f 36 51 59 60 7c 86
d 1b 12 27 2d 33 3f d
19 12 13 1b 2c 38 45 5b
:2 d :2 16 22 d a :2 12 10 :2 19
25 10 13 :2 1d 2f :2 39 45 49
58 5b 5c :2 58 :2 2f :3 13 :2 19 1e
2a 68 6b :2 2a 78 7b :2 2a 7f
82 :2 2a 8e 91 :2 2a 99 9c :2 2a
a8 ab b2 bb be :2 ab :2 2a :2 13
5f :2 10 :2 d :4 19 :2 d a :3 2c e
:2 17 22 20 :2 2b :2 20 d 17 2a
32 39 54 5c 63 7f 89 10
1e 15 2a 30 36 42 10 1c
15 16 1e 2f 3b 48 5e :2 10
:2 19 25 10 d :2 15 13 :2 1c 28
13 16 :2 20 32 :2 3c 48 4c 5b
5e 5f :2 5b :2 32 :3 16 :2 1c 21 2d
6b 6e :2 2d 7b 7e :2 2d 82 85
:2 2d 91 94 :2 2d 9c 9f :2 2d ab
ae b5 be c1 :2 ae :2 2d :2 16 62
:2 13 :2 10 :4 1c :2 10 d :4 3b :2 a 14
27 38 45 12 13 20 2e 46
54 :2 d :2 16 22 d a :2 12 10
:2 19 25 10 13 :2 1d 2f :2 39 45
49 58 5b 5c :2 58 :2 2f :3 13 :2 19
1e 2a 68 6b :2 2a 78 7b :2 2a
7f 82 :2 2a 8e 91 :2 2a 99 9c
:2 2a a8 ab b2 bb be :2 ab :2 2a
:2 13 5f :2 10 :2 d :4 19 :2 d a :4 2c
29 d :2 17 29 :2 33 3f 42 51
54 55 :2 51 :2 29 :3 d :2 13 18 24
62 65 :2 24 72 75 :2 24 79 7c
:2 24 86 89 92 9a :2 a3 :2 92 b4
:2 89 :2 24 :2 d 58 :2 a d :2 17 29
:2 33 3f 42 51 54 55 :2 51 :2 29
:3 d :2 13 18 24 62 65 :2 24 :2 d
58 :3 a :2 15 2b :2 34 44 :2 a :4 7
b :2 14 1f 1d :2 28 :2 1d :2 a 1d
2b 2e 37 3f :2 2e 43 :2 4c 24
:2 1d :2 a 1d 2b 2e 37 3f :2 2e
43 :2 4c 24 :2 1d a 14 2d 12
20 38 49 52 5d 66 72 7b
89 92 a0 a9 bd c6 12 20
39 42 12 20 38 41 12 1b
23 30 39 :2 12 20 3a 12 13
27 d 14 10 1c :3 1a 10 :2 19
25 10 21 10 :2 19 25 10 :4 d
a :2 12 10 :2 19 25 10 13 :2 1d
2f :2 39 45 49 58 5b 5c :2 58
:2 2f :3 13 :2 19 1e 2a 68 6b :2 2a
78 7b :2 2a 7f 82 :2 2a 8e 91
:2 2a 99 9c :2 2a a8 ab b2 bb
be :2 ab :2 2a :2 13 5f :2 10 :2 d :4 19
:2 d a :3 38 a 1d 33 :2 1d a
38 a :3 19 :2 a 1d 2b 2e 37
3f :2 2e 43 :2 4c 24 :2 1d :2 a 20
:2 29 :2 a 1c :2 a 1d 34 42 4c
54 2d 41 4d :2 1d a 19 2e
41 4d 59 67 d 1c 29 36
43 4d 15 22 30 3b 43 d
19 23 2c 39 4d 5a d 14
10 1c :3 1a 10 :2 19 25 10 21
10 :2 19 25 10 :4 d a :2 12 10
:2 19 25 10 13 :2 1d 2f :2 39 45
49 58 5b 5c :2 58 :2 2f :3 13 :2 19
1e 2a 68 6b :2 2a 78 7b :2 2a
7f 82 :2 2a 8e 91 :2 2a 99 9c
:2 2a a8 ab b2 bb be :2 ab :2 2a
:2 13 5f :2 10 :2 d :4 19 :2 d a :7 7
b 14 21 :2 b 24 26 :2 24 a
:4 2f 2e 2d :2 a 14 36 4a 60
6d :2 d :2 16 22 d a :2 12 10
:2 19 25 10 13 :2 1d 2f :2 39 45
49 58 5b 5c :2 58 :2 2f :3 13 :2 19
1e 2a 68 6b :2 2a 78 7b :2 2a
7f 82 :2 2a 8e 91 :2 2a 99 9c
:2 2a a8 ab b2 bb be :2 ab :2 2a
:2 13 5f :2 10 :2 d :4 19 :2 d a :3 42
d 14 24 27 :2 d 2a 2c :2 2a
d 1d 1e :2 1d :2 d :2 16 22 39
47 55 6a 2f 35 41 4d 2f
42 :2 22 d 30 :2 a 42 :3 7 15
7 a 11 1d 20 :2 a 23 25
:2 23 a 15 :2 1e a 29 a 15
1e 2a :2 15 a :5 7 13 1f 2c
3a 45 4f 5b 1b 28 35 42
4f 1b 28 34 3e 46 4f 57
5e 1b 27 34 3f 4a 58 1b
26 32 3e 41 44 4a :2 13 7
a 13 15 :2 13 14 27 44 4b
d 14 10 1c :3 1a 10 :2 19 25
10 21 10 :2 19 25 10 :4 d a
:2 12 10 :2 19 25 10 13 :2 1d 2f
:2 39 45 49 58 5b 5c :2 58 :2 2f
:3 13 :2 19 1e 2a 68 6b :2 2a 78
7b :2 2a 7f 82 :2 2a 8e 91 :2 2a
99 9c :2 2a a8 ab b2 bb be
:2 ab :2 2a :2 13 5f :2 10 :2 d :4 19 :2 d
a :4 17 :2 7 1f 7 15 :2 7 16
:2 7 16 7 a 13 1a :2 13 28
:2 a 2b 2d :2 2b a 16 a 30
a 16 1d 26 2d :2 26 3b :2 1d
3e 40 :2 1d 1c 43 45 :2 1c :2 16
a :4 7 a 13 15 :2 13 a 15
:2 a 10 19 22 :2 10 27 25 30
:2 25 a d 19 :2 22 2b 2f 33
3c 45 :2 33 48 4a :2 33 4c 4d
:2 33 50 :2 19 :2 d 1b :2 24 2d 30
33 3c 45 :2 33 48 4a :2 33 4d
4f :2 33 51 52 :2 33 55 :2 1b d
10 17 23 26 :2 10 29 2b :2 29
10 1b :2 24 10 13 1c 23 :2 1c
31 :2 13 34 36 :2 34 13 22 13
38 13 22 29 35 38 :2 29 41
44 :2 22 :2 13 22 29 35 38 :2 29
42 45 :2 22 13 :4 10 2f 10 1b
24 30 :2 1b 10 13 1c 23 :2 1c
30 :2 13 33 35 :2 33 13 21 13
37 13 21 28 33 36 :2 28 3f
42 :2 21 :2 13 21 28 33 36 :2 28
40 43 :2 21 13 :4 10 :4 d 10 17
23 26 :2 10 29 2b :2 29 24 2c
33 51 59 60 7a 82 89 18
33 40 18 28 19 21 32 3e
4b :2 13 :2 1c 28 13 10 :2 18 16
:2 1f 2b 16 19 :2 23 35 :2 3f 4b
4f 5e 61 62 :2 5e :2 35 :3 19 :2 1f
24 30 6e 71 :2 30 7e 81 :2 30
85 88 :2 30 94 97 :2 30 9f a2
:2 30 ae b1 b8 c1 c4 :2 b1 :2 30
:2 19 65 :2 16 :2 13 :4 1f :2 13 10 :3 2f
10 1b :2 10 1f 10 2f 24 2c
33 51 59 60 7a 82 89 18
33 40 18 28 19 21 32 3e
4b 61 :2 13 :2 1c 28 13 10 :2 18
16 :2 1f 2b 16 19 :2 23 35 :2 3f
4b 4f 5e 61 62 :2 5e :2 35 :3 19
:2 1f 24 30 6e 71 :2 30 7e 81
:2 30 85 88 :2 30 94 97 :2 30 9f
a2 :2 30 ae b1 b8 c1 c4 :2 b1
:2 30 :2 19 65 :2 16 :2 13 :4 1f :2 13 10
:3 d 14 :2 1d 28 26 :2 31 :2 26 13
27 2f 36 54 5c 63 7d 85
8c 1b 36 43 1b 2b 1c 24
35 41 4e 64 :2 16 :2 1f 2b 16
13 :2 1b 19 :2 22 2e 19 1c :2 26
38 :2 42 4e 52 61 64 65 :2 61
:2 38 :3 1c :2 22 27 33 71 74 :2 33
81 84 :2 33 88 8b :2 33 97 9a
:2 33 a2 a5 :2 33 b1 b4 bb c4
c7 :2 b4 :2 33 :2 1c 68 :2 19 :2 16 :4 22
:2 16 13 :4 41 :2 10 :5 d 1b d 10
17 23 26 :2 10 29 2b :2 29 10
1b :2 24 10 2f 10 1b 24 30
:2 1b 10 :5 d 1b :2 d 19 25 32
40 4b 55 61 1b 28 35 42
4f 1b 28 34 3e 46 4f 57
5e 1b 27 34 3f 4a 58 1b
26 32 3e 41 44 4a :2 19 d
10 19 1b :2 19 1a 2d 4a 51
13 1a 16 22 :3 20 16 :2 1f 2b
16 27 16 :2 1f 2b 16 :4 13 10
:2 18 16 :2 1f 2b 16 19 :2 23 35
:2 3f 4b 4f 5e 61 62 :2 5e :2 35
:3 19 :2 1f 24 30 6e 71 :2 30 7e
81 :2 30 85 88 :2 30 94 97 :2 30
9f a2 :2 30 ae b1 b8 c1 c4
:2 b1 :2 30 :2 19 65 :2 16 :2 13 :4 1f :2 13
10 :4 1d :3 d 18 21 2a :2 18 2d
2f :2 18 d 30 e a 17 :2 7
:4 4 8 11 14 :2 11 7 1c 25
2d :2 1c 30 32 :2 30 1b :2 7 a
:2 14 26 :2 30 3c 40 4f 52 53
:2 4f :2 26 :3 a :2 10 15 21 5f 62
:2 21 6f 72 :2 21 76 79 :2 21 83
86 8f 97 :2 a0 :2 8f c1 :2 86 :2 21
c9 cc :2 21 d4 d7 :2 21 dc df
:2 21 eb ee :2 21 :2 a 56 :2 7 a
:2 14 26 :2 30 3c 3f 4e 51 52
:2 4e :2 26 :3 a :2 10 15 21 5f 62
:2 21 :2 a 55 :3 7 :2 12 26 :2 2f 4f
f :2 7 35 :2 4 7 10 18 :2 7
1b 1d :2 1b 7 17 7 1f :2 4
8 11 18 :2 11 25 :2 8 28 2a
:2 28 7 32 3b 42 :2 3b 50 :2 32
53 55 :2 53 31 :3 7 d e 11
:2 d e 11 :2 d e 11 :2 d e
11 :2 d 2c 2f 37 40 4a :2 37
:2 2f :2 d 4e 51 :2 d 13 16 1e
27 30 :2 1e :2 16 :2 d 13 16 :2 d
e 11 19 22 2d :2 19 :2 11 :2 d
13 16 :2 d e 11 :2 d e 11
:2 d e 11 :2 d e 11 :2 d e
11 :2 d 29 2c :2 d 13 16 :2 d
4e 51 :2 d 13 16 :2 d e 11
:2 d e 11 :2 d e 11 :2 d e
11 :2 1a :2 d 32 35 :2 d 48 4b
:2 54 :2 d 13 16 :2 d e 11 :2 d
e 11 :2 d 47 4a 52 5b 65
:2 52 :2 4a :2 d 13 16 :2 d 2a 2d
35 3e 47 :2 35 :2 2d :2 d 4b 4e
:2 d e 11 :2 d 54 57 5f 13
1e :2 5f :2 57 :2 d 13 16 :2 d e
11 :2 d 4d 50 :2 d 13 16 :2 d
50 53 :2 d 13 16 :2 d e 11
:2 d e 11 :2 d 7 4 58 a
13 1a :2 13 27 :2 a 2a 2c :2 2a
7 d e 11 :2 d e 11 :2 d
e 11 :2 d e 11 :2 d 2c 2f
37 40 4a :2 37 :2 2f :2 d 4e 51
:2 d 13 16 1e 27 30 :2 1e :2 16
:2 d 13 16 :2 d e 11 19 22
2d :2 19 :2 11 :2 d 13 16 :2 d e
11 :2 d e 11 :2 d e 11 :2 d
e 11 :2 d e 11 :2 d 29 2c
:2 d 13 16 :2 d 4e 51 :2 d 13
16 :2 d e 11 :2 d 7 4 2e
58 a 13 1a :2 13 28 :2 a 2b
2d :2 2b 7 d e 11 :2 d e
11 :2 1a :2 d 32 35 :2 d 48 4b
:2 54 :2 d 13 16 :2 d e 11 :2 d
e 11 :2 d 47 4a 52 5b 65
:2 52 :2 4a :2 d 13 16 :2 d 2a 2d
35 3e 47 :2 35 :2 2d :2 d 4b 4e
:2 d e 11 :2 d 54 57 5f 13
1e :2 5f :2 57 :2 d 13 16 :2 d e
11 :2 d 4d 50 :2 d 13 16 :2 d
50 53 :2 d 13 16 :2 d e 11
:2 d e 11 :2 d 7 2f 58 :2 4
7 :2 11 23 :2 2d 39 3c 4b 4e
4f :2 4b :2 23 :3 7 :2 d 12 1e 5c
5f :2 1e :2 7 52 :2 4 7 :2 11 23
:2 2d 39 3c 4b 4e 4f :2 4b :2 23
:3 7 :2 d 12 1e 5c 5f :2 1e :2 7
52 :3 4 b :2 16 26 :2 b 4 1
9 12 9 a :2 14 26 :2 30 3c
40 4f 52 53 :2 4f :2 26 :3 a :2 10
15 21 5f 62 :2 21 :3 a :2 10 15
39 5c 5f :2 68 :2 39 76 79 :2 39
81 84 :2 8d :2 39 :2 a 56 :3 7 c
15 1e 2c a 13 1e f e
7 e 7 e 7 29 :2 4 :2 9
7 :2 10 1c :2 7 :2 11 23 :2 2d 39
3d 4c 4f 50 :2 4c :2 23 :3 7 :2 d
12 1e 5c 5f :2 1e :3 7 :2 d 12
36 42 45 :2 36 4d 50 :2 36 5c
5f 66 6f 72 :2 5f :2 36 :2 7 53
:2 4 7 c 1b a 13 1e f
e 7 e 7 e 7 :2 4 :4 10
:2 4 :8 1 
19b9
4
0 :2 1 :4 3 :4 4
:4 5 :4 6 :4 7 :4 8
:4 9 :4 a :4 b :4 c
:4 d :4 e :4 f :4 10
:4 11 2 :4 12 :2 1
:7 14 :7 15 :7 16 :7 17
:7 18 :7 19 :7 1a :5 1b
:7 1c :7 1d :7 1e :7 1f
:7 20 :7 21 :7 22 :7 23
:5 24 :5 25 :7 26 :6 27
:6 28 :6 29 :6 2a :6 2b
:6 2c :6 2d :6 2e :6 2f
:6 30 :6 31 :6 32 :6 33
:6 34 :6 35 :6 36 :6 37
:6 38 :6 39 :6 3a :6 3b
:6 3c :6 3d :6 3e :6 3f
:6 40 :6 41 :6 42 :6 43
:6 44 :7 45 :7 46 :6 47
:6 48 :7 49 :6 4a :6 4b
:6 4c :6 4d :6 4e :6 4f
:5 50 :7 52 :b 54 :11 55
56 :2 55 :2 56 :2 55
:2 56 :2 55 :2 57 :2 55
:2 57 :2 55 :2 57 :2 55
:2 57 :2 55 :2 58 :2 55
:2 58 :2 55 :2 58 :2 55
:2 58 :2 55 :2 59 :2 55
:9 59 :2 55 :2 5a :2 55
:9 5a :2 55 :2 5b :2 55
:9 5b :2 55 :2 5c :2 55
:9 5c :2 55 :2 5d :2 55
:9 5d :2 55 :2 5e :2 55
:9 5e :2 55 :2 5f :2 55
:9 5f :2 55 :2 60 :2 55
:9 60 :2 55 :2 61 :2 55
:9 61 :2 55 :2 62 :2 55
:9 62 :2 55 :2 63 :2 55
:2 63 :2 55 :2 63 :2 55
:2 63 :2 55 :2 64 :2 55
:2 64 :2 55 :2 64 :2 55
:2 64 :2 55 :2 64 :4 55
:3 54 :11 67 :b 68 :3 67
:3 6f :3 70 :3 71 :3 72
:3 74 :3 76 :3 78 :3 7a
:3 7b :3 7c :3 7d :3 7e
:3 7f :3 80 :3 82 :a 83
:3 88 :3 89 :5 8b :11 8c
:20 8d :3 8c :11 8f :b 90
:3 8f :9 92 :3 8b :1f 9f
:11 a0 :20 a1 :3 a0 :11 a3
:b a4 :3 a3 :9 a6 :3 9f
:14 a9 :6 aa :2 a9 :6 ac
ad ae ac :5 af
ab :2 b1 :5 b3 :11 b4
:24 b5 :3 b4 :2 b2 :6 b1
b0 :3 aa :16 ba :11 bb
:20 bc :3 bb :11 be :b bf
:3 be :9 c1 :3 ba :3 c4
c5 aa :e c5 :2 c7
c8 c7 :5 c9 c6
:2 cb :5 cd :11 ce :24 cf
:3 ce :2 cc :6 cb ca
:4 c5 aa :2 a9 :3 d5
:14 d7 :e d9 :9 dc :5 de
:3 df :3 e0 de :5 e1
dd :2 e3 :5 e5 :11 e6
:24 e7 :3 e6 :2 e4 :6 e3
e2 :3 dc :a ec :7 ee
:5 ef ed :2 f1 :5 f3
:11 f4 :24 f5 :3 f4 :2 f2
:6 f1 f0 :3 ec :a f9
:11 fa :30 fb :3 fa :11 fd
:b fe :3 fd :a 100 :3 f9
:3 ec :3 104 :2 106 107
:2 108 106 :5 109 105
:2 10b :5 10d :11 10e :24 10f
:3 10e :2 10c :6 10b 10a
:3 dc :9 114 :2 116 117
:2 118 116 :5 119 115
:2 11b :5 11d :11 11e :24 11f
:3 11e :2 11c :6 11b 11a
:3 114 :b 124 :11 125 :30 126
:3 125 :11 128 :b 129 :3 128
:a 12b :3 124 :3 114 dc
:5 12f :11 130 :20 131 :3 130
:11 133 :b 134 :3 133 :9 136
:3 12f :3 139 :d 13d :b 141
:c 143 :6 145 :4 146 :e 147
145 :5 148 144 :2 14a
:5 14c :11 14d :24 14e :3 14d
:2 14b :6 14a 149 :3 143
:a 153 :11 154 :30 155 :3 154
:11 157 :b 158 :3 157 :a 15a
:3 153 143 :11 15d :30 15e
:3 15d :11 160 :b 161 :3 160
:a 163 15c :3 143 12e
:3 dc :16 168 :3 169 :3 168
:5 16c :3 16e :3 16f :e 171
:b 172 :2 173 :2 172 :a 173
:8 174 :3 171 :b 176 :11 177
:20 178 :3 177 :11 17a :b 17b
:3 17a :9 17d 17e 176
:9 17e :11 17f :2e 180 :3 17f
:11 182 :b 183 :3 182 :c 185
17e :3 176 :3 16c :16 188
:16 189 :3 18a 18b 189
:9 18b :3 18c 18d 18b
189 :16 18d :3 18e 18f
18d 189 :9 18f :f 190
:3 191 18f :3 189 :3 188
:9 196 :9 197 :11 198 :30 199
:3 198 :11 19b :b 19c :3 19b
:a 19e :3 197 :9 1a0 :3 1a1
1a0 :11 1a3 1a2 :3 1a0
:3 196 :5 1a7 :3 1aa :3 1ab
:3 1ac :3 1ad :8 1af :8 1b1
:9 1b6 :3 1b7 :3 1b8 :a 1b9
:9 1c3 :2 1c4 :5 1c5 :2 1c6
1c7 :6 1c8 1c3 :5 1c9
1c2 :2 1cb :5 1cd :11 1ce
:24 1cf :3 1ce :2 1cc :6 1cb
1ca :3 1b9 :6 1d5 :5 1d6
1d4 :2 1d8 :5 1da :11 1db
:24 1dc :3 1db :2 1d9 :6 1d8
1d7 :3 1b9 :a 1e1 :11 1e2
:30 1e3 :3 1e2 :11 1e5 :b 1e6
:3 1e5 :a 1e8 :3 1e1 :3 1eb
:4 1ee 1ef :5 1f0 1ee
:5 1f1 1ed :2 1f3 :5 1f5
:11 1f6 :24 1f7 :3 1f6 :2 1f4
:6 1f3 1f2 :3 1b9 1fb
1b9 :a 1fb :6 1fd :5 1fe
1fc :2 200 :5 202 :11 203
:24 204 :3 203 :2 201 :6 200
1ff :3 1fb :a 209 :11 20a
:30 20b :3 20a :11 20d :b 20e
:3 20d :a 210 :3 209 :3 213
:9 216 :2 217 :5 218 :2 219
21a :6 21b 216 :5 21c
215 :2 21e :5 220 :11 221
:24 222 :3 221 :2 21f :6 21e
21d :3 1fb :a 233 :9 235
:2 236 :5 237 :2 238 239
:6 23a 235 :5 23b 234
:2 23d :5 23f :11 240 :24 241
:3 240 :2 23e :6 23d 23c
:6 233 :4 249 24a :5 24b
249 :5 24c 248 :2 24e
:5 250 :11 251 :24 252 :3 251
:2 24f :6 24e 24d :4 1fb
1b9 :11 257 :20 258 :3 257
:11 25a :b 25b :3 25a :9 25d
256 :3 1b9 :a 261 :b 262
263 :3 262 :b 264 265
:3 264 :2 268 :f 26a :4 26b
:4 26c :5 26d 26e :3 270
271 :2 273 268 :6 274
:5 275 274 :5 277 276
:3 274 267 :2 27a :5 27c
:11 27d :24 27e :3 27d :2 27b
:6 27a 279 :3 261 :6 283
261 :5 286 :b 288 289
:3 288 :5 28b :3 28c :6 28e
:3 28f :3 28e :6 292 :6 293
:5 294 :7 295 292 :6 296
:5 297 296 :5 299 298
:3 296 291 :2 29c :5 29e
:11 29f :24 2a0 :3 29f :2 29d
:6 29c 29b :4 284 :3 261
:12 2a7 :6 2a9 :5 2aa 2a8
:2 2ac :5 2ae :11 2af :24 2b0
:3 2af :2 2ad :6 2ac 2ab
:3 2a7 :a 2b6 :6 2b7 :8 2b8
:4 2b9 :2 2ba :3 2b8 :3 2b6
:3 2a7 :3 2be :a 2c3 :5 2c4
2c3 :7 2c7 2c5 :3 2c3
:8 2cb :5 2cc :8 2cd :6 2ce
:7 2cf :3 2cb :5 2d2 :5 2d4
:6 2d5 :5 2d6 2d5 :5 2d8
2d7 :3 2d5 2d3 :2 2db
:5 2dd :11 2de :24 2df :3 2de
:2 2dc :6 2db 2da :6 2d2
1b6 :3 2e5 :3 2e6 :3 2e8
:c 2ea :3 2eb 2ea :16 2ed
2ec :3 2ea :5 2f0 :3 2f1
:c 2f2 :17 2f5 :1b 2f7 :a 2f9
:5 2fa :c 2fc :3 2fd 2fc
:c 2ff :c 300 2fe :3 2fc
2f9 :7 303 :c 305 :3 306
305 :c 308 :c 309 307
:3 305 302 :3 2f9 :a 30d
:9 30f :3 310 :2 311 :5 312
30f :5 313 30e :2 315
:5 317 :11 318 :24 319 :3 318
:2 316 :6 315 314 :3 30d
:3 31e :3 31f 30d :9 323
:3 324 :2 325 :6 326 323
:5 327 322 :2 329 :5 32b
:11 32c :24 32d :3 32c :2 32a
:6 329 328 :3 321 :a 332
:9 334 :3 335 :2 336 :6 337
334 :5 338 333 :2 33a
:5 33c :11 33d :24 33e :3 33d
:2 33b :6 33a 339 :6 332
321 :3 30d :3 346 :a 348
:5 349 348 :7 34b 34a
:3 348 :3 34e :8 350 :5 351
:8 352 :6 353 :7 354 :3 350
:5 357 :5 359 :6 35a :5 35b
35a :5 35d 35c :3 35a
358 :2 360 :5 362 :11 363
:24 364 :3 363 :2 361 :6 360
35f :6 357 :b 36a 2f2
36b 2f2 :3 2f0 2e4
:3 1b6 :12 370 :11 371 :30 372
:3 371 :11 374 :b 375 :3 374
:7 377 378 :2 377 :3 370
:9 37b :3 37c :3 37b :1c 381
382 383 :2 384 :2 383
:2 385 :2 383 :2 386 :2 383
:2 387 :2 383 :9 387 :2 383
:2 387 :2 383 :9 388 :2 383
:2 389 :2 383 :9 38a :2 383
:2 38b :2 383 :2 38c :2 383
:2 38d :2 383 :2 38e :2 383
:2 38f :2 383 :2 390 :2 383
:2 390 :2 383 :2 391 :2 383
:2 391 :2 383 :2 392 :2 383
:2 393 :2 383 :2 394 :2 383
:2 395 :2 383 :4 396 :2 383
:2 396 :2 383 :4 396 :2 383
:2 397 :2 383 :2 398 :2 383
:2 399 :2 383 :9 399 :2 383
:2 39a :2 383 :9 39a :2 383
:2 39a :2 383 :2 39b :2 383
:3 39b :2 39c :4 39b :2 383
:2 39d :2 383 :2 39e :2 383
:2 39e :2 383 :2 39f :2 383
:2 39f :2 383 :2 3a0 :2 383
:2 3a1 :2 383 :2 3a2 :2 383
382 3a3 381 :c 3a3
3a4 3a5 :2 3a6 :2 3a5
:2 3a7 :2 3a5 :2 3a8 :2 3a5
:2 3a9 :2 3a5 :9 3a9 :2 3a5
:2 3a9 :2 3a5 :9 3aa :2 3a5
:2 3ab :2 3a5 :9 3ac :2 3a5
:2 3ad :2 3a5 :2 3ae :2 3a5
:2 3af :2 3a5 :2 3b0 :2 3a5
:2 3b1 :2 3a5 :2 3b2 :2 3a5
:2 3b2 :2 3a5 :2 3b3 :2 3a5
:2 3b3 :2 3a5 :2 3b4 :2 3a5
:2 3b5 :2 3a5 3a4 3b6
3a3 381 :c 3b6 3b7
3b8 :2 3b9 :2 3b8 :4 3ba
:2 3b8 :2 3ba :2 3b8 :4 3ba
:2 3b8 :2 3bb :2 3b8 :2 3bc
:2 3b8 :2 3bd :2 3b8 :9 3bd
:2 3b8 :2 3be :2 3b8 :9 3be
:2 3b8 :2 3be :2 3b8 :2 3bf
:2 3b8 :3 3bf :2 3c0 :4 3bf
:2 3b8 :2 3c1 :2 3b8 :2 3c2
:2 3b8 :2 3c2 :2 3b8 :2 3c3
:2 3b8 :2 3c3 :2 3b8 :2 3c4
:2 3b8 :2 3c5 :2 3b8 :2 3c6
:2 3b8 3b7 3b6 :3 381
:11 3ca :b 3cb :3 3ca :11 3cd
:b 3ce :3 3cd :8 3d0 53
:3 3d4 :11 3d5 :b 3d6 :17 3d7
:3 3d5 :2 3d9 :3 3da :3 3db
3dc 3da 3d9 3da
:3 3dd :3 3d4 :2 3de :5 3e0
:11 3e1 :b 3e2 :18 3e3 :3 3e1
:2 3e5 3e6 :3 3e7 3e8
3e6 3e5 3e6 :3 3e9
:2 3df :6 3de 3d3 :7 1

58fe
4
:3 0 1 :3 0 2
:a 0 19b4 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
56 0 7 4
:3 0 5 :7 0 9
8 :3 0 4 :3 0
6 :7 0 d c
:3 0 d 7c 0
b 8 :3 0 7
:7 0 11 10 :3 0
8 :3 0 9 :7 0
15 14 :3 0 11
a2 0 f 8
:3 0 a :7 0 19
18 :3 0 8 :3 0
b :7 0 1d 1c
:3 0 15 c8 0
13 8 :3 0 c
:7 0 21 20 :3 0
8 :3 0 d :7 0
25 24 :3 0 19
ee 0 17 8
:3 0 e :7 0 29
28 :3 0 8 :3 0
f :7 0 2d 2c
:3 0 1d 114 0
1b 8 :3 0 10
:7 0 31 30 :3 0
8 :3 0 11 :7 0
35 34 :3 0 21
:2 0 1f 4 :3 0
12 :7 0 39 38
:3 0 4 :3 0 13
:7 0 3d 3c :3 0
14 :3 0 15 :3 0
16 :2 0 4 41
42 0 3f 43
0 19b4 2 44
:2 0 18 :2 0 33
4 :3 0 18 :2 0
31 47 49 :6 0
4c 4a 0 19b2
0 17 :6 0 18
:2 0 37 4 :3 0
35 4e 50 :6 0
53 51 0 19b2
0 19 :6 0 18
:2 0 3b 4 :3 0
39 55 57 :6 0
5a 58 0 19b2
0 1a :6 0 1d
:2 0 3f 4 :3 0
3d 5c 5e :6 0
61 5f 0 19b2
0 1b :6 0 1d
:2 0 43 4 :3 0
41 63 65 :6 0
68 66 0 19b2
0 1c :6 0 1d
:2 0 47 4 :3 0
45 6a 6c :6 0
6f 6d 0 19b2
0 1e :6 0 4d
21f 0 4b 4
:3 0 49 71 73
:6 0 76 74 0
19b2 0 1f :6 0
23 :2 0 51 21
:3 0 78 :7 0 7b
79 0 19b2 0
20 :6 0 4 :3 0
23 :2 0 4f 7d
7f :6 0 82 80
0 19b2 0 22
:6 0 23 :2 0 55
4 :3 0 53 84
86 :6 0 89 87
0 19b2 0 24
:6 0 18 :2 0 59
4 :3 0 57 8b
8d :6 0 90 8e
0 19b2 0 25
:6 0 18 :2 0 5d
4 :3 0 5b 92
94 :6 0 97 95
0 19b2 0 26
:6 0 29 :2 0 61
4 :3 0 5f 99
9b :6 0 9e 9c
0 19b2 0 27
:6 0 29 :2 0 65
4 :3 0 63 a0
a2 :6 0 a5 a3
0 19b2 0 28
:6 0 29 :2 0 69
4 :3 0 67 a7
a9 :6 0 ac aa
0 19b2 0 2a
:6 0 6f 322 0
6d 4 :3 0 6b
ae b0 :6 0 b3
b1 0 19b2 0
2b :6 0 2f :2 0
71 21 :3 0 b5
:7 0 b8 b6 0
19b2 0 2c :6 0
21 :3 0 ba :7 0
bd bb 0 19b2
0 2d :6 0 31
:2 0 75 4 :3 0
73 bf c1 :6 0
c4 c2 0 19b2
0 2e :6 0 31
:2 0 77 8 :3 0
c6 :7 0 ca c7
c8 19b2 0 30
:6 0 31 :2 0 79
8 :3 0 cc :7 0
d0 cd ce 19b2
0 32 :6 0 31
:2 0 7b 8 :3 0
d2 :7 0 d6 d3
d4 19b2 0 33
:6 0 31 :2 0 7d
8 :3 0 d8 :7 0
dc d9 da 19b2
0 34 :6 0 31
:2 0 7f 8 :3 0
de :7 0 e2 df
e0 19b2 0 35
:6 0 31 :2 0 81
8 :3 0 e4 :7 0
e8 e5 e6 19b2
0 36 :6 0 31
:2 0 83 8 :3 0
ea :7 0 ee eb
ec 19b2 0 37
:6 0 31 :2 0 85
8 :3 0 f0 :7 0
f4 f1 f2 19b2
0 38 :6 0 31
:2 0 87 8 :3 0
f6 :7 0 fa f7
f8 19b2 0 39
:6 0 31 :2 0 89
8 :3 0 fc :7 0
100 fd fe 19b2
0 3a :6 0 31
:2 0 8b 8 :3 0
102 :7 0 106 103
104 19b2 0 3b
:6 0 31 :2 0 8d
8 :3 0 108 :7 0
10c 109 10a 19b2
0 3c :6 0 31
:2 0 8f 8 :3 0
10e :7 0 112 10f
110 19b2 0 3d
:6 0 31 :2 0 91
8 :3 0 114 :7 0
118 115 116 19b2
0 3e :6 0 31
:2 0 93 8 :3 0
11a :7 0 11e 11b
11c 19b2 0 3f
:6 0 31 :2 0 95
8 :3 0 120 :7 0
124 121 122 19b2
0 40 :6 0 31
:2 0 97 8 :3 0
126 :7 0 12a 127
128 19b2 0 41
:6 0 31 :2 0 99
8 :3 0 12c :7 0
130 12d 12e 19b2
0 42 :6 0 31
:2 0 9b 8 :3 0
132 :7 0 136 133
134 19b2 0 43
:6 0 31 :2 0 9d
8 :3 0 138 :7 0
13c 139 13a 19b2
0 44 :6 0 31
:2 0 9f 8 :3 0
13e :7 0 142 13f
140 19b2 0 45
:6 0 31 :2 0 a1
8 :3 0 144 :7 0
148 145 146 19b2
0 46 :6 0 31
:2 0 a3 8 :3 0
14a :7 0 14e 14b
14c 19b2 0 47
:6 0 31 :2 0 a5
49 :3 0 150 :7 0
154 151 152 19b2
0 48 :6 0 31
:2 0 a7 8 :3 0
156 :7 0 15a 157
158 19b2 0 4a
:6 0 31 :2 0 a9
8 :3 0 15c :7 0
160 15d 15e 19b2
0 4b :6 0 4e
:2 0 ab 8 :3 0
162 :7 0 166 163
164 19b2 0 4c
:6 0 4e :2 0 ad
49 :3 0 168 :7 0
16c 169 16a 19b2
0 4d :6 0 31
:2 0 af 49 :3 0
16e :7 0 172 16f
170 19b2 0 4f
:6 0 18 :2 0 b1
8 :3 0 174 :7 0
178 175 176 19b2
0 50 :6 0 18
:2 0 b5 52 :3 0
b3 17a 17c :6 0
17f 17d 0 19b2
0 51 :6 0 31
:2 0 b9 52 :3 0
b7 181 183 :6 0
186 184 0 19b2
0 53 :6 0 31
:2 0 bb 8 :3 0
188 :7 0 18c 189
18a 19b2 0 54
:6 0 57 :2 0 bd
8 :3 0 18e :7 0
192 18f 190 19b2
0 55 :6 0 31
:2 0 c1 4 :3 0
bf 194 196 :6 0
199 197 0 19b2
0 56 :6 0 31
:2 0 c3 8 :3 0
19b :7 0 19f 19c
19d 19b2 0 58
:6 0 23 :2 0 c5
8 :3 0 1a1 :7 0
1a5 1a2 1a3 19b2
0 59 :6 0 23
:2 0 c7 8 :3 0
1a7 0 2 :5 0
1ab 1a8 1a9 19b2
0 5a :6 0 31
:2 0 c9 8 :3 0
1ad 0 2 :5 0
1b1 1ae 1af 19b2
0 5b :6 0 31
:2 0 cb 8 :3 0
1b3 0 2 :5 0
1b7 1b4 1b5 19b2
0 5c :6 0 cf
7f2 0 cd 8
:3 0 1b9 0 2
:5 0 1bd 1ba 1bb
19b2 0 5d :6 0
1ca 1cb 0 d1
8 :3 0 1bf :7 0
1c2 1c0 0 19b2
0 5e :6 0 15
:3 0 16 :2 0 4
1c4 1c5 0 1c6
:7 0 1c9 1c7 0
19b2 0 5f :6 0
60 :3 0 61 :3 0
60 :3 0 62 :3 0
1cd 1ce 0 2
:4 0 d3 1cf 1d1
1cc 1d3 1d2 :2 0
63 :3 0 64 :3 0
1d5 1d6 0 65
:4 0 60 :3 0 66
:3 0 1d9 1da 0
2 :4 0 d5 1db
1dd 67 :4 0 68
:2 0 69 :3 0 d7
1e0 1e2 :3 0 6a
:4 0 68 :2 0 6b
:4 0 da 1e5 1e7
:3 0 68 :2 0 3
:3 0 dd 1e9 1eb
:3 0 68 :2 0 6b
:4 0 e0 1ed 1ef
:3 0 68 :2 0 6c
:4 0 e3 1f1 1f3
:3 0 68 :2 0 6b
:4 0 e6 1f5 1f7
:3 0 68 :2 0 5
:3 0 e9 1f9 1fb
:3 0 68 :2 0 6b
:4 0 ec 1fd 1ff
:3 0 68 :2 0 6c
:4 0 ef 201 203
:3 0 68 :2 0 6b
:4 0 f2 205 207
:3 0 68 :2 0 6
:3 0 f5 209 20b
:3 0 68 :2 0 6b
:4 0 f8 20d 20f
:3 0 68 :2 0 6c
:4 0 fb 211 213
:3 0 68 :2 0 6d
:3 0 6e :3 0 7
:3 0 fe 217 219
6f :4 0 100 216
21c 103 215 21e
:3 0 68 :2 0 6c
:4 0 106 220 222
:3 0 68 :2 0 6d
:3 0 6e :3 0 9
:3 0 109 226 228
6f :4 0 10b 225
22b 10e 224 22d
:3 0 68 :2 0 6c
:4 0 111 22f 231
:3 0 68 :2 0 6d
:3 0 6e :3 0 a
:3 0 114 235 237
6f :4 0 116 234
23a 119 233 23c
:3 0 68 :2 0 6c
:4 0 11c 23e 240
:3 0 68 :2 0 6d
:3 0 6e :3 0 b
:3 0 11f 244 246
6f :4 0 121 243
249 124 242 24b
:3 0 68 :2 0 6c
:4 0 127 24d 24f
:3 0 68 :2 0 6d
:3 0 6e :3 0 c
:3 0 12a 253 255
6f :4 0 12c 252
258 12f 251 25a
:3 0 68 :2 0 6c
:4 0 132 25c 25e
:3 0 68 :2 0 6d
:3 0 6e :3 0 d
:3 0 135 262 264
6f :4 0 137 261
267 13a 260 269
:3 0 68 :2 0 6c
:4 0 13d 26b 26d
:3 0 68 :2 0 6d
:3 0 6e :3 0 e
:3 0 140 271 273
6f :4 0 142 270
276 145 26f 278
:3 0 68 :2 0 6c
:4 0 148 27a 27c
:3 0 68 :2 0 6d
:3 0 6e :3 0 f
:3 0 14b 280 282
6f :4 0 14d 27f
285 150 27e 287
:3 0 68 :2 0 6c
:4 0 153 289 28b
:3 0 68 :2 0 6d
:3 0 6e :3 0 10
:3 0 156 28f 291
6f :4 0 158 28e
294 15b 28d 296
:3 0 68 :2 0 6c
:4 0 15e 298 29a
:3 0 68 :2 0 6d
:3 0 6e :3 0 11
:3 0 161 29e 2a0
6f :4 0 163 29d
2a3 166 29c 2a5
:3 0 68 :2 0 6c
:4 0 169 2a7 2a9
:3 0 68 :2 0 6b
:4 0 16c 2ab 2ad
:3 0 68 :2 0 12
:3 0 16f 2af 2b1
:3 0 68 :2 0 6b
:4 0 172 2b3 2b5
:3 0 68 :2 0 6c
:4 0 175 2b7 2b9
:3 0 68 :2 0 6b
:4 0 178 2bb 2bd
:3 0 68 :2 0 13
:3 0 17b 2bf 2c1
:3 0 68 :2 0 6b
:4 0 17e 2c3 2c5
:3 0 68 :2 0 70
:4 0 181 2c7 2c9
:3 0 184 1d7 2cb
:2 0 2cd 189 2ce
1d4 2cd 0 2cf
18b 0 1912 60
:3 0 61 :3 0 2d0
2d1 0 60 :3 0
71 :3 0 2d3 2d4
0 23 :2 0 2
:4 0 72 :2 0 73
:2 0 23 :2 0 18d
2d9 2db :3 0 190
2d5 2dd 2d2 2df
2de :2 0 63 :3 0
74 :3 0 2e1 2e2
0 65 :4 0 75
:4 0 68 :2 0 69
:3 0 194 2e6 2e8
:3 0 197 2e3 2ea
:2 0 2ec 19a 2ed
2e0 2ec 0 2ee
19c 0 1912 17
:3 0 3 :3 0 2ef
2f0 0 1912 1c
:3 0 5 :3 0 2f2
2f3 0 1912 1f
:3 0 6 :3 0 2f5
2f6 0 1912 1a
:3 0 13 :3 0 2f8
2f9 0 1912 39
:3 0 7 :3 0 2fb
2fc 0 1912 37
:3 0 9 :3 0 2fe
2ff 0 1912 38
:3 0 e :3 0 301
302 0 1912 3a
:3 0 b :3 0 304
305 0 1912 3c
:3 0 f :3 0 307
308 0 1912 3b
:3 0 c :3 0 30a
30b 0 1912 33
:3 0 11 :3 0 30d
30e 0 1912 32
:3 0 a :3 0 310
311 0 1912 3d
:3 0 d :3 0 313
314 0 1912 35
:3 0 10 :3 0 316
317 0 1912 19
:3 0 17 :3 0 319
31a 0 1912 58
:3 0 76 :3 0 6d
:3 0 33 :3 0 31
:2 0 19e 31e 321
1a1 31d 323 31c
324 0 1912 48
:3 0 4e :2 0 326
327 0 1912 34
:3 0 31 :2 0 329
32a 0 1912 3
:3 0 77 :2 0 1a3
32d 32e :3 0 32f
:2 0 60 :3 0 61
:3 0 331 332 0
60 :3 0 71 :3 0
334 335 0 78
:2 0 2 :4 0 79
:2 0 73 :2 0 23
:2 0 1a5 33a 33c
:3 0 1a8 336 33e
333 340 33f :2 0
63 :3 0 74 :3 0
342 343 0 65
:4 0 7a :4 0 68
:2 0 69 :3 0 1ac
347 349 :3 0 68
:2 0 7b :4 0 1af
34b 34d :3 0 68
:2 0 7c :4 0 1b2
34f 351 :3 0 68
:2 0 6d :3 0 6e
:3 0 7d :3 0 7e
:3 0 356 357 0
1b5 355 359 6f
:4 0 1b7 354 35c
1ba 353 35e :3 0
1bd 344 360 :2 0
362 1c0 363 341
362 0 364 1c2
0 38d 60 :3 0
61 :3 0 365 366
0 60 :3 0 71
:3 0 368 369 0
23 :2 0 2 :4 0
7f :2 0 73 :2 0
23 :2 0 1c4 36e
370 :3 0 1c7 36a
372 367 374 373
:2 0 63 :3 0 74
:3 0 376 377 0
65 :4 0 80 :4 0
68 :2 0 69 :3 0
1cb 37b 37d :3 0
1ce 378 37f :2 0
381 1d1 382 375
381 0 383 1d3
0 38d 81 :3 0
82 :3 0 384 385
0 7d :3 0 7e
:3 0 387 388 0
83 :3 0 1d5 386
38b :2 0 38d 1d8
38e 330 38d 0
38f 1dc 0 1912
6d :3 0 32 :3 0
31 :2 0 1de 390
393 84 :2 0 85
:2 0 1e3 395 397
:3 0 6d :3 0 3b
:3 0 31 :2 0 1e6
399 39c 84 :2 0
85 :2 0 1eb 39e
3a0 :3 0 398 3a2
3a1 :2 0 6d :3 0
37 :3 0 31 :2 0
1ee 3a4 3a7 84
:2 0 85 :2 0 1f3
3a9 3ab :3 0 3a3
3ad 3ac :2 0 60
:3 0 61 :3 0 3af
3b0 0 60 :3 0
71 :3 0 3b2 3b3
0 78 :2 0 2
:4 0 86 :2 0 73
:2 0 23 :2 0 1f6
3b8 3ba :3 0 1f9
3b4 3bc 3b1 3be
3bd :2 0 63 :3 0
74 :3 0 3c0 3c1
0 65 :4 0 87
:4 0 68 :2 0 69
:3 0 1fd 3c5 3c7
:3 0 68 :2 0 7b
:4 0 200 3c9 3cb
:3 0 68 :2 0 7c
:4 0 203 3cd 3cf
:3 0 68 :2 0 6d
:3 0 6e :3 0 7d
:3 0 88 :3 0 3d4
3d5 0 206 3d3
3d7 6f :4 0 208
3d2 3da 20b 3d1
3dc :3 0 20e 3c2
3de :2 0 3e0 211
3e1 3bf 3e0 0
3e2 213 0 40b
60 :3 0 61 :3 0
3e3 3e4 0 60
:3 0 71 :3 0 3e6
3e7 0 23 :2 0
2 :4 0 89 :2 0
73 :2 0 23 :2 0
215 3ec 3ee :3 0
218 3e8 3f0 3e5
3f2 3f1 :2 0 63
:3 0 74 :3 0 3f4
3f5 0 65 :4 0
8a :4 0 68 :2 0
69 :3 0 21c 3f9
3fb :3 0 21f 3f6
3fd :2 0 3ff 222
400 3f3 3ff 0
401 224 0 40b
81 :3 0 82 :3 0
402 403 0 7d
:3 0 88 :3 0 405
406 0 83 :3 0
226 404 409 :2 0
40b 229 40c 3ae
40b 0 40d 22d
0 1912 6d :3 0
32 :3 0 31 :2 0
22f 40e 411 7d
:3 0 8b :2 0 8c
:3 0 413 415 0
234 414 417 :3 0
418 :2 0 5 :3 0
8d :2 0 237 41b
41c :3 0 41d :2 0
41e :2 0 419 420
41f :2 0 6 :3 0
8d :2 0 239 423
424 :3 0 425 :2 0
426 :2 0 421 428
427 :2 0 8e :3 0
8f :3 0 6 :3 0
8e :3 0 8f :3 0
5 :3 0 44 :3 0
90 :4 0 91 1
:8 0 438 15 :3 0
92 :3 0 433 434
0 93 :3 0 435
436 0 438 23b
482 94 :3 0 15
:3 0 92 :3 0 43b
43c 0 93 :3 0
43d 43e 0 478
60 :3 0 61 :3 0
440 441 0 60
:3 0 71 :3 0 443
444 0 95 :2 0
2 :4 0 96 :2 0
73 :2 0 23 :2 0
23e 449 44b :3 0
241 445 44d 442
44f 44e :2 0 63
:3 0 74 :3 0 451
452 0 65 :4 0
97 :4 0 68 :2 0
69 :3 0 245 456
458 :3 0 68 :2 0
7b :4 0 248 45a
45c :3 0 68 :2 0
98 :4 0 24b 45e
460 :3 0 68 :2 0
93 :3 0 24e 462
464 :3 0 68 :2 0
99 :4 0 251 466
468 :3 0 68 :2 0
9a :3 0 9b :3 0
23 :2 0 9c :2 0
254 46b 46f 258
46a 471 :3 0 25b
453 473 :2 0 475
25e 476 450 475
0 477 260 0
478 262 47b :3 0
47b 0 47b 47a
478 479 :6 0 47d
2 :3 0 265 47f
267 47e 47d :2 0
480 269 :2 0 482
0 482 481 438
480 :6 0 4fd 1
:3 0 15 :3 0 92
:3 0 484 485 0
15 :3 0 84 :2 0
9d :3 0 487 489
0 26d 488 48b
:3 0 48c :2 0 6d
:3 0 44 :3 0 31
:2 0 270 48e 491
9e :2 0 31 :2 0
275 493 495 :3 0
496 :2 0 48d 498
497 :2 0 60 :3 0
61 :3 0 49a 49b
0 60 :3 0 71
:3 0 49d 49e 0
78 :2 0 2 :4 0
9f :2 0 73 :2 0
23 :2 0 278 4a3
4a5 :3 0 27b 49f
4a7 49c 4a9 4a8
:2 0 63 :3 0 74
:3 0 4ab 4ac 0
65 :4 0 a0 :4 0
68 :2 0 69 :3 0
27f 4b0 4b2 :3 0
68 :2 0 7b :4 0
282 4b4 4b6 :3 0
68 :2 0 7c :4 0
285 4b8 4ba :3 0
68 :2 0 6d :3 0
6e :3 0 7d :3 0
a1 :3 0 4bf 4c0
0 288 4be 4c2
6f :4 0 28a 4bd
4c5 28d 4bc 4c7
:3 0 290 4ad 4c9
:2 0 4cb 293 4cc
4aa 4cb 0 4cd
295 0 4f6 60
:3 0 61 :3 0 4ce
4cf 0 60 :3 0
71 :3 0 4d1 4d2
0 23 :2 0 2
:4 0 a2 :2 0 73
:2 0 23 :2 0 297
4d7 4d9 :3 0 29a
4d3 4db 4d0 4dd
4dc :2 0 63 :3 0
74 :3 0 4df 4e0
0 65 :4 0 a3
:4 0 68 :2 0 69
:3 0 29e 4e4 4e6
:3 0 2a1 4e1 4e8
:2 0 4ea 2a4 4eb
4de 4ea 0 4ec
2a6 0 4f6 81
:3 0 82 :3 0 4ed
4ee 0 7d :3 0
a1 :3 0 4f0 4f1
0 83 :3 0 2a8
4ef 4f4 :2 0 4f6
2ab 4f7 499 4f6
0 4f8 2af 0
4fd 5d :3 0 23
:2 0 4f9 4fa 0
4fd a4 :3 0 2b1
563 5 :3 0 77
:2 0 2b5 4ff 500
:3 0 501 :2 0 502
:2 0 6 :3 0 77
:2 0 2b7 505 506
:3 0 507 :2 0 508
:2 0 503 50a 509
:2 0 69 :3 0 1c
:3 0 90 :4 0 a5
1 :8 0 515 15
:3 0 92 :3 0 510
511 0 93 :3 0
512 513 0 515
2b9 55f 94 :3 0
15 :3 0 92 :3 0
518 519 0 93
:3 0 51a 51b 0
555 60 :3 0 61
:3 0 51d 51e 0
60 :3 0 71 :3 0
520 521 0 95
:2 0 2 :4 0 a6
:2 0 73 :2 0 23
:2 0 2bc 526 528
:3 0 2bf 522 52a
51f 52c 52b :2 0
63 :3 0 74 :3 0
52e 52f 0 65
:4 0 a7 :4 0 68
:2 0 69 :3 0 2c3
533 535 :3 0 68
:2 0 7b :4 0 2c6
537 539 :3 0 68
:2 0 98 :4 0 2c9
53b 53d :3 0 68
:2 0 93 :3 0 2cc
53f 541 :3 0 68
:2 0 99 :4 0 2cf
543 545 :3 0 68
:2 0 9a :3 0 9b
:3 0 23 :2 0 9c
:2 0 2d2 548 54c
2d6 547 54e :3 0
2d9 530 550 :2 0
552 2dc 553 52d
552 0 554 2de
0 555 2e0 558
:3 0 558 0 558
557 555 556 :6 0
55a 4 :3 0 2e3
55c 2e5 55b 55a
:2 0 55d 2e7 :2 0
55f 0 55f 55e
515 55d :6 0 561
1 :3 0 2e9 562
50b 561 0 564
429 4fd 0 564
2eb 0 1912 1e
:3 0 1c :3 0 565
566 0 1912 36
:3 0 a8 :3 0 a9
:3 0 569 56a 0
aa :3 0 6d :3 0
3c :3 0 31 :2 0
2ee 56d 570 7d
:3 0 ab :3 0 572
573 0 2f1 56c
575 576 :2 0 ac
:2 0 2f4 56b 579
568 57a 0 1912
3c :3 0 aa :3 0
6d :3 0 3c :3 0
31 :2 0 2f7 57e
581 7d :3 0 ad
:3 0 583 584 0
2fa 57d 586 587
:2 0 57c 588 0
1912 6d :3 0 33
:3 0 31 :2 0 2fd
58a 58d 84 :2 0
31 :2 0 302 58f
591 :3 0 6d :3 0
ae :3 0 6d :3 0
af :3 0 b0 :3 0
3f :3 0 40 :3 0
46 :3 0 b1 :3 0
b2 :3 0 17 :4 0
b3 1 :8 0 5a4
15 :3 0 92 :3 0
59f 5a0 0 93
:3 0 5a1 5a2 0
5a4 305 5ee 94
:3 0 15 :3 0 92
:3 0 5a7 5a8 0
93 :3 0 5a9 5aa
0 5e4 60 :3 0
61 :3 0 5ac 5ad
0 60 :3 0 71
:3 0 5af 5b0 0
95 :2 0 2 :4 0
b4 :2 0 73 :2 0
23 :2 0 308 5b5
5b7 :3 0 30b 5b1
5b9 5ae 5bb 5ba
:2 0 63 :3 0 74
:3 0 5bd 5be 0
65 :4 0 b5 :4 0
68 :2 0 69 :3 0
30f 5c2 5c4 :3 0
68 :2 0 7b :4 0
312 5c6 5c8 :3 0
68 :2 0 98 :4 0
315 5ca 5cc :3 0
68 :2 0 93 :3 0
318 5ce 5d0 :3 0
68 :2 0 99 :4 0
31b 5d2 5d4 :3 0
68 :2 0 9a :3 0
9b :3 0 23 :2 0
9c :2 0 31e 5d7
5db 322 5d6 5dd
:3 0 325 5bf 5df
:2 0 5e1 328 5e2
5bc 5e1 0 5e3
32a 0 5e4 32c
5e7 :3 0 5e7 0
5e7 5e6 5e4 5e5
:6 0 5e9 6 :3 0
32f 5eb 331 5ea
5e9 :2 0 5ec 333
:2 0 5ee 0 5ee
5ed 5a4 5ec :6 0
807 1 :3 0 15
:3 0 92 :3 0 5f0
5f1 0 15 :3 0
84 :2 0 b6 :3 0
5f3 5f5 0 337
5f4 5f7 :3 0 5f8
:2 0 3f :3 0 40
:3 0 46 :3 0 b7
:3 0 b2 :3 0 17
:4 0 b8 1 :8 0
606 15 :3 0 92
:3 0 601 602 0
93 :3 0 603 604
0 606 33a 650
94 :3 0 15 :3 0
92 :3 0 609 60a
0 93 :3 0 60b
60c 0 646 60
:3 0 61 :3 0 60e
60f 0 60 :3 0
71 :3 0 611 612
0 95 :2 0 2
:4 0 b9 :2 0 73
:2 0 23 :2 0 33d
617 619 :3 0 340
613 61b 610 61d
61c :2 0 63 :3 0
74 :3 0 61f 620
0 65 :4 0 ba
:4 0 68 :2 0 69
:3 0 344 624 626
:3 0 68 :2 0 7b
:4 0 347 628 62a
:3 0 68 :2 0 98
:4 0 34a 62c 62e
:3 0 68 :2 0 93
:3 0 34d 630 632
:3 0 68 :2 0 99
:4 0 350 634 636
:3 0 68 :2 0 9a
:3 0 9b :3 0 23
:2 0 9c :2 0 353
639 63d 357 638
63f :3 0 35a 621
641 :2 0 643 35d
644 61e 643 0
645 35f 0 646
361 649 :3 0 649
0 649 648 646
647 :6 0 64b 8
:3 0 364 64d 366
64c 64b :2 0 64e
368 :2 0 650 0
650 64f 606 64e
:6 0 6cc 1 :3 0
15 :3 0 92 :3 0
652 653 0 15
:3 0 84 :2 0 b6
:3 0 655 657 0
36c 656 659 :3 0
65a :2 0 60 :3 0
61 :3 0 65c 65d
0 60 :3 0 71
:3 0 65f 660 0
18 :2 0 2 :4 0
bb :2 0 73 :2 0
23 :2 0 36f 665
667 :3 0 372 661
669 65e 66b 66a
:2 0 63 :3 0 74
:3 0 66d 66e 0
65 :4 0 bc :4 0
68 :2 0 69 :3 0
376 672 674 :3 0
68 :2 0 7b :4 0
379 676 678 :3 0
68 :2 0 7c :4 0
37c 67a 67c :3 0
68 :2 0 6d :3 0
6e :3 0 7d :3 0
88 :3 0 681 682
0 37f 680 684
6f :4 0 381 67f
687 384 67e 689
:3 0 68 :2 0 bd
:4 0 387 68b 68d
:3 0 68 :2 0 6b
:4 0 38a 68f 691
:3 0 68 :2 0 17
:3 0 38d 693 695
:3 0 68 :2 0 6b
:4 0 390 697 699
:3 0 393 66f 69b
:2 0 69d 396 69e
66c 69d 0 69f
398 0 6c9 60
:3 0 61 :3 0 6a0
6a1 0 60 :3 0
71 :3 0 6a3 6a4
0 23 :2 0 2
:4 0 be :2 0 73
:2 0 23 :2 0 39a
6a9 6ab :3 0 39d
6a5 6ad 6a2 6af
6ae :2 0 63 :3 0
74 :3 0 6b1 6b2
0 65 :4 0 bf
:4 0 68 :2 0 69
:3 0 3a1 6b6 6b8
:3 0 3a4 6b3 6ba
:2 0 6bc 3a7 6bd
6b0 6bc 0 6be
3a9 0 6c9 81
:3 0 c0 :3 0 6bf
6c0 0 7d :3 0
88 :3 0 6c2 6c3
0 17 :3 0 83
:3 0 3ab 6c1 6c7
:2 0 6c9 3af 6ca
65b 6c9 0 6cb
3b3 0 6cc 3b5
6cd 5f9 6cc 0
6ce 3b8 0 807
59 :3 0 31 :2 0
6cf 6d0 0 807
c1 :3 0 59 :3 0
c2 :3 0 c3 :3 0
17 :4 0 c4 1
:8 0 6dd 15 :3 0
92 :3 0 6d8 6d9
0 93 :3 0 6da
6db 0 6dd 3ba
727 94 :3 0 15
:3 0 92 :3 0 6e0
6e1 0 93 :3 0
6e2 6e3 0 71d
60 :3 0 61 :3 0
6e5 6e6 0 60
:3 0 71 :3 0 6e8
6e9 0 95 :2 0
2 :4 0 c5 :2 0
73 :2 0 23 :2 0
3bd 6ee 6f0 :3 0
3c0 6ea 6f2 6e7
6f4 6f3 :2 0 63
:3 0 74 :3 0 6f6
6f7 0 65 :4 0
c6 :4 0 68 :2 0
69 :3 0 3c4 6fb
6fd :3 0 68 :2 0
7b :4 0 3c7 6ff
701 :3 0 68 :2 0
98 :4 0 3ca 703
705 :3 0 68 :2 0
93 :3 0 3cd 707
709 :3 0 68 :2 0
99 :4 0 3d0 70b
70d :3 0 68 :2 0
9a :3 0 9b :3 0
23 :2 0 9c :2 0
3d3 710 714 3d7
70f 716 :3 0 3da
6f8 718 :2 0 71a
3dd 71b 6f5 71a
0 71c 3df 0
71d 3e1 720 :3 0
720 0 720 71f
71d 71e :6 0 722
a :3 0 3e4 724
3e6 723 722 :2 0
725 3e8 :2 0 727
0 727 726 6dd
725 :6 0 807 1
:3 0 6d :3 0 59
:3 0 31 :2 0 3ea
729 72c c7 :2 0
31 :2 0 3ef 72e
730 :3 0 c8 :3 0
22 :3 0 b1 :3 0
b2 :3 0 17 :4 0
c9 1 :8 0 73d
15 :3 0 92 :3 0
738 739 0 93
:3 0 73a 73b 0
73d 3f2 787 94
:3 0 15 :3 0 92
:3 0 740 741 0
93 :3 0 742 743
0 77d 60 :3 0
61 :3 0 745 746
0 60 :3 0 71
:3 0 748 749 0
95 :2 0 2 :4 0
ca :2 0 73 :2 0
23 :2 0 3f5 74e
750 :3 0 3f8 74a
752 747 754 753
:2 0 63 :3 0 74
:3 0 756 757 0
65 :4 0 cb :4 0
68 :2 0 69 :3 0
3fc 75b 75d :3 0
68 :2 0 7b :4 0
3ff 75f 761 :3 0
68 :2 0 98 :4 0
402 763 765 :3 0
68 :2 0 93 :3 0
405 767 769 :3 0
68 :2 0 99 :4 0
408 76b 76d :3 0
68 :2 0 9a :3 0
9b :3 0 23 :2 0
9c :2 0 40b 770
774 40f 76f 776
:3 0 412 758 778
:2 0 77a 415 77b
755 77a 0 77c
417 0 77d 419
780 :3 0 780 0
780 77f 77d 77e
:6 0 782 c :3 0
41c 784 41e 783
782 :2 0 785 420
:2 0 787 0 787
786 73d 785 :6 0
804 1 :3 0 8e
:3 0 cc :3 0 789
78a 0 22 :3 0
cd :4 0 422 78b
78e 84 :2 0 31
:2 0 427 790 792
:3 0 60 :3 0 61
:3 0 794 795 0
60 :3 0 71 :3 0
797 798 0 18
:2 0 2 :4 0 ce
:2 0 73 :2 0 23
:2 0 42a 79d 79f
:3 0 42d 799 7a1
796 7a3 7a2 :2 0
63 :3 0 74 :3 0
7a5 7a6 0 65
:4 0 cf :4 0 68
:2 0 69 :3 0 431
7aa 7ac :3 0 68
:2 0 7b :4 0 434
7ae 7b0 :3 0 68
:2 0 7c :4 0 437
7b2 7b4 :3 0 68
:2 0 6d :3 0 6e
:3 0 7d :3 0 d0
:3 0 7b9 7ba 0
43a 7b8 7bc 6f
:4 0 43c 7b7 7bf
43f 7b6 7c1 :3 0
68 :2 0 bd :4 0
442 7c3 7c5 :3 0
68 :2 0 6b :4 0
445 7c7 7c9 :3 0
68 :2 0 17 :3 0
448 7cb 7cd :3 0
68 :2 0 6b :4 0
44b 7cf 7d1 :3 0
44e 7a7 7d3 :2 0
7d5 451 7d6 7a4
7d5 0 7d7 453
0 801 60 :3 0
61 :3 0 7d8 7d9
0 60 :3 0 71
:3 0 7db 7dc 0
23 :2 0 2 :4 0
d1 :2 0 73 :2 0
23 :2 0 455 7e1
7e3 :3 0 458 7dd
7e5 7da 7e7 7e6
:2 0 63 :3 0 74
:3 0 7e9 7ea 0
65 :4 0 d2 :4 0
68 :2 0 69 :3 0
45c 7ee 7f0 :3 0
45f 7eb 7f2 :2 0
7f4 462 7f5 7e8
7f4 0 7f6 464
0 801 81 :3 0
c0 :3 0 7f7 7f8
0 7d :3 0 d0
:3 0 7fa 7fb 0
17 :3 0 83 :3 0
466 7f9 7ff :2 0
801 46a 802 793
801 0 803 46e
0 804 470 805
731 804 0 806
473 0 807 475
9ea 12 :3 0 77
:2 0 47b 809 80a
:3 0 80b :2 0 60
:3 0 61 :3 0 80d
80e 0 60 :3 0
71 :3 0 810 811
0 78 :2 0 2
:4 0 d3 :2 0 73
:2 0 23 :2 0 47d
816 818 :3 0 480
812 81a 80f 81c
81b :2 0 63 :3 0
74 :3 0 81e 81f
0 65 :4 0 d4
:4 0 68 :2 0 69
:3 0 484 823 825
:3 0 68 :2 0 7b
:4 0 487 827 829
:3 0 68 :2 0 7c
:4 0 48a 82b 82d
:3 0 68 :2 0 6d
:3 0 6e :3 0 7d
:3 0 7e :3 0 832
833 0 48d 831
835 6f :4 0 48f
830 838 492 82f
83a :3 0 495 820
83c :2 0 83e 498
83f 81d 83e 0
840 49a 0 869
60 :3 0 61 :3 0
841 842 0 60
:3 0 71 :3 0 844
845 0 23 :2 0
2 :4 0 d5 :2 0
73 :2 0 23 :2 0
49c 84a 84c :3 0
49f 846 84e 843
850 84f :2 0 63
:3 0 74 :3 0 852
853 0 65 :4 0
d6 :4 0 68 :2 0
69 :3 0 4a3 857
859 :3 0 4a6 854
85b :2 0 85d 4a9
85e 851 85d 0
85f 4ab 0 869
81 :3 0 82 :3 0
860 861 0 7d
:3 0 7e :3 0 863
864 0 83 :3 0
4ad 862 867 :2 0
869 4b0 86a 80c
869 0 86b 4b4
0 9e9 28 :3 0
12 :3 0 86c 86d
0 9e9 1b :3 0
9a :3 0 9a :3 0
28 :3 0 23 :2 0
18 :2 0 4b6 871
875 23 :2 0 18
:2 0 4ba 870 879
86f 87a 0 9e9
24 :3 0 d7 :3 0
d8 :3 0 87d 87e
0 23 :2 0 23
:2 0 d9 :2 0 28
:3 0 4be 87f 884
87c 885 0 9e9
da :3 0 6d :3 0
33 :3 0 31 :2 0
4c3 888 88b 4c6
887 88d 8b :2 0
31 :2 0 4ca 88f
891 :3 0 c3 :3 0
6d :3 0 ae :3 0
6d :3 0 af :3 0
b0 :3 0 17 :3 0
3f :3 0 40 :3 0
46 :3 0 b1 :3 0
b2 :3 0 19 :3 0
db :3 0 7d :3 0
dc :3 0 7d :3 0
dd :3 0 7d :3 0
de :3 0 7d :3 0
df :3 0 7d :3 0
e0 :4 0 e1 1
:8 0 8b1 15 :3 0
92 :3 0 8ac 8ad
0 93 :3 0 8ae
8af 0 8b1 4cd
8fb 94 :3 0 15
:3 0 92 :3 0 8b4
8b5 0 93 :3 0
8b6 8b7 0 8f1
60 :3 0 61 :3 0
8b9 8ba 0 60
:3 0 71 :3 0 8bc
8bd 0 95 :2 0
2 :4 0 e2 :2 0
73 :2 0 23 :2 0
4d0 8c2 8c4 :3 0
4d3 8be 8c6 8bb
8c8 8c7 :2 0 63
:3 0 74 :3 0 8ca
8cb 0 65 :4 0
e3 :4 0 68 :2 0
69 :3 0 4d7 8cf
8d1 :3 0 68 :2 0
7b :4 0 4da 8d3
8d5 :3 0 68 :2 0
98 :4 0 4dd 8d7
8d9 :3 0 68 :2 0
93 :3 0 4e0 8db
8dd :3 0 68 :2 0
99 :4 0 4e3 8df
8e1 :3 0 68 :2 0
9a :3 0 9b :3 0
23 :2 0 9c :2 0
4e6 8e4 8e8 4ea
8e3 8ea :3 0 4ed
8cc 8ec :2 0 8ee
4f0 8ef 8c9 8ee
0 8f0 4f2 0
8f1 4f4 8f4 :3 0
8f4 0 8f4 8f3
8f1 8f2 :6 0 8f6
e :3 0 4f7 8f8
4f9 8f7 8f6 :2 0
8f9 4fb :2 0 8fb
0 8fb 8fa 8b1
8f9 :6 0 977 1
:3 0 15 :3 0 92
:3 0 8fd 8fe 0
15 :3 0 84 :2 0
b6 :3 0 900 902
0 4ff 901 904
:3 0 905 :2 0 60
:3 0 61 :3 0 907
908 0 60 :3 0
71 :3 0 90a 90b
0 18 :2 0 2
:4 0 e4 :2 0 73
:2 0 23 :2 0 502
910 912 :3 0 505
90c 914 909 916
915 :2 0 63 :3 0
74 :3 0 918 919
0 65 :4 0 e5
:4 0 68 :2 0 69
:3 0 509 91d 91f
:3 0 68 :2 0 7b
:4 0 50c 921 923
:3 0 68 :2 0 7c
:4 0 50f 925 927
:3 0 68 :2 0 6d
:3 0 6e :3 0 7d
:3 0 e6 :3 0 92c
92d 0 512 92b
92f 6f :4 0 514
92a 932 517 929
934 :3 0 68 :2 0
bd :4 0 51a 936
938 :3 0 68 :2 0
6b :4 0 51d 93a
93c :3 0 68 :2 0
19 :3 0 520 93e
940 :3 0 68 :2 0
6b :4 0 523 942
944 :3 0 526 91a
946 :2 0 948 529
949 917 948 0
94a 52b 0 974
60 :3 0 61 :3 0
94b 94c 0 60
:3 0 71 :3 0 94e
94f 0 23 :2 0
2 :4 0 e7 :2 0
73 :2 0 23 :2 0
52d 954 956 :3 0
530 950 958 94d
95a 959 :2 0 63
:3 0 74 :3 0 95c
95d 0 65 :4 0
e8 :4 0 68 :2 0
69 :3 0 534 961
963 :3 0 537 95e
965 :2 0 967 53a
968 95b 967 0
969 53c 0 974
81 :3 0 c0 :3 0
96a 96b 0 7d
:3 0 e6 :3 0 96d
96e 0 19 :3 0
83 :3 0 53e 96c
972 :2 0 974 542
975 906 974 0
976 546 0 977
548 9e6 60 :3 0
61 :3 0 978 979
0 60 :3 0 71
:3 0 97b 97c 0
18 :2 0 2 :4 0
e9 :2 0 73 :2 0
23 :2 0 54b 981
983 :3 0 54e 97d
985 97a 987 986
:2 0 63 :3 0 74
:3 0 989 98a 0
65 :4 0 ea :4 0
68 :2 0 69 :3 0
552 98e 990 :3 0
68 :2 0 7b :4 0
555 992 994 :3 0
68 :2 0 7c :4 0
558 996 998 :3 0
68 :2 0 6d :3 0
6e :3 0 7d :3 0
e6 :3 0 99d 99e
0 55b 99c 9a0
6f :4 0 55d 99b
9a3 560 99a 9a5
:3 0 68 :2 0 bd
:4 0 563 9a7 9a9
:3 0 68 :2 0 6b
:4 0 566 9ab 9ad
:3 0 68 :2 0 19
:3 0 569 9af 9b1
:3 0 68 :2 0 6b
:4 0 56c 9b3 9b5
:3 0 56f 98b 9b7
:2 0 9b9 572 9ba
988 9b9 0 9bb
574 0 9e5 60
:3 0 61 :3 0 9bc
9bd 0 60 :3 0
71 :3 0 9bf 9c0
0 23 :2 0 2
:4 0 eb :2 0 73
:2 0 23 :2 0 576
9c5 9c7 :3 0 579
9c1 9c9 9be 9cb
9ca :2 0 63 :3 0
74 :3 0 9cd 9ce
0 65 :4 0 ec
:4 0 68 :2 0 69
:3 0 57d 9d2 9d4
:3 0 580 9cf 9d6
:2 0 9d8 583 9d9
9cc 9d8 0 9da
585 0 9e5 81
:3 0 c0 :3 0 9db
9dc 0 7d :3 0
e6 :3 0 9de 9df
0 19 :3 0 83
:3 0 587 9dd 9e3
:2 0 9e5 58b 9e7
892 977 0 9e8
0 9e5 0 9e8
58f 0 9e9 592
9eb 592 807 0
9ec 0 9e9 0
9ec 598 0 1912
6d :3 0 d :3 0
31 :2 0 59b 9ed
9f0 84 :2 0 31
:2 0 5a0 9f2 9f4
:3 0 9f5 :2 0 6d
:3 0 3b :3 0 31
:2 0 5a3 9f7 9fa
8b :2 0 ed :2 0
5a8 9fc 9fe :3 0
9ff :2 0 9f6 a01
a00 :2 0 37 :3 0
31 :2 0 a03 a04
0 a06 5ab a07
a02 a06 0 a08
5ad 0 1912 5d
:3 0 84 :2 0 31
:2 0 5b1 a0a a0c
:3 0 1e :3 0 5
:3 0 a0e a0f 0
b29 1f :3 0 ee
:4 0 a11 a12 0
b29 59 :3 0 ef
:3 0 1e :3 0 1f
:3 0 6d :3 0 3a
:3 0 31 :2 0 5b4
a18 a1b 6d :3 0
3b :3 0 31 :2 0
5b7 a1d a20 6d
:3 0 3c :3 0 31
:2 0 5ba a22 a25
6d :3 0 32 :3 0
31 :2 0 5bd a27
a2a 6d :3 0 3d
:3 0 31 :2 0 5c0
a2c a2f 6d :3 0
38 :3 0 31 :2 0
5c3 a31 a34 6d
:3 0 3f :3 0 31
:2 0 5c6 a36 a39
6d :3 0 40 :3 0
31 :2 0 5c9 a3b
a3e 37 :3 0 39
:3 0 42 :3 0 5cc
a15 a43 a14 a44
0 b29 6d :3 0
59 :3 0 31 :2 0
5da a46 a49 7d
:3 0 84 :2 0 88
:3 0 a4b a4d 0
5df a4c a4f :3 0
60 :3 0 61 :3 0
a51 a52 0 60
:3 0 71 :3 0 a54
a55 0 78 :2 0
2 :4 0 f0 :2 0
73 :2 0 23 :2 0
5e2 a5a a5c :3 0
5e5 a56 a5e a53
a60 a5f :2 0 63
:3 0 74 :3 0 a62
a63 0 65 :4 0
f1 :4 0 68 :2 0
69 :3 0 5e9 a67
a69 :3 0 68 :2 0
7b :4 0 5ec a6b
a6d :3 0 68 :2 0
7c :4 0 5ef a6f
a71 :3 0 68 :2 0
6d :3 0 6e :3 0
7d :3 0 88 :3 0
a76 a77 0 5f2
a75 a79 6f :4 0
5f4 a74 a7c 5f7
a73 a7e :3 0 5fa
a64 a80 :2 0 a82
5fd a83 a61 a82
0 a84 5ff 0
aae 60 :3 0 61
:3 0 a85 a86 0
60 :3 0 71 :3 0
a88 a89 0 23
:2 0 2 :4 0 f2
:2 0 73 :2 0 23
:2 0 601 a8e a90
:3 0 604 a8a a92
a87 a94 a93 :2 0
63 :3 0 74 :3 0
a96 a97 0 65
:4 0 f3 :4 0 68
:2 0 69 :3 0 608
a9b a9d :3 0 60b
a98 a9f :2 0 aa1
60e aa2 a95 aa1
0 aa3 610 0
aae 81 :3 0 82
:3 0 aa4 aa5 0
7d :3 0 88 :3 0
aa7 aa8 0 83
:3 0 612 aa6 aab
:2 0 aae a4 :3 0
615 b27 6d :3 0
59 :3 0 31 :2 0
619 aaf ab2 8b
:2 0 31 :2 0 61e
ab4 ab6 :3 0 60
:3 0 61 :3 0 ab8
ab9 0 60 :3 0
71 :3 0 abb abc
0 18 :2 0 2
:4 0 f4 :2 0 73
:2 0 23 :2 0 621
ac1 ac3 :3 0 624
abd ac5 aba ac7
ac6 :2 0 63 :3 0
74 :3 0 ac9 aca
0 65 :4 0 f5
:4 0 68 :2 0 69
:3 0 628 ace ad0
:3 0 68 :2 0 7b
:4 0 62b ad2 ad4
:3 0 68 :2 0 7c
:4 0 62e ad6 ad8
:3 0 68 :2 0 6d
:3 0 6e :3 0 59
:3 0 631 adc ade
6f :4 0 633 adb
ae1 636 ada ae3
:3 0 68 :2 0 bd
:4 0 639 ae5 ae7
:3 0 68 :2 0 6b
:4 0 63c ae9 aeb
:3 0 68 :2 0 17
:3 0 63f aed aef
:3 0 68 :2 0 6b
:4 0 642 af1 af3
:3 0 645 acb af5
:2 0 af7 648 af8
ac8 af7 0 af9
64a 0 b25 60
:3 0 61 :3 0 afa
afb 0 60 :3 0
71 :3 0 afd afe
0 23 :2 0 2
:4 0 f6 :2 0 73
:2 0 23 :2 0 64c
b03 b05 :3 0 64f
aff b07 afc b09
b08 :2 0 63 :3 0
74 :3 0 b0b b0c
0 65 :4 0 f7
:4 0 68 :2 0 69
:3 0 653 b10 b12
:3 0 656 b0d b14
:2 0 b16 659 b17
b0a b16 0 b18
65b 0 b25 81
:3 0 c0 :3 0 b19
b1a 0 6d :3 0
59 :3 0 31 :2 0
65d b1c b1f 17
:3 0 83 :3 0 660
b1b b23 :2 0 b25
664 b26 ab7 b25
0 b28 a50 aae
0 b28 668 0
b29 66b b2a a0d
b29 0 b2b 670
0 1912 6d :3 0
37 :3 0 31 :2 0
672 b2c b2f c7
:2 0 31 :2 0 677
b31 b33 :3 0 b34
:2 0 6d :3 0 3b
:3 0 31 :2 0 67a
b36 b39 8b :2 0
ed :2 0 67f b3b
b3d :3 0 b3e :2 0
b35 b40 b3f :2 0
6d :3 0 3b :3 0
31 :2 0 682 b42
b45 84 :2 0 23
:2 0 687 b47 b49
:3 0 b4a :2 0 6d
:3 0 3b :3 0 31
:2 0 68a b4c b4f
84 :2 0 f8 :2 0
68f b51 b53 :3 0
b54 :2 0 b4b b56
b55 :2 0 3a :3 0
f8 :2 0 b58 b59
0 b5c a4 :3 0
692 ba5 6d :3 0
3b :3 0 31 :2 0
694 b5d b60 84
:2 0 31 :2 0 699
b62 b64 :3 0 3a
:3 0 23 :2 0 b66
b67 0 b6a a4
:3 0 69c b6b b65
b6a 0 ba6 6d
:3 0 3b :3 0 31
:2 0 69e b6c b6f
84 :2 0 f9 :2 0
6a3 b71 b73 :3 0
b74 :2 0 6d :3 0
3b :3 0 31 :2 0
6a6 b76 b79 84
:2 0 fa :2 0 6ab
b7b b7d :3 0 b7e
:2 0 b75 b80 b7f
:2 0 3a :3 0 23
:2 0 b82 b83 0
b86 a4 :3 0 6ae
b87 b81 b86 0
ba6 6d :3 0 3b
:3 0 31 :2 0 6b0
b88 b8b 84 :2 0
85 :2 0 6b5 b8d
b8f :3 0 37 :3 0
6d :3 0 40 :3 0
31 :2 0 6b8 b92
b95 fb :2 0 6d
:3 0 37 :3 0 31
:2 0 6bb b98 b9b
6be b97 b9d :3 0
b91 b9e 0 ba3
3a :3 0 f9 :2 0
ba0 ba1 0 ba3
6c1 ba4 b90 ba3
0 ba6 b57 b5c
0 ba6 6c4 0
ba7 6c9 ba8 b41
ba7 0 ba9 6cb
0 1912 6d :3 0
39 :3 0 31 :2 0
6cd baa bad c7
:2 0 31 :2 0 6d2
baf bb1 :3 0 6d
:3 0 42 :3 0 31
:2 0 6d5 bb3 bb6
c7 :2 0 fc :2 0
6da bb8 bba :3 0
60 :3 0 61 :3 0
bbc bbd 0 60
:3 0 71 :3 0 bbf
bc0 0 18 :2 0
2 :4 0 fd :2 0
73 :2 0 23 :2 0
6dd bc5 bc7 :3 0
6e0 bc1 bc9 bbe
bcb bca :2 0 63
:3 0 74 :3 0 bcd
bce 0 65 :4 0
fe :4 0 68 :2 0
69 :3 0 6e4 bd2
bd4 :3 0 68 :2 0
7b :4 0 6e7 bd6
bd8 :3 0 68 :2 0
7c :4 0 6ea bda
bdc :3 0 68 :2 0
6d :3 0 6e :3 0
7d :3 0 ff :3 0
be1 be2 0 6ed
be0 be4 6f :4 0
6ef bdf be7 6f2
bde be9 :3 0 68
:2 0 bd :4 0 6f5
beb bed :3 0 68
:2 0 6b :4 0 6f8
bef bf1 :3 0 68
:2 0 17 :3 0 6fb
bf3 bf5 :3 0 68
:2 0 6b :4 0 6fe
bf7 bf9 :3 0 701
bcf bfb :2 0 bfd
704 bfe bcc bfd
0 bff 706 0
c29 60 :3 0 61
:3 0 c00 c01 0
60 :3 0 71 :3 0
c03 c04 0 23
:2 0 2 :4 0 100
:2 0 73 :2 0 23
:2 0 708 c09 c0b
:3 0 70b c05 c0d
c02 c0f c0e :2 0
63 :3 0 74 :3 0
c11 c12 0 65
:4 0 101 :4 0 68
:2 0 69 :3 0 70f
c16 c18 :3 0 712
c13 c1a :2 0 c1c
715 c1d c10 c1c
0 c1e 717 0
c29 81 :3 0 c0
:3 0 c1f c20 0
7d :3 0 ff :3 0
c22 c23 0 17
:3 0 83 :3 0 719
c21 c27 :2 0 c29
71d c2a bbb c29
0 c2b 721 0
c4e 6d :3 0 42
:3 0 31 :2 0 723
c2c c2f 9e :2 0
ac :2 0 728 c31
c33 :3 0 42 :3 0
102 :2 0 c35 c36
0 c38 72b c4b
42 :3 0 103 :3 0
104 :3 0 6d :3 0
42 :3 0 31 :2 0
72d c3c c3f 730
c3b c41 fb :2 0
105 :2 0 732 c43
c45 :3 0 735 c3a
c47 c39 c48 0
c4a 737 c4c c34
c38 0 c4d 0
c4a 0 c4d 739
0 c4e 73c c4f
bb2 c4e 0 c50
73f 0 1912 55
:3 0 106 :4 0 c52
c53 :3 0 c51 c54
0 1912 2a :3 0
ee :4 0 c56 c57
0 1912 2b :3 0
ee :4 0 c59 c5a
0 1912 20 :3 0
ee :4 0 c5c c5d
0 1912 26 :3 0
ee :4 0 c5f c60
0 1912 1b :3 0
9a :3 0 1b :3 0
23 :2 0 18 :2 0
741 c63 c67 c62
c68 0 1912 24
:3 0 9a :3 0 24
:3 0 23 :2 0 23
:2 0 745 c6b c6f
c6a c70 0 1912
6d :3 0 33 :3 0
31 :2 0 749 c72
c75 c7 :2 0 31
:2 0 74e c77 c79
:3 0 2c :4 0 c7b
c7c 0 1344 1e
:3 0 1c :3 0 c7e
c7f 0 1344 9a
:3 0 24 :3 0 23
:2 0 23 :2 0 751
c81 c85 84 :2 0
23 :4 0 757 c87
c89 :3 0 107 :3 0
108 :3 0 9a :3 0
109 :3 0 108 :3 0
9a :3 0 10a :3 0
10b :3 0 10c :3 0
10d :3 0 10e :3 0
27 :3 0 2c :3 0
2d :3 0 4a :3 0
4b :3 0 4d :3 0
4f :3 0 10f :3 0
110 :3 0 17 :3 0
111 :3 0 1b :3 0
112 :3 0 113 :4 0
114 1 :8 0 caa
15 :3 0 92 :3 0
ca5 ca6 0 93
:3 0 ca7 ca8 0
caa 75a cf4 94
:3 0 15 :3 0 92
:3 0 cad cae 0
93 :3 0 caf cb0
0 cea 60 :3 0
61 :3 0 cb2 cb3
0 60 :3 0 71
:3 0 cb5 cb6 0
95 :2 0 2 :4 0
115 :2 0 73 :2 0
23 :2 0 75d cbb
cbd :3 0 760 cb7
cbf cb4 cc1 cc0
:2 0 63 :3 0 74
:3 0 cc3 cc4 0
65 :4 0 116 :4 0
68 :2 0 69 :3 0
764 cc8 cca :3 0
68 :2 0 7b :4 0
767 ccc cce :3 0
68 :2 0 98 :4 0
76a cd0 cd2 :3 0
68 :2 0 93 :3 0
76d cd4 cd6 :3 0
68 :2 0 99 :4 0
770 cd8 cda :3 0
68 :2 0 9a :3 0
9b :3 0 23 :2 0
9c :2 0 773 cdd
ce1 777 cdc ce3
:3 0 77a cc5 ce5
:2 0 ce7 77d ce8
cc2 ce7 0 ce9
77f 0 cea 781
ced :3 0 ced 0
ced cec cea ceb
:6 0 cef 10 :3 0
784 cf1 786 cf0
cef :2 0 cf2 788
:2 0 cf4 0 cf4
cf3 caa cf2 :6 0
e27 1 :3 0 117
:3 0 2e :3 0 118
:3 0 119 :3 0 1b
:4 0 11a 1 :8 0
d01 15 :3 0 92
:3 0 cfc cfd 0
93 :3 0 cfe cff
0 d01 78a d4b
94 :3 0 15 :3 0
92 :3 0 d04 d05
0 93 :3 0 d06
d07 0 d41 60
:3 0 61 :3 0 d09
d0a 0 60 :3 0
71 :3 0 d0c d0d
0 95 :2 0 2
:4 0 11b :2 0 73
:2 0 23 :2 0 78d
d12 d14 :3 0 790
d0e d16 d0b d18
d17 :2 0 63 :3 0
74 :3 0 d1a d1b
0 65 :4 0 11c
:4 0 68 :2 0 69
:3 0 794 d1f d21
:3 0 68 :2 0 7b
:4 0 797 d23 d25
:3 0 68 :2 0 98
:4 0 79a d27 d29
:3 0 68 :2 0 93
:3 0 79d d2b d2d
:3 0 68 :2 0 99
:4 0 7a0 d2f d31
:3 0 68 :2 0 9a
:3 0 9b :3 0 23
:2 0 9c :2 0 7a3
d34 d38 7a7 d33
d3a :3 0 7aa d1c
d3c :2 0 d3e 7ad
d3f d19 d3e 0
d40 7af 0 d41
7b1 d44 :3 0 d44
0 d44 d43 d41
d42 :6 0 d46 12
:3 0 7b4 d48 7b6
d47 d46 :2 0 d49
7b8 :2 0 d4b 0
d4b d4a d01 d49
:6 0 e27 1 :3 0
15 :3 0 92 :3 0
d4d d4e 0 15
:3 0 84 :2 0 b6
:3 0 d50 d52 0
7bc d51 d54 :3 0
d55 :2 0 60 :3 0
61 :3 0 d57 d58
0 60 :3 0 71
:3 0 d5a d5b 0
18 :2 0 2 :4 0
11d :2 0 73 :2 0
23 :2 0 7bf d60
d62 :3 0 7c2 d5c
d64 d59 d66 d65
:2 0 63 :3 0 74
:3 0 d68 d69 0
65 :4 0 11e :4 0
68 :2 0 69 :3 0
7c6 d6d d6f :3 0
68 :2 0 7b :4 0
7c9 d71 d73 :3 0
68 :2 0 7c :4 0
7cc d75 d77 :3 0
68 :2 0 6d :3 0
6e :3 0 7d :3 0
e6 :3 0 d7c d7d
0 7cf d7b d7f
6f :4 0 7d1 d7a
d82 7d4 d79 d84
:3 0 68 :2 0 bd
:4 0 7d7 d86 d88
:3 0 68 :2 0 6b
:4 0 7da d8a d8c
:3 0 68 :2 0 1b
:3 0 7dd d8e d90
:3 0 68 :2 0 6b
:4 0 7e0 d92 d94
:3 0 7e3 d6a d96
:2 0 d98 7e6 d99
d67 d98 0 d9a
7e8 0 dc4 60
:3 0 61 :3 0 d9b
d9c 0 60 :3 0
71 :3 0 d9e d9f
0 23 :2 0 2
:4 0 11f :2 0 73
:2 0 23 :2 0 7ea
da4 da6 :3 0 7ed
da0 da8 d9d daa
da9 :2 0 63 :3 0
74 :3 0 dac dad
0 65 :4 0 120
:4 0 68 :2 0 69
:3 0 7f1 db1 db3
:3 0 7f4 dae db5
:2 0 db7 7f7 db8
dab db7 0 db9
7f9 0 dc4 81
:3 0 c0 :3 0 dba
dbb 0 7d :3 0
e6 :3 0 dbd dbe
0 1b :3 0 83
:3 0 7fb dbc dc2
:2 0 dc4 7ff dc5
d56 dc4 0 dc6
803 0 e27 2b
:3 0 1b :3 0 dc7
dc8 0 e27 121
:3 0 122 :3 0 26
:3 0 43 :3 0 123
:3 0 b2 :3 0 19
:3 0 112 :3 0 111
:3 0 1b :4 0 124
1 :8 0 dda 15
:3 0 92 :3 0 dd5
dd6 0 93 :3 0
dd7 dd8 0 dda
805 e24 94 :3 0
15 :3 0 92 :3 0
ddd dde 0 93
:3 0 ddf de0 0
e1a 60 :3 0 61
:3 0 de2 de3 0
60 :3 0 71 :3 0
de5 de6 0 95
:2 0 2 :4 0 125
:2 0 73 :2 0 23
:2 0 808 deb ded
:3 0 80b de7 def
de4 df1 df0 :2 0
63 :3 0 74 :3 0
df3 df4 0 65
:4 0 126 :4 0 68
:2 0 69 :3 0 80f
df8 dfa :3 0 68
:2 0 7b :4 0 812
dfc dfe :3 0 68
:2 0 98 :4 0 815
e00 e02 :3 0 68
:2 0 93 :3 0 818
e04 e06 :3 0 68
:2 0 99 :4 0 81b
e08 e0a :3 0 68
:2 0 9a :3 0 9b
:3 0 23 :2 0 9c
:2 0 81e e0d e11
822 e0c e13 :3 0
825 df5 e15 :2 0
e17 828 e18 df2
e17 0 e19 82a
0 e1a 82c e1d
:3 0 e1d 0 e1d
e1c e1a e1b :6 0
e1f 14 :3 0 82f
e21 831 e20 e1f
:2 0 e22 833 :2 0
e24 0 e24 e23
dda e22 :6 0 e27
1 :3 0 a4 :3 0
835 10a4 9a :3 0
24 :3 0 23 :2 0
23 :2 0 83b e28
e2c 84 :2 0 31
:4 0 841 e2e e30
:3 0 127 :3 0 2e
:3 0 128 :3 0 111
:3 0 1b :4 0 129
1 :8 0 e3d 15
:3 0 92 :3 0 e38
e39 0 93 :3 0
e3a e3b 0 e3d
844 e87 94 :3 0
15 :3 0 92 :3 0
e40 e41 0 93
:3 0 e42 e43 0
e7d 60 :3 0 61
:3 0 e45 e46 0
60 :3 0 71 :3 0
e48 e49 0 95
:2 0 2 :4 0 12a
:2 0 73 :2 0 23
:2 0 847 e4e e50
:3 0 84a e4a e52
e47 e54 e53 :2 0
63 :3 0 74 :3 0
e56 e57 0 65
:4 0 12b :4 0 68
:2 0 69 :3 0 84e
e5b e5d :3 0 68
:2 0 7b :4 0 851
e5f e61 :3 0 68
:2 0 98 :4 0 854
e63 e65 :3 0 68
:2 0 93 :3 0 857
e67 e69 :3 0 68
:2 0 99 :4 0 85a
e6b e6d :3 0 68
:2 0 9a :3 0 9b
:3 0 23 :2 0 9c
:2 0 85d e70 e74
861 e6f e76 :3 0
864 e58 e78 :2 0
e7a 867 e7b e55
e7a 0 e7c 869
0 e7d 86b e80
:3 0 e80 0 e80
e7f e7d e7e :6 0
e82 16 :3 0 86e
e84 870 e83 e82
:2 0 e85 872 :2 0
e87 0 e87 e86
e3d e85 :6 0 1045
1 :3 0 15 :3 0
92 :3 0 e89 e8a
0 15 :3 0 84
:2 0 b6 :3 0 e8c
e8e 0 876 e8d
e90 :3 0 e91 :2 0
60 :3 0 61 :3 0
e93 e94 0 60
:3 0 71 :3 0 e96
e97 0 18 :2 0
2 :4 0 12c :2 0
73 :2 0 23 :2 0
879 e9c e9e :3 0
87c e98 ea0 e95
ea2 ea1 :2 0 63
:3 0 74 :3 0 ea4
ea5 0 65 :4 0
12d :4 0 68 :2 0
69 :3 0 880 ea9
eab :3 0 68 :2 0
7b :4 0 883 ead
eaf :3 0 68 :2 0
7c :4 0 886 eb1
eb3 :3 0 68 :2 0
6d :3 0 6e :3 0
7d :3 0 e6 :3 0
eb8 eb9 0 889
eb7 ebb 6f :4 0
88b eb6 ebe 88e
eb5 ec0 :3 0 68
:2 0 bd :4 0 891
ec2 ec4 :3 0 68
:2 0 6b :4 0 894
ec6 ec8 :3 0 68
:2 0 1b :3 0 897
eca ecc :3 0 68
:2 0 6b :4 0 89a
ece ed0 :3 0 89d
ea6 ed2 :2 0 ed4
8a0 ed5 ea3 ed4
0 ed6 8a2 0
f00 60 :3 0 61
:3 0 ed7 ed8 0
60 :3 0 71 :3 0
eda edb 0 23
:2 0 2 :4 0 12e
:2 0 73 :2 0 23
:2 0 8a4 ee0 ee2
:3 0 8a7 edc ee4
ed9 ee6 ee5 :2 0
63 :3 0 74 :3 0
ee8 ee9 0 65
:4 0 12f :4 0 68
:2 0 69 :3 0 8ab
eed eef :3 0 8ae
eea ef1 :2 0 ef3
8b1 ef4 ee7 ef3
0 ef5 8b3 0
f00 81 :3 0 c0
:3 0 ef6 ef7 0
7d :3 0 e6 :3 0
ef9 efa 0 1b
:3 0 83 :3 0 8b5
ef8 efe :2 0 f00
8b9 f01 e92 f00
0 f02 8bd 0
1045 2a :3 0 1b
:3 0 f03 f04 0
1045 107 :3 0 108
:3 0 9a :3 0 109
:3 0 108 :3 0 9a
:3 0 10a :3 0 10b
:3 0 10c :3 0 10d
:3 0 10e :3 0 27
:3 0 2c :3 0 2d
:3 0 4a :3 0 4b
:3 0 4d :3 0 4f
:3 0 10f :3 0 110
:3 0 17 :3 0 111
:3 0 1b :3 0 112
:3 0 113 :4 0 130
1 :8 0 f25 15
:3 0 92 :3 0 f20
f21 0 93 :3 0
f22 f23 0 f25
8bf f6f 94 :3 0
15 :3 0 92 :3 0
f28 f29 0 93
:3 0 f2a f2b 0
f65 60 :3 0 61
:3 0 f2d f2e 0
60 :3 0 71 :3 0
f30 f31 0 95
:2 0 2 :4 0 131
:2 0 73 :2 0 23
:2 0 8c2 f36 f38
:3 0 8c5 f32 f3a
f2f f3c f3b :2 0
63 :3 0 74 :3 0
f3e f3f 0 65
:4 0 132 :4 0 68
:2 0 69 :3 0 8c9
f43 f45 :3 0 68
:2 0 7b :4 0 8cc
f47 f49 :3 0 68
:2 0 98 :4 0 8cf
f4b f4d :3 0 68
:2 0 93 :3 0 8d2
f4f f51 :3 0 68
:2 0 99 :4 0 8d5
f53 f55 :3 0 68
:2 0 9a :3 0 9b
:3 0 23 :2 0 9c
:2 0 8d8 f58 f5c
8dc f57 f5e :3 0
8df f40 f60 :2 0
f62 8e2 f63 f3d
f62 0 f64 8e4
0 f65 8e6 f68
:3 0 f68 0 f68
f67 f65 f66 :6 0
f6a 18 :3 0 8e9
f6c 8eb f6b f6a
:2 0 f6d 8ed :2 0
f6f 0 f6f f6e
f25 f6d :6 0 1045
1 :3 0 15 :3 0
92 :3 0 f71 f72
0 15 :3 0 84
:2 0 b6 :3 0 f74
f76 0 8f1 f75
f78 :3 0 f79 :2 0
107 :3 0 108 :3 0
9a :3 0 109 :3 0
108 :3 0 9a :3 0
10a :3 0 10b :3 0
10c :3 0 10d :3 0
10e :3 0 27 :3 0
2c :3 0 2d :3 0
4a :3 0 4b :3 0
4d :3 0 4f :3 0
10f :3 0 110 :3 0
17 :3 0 111 :3 0
1b :3 0 112 :3 0
113 :4 0 133 1
:8 0 f9a 15 :3 0
92 :3 0 f95 f96
0 93 :3 0 f97
f98 0 f9a 8f4
fe4 94 :3 0 15
:3 0 92 :3 0 f9d
f9e 0 93 :3 0
f9f fa0 0 fda
60 :3 0 61 :3 0
fa2 fa3 0 60
:3 0 71 :3 0 fa5
fa6 0 95 :2 0
2 :4 0 134 :2 0
73 :2 0 23 :2 0
8f7 fab fad :3 0
8fa fa7 faf fa4
fb1 fb0 :2 0 63
:3 0 74 :3 0 fb3
fb4 0 65 :4 0
135 :4 0 68 :2 0
69 :3 0 8fe fb8
fba :3 0 68 :2 0
7b :4 0 901 fbc
fbe :3 0 68 :2 0
98 :4 0 904 fc0
fc2 :3 0 68 :2 0
93 :3 0 907 fc4
fc6 :3 0 68 :2 0
99 :4 0 90a fc8
fca :3 0 68 :2 0
9a :3 0 9b :3 0
23 :2 0 9c :2 0
90d fcd fd1 911
fcc fd3 :3 0 914
fb5 fd5 :2 0 fd7
917 fd8 fb2 fd7
0 fd9 919 0
fda 91b fdd :3 0
fdd 0 fdd fdc
fda fdb :6 0 fdf
1a :3 0 91e fe1
920 fe0 fdf :2 0
fe2 922 :2 0 fe4
0 fe4 fe3 f9a
fe2 :6 0 fe6 1
:3 0 924 fe7 f7a
fe6 0 fe8 926
0 1045 121 :3 0
122 :3 0 26 :3 0
43 :3 0 123 :3 0
b2 :3 0 19 :3 0
112 :3 0 111 :3 0
1b :4 0 136 1
:8 0 ff9 15 :3 0
92 :3 0 ff4 ff5
0 93 :3 0 ff6
ff7 0 ff9 928
1043 94 :3 0 15
:3 0 92 :3 0 ffc
ffd 0 93 :3 0
ffe fff 0 1039
60 :3 0 61 :3 0
1001 1002 0 60
:3 0 71 :3 0 1004
1005 0 95 :2 0
2 :4 0 137 :2 0
73 :2 0 23 :2 0
92b 100a 100c :3 0
92e 1006 100e 1003
1010 100f :2 0 63
:3 0 74 :3 0 1012
1013 0 65 :4 0
138 :4 0 68 :2 0
69 :3 0 932 1017
1019 :3 0 68 :2 0
7b :4 0 935 101b
101d :3 0 68 :2 0
98 :4 0 938 101f
1021 :3 0 68 :2 0
93 :3 0 93b 1023
1025 :3 0 68 :2 0
99 :4 0 93e 1027
1029 :3 0 68 :2 0
9a :3 0 9b :3 0
23 :2 0 9c :2 0
941 102c 1030 945
102b 1032 :3 0 948
1014 1034 :2 0 1036
94b 1037 1011 1036
0 1038 94d 0
1039 94f 103c :3 0
103c 0 103c 103b
1039 103a :6 0 103e
1c :3 0 952 1040
954 103f 103e :2 0
1041 956 :2 0 1043
0 1043 1042 ff9
1041 :6 0 1045 1
:3 0 958 1046 e31
1045 0 10a6 60
:3 0 61 :3 0 1047
1048 0 60 :3 0
71 :3 0 104a 104b
0 78 :2 0 2
:4 0 139 :2 0 73
:2 0 23 :2 0 95f
1050 1052 :3 0 962
104c 1054 1049 1056
1055 :2 0 63 :3 0
74 :3 0 1058 1059
0 65 :4 0 13a
:4 0 68 :2 0 69
:3 0 966 105d 105f
:3 0 68 :2 0 7b
:4 0 969 1061 1063
:3 0 68 :2 0 7c
:4 0 96c 1065 1067
:3 0 68 :2 0 6d
:3 0 6e :3 0 7d
:3 0 88 :3 0 106c
106d 0 96f 106b
106f 6f :4 0 971
106a 1072 974 1069
1074 :3 0 977 105a
1076 :2 0 1078 97a
1079 1057 1078 0
107a 97c 0 10a3
60 :3 0 61 :3 0
107b 107c 0 60
:3 0 71 :3 0 107e
107f 0 23 :2 0
2 :4 0 13b :2 0
73 :2 0 23 :2 0
97e 1084 1086 :3 0
981 1080 1088 107d
108a 1089 :2 0 63
:3 0 74 :3 0 108c
108d 0 65 :4 0
13c :4 0 68 :2 0
69 :3 0 985 1091
1093 :3 0 988 108e
1095 :2 0 1097 98b
1098 108b 1097 0
1099 98d 0 10a3
81 :3 0 82 :3 0
109a 109b 0 7d
:3 0 88 :3 0 109d
109e 0 83 :3 0
98f 109c 10a1 :2 0
10a3 992 10a5 c8a
e27 0 10a6 0
10a3 0 10a6 996
0 1344 15 :3 0
92 :3 0 10a7 10a8
0 15 :3 0 84
:2 0 9d :3 0 10aa
10ac 0 99c 10ab
10ae :3 0 10af :2 0
55 :3 0 13d :3 0
31 :2 0 6d :3 0
33 :3 0 31 :2 0
99f 10b4 10b7 7d
:3 0 13e :3 0 10b9
10ba 0 51 :3 0
9a2 10b2 10bd 10b1
10be 0 115c 55
:3 0 13d :3 0 31
:2 0 6d :3 0 33
:3 0 31 :2 0 9a7
10c3 10c6 7d :3 0
13f :3 0 10c8 10c9
0 53 :3 0 9aa
10c1 10cc 10c0 10cd
0 115c 123 :3 0
122 :3 0 140 :3 0
53 :3 0 141 :3 0
7d :3 0 dc :3 0
7d :3 0 dd :3 0
7d :3 0 de :3 0
7d :3 0 df :3 0
7d :3 0 e0 :3 0
7d :3 0 142 :3 0
140 :3 0 53 :3 0
7d :3 0 143 :3 0
140 :3 0 51 :3 0
7d :3 0 142 :3 0
d7 :3 0 144 :3 0
122 :3 0 7d :3 0
143 :3 0 140 :3 0
140 :3 0 53 :3 0
51 :3 0 140 :3 0
121 :3 0 26 :4 0
145 1 :8 0 110a
146 :4 0 10f5 :3 0
83 :3 0 84 :2 0
9b1 10f8 10f9 :3 0
15 :3 0 92 :3 0
10fb 10fc 0 31
:2 0 10fd 10fe 0
1100 9b4 1107 15
:3 0 92 :3 0 1101
1102 0 ed :2 0
1103 1104 0 1106
9b6 1108 10fa 1100
0 1109 0 1106
0 1109 9b8 0
110a 9bb 1154 94
:3 0 15 :3 0 92
:3 0 110d 110e 0
93 :3 0 110f 1110
0 114a 60 :3 0
61 :3 0 1112 1113
0 60 :3 0 71
:3 0 1115 1116 0
95 :2 0 2 :4 0
147 :2 0 73 :2 0
23 :2 0 9be 111b
111d :3 0 9c1 1117
111f 1114 1121 1120
:2 0 63 :3 0 74
:3 0 1123 1124 0
65 :4 0 148 :4 0
68 :2 0 69 :3 0
9c5 1128 112a :3 0
68 :2 0 7b :4 0
9c8 112c 112e :3 0
68 :2 0 98 :4 0
9cb 1130 1132 :3 0
68 :2 0 93 :3 0
9ce 1134 1136 :3 0
68 :2 0 99 :4 0
9d1 1138 113a :3 0
68 :2 0 9a :3 0
9b :3 0 23 :2 0
9c :2 0 9d4 113d
1141 9d8 113c 1143
:3 0 9db 1125 1145
:2 0 1147 9de 1148
1122 1147 0 1149
9e0 0 114a 9e2
114d :3 0 114d 0
114d 114c 114a 114b
:6 0 114f 1e :3 0
9e5 1151 9e7 1150
114f :2 0 1152 9e9
:2 0 1154 0 1154
1153 110a 1152 :6 0
115c 1 :3 0 55
:3 0 149 :3 0 26
:3 0 9eb 1157 1159
1156 115a 0 115c
9ed 1200 26 :3 0
14a :4 0 115e 115f
:3 0 115d 1160 0
11ff 55 :3 0 13d
:3 0 31 :2 0 6d
:3 0 33 :3 0 31
:2 0 9f2 1165 1168
7d :3 0 13e :3 0
116a 116b 0 51
:3 0 9f5 1163 116e
1162 116f 0 11ff
50 :3 0 7d :3 0
142 :3 0 1172 1173
0 1171 1174 0
11ff 54 :3 0 23
:2 0 1176 1177 0
11ff 55 :3 0 14b
:3 0 17 :3 0 1b
:3 0 33 :3 0 50
:3 0 51 :3 0 24
:3 0 54 :3 0 9fa
117a 1182 1179 1183
0 11ff 123 :3 0
121 :3 0 c3 :3 0
b2 :3 0 141 :3 0
14c :3 0 112 :3 0
111 :3 0 122 :3 0
140 :3 0 14d :3 0
14e :3 0 26 :3 0
17 :3 0 19 :3 0
33 :3 0 58 :3 0
24 :3 0 1b :3 0
7d :3 0 142 :3 0
51 :3 0 13 :3 0
69 :4 0 14f 1
:8 0 11b3 146 :4 0
119e :3 0 83 :3 0
84 :2 0 a04 11a1
11a2 :3 0 15 :3 0
92 :3 0 11a4 11a5
0 31 :2 0 11a6
11a7 0 11a9 a07
11b0 15 :3 0 92
:3 0 11aa 11ab 0
ed :2 0 11ac 11ad
0 11af a09 11b1
11a3 11a9 0 11b2
0 11af 0 11b2
a0b 0 11b3 a0e
11fd 94 :3 0 15
:3 0 92 :3 0 11b6
11b7 0 93 :3 0
11b8 11b9 0 11f3
60 :3 0 61 :3 0
11bb 11bc 0 60
:3 0 71 :3 0 11be
11bf 0 95 :2 0
2 :4 0 150 :2 0
73 :2 0 23 :2 0
a11 11c4 11c6 :3 0
a14 11c0 11c8 11bd
11ca 11c9 :2 0 63
:3 0 74 :3 0 11cc
11cd 0 65 :4 0
151 :4 0 68 :2 0
69 :3 0 a18 11d1
11d3 :3 0 68 :2 0
7b :4 0 a1b 11d5
11d7 :3 0 68 :2 0
98 :4 0 a1e 11d9
11db :3 0 68 :2 0
93 :3 0 a21 11dd
11df :3 0 68 :2 0
99 :4 0 a24 11e1
11e3 :3 0 68 :2 0
9a :3 0 9b :3 0
23 :2 0 9c :2 0
a27 11e6 11ea a2b
11e5 11ec :3 0 a2e
11ce 11ee :2 0 11f0
a31 11f1 11cb 11f0
0 11f2 a33 0
11f3 a35 11f6 :3 0
11f6 0 11f6 11f5
11f3 11f4 :6 0 11f8
20 :3 0 a38 11fa
a3a 11f9 11f8 :2 0
11fb a3c :2 0 11fd
0 11fd 11fc 11b3
11fb :6 0 11ff 1
:3 0 a3e 1201 10b0
115c 0 1202 0
11ff 0 1202 a45
0 1344 6d :3 0
35 :3 0 31 :2 0
a48 1203 1206 84
:2 0 31 :2 0 a4d
1208 120a :3 0 120b
:2 0 2c :3 0 8d
:2 0 a50 120e 120f
:3 0 1210 :2 0 1211
:2 0 120c 1213 1212
:2 0 152 :3 0 25
:3 0 c2 :3 0 c3
:3 0 17 :4 0 153
1 :8 0 1220 15
:3 0 92 :3 0 121b
121c 0 93 :3 0
121d 121e 0 1220
a52 126a 94 :3 0
15 :3 0 92 :3 0
1223 1224 0 93
:3 0 1225 1226 0
1260 60 :3 0 61
:3 0 1228 1229 0
60 :3 0 71 :3 0
122b 122c 0 95
:2 0 2 :4 0 154
:2 0 73 :2 0 23
:2 0 a55 1231 1233
:3 0 a58 122d 1235
122a 1237 1236 :2 0
63 :3 0 74 :3 0
1239 123a 0 65
:4 0 155 :4 0 68
:2 0 69 :3 0 a5c
123e 1240 :3 0 68
:2 0 7b :4 0 a5f
1242 1244 :3 0 68
:2 0 98 :4 0 a62
1246 1248 :3 0 68
:2 0 93 :3 0 a65
124a 124c :3 0 68
:2 0 99 :4 0 a68
124e 1250 :3 0 68
:2 0 9a :3 0 9b
:3 0 23 :2 0 9c
:2 0 a6b 1253 1257
a6f 1252 1259 :3 0
a72 123b 125b :2 0
125d a75 125e 1238
125d 0 125f a77
0 1260 a79 1263
:3 0 1263 0 1263
1262 1260 1261 :6 0
1265 22 :3 0 a7c
1267 a7e 1266 1265
:2 0 1268 a80 :2 0
126a 0 126a 1269
1220 1268 :6 0 1290
1 :3 0 9a :3 0
25 :3 0 23 :2 0
23 :2 0 a82 126c
1270 84 :2 0 156
:4 0 a88 1272 1274
:3 0 4c :3 0 157
:2 0 23 :2 0 a8b
1277 1279 :3 0 1276
127a 0 128d 15
:3 0 92 :3 0 127c
127d 0 158 :3 0
17 :3 0 17 :3 0
27 :3 0 2c :3 0
2d :3 0 4d :3 0
4f :3 0 4c :3 0
4b :3 0 4a :3 0
a8d 127f 128a 127e
128b 0 128d a98
128e 1275 128d 0
128f a9b 0 1290
a9d 1291 1214 1290
0 1292 aa0 0
1344 1e :3 0 1e
:3 0 1293 1294 0
1344 9a :3 0 24
:3 0 23 :2 0 23
:2 0 aa2 1296 129a
84 :2 0 23 :4 0
aa8 129c 129e :3 0
45 :3 0 7d :3 0
159 :3 0 12a1 12a2
0 12a0 12a3 0
12a5 aab 12ae 45
:3 0 6d :3 0 3c
:3 0 31 :2 0 aad
12a7 12aa 12a6 12ab
0 12ad ab0 12af
129f 12a5 0 12b0
0 12ad 0 12b0
ab2 0 1344 5c
:3 0 15a :3 0 26
:3 0 17 :3 0 19
:3 0 1b :3 0 48
:3 0 33 :3 0 20
:3 0 20 :3 0 20
:3 0 20 :3 0 1e
:3 0 1f :3 0 42
:3 0 39 :3 0 37
:3 0 3a :3 0 3b
:3 0 36 :3 0 45
:3 0 24 :3 0 35
:3 0 32 :3 0 3d
:3 0 38 :3 0 34
:3 0 3f :3 0 46
:3 0 1a :3 0 31
:2 0 31 :2 0 4e
:2 0 4e :2 0 ab5
12b2 12d3 12b1 12d4
0 1344 5c :3 0
84 :2 0 31 :2 0
ad8 12d7 12d9 :3 0
15b :3 0 15c :3 0
15d :3 0 1b :4 0
15e 1 :8 0 12f5
146 :4 0 12e0 :3 0
83 :3 0 84 :2 0
add 12e3 12e4 :3 0
15 :3 0 92 :3 0
12e6 12e7 0 31
:2 0 12e8 12e9 0
12eb ae0 12f2 15
:3 0 92 :3 0 12ec
12ed 0 ed :2 0
12ee 12ef 0 12f1
ae2 12f3 12e5 12eb
0 12f4 0 12f1
0 12f4 ae4 0
12f5 ae7 133f 94
:3 0 15 :3 0 92
:3 0 12f8 12f9 0
93 :3 0 12fa 12fb
0 1335 60 :3 0
61 :3 0 12fd 12fe
0 60 :3 0 71
:3 0 1300 1301 0
95 :2 0 2 :4 0
15f :2 0 73 :2 0
23 :2 0 aea 1306
1308 :3 0 aed 1302
130a 12ff 130c 130b
:2 0 63 :3 0 74
:3 0 130e 130f 0
65 :4 0 160 :4 0
68 :2 0 69 :3 0
af1 1313 1315 :3 0
68 :2 0 7b :4 0
af4 1317 1319 :3 0
68 :2 0 98 :4 0
af7 131b 131d :3 0
68 :2 0 93 :3 0
afa 131f 1321 :3 0
68 :2 0 99 :4 0
afd 1323 1325 :3 0
68 :2 0 9a :3 0
9b :3 0 23 :2 0
9c :2 0 b00 1328
132c b04 1327 132e
:3 0 b07 1310 1330
:2 0 1332 b0a 1333
130d 1332 0 1334
b0c 0 1335 b0e
1338 :3 0 1338 0
1338 1337 1335 1336
:6 0 133a 24 :3 0
b11 133c b13 133b
133a :2 0 133d b15
:2 0 133f 0 133f
133e 12f5 133d :6 0
1341 1 :3 0 b17
1342 12da 1341 0
1343 b19 0 1344
b1b 164a 2a :3 0
ee :4 0 1345 1346
0 1649 2b :3 0
ee :4 0 1348 1349
0 1649 28 :3 0
12 :3 0 134b 134c
0 1649 6d :3 0
161 :3 0 28 :3 0
b25 134f 1351 31
:2 0 b27 134e 1354
9e :2 0 18 :2 0
b2c 1356 1358 :3 0
5e :3 0 31 :2 0
135a 135b 0 135d
b2f 1375 5e :3 0
103 :3 0 6d :3 0
161 :3 0 28 :3 0
b31 1361 1363 31
:2 0 b33 1360 1366
73 :2 0 23 :2 0
b36 1368 136a :3 0
136b :2 0 162 :2 0
d9 :2 0 b39 136d
136f :3 0 b3c 135f
1371 135e 1372 0
1374 b3e 1376 1359
135d 0 1377 0
1374 0 1377 b40
0 1649 5e :3 0
c7 :2 0 31 :2 0
b45 1379 137b :3 0
30 :3 0 31 :2 0
137d 137e 0 1646
163 :3 0 6d :3 0
30 :3 0 31 :2 0
b48 1381 1384 5e
:3 0 9e :2 0 164
:3 0 b4d 1387 1389
:3 0 138a 1645 1b
:3 0 d7 :3 0 d8
:3 0 138d 138e 0
18 :2 0 18 :2 0
6d :3 0 30 :3 0
31 :2 0 b50 1392
1395 fb :2 0 d9
:2 0 b53 1397 1399
:3 0 73 :2 0 23
:2 0 b56 139b 139d
:3 0 28 :3 0 b59
138f 13a0 138c 13a1
0 1643 24 :3 0
d7 :3 0 d8 :3 0
13a4 13a5 0 23
:2 0 23 :2 0 6d
:3 0 30 :3 0 31
:2 0 b5e 13a9 13ac
fb :2 0 d9 :2 0
b61 13ae 13b0 :3 0
73 :2 0 18 :2 0
b64 13b2 13b4 :3 0
73 :2 0 23 :2 0
b67 13b6 13b8 :3 0
28 :3 0 b6a 13a6
13bb 13a3 13bc 0
1643 9a :3 0 24
:3 0 23 :2 0 23
:2 0 b6f 13be 13c2
84 :2 0 23 :4 0
b75 13c4 13c6 :3 0
45 :3 0 7d :3 0
159 :3 0 13c9 13ca
0 13c8 13cb 0
13f9 6d :3 0 161
:3 0 2b :3 0 b78
13ce 13d0 31 :2 0
b7a 13cd 13d3 84
:2 0 31 :2 0 b7f
13d5 13d7 :3 0 2b
:3 0 1b :3 0 13d9
13da 0 13dc b82
13f6 2b :3 0 9a
:3 0 2b :3 0 68
:2 0 165 :4 0 b84
13e0 13e2 :3 0 23
:2 0 29 :2 0 b87
13de 13e6 13dd 13e7
0 13f5 2b :3 0
9a :3 0 2b :3 0
68 :2 0 1b :3 0
b8b 13ec 13ee :3 0
23 :2 0 29 :2 0
b8e 13ea 13f2 13e9
13f3 0 13f5 b92
13f7 13d8 13dc 0
13f8 0 13f5 0
13f8 b95 0 13f9
b98 142e 45 :3 0
6d :3 0 3c :3 0
31 :2 0 b9b 13fb
13fe 13fa 13ff 0
142d 6d :3 0 161
:3 0 2a :3 0 b9e
1402 1404 31 :2 0
ba0 1401 1407 84
:2 0 31 :2 0 ba5
1409 140b :3 0 2a
:3 0 1b :3 0 140d
140e 0 1410 ba8
142a 2a :3 0 9a
:3 0 2a :3 0 68
:2 0 165 :4 0 baa
1414 1416 :3 0 23
:2 0 29 :2 0 bad
1412 141a 1411 141b
0 1429 2a :3 0
9a :3 0 2a :3 0
68 :2 0 1b :3 0
bb1 1420 1422 :3 0
23 :2 0 29 :2 0
bb4 141e 1426 141d
1427 0 1429 bb8
142b 140c 1410 0
142c 0 1429 0
142c bbb 0 142d
bbe 142f 13c7 13f9
0 1430 0 142d
0 1430 bc1 0
1643 9a :3 0 24
:3 0 23 :2 0 23
:2 0 bc4 1431 1435
84 :2 0 23 :4 0
bca 1437 1439 :3 0
108 :3 0 9a :3 0
1c :3 0 108 :3 0
9a :3 0 166 :3 0
108 :3 0 9a :3 0
167 :3 0 166 :3 0
168 :3 0 1c :3 0
1e :3 0 10f :3 0
110 :3 0 17 :3 0
111 :3 0 1b :3 0
112 :4 0 169 1
:8 0 1454 15 :3 0
92 :3 0 144f 1450
0 93 :3 0 1451
1452 0 1454 bcd
149e 94 :3 0 15
:3 0 92 :3 0 1457
1458 0 93 :3 0
1459 145a 0 1494
60 :3 0 61 :3 0
145c 145d 0 60
:3 0 71 :3 0 145f
1460 0 95 :2 0
2 :4 0 16a :2 0
73 :2 0 23 :2 0
bd0 1465 1467 :3 0
bd3 1461 1469 145e
146b 146a :2 0 63
:3 0 74 :3 0 146d
146e 0 65 :4 0
16b :4 0 68 :2 0
69 :3 0 bd7 1472
1474 :3 0 68 :2 0
7b :4 0 bda 1476
1478 :3 0 68 :2 0
98 :4 0 bdd 147a
147c :3 0 68 :2 0
93 :3 0 be0 147e
1480 :3 0 68 :2 0
99 :4 0 be3 1482
1484 :3 0 68 :2 0
9a :3 0 9b :3 0
23 :2 0 9c :2 0
be6 1487 148b bea
1486 148d :3 0 bed
146f 148f :2 0 1491
bf0 1492 146c 1491
0 1493 bf2 0
1494 bf4 1497 :3 0
1497 0 1497 1496
1494 1495 :6 0 1499
27 :3 0 bf7 149b
bf9 149a 1499 :2 0
149c bfb :2 0 149e
0 149e 149d 1454
149c :6 0 14a6 26
:3 0 44 :3 0 31
:2 0 14a0 14a1 0
14a6 35 :3 0 31
:2 0 14a3 14a4 0
14a6 bfd 1581 108
:3 0 9a :3 0 1c
:3 0 108 :3 0 9a
:3 0 166 :3 0 108
:3 0 9a :3 0 167
:3 0 166 :3 0 168
:3 0 1c :3 0 1e
:3 0 10f :3 0 110
:3 0 17 :3 0 111
:3 0 1b :3 0 112
:3 0 113 :4 0 16c
1 :8 0 14c1 15
:3 0 92 :3 0 14bc
14bd 0 93 :3 0
14be 14bf 0 14c1
c01 150b 94 :3 0
15 :3 0 92 :3 0
14c4 14c5 0 93
:3 0 14c6 14c7 0
1501 60 :3 0 61
:3 0 14c9 14ca 0
60 :3 0 71 :3 0
14cc 14cd 0 95
:2 0 2 :4 0 16d
:2 0 73 :2 0 23
:2 0 c04 14d2 14d4
:3 0 c07 14ce 14d6
14cb 14d8 14d7 :2 0
63 :3 0 74 :3 0
14da 14db 0 65
:4 0 16e :4 0 68
:2 0 69 :3 0 c0b
14df 14e1 :3 0 68
:2 0 7b :4 0 c0e
14e3 14e5 :3 0 68
:2 0 98 :4 0 c11
14e7 14e9 :3 0 68
:2 0 93 :3 0 c14
14eb 14ed :3 0 68
:2 0 99 :4 0 c17
14ef 14f1 :3 0 68
:2 0 9a :3 0 9b
:3 0 23 :2 0 9c
:2 0 c1a 14f4 14f8
c1e 14f3 14fa :3 0
c21 14dc 14fc :2 0
14fe c24 14ff 14d9
14fe 0 1500 c26
0 1501 c28 1504
:3 0 1504 0 1504
1503 1501 1502 :6 0
1506 29 :3 0 c2b
1508 c2d 1507 1506
:2 0 1509 c2f :2 0
150b 0 150b 150a
14c1 1509 :6 0 1580
26 :3 0 15 :3 0
92 :3 0 150d 150e
0 15 :3 0 84
:2 0 b6 :3 0 1510
1512 0 c33 1511
1514 :3 0 1515 :2 0
108 :3 0 9a :3 0
1c :3 0 108 :3 0
9a :3 0 166 :3 0
108 :3 0 9a :3 0
167 :3 0 166 :3 0
168 :3 0 1c :3 0
1e :3 0 10f :3 0
110 :3 0 17 :3 0
111 :3 0 1b :3 0
112 :3 0 113 :4 0
16f 1 :8 0 1531
15 :3 0 92 :3 0
152c 152d 0 93
:3 0 152e 152f 0
1531 c36 157b 94
:3 0 15 :3 0 92
:3 0 1534 1535 0
93 :3 0 1536 1537
0 1571 60 :3 0
61 :3 0 1539 153a
0 60 :3 0 71
:3 0 153c 153d 0
95 :2 0 2 :4 0
170 :2 0 73 :2 0
23 :2 0 c39 1542
1544 :3 0 c3c 153e
1546 153b 1548 1547
:2 0 63 :3 0 74
:3 0 154a 154b 0
65 :4 0 171 :4 0
68 :2 0 69 :3 0
c40 154f 1551 :3 0
68 :2 0 7b :4 0
c43 1553 1555 :3 0
68 :2 0 98 :4 0
c46 1557 1559 :3 0
68 :2 0 93 :3 0
c49 155b 155d :3 0
68 :2 0 99 :4 0
c4c 155f 1561 :3 0
68 :2 0 9a :3 0
9b :3 0 23 :2 0
9c :2 0 c4f 1564
1568 c53 1563 156a
:3 0 c56 154c 156c
:2 0 156e c59 156f
1549 156e 0 1570
c5b 0 1571 c5d
1574 :3 0 1574 0
1574 1573 1571 1572
:6 0 1576 2b :3 0
c60 1578 c62 1577
1576 :2 0 1579 c64
:2 0 157b 0 157b
157a 1531 1579 :6 0
157d 26 :3 0 c66
157e 1516 157d 0
157f c68 0 1580
c6a 1582 143a 14a6
0 1583 0 1580
0 1583 c6d 0
1643 1e :3 0 1e
:3 0 1584 1585 0
1643 9a :3 0 24
:3 0 23 :2 0 23
:2 0 c70 1587 158b
84 :2 0 23 :4 0
c76 158d 158f :3 0
45 :3 0 7d :3 0
159 :3 0 1592 1593
0 1591 1594 0
1596 c79 159f 45
:3 0 6d :3 0 3c
:3 0 31 :2 0 c7b
1598 159b 1597 159c
0 159e c7e 15a0
1590 1596 0 15a1
0 159e 0 15a1
c80 0 1643 1e
:3 0 1c :3 0 15a2
15a3 0 1643 5c
:3 0 15a :3 0 26
:3 0 17 :3 0 19
:3 0 1b :3 0 48
:3 0 33 :3 0 20
:3 0 20 :3 0 20
:3 0 20 :3 0 1e
:3 0 1f :3 0 42
:3 0 39 :3 0 37
:3 0 3a :3 0 3b
:3 0 36 :3 0 45
:3 0 24 :3 0 35
:3 0 32 :3 0 3d
:3 0 38 :3 0 34
:3 0 3f :3 0 46
:3 0 1a :3 0 31
:2 0 31 :2 0 4e
:2 0 4e :2 0 c83
15a6 15c7 15a5 15c8
0 1643 5c :3 0
84 :2 0 31 :2 0
ca6 15cb 15cd :3 0
15b :3 0 15c :3 0
15d :3 0 1b :4 0
15e 1 :8 0 15e9
146 :4 0 15d4 :3 0
83 :3 0 84 :2 0
cab 15d7 15d8 :3 0
15 :3 0 92 :3 0
15da 15db 0 31
:2 0 15dc 15dd 0
15df cae 15e6 15
:3 0 92 :3 0 15e0
15e1 0 ed :2 0
15e2 15e3 0 15e5
cb0 15e7 15d9 15df
0 15e8 0 15e5
0 15e8 cb2 0
15e9 cb5 1633 94
:3 0 15 :3 0 92
:3 0 15ec 15ed 0
93 :3 0 15ee 15ef
0 1629 60 :3 0
61 :3 0 15f1 15f2
0 60 :3 0 71
:3 0 15f4 15f5 0
95 :2 0 2 :4 0
172 :2 0 73 :2 0
23 :2 0 cb8 15fa
15fc :3 0 cbb 15f6
15fe 15f3 1600 15ff
:2 0 63 :3 0 74
:3 0 1602 1603 0
65 :4 0 173 :4 0
68 :2 0 69 :3 0
cbf 1607 1609 :3 0
68 :2 0 7b :4 0
cc2 160b 160d :3 0
68 :2 0 98 :4 0
cc5 160f 1611 :3 0
68 :2 0 93 :3 0
cc8 1613 1615 :3 0
68 :2 0 99 :4 0
ccb 1617 1619 :3 0
68 :2 0 9a :3 0
9b :3 0 23 :2 0
9c :2 0 cce 161c
1620 cd2 161b 1622
:3 0 cd5 1604 1624
:2 0 1626 cd8 1627
1601 1626 0 1628
cda 0 1629 cdc
162c :3 0 162c 0
162c 162b 1629 162a
:6 0 162e 2d :3 0
cdf 1630 ce1 162f
162e :2 0 1631 ce3
:2 0 1633 0 1633
1632 15e9 1631 :6 0
1635 26 :3 0 ce5
1636 15ce 1635 0
1637 ce7 0 1643
30 :3 0 6d :3 0
30 :3 0 31 :2 0
ce9 1639 163c 73
:2 0 23 :2 0 cec
163e 1640 :3 0 1638
1641 0 1643 cef
1645 164 :3 0 138b
1643 :4 0 1646 cfa
1647 137c 1646 0
1648 cfd 0 1649
cff 164b c7a 1344
0 164c 0 1649
0 164c d05 0
1912 5c :3 0 8b
:2 0 31 :2 0 d0a
164e 1650 :3 0 1651
:2 0 6d :3 0 33
:3 0 31 :2 0 d0d
1653 1656 c7 :2 0
31 :2 0 d12 1658
165a :3 0 165b :2 0
1652 165d 165c :2 0
60 :3 0 61 :3 0
165f 1660 0 60
:3 0 71 :3 0 1662
1663 0 18 :2 0
2 :4 0 174 :2 0
73 :2 0 23 :2 0
d15 1668 166a :3 0
d18 1664 166c 1661
166e 166d :2 0 63
:3 0 74 :3 0 1670
1671 0 65 :4 0
175 :4 0 68 :2 0
69 :3 0 d1c 1675
1677 :3 0 68 :2 0
7b :4 0 d1f 1679
167b :3 0 68 :2 0
7c :4 0 d22 167d
167f :3 0 68 :2 0
6d :3 0 6e :3 0
7d :3 0 176 :3 0
1684 1685 0 d25
1683 1687 6f :4 0
d27 1682 168a d2a
1681 168c :3 0 68
:2 0 bd :4 0 d2d
168e 1690 :3 0 68
:2 0 6b :4 0 d30
1692 1694 :3 0 68
:2 0 26 :3 0 d33
1696 1698 :3 0 68
:2 0 6b :4 0 d36
169a 169c :3 0 d39
1672 169e :2 0 16a0
d3c 16a1 166f 16a0
0 16a2 d3e 0
16cc 60 :3 0 61
:3 0 16a3 16a4 0
60 :3 0 71 :3 0
16a6 16a7 0 23
:2 0 2 :4 0 177
:2 0 73 :2 0 23
:2 0 d40 16ac 16ae
:3 0 d43 16a8 16b0
16a5 16b2 16b1 :2 0
63 :3 0 74 :3 0
16b4 16b5 0 65
:4 0 178 :4 0 68
:2 0 69 :3 0 d47
16b9 16bb :3 0 d4a
16b6 16bd :2 0 16bf
d4d 16c0 16b3 16bf
0 16c1 d4f 0
16cc 81 :3 0 c0
:3 0 16c2 16c3 0
7d :3 0 176 :3 0
16c5 16c6 0 26
:3 0 83 :3 0 d51
16c4 16ca :2 0 16cc
d55 16cd 165e 16cc
0 16ce d59 0
1912 6d :3 0 33
:3 0 31 :2 0 d5b
16cf 16d2 c7 :2 0
31 :2 0 d60 16d4
16d6 :3 0 17 :3 0
19 :3 0 16d8 16d9
0 16db d63 16dc
16d7 16db 0 16dd
d65 0 1912 6d
:3 0 161 :3 0 2a
:3 0 d67 16df 16e1
31 :2 0 d69 16de
16e4 c7 :2 0 31
:2 0 d6e 16e6 16e8
:3 0 16e9 :2 0 6d
:3 0 161 :3 0 2b
:3 0 d71 16ec 16ee
31 :2 0 d73 16eb
16f1 c7 :2 0 31
:2 0 d78 16f3 16f5
:3 0 16f6 :2 0 16ea
16f8 16f7 :2 0 56
:3 0 179 :4 0 68
:2 0 17a :4 0 d7b
16fc 16fe :3 0 68
:2 0 17b :4 0 d7e
1700 1702 :3 0 68
:2 0 17c :4 0 d81
1704 1706 :3 0 68
:2 0 17d :4 0 d84
1708 170a :3 0 68
:2 0 6e :3 0 6d
:3 0 39 :3 0 31
:2 0 d87 170e 1711
d8a 170d 1713 d8c
170c 1715 :3 0 68
:2 0 17e :4 0 d8f
1717 1719 :3 0 68
:2 0 6e :3 0 6d
:3 0 3a :3 0 31
:2 0 d92 171d 1720
d95 171c 1722 d97
171b 1724 :3 0 68
:2 0 17f :4 0 d9a
1726 1728 :3 0 68
:2 0 6e :3 0 6d
:3 0 3f :3 0 31
:2 0 d9d 172c 172f
da0 172b 1731 da2
172a 1733 :3 0 68
:2 0 180 :4 0 da5
1735 1737 :3 0 68
:2 0 181 :4 0 da8
1739 173b :3 0 68
:2 0 182 :4 0 dab
173d 173f :3 0 68
:2 0 183 :4 0 dae
1741 1743 :3 0 68
:2 0 184 :4 0 db1
1745 1747 :3 0 68
:2 0 185 :4 0 db4
1749 174b :3 0 68
:2 0 17 :3 0 db7
174d 174f :3 0 68
:2 0 186 :4 0 dba
1751 1753 :3 0 68
:2 0 2a :3 0 dbd
1755 1757 :3 0 68
:2 0 187 :4 0 dc0
1759 175b :3 0 68
:2 0 188 :4 0 dc3
175d 175f :3 0 68
:2 0 189 :4 0 dc6
1761 1763 :3 0 68
:2 0 18a :4 0 dc9
1765 1767 :3 0 68
:2 0 7d :3 0 18b
:3 0 176a 176b 0
dcc 1769 176d :3 0
68 :2 0 18c :4 0
dcf 176f 1771 :3 0
68 :2 0 7d :3 0
18b :3 0 1774 1775
0 dd2 1773 1777
:3 0 68 :2 0 18d
:4 0 dd5 1779 177b
:3 0 68 :2 0 18e
:4 0 dd8 177d 177f
:3 0 68 :2 0 18f
:4 0 ddb 1781 1783
:3 0 68 :2 0 6e
:3 0 6d :3 0 39
:3 0 31 :2 0 dde
1787 178a de1 1786
178c de3 1785 178e
:3 0 68 :2 0 17e
:4 0 de6 1790 1792
:3 0 68 :2 0 6e
:3 0 6d :3 0 3a
:3 0 31 :2 0 de9
1796 1799 dec 1795
179b dee 1794 179d
:3 0 68 :2 0 190
:4 0 df1 179f 17a1
:3 0 68 :2 0 191
:4 0 df4 17a3 17a5
:3 0 68 :2 0 6e
:3 0 6d :3 0 3f
:3 0 31 :2 0 df7
17a9 17ac dfa 17a8
17ae dfc 17a7 17b0
:3 0 68 :2 0 192
:4 0 dff 17b2 17b4
:3 0 68 :2 0 193
:4 0 e02 17b6 17b8
:3 0 68 :2 0 17
:3 0 e05 17ba 17bc
:3 0 68 :2 0 194
:4 0 e08 17be 17c0
:3 0 68 :2 0 2b
:3 0 e0b 17c2 17c4
:3 0 68 :2 0 195
:4 0 e0e 17c6 17c8
:3 0 68 :2 0 196
:4 0 e11 17ca 17cc
:3 0 68 :2 0 197
:4 0 e14 17ce 17d0
:3 0 16fa 17d1 0
17d4 a4 :3 0 e17
18ca 6d :3 0 161
:3 0 2a :3 0 e19
17d6 17d8 31 :2 0
e1b 17d5 17db c7
:2 0 31 :2 0 e20
17dd 17df :3 0 56
:3 0 179 :4 0 68
:2 0 17a :4 0 e23
17e3 17e5 :3 0 68
:2 0 17b :4 0 e26
17e7 17e9 :3 0 68
:2 0 17c :4 0 e29
17eb 17ed :3 0 68
:2 0 17d :4 0 e2c
17ef 17f1 :3 0 68
:2 0 6e :3 0 6d
:3 0 39 :3 0 31
:2 0 e2f 17f5 17f8
e32 17f4 17fa e34
17f3 17fc :3 0 68
:2 0 17e :4 0 e37
17fe 1800 :3 0 68
:2 0 6e :3 0 6d
:3 0 3a :3 0 31
:2 0 e3a 1804 1807
e3d 1803 1809 e3f
1802 180b :3 0 68
:2 0 17f :4 0 e42
180d 180f :3 0 68
:2 0 6e :3 0 6d
:3 0 3f :3 0 31
:2 0 e45 1813 1816
e48 1812 1818 e4a
1811 181a :3 0 68
:2 0 180 :4 0 e4d
181c 181e :3 0 68
:2 0 181 :4 0 e50
1820 1822 :3 0 68
:2 0 182 :4 0 e53
1824 1826 :3 0 68
:2 0 183 :4 0 e56
1828 182a :3 0 68
:2 0 184 :4 0 e59
182c 182e :3 0 68
:2 0 185 :4 0 e5c
1830 1832 :3 0 68
:2 0 17 :3 0 e5f
1834 1836 :3 0 68
:2 0 186 :4 0 e62
1838 183a :3 0 68
:2 0 2a :3 0 e65
183c 183e :3 0 68
:2 0 187 :4 0 e68
1840 1842 :3 0 68
:2 0 197 :4 0 e6b
1844 1846 :3 0 17e1
1847 0 184a a4
:3 0 e6e 184b 17e0
184a 0 18cb 6d
:3 0 161 :3 0 2b
:3 0 e70 184d 184f
31 :2 0 e72 184c
1852 c7 :2 0 31
:2 0 e77 1854 1856
:3 0 56 :3 0 189
:4 0 68 :2 0 18a
:4 0 e7a 185a 185c
:3 0 68 :2 0 7d
:3 0 18b :3 0 185f
1860 0 e7d 185e
1862 :3 0 68 :2 0
18c :4 0 e80 1864
1866 :3 0 68 :2 0
7d :3 0 18b :3 0
1869 186a 0 e83
1868 186c :3 0 68
:2 0 18d :4 0 e86
186e 1870 :3 0 68
:2 0 18e :4 0 e89
1872 1874 :3 0 68
:2 0 18f :4 0 e8c
1876 1878 :3 0 68
:2 0 6e :3 0 6d
:3 0 39 :3 0 31
:2 0 e8f 187c 187f
e92 187b 1881 e94
187a 1883 :3 0 68
:2 0 17e :4 0 e97
1885 1887 :3 0 68
:2 0 6e :3 0 6d
:3 0 3a :3 0 31
:2 0 e9a 188b 188e
e9d 188a 1890 e9f
1889 1892 :3 0 68
:2 0 190 :4 0 ea2
1894 1896 :3 0 68
:2 0 191 :4 0 ea5
1898 189a :3 0 68
:2 0 6e :3 0 6d
:3 0 3f :3 0 31
:2 0 ea8 189e 18a1
eab 189d 18a3 ead
189c 18a5 :3 0 68
:2 0 192 :4 0 eb0
18a7 18a9 :3 0 68
:2 0 193 :4 0 eb3
18ab 18ad :3 0 68
:2 0 17 :3 0 eb6
18af 18b1 :3 0 68
:2 0 194 :4 0 eb9
18b3 18b5 :3 0 68
:2 0 2b :3 0 ebc
18b7 18b9 :3 0 68
:2 0 195 :4 0 ebf
18bb 18bd :3 0 68
:2 0 196 :4 0 ec2
18bf 18c1 :3 0 68
:2 0 197 :4 0 ec5
18c3 18c5 :3 0 1858
18c6 0 18c8 ec8
18c9 1857 18c8 0
18cb 16f9 17d4 0
18cb eca 0 1912
60 :3 0 61 :3 0
18cc 18cd 0 60
:3 0 71 :3 0 18cf
18d0 0 23 :2 0
2 :4 0 198 :2 0
73 :2 0 23 :2 0
ece 18d5 18d7 :3 0
ed1 18d1 18d9 18ce
18db 18da :2 0 63
:3 0 74 :3 0 18dd
18de 0 65 :4 0
199 :4 0 68 :2 0
69 :3 0 ed5 18e2
18e4 :3 0 ed8 18df
18e6 :2 0 18e8 edb
18e9 18dc 18e8 0
18ea edd 0 1912
60 :3 0 61 :3 0
18eb 18ec 0 60
:3 0 71 :3 0 18ee
18ef 0 23 :2 0
2 :4 0 19a :2 0
73 :2 0 23 :2 0
edf 18f4 18f6 :3 0
ee2 18f0 18f8 18ed
18fa 18f9 :2 0 63
:3 0 74 :3 0 18fc
18fd 0 65 :4 0
19b :4 0 68 :2 0
69 :3 0 ee6 1901
1903 :3 0 ee9 18fe
1905 :2 0 1907 eec
1908 18fb 1907 0
1909 eee 0 1912
14 :3 0 81 :3 0
19c :3 0 190b 190c
0 56 :3 0 ef0
190d 190f 1910 :2 0
1912 ef2 19b3 15
:3 0 19d :2 0 4
1913 1914 0 60
:3 0 61 :3 0 1916
1917 0 60 :3 0
71 :3 0 1919 191a
0 95 :2 0 2
:4 0 19e :2 0 73
:2 0 23 :2 0 f20
191f 1921 :3 0 f23
191b 1923 1918 1925
1924 :2 0 63 :3 0
74 :3 0 1927 1928
0 65 :4 0 19f
:4 0 68 :2 0 69
:3 0 f27 192c 192e
:3 0 f2a 1929 1930
:2 0 1949 63 :3 0
74 :3 0 1932 1933
0 65 :4 0 1a0
:4 0 68 :2 0 15
:3 0 1a1 :3 0 1938
1939 0 f2d 1937
193b :3 0 68 :2 0
bd :4 0 f30 193d
193f :3 0 68 :2 0
15 :3 0 1a2 :3 0
1942 1943 0 f33
1941 1945 :3 0 f36
1934 1947 :2 0 1949
f39 194a 1926 1949
0 194b f3c 0
195b 1a3 :3 0 5f
:3 0 15 :3 0 1a1
:3 0 1a4 :3 0 15
:3 0 1a2 :3 0 1a5
:3 0 90 :4 0 1a6
1 :a 0 1957 :2 0
195b 194d 1955 :2 0
14 :3 0 5f :3 0
1959 :2 0 195b f3e
195d f42 195c 195b
:2 0 19b1 94 :3 0
15 :3 0 92 :3 0
1960 1961 0 93
:3 0 1962 1963 0
19a9 60 :3 0 61
:3 0 1965 1966 0
60 :3 0 71 :3 0
1968 1969 0 95
:2 0 2 :4 0 1a7
:2 0 73 :2 0 23
:2 0 f44 196e 1970
:3 0 f47 196a 1972
1967 1974 1973 :2 0
63 :3 0 74 :3 0
1976 1977 0 65
:4 0 1a8 :4 0 68
:2 0 69 :3 0 f4b
197b 197d :3 0 f4e
1978 197f :2 0 1999
63 :3 0 74 :3 0
1981 1982 0 65
:4 0 98 :4 0 68
:2 0 93 :3 0 f51
1986 1988 :3 0 68
:2 0 99 :4 0 f54
198a 198c :3 0 68
:2 0 9a :3 0 9b
:3 0 23 :2 0 9c
:2 0 f57 198f 1993
f5b 198e 1995 :3 0
f5e 1983 1997 :2 0
1999 f61 199a 1975
1999 0 199b f64
0 19a9 1a3 :3 0
5f :3 0 1a4 :3 0
15 :3 0 1a2 :3 0
1a5 :3 0 90 :4 0
1a9 1 :a 0 19a5
:2 0 19a9 199d 19a3
:2 0 14 :3 0 5f
:3 0 19a7 :2 0 19a9
f66 19ac :3 0 19ac
0 19ac 19ab 19a9
19aa :6 0 19ae 1
:3 0 f6b 19b0 f6d
19af 19ae :2 0 19b1
f6f :2 0 19b3 f72
19b3 19b2 1912 19b1
:6 0 19b4 :2 0 2
44 19b3 19b7 :3 0
19b6 19b4 19b8 :8 0

fb1
4
:3 0 1 3 1
7 1 b 1
f 1 13 1
17 1 1b 1
1f 1 23 1
27 1 2b 1
2f 1 33 1
37 1 3b f
6 a e 12
16 1a 1e 22
26 2a 2e 32
36 3a 3e 1
48 1 46 1
4f 1 4d 1
56 1 54 1
5d 1 5b 1
64 1 62 1
6b 1 69 1
72 1 70 1
77 1 7e 1
7c 1 85 1
83 1 8c 1
8a 1 93 1
91 1 9a 1
98 1 a1 1
9f 1 a8 1
a6 1 af 1
ad 1 b4 1
b9 1 c0 1
be 1 c5 1
cb 1 d1 1
d7 1 dd 1
e3 1 e9 1
ef 1 f5 1
fb 1 101 1
107 1 10d 1
113 1 119 1
11f 1 125 1
12b 1 131 1
137 1 13d 1
143 1 149 1
14f 1 155 1
15b 1 161 1
167 1 16d 1
173 1 17b 1
179 1 182 1
180 1 187 1
18d 1 195 1
193 1 19a 1
1a0 1 1a6 1
1ac 1 1b2 1
1b8 1 1be 1
1c3 1 1d0 1
1dc 2 1df 1e1
2 1e4 1e6 2
1e8 1ea 2 1ec
1ee 2 1f0 1f2
2 1f4 1f6 2
1f8 1fa 2 1fc
1fe 2 200 202
2 204 206 2
208 20a 2 20c
20e 2 210 212
1 218 2 21a
21b 2 214 21d
2 21f 221 1
227 2 229 22a
2 223 22c 2
22e 230 1 236
2 238 239 2
232 23b 2 23d
23f 1 245 2
247 248 2 241
24a 2 24c 24e
1 254 2 256
257 2 250 259
2 25b 25d 1
263 2 265 266
2 25f 268 2
26a 26c 1 272
2 274 275 2
26e 277 2 279
27b 1 281 2
283 284 2 27d
286 2 288 28a
1 290 2 292
293 2 28c 295
2 297 299 1
29f 2 2a1 2a2
2 29b 2a4 2
2a6 2a8 2 2aa
2ac 2 2ae 2b0
2 2b2 2b4 2
2b6 2b8 2 2ba
2bc 2 2be 2c0
2 2c2 2c4 2
2c6 2c8 4 1d8
1de 1e3 2ca 1
2cc 1 2ce 2
2d8 2da 3 2d6
2d7 2dc 2 2e5
2e7 2 2e4 2e9
1 2eb 1 2ed
2 31f 320 1
322 1 32c 2
339 33b 3 337
338 33d 2 346
348 2 34a 34c
2 34e 350 1
358 2 35a 35b
2 352 35d 2
345 35f 1 361
1 363 2 36d
36f 3 36b 36c
371 2 37a 37c
2 379 37e 1
380 1 382 2
389 38a 3 364
383 38c 1 38e
2 391 392 1
396 2 394 396
2 39a 39b 1
39f 2 39d 39f
2 3a5 3a6 1
3aa 2 3a8 3aa
2 3b7 3b9 3
3b5 3b6 3bb 2
3c4 3c6 2 3c8
3ca 2 3cc 3ce
1 3d6 2 3d8
3d9 2 3d0 3db
2 3c3 3dd 1
3df 1 3e1 2
3eb 3ed 3 3e9
3ea 3ef 2 3f8
3fa 2 3f7 3fc
1 3fe 1 400
2 407 408 3
3e2 401 40a 1
40c 2 40f 410
1 416 2 412
416 1 41a 1
422 2 432 437
2 448 44a 3
446 447 44c 2
455 457 2 459
45b 2 45d 45f
2 461 463 2
465 467 3 46c
46d 46e 2 469
470 2 454 472
1 474 1 476
2 43f 477 1
47b 1 43a 1
47f 1 48a 2
486 48a 2 48f
490 1 494 2
492 494 2 4a2
4a4 3 4a0 4a1
4a6 2 4af 4b1
2 4b3 4b5 2
4b7 4b9 1 4c1
2 4c3 4c4 2
4bb 4c6 2 4ae
4c8 1 4ca 1
4cc 2 4d6 4d8
3 4d4 4d5 4da
2 4e3 4e5 2
4e2 4e7 1 4e9
1 4eb 2 4f2
4f3 3 4cd 4ec
4f5 1 4f7 3
482 4f8 4fb 1
4fe 1 504 2
50f 514 2 525
527 3 523 524
529 2 532 534
2 536 538 2
53a 53c 2 53e
540 2 542 544
3 549 54a 54b
2 546 54d 2
531 54f 1 551
1 553 2 51c
554 1 558 1
517 1 55c 1
55f 2 563 562
2 56e 56f 2
571 574 2 577
578 2 57f 580
2 582 585 2
58b 58c 1 590
2 58e 590 2
59e 5a3 2 5b4
5b6 3 5b2 5b3
5b8 2 5c1 5c3
2 5c5 5c7 2
5c9 5cb 2 5cd
5cf 2 5d1 5d3
3 5d8 5d9 5da
2 5d5 5dc 2
5c0 5de 1 5e0
1 5e2 2 5ab
5e3 1 5e7 1
5a6 1 5eb 1
5f6 2 5f2 5f6
2 600 605 2
616 618 3 614
615 61a 2 623
625 2 627 629
2 62b 62d 2
62f 631 2 633
635 3 63a 63b
63c 2 637 63e
2 622 640 1
642 1 644 2
60d 645 1 649
1 608 1 64d
1 658 2 654
658 2 664 666
3 662 663 668
2 671 673 2
675 677 2 679
67b 1 683 2
685 686 2 67d
688 2 68a 68c
2 68e 690 2
692 694 2 696
698 2 670 69a
1 69c 1 69e
2 6a8 6aa 3
6a6 6a7 6ac 2
6b5 6b7 2 6b4
6b9 1 6bb 1
6bd 3 6c4 6c5
6c6 3 69f 6be
6c8 1 6ca 2
650 6cb 1 6cd
2 6d7 6dc 2
6ed 6ef 3 6eb
6ec 6f1 2 6fa
6fc 2 6fe 700
2 702 704 2
706 708 2 70a
70c 3 711 712
713 2 70e 715
2 6f9 717 1
719 1 71b 2
6e4 71c 1 720
1 6df 1 724
2 72a 72b 1
72f 2 72d 72f
2 737 73c 2
74d 74f 3 74b
74c 751 2 75a
75c 2 75e 760
2 762 764 2
766 768 2 76a
76c 3 771 772
773 2 76e 775
2 759 777 1
779 1 77b 2
744 77c 1 780
1 73f 1 784
2 78c 78d 1
791 2 78f 791
2 79c 79e 3
79a 79b 7a0 2
7a9 7ab 2 7ad
7af 2 7b1 7b3
1 7bb 2 7bd
7be 2 7b5 7c0
2 7c2 7c4 2
7c6 7c8 2 7ca
7cc 2 7ce 7d0
2 7a8 7d2 1
7d4 1 7d6 2
7e0 7e2 3 7de
7df 7e4 2 7ed
7ef 2 7ec 7f1
1 7f3 1 7f5
3 7fc 7fd 7fe
3 7d7 7f6 800
1 802 2 787
803 1 805 5
5ee 6ce 6d1 727
806 1 808 2
815 817 3 813
814 819 2 822
824 2 826 828
2 82a 82c 1
834 2 836 837
2 82e 839 2
821 83b 1 83d
1 83f 2 849
84b 3 847 848
84d 2 856 858
2 855 85a 1
85c 1 85e 2
865 866 3 840
85f 868 1 86a
3 872 873 874
3 876 877 878
4 880 881 882
883 2 889 88a
1 88c 1 890
2 88e 890 2
8ab 8b0 2 8c1
8c3 3 8bf 8c0
8c5 2 8ce 8d0
2 8d2 8d4 2
8d6 8d8 2 8da
8dc 2 8de 8e0
3 8e5 8e6 8e7
2 8e2 8e9 2
8cd 8eb 1 8ed
1 8ef 2 8b8
8f0 1 8f4 1
8b3 1 8f8 1
903 2 8ff 903
2 90f 911 3
90d 90e 913 2
91c 91e 2 920
922 2 924 926
1 92e 2 930
931 2 928 933
2 935 937 2
939 93b 2 93d
93f 2 941 943
2 91b 945 1
947 1 949 2
953 955 3 951
952 957 2 960
962 2 95f 964
1 966 1 968
3 96f 970 971
3 94a 969 973
1 975 2 8fb
976 2 980 982
3 97e 97f 984
2 98d 98f 2
991 993 2 995
997 1 99f 2
9a1 9a2 2 999
9a4 2 9a6 9a8
2 9aa 9ac 2
9ae 9b0 2 9b2
9b4 2 98c 9b6
1 9b8 1 9ba
2 9c4 9c6 3
9c2 9c3 9c8 2
9d1 9d3 2 9d0
9d5 1 9d7 1
9d9 3 9e0 9e1
9e2 3 9bb 9da
9e4 2 9e6 9e7
5 86b 86e 87b
886 9e8 2 9ea
9eb 2 9ee 9ef
1 9f3 2 9f1
9f3 2 9f8 9f9
1 9fd 2 9fb
9fd 1 a05 1
a07 1 a0b 2
a09 a0b 2 a19
a1a 2 a1e a1f
2 a23 a24 2
a28 a29 2 a2d
a2e 2 a32 a33
2 a37 a38 2
a3c a3d d a16
a17 a1c a21 a26
a2b a30 a35 a3a
a3f a40 a41 a42
2 a47 a48 1
a4e 2 a4a a4e
2 a59 a5b 3
a57 a58 a5d 2
a66 a68 2 a6a
a6c 2 a6e a70
1 a78 2 a7a
a7b 2 a72 a7d
2 a65 a7f 1
a81 1 a83 2
a8d a8f 3 a8b
a8c a91 2 a9a
a9c 2 a99 a9e
1 aa0 1 aa2
2 aa9 aaa 3
a84 aa3 aac 2
ab0 ab1 1 ab5
2 ab3 ab5 2
ac0 ac2 3 abe
abf ac4 2 acd
acf 2 ad1 ad3
2 ad5 ad7 1
add 2 adf ae0
2 ad9 ae2 2
ae4 ae6 2 ae8
aea 2 aec aee
2 af0 af2 2
acc af4 1 af6
1 af8 2 b02
b04 3 b00 b01
b06 2 b0f b11
2 b0e b13 1
b15 1 b17 2
b1d b1e 3 b20
b21 b22 3 af9
b18 b24 2 b27
b26 4 a10 a13
a45 b28 1 b2a
2 b2d b2e 1
b32 2 b30 b32
2 b37 b38 1
b3c 2 b3a b3c
2 b43 b44 1
b48 2 b46 b48
2 b4d b4e 1
b52 2 b50 b52
1 b5a 2 b5e
b5f 1 b63 2
b61 b63 1 b68
2 b6d b6e 1
b72 2 b70 b72
2 b77 b78 1
b7c 2 b7a b7c
1 b84 2 b89
b8a 1 b8e 2
b8c b8e 2 b93
b94 2 b99 b9a
2 b96 b9c 2
b9f ba2 4 ba5
b6b b87 ba4 1
ba6 1 ba8 2
bab bac 1 bb0
2 bae bb0 2
bb4 bb5 1 bb9
2 bb7 bb9 2
bc4 bc6 3 bc2
bc3 bc8 2 bd1
bd3 2 bd5 bd7
2 bd9 bdb 1
be3 2 be5 be6
2 bdd be8 2
bea bec 2 bee
bf0 2 bf2 bf4
2 bf6 bf8 2
bd0 bfa 1 bfc
1 bfe 2 c08
c0a 3 c06 c07
c0c 2 c15 c17
2 c14 c19 1
c1b 1 c1d 3
c24 c25 c26 3
bff c1e c28 1
c2a 2 c2d c2e
1 c32 2 c30
c32 1 c37 2
c3d c3e 1 c40
2 c42 c44 1
c46 1 c49 2
c4b c4c 2 c2b
c4d 1 c4f 3
c64 c65 c66 3
c6c c6d c6e 2
c73 c74 1 c78
2 c76 c78 3
c82 c83 c84 1
c88 2 c86 c88
2 ca4 ca9 2
cba cbc 3 cb8
cb9 cbe 2 cc7
cc9 2 ccb ccd
2 ccf cd1 2
cd3 cd5 2 cd7
cd9 3 cde cdf
ce0 2 cdb ce2
2 cc6 ce4 1
ce6 1 ce8 2
cb1 ce9 1 ced
1 cac 1 cf1
2 cfb d00 2
d11 d13 3 d0f
d10 d15 2 d1e
d20 2 d22 d24
2 d26 d28 2
d2a d2c 2 d2e
d30 3 d35 d36
d37 2 d32 d39
2 d1d d3b 1
d3d 1 d3f 2
d08 d40 1 d44
1 d03 1 d48
1 d53 2 d4f
d53 2 d5f d61
3 d5d d5e d63
2 d6c d6e 2
d70 d72 2 d74
d76 1 d7e 2
d80 d81 2 d78
d83 2 d85 d87
2 d89 d8b 2
d8d d8f 2 d91
d93 2 d6b d95
1 d97 1 d99
2 da3 da5 3
da1 da2 da7 2
db0 db2 2 daf
db4 1 db6 1
db8 3 dbf dc0
dc1 3 d9a db9
dc3 1 dc5 2
dd4 dd9 2 dea
dec 3 de8 de9
dee 2 df7 df9
2 dfb dfd 2
dff e01 2 e03
e05 2 e07 e09
3 e0e e0f e10
2 e0b e12 2
df6 e14 1 e16
1 e18 2 de1
e19 1 e1d 1
ddc 1 e21 5
cf4 d4b dc6 dc9
e24 3 e29 e2a
e2b 1 e2f 2
e2d e2f 2 e37
e3c 2 e4d e4f
3 e4b e4c e51
2 e5a e5c 2
e5e e60 2 e62
e64 2 e66 e68
2 e6a e6c 3
e71 e72 e73 2
e6e e75 2 e59
e77 1 e79 1
e7b 2 e44 e7c
1 e80 1 e3f
1 e84 1 e8f
2 e8b e8f 2
e9b e9d 3 e99
e9a e9f 2 ea8
eaa 2 eac eae
2 eb0 eb2 1
eba 2 ebc ebd
2 eb4 ebf 2
ec1 ec3 2 ec5
ec7 2 ec9 ecb
2 ecd ecf 2
ea7 ed1 1 ed3
1 ed5 2 edf
ee1 3 edd ede
ee3 2 eec eee
2 eeb ef0 1
ef2 1 ef4 3
efb efc efd 3
ed6 ef5 eff 1
f01 2 f1f f24
2 f35 f37 3
f33 f34 f39 2
f42 f44 2 f46
f48 2 f4a f4c
2 f4e f50 2
f52 f54 3 f59
f5a f5b 2 f56
f5d 2 f41 f5f
1 f61 1 f63
2 f2c f64 1
f68 1 f27 1
f6c 1 f77 2
f73 f77 2 f94
f99 2 faa fac
3 fa8 fa9 fae
2 fb7 fb9 2
fbb fbd 2 fbf
fc1 2 fc3 fc5
2 fc7 fc9 3
fce fcf fd0 2
fcb fd2 2 fb6
fd4 1 fd6 1
fd8 2 fa1 fd9
1 fdd 1 f9c
1 fe1 1 fe4
1 fe7 2 ff3
ff8 2 1009 100b
3 1007 1008 100d
2 1016 1018 2
101a 101c 2 101e
1020 2 1022 1024
2 1026 1028 3
102d 102e 102f 2
102a 1031 2 1015
1033 1 1035 1
1037 2 1000 1038
1 103c 1 ffb
1 1040 6 e87
f02 f05 f6f fe8
1043 2 104f 1051
3 104d 104e 1053
2 105c 105e 2
1060 1062 2 1064
1066 1 106e 2
1070 1071 2 1068
1073 2 105b 1075
1 1077 1 1079
2 1083 1085 3
1081 1082 1087 2
1090 1092 2 108f
1094 1 1096 1
1098 2 109f 10a0
3 107a 1099 10a2
3 10a4 1046 10a5
1 10ad 2 10a9
10ad 2 10b5 10b6
4 10b3 10b8 10bb
10bc 2 10c4 10c5
4 10c2 10c7 10ca
10cb 1 10f7 2
10f6 10f7 1 10ff
1 1105 2 1107
1108 2 10f4 1109
2 111a 111c 3
1118 1119 111e 2
1127 1129 2 112b
112d 2 112f 1131
2 1133 1135 2
1137 1139 3 113e
113f 1140 2 113b
1142 2 1126 1144
1 1146 1 1148
2 1111 1149 1
114d 1 110c 1
1151 1 1158 4
10bf 10ce 1154 115b
2 1166 1167 4
1164 1169 116c 116d
7 117b 117c 117d
117e 117f 1180 1181
1 11a0 2 119f
11a0 1 11a8 1
11ae 2 11b0 11b1
2 119d 11b2 2
11c3 11c5 3 11c1
11c2 11c7 2 11d0
11d2 2 11d4 11d6
2 11d8 11da 2
11dc 11de 2 11e0
11e2 3 11e7 11e8
11e9 2 11e4 11eb
2 11cf 11ed 1
11ef 1 11f1 2
11ba 11f2 1 11f6
1 11b5 1 11fa
6 1161 1170 1175
1178 1184 11fd 2
1200 1201 2 1204
1205 1 1209 2
1207 1209 1 120d
2 121a 121f 2
1230 1232 3 122e
122f 1234 2 123d
123f 2 1241 1243
2 1245 1247 2
1249 124b 2 124d
124f 3 1254 1255
1256 2 1251 1258
2 123c 125a 1
125c 1 125e 2
1227 125f 1 1263
1 1222 1 1267
3 126d 126e 126f
1 1273 2 1271
1273 1 1278 a
1280 1281 1282 1283
1284 1285 1286 1287
1288 1289 2 127b
128c 1 128e 2
126a 128f 1 1291
3 1297 1298 1299
1 129d 2 129b
129d 1 12a4 2
12a8 12a9 1 12ac
2 12ae 12af 20
12b3 12b4 12b5 12b6
12b7 12b8 12b9 12ba
12bb 12bc 12bd 12be
12bf 12c0 12c1 12c2
12c3 12c4 12c5 12c6
12c7 12c8 12c9 12ca
12cb 12cc 12cd 12ce
12cf 12d0 12d1 12d2
1 12d8 2 12d6
12d8 1 12e2 2
12e1 12e2 1 12ea
1 12f0 2 12f2
12f3 2 12df 12f4
2 1305 1307 3
1303 1304 1309 2
1312 1314 2 1316
1318 2 131a 131c
2 131e 1320 2
1322 1324 3 1329
132a 132b 2 1326
132d 2 1311 132f
1 1331 1 1333
2 12fc 1334 1
1338 1 12f7 1
133c 1 133f 1
1342 9 c7d c80
10a6 1202 1292 1295
12b0 12d5 1343 1
1350 2 1352 1353
1 1357 2 1355
1357 1 135c 1
1362 2 1364 1365
2 1367 1369 2
136c 136e 1 1370
1 1373 2 1375
1376 1 137a 2
1378 137a 2 1382
1383 1 1386 2
1385 1386 2 1393
1394 2 1396 1398
2 139a 139c 4
1390 1391 139e 139f
2 13aa 13ab 2
13ad 13af 2 13b1
13b3 2 13b5 13b7
4 13a7 13a8 13b9
13ba 3 13bf 13c0
13c1 1 13c5 2
13c3 13c5 1 13cf
2 13d1 13d2 1
13d6 2 13d4 13d6
1 13db 2 13df
13e1 3 13e3 13e4
13e5 2 13eb 13ed
3 13ef 13f0 13f1
2 13e8 13f4 2
13f6 13f7 2 13cc
13f8 2 13fc 13fd
1 1403 2 1405
1406 1 140a 2
1408 140a 1 140f
2 1413 1415 3
1417 1418 1419 2
141f 1421 3 1423
1424 1425 2 141c
1428 2 142a 142b
2 1400 142c 2
142e 142f 3 1432
1433 1434 1 1438
2 1436 1438 2
144e 1453 2 1464
1466 3 1462 1463
1468 2 1471 1473
2 1475 1477 2
1479 147b 2 147d
147f 2 1481 1483
3 1488 1489 148a
2 1485 148c 2
1470 148e 1 1490
1 1492 2 145b
1493 1 1497 1
1456 1 149b 3
149e 14a2 14a5 2
14bb 14c0 2 14d1
14d3 3 14cf 14d0
14d5 2 14de 14e0
2 14e2 14e4 2
14e6 14e8 2 14ea
14ec 2 14ee 14f0
3 14f5 14f6 14f7
2 14f2 14f9 2
14dd 14fb 1 14fd
1 14ff 2 14c8
1500 1 1504 1
14c3 1 1508 1
1513 2 150f 1513
2 152b 1530 2
1541 1543 3 153f
1540 1545 2 154e
1550 2 1552 1554
2 1556 1558 2
155a 155c 2 155e
1560 3 1565 1566
1567 2 1562 1569
2 154d 156b 1
156d 1 156f 2
1538 1570 1 1574
1 1533 1 1578
1 157b 1 157e
2 150b 157f 2
1581 1582 3 1588
1589 158a 1 158e
2 158c 158e 1
1595 2 1599 159a
1 159d 2 159f
15a0 20 15a7 15a8
15a9 15aa 15ab 15ac
15ad 15ae 15af 15b0
15b1 15b2 15b3 15b4
15b5 15b6 15b7 15b8
15b9 15ba 15bb 15bc
15bd 15be 15bf 15c0
15c1 15c2 15c3 15c4
15c5 15c6 1 15cc
2 15ca 15cc 1
15d6 2 15d5 15d6
1 15de 1 15e4
2 15e6 15e7 2
15d3 15e8 2 15f9
15fb 3 15f7 15f8
15fd 2 1606 1608
2 160a 160c 2
160e 1610 2 1612
1614 2 1616 1618
3 161d 161e 161f
2 161a 1621 2
1605 1623 1 1625
1 1627 2 15f0
1628 1 162c 1
15eb 1 1630 1
1633 1 1636 2
163a 163b 2 163d
163f a 13a2 13bd
1430 1583 1586 15a1
15a4 15c9 1637 1642
2 137f 1645 1
1647 5 1347 134a
134d 1377 1648 2
164a 164b 1 164f
2 164d 164f 2
1654 1655 1 1659
2 1657 1659 2
1667 1669 3 1665
1666 166b 2 1674
1676 2 1678 167a
2 167c 167e 1
1686 2 1688 1689
2 1680 168b 2
168d 168f 2 1691
1693 2 1695 1697
2 1699 169b 2
1673 169d 1 169f
1 16a1 2 16ab
16ad 3 16a9 16aa
16af 2 16b8 16ba
2 16b7 16bc 1
16be 1 16c0 3
16c7 16c8 16c9 3
16a2 16c1 16cb 1
16cd 2 16d0 16d1
1 16d5 2 16d3
16d5 1 16da 1
16dc 1 16e0 2
16e2 16e3 1 16e7
2 16e5 16e7 1
16ed 2 16ef 16f0
1 16f4 2 16f2
16f4 2 16fb 16fd
2 16ff 1701 2
1703 1705 2 1707
1709 2 170f 1710
1 1712 2 170b
1714 2 1716 1718
2 171e 171f 1
1721 2 171a 1723
2 1725 1727 2
172d 172e 1 1730
2 1729 1732 2
1734 1736 2 1738
173a 2 173c 173e
2 1740 1742 2
1744 1746 2 1748
174a 2 174c 174e
2 1750 1752 2
1754 1756 2 1758
175a 2 175c 175e
2 1760 1762 2
1764 1766 2 1768
176c 2 176e 1770
2 1772 1776 2
1778 177a 2 177c
177e 2 1780 1782
2 1788 1789 1
178b 2 1784 178d
2 178f 1791 2
1797 1798 1 179a
2 1793 179c 2
179e 17a0 2 17a2
17a4 2 17aa 17ab
1 17ad 2 17a6
17af 2 17b1 17b3
2 17b5 17b7 2
17b9 17bb 2 17bd
17bf 2 17c1 17c3
2 17c5 17c7 2
17c9 17cb 2 17cd
17cf 1 17d2 1
17d7 2 17d9 17da
1 17de 2 17dc
17de 2 17e2 17e4
2 17e6 17e8 2
17ea 17ec 2 17ee
17f0 2 17f6 17f7
1 17f9 2 17f2
17fb 2 17fd 17ff
2 1805 1806 1
1808 2 1801 180a
2 180c 180e 2
1814 1815 1 1817
2 1810 1819 2
181b 181d 2 181f
1821 2 1823 1825
2 1827 1829 2
182b 182d 2 182f
1831 2 1833 1835
2 1837 1839 2
183b 183d 2 183f
1841 2 1843 1845
1 1848 1 184e
2 1850 1851 1
1855 2 1853 1855
2 1859 185b 2
185d 1861 2 1863
1865 2 1867 186b
2 186d 186f 2
1871 1873 2 1875
1877 2 187d 187e
1 1880 2 1879
1882 2 1884 1886
2 188c 188d 1
188f 2 1888 1891
2 1893 1895 2
1897 1899 2 189f
18a0 1 18a2 2
189b 18a4 2 18a6
18a8 2 18aa 18ac
2 18ae 18b0 2
18b2 18b4 2 18b6
18b8 2 18ba 18bc
2 18be 18c0 2
18c2 18c4 1 18c7
3 18ca 184b 18c9
2 18d4 18d6 3
18d2 18d3 18d8 2
18e1 18e3 2 18e0
18e5 1 18e7 1
18e9 2 18f3 18f5
3 18f1 18f2 18f7
2 1900 1902 2
18ff 1904 1 1906
1 1908 1 190e
2d 2cf 2ee 2f1
2f4 2f7 2fa 2fd
300 303 306 309
30c 30f 312 315
318 31b 325 328
32b 38f 40d 564
567 57b 589 9ec
a08 b2b ba9 c50
c55 c58 c5b c5e
c61 c69 c71 164c
16ce 16dd 18cb 18ea
1909 1911 2 191e
1920 3 191c 191d
1922 2 192b 192d
2 192a 192f 2
1936 193a 2 193c
193e 2 1940 1944
2 1935 1946 2
1931 1948 1 194a
3 194b 1956 195a
1 1915 2 196d
196f 3 196b 196c
1971 2 197a 197c
2 1979 197e 2
1985 1987 2 1989
198b 3 1990 1991
1992 2 198d 1994
2 1984 1996 2
1980 1998 1 199a
4 1964 199b 19a4
19a8 1 19ac 1
195f 2 195d 19b0
3e 4b 52 59
60 67 6e 75
7a 81 88 8f
96 9d a4 ab
b2 b7 bc c3
c9 cf d5 db
e1 e7 ed f3
f9 ff 105 10b
111 117 11d 123
129 12f 135 13b
141 147 14d 153
159 15f 165 16b
171 177 17e 185
18b 191 198 19e
1a4 1aa 1b0 1b6
1bc 1c1 1c8 
1
4
0 
19b7
0
1
50
2f
4e
0 1 2 1 4 1 6 1
8 1 a 1 c 1 e 1
10 1 12 1 14 1 16 1
18 1 1a 1 1c 1 1e 1
20 1 22 1 24 1 26 27
26 29 26 2b 26 2d 1 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0

3b 1 0
13d 1 0
2b 1 0
173 1 0
1b2 1 0
149 1 0
2f 1 0
1a0 1 0
a6 1 0
107 1 0
e3 1 0
1ac 1 0
8a 1 0
27 1 0
161 1 0
179 1 0
98 1 0
1f 1 0
1b 1 0
1b8 1 0
83 1 0
c5 1 0
16d 1 0
91 1 0
d7 1 0
193 1 0
77 1 0
1be 1 0
18d 1 0
13 1 0
101 1 0
f5 1 0
69 1 0
7c 1 0
131 1 0
9f 1 0
62 1 0
f 1 0
ef 1 0
155 1 0
3 1 0
cb 1 0
b9 1 0
70 1 0
187 1 0
137 1 0
15b 1 0
11f 1 0
113 1 0
23 1 0
2 0 1
4d 1 0
1a6 1 0
7 1 0
14f 1 0
fb 1 0
e9 1 0
143 1 0
dd 1 0
19a 1 0
d1 1 0
5b 1 0
46 1 0
119 1 0
37 1 0
ad 1 0
125 1 0
17 1 0
167 1 0
b4 1 0
be 1 0
12b 1 0
54 1 0
33 1 0
10d 1 0
b 1 0
1c3 1 0
180 1 0
0

/
SHOW ERRORS FUNCTION SP_SEARCH_3;
ALTER FUNCTION SP_SEARCH_3 COMPILE DEBUG;
/*
#Stored Procedure  :SP_I_PROFILE
#Short Description :Assign a profile to a task or project
#Description       :used tables: RESOURCE_ASSIGNMENTS, PROFILES
#Table Name        :
#Parameters        :
#Returns           :
#Errors            :
*/
Prompt == FUNCTION SP_I_PROFILE ==
CREATE OR REPLACE FUNCTION SP_I_PROFILE wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
9a
2 :e:
1FUNCTION:
1SP_I_PROFILE:
1PRJ_ID:
1VARCHAR2:
1AND_ROLES:
1AND_SKILLS:
1ORG_ID001:
1GEO_ID001:
1POOL_ID001:
1REC_USER001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_UNIQUEID:
132:
1H_AND_ROLES:
18000:
1H_ROLE_ID:
1H_FULL_NAME:
1255:
1H_COUNT:
1PLS_INTEGER:
10:
1H_NUMBER:
1NUMITEMS:
1NUMITEMS001:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_I_PROFILE(:
1':
1, :
1);:
1CHECK_TRACE:
11:
134:
1+:
1FPUT:
1               ENTER:: SP_I_PROFILE(35) :: cplan.sql(5331) :: :
1IS NULL:
18:
141:
1      RETURN_INVALID:: SP_I_PROFILE(42) :: cplan.sql(5338) :: :
1 :
1STATE:: :
1COALESCE:
1TO_CHAR:
1PMO_CNST:
1INVALID_PARAMS:
1NULL:
144:
1                EXIT:: SP_I_PROFILE(45) :: cplan.sql(5341) :: :
1PMODEFINES:
1PMO_RETURN_INVALID_SP:
1TRUE:
1SUBSTR:
1MAX:
1PROF_NUMBER:
1PROFILES:
1PROJECT_ID:
1ROLE_ID:
1SELECT COALESCE(MAX(PROF_NUMBER),0)+1 INTO h_number:n      FROM PROFILES:n   +
1   WHERE PROJECT_ID=prj_id/**prj_id*/ AND ROLE_ID=h_role_id:
1SC_STATE:
1SQLCODE:
1OTHERS:
116:
165:
1           EXCEPTION:: SP_I_PROFILE(66) :: cplan.sql(5362) :: :
1SQLCODE:: :
1 SQLERR:: :
1SQLERRM:
1500:
1PMO_ORASTD:
1STRINGCONCAT:
1RTRIM:
1TCP:
1ELEMENT_NAME:
1TC:
1TMT_COMPETENCIES:
1ELEMENT_ID:
1PARENT_ID:
1SELECT PMO_ORASTD.StringConcat(PMO_ORASTD.StringConcat(PMO_ORASTD.StringConca+
1t(PMO_ORASTD.StringConcat(PMO_ORASTD.StringConcat(RTRIM(TCP.ELEMENT_NAME), ',+
1 '), RTRIM(TC.ELEMENT_NAME)), '('), RTRIM(TO_CHAR(h_number))), ')'):n      IN+
1TO h_full_name FROM TMT_COMPETENCIES TC, TMT_COMPETENCIES TCP:n      WHERE TC+
1.ELEMENT_ID = h_role_id AND TCP.ELEMENT_ID = TC.PARENT_ID:
180:
1           EXCEPTION:: SP_I_PROFILE(81) :: cplan.sql(5377) :: :
1=:
1SC_SQL_NO_DATA:
188:
1        RETURN_ERROR:: SP_I_PROFILE(89) :: cplan.sql(5385) :: :
1RECORD_NOT_FOUND:
1 ID:: :
191:
1                EXIT:: SP_I_PROFILE(92) :: cplan.sql(5388) :: :
1PMO_RETURN_ERROR_SP:
1SYS_GUID:
1PROFILE_ID:
1PROFILE_NAME:
1POOL_ID:
1GEO_ID:
1ORG_ID:
1INSERT INTO PROFILES(PROFILE_ID,PROJECT_ID,ROLE_ID,PROF_NUMBER, PROFILE_NAME,+
1 POOL_ID, GEO_ID, ORG_ID):n      VALUES(h_uniqueID, prj_id, h_role_id, h_numb+
1er, h_full_name, pool_id001, geo_id001, org_id001):
1FOUND:
1100:
1112:
1           EXCEPTION:: SP_I_PROFILE(113) :: cplan.sql(5409) :: :
1SC_SQL_SUCCESS:
1TRUNC:
1LENGTH:
1/:
1>:
1WHILE:
1<:
1LOOP:
1PMO_STPU:
1STRNPCPY:
1*:
1RESOURCE_ASSIGN_ROLES:
1PROFICIENCY_LEVEL_ID:
1PREFERENCE_LEVEL_ID:
1EXPERIENCE_ID:
1LAST_USED_DATETIME:
1INSERT INTO RESOURCE_ASSIGN_ROLES:n               SELECT h_uniqueID, ELEMENT_+
1ID, PROFICIENCY_LEVEL_ID, PREFERENCE_LEVEL_ID,:n               EXPERIENCE_ID,+
1 LAST_USED_DATETIME, TO_CHAR(h_count):n               FROM TMT_COMPETENCIES W+
1HERE ELEMENT_ID = h_role_id:
1143:
1           EXCEPTION:: SP_I_PROFILE(144) :: cplan.sql(5440) :: :
1IS NOT NULL:
1RESOURCE_ASSIGN_SKILLS:
1INSERT INTO RESOURCE_ASSIGN_SKILLS:n                  SELECT h_uniqueID, h_ro+
1le_id, PROFICIENCY_LEVEL_ID, EXPERIENCE_ID,:n                  PREFERENCE_LEV+
1EL_ID, LAST_USED_DATETIME, TO_CHAR(h_count):n                  FROM TMT_COMPE+
1TENCIES WHERE ELEMENT_ID = h_role_id:
1180:
1           EXCEPTION:: SP_I_PROFILE(181) :: cplan.sql(5477) :: :
14:
1192:
1       RETURN_STATUS:: SP_I_PROFILE(193) :: cplan.sql(5489) :: :
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
1199:
1           EXCEPTION:: SP_I_PROFILE(200) :: cplan.sql(5496) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1ID:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
1211:
1           EXCEPTION:: SP_I_PROFILE(212) :: cplan.sql(5508) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
5d6
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 81
b0 a3 a0 1c 81 b0 a3 :2 a0
6b 1c 81 b0 :2 a0 6b :2 a0 6b
6e a5 b a 10 :2 a0 6b 6e
:2 a0 6b 6e a5 b 6e 7e a0
b4 2e 6e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c a0 7e b4 2e :2 5a
a0 7e b4 2e :2 5a 52 10 :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b a0 a5 57 b7 19
3c :2 a0 d :4 a0 :2 51 a5 b :2 51
a5 b d :9 a0 12a :2 a0 6b a0
d b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :1f a0 12a
:2 a0 6b a0 d b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6b a0 7e a0 6b b4
2e 5a :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b :2 a0 a5
57 b7 19 3c :2 a0 b4 2e d
:11 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6b a0 7e a0 6b b4
2e 5a :5 a0 a5 b 51 a5 b
7e 51 b4 2e 5a 7e 51 b4
2e a5 b d a0 7e 51 b4
2e a0 51 d :3 a0 51 a5 b
a0 7e a0 b4 2e 82 :3 a0 6b
:2 51 :2 a0 51 a5 b 7e 51 b4
2e 7e 51 b4 2e a0 a5 b
d :c a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :3 a0 51 a5 b 7e 51
b4 2e d b7 a0 47 b7 19
3c a0 7e b4 2e 5a :2 a0 d
:5 a0 a5 b 51 a5 b 7e 51
b4 2e 5a 7e 51 b4 2e a5
b d a0 7e 51 b4 2e a0
51 d :3 a0 51 a5 b a0 7e
a0 b4 2e 82 :3 a0 6b :2 51 :2 a0
51 a5 b 7e 51 b4 2e 7e
51 b4 2e a0 a5 b d :c a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:3 a0 51 a5 b 7e 51 b4 2e
d b7 a0 47 b7 19 3c b7
19 3c b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b :2 a0 a5
57 b7 :2 a0 6b :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 :2 a0 6b :2 6e 7e
:2 a0 6b b4 2e 7e 6e b4 2e
7e :2 a0 6b b4 2e a5 57 b7
19 3c :9 a0 12a e9 dd :2 a0 65
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
:7 a0 12a e9 dd :2 a0 65 b7 a4
b1 11 4f b7 a6 9 a4 b1
11 68 4f 1d 17 b5 
5d6
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 5e
5a 30 66 6f 6b 59 77 84
80 56 8c 95 91 7f 9d 7c
a2 a6 aa ae b1 b5 d2 bd
c1 c4 c5 cd bc ef dd b9
e1 e2 ea dc 10c fa d9 fe
ff 107 f9 129 117 f6 11b 11c
124 116 145 134 138 113 140 133
161 150 154 130 15c 14f 17d 16c
170 178 14c 195 184 188 190 16b
1b5 1a0 1a4 168 1a8 1b0 19f 1bc
1c0 19c 1c4 1c8 1cc 1cf 1d4 1d5
1 1d7 1dc 1e0 1e4 1e7 1ec 1f0
1f4 1f7 1fc 1fd 1ff 204 207 20b
20c 211 216 219 21e 21f 224 227
22b 22c 231 234 239 23a 23f 242
247 248 24d 250 255 256 25b 25e
262 263 268 26b 270 271 276 279
27e 27f 284 287 28c 28d 292 295
299 29a 29f 2a2 2a7 2a8 2ad 2b0
2b5 2b6 2bb 2be 2c3 2c4 2c9 2cc
2d0 2d1 2d6 2d9 2de 2df 2e4 2e7
2ec 2ed 2f2 2f5 2fa 2fb 300 303
307 308 30d 310 315 316 31b 31e
323 324 329 32c 331 332 337 33a
33e 33f 344 347 34c 34d 352 355
35a 35b 360 363 368 369 36e 371
375 376 37b 37e 383 384 389 38c
391 392 397 398 39d 39f 3a3 3a6
3aa 3ae 3b1 3b5 3b9 3bc 3bf 3c4
3c7 3ca 3cd 3ce 3d3 3d4 1 3d6
3db 3df 3e3 3e6 3eb 3f0 3f3 3f7
3f8 3fd 3fe 403 405 409 40c 410
413 414 419 41c 41f 423 426 427
42c 42f 1 432 437 43b 43f 442
446 44a 44d 450 455 458 45b 45e
45f 464 465 1 467 46c 470 474
477 47c 481 484 488 489 48e 491
496 497 49c 49f 4a4 4a5 4aa 4ad
4b1 4b5 4b9 4bd 4c0 4c1 4c3 4c8
4c9 4cb 4cc 4d1 4d2 4d7 4d9 4dd
4e0 4e4 4e8 4eb 4ef 4f3 4f6 4f9
4fe 501 504 507 508 50d 50e 1
510 515 519 51d 520 525 52a 52d
531 532 537 538 53d 53f 543 546
54a 54e 551 555 559 55c 560 561
566 568 56c 56f 573 577 57b 57f
583 587 58b 58e 591 592 594 597
59a 59b 59d 5a1 5a5 5a9 5ad 5b1
5b5 5b9 5bd 5c1 5c5 5d1 5d5 5d9
5dc 5e0 5e4 5e6 1 5ea 5ee 5f2
5f5 5f9 5fd 601 605 608 60c 610
613 616 61b 61e 621 624 625 62a
62b 1 62d 632 636 63a 63d 642
647 64a 64e 64f 654 657 65c 65d
662 665 66a 66b 670 673 677 678
67d 680 685 686 68b 68e 692 696
699 69c 69d 69f 6a0 6a5 6a6 6ab
6ad 6b1 6b4 6b6 6ba 6bc 6c8 6ca
6cc 6cd 6d2 6d6 6d8 6e4 6e6 6ea
6ee 6f2 6f6 6fa 6fe 702 706 70a
70e 712 716 71a 71e 722 726 72a
72e 732 736 73a 73e 742 746 74a
74e 752 756 75a 75e 762 76e 772
776 779 77d 781 783 1 787 78b
78f 792 796 79a 79e 7a2 7a5 7a9
7ad 7b0 7b3 7b8 7bb 7be 7c1 7c2
7c7 7c8 1 7ca 7cf 7d3 7d7 7da
7df 7e4 7e7 7eb 7ec 7f1 7f4 7f9
7fa 7ff 802 807 808 80d 810 814
815 81a 81d 822 823 828 82b 82f
833 836 839 83a 83c 83d 842 843
848 84a 84e 851 853 857 859 865
867 869 86a 86f 873 875 881 883
887 88b 88e 892 895 899 89c 89d
8a2 8a5 8a9 8ad 8b0 8b4 8b8 8bb
8be 8c3 8c6 8c9 8cc 8cd 8d2 8d3
1 8d5 8da 8de 8e2 8e5 8ea 8ef
8f2 8f6 8f7 8fc 8ff 904 905 90a
90d 912 913 918 91b 91f 923 927
92b 92e 92f 931 936 937 939 93a
93f 942 947 948 94d 950 955 956
95b 95e 962 963 968 96b 970 971
976 977 97c 97e 982 985 989 98d
990 994 998 99b 99e 9a3 9a6 9a9
9ac 9ad 9b2 9b3 1 9b5 9ba 9be
9c2 9c5 9ca 9cf 9d2 9d6 9d7 9dc
9dd 9e2 9e4 9e8 9eb 9ef 9f3 9f6
9fa 9fe a01 a05 a09 a0a a0f a11
a15 a18 a1c a20 a21 a26 a2a a2e
a32 a36 a3a a3e a42 a46 a4a a4e
a52 a56 a5a a5e a62 a66 a6a a6e
a7a a7e a83 a87 a8a a8b a90 a94
a98 a9b a9e aa2 aa4 aa8 aac aaf
ab2 ab6 ab8 abc ac0 ac3 ac5 1
ac9 acd ad1 ad4 ad8 adc ae0 ae4
ae7 aeb aef af2 af5 afa afd b00
b03 b04 b09 b0a 1 b0c b11 b15
b19 b1c b21 b26 b29 b2d b2e b33
b36 b3b b3c b41 b44 b49 b4a b4f
b52 b56 b57 b5c b5f b64 b65 b6a
b6d b71 b75 b78 b7b b7c b7e b7f
b84 b85 b8a b8c b90 b93 b95 b99
b9b ba7 ba9 bab bac bb1 bb5 bb7
bc3 bc5 bc9 bcd bd0 bd4 bd7 bdb
bde bdf be4 be7 beb bef bf3 bf7
bfb bfc bfe c01 c02 c04 c07 c0a
c0b c10 c13 c16 c19 c1a c1f c20
c22 c26 c2a c2d c30 c31 c36 c3a
c3d c41 c45 c49 c4d c50 c51 c53
c57 c5a c5e c5f c64 c66 c6a c6e
c72 c75 c78 c7b c7f c83 c86 c87
c89 c8c c8f c90 c95 c98 c9b c9c
ca1 ca5 ca6 ca8 cac cb0 cb4 cb8
cbc cc0 cc4 cc8 ccc cd0 cd4 cd8
cdc ce8 cec cf1 cf5 cf8 cf9 cfe
d02 d06 d09 d0c d10 d12 d16 d1a
d1d d20 d24 d26 d2a d2e d31 d33
1 d37 d3b d3f d42 d46 d4a d4e
d52 d55 d59 d5d d60 d63 d68 d6b
d6e d71 d72 d77 d78 1 d7a d7f
d83 d87 d8a d8f d94 d97 d9b d9c
da1 da4 da9 daa daf db2 db7 db8
dbd dc0 dc4 dc5 dca dcd dd2 dd3
dd8 ddb ddf de3 de6 de9 dea dec
ded df2 df3 df8 dfa dfe e01 e03
e07 e09 e15 e17 e19 e1a e1f e23
e25 e31 e33 e37 e3b e3f e42 e43
e45 e48 e4b e4c e51 e55 e57 e5b
e62 e64 e68 e6b e6f e72 e73 e78
e7b e7f e83 e87 e8b e8f e93 e97
e9b e9c e9e ea1 ea2 ea4 ea7 eaa
eab eb0 eb3 eb6 eb9 eba ebf ec0
ec2 ec6 eca ecd ed0 ed1 ed6 eda
edd ee1 ee5 ee9 eed ef0 ef1 ef3
ef7 efa efe eff f04 f06 f0a f0e
f12 f15 f18 f1b f1f f23 f26 f27
f29 f2c f2f f30 f35 f38 f3b f3c
f41 f45 f46 f48 f4c f50 f54 f58
f5c f60 f64 f68 f6c f70 f74 f78
f7c f88 f8c f91 f95 f98 f99 f9e
fa2 fa6 fa9 fac fb0 fb2 fb6 fba
fbd fc0 fc4 fc6 fca fce fd1 fd3
1 fd7 fdb fdf fe2 fe6 fea fee
ff2 ff5 ff9 ffd 1000 1003 1008 100b
100e 1011 1012 1017 1018 1 101a 101f
1023 1027 102a 102f 1034 1037 103b 103c
1041 1044 1049 104a 104f 1052 1057 1058
105d 1060 1064 1065 106a 106d 1072 1073
1078 107b 107f 1083 1086 1089 108a 108c
108d 1092 1093 1098 109a 109e 10a1 10a3
10a7 10a9 10b5 10b7 10b9 10ba 10bf 10c3
10c5 10d1 10d3 10d7 10db 10df 10e2 10e3
10e5 10e8 10eb 10ec 10f1 10f5 10f7 10fb
1102 1104 1108 110b 110d 1111 1114 1116
111a 111d 1121 1125 1128 112c 1130 1133
1136 113b 113e 1141 1144 1145 114a 114b
1 114d 1152 1156 115a 115d 1162 1167
116a 116e 116f 1174 1177 117c 117d 1182
1185 118a 118b 1190 1193 1197 119b 119f
11a3 11a6 11a7 11a9 11ae 11af 11b1 11b2
11b7 11ba 11bf 11c0 11c5 11c8 11cd 11ce
11d3 11d6 11da 11db 11e0 11e3 11e8 11e9
11ee 11ef 11f4 11f6 11fa 11fd 1201 1205
1208 120c 1210 1213 1217 121b 121c 1221
1223 1227 122b 122e 1232 1236 1239 123d
1241 1244 1247 124c 124f 1252 1255 1256
125b 125c 1 125e 1263 1267 126b 126e
1273 1278 127b 127f 1280 1285 1286 128b
128f 1293 1296 129b 12a0 12a3 12a7 12ab
12ae 12af 12b4 12b7 12bc 12bd 12c2 12c5
12c9 12cd 12d0 12d1 12d6 12d7 12dc 12de
12e2 12e5 12e9 12ed 12f1 12f5 12f9 12fd
1301 1305 1309 1315 131a 131e 1322 1326
132a 132c 132d 1332 1 1336 133a 133e
1341 1345 1349 134d 1351 1354 1358 135c
135f 1362 1367 136a 136d 1370 1371 1376
1377 1 1379 137e 1382 1386 1389 138e
1393 1396 139a 139b 13a0 13a1 13a6 13aa
13ae 13b1 13b6 13bb 13be 13c2 13c3 13c8
13cb 13d0 13d1 13d6 13d9 13dd 13e1 13e4
13e7 13e8 13ea 13eb 13f0 13f1 13f6 13f8
13fc 13ff 1403 1407 140b 140f 1413 1417
141b 1427 142c 1430 1434 1438 143c 143e
1442 1444 1450 1452 1454 1455 145a 145e
1460 146c 1470 1472 1473 147c 
5d6
2
0 1 a 6 d :3 6 10 :3 6
11 :3 6 10 :3 6 10 :3 6 11 :3 6
12 :2 6 1 3 a 13 a :2 1
4 f 18 17 :2 f :2 4 10 19
18 :2 10 :2 4 e 17 16 :2 e :2 4
10 19 18 :2 10 :2 4 :2 c 1b c
:2 4 :2 d 1c d :2 4 :3 d :2 4 :3 10
:2 4 e 17 :3 e 4 7 :2 11 23
:2 2d 3a :2 23 :3 7 :2 d 19 25 :2 2f
43 :2 25 54 5a 5d :2 54 6b 81
8 :2 6b d 10 :2 6b 17 1a :2 6b
b e :2 6b 13 16 :2 6b 1b 1e
:2 6b 28 2b :2 6b b e :2 6b 13
16 :2 6b 1b 1e :2 6b 29 2c :2 6b
b e :2 6b 13 16 :2 6b 1b 1e
:2 6b 28 2b :2 6b b e :2 6b 13
16 :2 6b 1b 1e :2 6b 28 2b :2 6b
b e :2 6b 13 16 :2 6b 1b 1e
:2 6b 29 2c :2 6b b e :2 6b 13
16 :2 6b 1b 1e :2 6b 2a 2d :2 6b
32 35 :2 6b :2 7 4a :2 4 7 :2 11
23 :2 2d 39 3c 4c 4e 4f :2 4c
:2 23 :3 7 :2 d 12 1e 5c 5f :2 1e
:2 7 52 :2 4 :4 9 8 7 :4 1f 1e
1d :2 7 a :2 14 26 :2 30 3c 3f
4f 51 52 :2 4f :2 26 :3 a :2 10 15
21 5f 62 :2 21 6f 72 :2 21 76
79 :2 21 83 86 8f 97 :2 a0 :2 8f
b1 :2 86 :2 21 :2 a 55 :2 7 a :2 14
26 :2 30 3c 3f 4f 51 52 :2 4f
:2 26 :3 a :2 10 15 21 5f 62 :2 21
:2 a 55 :3 7 :2 12 28 :2 31 41 :2 7
33 :3 4 13 :2 4 11 18 1f 2c
2f :2 18 34 37 :2 11 4 e 17
1b 32 c d 18 2e 36 :2 7
:2 10 1c 7 4 :2 c a :2 13 1f
a d :2 17 29 :2 33 3f 43 53
55 56 :2 53 :2 29 :3 d :2 13 18 24
62 65 :2 24 72 75 :2 24 79 7c
:2 24 88 8b :2 24 93 96 :2 24 a2
a5 ac b5 b8 :2 a5 :2 24 :2 d 59
:2 a :2 7 :4 13 :2 7 4 :3 1 e 19
26 31 3e 49 56 61 6e 79
86 8c 90 a6 ac af c5 cb
d3 c 1d 2e 32 43 d 10
1d 2b 2f 3c 3f :2 7 :2 10 1c
7 4 :2 c a :2 13 1f a d
:2 17 29 :2 33 3f 43 53 55 56
:2 53 :2 29 :3 d :2 13 18 24 62 65
:2 24 72 75 :2 24 79 7c :2 24 88
8b :2 24 93 96 :2 24 a2 a5 ac
b5 b8 :2 a5 :2 24 :2 d 59 :2 a :2 7
:4 13 :2 7 4 :3 1 8 :2 11 1c 1a
:2 25 :2 1a 7 a :2 14 26 :2 30 3c
40 50 52 53 :2 50 :2 26 :3 a :2 10
15 21 5f 62 :2 21 6f 72 :2 21
76 79 :2 21 83 86 8f 97 :2 a0
:2 8f b3 :2 86 :2 21 bb be :2 21 c6
c9 :2 21 ce d1 :2 21 db de :2 21
:2 a 56 :2 7 a :2 14 26 :2 30 3c
3f 4f 51 52 :2 4f :2 26 :3 a :2 10
15 21 5f 62 :2 21 :2 a 55 :3 7
:2 12 26 :2 2f 41 4c :2 7 35 :3 4
:3 12 4 13 1c 27 32 3a 47
55 5e 66 e 1a 22 2d 37
44 50 5b 7 e a 16 :3 14
a :2 13 1f a 1b a :2 13 1f
a :4 7 4 :2 c a :2 13 1f a
d :2 17 29 :2 33 3f 43 53 56
57 :2 53 :2 29 :3 d :2 13 18 24 63
66 :2 24 73 76 :2 24 7a 7d :2 24
89 8c :2 24 94 97 :2 24 a3 a6
ad b6 b9 :2 a6 :2 24 :2 d 5a :2 a
:2 7 :4 13 :2 7 4 :3 1 8 :2 11 1c
1a :2 25 :2 1a :2 7 13 1a 23 2a
:2 23 38 :2 1a 3b 3d :2 1a 19 40
42 :2 19 :2 13 7 a 13 15 :2 13
a 15 :2 a 10 19 22 :2 10 27
25 30 :2 25 a d 1a :2 23 2c
30 34 3d 46 :2 34 49 4b :2 34
4d 4e :2 34 51 :2 1a d 1c 17
23 2f 45 10 1f 33 3b 15
2c 39 10 17 13 1f :3 1d 13
:2 1c 28 13 24 13 :2 1c 28 13
:4 10 d :2 15 13 :2 1c 28 13 16
:2 20 32 :2 3c 48 4c 5c 5f 60
:2 5c :2 32 :3 16 :2 1c 21 2d 6c 6f
:2 2d 7c 7f :2 2d 83 86 :2 2d 92
95 :2 2d 9d a0 :2 2d ac af b6
bf c2 :2 af :2 2d :2 16 63 :2 13 :2 10
:4 1c :2 10 d :3 30 d 18 21 2a
:2 18 2d 2f :2 18 d 30 e a
17 :2 7 :4 b :2 a 19 :2 a 19 20
29 30 :2 29 3e :2 20 41 43 :2 20
1f 46 48 :2 1f :2 19 a d 19
1b :2 19 d 18 :2 d 13 1c 25
:2 13 2a 28 36 :2 28 d 10 1d
:2 26 2f 33 37 40 49 :2 37 4c
4e :2 37 50 51 :2 37 54 :2 1d 10
1f 1a 26 31 47 13 28 3c
44 18 2f 3c 13 1a 16 22
:3 20 16 :2 1f 2b 16 27 16 :2 1f
2b 16 :4 13 10 :2 18 16 :2 1f 2b
16 19 :2 23 35 :2 3f 4b 4f 5f
62 63 :2 5f :2 35 :3 19 :2 1f 24 30
6f 72 :2 30 7f 82 :2 30 86 89
:2 30 95 98 :2 30 a0 a3 :2 30 af
b2 b9 c2 c5 :2 b2 :2 30 :2 19 66
:2 16 :2 13 :4 1f :2 13 10 :3 36 10 1b
24 2d :2 1b 30 32 :2 1b 10 36
11 d 1d :2 a 23 :2 7 35 :2 4
7 :2 11 23 :2 2d 39 3c 4c 4f
50 :2 4c :2 23 :3 7 :2 d 12 1e 5d
60 :2 1e 6d 70 :2 1e 74 77 :2 1e
81 84 8d 95 :2 9e :2 8d a9 :2 84
:2 1e b1 b4 :2 1e bc bf :2 1e c4
c7 :2 1e d2 d5 :2 1e :2 7 53 :3 4
:2 f 21 :2 2a 34 40 :2 4 1 9
12 9 a :2 14 26 :2 30 3c 40
50 53 54 :2 50 :2 26 :3 a :2 10 15
21 60 63 :2 21 :3 a :2 10 15 39
5c 5f :2 68 :2 39 76 79 :2 39 81
84 :2 8d :2 39 :2 a 57 :3 7 c 15
1e 2c a 13 1e f e 7
e 7 e 7 29 :2 4 :2 9 7
:2 10 1c :2 7 :2 11 23 :2 2d 39 3d
4d 50 51 :2 4d :2 23 :3 7 :2 d 12
1e 5d 60 :2 1e :3 7 :2 d 12 36
42 45 :2 36 4d 50 :2 36 5c 5f
66 6f 72 :2 5f :2 36 :2 7 54 :2 4
7 c 1b a 13 1e f e
7 e 7 e 7 :2 4 :4 10 :2 4
:8 1 
5d6
4
0 :2 1 :4 3 :4 4
:4 5 :4 6 :4 7 :4 8
:4 9 2 :4 a :2 1
:7 c :7 d :7 e :7 f
:6 10 :6 11 :5 12 :5 13
:7 15 :b 17 :11 18 19
:2 18 :2 19 :2 18 :2 19
:2 18 :2 1a :2 18 :2 1a
:2 18 :2 1a :2 18 :2 1a
:2 18 :2 1b :2 18 :2 1b
:2 18 :2 1b :2 18 :2 1b
:2 18 :2 1c :2 18 :2 1c
:2 18 :2 1c :2 18 :2 1c
:2 18 :2 1d :2 18 :2 1d
:2 18 :2 1d :2 18 :2 1d
:2 18 :2 1e :2 18 :2 1e
:2 18 :2 1e :2 18 :2 1e
:2 18 :2 1f :2 18 :2 1f
:2 18 :2 1f :2 18 :2 1f
:2 18 :2 1f :4 18 :3 17
:11 22 :b 23 :3 22 :e 28
:11 29 :20 2a :3 29 :11 2c
:b 2d :3 2c :9 2f :3 28
:3 33 :d 36 :4 39 3a
:4 3b 39 :5 3c 38
:2 3e :5 40 :11 41 :24 42
:3 41 :2 3f :6 3e 3d
:3 16 :13 48 :5 49 :7 4a
48 :5 4b 47 :2 4d
:5 4f :11 50 :24 51 :3 50
:2 4e :6 4d 4c :3 16
:a 57 :11 58 :30 59 :3 58
:11 5b :b 5c :3 5b :a 5e
:3 57 :5 62 :9 65 :8 66
65 :6 67 :5 68 67
:5 6a 69 :3 67 64
:2 6d :5 6f :11 70 :24 71
:3 70 :2 6e :6 6d 6c
:3 16 :a 76 :16 78 :5 79
:3 7a :c 7b :17 7f 82
:4 83 :4 84 :3 85 82
:6 86 :5 87 86 :5 89
88 :3 86 81 :2 8c
:5 8e :11 8f :24 90 :3 8f
:2 8d :6 8c 8b :3 7b
:b 94 7b 95 7b
:3 79 :5 99 :3 9b :16 9c
:5 9e :3 9f :c a0 :17 a4
a7 :4 a8 :4 a9 :3 aa
a7 :6 ab :5 ac ab
:5 ae ad :3 ab a6
:2 b1 :5 b3 :11 b4 :24 b5
:3 b4 :2 b2 :6 b1 b0
:3 a0 :b ba a0 bb
a0 :3 9e :3 99 :3 76
:11 c0 :30 c1 :3 c0 :a c3
16 :3 c6 :11 c7 :b c8
:17 c9 :3 c7 :2 cb :3 cc
:3 cd ce cc cb
cc :3 cf :3 c6 :2 d0
:5 d2 :11 d3 :b d4 :18 d5
:3 d3 :2 d7 d8 :3 d9
da d8 d7 d8
:3 db :2 d1 :6 d0 c5
:7 1 
147e
4
:3 0 1 :3 0 2
:a 0 5d1 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
56 0 7 4
:3 0 5 :7 0 9
8 :3 0 4 :3 0
6 :7 0 d c
:3 0 d 7c 0
b 4 :3 0 7
:7 0 11 10 :3 0
4 :3 0 8 :7 0
15 14 :3 0 11
:2 0 f 4 :3 0
9 :7 0 19 18
:3 0 4 :3 0 a
:7 0 1d 1c :3 0
b :3 0 c :3 0
d :2 0 4 21
22 0 1f 23
0 5d1 2 24
:2 0 11 :2 0 1b
4 :3 0 f :2 0
19 27 29 :6 0
2c 2a 0 5cf
0 e :6 0 f
:2 0 1f 4 :3 0
1d 2e 30 :6 0
33 31 0 5cf
0 10 :6 0 14
:2 0 23 4 :3 0
21 35 37 :6 0
3a 38 0 5cf
0 12 :6 0 17
:2 0 27 4 :3 0
25 3c 3e :6 0
41 3f 0 5cf
0 13 :6 0 17
:2 0 29 16 :3 0
43 :7 0 47 44
45 5cf 0 15
:6 0 2d 168 0
2b 16 :3 0 49
:7 0 4d 4a 4b
5cf 0 18 :6 0
59 5a 0 2f
16 :3 0 4f :7 0
52 50 0 5cf
0 19 :6 0 16
:3 0 54 :7 0 57
55 0 5cf 0
1a :6 0 5f 60
0 31 c :3 0
d :2 0 4 5b
:7 0 5e 5c 0
5cf 0 1b :6 0
1c :3 0 1d :3 0
1c :3 0 1e :3 0
62 63 0 2
:4 0 33 64 66
61 68 67 :2 0
1f :3 0 20 :3 0
6a 6b 0 21
:4 0 1c :3 0 22
:3 0 6e 6f 0
2 :4 0 35 70
72 23 :4 0 24
:2 0 25 :3 0 37
75 77 :3 0 26
:4 0 24 :2 0 27
:4 0 3a 7a 7c
:3 0 24 :2 0 3
:3 0 3d 7e 80
:3 0 24 :2 0 27
:4 0 40 82 84
:3 0 24 :2 0 28
:4 0 43 86 88
:3 0 24 :2 0 27
:4 0 46 8a 8c
:3 0 24 :2 0 5
:3 0 49 8e 90
:3 0 24 :2 0 27
:4 0 4c 92 94
:3 0 24 :2 0 28
:4 0 4f 96 98
:3 0 24 :2 0 27
:4 0 52 9a 9c
:3 0 24 :2 0 6
:3 0 55 9e a0
:3 0 24 :2 0 27
:4 0 58 a2 a4
:3 0 24 :2 0 28
:4 0 5b a6 a8
:3 0 24 :2 0 27
:4 0 5e aa ac
:3 0 24 :2 0 7
:3 0 61 ae b0
:3 0 24 :2 0 27
:4 0 64 b2 b4
:3 0 24 :2 0 28
:4 0 67 b6 b8
:3 0 24 :2 0 27
:4 0 6a ba bc
:3 0 24 :2 0 8
:3 0 6d be c0
:3 0 24 :2 0 27
:4 0 70 c2 c4
:3 0 24 :2 0 28
:4 0 73 c6 c8
:3 0 24 :2 0 27
:4 0 76 ca cc
:3 0 24 :2 0 9
:3 0 79 ce d0
:3 0 24 :2 0 27
:4 0 7c d2 d4
:3 0 24 :2 0 28
:4 0 7f d6 d8
:3 0 24 :2 0 27
:4 0 82 da dc
:3 0 24 :2 0 a
:3 0 85 de e0
:3 0 24 :2 0 27
:4 0 88 e2 e4
:3 0 24 :2 0 29
:4 0 8b e6 e8
:3 0 8e 6c ea
:2 0 ec 93 ed
69 ec 0 ee
95 0 52f 1c
:3 0 1d :3 0 ef
f0 0 1c :3 0
2a :3 0 f2 f3
0 2b :2 0 2
:4 0 2c :2 0 2d
:2 0 2b :2 0 97
f8 fa :3 0 9a
f4 fc f1 fe
fd :2 0 1f :3 0
2e :3 0 100 101
0 21 :4 0 2f
:4 0 24 :2 0 25
:3 0 9e 105 107
:3 0 a1 102 109
:2 0 10b a4 10c
ff 10b 0 10d
a6 0 52f 3
:3 0 30 :2 0 a8
10f 110 :3 0 111
:2 0 112 :2 0 5
:3 0 30 :2 0 aa
115 116 :3 0 117
:2 0 118 :2 0 113
11a 119 :2 0 1c
:3 0 1d :3 0 11c
11d 0 1c :3 0
2a :3 0 11f 120
0 31 :2 0 2
:4 0 32 :2 0 2d
:2 0 2b :2 0 ac
125 127 :3 0 af
121 129 11e 12b
12a :2 0 1f :3 0
2e :3 0 12d 12e
0 21 :4 0 33
:4 0 24 :2 0 25
:3 0 b3 132 134
:3 0 24 :2 0 34
:4 0 b6 136 138
:3 0 24 :2 0 35
:4 0 b9 13a 13c
:3 0 24 :2 0 36
:3 0 37 :3 0 38
:3 0 39 :3 0 141
142 0 bc 140
144 3a :4 0 be
13f 147 c1 13e
149 :3 0 c4 12f
14b :2 0 14d c7
14e 12c 14d 0
14f c9 0 178
1c :3 0 1d :3 0
150 151 0 1c
:3 0 2a :3 0 153
154 0 2b :2 0
2 :4 0 3b :2 0
2d :2 0 2b :2 0
cb 159 15b :3 0
ce 155 15d 152
15f 15e :2 0 1f
:3 0 2e :3 0 161
162 0 21 :4 0
3c :4 0 24 :2 0
25 :3 0 d2 166
168 :3 0 d5 163
16a :2 0 16c d8
16d 160 16c 0
16e da 0 178
3d :3 0 3e :3 0
16f 170 0 38
:3 0 39 :3 0 172
173 0 3f :3 0
dc 171 176 :2 0
178 df 179 11b
178 0 17a e3
0 52f 10 :3 0
5 :3 0 17b 17c
0 52f 12 :3 0
40 :3 0 40 :3 0
10 :3 0 2b :2 0
f :2 0 e5 180
184 2b :2 0 f
:2 0 e9 17f 188
17e 189 0 52f
36 :3 0 41 :3 0
42 :3 0 18 :3 0
43 :3 0 44 :3 0
3 :3 0 45 :3 0
12 :4 0 46 1
:8 0 19a c :3 0
47 :3 0 195 196
0 48 :3 0 197
198 0 19a ed
1e4 49 :3 0 c
:3 0 47 :3 0 19d
19e 0 48 :3 0
19f 1a0 0 1da
1c :3 0 1d :3 0
1a2 1a3 0 1c
:3 0 2a :3 0 1a5
1a6 0 4a :2 0
2 :4 0 4b :2 0
2d :2 0 2b :2 0
f0 1ab 1ad :3 0
f3 1a7 1af 1a4
1b1 1b0 :2 0 1f
:3 0 2e :3 0 1b3
1b4 0 21 :4 0
4c :4 0 24 :2 0
25 :3 0 f7 1b8
1ba :3 0 24 :2 0
34 :4 0 fa 1bc
1be :3 0 24 :2 0
4d :4 0 fd 1c0
1c2 :3 0 24 :2 0
48 :3 0 100 1c4
1c6 :3 0 24 :2 0
4e :4 0 103 1c8
1ca :3 0 24 :2 0
40 :3 0 4f :3 0
2b :2 0 50 :2 0
106 1cd 1d1 10a
1cc 1d3 :3 0 10d
1b5 1d5 :2 0 1d7
110 1d8 1b2 1d7
0 1d9 112 0
1da 114 1dd :3 0
1dd 0 1dd 1dc
1da 1db :6 0 1df
2 :3 0 117 1e1
119 1e0 1df :2 0
1e2 11b :2 0 1e4
0 1e4 1e3 19a
1e2 :6 0 52f 1
:3 0 51 :3 0 52
:3 0 51 :3 0 52
:3 0 51 :3 0 52
:3 0 51 :3 0 52
:3 0 51 :3 0 52
:3 0 53 :3 0 54
:3 0 55 :3 0 53
:3 0 56 :3 0 55
:3 0 53 :3 0 37
:3 0 18 :3 0 13
:3 0 57 :3 0 56
:3 0 57 :3 0 54
:3 0 56 :3 0 58
:3 0 12 :3 0 54
:3 0 58 :3 0 56
:3 0 59 :4 0 5a
1 :8 0 20b c
:3 0 47 :3 0 206
207 0 48 :3 0
208 209 0 20b
11d 255 49 :3 0
c :3 0 47 :3 0
20e 20f 0 48
:3 0 210 211 0
24b 1c :3 0 1d
:3 0 213 214 0
1c :3 0 2a :3 0
216 217 0 4a
:2 0 2 :4 0 5b
:2 0 2d :2 0 2b
:2 0 120 21c 21e
:3 0 123 218 220
215 222 221 :2 0
1f :3 0 2e :3 0
224 225 0 21
:4 0 5c :4 0 24
:2 0 25 :3 0 127
229 22b :3 0 24
:2 0 34 :4 0 12a
22d 22f :3 0 24
:2 0 4d :4 0 12d
231 233 :3 0 24
:2 0 48 :3 0 130
235 237 :3 0 24
:2 0 4e :4 0 133
239 23b :3 0 24
:2 0 40 :3 0 4f
:3 0 2b :2 0 50
:2 0 136 23e 242
13a 23d 244 :3 0
13d 226 246 :2 0
248 140 249 223
248 0 24a 142
0 24b 144 24e
:3 0 24e 0 24e
24d 24b 24c :6 0
250 4 :3 0 147
252 149 251 250
:2 0 253 14b :2 0
255 0 255 254
20b 253 :6 0 52f
1 :3 0 c :3 0
47 :3 0 257 258
0 c :3 0 5d
:2 0 5e :3 0 25a
25c 0 14f 25b
25e :3 0 25f :2 0
1c :3 0 1d :3 0
261 262 0 1c
:3 0 2a :3 0 264
265 0 f :2 0
2 :4 0 5f :2 0
2d :2 0 2b :2 0
152 26a 26c :3 0
155 266 26e 263
270 26f :2 0 1f
:3 0 2e :3 0 272
273 0 21 :4 0
60 :4 0 24 :2 0
25 :3 0 159 277
279 :3 0 24 :2 0
34 :4 0 15c 27b
27d :3 0 24 :2 0
35 :4 0 15f 27f
281 :3 0 24 :2 0
36 :3 0 37 :3 0
38 :3 0 61 :3 0
286 287 0 162
285 289 3a :4 0
164 284 28c 167
283 28e :3 0 24
:2 0 62 :4 0 16a
290 292 :3 0 24
:2 0 27 :4 0 16d
294 296 :3 0 24
:2 0 12 :3 0 170
298 29a :3 0 24
:2 0 27 :4 0 173
29c 29e :3 0 176
274 2a0 :2 0 2a2
179 2a3 271 2a2
0 2a4 17b 0
2ce 1c :3 0 1d
:3 0 2a5 2a6 0
1c :3 0 2a :3 0
2a8 2a9 0 2b
:2 0 2 :4 0 63
:2 0 2d :2 0 2b
:2 0 17d 2ae 2b0
:3 0 180 2aa 2b2
2a7 2b4 2b3 :2 0
1f :3 0 2e :3 0
2b6 2b7 0 21
:4 0 64 :4 0 24
:2 0 25 :3 0 184
2bb 2bd :3 0 187
2b8 2bf :2 0 2c1
18a 2c2 2b5 2c1
0 2c3 18c 0
2ce 3d :3 0 65
:3 0 2c4 2c5 0
38 :3 0 61 :3 0
2c7 2c8 0 12
:3 0 3f :3 0 18e
2c6 2cc :2 0 2ce
192 2cf 260 2ce
0 2d0 196 0
52f e :3 0 66
:4 0 2d2 2d3 :3 0
2d1 2d4 0 52f
43 :3 0 67 :3 0
44 :3 0 45 :3 0
42 :3 0 68 :3 0
69 :3 0 6a :3 0
6b :3 0 e :3 0
3 :3 0 12 :3 0
18 :3 0 13 :3 0
9 :3 0 8 :3 0
7 :4 0 6c 1
:8 0 2fd 6d :4 0
2e8 :3 0 3f :3 0
5d :2 0 19a 2eb
2ec :3 0 c :3 0
47 :3 0 2ee 2ef
0 17 :2 0 2f0
2f1 0 2f3 19d
2fa c :3 0 47
:3 0 2f4 2f5 0
6e :2 0 2f6 2f7
0 2f9 19f 2fb
2ed 2f3 0 2fc
0 2f9 0 2fc
1a1 0 2fd 1a4
347 49 :3 0 c
:3 0 47 :3 0 300
301 0 48 :3 0
302 303 0 33d
1c :3 0 1d :3 0
305 306 0 1c
:3 0 2a :3 0 308
309 0 4a :2 0
2 :4 0 6f :2 0
2d :2 0 2b :2 0
1a7 30e 310 :3 0
1aa 30a 312 307
314 313 :2 0 1f
:3 0 2e :3 0 316
317 0 21 :4 0
70 :4 0 24 :2 0
25 :3 0 1ae 31b
31d :3 0 24 :2 0
34 :4 0 1b1 31f
321 :3 0 24 :2 0
4d :4 0 1b4 323
325 :3 0 24 :2 0
48 :3 0 1b7 327
329 :3 0 24 :2 0
4e :4 0 1ba 32b
32d :3 0 24 :2 0
40 :3 0 4f :3 0
2b :2 0 50 :2 0
1bd 330 334 1c1
32f 336 :3 0 1c4
318 338 :2 0 33a
1c7 33b 315 33a
0 33c 1c9 0
33d 1cb 340 :3 0
340 0 340 33f
33d 33e :6 0 342
6 :3 0 1ce 344
1d0 343 342 :2 0
345 1d2 :2 0 347
0 347 346 2fd
345 :6 0 52f 1
:3 0 c :3 0 47
:3 0 349 34a 0
c :3 0 5d :2 0
71 :3 0 34c 34e
0 1d6 34d 350
:3 0 351 :2 0 19
:3 0 72 :3 0 36
:3 0 73 :3 0 10
:3 0 1d9 356 358
17 :2 0 1db 355
35b 2d :2 0 2b
:2 0 1de 35d 35f
:3 0 360 :2 0 74
:2 0 f :2 0 1e1
362 364 :3 0 1e4
354 366 353 367
0 4de 19 :3 0
75 :2 0 2b :2 0
1e8 36a 36c :3 0
15 :3 0 2b :2 0
36e 36f 0 410
76 :3 0 36 :3 0
15 :3 0 17 :2 0
1eb 372 375 19
:3 0 77 :2 0 78
:3 0 1f0 378 37a
:3 0 37b 40f 12
:3 0 79 :3 0 7a
:3 0 37e 37f 0
f :2 0 f :2 0
36 :3 0 15 :3 0
17 :2 0 1f3 383
386 7b :2 0 f
:2 0 1f6 388 38a
:3 0 2d :2 0 2b
:2 0 1f9 38c 38e
:3 0 10 :3 0 1fc
380 391 37d 392
0 40d 7c :3 0
e :3 0 58 :3 0
7d :3 0 7e :3 0
7f :3 0 80 :3 0
37 :3 0 15 :3 0
57 :3 0 58 :3 0
12 :4 0 81 1
:8 0 3b6 6d :4 0
3a1 :3 0 3f :3 0
5d :2 0 203 3a4
3a5 :3 0 c :3 0
47 :3 0 3a7 3a8
0 17 :2 0 3a9
3aa 0 3ac 206
3b3 c :3 0 47
:3 0 3ad 3ae 0
6e :2 0 3af 3b0
0 3b2 208 3b4
3a6 3ac 0 3b5
0 3b2 0 3b5
20a 0 3b6 20d
400 49 :3 0 c
:3 0 47 :3 0 3b9
3ba 0 48 :3 0
3bb 3bc 0 3f6
1c :3 0 1d :3 0
3be 3bf 0 1c
:3 0 2a :3 0 3c1
3c2 0 4a :2 0
2 :4 0 82 :2 0
2d :2 0 2b :2 0
210 3c7 3c9 :3 0
213 3c3 3cb 3c0
3cd 3cc :2 0 1f
:3 0 2e :3 0 3cf
3d0 0 21 :4 0
83 :4 0 24 :2 0
25 :3 0 217 3d4
3d6 :3 0 24 :2 0
34 :4 0 21a 3d8
3da :3 0 24 :2 0
4d :4 0 21d 3dc
3de :3 0 24 :2 0
48 :3 0 220 3e0
3e2 :3 0 24 :2 0
4e :4 0 223 3e4
3e6 :3 0 24 :2 0
40 :3 0 4f :3 0
2b :2 0 50 :2 0
226 3e9 3ed 22a
3e8 3ef :3 0 22d
3d1 3f1 :2 0 3f3
230 3f4 3ce 3f3
0 3f5 232 0
3f6 234 3f9 :3 0
3f9 0 3f9 3f8
3f6 3f7 :6 0 3fb
9 :3 0 237 3fd
239 3fc 3fb :2 0
3fe 23b :2 0 400
0 400 3ff 3b6
3fe :6 0 40d 8
:3 0 15 :3 0 36
:3 0 15 :3 0 17
:2 0 23d 403 406
2d :2 0 2b :2 0
240 408 40a :3 0
402 40b 0 40d
243 40f 78 :3 0
37c 40d :4 0 410
247 411 36d 410
0 412 24a 0
4de 6 :3 0 84
:2 0 24c 414 415
:3 0 416 :2 0 10
:3 0 6 :3 0 418
419 0 4db 1a
:3 0 72 :3 0 36
:3 0 73 :3 0 10
:3 0 24e 41e 420
17 :2 0 250 41d
423 2d :2 0 2b
:2 0 253 425 427
:3 0 428 :2 0 74
:2 0 f :2 0 256
42a 42c :3 0 259
41c 42e 41b 42f
0 4db 1a :3 0
75 :2 0 17 :2 0
25d 432 434 :3 0
15 :3 0 17 :2 0
436 437 0 4d8
76 :3 0 36 :3 0
15 :3 0 17 :2 0
260 43a 43d 1a
:3 0 77 :2 0 78
:3 0 265 440 442
:3 0 443 4d7 12
:3 0 79 :3 0 7a
:3 0 446 447 0
f :2 0 f :2 0
36 :3 0 15 :3 0
17 :2 0 268 44b
44e 7b :2 0 f
:2 0 26b 450 452
:3 0 2d :2 0 2b
:2 0 26e 454 456
:3 0 10 :3 0 271
448 459 445 45a
0 4d5 85 :3 0
e :3 0 12 :3 0
7d :3 0 7f :3 0
7e :3 0 80 :3 0
37 :3 0 15 :3 0
57 :3 0 58 :3 0
12 :4 0 86 1
:8 0 47e 6d :4 0
469 :3 0 3f :3 0
5d :2 0 278 46c
46d :3 0 c :3 0
47 :3 0 46f 470
0 17 :2 0 471
472 0 474 27b
47b c :3 0 47
:3 0 475 476 0
6e :2 0 477 478
0 47a 27d 47c
46e 474 0 47d
0 47a 0 47d
27f 0 47e 282
4c8 49 :3 0 c
:3 0 47 :3 0 481
482 0 48 :3 0
483 484 0 4be
1c :3 0 1d :3 0
486 487 0 1c
:3 0 2a :3 0 489
48a 0 4a :2 0
2 :4 0 87 :2 0
2d :2 0 2b :2 0
285 48f 491 :3 0
288 48b 493 488
495 494 :2 0 1f
:3 0 2e :3 0 497
498 0 21 :4 0
88 :4 0 24 :2 0
25 :3 0 28c 49c
49e :3 0 24 :2 0
34 :4 0 28f 4a0
4a2 :3 0 24 :2 0
4d :4 0 292 4a4
4a6 :3 0 24 :2 0
48 :3 0 295 4a8
4aa :3 0 24 :2 0
4e :4 0 298 4ac
4ae :3 0 24 :2 0
40 :3 0 4f :3 0
2b :2 0 50 :2 0
29b 4b1 4b5 29f
4b0 4b7 :3 0 2a2
499 4b9 :2 0 4bb
2a5 4bc 496 4bb
0 4bd 2a7 0
4be 2a9 4c1 :3 0
4c1 0 4c1 4c0
4be 4bf :6 0 4c3
c :3 0 2ac 4c5
2ae 4c4 4c3 :2 0
4c6 2b0 :2 0 4c8
0 4c8 4c7 47e
4c6 :6 0 4d5 b
:3 0 15 :3 0 36
:3 0 15 :3 0 17
:2 0 2b2 4cb 4ce
2d :2 0 2b :2 0
2b5 4d0 4d2 :3 0
4ca 4d3 0 4d5
2b8 4d7 78 :3 0
444 4d5 :4 0 4d8
2bc 4d9 435 4d8
0 4da 2bf 0
4db 2c1 4dc 417
4db 0 4dd 2c5
0 4de 2c7 4df
352 4de 0 4e0
2cb 0 52f 1c
:3 0 1d :3 0 4e1
4e2 0 1c :3 0
2a :3 0 4e4 4e5
0 89 :2 0 2
:4 0 8a :2 0 2d
:2 0 2b :2 0 2cd
4ea 4ec :3 0 2d0
4e6 4ee 4e3 4f0
4ef :2 0 1f :3 0
2e :3 0 4f2 4f3
0 21 :4 0 8b
:4 0 24 :2 0 25
:3 0 2d4 4f7 4f9
:3 0 24 :2 0 34
:4 0 2d7 4fb 4fd
:3 0 24 :2 0 35
:4 0 2da 4ff 501
:3 0 24 :2 0 36
:3 0 37 :3 0 c
:3 0 47 :3 0 506
507 0 2dd 505
509 3a :4 0 2df
504 50c 2e2 503
50e :3 0 24 :2 0
62 :4 0 2e5 510
512 :3 0 24 :2 0
27 :4 0 2e8 514
516 :3 0 24 :2 0
e :3 0 2eb 518
51a :3 0 24 :2 0
27 :4 0 2ee 51c
51e :3 0 2f1 4f4
520 :2 0 522 2f4
523 4f1 522 0
524 2f6 0 52f
3d :3 0 8c :3 0
525 526 0 c
:3 0 47 :3 0 528
529 0 e :3 0
3f :3 0 2f8 527
52d :2 0 52f 2fc
5d0 c :3 0 8d
:2 0 4 530 531
0 1c :3 0 1d
:3 0 533 534 0
1c :3 0 2a :3 0
536 537 0 4a
:2 0 2 :4 0 8e
:2 0 2d :2 0 2b
:2 0 30a 53c 53e
:3 0 30d 538 540
535 542 541 :2 0
1f :3 0 2e :3 0
544 545 0 21
:4 0 8f :4 0 24
:2 0 25 :3 0 311
549 54b :3 0 314
546 54d :2 0 566
1f :3 0 2e :3 0
54f 550 0 21
:4 0 90 :4 0 24
:2 0 c :3 0 91
:3 0 555 556 0
317 554 558 :3 0
24 :2 0 62 :4 0
31a 55a 55c :3 0
24 :2 0 c :3 0
92 :3 0 55f 560
0 31d 55e 562
:3 0 320 551 564
:2 0 566 323 567
543 566 0 568
326 0 578 93
:3 0 1b :3 0 c
:3 0 91 :3 0 94
:3 0 c :3 0 92
:3 0 95 :3 0 96
:4 0 97 1 :a 0
574 :2 0 578 56a
572 :2 0 b :3 0
1b :3 0 576 :2 0
578 328 57a 32c
579 578 :2 0 5ce
49 :3 0 c :3 0
47 :3 0 57d 57e
0 48 :3 0 57f
580 0 5c6 1c
:3 0 1d :3 0 582
583 0 1c :3 0
2a :3 0 585 586
0 4a :2 0 2
:4 0 98 :2 0 2d
:2 0 2b :2 0 32e
58b 58d :3 0 331
587 58f 584 591
590 :2 0 1f :3 0
2e :3 0 593 594
0 21 :4 0 99
:4 0 24 :2 0 25
:3 0 335 598 59a
:3 0 338 595 59c
:2 0 5b6 1f :3 0
2e :3 0 59e 59f
0 21 :4 0 4d
:4 0 24 :2 0 48
:3 0 33b 5a3 5a5
:3 0 24 :2 0 4e
:4 0 33e 5a7 5a9
:3 0 24 :2 0 40
:3 0 4f :3 0 2b
:2 0 50 :2 0 341
5ac 5b0 345 5ab
5b2 :3 0 348 5a0
5b4 :2 0 5b6 34b
5b7 592 5b6 0
5b8 34e 0 5c6
93 :3 0 1b :3 0
94 :3 0 c :3 0
92 :3 0 95 :3 0
96 :4 0 9a 1
:a 0 5c2 :2 0 5c6
5ba 5c0 :2 0 b
:3 0 1b :3 0 5c4
:2 0 5c6 350 5c9
:3 0 5c9 0 5c9
5c8 5c6 5c7 :6 0
5cb 1 :3 0 355
5cd 357 5cc 5cb
:2 0 5ce 359 :2 0
5d0 35c 5d0 5cf
52f 5ce :6 0 5d1
:2 0 2 24 5d0
5d4 :3 0 5d3 5d1
5d5 :8 0 
366
4
:3 0 1 3 1
7 1 b 1
f 1 13 1
17 1 1b 7
6 a e 12
16 1a 1e 1
28 1 26 1
2f 1 2d 1
36 1 34 1
3d 1 3b 1
42 1 48 1
4e 1 53 1
58 1 65 1
71 2 74 76
2 79 7b 2
7d 7f 2 81
83 2 85 87
2 89 8b 2
8d 8f 2 91
93 2 95 97
2 99 9b 2
9d 9f 2 a1
a3 2 a5 a7
2 a9 ab 2
ad af 2 b1
b3 2 b5 b7
2 b9 bb 2
bd bf 2 c1
c3 2 c5 c7
2 c9 cb 2
cd cf 2 d1
d3 2 d5 d7
2 d9 db 2
dd df 2 e1
e3 2 e5 e7
4 6d 73 78
e9 1 eb 1
ed 2 f7 f9
3 f5 f6 fb
2 104 106 2
103 108 1 10a
1 10c 1 10e
1 114 2 124
126 3 122 123
128 2 131 133
2 135 137 2
139 13b 1 143
2 145 146 2
13d 148 2 130
14a 1 14c 1
14e 2 158 15a
3 156 157 15c
2 165 167 2
164 169 1 16b
1 16d 2 174
175 3 14f 16e
177 1 179 3
181 182 183 3
185 186 187 2
194 199 2 1aa
1ac 3 1a8 1a9
1ae 2 1b7 1b9
2 1bb 1bd 2
1bf 1c1 2 1c3
1c5 2 1c7 1c9
3 1ce 1cf 1d0
2 1cb 1d2 2
1b6 1d4 1 1d6
1 1d8 2 1a1
1d9 1 1dd 1
19c 1 1e1 2
205 20a 2 21b
21d 3 219 21a
21f 2 228 22a
2 22c 22e 2
230 232 2 234
236 2 238 23a
3 23f 240 241
2 23c 243 2
227 245 1 247
1 249 2 212
24a 1 24e 1
20d 1 252 1
25d 2 259 25d
2 269 26b 3
267 268 26d 2
276 278 2 27a
27c 2 27e 280
1 288 2 28a
28b 2 282 28d
2 28f 291 2
293 295 2 297
299 2 29b 29d
2 275 29f 1
2a1 1 2a3 2
2ad 2af 3 2ab
2ac 2b1 2 2ba
2bc 2 2b9 2be
1 2c0 1 2c2
3 2c9 2ca 2cb
3 2a4 2c3 2cd
1 2cf 1 2ea
2 2e9 2ea 1
2f2 1 2f8 2
2fa 2fb 2 2e7
2fc 2 30d 30f
3 30b 30c 311
2 31a 31c 2
31e 320 2 322
324 2 326 328
2 32a 32c 3
331 332 333 2
32e 335 2 319
337 1 339 1
33b 2 304 33c
1 340 1 2ff
1 344 1 34f
2 34b 34f 1
357 2 359 35a
2 35c 35e 2
361 363 1 365
1 36b 2 369
36b 2 373 374
1 377 2 376
377 2 384 385
2 387 389 2
38b 38d 4 381
382 38f 390 1
3a3 2 3a2 3a3
1 3ab 1 3b1
2 3b3 3b4 2
3a0 3b5 2 3c6
3c8 3 3c4 3c5
3ca 2 3d3 3d5
2 3d7 3d9 2
3db 3dd 2 3df
3e1 2 3e3 3e5
3 3ea 3eb 3ec
2 3e7 3ee 2
3d2 3f0 1 3f2
1 3f4 2 3bd
3f5 1 3f9 1
3b8 1 3fd 2
404 405 2 407
409 3 393 400
40c 2 370 40f
1 411 1 413
1 41f 2 421
422 2 424 426
2 429 42b 1
42d 1 433 2
431 433 2 43b
43c 1 43f 2
43e 43f 2 44c
44d 2 44f 451
2 453 455 4
449 44a 457 458
1 46b 2 46a
46b 1 473 1
479 2 47b 47c
2 468 47d 2
48e 490 3 48c
48d 492 2 49b
49d 2 49f 4a1
2 4a3 4a5 2
4a7 4a9 2 4ab
4ad 3 4b2 4b3
4b4 2 4af 4b6
2 49a 4b8 1
4ba 1 4bc 2
485 4bd 1 4c1
1 480 1 4c5
2 4cc 4cd 2
4cf 4d1 3 45b
4c8 4d4 2 438
4d7 1 4d9 3
41a 430 4da 1
4dc 3 368 412
4dd 1 4df 2
4e9 4eb 3 4e7
4e8 4ed 2 4f6
4f8 2 4fa 4fc
2 4fe 500 1
508 2 50a 50b
2 502 50d 2
50f 511 2 513
515 2 517 519
2 51b 51d 2
4f5 51f 1 521
1 523 3 52a
52b 52c d ee
10d 17a 17d 18a
1e4 255 2d0 2d5
347 4e0 524 52e
2 53b 53d 3
539 53a 53f 2
548 54a 2 547
54c 2 553 557
2 559 55b 2
55d 561 2 552
563 2 54e 565
1 567 3 568
573 577 1 532
2 58a 58c 3
588 589 58e 2
597 599 2 596
59b 2 5a2 5a4
2 5a6 5a8 3
5ad 5ae 5af 2
5aa 5b1 2 5a1
5b3 2 59d 5b5
1 5b7 4 581
5b8 5c1 5c5 1
5c9 1 57c 2
57a 5cd 9 2b
32 39 40 46
4c 51 56 5d

1
4
0 
5d4
0
1
14
e
11
0 1 2 1 4 1 6 1
8 9 1 b c 1 0 0
0 0 0 0 
1b 1 0
b 1 0
34 1 0
42 1 0
4e 1 0
17 1 0
48 1 0
2d 1 0
13 1 0
f 1 0
26 1 0
3 1 0
53 1 0
2 0 1
7 1 0
3b 1 0
58 1 0
0

/
SHOW ERRORS FUNCTION SP_I_PROFILE;
ALTER FUNCTION SP_I_PROFILE COMPILE DEBUG;
/*######################################################################################*/
/* assign a profile to a task or project, used tables: RESOURCE_ASSIGNMENTS, PROFILES   */
/****************************************************************************************/
/*  RES_ID is profile_id, role_id is role_id in TMT_COMPETENCIES    */
/****************************************************************************************/
/*
#Stored Procedure  :SP_A_TSKPROF
#Short Description :
#Description       :
#Table Name        :
#Parameters        :
#Returns           :
#Errors            :
*/
Prompt == FUNCTION SP_A_TSKPROF ==
CREATE OR REPLACE FUNCTION SP_A_TSKPROF wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
d5
2 :e:
1FUNCTION:
1SP_A_TSKPROF:
1TASK_ID001:
1VARCHAR2:
1RES_ID001:
1ROLE_ID001:
1REC_USER001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_UNIQUEID:
132:
1H_PROJECT_ID:
1H_RES_ID:
1H_AND_ROLES:
18000:
1H_ROLE_ID:
1H_REC_STATUS:
11:
1H_FULL_NAME:
1255:
1H_TYPE:
1PLS_INTEGER:
10:
1H_CRI:
1H_BITFLAG:
1H_NUMBER:
1H_TEMP_PARTICIPANT:
1H_TEMP_SECURITY_ID:
1H_TEMP_BITFLAG:
1H_TEMP_RES_TYPE:
1H_TEMP_SC_STATE:
1H_TABLE_TYPE:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_A_TSKPROF(:
1':
1, :
1);:
1CHECK_TRACE:
137:
1+:
1FPUT:
1               ENTER:: SP_A_TSKPROF(38) :: cplan.sql(5580) :: :
1IS NULL:
18:
144:
1      RETURN_INVALID:: SP_A_TSKPROF(45) :: cplan.sql(5587) :: :
1 :
1STATE:: :
1COALESCE:
1TO_CHAR:
1PMO_CNST:
1INVALID_PARAMS:
1NULL:
147:
1                EXIT:: SP_A_TSKPROF(48) :: cplan.sql(5590) :: :
1PMODEFINES:
1PMO_RETURN_INVALID_SP:
1TRUE:
1PROJECT_ID:
1TYPE_ID:
1TMT_WBS:
1ELEMENT_ID:
1SELECT PROJECT_ID, TYPE_ID INTO h_project_id, h_type FROM TMT_WBS WHERE ELEME+
1NT_ID = task_id001:
1SC_STATE:
1SQLCODE:
1OTHERS:
116:
160:
1           EXCEPTION:: SP_A_TSKPROF(61) :: cplan.sql(5603) :: :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1=:
1SC_SQL_NO_DATA:
1TMT_CRI:
1SELECT PROJECT_ID, TYPE_ID INTO h_project_id, h_type FROM TMT_CRI WHERE ELEME+
1NT_ID = task_id001:
174:
1           EXCEPTION:: SP_A_TSKPROF(75) :: cplan.sql(5617) :: :
181:
1        RETURN_ERROR:: SP_A_TSKPROF(82) :: cplan.sql(5624) :: :
1RECORD_NOT_FOUND:
1 ID:: :
184:
1                EXIT:: SP_A_TSKPROF(85) :: cplan.sql(5627) :: :
1PMO_RETURN_ERROR_SP:
1SC_TABLE_CRI:
1SC_TABLE_WBS:
1PROFILE_ID:
1PROFILE_NAME:
1REC_STATUS:
1PROFILES:
1SELECT PROFILE_ID, PROFILE_NAME, REC_STATUS INTO h_res_id, h_full_name, h_rec+
1_status:n      FROM PROFILES WHERE PROFILE_ID = h_res_id:
1107:
1           EXCEPTION:: SP_A_TSKPROF(108) :: cplan.sql(5650) :: :
1MAX:
1PROF_NUMBER:
1ROLE_ID:
1SELECT COALESCE(MAX(PROF_NUMBER),0)+1 INTO h_number:n         FROM PROFILES:n+
1         WHERE PROJECT_ID=h_project_id AND ROLE_ID=h_role_id:
1127:
1           EXCEPTION:: SP_A_TSKPROF(128) :: cplan.sql(5670) :: :
1PMO_ORASTD:
1STRINGCONCAT:
1RTRIM:
1TCP:
1ELEMENT_NAME:
1TC:
1TMT_COMPETENCIES:
1PARENT_ID:
1SELECT PMO_ORASTD.StringConcat(PMO_ORASTD.StringConcat(PMO_ORASTD.StringConca+
1t(PMO_ORASTD.StringConcat(PMO_ORASTD.StringConcat(RTRIM(TCP.ELEMENT_NAME), ',+
1 '), RTRIM(TC.ELEMENT_NAME)), '('), RTRIM(TO_CHAR(h_number))), ')') INTO h_fu+
1ll_name:n         FROM TMT_COMPETENCIES TC, TMT_COMPETENCIES TCP:n         WH+
1ERE TC.ELEMENT_ID = h_role_id AND TCP.ELEMENT_ID = TC.PARENT_ID:
1142:
1           EXCEPTION:: SP_A_TSKPROF(143) :: cplan.sql(5685) :: :
1149:
1        RETURN_ERROR:: SP_A_TSKPROF(150) :: cplan.sql(5692) :: :
1152:
1                EXIT:: SP_A_TSKPROF(153) :: cplan.sql(5695) :: :
1INSERT INTO PROFILES(PROFILE_ID,PROJECT_ID,ROLE_ID,PROF_NUMBER, PROFILE_NAME)+
1:n         VALUES(h_res_id, h_project_id, h_role_id, h_number, h_full_name):
1FOUND:
1100:
1170:
1           EXCEPTION:: SP_A_TSKPROF(171) :: cplan.sql(5713) :: :
1!=:
1SC_SQL_SUCCESS:
1177:
1        RETURN_ERROR:: SP_A_TSKPROF(178) :: cplan.sql(5720) :: :
1180:
1                EXIT:: SP_A_TSKPROF(181) :: cplan.sql(5723) :: :
1ELSIF:
1ISNOTPROJECTTYPE:
1A:
1RES_ASSIGNMENT_ID:
1RESOURCE_ASSIGNMENTS:
1RESOURCE_ID:
1RESOURCE_TYPE:
1SELECT a.RES_ASSIGNMENT_ID INTO h_uniqueID :n            FROM RESOURCE_ASSIGN+
1MENTS a:n            WHERE a.ELEMENT_ID = task_id001  :n            AND a.RES+
1OURCE_ID = res_id001:n            AND a.RESOURCE_TYPE = '1':
1198:
1           EXCEPTION:: SP_A_TSKPROF(199) :: cplan.sql(5741) :: :
1205:
1        RETURN_ERROR:: SP_A_TSKPROF(206) :: cplan.sql(5748) :: :
1RECORD_ALREADY_ASSIGNED:
1208:
1                EXIT:: SP_A_TSKPROF(209) :: cplan.sql(5751) :: :
1D:
1UPDATE PROFILES SET REC_STATUS = 'U' WHERE PROFILE_ID = h_res_id:
1227:
1           EXCEPTION:: SP_A_TSKPROF(228) :: cplan.sql(5770) :: :
1234:
1        RETURN_ERROR:: SP_A_TSKPROF(235) :: cplan.sql(5777) :: :
1237:
1                EXIT:: SP_A_TSKPROF(238) :: cplan.sql(5780) :: :
1SELECT RES_ASSIGNMENT_ID INTO h_uniqueID :n      FROM RESOURCE_ASSIGNMENTS:n +
1     WHERE ELEMENT_ID = task_id001 :n      AND RESOURCE_ID = h_res_id :n     +
1 AND RESOURCE_TYPE = '1':
1           EXCEPTION:: SP_A_TSKPROF(256) :: cplan.sql(5798) :: :
1ASSIGN_NAMES:
1INSTR:
1LENGTH:
1UPDATE TMT_WBS SET ASSIGN_NAMES =:n            CASE:n            WHEN InStr( +
1ASSIGN_NAMES, h_full_name || ';') > 0 THEN ASSIGN_NAMES:n            ELSE:n  +
1          CASE:n            WHEN LENGTH(h_full_name) + LENGTH(ASSIGN_NAMES) >+
1 2040 THEN ASSIGN_NAMES:n            ELSE ASSIGN_NAMES || h_full_name || ';'+
1:n            END:n            END:n            WHERE ELEMENT_ID = task_id001:
1284:
1           EXCEPTION:: SP_A_TSKPROF(285) :: cplan.sql(5827) :: :
1UPDATE TMT_CRI SET ASSIGN_NAMES =:n            CASE:n            WHEN InStr( +
1ASSIGN_NAMES, h_full_name || ';') > 0 THEN ASSIGN_NAMES:n            ELSE:n  +
1          CASE:n            WHEN LENGTH(h_full_name) + LENGTH(ASSIGN_NAMES) >+
1 2040 THEN ASSIGN_NAMES:n            ELSE ASSIGN_NAMES || h_full_name || ';'+
1:n            END:n            END:n            WHERE ELEMENT_ID = task_id001:
1310:
1           EXCEPTION:: SP_A_TSKPROF(311) :: cplan.sql(5853) :: :
1SYS_GUID:
1GETSECURITYID:
1SC_TEAMMEMBER_GROUP:
1ISPROJECTTYPE:
1SC_AFFECTED:
1SC_TEAMMEMBER:
1FC_BEFORE_I_RES_ASSIGN:
1ELEMENT_TYPE:
1PARTICIPANT:
1SECURITY_ID:
1REC_USER:
1REC_DATETIME:
1TABLE_TYPE:
1INSERT INTO RESOURCE_ASSIGNMENTS(RES_ASSIGNMENT_ID, PROJECT_ID, ELEMENT_ID, E+
1LEMENT_TYPE,:n         RESOURCE_TYPE, RESOURCE_ID, PARTICIPANT, SECURITY_ID, +
1REC_USER, REC_DATETIME,TABLE_TYPE) :n         VALUES (h_uniqueID, h_project_i+
1d,task_id001, h_type, :n         '1', h_res_id, h_temp_participant, h_temp_se+
1curity_id, rec_user001, SYSTIMESTAMP,h_table_type):
1348:
1           EXCEPTION:: SP_A_TSKPROF(349) :: cplan.sql(5891) :: :
1PMO_STPU:
1BIT_OR:
1UPDATE RESOURCE_ASSIGNMENTS SET PARTICIPANT = PMO_STPU.BIT_OR(PARTICIPANT, PM+
1O_CNST.SC_TEAMMEMBER):n         WHERE RES_ASSIGNMENT_ID = h_uniqueID:
1367:
1           EXCEPTION:: SP_A_TSKPROF(368) :: cplan.sql(5910) :: :
1FC_AFTER_U_RES_ASSIGN:
14:
1376:
1       RETURN_STATUS:: SP_A_TSKPROF(377) :: cplan.sql(5919) :: :
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
1383:
1           EXCEPTION:: SP_A_TSKPROF(384) :: cplan.sql(5926) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1ID:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
1395:
1           EXCEPTION:: SP_A_TSKPROF(396) :: cplan.sql(5938) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
add
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d b4 :3 a0 6b 2c 6a
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
1c 51 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
:2 a0 6b 1c 81 b0 :2 a0 6b :2 a0
6b 6e a5 b a 10 :2 a0 6b
6e :2 a0 6b 6e a5 b 6e 7e
a0 b4 2e 6e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c a0 7e b4 2e
:2 5a a0 7e b4 2e :2 5a 52 10
a0 7e b4 2e :2 5a 52 10 :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b a0 a5 57 b7 19
3c :7 a0 12a :2 a0 6b a0 d b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 6b a0 7e
a0 6b b4 2e 5a :7 a0 12a :2 a0
6b a0 d b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 6b a0 7e a0 6b b4 2e
5a :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b :2 a0 a5 57
b7 19 3c a0 51 d :3 a0 6b
d b7 a0 51 d :3 a0 6b d
b7 :2 19 3c :2 a0 d :9 a0 12a :2 a0
6b a0 d b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 6b a0 7e a0 6b b4 2e
5a :2 a0 d :3 a0 :2 51 a5 b d
:9 a0 12a :2 a0 6b a0 d b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :1f a0 12a :2 a0 6b a0
d b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
a0 7e a0 6b b4 2e 5a :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b :2 a0 a5 57 b7 19
3c :b a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 6b a0 7e a0 6b
b4 2e 5a :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b :2 a0
a5 57 b7 19 3c a0 b7 :2 a0
6b a0 7e a0 6b b4 2e 5a
:3 a0 51 a5 b a5 b 7e 51
b4 2e :d a0 12a :2 a0 6b a0 d
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 6b a0
7e a0 6b b4 2e 5a :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b :2 a0 a5 57 b7 19 3c
b7 19 3c :2 a0 :2 51 a5 b 7e
6e b4 2e :4 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 19 3c b7
19 :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b :2 a0 a5 57
b7 :2 19 3c a0 51 d :8 a0 12a
:2 a0 6b a0 d b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6b a0 7e a0 6b b4
2e 5a :2 a0 51 a5 b 7e 51
b4 2e :f a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f a0 b7 :2 a0 51 a5
b 7e 51 b4 2e :f a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 :2 19
3c :2 a0 b4 2e d :4 a0 51 a5
b :2 a0 51 a5 b :2 a0 6b a0
a5 b d :3 a0 51 a5 b a5
b 7e 51 b4 2e :3 a0 6b d
b7 :3 a0 6b d b7 :2 19 3c a0
6e d a0 51 d :9 a0 a5 b
d :16 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f a0 b7 :2 a0 6b a0 7e
a0 6b b4 2e 5a :9 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :3 a0 a5
b d b7 :2 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b :2 a0 a5
57 b7 :2 a0 6b :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 :2 a0 6b :2 6e 7e
:2 a0 6b b4 2e 7e 6e b4 2e
7e :2 a0 6b b4 2e a5 57 b7
19 3c :9 a0 12a e9 dd :2 a0 65
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
:7 a0 12a e9 dd :2 a0 65 b7 a4
b1 11 4f b7 a6 9 a4 b1
11 68 4f 1d 17 b5 
add
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 5e
5a 30 66 59 6b 6f 73 56
77 7b 98 83 87 8a 8b 93
82 b5 a3 7f a7 a8 b0 a2
d2 c0 9f c4 c5 cd bf ef
dd bc e1 e2 ea dc 10c fa
d9 fe ff 107 f9 129 117 f6
11b 11c 124 116 146 134 113 138
139 141 133 162 151 155 130 15d
150 17e 16d 171 14d 179 16c 19a
189 18d 169 195 188 1b6 1a5 1a9
185 1b1 1a4 1d2 1c1 1c5 1a1 1cd
1c0 1ef 1dd 1bd 1e1 1e2 1ea 1dc
20b 1fa 1fe 1d9 206 1f9 228 216
1f6 21a 21b 223 215 244 233 237
212 23f 232 260 24f 253 22f 25b
24e 280 26b 26f 24b 273 27b 26a
287 28b 267 28f 293 297 29a 29f
2a0 1 2a2 2a7 2ab 2af 2b2 2b7
2bb 2bf 2c2 2c7 2c8 2ca 2cf 2d2
2d6 2d7 2dc 2e1 2e4 2e9 2ea 2ef
2f2 2f6 2f7 2fc 2ff 304 305 30a
30d 312 313 318 31b 320 321 326
329 32d 32e 333 336 33b 33c 341
344 349 34a 34f 352 357 358 35d
360 364 365 36a 36d 372 373 378
37b 380 381 386 389 38e 38f 394
397 39b 39c 3a1 3a4 3a9 3aa 3af
3b2 3b7 3b8 3bd 3be 3c3 3c5 3c9
3cc 3d0 3d4 3d7 3db 3df 3e2 3e5
3ea 3ed 3f0 3f3 3f4 3f9 3fa 1
3fc 401 405 409 40c 411 416 419
41d 41e 423 424 429 42b 42f 432
436 439 43a 43f 442 445 449 44c
44d 452 455 1 458 45d 461 464
465 46a 46d 1 470 475 479 47d
480 484 488 48b 48e 493 496 499
49c 49d 4a2 4a3 1 4a5 4aa 4ae
4b2 4b5 4ba 4bf 4c2 4c6 4c7 4cc
4cf 4d4 4d5 4da 4dd 4e2 4e3 4e8
4eb 4ef 4f3 4f7 4fb 4fe 4ff 501
506 507 509 50a 50f 510 515 517
51b 51e 522 526 529 52d 531 534
537 53c 53f 542 545 546 54b 54c
1 54e 553 557 55b 55e 563 568
56b 56f 570 575 576 57b 57d 581
584 588 58c 58f 593 597 59a 59e
59f 5a4 5a6 5aa 5ad 5b1 5b5 5b9
5bd 5c1 5c5 5c9 5d5 5d9 5dd 5e0
5e4 5e8 5ea 1 5ee 5f2 5f6 5f9
5fd 601 605 609 60c 610 614 617
61a 61f 622 625 628 629 62e 62f
1 631 636 63a 63e 641 646 64b
64e 652 653 658 65b 660 661 666
669 66e 66f 674 677 67b 67c 681
684 689 68a 68f 692 696 69a 69d
6a0 6a1 6a3 6a4 6a9 6aa 6af 6b1
6b5 6b8 6ba 6be 6c0 6cc 6ce 6d0
6d1 6d6 6da 6dc 6e8 6ea 6ee 6f2
6f5 6f9 6fc 700 703 704 709 70c
710 714 718 71c 720 724 728 734
738 73c 73f 743 747 749 1 74d
751 755 758 75c 760 764 768 76b
76f 773 776 779 77e 781 784 787
788 78d 78e 1 790 795 799 79d
7a0 7a5 7aa 7ad 7b1 7b2 7b7 7ba
7bf 7c0 7c5 7c8 7cd 7ce 7d3 7d6
7da 7db 7e0 7e3 7e8 7e9 7ee 7f1
7f5 7f9 7fc 7ff 800 802 803 808
809 80e 810 814 817 819 81d 81f
82b 82d 82f 830 835 839 83b 847
849 84d 851 854 858 85b 85f 862
863 868 86b 86f 873 876 87a 87e
881 884 889 88c 88f 892 893 898
899 1 89b 8a0 8a4 8a8 8ab 8b0
8b5 8b8 8bc 8bd 8c2 8c5 8ca 8cb
8d0 8d3 8d8 8d9 8de 8e1 8e5 8e9
8ed 8f1 8f4 8f5 8f7 8fc 8fd 8ff
900 905 908 90d 90e 913 916 91b
91c 921 924 928 929 92e 931 936
937 93c 93d 942 944 948 94b 94f
953 956 95a 95e 961 964 969 96c
96f 972 973 978 979 1 97b 980
984 988 98b 990 995 998 99c 99d
9a2 9a3 9a8 9aa 9ae 9b1 9b5 9b9
9bc 9c0 9c4 9c7 9cb 9cf 9d0 9d5
9d7 9db 9de 9e2 9e5 9e9 9ed 9f1
9f5 9f8 9fc 9fe a02 a05 a09 a0d
a11 a15 a18 a1c a1e a22 a26 a29
a2d a31 a35 a39 a3d a41 a45 a49
a4d a51 a55 a59 a65 a69 a6d a70
a74 a78 a7a 1 a7e a82 a86 a89
a8d a91 a95 a99 a9c aa0 aa4 aa7
aaa aaf ab2 ab5 ab8 ab9 abe abf
1 ac1 ac6 aca ace ad1 ad6 adb
ade ae2 ae3 ae8 aeb af0 af1 af6
af9 afe aff b04 b07 b0b b0c b11
b14 b19 b1a b1f b22 b26 b2a b2d
b30 b31 b33 b34 b39 b3a b3f b41
b45 b48 b4a b4e b50 b5c b5e b60
b61 b66 b6a b6c b78 b7a b7e b82
b85 b89 b8c b90 b93 b94 b99 b9c
ba0 ba4 ba8 bac bb0 bb4 bb7 bba
bbb bbd bc1 bc5 bc9 bcd bd1 bd5
bd9 bdd be1 be5 bf1 bf5 bf9 bfc
c00 c04 c06 1 c0a c0e c12 c15
c19 c1d c21 c25 c28 c2c c30 c33
c36 c3b c3e c41 c44 c45 c4a c4b
1 c4d c52 c56 c5a c5d c62 c67
c6a c6e c6f c74 c77 c7c c7d c82
c85 c8a c8b c90 c93 c97 c98 c9d
ca0 ca5 ca6 cab cae cb2 cb6 cb9
cbc cbd cbf cc0 cc5 cc6 ccb ccd
cd1 cd4 cd6 cda cdc ce8 cea cec
ced cf2 cf6 cf8 d04 d06 d0a d0e
d12 d16 d1a d1e d22 d26 d2a d2e
d32 d36 d3a d3e d42 d46 d4a d4e
d52 d56 d5a d5e d62 d66 d6a d6e
d72 d76 d7a d7e d82 d8e d92 d96
d99 d9d da1 da3 1 da7 dab daf
db2 db6 dba dbe dc2 dc5 dc9 dcd
dd0 dd3 dd8 ddb dde de1 de2 de7
de8 1 dea def df3 df7 dfa dff
e04 e07 e0b e0c e11 e14 e19 e1a
e1f e22 e27 e28 e2d e30 e34 e35
e3a e3d e42 e43 e48 e4b e4f e53
e56 e59 e5a e5c e5d e62 e63 e68
e6a e6e e71 e73 e77 e79 e85 e87
e89 e8a e8f e93 e95 ea1 ea3 ea7
eab eae eb2 eb5 eb9 ebc ebd ec2
ec5 ec9 ecd ed0 ed4 ed8 edb ede
ee3 ee6 ee9 eec eed ef2 ef3 1
ef5 efa efe f02 f05 f0a f0f f12
f16 f17 f1c f1f f24 f25 f2a f2d
f32 f33 f38 f3b f3f f43 f47 f4b
f4e f4f f51 f56 f57 f59 f5a f5f
f62 f67 f68 f6d f70 f75 f76 f7b
f7e f82 f83 f88 f8b f90 f91 f96
f97 f9c f9e fa2 fa5 fa9 fad fb0
fb4 fb8 fbb fbe fc3 fc6 fc9 fcc
fcd fd2 fd3 1 fd5 fda fde fe2
fe5 fea fef ff2 ff6 ff7 ffc ffd
1002 1004 1008 100b 100f 1013 1016 101a
101e 1021 1025 1029 102a 102f 1031 1035
1038 103c 1040 1044 1048 104c 1050 1054
1058 105c 1060 1064 1070 1074 1079 107d
1080 1081 1086 108a 108e 1091 1094 1098
109a 109e 10a2 10a5 10a8 10ac 10ae 10b2
10b6 10b9 10bb 1 10bf 10c3 10c7 10ca
10ce 10d2 10d6 10da 10dd 10e1 10e5 10e8
10eb 10f0 10f3 10f6 10f9 10fa 10ff 1100
1 1102 1107 110b 110f 1112 1117 111c
111f 1123 1124 1129 112c 1131 1132 1137
113a 113f 1140 1145 1148 114c 114d 1152
1155 115a 115b 1160 1163 1167 116b 116e
1171 1172 1174 1175 117a 117b 1180 1182
1186 1189 118b 118f 1191 119d 119f 11a1
11a2 11a7 11ab 11ad 11b9 11bb 11bf 11c3
11c6 11ca 11cd 11d1 11d4 11d5 11da 11dd
11e1 11e5 11e8 11ec 11f0 11f3 11f6 11fb
11fe 1201 1204 1205 120a 120b 1 120d
1212 1216 121a 121d 1222 1227 122a 122e
122f 1234 1237 123c 123d 1242 1245 124a
124b 1250 1253 1257 125b 125f 1263 1266
1267 1269 126e 126f 1271 1272 1277 127a
127f 1280 1285 1288 128d 128e 1293 1296
129a 129b 12a0 12a3 12a8 12a9 12ae 12af
12b4 12b6 12ba 12bd 12c1 12c5 12c8 12cc
12d0 12d3 12d6 12db 12de 12e1 12e4 12e5
12ea 12eb 1 12ed 12f2 12f6 12fa 12fd
1302 1307 130a 130e 130f 1314 1315 131a
131c 1320 1323 1327 132b 132e 1332 1336
1339 133d 1341 1342 1347 1349 134d 1350
1354 1356 135a 135e 1361 1365 1368 136c
136f 1370 1375 1378 137c 1380 1384 1387
1388 138a 138b 138d 1390 1393 1394 1399
139d 13a1 13a5 13a9 13ad 13b1 13b5 13b9
13bd 13c1 13c5 13c9 13cd 13d9 13dd 13e1
13e4 13e8 13ec 13ee 1 13f2 13f6 13fa
13fd 1401 1405 1409 140d 1410 1414 1418
141b 141e 1423 1426 1429 142c 142d 1432
1433 1 1435 143a 143e 1442 1445 144a
144f 1452 1456 1457 145c 145f 1464 1465
146a 146d 1472 1473 1478 147b 147f 1480
1485 1488 148d 148e 1493 1496 149a 149e
14a1 14a4 14a5 14a7 14a8 14ad 14ae 14b3
14b5 14b9 14bc 14be 14c2 14c4 14d0 14d2
14d4 14d5 14da 14de 14e0 14ec 14ee 14f2
14f6 14f9 14fd 1500 1504 1507 1508 150d
1510 1514 1518 151b 151f 1523 1526 1529
152e 1531 1534 1537 1538 153d 153e 1
1540 1545 1549 154d 1550 1555 155a 155d
1561 1562 1567 156a 156f 1570 1575 1578
157d 157e 1583 1586 158a 158e 1592 1596
1599 159a 159c 15a1 15a2 15a4 15a5 15aa
15ad 15b2 15b3 15b8 15bb 15c0 15c1 15c6
15c9 15cd 15ce 15d3 15d6 15db 15dc 15e1
15e2 15e7 15e9 15ed 15f0 15f4 15f8 15fb
15ff 1603 1606 1609 160e 1611 1614 1617
1618 161d 161e 1 1620 1625 1629 162d
1630 1635 163a 163d 1641 1642 1647 1648
164d 164f 1653 1656 165a 165e 1661 1665
1669 166c 1670 1674 1675 167a 167c 1680
1683 1685 1689 168c 1690 1694 1697 169a
169b 169d 16a0 16a5 16a6 16ab 16af 16b3
16b7 16bb 16c7 16cb 16d0 16d4 16d7 16d8
16dd 16e1 16e5 16e8 16eb 16ef 16f1 16f5
16f9 16fc 16ff 1703 1705 1709 170d 1710
1712 1 1716 171a 171e 1721 1725 1729
172d 1731 1734 1738 173c 173f 1742 1747
174a 174d 1750 1751 1756 1757 1 1759
175e 1762 1766 1769 176e 1773 1776 177a
177b 1780 1783 1788 1789 178e 1791 1796
1797 179c 179f 17a3 17a4 17a9 17ac 17b1
17b2 17b7 17ba 17be 17c2 17c5 17c8 17c9
17cb 17cc 17d1 17d2 17d7 17d9 17dd 17e0
17e2 17e6 17e8 17f4 17f6 17f8 17f9 17fe
1802 1804 1810 1812 1814 1818 181b 181d
1821 1825 1829 182c 1830 1834 1837 183a
183f 1842 1845 1848 1849 184e 184f 1
1851 1856 185a 185e 1861 1866 186b 186e
1872 1873 1878 187b 1880 1881 1886 1889
188e 188f 1894 1897 189b 189f 18a3 18a7
18aa 18ab 18ad 18b2 18b3 18b5 18b6 18bb
18be 18c3 18c4 18c9 18cc 18d1 18d2 18d7
18da 18de 18df 18e4 18e7 18ec 18ed 18f2
18f3 18f8 18fa 18fe 1901 1905 1909 190c
1910 1914 1917 191a 191f 1922 1925 1928
1929 192e 192f 1 1931 1936 193a 193e
1941 1946 194b 194e 1952 1953 1958 1959
195e 1960 1964 1967 196b 196f 1972 1976
197a 197d 1981 1985 1986 198b 198d 1991
1995 1998 199c 199f 19a3 19a7 19ab 19af
19b3 19b7 19bb 19bf 19c3 19cf 19d3 19d7
19da 19de 19e2 19e4 1 19e8 19ec 19f0
19f3 19f7 19fb 19ff 1a03 1a06 1a0a 1a0e
1a11 1a14 1a19 1a1c 1a1f 1a22 1a23 1a28
1a29 1 1a2b 1a30 1a34 1a38 1a3b 1a40
1a45 1a48 1a4c 1a4d 1a52 1a55 1a5a 1a5b
1a60 1a63 1a68 1a69 1a6e 1a71 1a75 1a76
1a7b 1a7e 1a83 1a84 1a89 1a8c 1a90 1a94
1a97 1a9a 1a9b 1a9d 1a9e 1aa3 1aa4 1aa9
1aab 1aaf 1ab2 1ab4 1ab8 1aba 1ac6 1ac8
1aca 1acb 1ad0 1ad4 1ad6 1ae2 1ae4 1ae8
1aec 1aef 1af3 1af6 1afa 1afd 1afe 1b03
1b06 1b0a 1b0e 1b11 1b12 1b14 1b17 1b1a
1b1b 1b20 1b24 1b28 1b2c 1b30 1b34 1b38
1b3c 1b40 1b44 1b48 1b4c 1b50 1b54 1b58
1b5c 1b68 1b6c 1b71 1b75 1b78 1b79 1b7e
1b82 1b86 1b89 1b8c 1b90 1b92 1b96 1b9a
1b9d 1ba0 1ba4 1ba6 1baa 1bae 1bb1 1bb3
1 1bb7 1bbb 1bbf 1bc2 1bc6 1bca 1bce
1bd2 1bd5 1bd9 1bdd 1be0 1be3 1be8 1beb
1bee 1bf1 1bf2 1bf7 1bf8 1 1bfa 1bff
1c03 1c07 1c0a 1c0f 1c14 1c17 1c1b 1c1c
1c21 1c24 1c29 1c2a 1c2f 1c32 1c37 1c38
1c3d 1c40 1c44 1c45 1c4a 1c4d 1c52 1c53
1c58 1c5b 1c5f 1c63 1c66 1c69 1c6a 1c6c
1c6d 1c72 1c73 1c78 1c7a 1c7e 1c81 1c83
1c87 1c89 1c95 1c97 1c99 1c9a 1c9f 1ca3
1ca5 1cb1 1cb3 1cb7 1cb9 1cbd 1cc1 1cc4
1cc5 1cc7 1cca 1ccd 1cce 1cd3 1cd7 1cdb
1cdf 1ce3 1ce7 1ceb 1cef 1cf3 1cf7 1cfb
1cff 1d03 1d07 1d0b 1d0f 1d1b 1d1f 1d24
1d28 1d2b 1d2c 1d31 1d35 1d39 1d3c 1d3f
1d43 1d45 1d49 1d4d 1d50 1d53 1d57 1d59
1d5d 1d61 1d64 1d66 1 1d6a 1d6e 1d72
1d75 1d79 1d7d 1d81 1d85 1d88 1d8c 1d90
1d93 1d96 1d9b 1d9e 1da1 1da4 1da5 1daa
1dab 1 1dad 1db2 1db6 1dba 1dbd 1dc2
1dc7 1dca 1dce 1dcf 1dd4 1dd7 1ddc 1ddd
1de2 1de5 1dea 1deb 1df0 1df3 1df7 1df8
1dfd 1e00 1e05 1e06 1e0b 1e0e 1e12 1e16
1e19 1e1c 1e1d 1e1f 1e20 1e25 1e26 1e2b
1e2d 1e31 1e34 1e36 1e3a 1e3c 1e48 1e4a
1e4c 1e4d 1e52 1e56 1e58 1e64 1e66 1e68
1e6c 1e70 1e73 1e77 1e7b 1e7c 1e81 1e85
1e89 1e8d 1e91 1e95 1e98 1e99 1e9b 1e9f
1ea3 1ea6 1ea7 1ea9 1ead 1eb1 1eb4 1eb8
1eb9 1ebb 1ebf 1ec3 1ec7 1ecb 1ece 1ecf
1ed1 1ed2 1ed4 1ed7 1eda 1edb 1ee0 1ee4
1ee8 1eec 1eef 1ef3 1ef5 1ef9 1efd 1f01
1f04 1f08 1f0a 1f0e 1f12 1f15 1f19 1f1e
1f22 1f26 1f29 1f2d 1f31 1f35 1f39 1f3d
1f41 1f45 1f49 1f4d 1f51 1f52 1f54 1f58
1f5c 1f60 1f64 1f68 1f6c 1f70 1f74 1f78
1f7c 1f80 1f84 1f88 1f8c 1f90 1f94 1f98
1f9c 1fa0 1fa4 1fa8 1fac 1fb0 1fbc 1fc0
1fc5 1fc9 1fcc 1fcd 1fd2 1fd6 1fda 1fdd
1fe0 1fe4 1fe6 1fea 1fee 1ff1 1ff4 1ff8
1ffa 1ffe 2002 2005 2007 1 200b 200f
2013 2016 201a 201e 2022 2026 2029 202d
2031 2034 2037 203c 203f 2042 2045 2046
204b 204c 1 204e 2053 2057 205b 205e
2063 2068 206b 206f 2070 2075 2078 207d
207e 2083 2086 208b 208c 2091 2094 2098
2099 209e 20a1 20a6 20a7 20ac 20af 20b3
20b7 20ba 20bd 20be 20c0 20c1 20c6 20c7
20cc 20ce 20d2 20d5 20d7 20db 20dd 20e9
20eb 20ed 20ee 20f3 20f7 20f9 2105 2107
210b 210d 2111 2115 2118 211c 211f 2123
2126 2127 212c 212f 2133 2137 213b 213f
2143 2147 214b 214f 2153 215f 2163 2168
216c 216f 2170 2175 2179 217d 2180 2183
2187 2189 218d 2191 2194 2197 219b 219d
21a1 21a5 21a8 21aa 1 21ae 21b2 21b6
21b9 21bd 21c1 21c5 21c9 21cc 21d0 21d4
21d7 21da 21df 21e2 21e5 21e8 21e9 21ee
21ef 1 21f1 21f6 21fa 21fe 2201 2206
220b 220e 2212 2213 2218 221b 2220 2221
2226 2229 222e 222f 2234 2237 223b 223c
2241 2244 2249 224a 224f 2252 2256 225a
225d 2260 2261 2263 2264 2269 226a 226f
2271 2275 2278 227a 227e 2280 228c 228e
2290 2291 2296 229a 229c 22a8 22aa 22ae
22b2 22b6 22b7 22b9 22bd 22bf 22c3 22c7
22ca 22ce 22d2 22d5 22d9 22dd 22e0 22e3
22e8 22eb 22ee 22f1 22f2 22f7 22f8 1
22fa 22ff 2303 2307 230a 230f 2314 2317
231b 231c 2321 2324 2329 232a 232f 2332
2337 2338 233d 2340 2344 2348 234c 2350
2353 2354 2356 235b 235c 235e 235f 2364
2367 236c 236d 2372 2375 237a 237b 2380
2383 2387 2388 238d 2390 2395 2396 239b
239c 23a1 23a3 23a7 23aa 23ae 23b2 23b5
23b9 23bd 23c0 23c4 23c8 23c9 23ce 23d0
23d4 23d8 23db 23df 23e3 23e6 23ea 23ee
23f1 23f4 23f9 23fc 23ff 2402 2403 2408
2409 1 240b 2410 2414 2418 241b 2420
2425 2428 242c 242d 2432 2433 2438 243c
2440 2443 2448 244d 2450 2454 2458 245b
245c 2461 2464 2469 246a 246f 2472 2476
247a 247d 247e 2483 2484 2489 248b 248f
2492 2496 249a 249e 24a2 24a6 24aa 24ae
24b2 24b6 24c2 24c7 24cb 24cf 24d3 24d7
24d9 24da 24df 1 24e3 24e7 24eb 24ee
24f2 24f6 24fa 24fe 2501 2505 2509 250c
250f 2514 2517 251a 251d 251e 2523 2524
1 2526 252b 252f 2533 2536 253b 2540
2543 2547 2548 254d 254e 2553 2557 255b
255e 2563 2568 256b 256f 2570 2575 2578
257d 257e 2583 2586 258a 258e 2591 2594
2595 2597 2598 259d 259e 25a3 25a5 25a9
25ac 25b0 25b4 25b8 25bc 25c0 25c4 25c8
25d4 25d9 25dd 25e1 25e5 25e9 25eb 25ef
25f1 25fd 25ff 2601 2602 2607 260b 260d
2619 261d 261f 2620 2629 
add
2
0 1 a 6 11 :3 6 10 :3 6
11 :3 6 12 :2 6 1 3 a 13
a :2 1 4 f 18 17 :2 f :2 4
11 1a 19 :2 11 :2 4 d 16 15
:2 d :2 4 10 19 18 :2 10 :2 4 e
17 16 :2 e :2 4 11 1a 19 :2 11
:2 4 10 19 18 :2 10 :2 4 :2 b 1a
b :2 4 :2 a 19 a :2 4 :2 e 1d
e :2 4 :2 d 1c d :2 4 :2 17 26
17 :2 4 17 20 1f :2 17 :2 4 :2 13
22 13 :2 4 14 1d 1c :2 14 :2 4
:2 14 23 14 :2 4 :2 11 20 11 :2 4
e 17 :3 e 4 7 :2 11 23 :2 2d
3a :2 23 :3 7 :2 d 19 25 :2 2f 43
:2 25 54 5a 5d :2 54 6b 81 8
:2 6b d 10 :2 6b 1b 1e :2 6b b
e :2 6b 13 16 :2 6b 1b 1e :2 6b
28 2b :2 6b b e :2 6b 13 16
:2 6b 1b 1e :2 6b 29 2c :2 6b b
e :2 6b 13 16 :2 6b 1b 1e :2 6b
2a 2d :2 6b 32 35 :2 6b :2 7 4a
:2 4 7 :2 11 23 :2 2d 39 3c 4c
4e 4f :2 4c :2 23 :3 7 :2 d 12 1e
5c 5f :2 1e :2 7 52 :2 4 :4 9 8
7 :4 23 22 21 :2 7 :4 3c 3b 3a
:2 7 a :2 14 26 :2 30 3c 3f 4f
51 52 :2 4f :2 26 :3 a :2 10 15 21
5f 62 :2 21 6f 72 :2 21 76 79
:2 21 83 86 8f 97 :2 a0 :2 8f b1
:2 86 :2 21 :2 a 55 :2 7 a :2 14 26
:2 30 3c 3f 4f 51 52 :2 4f :2 26
:3 a :2 10 15 21 5f 62 :2 21 :2 a
55 :3 7 :2 12 28 :2 31 41 :2 7 51
:2 4 e 1a 27 35 41 4f 5c
:2 7 :2 10 1c 7 4 :2 c a :2 13
1f a d :2 17 29 :2 33 3f 43
53 55 56 :2 53 :2 29 :3 d :2 13 18
24 62 65 :2 24 72 75 :2 24 79
7c :2 24 88 8b :2 24 93 96 :2 24
a2 a5 ac b5 b8 :2 a5 :2 24 :2 d
59 :2 a :2 7 :4 13 :2 7 4 :3 1 8
:2 11 1c 1a :2 25 :2 1a 7 11 1d
2a 38 44 52 5f :2 a :2 13 1f
a 7 :2 f d :2 16 22 d 10
:2 1a 2c :2 36 42 46 56 58 59
:2 56 :2 2c :3 10 :2 16 1b 27 65 68
:2 27 75 78 :2 27 7c 7f :2 27 8b
8e :2 27 96 99 :2 27 a5 a8 af
b8 bb :2 a8 :2 27 :2 10 5c :2 d :2 a
:4 16 :2 a 7 :3 35 b :2 14 1f 1d
:2 28 :2 1d a d :2 17 29 :2 33 3f
43 53 55 56 :2 53 :2 29 :3 d :2 13
18 24 62 65 :2 24 72 75 :2 24
79 7c :2 24 86 89 92 9a :2 a3
:2 92 b6 :2 89 :2 24 be c1 :2 24 c9
cc :2 24 d1 d4 :2 24 df e2 :2 24
:2 d 59 :2 a d :2 17 29 :2 33 3f
42 52 54 55 :2 52 :2 29 :3 d :2 13
18 24 62 65 :2 24 :2 d 58 :3 a
:2 15 29 :2 32 44 50 :2 a 38 :3 7
10 :2 7 17 :2 20 7 35 7 10
:2 7 17 :2 20 7 :5 4 10 4 e
1a 28 38 42 4f c 1b 28
:2 7 :2 10 1c 7 4 :2 c a :2 13
1f a d :2 17 29 :2 33 3f 43
53 56 57 :2 53 :2 29 :3 d :2 13 18
24 63 66 :2 24 73 76 :2 24 7a
7d :2 24 89 8c :2 24 94 97 :2 24
a3 a6 ad b6 b9 :2 a6 :2 24 :2 d
5a :2 a :2 7 :4 13 :2 7 4 :3 1 8
:2 11 1c 1a :2 25 :2 1a :2 7 16 :2 7
14 1b 28 2b :2 14 7 11 1a
1e 35 f 10 1b 2c 34 :2 a
:2 13 1f a 7 :2 f d :2 16 22
d 10 :2 1a 2c :2 36 42 46 56
59 5a :2 56 :2 2c :3 10 :2 16 1b 27
66 69 :2 27 76 79 :2 27 7d 80
:2 27 8c 8f :2 27 97 9a :2 27 a6
a9 b0 b9 bc :2 a9 :2 27 :2 10 5d
:2 d :2 a :4 16 :2 a 7 :3 35 11 1c
29 34 41 4c 59 64 71 7c
89 8f 93 a9 af b2 c8 ce
d6 ed f 20 24 35 10 13
20 2e 32 3f 42 :2 a :2 13 1f
a 7 :2 f d :2 16 22 d 10
:2 1a 2c :2 36 42 46 56 59 5a
:2 56 :2 2c :3 10 :2 16 1b 27 66 69
:2 27 76 79 :2 27 7d 80 :2 27 8c
8f :2 27 97 9a :2 27 a6 a9 b0
b9 bc :2 a9 :2 27 :2 10 5d :2 d :2 a
:4 16 :2 a 7 :3 35 b :2 14 1f 1d
:2 28 :2 1d a d :2 17 29 :2 33 3f
43 53 56 57 :2 53 :2 29 :3 d :2 13
18 24 63 66 :2 24 73 76 :2 24
7a 7d :2 24 87 8a 93 9b :2 a4
:2 93 b7 :2 8a :2 24 bf c2 :2 24 ca
cd :2 24 d2 d5 :2 24 de e1 :2 24
:2 d 5a :2 a d :2 17 29 :2 33 3f
42 52 55 56 :2 52 :2 29 :3 d :2 13
18 24 63 66 :2 24 :2 d 59 :3 a
:2 15 29 :2 32 44 4e :2 a 38 :2 7
16 1f 2a 35 3d 4a 11 1b
29 34 3e a 11 d 19 :3 17
d :2 16 22 d 1e d :2 16 22
d :4 a 7 :2 f d :2 16 22 d
10 :2 1a 2c :2 36 42 46 56 59
5a :2 56 :2 2c :3 10 :2 16 1b 27 66
69 :2 27 76 79 :2 27 7d 80 :2 27
8c 8f :2 27 97 9a :2 27 a6 a9
b0 b9 bc :2 a9 :2 27 :2 10 5d :2 d
:2 a :4 16 :2 a 7 :3 35 b :2 14 20
1d :2 29 :2 1d a d :2 17 29 :2 33
3f 43 53 56 57 :2 53 :2 29 :3 d
:2 13 18 24 63 66 :2 24 73 76
:2 24 7a 7d :2 24 87 8a 93 9b
:2 a4 :2 93 af :2 8a :2 24 b7 ba :2 24
c2 c5 :2 24 ca cd :2 24 d7 da
:2 24 :2 d 5a :2 a d :2 17 29 :2 33
3f 42 52 55 56 :2 52 :2 29 :3 d
:2 13 18 24 63 66 :2 24 :2 d 59
:3 a :2 15 29 :2 32 3c 47 :2 a 39
:2 7 4 35 b :2 14 1f 1d :2 28
:2 1d :2 a 1b 24 2c :2 1b :2 a 30
33 :2 30 14 16 2d 12 27 13
15 22 11 13 21 11 13 :2 d
:2 16 22 d a :2 12 10 :2 19 25
10 13 :2 1d 2f :2 39 45 49 59
5c 5d :2 59 :2 2f :3 13 :2 19 1e 2a
69 6c :2 2a 79 7c :2 2a 80 83
:2 2a 8f 92 :2 2a 9a 9d :2 2a a9
ac b3 bc bf :2 ac :2 2a :2 13 60
:2 10 :2 d :4 19 :2 d a :3 35 e :2 17
22 20 :2 2b :2 20 d 10 :2 1a 2c
:2 36 42 46 56 59 5a :2 56 :2 2c
:3 10 :2 16 1b 27 66 69 :2 27 76
79 :2 27 7d 80 :2 27 8a 8d 96
9e :2 a7 :2 96 c1 :2 8d :2 27 c9 cc
:2 27 d4 d7 :2 27 dc df :2 27 e9
ec :2 27 :2 10 5d :2 d 10 :2 1a 2c
:2 36 42 45 55 58 59 :2 55 :2 2c
:3 10 :2 16 1b 27 66 69 :2 27 :2 10
5c :3 d :2 18 2c :2 35 4e 59 :2 d
3b :2 a 35 :2 7 a 11 1f 22
:2 a 25 27 :2 25 14 21 38 45
d 14 10 1c :3 1a 10 :2 19 25
10 21 10 :2 19 25 10 :4 d a
:2 12 10 :2 19 25 10 13 :2 1d 2f
:2 39 45 49 59 5c 5d :2 59 :2 2f
:3 13 :2 19 1e 2a 69 6c :2 2a 79
7c :2 2a 80 83 :2 2a 8f 92 :2 2a
9a 9d :2 2a a9 ac b3 bc bf
:2 ac :2 2a :2 13 60 :2 10 :2 d :4 19 :2 d
a :4 2b :2 7 38 35 a :2 14 26
:2 30 3c 40 50 53 54 :2 50 :2 26
:3 a :2 10 15 21 60 63 :2 21 70
73 :2 21 77 7a :2 21 84 87 90
98 :2 a1 :2 90 b4 :2 87 :2 21 bc bf
:2 21 c7 ca :2 21 cf d2 :2 21 dc
df :2 21 :2 a 57 :2 7 a :2 14 26
:2 30 3c 3f 4f 52 53 :2 4f :2 26
:3 a :2 10 15 21 60 63 :2 21 :2 a
56 :3 7 :2 12 26 :2 2f 41 4c :2 7
:5 4 11 4 e 25 c d 1a
b 19 b :2 7 :2 10 1c 7 4
:2 c a :2 13 1f a d :2 17 29
:2 33 3f 43 53 56 57 :2 53 :2 29
:3 d :2 13 18 24 63 66 :2 24 73
76 :2 24 7a 7d :2 24 89 8c :2 24
94 97 :2 24 a3 a6 ad b6 b9
:2 a6 :2 24 :2 d 5a :2 a :2 7 :4 13 :2 7
4 :3 1 8 :2 11 1c 1a :2 25 :2 1a
7 a 13 1a :2 a 1d 1f :2 1d
14 20 12 19 27 44 12 19
28 2f 49 12 22 13 20 d
14 10 1c :3 1a 10 :2 19 25 10
21 10 :2 19 25 10 :4 d a :2 12
10 :2 19 25 10 13 :2 1d 2f :2 39
45 49 59 5c 5d :2 59 :2 2f :3 13
:2 19 1e 2a 69 6c :2 2a 79 7c
:2 2a 80 83 :2 2a 8f 92 :2 2a 9a
9d :2 2a a9 ac b3 bc bf :2 ac
:2 2a :2 13 60 :2 10 :2 d :4 19 :2 d a
:3 21 7 21 d 16 1d :2 d 20
22 :2 20 14 20 12 19 27 44
12 19 28 2f 49 12 22 13
20 d 14 10 1c :3 1a 10 :2 19
25 10 21 10 :2 19 25 10 :4 d
a :2 12 10 :2 19 25 10 13 :2 1d
2f :2 39 45 49 59 5c 5d :2 59
:2 2f :3 13 :2 19 1e 2a 69 6c :2 2a
79 7c :2 2a 80 83 :2 2a 8f 92
:2 2a 9a 9d :2 2a a9 ac b3 bc
bf :2 ac :2 2a :2 13 60 :2 10 :2 d :4 19
:2 d a :4 24 21 :3 7 :3 15 :2 7 1a
28 31 3f :2 28 43 4c 54 :2 43
24 :2 2d 42 :2 1a 7 a 18 21
29 :2 18 :2 a 2d 30 :2 2d a 20
:2 29 a 32 a 20 :2 29 a :5 7
1a :2 7 19 :2 7 1a 31 3f 49
51 2d 41 52 :2 1a 7 16 2b
3e 4a 56 a 19 26 33 40
4a 57 12 1e 2b 37 f 19
2d 41 4e 5b a 11 d 19
:3 17 d :2 16 22 d 1e d :2 16
22 d :4 a 7 :2 f d :2 16 22
d 10 :2 1a 2c :2 36 42 46 56
59 5a :2 56 :2 2c :3 10 :2 16 1b 27
66 69 :2 27 76 79 :2 27 7d 80
:2 27 8c 8f :2 27 97 9a :2 27 a6
a9 b0 b9 bc :2 a9 :2 27 :2 10 5d
:2 d :2 a :4 16 :2 a 7 :3 35 4 35
b :2 14 1f 1d :2 28 :2 1d a 11
2a 38 41 48 55 5e 10 24
a 11 d 19 :3 17 d :2 16 22
d 1e d :2 16 22 d :4 a 7
:2 f d :2 16 22 d 10 :2 1a 2c
:2 36 42 46 56 59 5a :2 56 :2 2c
:3 10 :2 16 1b 27 66 69 :2 27 76
79 :2 27 7d 80 :2 27 8c 8f :2 27
97 9a :2 27 a6 a9 b0 b9 bc
:2 a9 :2 27 :2 10 5d :2 d :2 a :4 16 :2 a
7 :3 38 7 1a 30 :2 1a 7 38
35 :2 4 7 :2 11 23 :2 2d 39 3c
4c 4f 50 :2 4c :2 23 :3 7 :2 d 12
1e 5d 60 :2 1e 6d 70 :2 1e 74
77 :2 1e 81 84 8d 95 :2 9e :2 8d
a9 :2 84 :2 1e b1 b4 :2 1e bc bf
:2 1e c4 c7 :2 1e d2 d5 :2 1e :2 7
53 :3 4 :2 f 21 :2 2a 34 40 :2 4
1 9 12 9 a :2 14 26 :2 30
3c 40 50 53 54 :2 50 :2 26 :3 a
:2 10 15 21 60 63 :2 21 :3 a :2 10
15 39 5c 5f :2 68 :2 39 76 79
:2 39 81 84 :2 8d :2 39 :2 a 57 :3 7
c 15 1e 2c a 13 1e f
e 7 e 7 e 7 29 :2 4
:2 9 7 :2 10 1c :2 7 :2 11 23 :2 2d
39 3d 4d 50 51 :2 4d :2 23 :3 7
:2 d 12 1e 5d 60 :2 1e :3 7 :2 d
12 36 42 45 :2 36 4d 50 :2 36
5c 5f 66 6f 72 :2 5f :2 36 :2 7
54 :2 4 7 c 1b a 13 1e
f e 7 e 7 e 7 :2 4
:4 10 :2 4 :8 1 
add
4
0 :2 1 :4 3 :4 4
:4 5 :4 6 2 :4 7
:2 1 :7 9 :7 a :7 b
:7 c :7 d :7 e :7 f
:6 10 :6 11 :6 12 :6 13
:6 14 :7 15 :6 16 :7 17
:6 18 :6 19 :7 1b :b 1d
:11 1e 1f :2 1e :2 1f
:2 1e :2 1f :2 1e :2 20
:2 1e :2 20 :2 1e :2 20
:2 1e :2 20 :2 1e :2 21
:2 1e :2 21 :2 1e :2 21
:2 1e :2 21 :2 1e :2 22
:2 1e :2 22 :2 1e :2 22
:2 1e :2 22 :2 1e :2 22
:4 1e :3 1d :11 25 :b 26
:3 25 :16 2b :11 2c :20 2d
:3 2c :11 2f :b 30 :3 2f
:9 32 :3 2b :8 36 :5 37
35 :2 39 :5 3b :11 3c
:24 3d :3 3c :2 3a :6 39
38 :3 1c :a 42 :8 44
:5 45 43 :2 47 :5 49
:11 4a :24 4b :3 4a :2 48
:6 47 46 :3 42 :a 50
:11 51 :30 52 :3 51 :11 54
:b 55 :3 54 :a 57 :3 50
:3 59 :5 5a 42 :3 5c
:5 5d 5b :3 42 :3 60
:6 64 :3 65 64 :5 66
63 :2 68 :5 6a :11 6b
:24 6c :3 6b :2 69 :6 68
67 :3 1c :a 71 :3 72
:8 74 :4 77 78 :4 79
77 :5 7a 76 :2 7c
:5 7e :11 7f :24 80 :3 7f
:2 7d :6 7c 7b :3 71
:14 86 :4 87 :7 88 86
:5 89 85 :2 8b :5 8d
:11 8e :24 8f :3 8e :2 8c
:6 8b 8a :3 71 :a 94
:11 95 :30 96 :3 95 :11 98
:b 99 :3 98 :a 9b :3 94
:6 9f :5 a0 9f :6 a1
:5 a2 a1 :5 a4 a3
:3 a1 9e :2 a7 :5 a9
:11 aa :24 ab :3 aa :2 a8
:6 a7 a6 :3 71 :a b0
:11 b1 :30 b2 :3 b1 :11 b4
:b b5 :3 b4 :a b7 :3 b0
b9 71 :a b9 :c ba
:3 bc :2 bd :3 be :3 bf
:2 c0 bc :5 c1 bb
:2 c3 :5 c5 :11 c6 :24 c7
:3 c6 :2 c4 :6 c3 c2
:3 ba :a cc :11 cd :30 ce
:3 cd :11 d0 :b d1 :3 d0
:a d3 :3 cc :3 ba :a d7
:5 d9 :6 da :5 db da
:5 dd dc :3 da d8
:2 e0 :5 e2 :11 e3 :24 e4
:3 e3 :2 e1 :6 e0 df
:6 d7 b9 71 :11 ea
:30 eb :3 ea :11 ed :b ee
:3 ed :a f0 e9 :3 71
:3 f3 :2 f5 f6 :2 f7
:2 f8 f9 f5 :5 fa
f4 :2 fc :5 fe :11 ff
:24 100 :3 ff :2 fd :6 fc
fb :3 1c :a 106 :9 107
:2 109 :4 10b :5 10e :2 10f
:2 112 109 :6 113 :5 114
113 :5 116 115 :3 113
108 :2 119 :5 11b :11 11c
:24 11d :3 11c :2 11a :6 119
118 :3 107 121 107
:9 121 :2 123 :4 125 :5 128
:2 129 :2 12c 123 :6 12d
:5 12e 12d :5 130 12f
:3 12d 122 :2 133 :5 135
:11 136 :24 137 :3 136 :2 134
:6 133 132 :4 121 :3 107
:5 13e :c 13f :4 140 :3 13f
:c 142 :5 143 142 :5 145
144 :3 142 :3 148 :3 149
:6 14b :3 14c :3 14b :5 14f
:7 150 :4 151 :6 152 14f
:6 153 :5 154 153 :5 156
155 :3 153 14e :2 159
:5 15b :11 15c :24 15d :3 15c
:2 15a :6 159 158 :3 106
162 106 :a 162 :7 164
:2 165 164 :6 166 :5 167
166 :5 169 168 :3 166
163 :2 16c :5 16e :11 16f
:24 170 :3 16f :2 16d :6 16c
16b :3 162 :6 175 162
:3 106 :11 178 :30 179 :3 178
:a 17b 1c :3 17e :11 17f
:b 180 :17 181 :3 17f :2 183
:3 184 :3 185 186 184
183 184 :3 187 :3 17e
:2 188 :5 18a :11 18b :b 18c
:18 18d :3 18b :2 18f 190
:3 191 192 190 18f
190 :3 193 :2 189 :6 188
17d :7 1 
262b
4
:3 0 1 :3 0 2
:a 0 ad8 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
56 0 7 4
:3 0 5 :7 0 9
8 :3 0 4 :3 0
6 :7 0 d c
:3 0 15 16 0
b 4 :3 0 7
:7 0 11 10 :3 0
8 :3 0 9 :3 0
a :2 0 4 13
17 0 ad8 2
18 :2 0 c :2 0
12 4 :3 0 c
:2 0 10 1b 1d
:6 0 20 1e 0
ad6 0 b :6 0
c :2 0 16 4
:3 0 14 22 24
:6 0 27 25 0
ad6 0 d :6 0
10 :2 0 1a 4
:3 0 18 29 2b
:6 0 2e 2c 0
ad6 0 e :6 0
c :2 0 1e 4
:3 0 1c 30 32
:6 0 35 33 0
ad6 0 f :6 0
13 :2 0 22 4
:3 0 20 37 39
:6 0 3c 3a 0
ad6 0 11 :6 0
15 :2 0 26 4
:3 0 24 3e 40
:6 0 43 41 0
ad6 0 12 :6 0
18 :2 0 2a 4
:3 0 28 45 47
:6 0 4a 48 0
ad6 0 14 :6 0
18 :2 0 2c 17
:3 0 4c :7 0 50
4d 4e ad6 0
16 :6 0 18 :2 0
2e 17 :3 0 52
:7 0 56 53 54
ad6 0 19 :6 0
18 :2 0 30 17
:3 0 58 :7 0 5c
59 5a ad6 0
1a :6 0 18 :2 0
32 17 :3 0 5e
:7 0 62 5f 60
ad6 0 1b :6 0
c :2 0 34 17
:3 0 64 :7 0 68
65 66 ad6 0
1c :6 0 18 :2 0
38 4 :3 0 36
6a 6c :6 0 6f
6d 0 ad6 0
1d :6 0 13 :2 0
3a 17 :3 0 71
:7 0 75 72 73
ad6 0 1e :6 0
18 :2 0 3e 4
:3 0 3c 77 79
:6 0 7c 7a 0
ad6 0 1f :6 0
18 :2 0 40 17
:3 0 7e :7 0 82
7f 80 ad6 0
20 :6 0 8a 8b
0 42 17 :3 0
84 :7 0 88 85
86 ad6 0 21
:6 0 90 91 0
44 9 :3 0 a
:2 0 4 8c :7 0
8f 8d 0 ad6
0 22 :6 0 23
:3 0 24 :3 0 23
:3 0 25 :3 0 93
94 0 2 :4 0
46 95 97 92
99 98 :2 0 26
:3 0 27 :3 0 9b
9c 0 28 :4 0
23 :3 0 29 :3 0
9f a0 0 2
:4 0 48 a1 a3
2a :4 0 2b :2 0
2c :3 0 4a a6
a8 :3 0 2d :4 0
2b :2 0 2e :4 0
4d ab ad :3 0
2b :2 0 3 :3 0
50 af b1 :3 0
2b :2 0 2e :4 0
53 b3 b5 :3 0
2b :2 0 2f :4 0
56 b7 b9 :3 0
2b :2 0 2e :4 0
59 bb bd :3 0
2b :2 0 5 :3 0
5c bf c1 :3 0
2b :2 0 2e :4 0
5f c3 c5 :3 0
2b :2 0 2f :4 0
62 c7 c9 :3 0
2b :2 0 2e :4 0
65 cb cd :3 0
2b :2 0 6 :3 0
68 cf d1 :3 0
2b :2 0 2e :4 0
6b d3 d5 :3 0
2b :2 0 2f :4 0
6e d7 d9 :3 0
2b :2 0 2e :4 0
71 db dd :3 0
2b :2 0 7 :3 0
74 df e1 :3 0
2b :2 0 2e :4 0
77 e3 e5 :3 0
2b :2 0 30 :4 0
7a e7 e9 :3 0
7d 9d eb :2 0
ed 82 ee 9a
ed 0 ef 84
0 a36 23 :3 0
24 :3 0 f0 f1
0 23 :3 0 31
:3 0 f3 f4 0
13 :2 0 2 :4 0
32 :2 0 33 :2 0
13 :2 0 86 f9
fb :3 0 89 f5
fd f2 ff fe
:2 0 26 :3 0 34
:3 0 101 102 0
28 :4 0 35 :4 0
2b :2 0 2c :3 0
8d 106 108 :3 0
90 103 10a :2 0
10c 93 10d 100
10c 0 10e 95
0 a36 3 :3 0
36 :2 0 97 110
111 :3 0 112 :2 0
113 :2 0 5 :3 0
36 :2 0 99 116
117 :3 0 118 :2 0
119 :2 0 114 11b
11a :2 0 6 :3 0
36 :2 0 9b 11e
11f :3 0 120 :2 0
121 :2 0 11c 123
122 :2 0 23 :3 0
24 :3 0 125 126
0 23 :3 0 31
:3 0 128 129 0
37 :2 0 2 :4 0
38 :2 0 33 :2 0
13 :2 0 9d 12e
130 :3 0 a0 12a
132 127 134 133
:2 0 26 :3 0 34
:3 0 136 137 0
28 :4 0 39 :4 0
2b :2 0 2c :3 0
a4 13b 13d :3 0
2b :2 0 3a :4 0
a7 13f 141 :3 0
2b :2 0 3b :4 0
aa 143 145 :3 0
2b :2 0 3c :3 0
3d :3 0 3e :3 0
3f :3 0 14a 14b
0 ad 149 14d
40 :4 0 af 148
150 b2 147 152
:3 0 b5 138 154
:2 0 156 b8 157
135 156 0 158
ba 0 181 23
:3 0 24 :3 0 159
15a 0 23 :3 0
31 :3 0 15c 15d
0 13 :2 0 2
:4 0 41 :2 0 33
:2 0 13 :2 0 bc
162 164 :3 0 bf
15e 166 15b 168
167 :2 0 26 :3 0
34 :3 0 16a 16b
0 28 :4 0 42
:4 0 2b :2 0 2c
:3 0 c3 16f 171
:3 0 c6 16c 173
:2 0 175 c9 176
169 175 0 177
cb 0 181 43
:3 0 44 :3 0 178
179 0 3e :3 0
3f :3 0 17b 17c
0 45 :3 0 cd
17a 17f :2 0 181
d0 182 124 181
0 183 d4 0
a36 46 :3 0 47
:3 0 d :3 0 16
:3 0 48 :3 0 49
:3 0 3 :4 0 4a
1 :8 0 191 9
:3 0 4b :3 0 18c
18d 0 4c :3 0
18e 18f 0 191
d6 1db 4d :3 0
9 :3 0 4b :3 0
194 195 0 4c
:3 0 196 197 0
1d1 23 :3 0 24
:3 0 199 19a 0
23 :3 0 31 :3 0
19c 19d 0 4e
:2 0 2 :4 0 4f
:2 0 33 :2 0 13
:2 0 d9 1a2 1a4
:3 0 dc 19e 1a6
19b 1a8 1a7 :2 0
26 :3 0 34 :3 0
1aa 1ab 0 28
:4 0 50 :4 0 2b
:2 0 2c :3 0 e0
1af 1b1 :3 0 2b
:2 0 3a :4 0 e3
1b3 1b5 :3 0 2b
:2 0 51 :4 0 e6
1b7 1b9 :3 0 2b
:2 0 4c :3 0 e9
1bb 1bd :3 0 2b
:2 0 52 :4 0 ec
1bf 1c1 :3 0 2b
:2 0 53 :3 0 54
:3 0 13 :2 0 55
:2 0 ef 1c4 1c8
f3 1c3 1ca :3 0
f6 1ac 1cc :2 0
1ce f9 1cf 1a9
1ce 0 1d0 fb
0 1d1 fd 1d4
:3 0 1d4 0 1d4
1d3 1d1 1d2 :6 0
1d6 2 :3 0 100
1d8 102 1d7 1d6
:2 0 1d9 104 :2 0
1db 0 1db 1da
191 1d9 :6 0 a36
1 :3 0 9 :3 0
4b :3 0 1dd 1de
0 9 :3 0 56
:2 0 57 :3 0 1e0
1e2 0 108 1e1
1e4 :3 0 1e5 :2 0
46 :3 0 47 :3 0
d :3 0 16 :3 0
58 :3 0 49 :3 0
3 :4 0 59 1
:8 0 1f4 9 :3 0
4b :3 0 1ef 1f0
0 4c :3 0 1f1
1f2 0 1f4 10b
23e 4d :3 0 9
:3 0 4b :3 0 1f7
1f8 0 4c :3 0
1f9 1fa 0 234
23 :3 0 24 :3 0
1fc 1fd 0 23
:3 0 31 :3 0 1ff
200 0 4e :2 0
2 :4 0 5a :2 0
33 :2 0 13 :2 0
10e 205 207 :3 0
111 201 209 1fe
20b 20a :2 0 26
:3 0 34 :3 0 20d
20e 0 28 :4 0
5b :4 0 2b :2 0
2c :3 0 115 212
214 :3 0 2b :2 0
3a :4 0 118 216
218 :3 0 2b :2 0
51 :4 0 11b 21a
21c :3 0 2b :2 0
4c :3 0 11e 21e
220 :3 0 2b :2 0
52 :4 0 121 222
224 :3 0 2b :2 0
53 :3 0 54 :3 0
13 :2 0 55 :2 0
124 227 22b 128
226 22d :3 0 12b
20f 22f :2 0 231
12e 232 20c 231
0 233 130 0
234 132 237 :3 0
237 0 237 236
234 235 :6 0 239
4 :3 0 135 23b
137 23a 239 :2 0
23c 139 :2 0 23e
0 23e 23d 1f4
23c :6 0 2c2 1
:3 0 9 :3 0 4b
:3 0 240 241 0
9 :3 0 56 :2 0
57 :3 0 243 245
0 13d 244 247
:3 0 248 :2 0 23
:3 0 24 :3 0 24a
24b 0 23 :3 0
31 :3 0 24d 24e
0 c :2 0 2
:4 0 5c :2 0 33
:2 0 13 :2 0 140
253 255 :3 0 143
24f 257 24c 259
258 :2 0 26 :3 0
34 :3 0 25b 25c
0 28 :4 0 5d
:4 0 2b :2 0 2c
:3 0 147 260 262
:3 0 2b :2 0 3a
:4 0 14a 264 266
:3 0 2b :2 0 3b
:4 0 14d 268 26a
:3 0 2b :2 0 3c
:3 0 3d :3 0 3e
:3 0 5e :3 0 26f
270 0 150 26e
272 40 :4 0 152
26d 275 155 26c
277 :3 0 2b :2 0
5f :4 0 158 279
27b :3 0 2b :2 0
2e :4 0 15b 27d
27f :3 0 2b :2 0
3 :3 0 15e 281
283 :3 0 2b :2 0
2e :4 0 161 285
287 :3 0 164 25d
289 :2 0 28b 167
28c 25a 28b 0
28d 169 0 2b7
23 :3 0 24 :3 0
28e 28f 0 23
:3 0 31 :3 0 291
292 0 13 :2 0
2 :4 0 60 :2 0
33 :2 0 13 :2 0
16b 297 299 :3 0
16e 293 29b 290
29d 29c :2 0 26
:3 0 34 :3 0 29f
2a0 0 28 :4 0
61 :4 0 2b :2 0
2c :3 0 172 2a4
2a6 :3 0 175 2a1
2a8 :2 0 2aa 178
2ab 29e 2aa 0
2ac 17a 0 2b7
43 :3 0 62 :3 0
2ad 2ae 0 3e
:3 0 5e :3 0 2b0
2b1 0 3 :3 0
45 :3 0 17c 2af
2b5 :2 0 2b7 180
2b8 249 2b7 0
2b9 184 0 2c2
19 :3 0 13 :2 0
2ba 2bb 0 2c2
21 :3 0 3e :3 0
63 :3 0 2be 2bf
0 2bd 2c0 0
2c2 186 2cc 19
:3 0 18 :2 0 2c3
2c4 0 2cb 21
:3 0 3e :3 0 64
:3 0 2c7 2c8 0
2c6 2c9 0 2cb
18b 2cd 1e6 2c2
0 2ce 0 2cb
0 2ce 18e 0
a36 e :3 0 5
:3 0 2cf 2d0 0
a36 65 :3 0 66
:3 0 67 :3 0 e
:3 0 14 :3 0 12
:3 0 68 :3 0 65
:3 0 e :4 0 69
1 :8 0 2e1 9
:3 0 4b :3 0 2dc
2dd 0 4c :3 0
2de 2df 0 2e1
191 32b 4d :3 0
9 :3 0 4b :3 0
2e4 2e5 0 4c
:3 0 2e6 2e7 0
321 23 :3 0 24
:3 0 2e9 2ea 0
23 :3 0 31 :3 0
2ec 2ed 0 4e
:2 0 2 :4 0 6a
:2 0 33 :2 0 13
:2 0 194 2f2 2f4
:3 0 197 2ee 2f6
2eb 2f8 2f7 :2 0
26 :3 0 34 :3 0
2fa 2fb 0 28
:4 0 6b :4 0 2b
:2 0 2c :3 0 19b
2ff 301 :3 0 2b
:2 0 3a :4 0 19e
303 305 :3 0 2b
:2 0 51 :4 0 1a1
307 309 :3 0 2b
:2 0 4c :3 0 1a4
30b 30d :3 0 2b
:2 0 52 :4 0 1a7
30f 311 :3 0 2b
:2 0 53 :3 0 54
:3 0 13 :2 0 55
:2 0 1aa 314 318
1ae 313 31a :3 0
1b1 2fc 31c :2 0
31e 1b4 31f 2f9
31e 0 320 1b6
0 321 1b8 324
:3 0 324 0 324
323 321 322 :6 0
326 6 :3 0 1bb
328 1bd 327 326
:2 0 329 1bf :2 0
32b 0 32b 32a
2e1 329 :6 0 a36
1 :3 0 9 :3 0
4b :3 0 32d 32e
0 9 :3 0 56
:2 0 57 :3 0 330
332 0 1c3 331
334 :3 0 335 :2 0
f :3 0 6 :3 0
337 338 0 570
11 :3 0 53 :3 0
f :3 0 13 :2 0
c :2 0 1c6 33b
33f 33a 340 0
570 3c :3 0 6c
:3 0 6d :3 0 1b
:3 0 68 :3 0 46
:3 0 d :3 0 6e
:3 0 11 :4 0 6f
1 :8 0 351 9
:3 0 4b :3 0 34c
34d 0 4c :3 0
34e 34f 0 351
1ca 39b 4d :3 0
9 :3 0 4b :3 0
354 355 0 4c
:3 0 356 357 0
391 23 :3 0 24
:3 0 359 35a 0
23 :3 0 31 :3 0
35c 35d 0 4e
:2 0 2 :4 0 70
:2 0 33 :2 0 13
:2 0 1cd 362 364
:3 0 1d0 35e 366
35b 368 367 :2 0
26 :3 0 34 :3 0
36a 36b 0 28
:4 0 71 :4 0 2b
:2 0 2c :3 0 1d4
36f 371 :3 0 2b
:2 0 3a :4 0 1d7
373 375 :3 0 2b
:2 0 51 :4 0 1da
377 379 :3 0 2b
:2 0 4c :3 0 1dd
37b 37d :3 0 2b
:2 0 52 :4 0 1e0
37f 381 :3 0 2b
:2 0 53 :3 0 54
:3 0 13 :2 0 55
:2 0 1e3 384 388
1e7 383 38a :3 0
1ea 36c 38c :2 0
38e 1ed 38f 369
38e 0 390 1ef
0 391 1f1 394
:3 0 394 0 394
393 391 392 :6 0
396 8 :3 0 1f4
398 1f6 397 396
:2 0 399 1f8 :2 0
39b 0 39b 39a
351 399 :6 0 570
1 :3 0 72 :3 0
73 :3 0 72 :3 0
73 :3 0 72 :3 0
73 :3 0 72 :3 0
73 :3 0 72 :3 0
73 :3 0 74 :3 0
75 :3 0 76 :3 0
74 :3 0 77 :3 0
76 :3 0 74 :3 0
3d :3 0 1b :3 0
14 :3 0 78 :3 0
77 :3 0 78 :3 0
75 :3 0 77 :3 0
49 :3 0 11 :3 0
75 :3 0 49 :3 0
77 :3 0 79 :4 0
7a 1 :8 0 3c2
9 :3 0 4b :3 0
3bd 3be 0 4c
:3 0 3bf 3c0 0
3c2 1fa 40c 4d
:3 0 9 :3 0 4b
:3 0 3c5 3c6 0
4c :3 0 3c7 3c8
0 402 23 :3 0
24 :3 0 3ca 3cb
0 23 :3 0 31
:3 0 3cd 3ce 0
4e :2 0 2 :4 0
7b :2 0 33 :2 0
13 :2 0 1fd 3d3
3d5 :3 0 200 3cf
3d7 3cc 3d9 3d8
:2 0 26 :3 0 34
:3 0 3db 3dc 0
28 :4 0 7c :4 0
2b :2 0 2c :3 0
204 3e0 3e2 :3 0
2b :2 0 3a :4 0
207 3e4 3e6 :3 0
2b :2 0 51 :4 0
20a 3e8 3ea :3 0
2b :2 0 4c :3 0
20d 3ec 3ee :3 0
2b :2 0 52 :4 0
210 3f0 3f2 :3 0
2b :2 0 53 :3 0
54 :3 0 13 :2 0
55 :2 0 213 3f5
3f9 217 3f4 3fb
:3 0 21a 3dd 3fd
:2 0 3ff 21d 400
3da 3ff 0 401
21f 0 402 221
405 :3 0 405 0
405 404 402 403
:6 0 407 a :3 0
224 409 226 408
407 :2 0 40a 228
:2 0 40c 0 40c
40b 3c2 40a :6 0
570 1 :3 0 9
:3 0 4b :3 0 40e
40f 0 9 :3 0
56 :2 0 57 :3 0
411 413 0 22c
412 415 :3 0 416
:2 0 23 :3 0 24
:3 0 418 419 0
23 :3 0 31 :3 0
41b 41c 0 c
:2 0 2 :4 0 7d
:2 0 33 :2 0 13
:2 0 22f 421 423
:3 0 232 41d 425
41a 427 426 :2 0
26 :3 0 34 :3 0
429 42a 0 28
:4 0 7e :4 0 2b
:2 0 2c :3 0 236
42e 430 :3 0 2b
:2 0 3a :4 0 239
432 434 :3 0 2b
:2 0 3b :4 0 23c
436 438 :3 0 2b
:2 0 3c :3 0 3d
:3 0 3e :3 0 5e
:3 0 43d 43e 0
23f 43c 440 40
:4 0 241 43b 443
244 43a 445 :3 0
2b :2 0 5f :4 0
247 447 449 :3 0
2b :2 0 2e :4 0
24a 44b 44d :3 0
2b :2 0 e :3 0
24d 44f 451 :3 0
2b :2 0 2e :4 0
250 453 455 :3 0
253 42b 457 :2 0
459 256 45a 428
459 0 45b 258
0 485 23 :3 0
24 :3 0 45c 45d
0 23 :3 0 31
:3 0 45f 460 0
13 :2 0 2 :4 0
7f :2 0 33 :2 0
13 :2 0 25a 465
467 :3 0 25d 461
469 45e 46b 46a
:2 0 26 :3 0 34
:3 0 46d 46e 0
28 :4 0 80 :4 0
2b :2 0 2c :3 0
261 472 474 :3 0
264 46f 476 :2 0
478 267 479 46c
478 0 47a 269
0 485 43 :3 0
62 :3 0 47b 47c
0 3e :3 0 5e
:3 0 47e 47f 0
e :3 0 45 :3 0
26b 47d 483 :2 0
485 26f 486 417
485 0 487 273
0 570 68 :3 0
65 :3 0 46 :3 0
6e :3 0 6d :3 0
66 :3 0 e :3 0
d :3 0 11 :3 0
1b :3 0 14 :4 0
81 1 :8 0 4a9
82 :4 0 494 :3 0
45 :3 0 56 :2 0
277 497 498 :3 0
9 :3 0 4b :3 0
49a 49b 0 18
:2 0 49c 49d 0
49f 27a 4a6 9
:3 0 4b :3 0 4a0
4a1 0 83 :2 0
4a2 4a3 0 4a5
27c 4a7 499 49f
0 4a8 0 4a5
0 4a8 27e 0
4a9 281 4f3 4d
:3 0 9 :3 0 4b
:3 0 4ac 4ad 0
4c :3 0 4ae 4af
0 4e9 23 :3 0
24 :3 0 4b1 4b2
0 23 :3 0 31
:3 0 4b4 4b5 0
4e :2 0 2 :4 0
84 :2 0 33 :2 0
13 :2 0 284 4ba
4bc :3 0 287 4b6
4be 4b3 4c0 4bf
:2 0 26 :3 0 34
:3 0 4c2 4c3 0
28 :4 0 85 :4 0
2b :2 0 2c :3 0
28b 4c7 4c9 :3 0
2b :2 0 3a :4 0
28e 4cb 4cd :3 0
2b :2 0 51 :4 0
291 4cf 4d1 :3 0
2b :2 0 4c :3 0
294 4d3 4d5 :3 0
2b :2 0 52 :4 0
297 4d7 4d9 :3 0
2b :2 0 53 :3 0
54 :3 0 13 :2 0
55 :2 0 29a 4dc
4e0 29e 4db 4e2
:3 0 2a1 4c4 4e4
:2 0 4e6 2a4 4e7
4c1 4e6 0 4e8
2a6 0 4e9 2a8
4ec :3 0 4ec 0
4ec 4eb 4e9 4ea
:6 0 4ee c :3 0
2ab 4f0 2ad 4ef
4ee :2 0 4f1 2af
:2 0 4f3 0 4f3
4f2 4a9 4f1 :6 0
570 1 :3 0 9
:3 0 4b :3 0 4f5
4f6 0 9 :3 0
86 :2 0 87 :3 0
4f8 4fa 0 2b3
4f9 4fc :3 0 4fd
:2 0 23 :3 0 24
:3 0 4ff 500 0
23 :3 0 31 :3 0
502 503 0 c
:2 0 2 :4 0 88
:2 0 33 :2 0 13
:2 0 2b6 508 50a
:3 0 2b9 504 50c
501 50e 50d :2 0
26 :3 0 34 :3 0
510 511 0 28
:4 0 89 :4 0 2b
:2 0 2c :3 0 2bd
515 517 :3 0 2b
:2 0 3a :4 0 2c0
519 51b :3 0 2b
:2 0 3b :4 0 2c3
51d 51f :3 0 2b
:2 0 3c :3 0 3d
:3 0 9 :3 0 4b
:3 0 524 525 0
2c6 523 527 40
:4 0 2c8 522 52a
2cb 521 52c :3 0
2b :2 0 5f :4 0
2ce 52e 530 :3 0
2b :2 0 2e :4 0
2d1 532 534 :3 0
2b :2 0 5 :3 0
2d4 536 538 :3 0
2b :2 0 2e :4 0
2d7 53a 53c :3 0
2da 512 53e :2 0
540 2dd 541 50f
540 0 542 2df
0 56c 23 :3 0
24 :3 0 543 544
0 23 :3 0 31
:3 0 546 547 0
13 :2 0 2 :4 0
8a :2 0 33 :2 0
13 :2 0 2e1 54c
54e :3 0 2e4 548
550 545 552 551
:2 0 26 :3 0 34
:3 0 554 555 0
28 :4 0 8b :4 0
2b :2 0 2c :3 0
2e8 559 55b :3 0
2eb 556 55d :2 0
55f 2ee 560 553
55f 0 561 2f0
0 56c 43 :3 0
62 :3 0 562 563
0 9 :3 0 4b
:3 0 565 566 0
5 :3 0 45 :3 0
2f2 564 56a :2 0
56c 2f6 56d 4fe
56c 0 56e 2fa
0 570 8c :3 0
2fc 746 9 :3 0
4b :3 0 571 572
0 9 :3 0 56
:2 0 87 :3 0 574
576 0 306 575
578 :3 0 579 :2 0
8d :3 0 3c :3 0
16 :3 0 18 :2 0
309 57c 57f 30c
57b 581 86 :2 0
18 :2 0 310 583
585 :3 0 8e :3 0
8f :3 0 b :3 0
90 :3 0 8e :3 0
8e :3 0 49 :3 0
3 :3 0 8e :3 0
91 :3 0 5 :3 0
8e :3 0 92 :4 0
93 1 :8 0 59a
9 :3 0 4b :3 0
595 596 0 4c
:3 0 597 598 0
59a 313 5e4 4d
:3 0 9 :3 0 4b
:3 0 59d 59e 0
4c :3 0 59f 5a0
0 5da 23 :3 0
24 :3 0 5a2 5a3
0 23 :3 0 31
:3 0 5a5 5a6 0
4e :2 0 2 :4 0
94 :2 0 33 :2 0
13 :2 0 316 5ab
5ad :3 0 319 5a7
5af 5a4 5b1 5b0
:2 0 26 :3 0 34
:3 0 5b3 5b4 0
28 :4 0 95 :4 0
2b :2 0 2c :3 0
31d 5b8 5ba :3 0
2b :2 0 3a :4 0
320 5bc 5be :3 0
2b :2 0 51 :4 0
323 5c0 5c2 :3 0
2b :2 0 4c :3 0
326 5c4 5c6 :3 0
2b :2 0 52 :4 0
329 5c8 5ca :3 0
2b :2 0 53 :3 0
54 :3 0 13 :2 0
55 :2 0 32c 5cd
5d1 330 5cc 5d3
:3 0 333 5b5 5d5
:2 0 5d7 336 5d8
5b2 5d7 0 5d9
338 0 5da 33a
5dd :3 0 5dd 0
5dd 5dc 5da 5db
:6 0 5df e :3 0
33d 5e1 33f 5e0
5df :2 0 5e2 341
:2 0 5e4 0 5e4
5e3 59a 5e2 :6 0
660 1 :3 0 9
:3 0 4b :3 0 5e6
5e7 0 9 :3 0
56 :2 0 87 :3 0
5e9 5eb 0 345
5ea 5ed :3 0 5ee
:2 0 23 :3 0 24
:3 0 5f0 5f1 0
23 :3 0 31 :3 0
5f3 5f4 0 c
:2 0 2 :4 0 96
:2 0 33 :2 0 13
:2 0 348 5f9 5fb
:3 0 34b 5f5 5fd
5f2 5ff 5fe :2 0
26 :3 0 34 :3 0
601 602 0 28
:4 0 97 :4 0 2b
:2 0 2c :3 0 34f
606 608 :3 0 2b
:2 0 3a :4 0 352
60a 60c :3 0 2b
:2 0 3b :4 0 355
60e 610 :3 0 2b
:2 0 3c :3 0 3d
:3 0 3e :3 0 98
:3 0 615 616 0
358 614 618 40
:4 0 35a 613 61b
35d 612 61d :3 0
2b :2 0 5f :4 0
360 61f 621 :3 0
2b :2 0 2e :4 0
363 623 625 :3 0
2b :2 0 5 :3 0
366 627 629 :3 0
2b :2 0 2e :4 0
369 62b 62d :3 0
36c 603 62f :2 0
631 36f 632 600
631 0 633 371
0 65d 23 :3 0
24 :3 0 634 635
0 23 :3 0 31
:3 0 637 638 0
13 :2 0 2 :4 0
99 :2 0 33 :2 0
13 :2 0 373 63d
63f :3 0 376 639
641 636 643 642
:2 0 26 :3 0 34
:3 0 645 646 0
28 :4 0 9a :4 0
2b :2 0 2c :3 0
37a 64a 64c :3 0
37d 647 64e :2 0
650 380 651 644
650 0 652 382
0 65d 43 :3 0
62 :3 0 653 654
0 3e :3 0 98
:3 0 656 657 0
5 :3 0 45 :3 0
384 655 65b :2 0
65d 388 65e 5ef
65d 0 65f 38c
0 660 38e 661
586 660 0 662
391 0 6d6 53
:3 0 12 :3 0 13
:2 0 13 :2 0 393
663 667 56 :2 0
9b :4 0 399 669
66b :3 0 68 :3 0
67 :3 0 65 :3 0
e :4 0 9c 1
:8 0 687 82 :4 0
672 :3 0 45 :3 0
56 :2 0 39e 675
676 :3 0 9 :3 0
4b :3 0 678 679
0 18 :2 0 67a
67b 0 67d 3a1
684 9 :3 0 4b
:3 0 67e 67f 0
83 :2 0 680 681
0 683 3a3 685
677 67d 0 686
0 683 0 686
3a5 0 687 3a8
6d1 4d :3 0 9
:3 0 4b :3 0 68a
68b 0 4c :3 0
68c 68d 0 6c7
23 :3 0 24 :3 0
68f 690 0 23
:3 0 31 :3 0 692
693 0 4e :2 0
2 :4 0 9d :2 0
33 :2 0 13 :2 0
3ab 698 69a :3 0
3ae 694 69c 691
69e 69d :2 0 26
:3 0 34 :3 0 6a0
6a1 0 28 :4 0
9e :4 0 2b :2 0
2c :3 0 3b2 6a5
6a7 :3 0 2b :2 0
3a :4 0 3b5 6a9
6ab :3 0 2b :2 0
51 :4 0 3b8 6ad
6af :3 0 2b :2 0
4c :3 0 3bb 6b1
6b3 :3 0 2b :2 0
52 :4 0 3be 6b5
6b7 :3 0 2b :2 0
53 :3 0 54 :3 0
13 :2 0 55 :2 0
3c1 6ba 6be 3c5
6b9 6c0 :3 0 3c8
6a2 6c2 :2 0 6c4
3cb 6c5 69f 6c4
0 6c6 3cd 0
6c7 3cf 6ca :3 0
6ca 0 6ca 6c9
6c7 6c8 :6 0 6cc
10 :3 0 3d2 6ce
3d4 6cd 6cc :2 0
6cf 3d6 :2 0 6d1
0 6d1 6d0 687
6cf :6 0 6d3 1
:3 0 3d8 6d4 66c
6d3 0 6d5 3da
0 6d6 3dc 6d7
57a 6d6 0 748
23 :3 0 24 :3 0
6d8 6d9 0 23
:3 0 31 :3 0 6db
6dc 0 c :2 0
2 :4 0 9f :2 0
33 :2 0 13 :2 0
3df 6e1 6e3 :3 0
3e2 6dd 6e5 6da
6e7 6e6 :2 0 26
:3 0 34 :3 0 6e9
6ea 0 28 :4 0
a0 :4 0 2b :2 0
2c :3 0 3e6 6ee
6f0 :3 0 2b :2 0
3a :4 0 3e9 6f2
6f4 :3 0 2b :2 0
3b :4 0 3ec 6f6
6f8 :3 0 2b :2 0
3c :3 0 3d :3 0
3e :3 0 5e :3 0
6fd 6fe 0 3ef
6fc 700 40 :4 0
3f1 6fb 703 3f4
6fa 705 :3 0 2b
:2 0 5f :4 0 3f7
707 709 :3 0 2b
:2 0 2e :4 0 3fa
70b 70d :3 0 2b
:2 0 5 :3 0 3fd
70f 711 :3 0 2b
:2 0 2e :4 0 400
713 715 :3 0 403
6eb 717 :2 0 719
406 71a 6e8 719
0 71b 408 0
745 23 :3 0 24
:3 0 71c 71d 0
23 :3 0 31 :3 0
71f 720 0 13
:2 0 2 :4 0 a1
:2 0 33 :2 0 13
:2 0 40a 725 727
:3 0 40d 721 729
71e 72b 72a :2 0
26 :3 0 34 :3 0
72d 72e 0 28
:4 0 a2 :4 0 2b
:2 0 2c :3 0 411
732 734 :3 0 414
72f 736 :2 0 738
417 739 72c 738
0 73a 419 0
745 43 :3 0 62
:3 0 73b 73c 0
3e :3 0 5e :3 0
73e 73f 0 5
:3 0 45 :3 0 41b
73d 743 :2 0 745
41f 747 336 570
0 748 0 745
0 748 423 0
a36 1a :3 0 18
:2 0 749 74a 0
a36 8f :3 0 b
:3 0 90 :3 0 49
:3 0 3 :3 0 91
:3 0 e :3 0 92
:4 0 a3 1 :8 0
75a 9 :3 0 4b
:3 0 755 756 0
4c :3 0 757 758
0 75a 427 7a4
4d :3 0 9 :3 0
4b :3 0 75d 75e
0 4c :3 0 75f
760 0 79a 23
:3 0 24 :3 0 762
763 0 23 :3 0
31 :3 0 765 766
0 4e :2 0 2
:4 0 15 :2 0 33
:2 0 13 :2 0 42a
76b 76d :3 0 42d
767 76f 764 771
770 :2 0 26 :3 0
34 :3 0 773 774
0 28 :4 0 a4
:4 0 2b :2 0 2c
:3 0 431 778 77a
:3 0 2b :2 0 3a
:4 0 434 77c 77e
:3 0 2b :2 0 51
:4 0 437 780 782
:3 0 2b :2 0 4c
:3 0 43a 784 786
:3 0 2b :2 0 52
:4 0 43d 788 78a
:3 0 2b :2 0 53
:3 0 54 :3 0 13
:2 0 55 :2 0 440
78d 791 444 78c
793 :3 0 447 775
795 :2 0 797 44a
798 772 797 0
799 44c 0 79a
44e 79d :3 0 79d
0 79d 79c 79a
79b :6 0 79f 12
:3 0 451 7a1 453
7a0 79f :2 0 7a2
455 :2 0 7a4 0
7a4 7a3 75a 7a2
:6 0 a36 1 :3 0
9 :3 0 4b :3 0
7a6 7a7 0 9
:3 0 56 :2 0 57
:3 0 7a9 7ab 0
459 7aa 7ad :3 0
7ae :2 0 3c :3 0
19 :3 0 18 :2 0
45c 7b0 7b3 56
:2 0 18 :2 0 461
7b5 7b7 :3 0 48
:3 0 a5 :3 0 a6
:3 0 a5 :3 0 14
:3 0 a5 :3 0 a7
:3 0 14 :3 0 a7
:3 0 a5 :3 0 a5
:3 0 a5 :3 0 14
:3 0 49 :3 0 3
:4 0 a8 1 :8 0
7de 82 :4 0 7c9
:3 0 45 :3 0 56
:2 0 466 7cc 7cd
:3 0 9 :3 0 4b
:3 0 7cf 7d0 0
18 :2 0 7d1 7d2
0 7d4 469 7db
9 :3 0 4b :3 0
7d5 7d6 0 83
:2 0 7d7 7d8 0
7da 46b 7dc 7ce
7d4 0 7dd 0
7da 0 7dd 46d
0 7de 470 828
4d :3 0 9 :3 0
4b :3 0 7e1 7e2
0 4c :3 0 7e3
7e4 0 81e 23
:3 0 24 :3 0 7e6
7e7 0 23 :3 0
31 :3 0 7e9 7ea
0 4e :2 0 2
:4 0 a9 :2 0 33
:2 0 13 :2 0 473
7ef 7f1 :3 0 476
7eb 7f3 7e8 7f5
7f4 :2 0 26 :3 0
34 :3 0 7f7 7f8
0 28 :4 0 aa
:4 0 2b :2 0 2c
:3 0 47a 7fc 7fe
:3 0 2b :2 0 3a
:4 0 47d 800 802
:3 0 2b :2 0 51
:4 0 480 804 806
:3 0 2b :2 0 4c
:3 0 483 808 80a
:3 0 2b :2 0 52
:4 0 486 80c 80e
:3 0 2b :2 0 53
:3 0 54 :3 0 13
:2 0 55 :2 0 489
811 815 48d 810
817 :3 0 490 7f9
819 :2 0 81b 493
81c 7f6 81b 0
81d 495 0 81e
497 821 :3 0 821
0 821 820 81e
81f :6 0 823 14
:3 0 49a 825 49c
824 823 :2 0 826
49e :2 0 828 0
828 827 7de 826
:6 0 82b 1 :3 0
8c :3 0 4a0 8a8
3c :3 0 19 :3 0
18 :2 0 4a2 82c
82f 56 :2 0 13
:2 0 4a7 831 833
:3 0 58 :3 0 a5
:3 0 a6 :3 0 a5
:3 0 14 :3 0 a5
:3 0 a7 :3 0 14
:3 0 a7 :3 0 a5
:3 0 a5 :3 0 a5
:3 0 14 :3 0 49
:3 0 3 :4 0 ab
1 :8 0 85a 82
:4 0 845 :3 0 45
:3 0 56 :2 0 4ac
848 849 :3 0 9
:3 0 4b :3 0 84b
84c 0 18 :2 0
84d 84e 0 850
4af 857 9 :3 0
4b :3 0 851 852
0 83 :2 0 853
854 0 856 4b1
858 84a 850 0
859 0 856 0
859 4b3 0 85a
4b6 8a4 4d :3 0
9 :3 0 4b :3 0
85d 85e 0 4c
:3 0 85f 860 0
89a 23 :3 0 24
:3 0 862 863 0
23 :3 0 31 :3 0
865 866 0 4e
:2 0 2 :4 0 ac
:2 0 33 :2 0 13
:2 0 4b9 86b 86d
:3 0 4bc 867 86f
864 871 870 :2 0
26 :3 0 34 :3 0
873 874 0 28
:4 0 ad :4 0 2b
:2 0 2c :3 0 4c0
878 87a :3 0 2b
:2 0 3a :4 0 4c3
87c 87e :3 0 2b
:2 0 51 :4 0 4c6
880 882 :3 0 2b
:2 0 4c :3 0 4c9
884 886 :3 0 2b
:2 0 52 :4 0 4cc
888 88a :3 0 2b
:2 0 53 :3 0 54
:3 0 13 :2 0 55
:2 0 4cf 88d 891
4d3 88c 893 :3 0
4d6 875 895 :2 0
897 4d9 898 872
897 0 899 4db
0 89a 4dd 89d
:3 0 89d 0 89d
89c 89a 89b :6 0
89f 16 :3 0 4e0
8a1 4e2 8a0 89f
:2 0 8a2 4e4 :2 0
8a4 0 8a4 8a3
85a 8a2 :6 0 8a6
1 :3 0 4e6 8a7
834 8a6 0 8a9
7b8 82b 0 8a9
4e8 0 968 b
:3 0 ae :4 0 8ab
8ac :3 0 8aa 8ad
0 968 20 :3 0
af :3 0 3c :3 0
21 :3 0 18 :2 0
4eb 8b1 8b4 3c
:3 0 16 :3 0 18
:2 0 4ee 8b6 8b9
3e :3 0 b0 :3 0
8bb 8bc 0 1d
:3 0 4f1 8b0 8bf
8af 8c0 0 968
b1 :3 0 3c :3 0
16 :3 0 18 :2 0
4f6 8c3 8c6 4f9
8c2 8c8 86 :2 0
18 :2 0 4fd 8ca
8cc :3 0 1c :3 0
3e :3 0 b2 :3 0
8cf 8d0 0 8ce
8d1 0 8d3 500
8da 1c :3 0 3e
:3 0 b3 :3 0 8d5
8d6 0 8d4 8d7
0 8d9 502 8db
8cd 8d3 0 8dc
0 8d9 0 8dc
504 0 968 1f
:3 0 13 :4 0 8dd
8de 0 968 1e
:3 0 13 :2 0 8e0
8e1 0 968 20
:3 0 b4 :3 0 d
:3 0 e :3 0 16
:3 0 1c :3 0 1d
:3 0 1f :3 0 1e
:3 0 507 8e4 8ec
8e3 8ed 0 968
90 :3 0 8f :3 0
46 :3 0 49 :3 0
b5 :3 0 92 :3 0
91 :3 0 b6 :3 0
b7 :3 0 b8 :3 0
b9 :3 0 ba :3 0
b :3 0 d :3 0
3 :3 0 16 :3 0
e :3 0 1c :3 0
1d :3 0 7 :3 0
2c :3 0 21 :4 0
bb 1 :8 0 91b
82 :4 0 906 :3 0
45 :3 0 56 :2 0
511 909 90a :3 0
9 :3 0 4b :3 0
90c 90d 0 18
:2 0 90e 90f 0
911 514 918 9
:3 0 4b :3 0 912
913 0 83 :2 0
914 915 0 917
516 919 90b 911
0 91a 0 917
0 91a 518 0
91b 51b 965 4d
:3 0 9 :3 0 4b
:3 0 91e 91f 0
4c :3 0 920 921
0 95b 23 :3 0
24 :3 0 923 924
0 23 :3 0 31
:3 0 926 927 0
4e :2 0 2 :4 0
bc :2 0 33 :2 0
13 :2 0 51e 92c
92e :3 0 521 928
930 925 932 931
:2 0 26 :3 0 34
:3 0 934 935 0
28 :4 0 bd :4 0
2b :2 0 2c :3 0
525 939 93b :3 0
2b :2 0 3a :4 0
528 93d 93f :3 0
2b :2 0 51 :4 0
52b 941 943 :3 0
2b :2 0 4c :3 0
52e 945 947 :3 0
2b :2 0 52 :4 0
531 949 94b :3 0
2b :2 0 53 :3 0
54 :3 0 13 :2 0
55 :2 0 534 94e
952 538 94d 954
:3 0 53b 936 956
:2 0 958 53e 959
933 958 0 95a
540 0 95b 542
95e :3 0 95e 0
95e 95d 95b 95c
:6 0 960 18 :3 0
545 962 547 961
960 :2 0 963 549
:2 0 965 0 965
964 91b 963 :6 0
968 1 :3 0 8c
:3 0 54b 9e6 9
:3 0 4b :3 0 969
96a 0 9 :3 0
56 :2 0 87 :3 0
96c 96e 0 556
96d 970 :3 0 971
:2 0 90 :3 0 b6
:3 0 be :3 0 bf
:3 0 b6 :3 0 3e
:3 0 b3 :3 0 8f
:3 0 b :4 0 c0
1 :8 0 992 82
:4 0 97d :3 0 45
:3 0 56 :2 0 55b
980 981 :3 0 9
:3 0 4b :3 0 983
984 0 18 :2 0
985 986 0 988
55e 98f 9 :3 0
4b :3 0 989 98a
0 83 :2 0 98b
98c 0 98e 560
990 982 988 0
991 0 98e 0
991 562 0 992
565 9dc 4d :3 0
9 :3 0 4b :3 0
995 996 0 4c
:3 0 997 998 0
9d2 23 :3 0 24
:3 0 99a 99b 0
23 :3 0 31 :3 0
99d 99e 0 4e
:2 0 2 :4 0 c1
:2 0 33 :2 0 13
:2 0 568 9a3 9a5
:3 0 56b 99f 9a7
99c 9a9 9a8 :2 0
26 :3 0 34 :3 0
9ab 9ac 0 28
:4 0 c2 :4 0 2b
:2 0 2c :3 0 56f
9b0 9b2 :3 0 2b
:2 0 3a :4 0 572
9b4 9b6 :3 0 2b
:2 0 51 :4 0 575
9b8 9ba :3 0 2b
:2 0 4c :3 0 578
9bc 9be :3 0 2b
:2 0 52 :4 0 57b
9c0 9c2 :3 0 2b
:2 0 53 :3 0 54
:3 0 13 :2 0 55
:2 0 57e 9c5 9c9
582 9c4 9cb :3 0
585 9ad 9cd :2 0
9cf 588 9d0 9aa
9cf 0 9d1 58a
0 9d2 58c 9d5
:3 0 9d5 0 9d5
9d4 9d2 9d3 :6 0
9d7 1a :3 0 58f
9d9 591 9d8 9d7
:2 0 9da 593 :2 0
9dc 0 9dc 9db
992 9da :6 0 9e4
1 :3 0 20 :3 0
c3 :3 0 b :3 0
595 9df 9e1 9de
9e2 0 9e4 597
9e5 972 9e4 0
9e7 7af 968 0
9e7 59a 0 a36
23 :3 0 24 :3 0
9e8 9e9 0 23
:3 0 31 :3 0 9eb
9ec 0 c4 :2 0
2 :4 0 c5 :2 0
33 :2 0 13 :2 0
59d 9f1 9f3 :3 0
5a0 9ed 9f5 9ea
9f7 9f6 :2 0 26
:3 0 34 :3 0 9f9
9fa 0 28 :4 0
c6 :4 0 2b :2 0
2c :3 0 5a4 9fe
a00 :3 0 2b :2 0
3a :4 0 5a7 a02
a04 :3 0 2b :2 0
3b :4 0 5aa a06
a08 :3 0 2b :2 0
3c :3 0 3d :3 0
9 :3 0 4b :3 0
a0d a0e 0 5ad
a0c a10 40 :4 0
5af a0b a13 5b2
a0a a15 :3 0 2b
:2 0 5f :4 0 5b5
a17 a19 :3 0 2b
:2 0 2e :4 0 5b8
a1b a1d :3 0 2b
:2 0 b :3 0 5bb
a1f a21 :3 0 2b
:2 0 2e :4 0 5be
a23 a25 :3 0 5c1
9fb a27 :2 0 a29
5c4 a2a 9f8 a29
0 a2b 5c6 0
a36 43 :3 0 c7
:3 0 a2c a2d 0
9 :3 0 4b :3 0
a2f a30 0 b
:3 0 45 :3 0 5c8
a2e a34 :2 0 a36
5cc ad7 9 :3 0
c8 :2 0 4 a37
a38 0 23 :3 0
24 :3 0 a3a a3b
0 23 :3 0 31
:3 0 a3d a3e 0
4e :2 0 2 :4 0
c9 :2 0 33 :2 0
13 :2 0 5da a43
a45 :3 0 5dd a3f
a47 a3c a49 a48
:2 0 26 :3 0 34
:3 0 a4b a4c 0
28 :4 0 ca :4 0
2b :2 0 2c :3 0
5e1 a50 a52 :3 0
5e4 a4d a54 :2 0
a6d 26 :3 0 34
:3 0 a56 a57 0
28 :4 0 cb :4 0
2b :2 0 9 :3 0
cc :3 0 a5c a5d
0 5e7 a5b a5f
:3 0 2b :2 0 5f
:4 0 5ea a61 a63
:3 0 2b :2 0 9
:3 0 cd :3 0 a66
a67 0 5ed a65
a69 :3 0 5f0 a58
a6b :2 0 a6d 5f3
a6e a4a a6d 0
a6f 5f6 0 a7f
ce :3 0 22 :3 0
9 :3 0 cc :3 0
cf :3 0 9 :3 0
cd :3 0 d0 :3 0
d1 :4 0 d2 1
:a 0 a7b :2 0 a7f
a71 a79 :2 0 8
:3 0 22 :3 0 a7d
:2 0 a7f 5f8 a81
5fc a80 a7f :2 0
ad5 4d :3 0 9
:3 0 4b :3 0 a84
a85 0 4c :3 0
a86 a87 0 acd
23 :3 0 24 :3 0
a89 a8a 0 23
:3 0 31 :3 0 a8c
a8d 0 4e :2 0
2 :4 0 d3 :2 0
33 :2 0 13 :2 0
5fe a92 a94 :3 0
601 a8e a96 a8b
a98 a97 :2 0 26
:3 0 34 :3 0 a9a
a9b 0 28 :4 0
d4 :4 0 2b :2 0
2c :3 0 605 a9f
aa1 :3 0 608 a9c
aa3 :2 0 abd 26
:3 0 34 :3 0 aa5
aa6 0 28 :4 0
51 :4 0 2b :2 0
4c :3 0 60b aaa
aac :3 0 2b :2 0
52 :4 0 60e aae
ab0 :3 0 2b :2 0
53 :3 0 54 :3 0
13 :2 0 55 :2 0
611 ab3 ab7 615
ab2 ab9 :3 0 618
aa7 abb :2 0 abd
61b abe a99 abd
0 abf 61e 0
acd ce :3 0 22
:3 0 cf :3 0 9
:3 0 cd :3 0 d0
:3 0 d1 :4 0 d5
1 :a 0 ac9 :2 0
acd ac1 ac7 :2 0
8 :3 0 22 :3 0
acb :2 0 acd 620
ad0 :3 0 ad0 0
ad0 acf acd ace
:6 0 ad2 1 :3 0
625 ad4 627 ad3
ad2 :2 0 ad5 629
:2 0 ad7 62c ad7
ad6 a36 ad5 :6 0
ad8 :2 0 2 18
ad7 adb :3 0 ada
ad8 adc :8 0 
63f
4
:3 0 1 3 1
7 1 b 1
f 4 6 a
e 12 1 1c
1 1a 1 23
1 21 1 2a
1 28 1 31
1 2f 1 38
1 36 1 3f
1 3d 1 46
1 44 1 4b
1 51 1 57
1 5d 1 63
1 6b 1 69
1 70 1 78
1 76 1 7d
1 83 1 89
1 96 1 a2
2 a5 a7 2
aa ac 2 ae
b0 2 b2 b4
2 b6 b8 2
ba bc 2 be
c0 2 c2 c4
2 c6 c8 2
ca cc 2 ce
d0 2 d2 d4
2 d6 d8 2
da dc 2 de
e0 2 e2 e4
2 e6 e8 4
9e a4 a9 ea
1 ec 1 ee
2 f8 fa 3
f6 f7 fc 2
105 107 2 104
109 1 10b 1
10d 1 10f 1
115 1 11d 2
12d 12f 3 12b
12c 131 2 13a
13c 2 13e 140
2 142 144 1
14c 2 14e 14f
2 146 151 2
139 153 1 155
1 157 2 161
163 3 15f 160
165 2 16e 170
2 16d 172 1
174 1 176 2
17d 17e 3 158
177 180 1 182
2 18b 190 2
1a1 1a3 3 19f
1a0 1a5 2 1ae
1b0 2 1b2 1b4
2 1b6 1b8 2
1ba 1bc 2 1be
1c0 3 1c5 1c6
1c7 2 1c2 1c9
2 1ad 1cb 1
1cd 1 1cf 2
198 1d0 1 1d4
1 193 1 1d8
1 1e3 2 1df
1e3 2 1ee 1f3
2 204 206 3
202 203 208 2
211 213 2 215
217 2 219 21b
2 21d 21f 2
221 223 3 228
229 22a 2 225
22c 2 210 22e
1 230 1 232
2 1fb 233 1
237 1 1f6 1
23b 1 246 2
242 246 2 252
254 3 250 251
256 2 25f 261
2 263 265 2
267 269 1 271
2 273 274 2
26b 276 2 278
27a 2 27c 27e
2 280 282 2
284 286 2 25e
288 1 28a 1
28c 2 296 298
3 294 295 29a
2 2a3 2a5 2
2a2 2a7 1 2a9
1 2ab 3 2b2
2b3 2b4 3 28d
2ac 2b6 1 2b8
4 23e 2b9 2bc
2c1 2 2c5 2ca
2 2cc 2cd 2
2db 2e0 2 2f1
2f3 3 2ef 2f0
2f5 2 2fe 300
2 302 304 2
306 308 2 30a
30c 2 30e 310
3 315 316 317
2 312 319 2
2fd 31b 1 31d
1 31f 2 2e8
320 1 324 1
2e3 1 328 1
333 2 32f 333
3 33c 33d 33e
2 34b 350 2
361 363 3 35f
360 365 2 36e
370 2 372 374
2 376 378 2
37a 37c 2 37e
380 3 385 386
387 2 382 389
2 36d 38b 1
38d 1 38f 2
358 390 1 394
1 353 1 398
2 3bc 3c1 2
3d2 3d4 3 3d0
3d1 3d6 2 3df
3e1 2 3e3 3e5
2 3e7 3e9 2
3eb 3ed 2 3ef
3f1 3 3f6 3f7
3f8 2 3f3 3fa
2 3de 3fc 1
3fe 1 400 2
3c9 401 1 405
1 3c4 1 409
1 414 2 410
414 2 420 422
3 41e 41f 424
2 42d 42f 2
431 433 2 435
437 1 43f 2
441 442 2 439
444 2 446 448
2 44a 44c 2
44e 450 2 452
454 2 42c 456
1 458 1 45a
2 464 466 3
462 463 468 2
471 473 2 470
475 1 477 1
479 3 480 481
482 3 45b 47a
484 1 486 1
496 2 495 496
1 49e 1 4a4
2 4a6 4a7 2
493 4a8 2 4b9
4bb 3 4b7 4b8
4bd 2 4c6 4c8
2 4ca 4cc 2
4ce 4d0 2 4d2
4d4 2 4d6 4d8
3 4dd 4de 4df
2 4da 4e1 2
4c5 4e3 1 4e5
1 4e7 2 4b0
4e8 1 4ec 1
4ab 1 4f0 1
4fb 2 4f7 4fb
2 507 509 3
505 506 50b 2
514 516 2 518
51a 2 51c 51e
1 526 2 528
529 2 520 52b
2 52d 52f 2
531 533 2 535
537 2 539 53b
2 513 53d 1
53f 1 541 2
54b 54d 3 549
54a 54f 2 558
55a 2 557 55c
1 55e 1 560
3 567 568 569
3 542 561 56b
1 56d 7 339
341 39b 40c 487
4f3 56e 1 577
2 573 577 2
57d 57e 1 580
1 584 2 582
584 2 594 599
2 5aa 5ac 3
5a8 5a9 5ae 2
5b7 5b9 2 5bb
5bd 2 5bf 5c1
2 5c3 5c5 2
5c7 5c9 3 5ce
5cf 5d0 2 5cb
5d2 2 5b6 5d4
1 5d6 1 5d8
2 5a1 5d9 1
5dd 1 59c 1
5e1 1 5ec 2
5e8 5ec 2 5f8
5fa 3 5f6 5f7
5fc 2 605 607
2 609 60b 2
60d 60f 1 617
2 619 61a 2
611 61c 2 61e
620 2 622 624
2 626 628 2
62a 62c 2 604
62e 1 630 1
632 2 63c 63e
3 63a 63b 640
2 649 64b 2
648 64d 1 64f
1 651 3 658
659 65a 3 633
652 65c 1 65e
2 5e4 65f 1
661 3 664 665
666 1 66a 2
668 66a 1 674
2 673 674 1
67c 1 682 2
684 685 2 671
686 2 697 699
3 695 696 69b
2 6a4 6a6 2
6a8 6aa 2 6ac
6ae 2 6b0 6b2
2 6b4 6b6 3
6bb 6bc 6bd 2
6b8 6bf 2 6a3
6c1 1 6c3 1
6c5 2 68e 6c6
1 6ca 1 689
1 6ce 1 6d1
1 6d4 2 662
6d5 2 6e0 6e2
3 6de 6df 6e4
2 6ed 6ef 2
6f1 6f3 2 6f5
6f7 1 6ff 2
701 702 2 6f9
704 2 706 708
2 70a 70c 2
70e 710 2 712
714 2 6ec 716
1 718 1 71a
2 724 726 3
722 723 728 2
731 733 2 730
735 1 737 1
739 3 740 741
742 3 71b 73a
744 3 746 6d7
747 2 754 759
2 76a 76c 3
768 769 76e 2
777 779 2 77b
77d 2 77f 781
2 783 785 2
787 789 3 78e
78f 790 2 78b
792 2 776 794
1 796 1 798
2 761 799 1
79d 1 75c 1
7a1 1 7ac 2
7a8 7ac 2 7b1
7b2 1 7b6 2
7b4 7b6 1 7cb
2 7ca 7cb 1
7d3 1 7d9 2
7db 7dc 2 7c8
7dd 2 7ee 7f0
3 7ec 7ed 7f2
2 7fb 7fd 2
7ff 801 2 803
805 2 807 809
2 80b 80d 3
812 813 814 2
80f 816 2 7fa
818 1 81a 1
81c 2 7e5 81d
1 821 1 7e0
1 825 1 828
2 82d 82e 1
832 2 830 832
1 847 2 846
847 1 84f 1
855 2 857 858
2 844 859 2
86a 86c 3 868
869 86e 2 877
879 2 87b 87d
2 87f 881 2
883 885 2 887
889 3 88e 88f
890 2 88b 892
2 876 894 1
896 1 898 2
861 899 1 89d
1 85c 1 8a1
1 8a4 2 8a8
8a7 2 8b2 8b3
2 8b7 8b8 4
8b5 8ba 8bd 8be
2 8c4 8c5 1
8c7 1 8cb 2
8c9 8cb 1 8d2
1 8d8 2 8da
8db 7 8e5 8e6
8e7 8e8 8e9 8ea
8eb 1 908 2
907 908 1 910
1 916 2 918
919 2 905 91a
2 92b 92d 3
929 92a 92f 2
938 93a 2 93c
93e 2 940 942
2 944 946 2
948 94a 3 94f
950 951 2 94c
953 2 937 955
1 957 1 959
2 922 95a 1
95e 1 91d 1
962 8 8a9 8ae
8c1 8dc 8df 8e2
8ee 965 1 96f
2 96b 96f 1
97f 2 97e 97f
1 987 1 98d
2 98f 990 2
97c 991 2 9a2
9a4 3 9a0 9a1
9a6 2 9af 9b1
2 9b3 9b5 2
9b7 9b9 2 9bb
9bd 2 9bf 9c1
3 9c6 9c7 9c8
2 9c3 9ca 2
9ae 9cc 1 9ce
1 9d0 2 999
9d1 1 9d5 1
994 1 9d9 1
9e0 2 9dc 9e3
2 9e6 9e5 2
9f0 9f2 3 9ee
9ef 9f4 2 9fd
9ff 2 a01 a03
2 a05 a07 1
a0f 2 a11 a12
2 a09 a14 2
a16 a18 2 a1a
a1c 2 a1e a20
2 a22 a24 2
9fc a26 1 a28
1 a2a 3 a31
a32 a33 d ef
10e 183 1db 2ce
2d1 32b 748 74b
7a4 9e7 a2b a35
2 a42 a44 3
a40 a41 a46 2
a4f a51 2 a4e
a53 2 a5a a5e
2 a60 a62 2
a64 a68 2 a59
a6a 2 a55 a6c
1 a6e 3 a6f
a7a a7e 1 a39
2 a91 a93 3
a8f a90 a95 2
a9e aa0 2 a9d
aa2 2 aa9 aab
2 aad aaf 3
ab4 ab5 ab6 2
ab1 ab8 2 aa8
aba 2 aa4 abc
1 abe 4 a88
abf ac8 acc 1
ad0 1 a83 2
a81 ad4 12 1f
26 2d 34 3b
42 49 4f 55
5b 61 67 6e
74 7b 81 87
8e 
1
4
0 
adb
0
1
28
1c
17
0 1 2 1 4 1 6 1
8 1 a 1 c 1 e 1
10 1 12 1 14 1 16 1
18 1 1a 1 0 0 0 0
0 0 0 0 0 0 0 0

f 1 0
63 1 0
51 1 0
69 1 0
7 1 0
36 1 0
76 1 0
7d 1 0
b 1 0
3d 1 0
5d 1 0
2f 1 0
1a 1 0
57 1 0
3 1 0
70 1 0
2 0 1
83 1 0
4b 1 0
28 1 0
21 1 0
44 1 0
89 1 0
0

/
SHOW ERRORS FUNCTION SP_A_TSKPROF;
ALTER FUNCTION SP_A_TSKPROF COMPILE DEBUG;
/***************************************************************************************************/
/*
#Stored Procedure  :SP_A_TSKRES
#Short Description :
#Description       :
#Table Name        :
#Parameters        :
#Returns           :
#Errors            :
*/
Prompt == FUNCTION SP_A_TSKRES ==
CREATE OR REPLACE FUNCTION SP_A_TSKRES wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
5e
2 :e:
1FUNCTION:
1SP_A_TSKRES:
1ID001:
1VARCHAR2:
1RES_ID001:
1REC_USER001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_ELEMENT_ID:
132:
1H_RA_ID:
1H_PROJECT_ID:
1H_REC_USER:
1H_RESOURCE_ID:
1H_TABLE_TYPE:
1PLS_INTEGER:
10:
1H_TYPE_ID:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_A_TSKRES(:
1':
1, :
1);:
1CHECK_TRACE:
11:
125:
1+:
1FPUT:
1               ENTER:: SP_A_TSKRES(26) :: cplan.sql(5990) :: :
1IS NULL:
18:
130:
1      RETURN_INVALID:: SP_A_TSKRES(31) :: cplan.sql(5995) :: :
1 :
1STATE:: :
1COALESCE:
1TO_CHAR:
1PMO_CNST:
1INVALID_PARAMS:
1NULL:
133:
1                EXIT:: SP_A_TSKRES(34) :: cplan.sql(5998) :: :
1PMODEFINES:
1PMO_RETURN_INVALID_SP:
1TRUE:
1SC_TABLE_WBS:
1TYPE_ID:
1PROJECT_ID:
1TMT_WBS:
1ELEMENT_ID:
1SELECT TYPE_ID, PROJECT_ID INTO h_type_id, h_project_id:n      FROM TMT_WBS W+
1HERE ELEMENT_ID = h_element_id:
1SC_STATE:
1SQLCODE:
1OTHERS:
116:
154:
1           EXCEPTION:: SP_A_TSKRES(55) :: cplan.sql(6019) :: :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1SYS_GUID:
1ASSIGNRESOURCE:
14:
165:
1       RETURN_STATUS:: SP_A_TSKRES(66) :: cplan.sql(6030) :: :
1 ID:: :
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
172:
1           EXCEPTION:: SP_A_TSKRES(73) :: cplan.sql(6037) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1ID:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
184:
1           EXCEPTION:: SP_A_TSKRES(85) :: cplan.sql(6049) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
29e
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 :2 a0 6b 1c 81
b0 :2 a0 6b :2 a0 6b 6e a5 b
a 10 :2 a0 6b 6e :2 a0 6b 6e
a5 b 6e 7e a0 b4 2e 6e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
a0 7e b4 2e :2 5a a0 7e b4
2e :2 5a 52 10 a0 7e b4 2e
:2 5a 52 10 :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b a0
a5 57 b7 19 3c :2 a0 d :2 a0
d :2 a0 d :3 a0 6b d :7 a0 12a
:2 a0 6b a0 d b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 b4 2e d :2 a0 6b :7 a0
a5 b d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b :2 a0 a5 57 b7
:2 a0 6b :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 :2 a0 6b :2 6e 7e :2 a0 6b
b4 2e 7e 6e b4 2e 7e :2 a0
6b b4 2e a5 57 b7 19 3c
:9 a0 12a e9 dd :2 a0 65 b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c :7 a0 12a
e9 dd :2 a0 65 b7 a4 b1 11
4f b7 a6 9 a4 b1 11 68
4f 1d 17 b5 
29e
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 30
56 5a 5e 62 65 69 86 71
75 78 79 81 70 a3 91 6d
95 96 9e 90 c0 ae 8d b2
b3 bb ad dd cb aa cf d0
d8 ca fa e8 c7 ec ed f5
e7 116 105 109 e4 111 104 132
121 125 101 12d 120 152 13d 141
11d 145 14d 13c 159 15d 139 161
165 169 16c 171 172 1 174 179
17d 181 184 189 18d 191 194 199
19a 19c 1a1 1a4 1a8 1a9 1ae 1b3
1b6 1bb 1bc 1c1 1c4 1c8 1c9 1ce
1d1 1d6 1d7 1dc 1df 1e4 1e5 1ea
1ed 1f2 1f3 1f8 1fb 1ff 200 205
208 20d 20e 213 216 21b 21c 221
224 229 22a 22f 232 236 237 23c
23f 244 245 24a 24d 252 253 258
259 25e 260 264 267 26b 26f 272
276 27a 27d 280 285 288 28b 28e
28f 294 295 1 297 29c 2a0 2a4
2a7 2ac 2b1 2b4 2b8 2b9 2be 2bf
2c4 2c6 2ca 2cd 2d1 2d4 2d5 2da
2dd 2e0 2e4 2e7 2e8 2ed 2f0 1
2f3 2f8 2fc 2ff 300 305 308 1
30b 310 314 318 31b 31f 323 326
329 32e 331 334 337 338 33d 33e
1 340 345 349 34d 350 355 35a
35d 361 362 367 36a 36f 370 375
378 37d 37e 383 386 38a 38e 392
396 399 39a 39c 3a1 3a2 3a4 3a5
3aa 3ab 3b0 3b2 3b6 3b9 3bd 3c1
3c4 3c8 3cc 3cf 3d2 3d7 3da 3dd
3e0 3e1 3e6 3e7 1 3e9 3ee 3f2
3f6 3f9 3fe 403 406 40a 40b 410
411 416 418 41c 41f 423 427 42a
42e 432 435 439 43a 43f 441 445
448 44c 450 454 458 45c 460 464
468 46c 470 474 478 47b 47f 483
487 48b 48f 493 497 49b 4a7 4ab
4af 4b2 4b6 4ba 4bc 1 4c0 4c4
4c8 4cb 4cf 4d3 4d7 4db 4de 4e2
4e6 4e9 4ec 4f1 4f4 4f7 4fa 4fb
500 501 1 503 508 50c 510 513
518 51d 520 524 525 52a 52d 532
533 538 53b 540 541 546 549 54d
54e 553 556 55b 55c 561 564 568
56c 56f 572 573 575 576 57b 57c
581 583 587 58a 58c 590 592 59e
5a0 5a2 5a3 5a8 5ac 5ae 5ba 5bc
5c0 5c4 5c5 5ca 5ce 5d2 5d6 5d9
5dd 5e1 5e5 5e9 5ed 5f1 5f5 5f6
5f8 5fc 600 604 607 60b 60f 612
615 61a 61d 620 623 624 629 62a
1 62c 631 635 639 63c 641 646
649 64d 64e 653 656 65b 65c 661
664 669 66a 66f 672 676 67a 67e
682 685 686 688 68d 68e 690 691
696 699 69e 69f 6a4 6a7 6ac 6ad
6b2 6b5 6b9 6ba 6bf 6c2 6c7 6c8
6cd 6ce 6d3 6d5 6d9 6dc 6e0 6e4
6e7 6eb 6ef 6f2 6f6 6fa 6fb 700
702 706 70a 70d 711 715 718 71c
720 723 726 72b 72e 731 734 735
73a 73b 1 73d 742 746 74a 74d
752 757 75a 75e 75f 764 765 76a
76e 772 775 77a 77f 782 786 78a
78d 78e 793 796 79b 79c 7a1 7a4
7a8 7ac 7af 7b0 7b5 7b6 7bb 7bd
7c1 7c4 7c8 7cc 7d0 7d4 7d8 7dc
7e0 7e4 7e8 7f4 7f9 7fd 801 805
809 80b 80c 811 1 815 819 81d
820 824 828 82c 830 833 837 83b
83e 841 846 849 84c 84f 850 855
856 1 858 85d 861 865 868 86d
872 875 879 87a 87f 880 885 889
88d 890 895 89a 89d 8a1 8a2 8a7
8aa 8af 8b0 8b5 8b8 8bc 8c0 8c3
8c6 8c7 8c9 8ca 8cf 8d0 8d5 8d7
8db 8de 8e2 8e6 8ea 8ee 8f2 8f6
8fa 906 90b 90f 913 917 91b 91d
921 923 92f 931 933 934 939 93d
93f 94b 94f 951 952 95b 
29e
2
0 1 a 6 c :3 6 10 :3 6
12 :2 6 1 3 a 13 a :2 1
4 11 1a 19 :2 11 :2 4 c 15
14 :2 c :2 4 11 1a 19 :2 11 :2 4
f 18 17 :2 f :2 4 12 1b 1a
:2 12 :2 4 :2 11 20 11 :2 4 :2 e 1d
e :2 4 e 17 :3 e 4 7 :2 11
23 :2 2d 3a :2 23 :3 7 :2 d 19 25
:2 2f 43 :2 25 53 59 5c :2 53 6a
7f 8 :2 6a d 10 :2 6a 16 19
:2 6a b e :2 6a 13 16 :2 6a 1b
1e :2 6a 28 2b :2 6a b e :2 6a
13 16 :2 6a 1b 1e :2 6a 2a 2d
:2 6a 32 35 :2 6a :2 7 49 :2 4 7
:2 11 23 :2 2d 39 3c 4b 4d 4e
:2 4b :2 23 :3 7 :2 d 12 1e 5b 5e
:2 1e :2 7 51 :2 4 :4 9 8 7 :4 1e
1d 1c :2 7 :4 37 36 35 :2 7 a
:2 14 26 :2 30 3c 3f 4e 50 51
:2 4e :2 26 :3 a :2 10 15 21 5e 61
:2 21 6e 71 :2 21 75 78 :2 21 82
85 8e 96 :2 9f :2 8e b0 :2 85 :2 21
:2 a 54 :2 7 a :2 14 26 :2 30 3c
3f 4e 50 51 :2 4e :2 26 :3 a :2 10
15 21 5e 61 :2 21 :2 a 54 :3 7
:2 12 28 :2 31 41 :2 7 4d :3 4 14
:2 4 15 :2 4 12 :2 4 14 :2 1d 4
e 17 27 32 c 1a 27 :2 7
:2 10 1c 7 4 :2 c a :2 13 1f
a d :2 17 29 :2 33 3f 43 52
54 55 :2 52 :2 29 :3 d :2 13 18 24
61 64 :2 24 71 74 :2 24 78 7b
:2 24 87 8a :2 24 92 95 :2 24 a1
a4 ab b4 b7 :2 a4 :2 24 :2 d 58
:2 a :2 7 :4 13 :2 7 4 :3 1 4 :3 f
:2 4 :2 d 19 28 36 41 4f 5e
27 :2 19 4 7 :2 11 23 :2 2d 39
3c 4b 4d 4e :2 4b :2 23 :3 7 :2 d
12 1e 5b 5e :2 1e 6b 6e :2 1e
72 75 :2 1e 7f 82 8b 93 :2 9c
:2 8b a7 :2 82 :2 1e af b2 :2 1e ba
bd :2 1e c2 c5 :2 1e cd d0 :2 1e
:2 7 51 :3 4 :2 f 21 :2 2a 34 3d
:2 4 1 9 12 9 a :2 14 26
:2 30 3c 40 4f 51 52 :2 4f :2 26
:3 a :2 10 15 21 5e 61 :2 21 :3 a
:2 10 15 39 5c 5f :2 68 :2 39 76
79 :2 39 81 84 :2 8d :2 39 :2 a 55
:3 7 c 15 1e 2c a 13 1e
f e 7 e 7 e 7 29
:2 4 :2 9 7 :2 10 1c :2 7 :2 11 23
:2 2d 39 3d 4c 4e 4f :2 4c :2 23
:3 7 :2 d 12 1e 5b 5e :2 1e :3 7
:2 d 12 36 42 45 :2 36 4d 50
:2 36 5c 5f 66 6f 72 :2 5f :2 36
:2 7 52 :2 4 7 c 1b a 13
1e f e 7 e 7 e 7
:2 4 :4 10 :2 4 :8 1 
29e
4
0 :2 1 :4 3 :4 4
:4 5 2 :4 6 :2 1
:7 8 :7 9 :7 a :7 b
:7 c :6 d :6 e :7 10
:b 12 :11 13 14 :2 13
:2 14 :2 13 :2 14 :2 13
:2 15 :2 13 :2 15 :2 13
:2 15 :2 13 :2 15 :2 13
:2 16 :2 13 :2 16 :2 13
:2 16 :2 13 :2 16 :2 13
:2 16 :4 13 :3 12 :11 19
:b 1a :3 19 :16 1d :11 1e
:20 1f :3 1e :11 21 :b 22
:3 21 :9 24 :3 1d :3 29
:3 2a :3 2b :5 2c :4 2f
:3 30 2f :5 31 2e
:2 33 :5 35 :11 36 :24 37
:3 36 :2 34 :6 33 32
:3 11 :5 3c :9 3e 3f
:3 3e :11 41 :30 42 :3 41
:a 44 11 :3 47 :11 48
:b 49 :17 4a :3 48 :2 4c
:3 4d :3 4e 4f 4d
4c 4d :3 50 :3 47
:2 51 :5 53 :11 54 :b 55
:18 56 :3 54 :2 58 59
:3 5a 5b 59 58
59 :3 5c :2 52 :6 51
46 :7 1 
95d
4
:3 0 1 :3 0 2
:a 0 299 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
:2 0 7 4 :3 0
5 :7 0 9 8
:3 0 4 :3 0 6
:7 0 d c :3 0
7 :3 0 8 :3 0
9 :2 0 4 11
12 0 f 13
0 299 2 14
:2 0 b :2 0 f
4 :3 0 b :2 0
d 17 19 :6 0
1c 1a 0 297
0 a :6 0 b
:2 0 13 4 :3 0
11 1e 20 :6 0
23 21 0 297
0 c :6 0 b
:2 0 17 4 :3 0
15 25 27 :6 0
2a 28 0 297
0 d :6 0 b
:2 0 1b 4 :3 0
19 2c 2e :6 0
31 2f 0 297
0 e :6 0 12
:2 0 1f 4 :3 0
1d 33 35 :6 0
38 36 0 297
0 f :6 0 12
:2 0 21 11 :3 0
3a :7 0 3e 3b
3c 297 0 10
:6 0 46 47 0
23 11 :3 0 40
:7 0 44 41 42
297 0 13 :6 0
4c 4d 0 25
8 :3 0 9 :2 0
4 48 :7 0 4b
49 0 297 0
14 :6 0 15 :3 0
16 :3 0 15 :3 0
17 :3 0 4f 50
0 2 :4 0 27
51 53 4e 55
54 :2 0 18 :3 0
19 :3 0 57 58
0 1a :4 0 15
:3 0 1b :3 0 5b
5c 0 2 :4 0
29 5d 5f 1c
:4 0 1d :2 0 1e
:3 0 2b 62 64
:3 0 1f :4 0 1d
:2 0 20 :4 0 2e
67 69 :3 0 1d
:2 0 3 :3 0 31
6b 6d :3 0 1d
:2 0 20 :4 0 34
6f 71 :3 0 1d
:2 0 21 :4 0 37
73 75 :3 0 1d
:2 0 20 :4 0 3a
77 79 :3 0 1d
:2 0 5 :3 0 3d
7b 7d :3 0 1d
:2 0 20 :4 0 40
7f 81 :3 0 1d
:2 0 21 :4 0 43
83 85 :3 0 1d
:2 0 20 :4 0 46
87 89 :3 0 1d
:2 0 6 :3 0 49
8b 8d :3 0 1d
:2 0 20 :4 0 4c
8f 91 :3 0 1d
:2 0 22 :4 0 4f
93 95 :3 0 52
59 97 :2 0 99
57 9a 56 99
0 9b 59 0
1f7 15 :3 0 16
:3 0 9c 9d 0
15 :3 0 23 :3 0
9f a0 0 24
:2 0 2 :4 0 25
:2 0 26 :2 0 24
:2 0 5b a5 a7
:3 0 5e a1 a9
9e ab aa :2 0
18 :3 0 27 :3 0
ad ae 0 1a
:4 0 28 :4 0 1d
:2 0 1e :3 0 62
b2 b4 :3 0 65
af b6 :2 0 b8
68 b9 ac b8
0 ba 6a 0
1f7 3 :3 0 29
:2 0 6c bc bd
:3 0 be :2 0 bf
:2 0 5 :3 0 29
:2 0 6e c2 c3
:3 0 c4 :2 0 c5
:2 0 c0 c7 c6
:2 0 6 :3 0 29
:2 0 70 ca cb
:3 0 cc :2 0 cd
:2 0 c8 cf ce
:2 0 15 :3 0 16
:3 0 d1 d2 0
15 :3 0 23 :3 0
d4 d5 0 2a
:2 0 2 :4 0 2b
:2 0 26 :2 0 24
:2 0 72 da dc
:3 0 75 d6 de
d3 e0 df :2 0
18 :3 0 27 :3 0
e2 e3 0 1a
:4 0 2c :4 0 1d
:2 0 1e :3 0 79
e7 e9 :3 0 1d
:2 0 2d :4 0 7c
eb ed :3 0 1d
:2 0 2e :4 0 7f
ef f1 :3 0 1d
:2 0 2f :3 0 30
:3 0 31 :3 0 32
:3 0 f6 f7 0
82 f5 f9 33
:4 0 84 f4 fc
87 f3 fe :3 0
8a e4 100 :2 0
102 8d 103 e1
102 0 104 8f
0 12d 15 :3 0
16 :3 0 105 106
0 15 :3 0 23
:3 0 108 109 0
24 :2 0 2 :4 0
34 :2 0 26 :2 0
24 :2 0 91 10e
110 :3 0 94 10a
112 107 114 113
:2 0 18 :3 0 27
:3 0 116 117 0
1a :4 0 35 :4 0
1d :2 0 1e :3 0
98 11b 11d :3 0
9b 118 11f :2 0
121 9e 122 115
121 0 123 a0
0 12d 36 :3 0
37 :3 0 124 125
0 31 :3 0 32
:3 0 127 128 0
38 :3 0 a2 126
12b :2 0 12d a5
12e d0 12d 0
12f a9 0 1f7
a :3 0 3 :3 0
130 131 0 1f7
f :3 0 5 :3 0
133 134 0 1f7
e :3 0 6 :3 0
136 137 0 1f7
10 :3 0 31 :3 0
39 :3 0 13a 13b
0 139 13c 0
1f7 3a :3 0 3b
:3 0 13 :3 0 d
:3 0 3c :3 0 3d
:3 0 a :4 0 3e
1 :8 0 14b 8
:3 0 3f :3 0 146
147 0 40 :3 0
148 149 0 14b
ab 195 41 :3 0
8 :3 0 3f :3 0
14e 14f 0 40
:3 0 150 151 0
18b 15 :3 0 16
:3 0 153 154 0
15 :3 0 23 :3 0
156 157 0 42
:2 0 2 :4 0 43
:2 0 26 :2 0 24
:2 0 ae 15c 15e
:3 0 b1 158 160
155 162 161 :2 0
18 :3 0 27 :3 0
164 165 0 1a
:4 0 44 :4 0 1d
:2 0 1e :3 0 b5
169 16b :3 0 1d
:2 0 2d :4 0 b8
16d 16f :3 0 1d
:2 0 45 :4 0 bb
171 173 :3 0 1d
:2 0 40 :3 0 be
175 177 :3 0 1d
:2 0 46 :4 0 c1
179 17b :3 0 1d
:2 0 47 :3 0 48
:3 0 24 :2 0 49
:2 0 c4 17e 182
c8 17d 184 :3 0
cb 166 186 :2 0
188 ce 189 163
188 0 18a d0
0 18b d2 18e
:3 0 18e 0 18e
18d 18b 18c :6 0
190 2 :3 0 d5
192 d7 191 190
:2 0 193 d9 :2 0
195 0 195 194
14b 193 :6 0 1f7
1 :3 0 c :3 0
4a :4 0 198 199
:3 0 197 19a 0
1f7 8 :3 0 3f
:3 0 19c 19d 0
4b :3 0 10 :3 0
13 :3 0 a :3 0
f :3 0 e :3 0
c :3 0 db 19f
1a6 19e 1a7 0
1f7 15 :3 0 16
:3 0 1a9 1aa 0
15 :3 0 23 :3 0
1ac 1ad 0 4c
:2 0 2 :4 0 4d
:2 0 26 :2 0 24
:2 0 e2 1b2 1b4
:3 0 e5 1ae 1b6
1ab 1b8 1b7 :2 0
18 :3 0 27 :3 0
1ba 1bb 0 1a
:4 0 4e :4 0 1d
:2 0 1e :3 0 e9
1bf 1c1 :3 0 1d
:2 0 2d :4 0 ec
1c3 1c5 :3 0 1d
:2 0 2e :4 0 ef
1c7 1c9 :3 0 1d
:2 0 2f :3 0 30
:3 0 8 :3 0 3f
:3 0 1ce 1cf 0
f2 1cd 1d1 33
:4 0 f4 1cc 1d4
f7 1cb 1d6 :3 0
1d :2 0 4f :4 0
fa 1d8 1da :3 0
1d :2 0 20 :4 0
fd 1dc 1de :3 0
1d :2 0 c :3 0
100 1e0 1e2 :3 0
1d :2 0 20 :4 0
103 1e4 1e6 :3 0
106 1bc 1e8 :2 0
1ea 109 1eb 1b9
1ea 0 1ec 10b
0 1f7 36 :3 0
50 :3 0 1ed 1ee
0 8 :3 0 3f
:3 0 1f0 1f1 0
c :3 0 38 :3 0
10d 1ef 1f5 :2 0
1f7 111 298 8
:3 0 51 :2 0 4
1f8 1f9 0 15
:3 0 16 :3 0 1fb
1fc 0 15 :3 0
23 :3 0 1fe 1ff
0 42 :2 0 2
:4 0 52 :2 0 26
:2 0 24 :2 0 11e
204 206 :3 0 121
200 208 1fd 20a
209 :2 0 18 :3 0
27 :3 0 20c 20d
0 1a :4 0 53
:4 0 1d :2 0 1e
:3 0 125 211 213
:3 0 128 20e 215
:2 0 22e 18 :3 0
27 :3 0 217 218
0 1a :4 0 54
:4 0 1d :2 0 8
:3 0 55 :3 0 21d
21e 0 12b 21c
220 :3 0 1d :2 0
4f :4 0 12e 222
224 :3 0 1d :2 0
8 :3 0 56 :3 0
227 228 0 131
226 22a :3 0 134
219 22c :2 0 22e
137 22f 20b 22e
0 230 13a 0
240 57 :3 0 14
:3 0 8 :3 0 55
:3 0 58 :3 0 8
:3 0 56 :3 0 59
:3 0 5a :4 0 5b
1 :a 0 23c :2 0
240 232 23a :2 0
7 :3 0 14 :3 0
23e :2 0 240 13c
242 140 241 240
:2 0 296 41 :3 0
8 :3 0 3f :3 0
245 246 0 40
:3 0 247 248 0
28e 15 :3 0 16
:3 0 24a 24b 0
15 :3 0 23 :3 0
24d 24e 0 42
:2 0 2 :4 0 5c
:2 0 26 :2 0 24
:2 0 142 253 255
:3 0 145 24f 257
24c 259 258 :2 0
18 :3 0 27 :3 0
25b 25c 0 1a
:4 0 5d :4 0 1d
:2 0 1e :3 0 149
260 262 :3 0 14c
25d 264 :2 0 27e
18 :3 0 27 :3 0
266 267 0 1a
:4 0 45 :4 0 1d
:2 0 40 :3 0 14f
26b 26d :3 0 1d
:2 0 46 :4 0 152
26f 271 :3 0 1d
:2 0 47 :3 0 48
:3 0 24 :2 0 49
:2 0 155 274 278
159 273 27a :3 0
15c 268 27c :2 0
27e 15f 27f 25a
27e 0 280 162
0 28e 57 :3 0
14 :3 0 58 :3 0
8 :3 0 56 :3 0
59 :3 0 5a :4 0
5e 1 :a 0 28a
:2 0 28e 282 288
:2 0 7 :3 0 14
:3 0 28c :2 0 28e
164 291 :3 0 291
0 291 290 28e
28f :6 0 293 1
:3 0 169 295 16b
294 293 :2 0 296
16d :2 0 298 170
298 297 1f7 296
:6 0 299 :2 0 2
14 298 29c :3 0
29b 299 29d :8 0

179
4
:3 0 1 3 1
7 1 b 3
6 a e 1
18 1 16 1
1f 1 1d 1
26 1 24 1
2d 1 2b 1
34 1 32 1
39 1 3f 1
45 1 52 1
5e 2 61 63
2 66 68 2
6a 6c 2 6e
70 2 72 74
2 76 78 2
7a 7c 2 7e
80 2 82 84
2 86 88 2
8a 8c 2 8e
90 2 92 94
4 5a 60 65
96 1 98 1
9a 2 a4 a6
3 a2 a3 a8
2 b1 b3 2
b0 b5 1 b7
1 b9 1 bb
1 c1 1 c9
2 d9 db 3
d7 d8 dd 2
e6 e8 2 ea
ec 2 ee f0
1 f8 2 fa
fb 2 f2 fd
2 e5 ff 1
101 1 103 2
10d 10f 3 10b
10c 111 2 11a
11c 2 119 11e
1 120 1 122
2 129 12a 3
104 123 12c 1
12e 2 145 14a
2 15b 15d 3
159 15a 15f 2
168 16a 2 16c
16e 2 170 172
2 174 176 2
178 17a 3 17f
180 181 2 17c
183 2 167 185
1 187 1 189
2 152 18a 1
18e 1 14d 1
192 6 1a0 1a1
1a2 1a3 1a4 1a5
2 1b1 1b3 3
1af 1b0 1b5 2
1be 1c0 2 1c2
1c4 2 1c6 1c8
1 1d0 2 1d2
1d3 2 1ca 1d5
2 1d7 1d9 2
1db 1dd 2 1df
1e1 2 1e3 1e5
2 1bd 1e7 1
1e9 1 1eb 3
1f2 1f3 1f4 c
9b ba 12f 132
135 138 13d 195
19b 1a8 1ec 1f6
2 203 205 3
201 202 207 2
210 212 2 20f
214 2 21b 21f
2 221 223 2
225 229 2 21a
22b 2 216 22d
1 22f 3 230
23b 23f 1 1fa
2 252 254 3
250 251 256 2
25f 261 2 25e
263 2 26a 26c
2 26e 270 3
275 276 277 2
272 279 2 269
27b 2 265 27d
1 27f 4 249
280 289 28d 1
291 1 244 2
242 295 8 1b
22 29 30 37
3d 43 4a 
1
4
0 
29c
0
1
14
4
c
0 1 2 1 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 
b 1 0
16 1 0
32 1 0
7 1 0
2 0 1
3f 1 0
3 1 0
1d 1 0
39 1 0
24 1 0
2b 1 0
45 1 0
0

/
SHOW ERRORS FUNCTION SP_A_TSKRES;
ALTER FUNCTION SP_A_TSKRES COMPILE DEBUG;
/*
#Stored Procedure  :SP_A_CRIRES
#Short Description :
#Description       :
#Table Name        :
#Parameters        :
#Returns           :
#Errors            :
*/
Prompt == FUNCTION SP_A_CRIRES ==
CREATE OR REPLACE FUNCTION SP_A_CRIRES wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
62
2 :e:
1FUNCTION:
1SP_A_CRIRES:
1ID001:
1VARCHAR2:
1RES_ID001:
1REC_USER001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_ELEMENT_ID:
132:
1H_RA_ID:
1H_REC_USER:
1H_RESOURCE_ID:
1H_TABLE_TYPE:
1PLS_INTEGER:
10:
1H_TYPE_ID:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_A_CRIRES(:
1':
1, :
1);:
1CHECK_TRACE:
11:
124:
1+:
1FPUT:
1               ENTER:: SP_A_CRIRES(25) :: cplan.sql(6098) :: :
1IS NULL:
18:
129:
1      RETURN_INVALID:: SP_A_CRIRES(30) :: cplan.sql(6103) :: :
1 :
1STATE:: :
1COALESCE:
1TO_CHAR:
1PMO_CNST:
1INVALID_PARAMS:
1NULL:
1                EXIT:: SP_A_CRIRES(33) :: cplan.sql(6106) :: :
1PMODEFINES:
1PMO_RETURN_INVALID_SP:
1TRUE:
1TYPE_ID:
1TMT_WBS:
1ELEMENT_ID:
1SELECT TYPE_ID INTO h_type_id FROM TMT_WBS WHERE ELEMENT_ID = h_element_id:
1SC_STATE:
1SQLCODE:
1OTHERS:
116:
151:
1           EXCEPTION:: SP_A_CRIRES(52) :: cplan.sql(6125) :: :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1=:
1SC_SQL_NO_DATA:
1TMT_CRI:
1SELECT TYPE_ID INTO h_type_id FROM TMT_CRI WHERE ELEMENT_ID = h_element_id:
166:
1           EXCEPTION:: SP_A_CRIRES(67) :: cplan.sql(6140) :: :
1SC_TABLE_CRI:
1SC_TABLE_WBS:
1SYS_GUID:
1ASSIGNRESOURCE:
14:
182:
1       RETURN_STATUS:: SP_A_CRIRES(83) :: cplan.sql(6156) :: :
1 ID:: :
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
189:
1           EXCEPTION:: SP_A_CRIRES(90) :: cplan.sql(6163) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1ID:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
1101:
1           EXCEPTION:: SP_A_CRIRES(102) :: cplan.sql(6175) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
300
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 :2 a0 6b 1c
81 b0 :2 a0 6b :2 a0 6b 6e a5
b a 10 :2 a0 6b 6e :2 a0 6b
6e a5 b 6e 7e a0 b4 2e
6e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c a0 7e b4 2e :2 5a a0 7e
b4 2e :2 5a 52 10 a0 7e b4
2e :2 5a 52 10 :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :4 a0 6b a5 b 6e
a5 b b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
a0 a5 57 b7 19 3c :2 a0 d
:2 a0 d :2 a0 d :5 a0 12a :2 a0 6b
a0 d b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
6b a0 7e a0 6b b4 2e 5a
:5 a0 12a :2 a0 6b a0 d b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :3 a0 6b d b7 :3 a0
6b d b7 :2 19 3c :2 a0 b4 2e
d :2 a0 6b :7 a0 a5 b d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
:2 a0 a5 57 b7 :2 a0 6b :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 :2 a0 6b
:2 6e 7e :2 a0 6b b4 2e 7e 6e
b4 2e 7e :2 a0 6b b4 2e a5
57 b7 19 3c :9 a0 12a e9 dd
:2 a0 65 b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c :7 a0 12a e9 dd :2 a0 65
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 68 4f 1d 17 b5 
300
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 30
56 5a 5e 62 65 69 86 71
75 78 79 81 70 a3 91 6d
95 96 9e 90 c0 ae 8d b2
b3 bb ad dd cb aa cf d0
d8 ca f9 e8 ec c7 f4 e7
115 104 108 e4 110 103 135 120
124 100 128 130 11f 13c 140 11c
144 148 14c 14f 154 155 1 157
15c 160 164 167 16c 170 174 177
17c 17d 17f 184 187 18b 18c 191
196 199 19e 19f 1a4 1a7 1ab 1ac
1b1 1b4 1b9 1ba 1bf 1c2 1c7 1c8
1cd 1d0 1d5 1d6 1db 1de 1e2 1e3
1e8 1eb 1f0 1f1 1f6 1f9 1fe 1ff
204 207 20c 20d 212 215 219 21a
21f 222 227 228 22d 230 235 236
23b 23c 241 243 247 24a 24e 252
255 259 25d 260 263 268 26b 26e
271 272 277 278 1 27a 27f 283
287 28a 28f 294 297 29b 29c 2a1
2a2 2a7 2a9 2ad 2b0 2b4 2b7 2b8
2bd 2c0 2c3 2c7 2ca 2cb 2d0 2d3
1 2d6 2db 2df 2e2 2e3 2e8 2eb
1 2ee 2f3 2f7 2fb 2fe 302 306
309 30c 311 314 317 31a 31b 320
321 1 323 328 32c 330 333 338
33d 340 344 345 34a 34d 352 353
358 35b 360 361 366 369 36d 371
375 379 37c 37d 37f 384 385 387
388 38d 38e 393 395 399 39c 3a0
3a4 3a7 3ab 3af 3b2 3b5 3ba 3bd
3c0 3c3 3c4 3c9 3ca 1 3cc 3d1
3d5 3d9 3dc 3e1 3e6 3e9 3ed 3ee
3f3 3f4 3f9 3fb 3ff 402 406 40a
40d 411 415 418 41c 41d 422 424
428 42b 42f 433 437 43b 43f 443
447 44b 44f 453 457 45b 45f 463
46f 473 477 47a 47e 482 484 1
488 48c 490 493 497 49b 49f 4a3
4a6 4aa 4ae 4b1 4b4 4b9 4bc 4bf
4c2 4c3 4c8 4c9 1 4cb 4d0 4d4
4d8 4db 4e0 4e5 4e8 4ec 4ed 4f2
4f5 4fa 4fb 500 503 508 509 50e
511 515 516 51b 51e 523 524 529
52c 530 534 537 53a 53b 53d 53e
543 544 549 54b 54f 552 554 558
55a 566 568 56a 56b 570 574 576
582 584 588 58c 58f 593 596 59a
59d 59e 5a3 5a6 5aa 5ae 5b2 5b6
5ba 5c6 5ca 5ce 5d1 5d5 5d9 5db
1 5df 5e3 5e7 5ea 5ee 5f2 5f6
5fa 5fd 601 605 608 60b 610 613
616 619 61a 61f 620 1 622 627
62b 62f 632 637 63c 63f 643 644
649 64c 651 652 657 65a 65f 660
665 668 66c 66d 672 675 67a 67b
680 683 687 68b 68e 691 692 694
695 69a 69b 6a0 6a2 6a6 6a9 6ab
6af 6b1 6bd 6bf 6c1 6c2 6c7 6cb
6cd 6d9 6db 6df 6e3 6e7 6ea 6ee
6f0 6f4 6f8 6fc 6ff 703 705 709
70d 710 714 718 719 71e 722 726
72a 72d 731 735 739 73d 741 745
749 74a 74c 750 754 758 75b 75f
763 766 769 76e 771 774 777 778
77d 77e 1 780 785 789 78d 790
795 79a 79d 7a1 7a2 7a7 7aa 7af
7b0 7b5 7b8 7bd 7be 7c3 7c6 7ca
7ce 7d2 7d6 7d9 7da 7dc 7e1 7e2
7e4 7e5 7ea 7ed 7f2 7f3 7f8 7fb
800 801 806 809 80d 80e 813 816
81b 81c 821 822 827 829 82d 830
834 838 83b 83f 843 846 84a 84e
84f 854 856 85a 85e 861 865 869
86c 870 874 877 87a 87f 882 885
888 889 88e 88f 1 891 896 89a
89e 8a1 8a6 8ab 8ae 8b2 8b3 8b8
8b9 8be 8c2 8c6 8c9 8ce 8d3 8d6
8da 8de 8e1 8e2 8e7 8ea 8ef 8f0
8f5 8f8 8fc 900 903 904 909 90a
90f 911 915 918 91c 920 924 928
92c 930 934 938 93c 948 94d 951
955 959 95d 95f 960 965 1 969
96d 971 974 978 97c 980 984 987
98b 98f 992 995 99a 99d 9a0 9a3
9a4 9a9 9aa 1 9ac 9b1 9b5 9b9
9bc 9c1 9c6 9c9 9cd 9ce 9d3 9d4
9d9 9dd 9e1 9e4 9e9 9ee 9f1 9f5
9f6 9fb 9fe a03 a04 a09 a0c a10
a14 a17 a1a a1b a1d a1e a23 a24
a29 a2b a2f a32 a36 a3a a3e a42
a46 a4a a4e a5a a5f a63 a67 a6b
a6f a71 a75 a77 a83 a85 a87 a88
a8d a91 a93 a9f aa3 aa5 aa6 aaf 
300
2
0 1 a 6 c :3 6 10 :3 6
12 :2 6 1 3 a 13 a :2 1
4 11 1a 19 :2 11 :2 4 c 15
14 :2 c :2 4 f 18 17 :2 f :2 4
12 1b 1a :2 12 :2 4 :2 11 20 11
:2 4 :2 e 1d e :2 4 e 17 :3 e
4 7 :2 11 23 :2 2d 3a :2 23 :3 7
:2 d 19 25 :2 2f 43 :2 25 53 59
5c :2 53 6a 7f 8 :2 6a d 10
:2 6a 16 19 :2 6a b e :2 6a 13
16 :2 6a 1b 1e :2 6a 28 2b :2 6a
b e :2 6a 13 16 :2 6a 1b 1e
:2 6a 2a 2d :2 6a 32 35 :2 6a :2 7
49 :2 4 7 :2 11 23 :2 2d 39 3c
4b 4d 4e :2 4b :2 23 :3 7 :2 d 12
1e 5b 5e :2 1e :2 7 51 :2 4 :4 9
8 7 :4 1e 1d 1c :2 7 :4 37 36
35 :2 7 a :2 14 26 :2 30 3c 3f
4e 50 51 :2 4e :2 26 :3 a :2 10 15
21 5e 61 :2 21 6e 71 :2 21 75
78 :2 21 82 85 8e 96 :2 9f :2 8e
b0 :2 85 :2 21 :2 a 54 :2 7 a :2 14
26 :2 30 3c 3f 4e 50 51 :2 4e
:2 26 :3 a :2 10 15 21 5e 61 :2 21
:2 a 54 :3 7 :2 12 28 :2 31 41 :2 7
4d :3 4 14 :2 4 15 :2 4 12 4
e 1b 2a 38 45 :2 7 :2 10 1c
7 4 :2 c a :2 13 1f a d
:2 17 29 :2 33 3f 43 52 54 55
:2 52 :2 29 :3 d :2 13 18 24 61 64
:2 24 71 74 :2 24 78 7b :2 24 87
8a :2 24 92 95 :2 24 a1 a4 ab
b4 b7 :2 a4 :2 24 :2 d 58 :2 a :2 7
:4 13 :2 7 4 :3 1 8 :2 11 1c 1a
:2 25 :2 1a 7 11 1e 2d 3b 48
:2 a :2 13 1f a 7 :2 f d :2 16
22 d 10 :2 1a 2c :2 36 42 46
55 57 58 :2 55 :2 2c :3 10 :2 16 1b
27 64 67 :2 27 74 77 :2 27 7b
7e :2 27 8a 8d :2 27 95 98 :2 27
a4 a7 ae b7 ba :2 a7 :2 27 :2 10
5b :2 d :2 a :4 16 :2 a 7 :3 35 7
17 :2 20 7 35 7 17 :2 20 7
:5 4 :3 f :2 4 :2 d 19 28 36 41
4f 5e 27 :2 19 4 7 :2 11 23
:2 2d 39 3c 4b 4d 4e :2 4b :2 23
:3 7 :2 d 12 1e 5b 5e :2 1e 6b
6e :2 1e 72 75 :2 1e 7f 82 8b
93 :2 9c :2 8b a7 :2 82 :2 1e af b2
:2 1e ba bd :2 1e c2 c5 :2 1e cd
d0 :2 1e :2 7 51 :3 4 :2 f 21 :2 2a
34 3d :2 4 1 9 12 9 a
:2 14 26 :2 30 3c 40 4f 51 52
:2 4f :2 26 :3 a :2 10 15 21 5e 61
:2 21 :3 a :2 10 15 39 5c 5f :2 68
:2 39 76 79 :2 39 81 84 :2 8d :2 39
:2 a 55 :3 7 c 15 1e 2c a
13 1e f e 7 e 7 e
7 29 :2 4 :2 9 7 :2 10 1c :2 7
:2 11 23 :2 2d 39 3d 4c 4f 50
:2 4c :2 23 :3 7 :2 d 12 1e 5c 5f
:2 1e :3 7 :2 d 12 36 42 45 :2 36
4d 50 :2 36 5c 5f 66 6f 72
:2 5f :2 36 :2 7 53 :2 4 7 c 1b
a 13 1e f e 7 e 7
e 7 :2 4 :4 10 :2 4 :8 1 
300
4
0 :2 1 :4 3 :4 4
:4 5 2 :4 6 :2 1
:7 8 :7 9 :7 a :7 b
:6 c :6 d :7 f :b 11
:11 12 13 :2 12 :2 13
:2 12 :2 13 :2 12 :2 14
:2 12 :2 14 :2 12 :2 14
:2 12 :2 14 :2 12 :2 15
:2 12 :2 15 :2 12 :2 15
:2 12 :2 15 :2 12 :2 15
:4 12 :3 11 :11 18 :b 19
:3 18 :16 1c :11 1d :20 1e
:3 1d :11 20 :b 21 :3 20
:9 23 :3 1c :3 28 :3 29
:3 2a :6 2d :5 2e 2c
:2 30 :5 32 :11 33 :24 34
:3 33 :2 31 :6 30 2f
:3 10 :a 3a :6 3c :5 3d
3b :2 3f :5 41 :11 42
:24 43 :3 42 :2 40 :6 3f
3e :3 3a :5 48 3a
:5 4a 49 :3 3a :5 4d
:9 4f 50 :3 4f :11 52
:30 53 :3 52 :a 55 10
:3 58 :11 59 :b 5a :17 5b
:3 59 :2 5d :3 5e :3 5f
60 5e 5d 5e
:3 61 :3 58 :2 62 :5 64
:11 65 :b 66 :18 67 :3 65
:2 69 6a :3 6b 6c
6a 69 6a :3 6d
:2 63 :6 62 57 :7 1

ab1
4
:3 0 1 :3 0 2
:a 0 2fb 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
:2 0 7 4 :3 0
5 :7 0 9 8
:3 0 4 :3 0 6
:7 0 d c :3 0
7 :3 0 8 :3 0
9 :2 0 4 11
12 0 f 13
0 2fb 2 14
:2 0 b :2 0 f
4 :3 0 b :2 0
d 17 19 :6 0
1c 1a 0 2f9
0 a :6 0 b
:2 0 13 4 :3 0
11 1e 20 :6 0
23 21 0 2f9
0 c :6 0 b
:2 0 17 4 :3 0
15 25 27 :6 0
2a 28 0 2f9
0 d :6 0 11
:2 0 1b 4 :3 0
19 2c 2e :6 0
31 2f 0 2f9
0 e :6 0 11
:2 0 1d 10 :3 0
33 :7 0 37 34
35 2f9 0 f
:6 0 3f 40 0
1f 10 :3 0 39
:7 0 3d 3a 3b
2f9 0 12 :6 0
45 46 0 21
8 :3 0 9 :2 0
4 41 :7 0 44
42 0 2f9 0
13 :6 0 14 :3 0
15 :3 0 14 :3 0
16 :3 0 48 49
0 2 :4 0 23
4a 4c 47 4e
4d :2 0 17 :3 0
18 :3 0 50 51
0 19 :4 0 14
:3 0 1a :3 0 54
55 0 2 :4 0
25 56 58 1b
:4 0 1c :2 0 1d
:3 0 27 5b 5d
:3 0 1e :4 0 1c
:2 0 1f :4 0 2a
60 62 :3 0 1c
:2 0 3 :3 0 2d
64 66 :3 0 1c
:2 0 1f :4 0 30
68 6a :3 0 1c
:2 0 20 :4 0 33
6c 6e :3 0 1c
:2 0 1f :4 0 36
70 72 :3 0 1c
:2 0 5 :3 0 39
74 76 :3 0 1c
:2 0 1f :4 0 3c
78 7a :3 0 1c
:2 0 20 :4 0 3f
7c 7e :3 0 1c
:2 0 1f :4 0 42
80 82 :3 0 1c
:2 0 6 :3 0 45
84 86 :3 0 1c
:2 0 1f :4 0 48
88 8a :3 0 1c
:2 0 21 :4 0 4b
8c 8e :3 0 4e
52 90 :2 0 92
53 93 4f 92
0 94 55 0
259 14 :3 0 15
:3 0 95 96 0
14 :3 0 22 :3 0
98 99 0 23
:2 0 2 :4 0 24
:2 0 25 :2 0 23
:2 0 57 9e a0
:3 0 5a 9a a2
97 a4 a3 :2 0
17 :3 0 26 :3 0
a6 a7 0 19
:4 0 27 :4 0 1c
:2 0 1d :3 0 5e
ab ad :3 0 61
a8 af :2 0 b1
64 b2 a5 b1
0 b3 66 0
259 3 :3 0 28
:2 0 68 b5 b6
:3 0 b7 :2 0 b8
:2 0 5 :3 0 28
:2 0 6a bb bc
:3 0 bd :2 0 be
:2 0 b9 c0 bf
:2 0 6 :3 0 28
:2 0 6c c3 c4
:3 0 c5 :2 0 c6
:2 0 c1 c8 c7
:2 0 14 :3 0 15
:3 0 ca cb 0
14 :3 0 22 :3 0
cd ce 0 29
:2 0 2 :4 0 2a
:2 0 25 :2 0 23
:2 0 6e d3 d5
:3 0 71 cf d7
cc d9 d8 :2 0
17 :3 0 26 :3 0
db dc 0 19
:4 0 2b :4 0 1c
:2 0 1d :3 0 75
e0 e2 :3 0 1c
:2 0 2c :4 0 78
e4 e6 :3 0 1c
:2 0 2d :4 0 7b
e8 ea :3 0 1c
:2 0 2e :3 0 2f
:3 0 30 :3 0 31
:3 0 ef f0 0
7e ee f2 32
:4 0 80 ed f5
83 ec f7 :3 0
86 dd f9 :2 0
fb 89 fc da
fb 0 fd 8b
0 126 14 :3 0
15 :3 0 fe ff
0 14 :3 0 22
:3 0 101 102 0
23 :2 0 2 :4 0
b :2 0 25 :2 0
23 :2 0 8d 107
109 :3 0 90 103
10b 100 10d 10c
:2 0 17 :3 0 26
:3 0 10f 110 0
19 :4 0 33 :4 0
1c :2 0 1d :3 0
94 114 116 :3 0
97 111 118 :2 0
11a 9a 11b 10e
11a 0 11c 9c
0 126 34 :3 0
35 :3 0 11d 11e
0 30 :3 0 31
:3 0 120 121 0
36 :3 0 9e 11f
124 :2 0 126 a1
127 c9 126 0
128 a5 0 259
a :3 0 3 :3 0
129 12a 0 259
e :3 0 5 :3 0
12c 12d 0 259
d :3 0 6 :3 0
12f 130 0 259
37 :3 0 12 :3 0
38 :3 0 39 :3 0
a :4 0 3a 1
:8 0 13d 8 :3 0
3b :3 0 138 139
0 3c :3 0 13a
13b 0 13d a7
187 3d :3 0 8
:3 0 3b :3 0 140
141 0 3c :3 0
142 143 0 17d
14 :3 0 15 :3 0
145 146 0 14
:3 0 22 :3 0 148
149 0 3e :2 0
2 :4 0 3f :2 0
25 :2 0 23 :2 0
aa 14e 150 :3 0
ad 14a 152 147
154 153 :2 0 17
:3 0 26 :3 0 156
157 0 19 :4 0
40 :4 0 1c :2 0
1d :3 0 b1 15b
15d :3 0 1c :2 0
2c :4 0 b4 15f
161 :3 0 1c :2 0
41 :4 0 b7 163
165 :3 0 1c :2 0
3c :3 0 ba 167
169 :3 0 1c :2 0
42 :4 0 bd 16b
16d :3 0 1c :2 0
43 :3 0 44 :3 0
23 :2 0 45 :2 0
c0 170 174 c4
16f 176 :3 0 c7
158 178 :2 0 17a
ca 17b 155 17a
0 17c cc 0
17d ce 180 :3 0
180 0 180 17f
17d 17e :6 0 182
2 :3 0 d1 184
d3 183 182 :2 0
185 d5 :2 0 187
0 187 186 13d
185 :6 0 259 1
:3 0 8 :3 0 3b
:3 0 189 18a 0
8 :3 0 46 :2 0
47 :3 0 18c 18e
0 d9 18d 190
:3 0 191 :2 0 37
:3 0 12 :3 0 48
:3 0 39 :3 0 a
:4 0 49 1 :8 0
19e 8 :3 0 3b
:3 0 199 19a 0
3c :3 0 19b 19c
0 19e dc 1e8
3d :3 0 8 :3 0
3b :3 0 1a1 1a2
0 3c :3 0 1a3
1a4 0 1de 14
:3 0 15 :3 0 1a6
1a7 0 14 :3 0
22 :3 0 1a9 1aa
0 3e :2 0 2
:4 0 4a :2 0 25
:2 0 23 :2 0 df
1af 1b1 :3 0 e2
1ab 1b3 1a8 1b5
1b4 :2 0 17 :3 0
26 :3 0 1b7 1b8
0 19 :4 0 4b
:4 0 1c :2 0 1d
:3 0 e6 1bc 1be
:3 0 1c :2 0 2c
:4 0 e9 1c0 1c2
:3 0 1c :2 0 41
:4 0 ec 1c4 1c6
:3 0 1c :2 0 3c
:3 0 ef 1c8 1ca
:3 0 1c :2 0 42
:4 0 f2 1cc 1ce
:3 0 1c :2 0 43
:3 0 44 :3 0 23
:2 0 45 :2 0 f5
1d1 1d5 f9 1d0
1d7 :3 0 fc 1b9
1d9 :2 0 1db ff
1dc 1b6 1db 0
1dd 101 0 1de
103 1e1 :3 0 1e1
0 1e1 1e0 1de
1df :6 0 1e3 4
:3 0 106 1e5 108
1e4 1e3 :2 0 1e6
10a :2 0 1e8 0
1e8 1e7 19e 1e6
:6 0 1ef 1 :3 0
f :3 0 30 :3 0
4c :3 0 1eb 1ec
0 1ea 1ed 0
1ef 10c 1f6 f
:3 0 30 :3 0 4d
:3 0 1f1 1f2 0
1f0 1f3 0 1f5
10f 1f7 192 1ef
0 1f8 0 1f5
0 1f8 111 0
259 c :3 0 4e
:4 0 1fa 1fb :3 0
1f9 1fc 0 259
8 :3 0 3b :3 0
1fe 1ff 0 4f
:3 0 f :3 0 12
:3 0 a :3 0 e
:3 0 d :3 0 c
:3 0 114 201 208
200 209 0 259
14 :3 0 15 :3 0
20b 20c 0 14
:3 0 22 :3 0 20e
20f 0 50 :2 0
2 :4 0 51 :2 0
25 :2 0 23 :2 0
11b 214 216 :3 0
11e 210 218 20d
21a 219 :2 0 17
:3 0 26 :3 0 21c
21d 0 19 :4 0
52 :4 0 1c :2 0
1d :3 0 122 221
223 :3 0 1c :2 0
2c :4 0 125 225
227 :3 0 1c :2 0
2d :4 0 128 229
22b :3 0 1c :2 0
2e :3 0 2f :3 0
8 :3 0 3b :3 0
230 231 0 12b
22f 233 32 :4 0
12d 22e 236 130
22d 238 :3 0 1c
:2 0 53 :4 0 133
23a 23c :3 0 1c
:2 0 1f :4 0 136
23e 240 :3 0 1c
:2 0 c :3 0 139
242 244 :3 0 1c
:2 0 1f :4 0 13c
246 248 :3 0 13f
21e 24a :2 0 24c
142 24d 21b 24c
0 24e 144 0
259 34 :3 0 54
:3 0 24f 250 0
8 :3 0 3b :3 0
252 253 0 c
:3 0 36 :3 0 146
251 257 :2 0 259
14a 2fa 8 :3 0
55 :2 0 4 25a
25b 0 14 :3 0
15 :3 0 25d 25e
0 14 :3 0 22
:3 0 260 261 0
3e :2 0 2 :4 0
56 :2 0 25 :2 0
23 :2 0 157 266
268 :3 0 15a 262
26a 25f 26c 26b
:2 0 17 :3 0 26
:3 0 26e 26f 0
19 :4 0 57 :4 0
1c :2 0 1d :3 0
15e 273 275 :3 0
161 270 277 :2 0
290 17 :3 0 26
:3 0 279 27a 0
19 :4 0 58 :4 0
1c :2 0 8 :3 0
59 :3 0 27f 280
0 164 27e 282
:3 0 1c :2 0 53
:4 0 167 284 286
:3 0 1c :2 0 8
:3 0 5a :3 0 289
28a 0 16a 288
28c :3 0 16d 27b
28e :2 0 290 170
291 26d 290 0
292 173 0 2a2
5b :3 0 13 :3 0
8 :3 0 59 :3 0
5c :3 0 8 :3 0
5a :3 0 5d :3 0
5e :4 0 5f 1
:a 0 29e :2 0 2a2
294 29c :2 0 7
:3 0 13 :3 0 2a0
:2 0 2a2 175 2a4
179 2a3 2a2 :2 0
2f8 3d :3 0 8
:3 0 3b :3 0 2a7
2a8 0 3c :3 0
2a9 2aa 0 2f0
14 :3 0 15 :3 0
2ac 2ad 0 14
:3 0 22 :3 0 2af
2b0 0 3e :2 0
2 :4 0 60 :2 0
25 :2 0 23 :2 0
17b 2b5 2b7 :3 0
17e 2b1 2b9 2ae
2bb 2ba :2 0 17
:3 0 26 :3 0 2bd
2be 0 19 :4 0
61 :4 0 1c :2 0
1d :3 0 182 2c2
2c4 :3 0 185 2bf
2c6 :2 0 2e0 17
:3 0 26 :3 0 2c8
2c9 0 19 :4 0
41 :4 0 1c :2 0
3c :3 0 188 2cd
2cf :3 0 1c :2 0
42 :4 0 18b 2d1
2d3 :3 0 1c :2 0
43 :3 0 44 :3 0
23 :2 0 45 :2 0
18e 2d6 2da 192
2d5 2dc :3 0 195
2ca 2de :2 0 2e0
198 2e1 2bc 2e0
0 2e2 19b 0
2f0 5b :3 0 13
:3 0 5c :3 0 8
:3 0 5a :3 0 5d
:3 0 5e :4 0 62
1 :a 0 2ec :2 0
2f0 2e4 2ea :2 0
7 :3 0 13 :3 0
2ee :2 0 2f0 19d
2f3 :3 0 2f3 0
2f3 2f2 2f0 2f1
:6 0 2f5 1 :3 0
1a2 2f7 1a4 2f6
2f5 :2 0 2f8 1a6
:2 0 2fa 1a9 2fa
2f9 259 2f8 :6 0
2fb :2 0 2 14
2fa 2fe :3 0 2fd
2fb 2ff :8 0 
1b1
4
:3 0 1 3 1
7 1 b 3
6 a e 1
18 1 16 1
1f 1 1d 1
26 1 24 1
2d 1 2b 1
32 1 38 1
3e 1 4b 1
57 2 5a 5c
2 5f 61 2
63 65 2 67
69 2 6b 6d
2 6f 71 2
73 75 2 77
79 2 7b 7d
2 7f 81 2
83 85 2 87
89 2 8b 8d
4 53 59 5e
8f 1 91 1
93 2 9d 9f
3 9b 9c a1
2 aa ac 2
a9 ae 1 b0
1 b2 1 b4
1 ba 1 c2
2 d2 d4 3
d0 d1 d6 2
df e1 2 e3
e5 2 e7 e9
1 f1 2 f3
f4 2 eb f6
2 de f8 1
fa 1 fc 2
106 108 3 104
105 10a 2 113
115 2 112 117
1 119 1 11b
2 122 123 3
fd 11c 125 1
127 2 137 13c
2 14d 14f 3
14b 14c 151 2
15a 15c 2 15e
160 2 162 164
2 166 168 2
16a 16c 3 171
172 173 2 16e
175 2 159 177
1 179 1 17b
2 144 17c 1
180 1 13f 1
184 1 18f 2
18b 18f 2 198
19d 2 1ae 1b0
3 1ac 1ad 1b2
2 1bb 1bd 2
1bf 1c1 2 1c3
1c5 2 1c7 1c9
2 1cb 1cd 3
1d2 1d3 1d4 2
1cf 1d6 2 1ba
1d8 1 1da 1
1dc 2 1a5 1dd
1 1e1 1 1a0
1 1e5 2 1e8
1ee 1 1f4 2
1f6 1f7 6 202
203 204 205 206
207 2 213 215
3 211 212 217
2 220 222 2
224 226 2 228
22a 1 232 2
234 235 2 22c
237 2 239 23b
2 23d 23f 2
241 243 2 245
247 2 21f 249
1 24b 1 24d
3 254 255 256
c 94 b3 128
12b 12e 131 187
1f8 1fd 20a 24e
258 2 265 267
3 263 264 269
2 272 274 2
271 276 2 27d
281 2 283 285
2 287 28b 2
27c 28d 2 278
28f 1 291 3
292 29d 2a1 1
25c 2 2b4 2b6
3 2b2 2b3 2b8
2 2c1 2c3 2
2c0 2c5 2 2cc
2ce 2 2d0 2d2
3 2d7 2d8 2d9
2 2d4 2db 2
2cb 2dd 2 2c7
2df 1 2e1 4
2ab 2e2 2eb 2ef
1 2f3 1 2a6
2 2a4 2f7 7
1b 22 29 30
36 3c 43 
1
4
0 
2fe
0
1
14
6
b
0 1 2 1 4 1 0 0
0 0 0 0 0 0 0 0
0 0 0 0 
b 1 0
16 1 0
2b 1 0
7 1 0
38 1 0
3 1 0
2 0 1
1d 1 0
32 1 0
24 1 0
3e 1 0
0

/
SHOW ERRORS FUNCTION SP_A_CRIRES;
ALTER FUNCTION SP_A_CRIRES COMPILE DEBUG;
/***************************************************************************************************/
/*
#Stored Procedure  :SP_A_REQRES
#Short Description :
#Description       :
#Table Name        :
#Parameters        :
#Returns           :
#Errors            :
*/
Prompt == FUNCTION SP_A_REQRES ==
CREATE OR REPLACE FUNCTION SP_A_REQRES wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
59
2 :e:
1FUNCTION:
1SP_A_REQRES:
1ID001:
1VARCHAR2:
1RES_ID001:
1REC_USER001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_ELEMENT_ID:
132:
1H_RA_ID:
1H_REC_USER:
1H_RESOURCE_ID:
1H_TYPE_ID:
1PLS_INTEGER:
10:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_A_REQRES(:
1':
1, :
1);:
1CHECK_TRACE:
11:
123:
1+:
1FPUT:
1               ENTER:: SP_A_REQRES(24) :: cplan.sql(6225) :: :
1IS NULL:
18:
128:
1      RETURN_INVALID:: SP_A_REQRES(29) :: cplan.sql(6230) :: :
1 :
1STATE:: :
1COALESCE:
1TO_CHAR:
1PMO_CNST:
1INVALID_PARAMS:
1NULL:
131:
1                EXIT:: SP_A_REQRES(32) :: cplan.sql(6233) :: :
1PMODEFINES:
1PMO_RETURN_INVALID_SP:
1TRUE:
1TYPE_ID:
1TMT_WBS:
1ELEMENT_ID:
1SELECT TYPE_ID INTO h_type_id FROM TMT_WBS WHERE ELEMENT_ID = h_element_id:
1SC_STATE:
1SQLCODE:
1OTHERS:
116:
150:
1           EXCEPTION:: SP_A_REQRES(51) :: cplan.sql(6252) :: :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1SYS_GUID:
14:
162:
1       RETURN_STATUS:: SP_A_REQRES(63) :: cplan.sql(6264) :: :
1 ID:: :
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
169:
1           EXCEPTION:: SP_A_REQRES(70) :: cplan.sql(6271) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1ID:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
181:
1           EXCEPTION:: SP_A_REQRES(82) :: cplan.sql(6283) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
27b
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 1c 51 81 b0 a3 :2 a0
6b 1c 81 b0 :2 a0 6b :2 a0 6b
6e a5 b a 10 :2 a0 6b 6e
:2 a0 6b 6e a5 b 6e 7e a0
b4 2e 6e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c a0 7e b4 2e 5a
a0 7e b4 2e 5a 52 10 a0
7e b4 2e :2 5a 52 10 :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b a0 a5 57 b7 19 3c
:2 a0 d :2 a0 d :2 a0 d :5 a0 12a
:2 a0 6b a0 d b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 b4 2e d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b :2 a0 a5
57 b7 :2 a0 6b :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 :2 a0 6b :2 6e 7e
:2 a0 6b b4 2e 7e 6e b4 2e
7e :2 a0 6b b4 2e a5 57 b7
19 3c :9 a0 12a e9 dd :2 a0 65
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
:7 a0 12a e9 dd :2 a0 65 b7 a4
b1 11 4f b7 a6 9 a4 b1
11 68 4f 1d 17 b5 
27b
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 30
56 5a 5e 62 65 69 86 71
75 78 79 81 70 a3 91 6d
95 96 9e 90 c0 ae 8d b2
b3 bb ad dd cb aa cf d0
d8 ca f9 e8 ec c7 f4 e7
119 104 108 e4 10c 114 103 120
124 100 128 12c 130 133 138 139
1 13b 140 144 148 14b 150 154
158 15b 160 161 163 168 16b 16f
170 175 17a 17d 182 183 188 18b
18f 190 195 198 19d 19e 1a3 1a6
1ab 1ac 1b1 1b4 1b9 1ba 1bf 1c2
1c6 1c7 1cc 1cf 1d4 1d5 1da 1dd
1e2 1e3 1e8 1eb 1f0 1f1 1f6 1f9
1fd 1fe 203 206 20b 20c 211 214
219 21a 21f 220 225 227 22b 22e
232 236 239 23d 241 244 247 24c
24f 252 255 256 25b 25c 1 25e
263 267 26b 26e 273 278 27b 27f
280 285 286 28b 28d 291 294 298
29b 29c 2a1 2a4 2a8 2ab 2ac 2b1
1 2b4 2b9 2bd 2c0 2c1 2c6 2c9
1 2cc 2d1 2d5 2d9 2dc 2e0 2e4
2e7 2ea 2ef 2f2 2f5 2f8 2f9 2fe
2ff 1 301 306 30a 30e 311 316
31b 31e 322 323 328 32b 330 331
336 339 33e 33f 344 347 34b 34f
353 357 35a 35b 35d 362 363 365
366 36b 36c 371 373 377 37a 37e
382 385 389 38d 390 393 398 39b
39e 3a1 3a2 3a7 3a8 1 3aa 3af
3b3 3b7 3ba 3bf 3c4 3c7 3cb 3cc
3d1 3d2 3d7 3d9 3dd 3e0 3e4 3e8
3eb 3ef 3f3 3f6 3fa 3fb 400 402
406 409 40d 411 415 419 41d 421
425 429 42d 431 435 439 43d 441
44d 451 455 458 45c 460 462 1
466 46a 46e 471 475 479 47d 481
484 488 48c 48f 492 497 49a 49d
4a0 4a1 4a6 4a7 1 4a9 4ae 4b2
4b6 4b9 4be 4c3 4c6 4ca 4cb 4d0
4d3 4d8 4d9 4de 4e1 4e6 4e7 4ec
4ef 4f3 4f4 4f9 4fc 501 502 507
50a 50e 512 515 518 519 51b 51c
521 522 527 529 52d 530 532 536
538 544 546 548 549 54e 552 554
560 562 566 56a 56b 570 574 578
57c 57f 583 587 58a 58d 592 595
598 59b 59c 5a1 5a2 1 5a4 5a9
5ad 5b1 5b4 5b9 5be 5c1 5c5 5c6
5cb 5ce 5d3 5d4 5d9 5dc 5e1 5e2
5e7 5ea 5ee 5f2 5f6 5fa 5fd 5fe
600 605 606 608 609 60e 611 616
617 61c 61f 624 625 62a 62d 631
632 637 63a 63f 640 645 646 64b
64d 651 654 658 65c 65f 663 667
66a 66e 672 673 678 67a 67e 682
685 689 68d 690 694 698 69b 69e
6a3 6a6 6a9 6ac 6ad 6b2 6b3 1
6b5 6ba 6be 6c2 6c5 6ca 6cf 6d2
6d6 6d7 6dc 6dd 6e2 6e6 6ea 6ed
6f2 6f7 6fa 6fe 702 705 706 70b
70e 713 714 719 71c 720 724 727
728 72d 72e 733 735 739 73c 740
744 748 74c 750 754 758 75c 760
76c 771 775 779 77d 781 783 784
789 1 78d 791 795 798 79c 7a0
7a4 7a8 7ab 7af 7b3 7b6 7b9 7be
7c1 7c4 7c7 7c8 7cd 7ce 1 7d0
7d5 7d9 7dd 7e0 7e5 7ea 7ed 7f1
7f2 7f7 7f8 7fd 801 805 808 80d
812 815 819 81a 81f 822 827 828
82d 830 834 838 83b 83e 83f 841
842 847 848 84d 84f 853 856 85a
85e 862 866 86a 86e 872 87e 883
887 88b 88f 893 895 899 89b 8a7
8a9 8ab 8ac 8b1 8b5 8b7 8c3 8c7
8c9 8ca 8d3 
27b
2
0 1 a 6 c :3 6 10 :3 6
12 :2 6 1 3 a 13 a :2 1
4 11 1a 19 :2 11 :2 4 c 15
14 :2 c :2 4 f 18 17 :2 f :2 4
12 1b 1a :2 12 :2 4 :2 e 1d e
:2 4 e 17 :3 e 4 7 :2 11 23
:2 2d 3a :2 23 :3 7 :2 d 19 25 :2 2f
43 :2 25 53 59 5c :2 53 6a 7f
8 :2 6a d 10 :2 6a 16 19 :2 6a
b e :2 6a 13 16 :2 6a 1b 1e
:2 6a 28 2b :2 6a b e :2 6a 13
16 :2 6a 1b 1e :2 6a 2a 2d :2 6a
32 35 :2 6a :2 7 49 :2 4 7 :2 11
23 :2 2d 39 3c 4b 4d 4e :2 4b
:2 23 :3 7 :2 d 12 1e 5b 5e :2 1e
:2 7 51 :2 4 :4 8 7 :4 1b 1a :2 7
:4 33 32 31 :2 7 a :2 14 26 :2 30
3c 3f 4e 50 51 :2 4e :2 26 :3 a
:2 10 15 21 5e 61 :2 21 6e 71
:2 21 75 78 :2 21 82 85 8e 96
:2 9f :2 8e b0 :2 85 :2 21 :2 a 54 :2 7
a :2 14 26 :2 30 3c 3f 4e 50
51 :2 4e :2 26 :3 a :2 10 15 21 5e
61 :2 21 :2 a 54 :3 7 :2 12 28 :2 31
41 :2 7 49 :3 4 14 :2 4 15 :2 4
12 4 e 1b 2a 38 45 :2 7
:2 10 1c 7 4 :2 c a :2 13 1f
a d :2 17 29 :2 33 3f 43 52
54 55 :2 52 :2 29 :3 d :2 13 18 24
61 64 :2 24 71 74 :2 24 78 7b
:2 24 87 8a :2 24 92 95 :2 24 a1
a4 ab b4 b7 :2 a4 :2 24 :2 d 58
:2 a :2 7 :4 13 :2 7 4 :3 1 4 :3 f
4 7 :2 11 23 :2 2d 39 3c 4b
4d 4e :2 4b :2 23 :3 7 :2 d 12 1e
5b 5e :2 1e 6b 6e :2 1e 72 75
:2 1e 7f 82 8b 93 :2 9c :2 8b a7
:2 82 :2 1e af b2 :2 1e ba bd :2 1e
c2 c5 :2 1e cd d0 :2 1e :2 7 51
:3 4 :2 f 21 :2 2a 34 3d :2 4 1
9 12 9 a :2 14 26 :2 30 3c
40 4f 51 52 :2 4f :2 26 :3 a :2 10
15 21 5e 61 :2 21 :3 a :2 10 15
39 5c 5f :2 68 :2 39 76 79 :2 39
81 84 :2 8d :2 39 :2 a 55 :3 7 c
15 1e 2c a 13 1e f e
7 e 7 e 7 29 :2 4 :2 9
7 :2 10 1c :2 7 :2 11 23 :2 2d 39
3d 4c 4e 4f :2 4c :2 23 :3 7 :2 d
12 1e 5b 5e :2 1e :3 7 :2 d 12
36 42 45 :2 36 4d 50 :2 36 5c
5f 66 6f 72 :2 5f :2 36 :2 7 52
:2 4 7 c 1b a 13 1e f
e 7 e 7 e 7 :2 4 :4 10
:2 4 :8 1 
27b
4
0 :2 1 :4 3 :4 4
:4 5 2 :4 6 :2 1
:7 8 :7 9 :7 a :7 b
:6 c :7 e :b 10 :11 11
12 :2 11 :2 12 :2 11
:2 12 :2 11 :2 13 :2 11
:2 13 :2 11 :2 13 :2 11
:2 13 :2 11 :2 14 :2 11
:2 14 :2 11 :2 14 :2 11
:2 14 :2 11 :2 14 :4 11
:3 10 :11 17 :b 18 :3 17
:14 1b :11 1c :20 1d :3 1c
:11 1f :b 20 :3 1f :9 22
:3 1b :3 27 :3 28 :3 29
:6 2c :5 2d 2b :2 2f
:5 31 :11 32 :24 33 :3 32
:2 30 :6 2f 2e :3 f
:5 3a :11 3e :30 3f :3 3e
:a 41 f :3 44 :11 45
:b 46 :17 47 :3 45 :2 49
:3 4a :3 4b 4c 4a
49 4a :3 4d :3 44
:2 4e :5 50 :11 51 :b 52
:18 53 :3 51 :2 55 56
:3 57 58 56 55
56 :3 59 :2 4f :6 4e
43 :7 1 
8d5
4
:3 0 1 :3 0 2
:a 0 276 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
:2 0 7 4 :3 0
5 :7 0 9 8
:3 0 4 :3 0 6
:7 0 d c :3 0
7 :3 0 8 :3 0
9 :2 0 4 11
12 0 f 13
0 276 2 14
:2 0 b :2 0 f
4 :3 0 b :2 0
d 17 19 :6 0
1c 1a 0 274
0 a :6 0 b
:2 0 13 4 :3 0
11 1e 20 :6 0
23 21 0 274
0 c :6 0 b
:2 0 17 4 :3 0
15 25 27 :6 0
2a 28 0 274
0 d :6 0 11
:2 0 1b 4 :3 0
19 2c 2e :6 0
31 2f 0 274
0 e :6 0 39
3a 0 1d 10
:3 0 33 :7 0 37
34 35 274 0
f :6 0 3f 40
0 1f 8 :3 0
9 :2 0 4 3b
:7 0 3e 3c 0
274 0 12 :6 0
13 :3 0 14 :3 0
13 :3 0 15 :3 0
42 43 0 2
:4 0 21 44 46
41 48 47 :2 0
16 :3 0 17 :3 0
4a 4b 0 18
:4 0 13 :3 0 19
:3 0 4e 4f 0
2 :4 0 23 50
52 1a :4 0 1b
:2 0 1c :3 0 25
55 57 :3 0 1d
:4 0 1b :2 0 1e
:4 0 28 5a 5c
:3 0 1b :2 0 3
:3 0 2b 5e 60
:3 0 1b :2 0 1e
:4 0 2e 62 64
:3 0 1b :2 0 1f
:4 0 31 66 68
:3 0 1b :2 0 1e
:4 0 34 6a 6c
:3 0 1b :2 0 5
:3 0 37 6e 70
:3 0 1b :2 0 1e
:4 0 3a 72 74
:3 0 1b :2 0 1f
:4 0 3d 76 78
:3 0 1b :2 0 1e
:4 0 40 7a 7c
:3 0 1b :2 0 6
:3 0 43 7e 80
:3 0 1b :2 0 1e
:4 0 46 82 84
:3 0 1b :2 0 20
:4 0 49 86 88
:3 0 :2 4c 8a :2 0
8c 51 8d 49
8c 0 8e 53
0 1d4 13 :3 0
14 :3 0 8f 90
0 13 :3 0 21
:3 0 92 93 0
22 :2 0 2 :4 0
23 :2 0 24 :2 0
22 :2 0 55 98
9a :3 0 58 94
9c 91 9e 9d
:2 0 16 :3 0 25
:3 0 a0 a1 0
18 :4 0 26 :4 0
1b :2 0 1c :3 0
5c a5 a7 :3 0
5f a2 a9 :2 0
ab 62 ac 9f
ab 0 ad 64
0 1d4 3 :3 0
27 :2 0 66 af
b0 :3 0 b1 :2 0
5 :3 0 27 :2 0
68 b4 b5 :3 0
b6 :2 0 b2 b8
b7 :2 0 6 :3 0
27 :2 0 6a bb
bc :3 0 bd :2 0
be :2 0 b9 c0
bf :2 0 13 :3 0
14 :3 0 c2 c3
0 13 :3 0 21
:3 0 c5 c6 0
28 :2 0 2 :4 0
29 :2 0 24 :2 0
22 :2 0 6c cb
cd :3 0 6f c7
cf c4 d1 d0
:2 0 16 :3 0 25
:3 0 d3 d4 0
18 :4 0 2a :4 0
1b :2 0 1c :3 0
73 d8 da :3 0
1b :2 0 2b :4 0
76 dc de :3 0
1b :2 0 2c :4 0
79 e0 e2 :3 0
1b :2 0 2d :3 0
2e :3 0 2f :3 0
30 :3 0 e7 e8
0 7c e6 ea
31 :4 0 7e e5
ed 81 e4 ef
:3 0 84 d5 f1
:2 0 f3 87 f4
d2 f3 0 f5
89 0 11e 13
:3 0 14 :3 0 f6
f7 0 13 :3 0
21 :3 0 f9 fa
0 22 :2 0 2
:4 0 32 :2 0 24
:2 0 22 :2 0 8b
ff 101 :3 0 8e
fb 103 f8 105
104 :2 0 16 :3 0
25 :3 0 107 108
0 18 :4 0 33
:4 0 1b :2 0 1c
:3 0 92 10c 10e
:3 0 95 109 110
:2 0 112 98 113
106 112 0 114
9a 0 11e 34
:3 0 35 :3 0 115
116 0 2f :3 0
30 :3 0 118 119
0 36 :3 0 9c
117 11c :2 0 11e
9f 11f c1 11e
0 120 a3 0
1d4 a :3 0 3
:3 0 121 122 0
1d4 e :3 0 5
:3 0 124 125 0
1d4 d :3 0 6
:3 0 127 128 0
1d4 37 :3 0 f
:3 0 38 :3 0 39
:3 0 a :4 0 3a
1 :8 0 135 8
:3 0 3b :3 0 130
131 0 3c :3 0
132 133 0 135
a5 17f 3d :3 0
8 :3 0 3b :3 0
138 139 0 3c
:3 0 13a 13b 0
175 13 :3 0 14
:3 0 13d 13e 0
13 :3 0 21 :3 0
140 141 0 3e
:2 0 2 :4 0 3f
:2 0 24 :2 0 22
:2 0 a8 146 148
:3 0 ab 142 14a
13f 14c 14b :2 0
16 :3 0 25 :3 0
14e 14f 0 18
:4 0 40 :4 0 1b
:2 0 1c :3 0 af
153 155 :3 0 1b
:2 0 2b :4 0 b2
157 159 :3 0 1b
:2 0 41 :4 0 b5
15b 15d :3 0 1b
:2 0 3c :3 0 b8
15f 161 :3 0 1b
:2 0 42 :4 0 bb
163 165 :3 0 1b
:2 0 43 :3 0 44
:3 0 22 :2 0 45
:2 0 be 168 16c
c2 167 16e :3 0
c5 150 170 :2 0
172 c8 173 14d
172 0 174 ca
0 175 cc 178
:3 0 178 0 178
177 175 176 :6 0
17a 2 :3 0 cf
17c d1 17b 17a
:2 0 17d d3 :2 0
17f 0 17f 17e
135 17d :6 0 1d4
1 :3 0 c :3 0
46 :4 0 182 183
:3 0 181 184 0
1d4 13 :3 0 14
:3 0 186 187 0
13 :3 0 21 :3 0
189 18a 0 47
:2 0 2 :4 0 48
:2 0 24 :2 0 22
:2 0 d5 18f 191
:3 0 d8 18b 193
188 195 194 :2 0
16 :3 0 25 :3 0
197 198 0 18
:4 0 49 :4 0 1b
:2 0 1c :3 0 dc
19c 19e :3 0 1b
:2 0 2b :4 0 df
1a0 1a2 :3 0 1b
:2 0 2c :4 0 e2
1a4 1a6 :3 0 1b
:2 0 2d :3 0 2e
:3 0 8 :3 0 3b
:3 0 1ab 1ac 0
e5 1aa 1ae 31
:4 0 e7 1a9 1b1
ea 1a8 1b3 :3 0
1b :2 0 4a :4 0
ed 1b5 1b7 :3 0
1b :2 0 1e :4 0
f0 1b9 1bb :3 0
1b :2 0 c :3 0
f3 1bd 1bf :3 0
1b :2 0 1e :4 0
f6 1c1 1c3 :3 0
f9 199 1c5 :2 0
1c7 fc 1c8 196
1c7 0 1c9 fe
0 1d4 34 :3 0
4b :3 0 1ca 1cb
0 8 :3 0 3b
:3 0 1cd 1ce 0
c :3 0 36 :3 0
100 1cc 1d2 :2 0
1d4 104 275 8
:3 0 4c :2 0 4
1d5 1d6 0 13
:3 0 14 :3 0 1d8
1d9 0 13 :3 0
21 :3 0 1db 1dc
0 3e :2 0 2
:4 0 4d :2 0 24
:2 0 22 :2 0 10f
1e1 1e3 :3 0 112
1dd 1e5 1da 1e7
1e6 :2 0 16 :3 0
25 :3 0 1e9 1ea
0 18 :4 0 4e
:4 0 1b :2 0 1c
:3 0 116 1ee 1f0
:3 0 119 1eb 1f2
:2 0 20b 16 :3 0
25 :3 0 1f4 1f5
0 18 :4 0 4f
:4 0 1b :2 0 8
:3 0 50 :3 0 1fa
1fb 0 11c 1f9
1fd :3 0 1b :2 0
4a :4 0 11f 1ff
201 :3 0 1b :2 0
8 :3 0 51 :3 0
204 205 0 122
203 207 :3 0 125
1f6 209 :2 0 20b
128 20c 1e8 20b
0 20d 12b 0
21d 52 :3 0 12
:3 0 8 :3 0 50
:3 0 53 :3 0 8
:3 0 51 :3 0 54
:3 0 55 :4 0 56
1 :a 0 219 :2 0
21d 20f 217 :2 0
7 :3 0 12 :3 0
21b :2 0 21d 12d
21f 131 21e 21d
:2 0 273 3d :3 0
8 :3 0 3b :3 0
222 223 0 3c
:3 0 224 225 0
26b 13 :3 0 14
:3 0 227 228 0
13 :3 0 21 :3 0
22a 22b 0 3e
:2 0 2 :4 0 57
:2 0 24 :2 0 22
:2 0 133 230 232
:3 0 136 22c 234
229 236 235 :2 0
16 :3 0 25 :3 0
238 239 0 18
:4 0 58 :4 0 1b
:2 0 1c :3 0 13a
23d 23f :3 0 13d
23a 241 :2 0 25b
16 :3 0 25 :3 0
243 244 0 18
:4 0 41 :4 0 1b
:2 0 3c :3 0 140
248 24a :3 0 1b
:2 0 42 :4 0 143
24c 24e :3 0 1b
:2 0 43 :3 0 44
:3 0 22 :2 0 45
:2 0 146 251 255
14a 250 257 :3 0
14d 245 259 :2 0
25b 150 25c 237
25b 0 25d 153
0 26b 52 :3 0
12 :3 0 53 :3 0
8 :3 0 51 :3 0
54 :3 0 55 :4 0
59 1 :a 0 267
:2 0 26b 25f 265
:2 0 7 :3 0 12
:3 0 269 :2 0 26b
155 26e :3 0 26e
0 26e 26d 26b
26c :6 0 270 1
:3 0 15a 272 15c
271 270 :2 0 273
15e :2 0 275 161
275 274 1d4 273
:6 0 276 :2 0 2
14 275 279 :3 0
278 276 27a :8 0

168
4
:3 0 1 3 1
7 1 b 3
6 a e 1
18 1 16 1
1f 1 1d 1
26 1 24 1
2d 1 2b 1
32 1 38 1
45 1 51 2
54 56 2 59
5b 2 5d 5f
2 61 63 2
65 67 2 69
6b 2 6d 6f
2 71 73 2
75 77 2 79
7b 2 7d 7f
2 81 83 2
85 87 4 4d
53 58 89 1
8b 1 8d 2
97 99 3 95
96 9b 2 a4
a6 2 a3 a8
1 aa 1 ac
1 ae 1 b3
1 ba 2 ca
cc 3 c8 c9
ce 2 d7 d9
2 db dd 2
df e1 1 e9
2 eb ec 2
e3 ee 2 d6
f0 1 f2 1
f4 2 fe 100
3 fc fd 102
2 10b 10d 2
10a 10f 1 111
1 113 2 11a
11b 3 f5 114
11d 1 11f 2
12f 134 2 145
147 3 143 144
149 2 152 154
2 156 158 2
15a 15c 2 15e
160 2 162 164
3 169 16a 16b
2 166 16d 2
151 16f 1 171
1 173 2 13c
174 1 178 1
137 1 17c 2
18e 190 3 18c
18d 192 2 19b
19d 2 19f 1a1
2 1a3 1a5 1
1ad 2 1af 1b0
2 1a7 1b2 2
1b4 1b6 2 1b8
1ba 2 1bc 1be
2 1c0 1c2 2
19a 1c4 1 1c6
1 1c8 3 1cf
1d0 1d1 a 8e
ad 120 123 126
129 17f 185 1c9
1d3 2 1e0 1e2
3 1de 1df 1e4
2 1ed 1ef 2
1ec 1f1 2 1f8
1fc 2 1fe 200
2 202 206 2
1f7 208 2 1f3
20a 1 20c 3
20d 218 21c 1
1d7 2 22f 231
3 22d 22e 233
2 23c 23e 2
23b 240 2 247
249 2 24b 24d
3 252 253 254
2 24f 256 2
246 258 2 242
25a 1 25c 4
226 25d 266 26a
1 26e 1 221
2 21f 272 6
1b 22 29 30
36 3d 
1
4
0 
279
0
1
14
4
a
0 1 2 1 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 
b 1 0
16 1 0
2b 1 0
7 1 0
32 1 0
3 1 0
1d 1 0
24 1 0
2 0 1
38 1 0
0

/
SHOW ERRORS FUNCTION SP_A_REQRES;
ALTER FUNCTION SP_A_REQRES COMPILE DEBUG;
/*
#Stored Procedure  :SP_A_POOLRES
#Short Description :
#Description       :
#Table Name        :
#Parameters        :
#Returns           :
#Errors            :
*/
Prompt == FUNCTION SP_A_POOLRES ==
CREATE OR REPLACE FUNCTION SP_A_POOLRES wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
5b
2 :e:
1FUNCTION:
1SP_A_POOLRES:
1ID001:
1VARCHAR2:
1RES_ID001:
1REC_USER001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_ELEMENT_ID:
132:
1H_RA_ID:
1H_REC_USER:
1H_RESOURCE_ID:
1H_TABLE_TYPE:
1PLS_INTEGER:
10:
1H_TYPE_ID:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_A_POOLRES(:
1':
1, :
1);:
1CHECK_TRACE:
11:
124:
1+:
1FPUT:
1               ENTER:: SP_A_POOLRES(25) :: cplan.sql(6332) :: :
1IS NULL:
18:
129:
1      RETURN_INVALID:: SP_A_POOLRES(30) :: cplan.sql(6337) :: :
1 :
1STATE:: :
1COALESCE:
1TO_CHAR:
1PMO_CNST:
1INVALID_PARAMS:
1NULL:
1                EXIT:: SP_A_POOLRES(33) :: cplan.sql(6340) :: :
1PMODEFINES:
1PMO_RETURN_INVALID_SP:
1TRUE:
1SC_TABLE_POL:
1TYPE_ID:
1TMT_POOLS:
1ELEMENT_ID:
1SELECT TYPE_ID INTO h_type_id FROM TMT_POOLS WHERE ELEMENT_ID = h_element_id:
1SC_STATE:
1SQLCODE:
1OTHERS:
116:
152:
1           EXCEPTION:: SP_A_POOLRES(53) :: cplan.sql(6360) :: :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1SYS_GUID:
1ASSIGNRESOURCE:
14:
163:
1       RETURN_STATUS:: SP_A_POOLRES(64) :: cplan.sql(6371) :: :
1 ID:: :
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
170:
1           EXCEPTION:: SP_A_POOLRES(71) :: cplan.sql(6378) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1ID:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
182:
1           EXCEPTION:: SP_A_POOLRES(83) :: cplan.sql(6390) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
295
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 :2 a0 6b 1c
81 b0 :2 a0 6b :2 a0 6b 6e a5
b a 10 :2 a0 6b 6e :2 a0 6b
6e a5 b 6e 7e a0 b4 2e
6e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c a0 7e b4 2e :2 5a a0 7e
b4 2e :2 5a 52 10 a0 7e b4
2e :2 5a 52 10 :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :4 a0 6b a5 b 6e
a5 b b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
a0 a5 57 b7 19 3c :2 a0 d
:2 a0 d :2 a0 d :3 a0 6b d :5 a0
12a :2 a0 6b a0 d b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 b4 2e d :2 a0 6b
:7 a0 a5 b d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :4 a0 6b a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b :2 a0 a5 57
b7 :2 a0 6b :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 :2 a0 6b :2 6e 7e :2 a0
6b b4 2e 7e 6e b4 2e 7e
:2 a0 6b b4 2e a5 57 b7 19
3c :9 a0 12a e9 dd :2 a0 65 b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c :7 a0
12a e9 dd :2 a0 65 b7 a4 b1
11 4f b7 a6 9 a4 b1 11
68 4f 1d 17 b5 
295
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 30
56 5a 5e 62 65 69 86 71
75 78 79 81 70 a3 91 6d
95 96 9e 90 c0 ae 8d b2
b3 bb ad dd cb aa cf d0
d8 ca f9 e8 ec c7 f4 e7
115 104 108 e4 110 103 135 120
124 100 128 130 11f 13c 140 11c
144 148 14c 14f 154 155 1 157
15c 160 164 167 16c 170 174 177
17c 17d 17f 184 187 18b 18c 191
196 199 19e 19f 1a4 1a7 1ab 1ac
1b1 1b4 1b9 1ba 1bf 1c2 1c7 1c8
1cd 1d0 1d5 1d6 1db 1de 1e2 1e3
1e8 1eb 1f0 1f1 1f6 1f9 1fe 1ff
204 207 20c 20d 212 215 219 21a
21f 222 227 228 22d 230 235 236
23b 23c 241 243 247 24a 24e 252
255 259 25d 260 263 268 26b 26e
271 272 277 278 1 27a 27f 283
287 28a 28f 294 297 29b 29c 2a1
2a2 2a7 2a9 2ad 2b0 2b4 2b7 2b8
2bd 2c0 2c3 2c7 2ca 2cb 2d0 2d3
1 2d6 2db 2df 2e2 2e3 2e8 2eb
1 2ee 2f3 2f7 2fb 2fe 302 306
309 30c 311 314 317 31a 31b 320
321 1 323 328 32c 330 333 338
33d 340 344 345 34a 34d 352 353
358 35b 360 361 366 369 36d 371
375 379 37c 37d 37f 384 385 387
388 38d 38e 393 395 399 39c 3a0
3a4 3a7 3ab 3af 3b2 3b5 3ba 3bd
3c0 3c3 3c4 3c9 3ca 1 3cc 3d1
3d5 3d9 3dc 3e1 3e6 3e9 3ed 3ee
3f3 3f4 3f9 3fb 3ff 402 406 40a
40d 411 415 418 41c 41d 422 424
428 42b 42f 433 437 43b 43f 443
447 44b 44f 453 457 45b 45e 462
466 46a 46e 472 476 482 486 48a
48d 491 495 497 1 49b 49f 4a3
4a6 4aa 4ae 4b2 4b6 4b9 4bd 4c1
4c4 4c7 4cc 4cf 4d2 4d5 4d6 4db
4dc 1 4de 4e3 4e7 4eb 4ee 4f3
4f8 4fb 4ff 500 505 508 50d 50e
513 516 51b 51c 521 524 528 529
52e 531 536 537 53c 53f 543 547
54a 54d 54e 550 551 556 557 55c
55e 562 565 567 56b 56d 579 57b
57d 57e 583 587 589 595 597 59b
59f 5a0 5a5 5a9 5ad 5b1 5b4 5b8
5bc 5c0 5c4 5c8 5cc 5d0 5d1 5d3
5d7 5db 5df 5e2 5e6 5ea 5ed 5f0
5f5 5f8 5fb 5fe 5ff 604 605 1
607 60c 610 614 617 61c 621 624
628 629 62e 631 636 637 63c 63f
644 645 64a 64d 651 655 659 65d
660 661 663 668 669 66b 66c 671
674 679 67a 67f 682 687 688 68d
690 694 695 69a 69d 6a2 6a3 6a8
6a9 6ae 6b0 6b4 6b7 6bb 6bf 6c2
6c6 6ca 6cd 6d1 6d5 6d6 6db 6dd
6e1 6e5 6e8 6ec 6f0 6f3 6f7 6fb
6fe 701 706 709 70c 70f 710 715
716 1 718 71d 721 725 728 72d
732 735 739 73a 73f 740 745 749
74d 750 755 75a 75d 761 765 768
769 76e 771 776 777 77c 77f 783
787 78a 78b 790 791 796 798 79c
79f 7a3 7a7 7ab 7af 7b3 7b7 7bb
7bf 7c3 7cf 7d4 7d8 7dc 7e0 7e4
7e6 7e7 7ec 1 7f0 7f4 7f8 7fb
7ff 803 807 80b 80e 812 816 819
81c 821 824 827 82a 82b 830 831
1 833 838 83c 840 843 848 84d
850 854 855 85a 85b 860 864 868
86b 870 875 878 87c 87d 882 885
88a 88b 890 893 897 89b 89e 8a1
8a2 8a4 8a5 8aa 8ab 8b0 8b2 8b6
8b9 8bd 8c1 8c5 8c9 8cd 8d1 8d5
8e1 8e6 8ea 8ee 8f2 8f6 8f8 8fc
8fe 90a 90c 90e 90f 914 918 91a
926 92a 92c 92d 936 
295
2
0 1 a 6 c :3 6 10 :3 6
12 :2 6 1 3 a 13 a :2 1
4 11 1a 19 :2 11 :2 4 c 15
14 :2 c :2 4 f 18 17 :2 f :2 4
12 1b 1a :2 12 :2 4 :2 11 20 11
:2 4 :2 e 1d e :2 4 e 17 :3 e
4 7 :2 11 23 :2 2d 3a :2 23 :3 7
:2 d 19 25 :2 2f 43 :2 25 54 5a
5d :2 54 6b 81 8 :2 6b d 10
:2 6b 16 19 :2 6b b e :2 6b 13
16 :2 6b 1b 1e :2 6b 28 2b :2 6b
b e :2 6b 13 16 :2 6b 1b 1e
:2 6b 2a 2d :2 6b 32 35 :2 6b :2 7
4a :2 4 7 :2 11 23 :2 2d 39 3c
4c 4e 4f :2 4c :2 23 :3 7 :2 d 12
1e 5c 5f :2 1e :2 7 52 :2 4 :4 9
8 7 :4 1e 1d 1c :2 7 :4 37 36
35 :2 7 a :2 14 26 :2 30 3c 3f
4f 51 52 :2 4f :2 26 :3 a :2 10 15
21 5f 62 :2 21 6f 72 :2 21 76
79 :2 21 83 86 8f 97 :2 a0 :2 8f
b1 :2 86 :2 21 :2 a 55 :2 7 a :2 14
26 :2 30 3c 3f 4f 51 52 :2 4f
:2 26 :3 a :2 10 15 21 5f 62 :2 21
:2 a 55 :3 7 :2 12 28 :2 31 41 :2 7
4d :3 4 14 :2 4 15 :2 4 12 :2 4
14 :2 1d 4 e 1b 2a 3a 47
:2 7 :2 10 1c 7 4 :2 c a :2 13
1f a d :2 17 29 :2 33 3f 43
53 55 56 :2 53 :2 29 :3 d :2 13 18
24 62 65 :2 24 72 75 :2 24 79
7c :2 24 88 8b :2 24 93 96 :2 24
a2 a5 ac b5 b8 :2 a5 :2 24 :2 d
59 :2 a :2 7 :4 13 :2 7 4 :3 1 4
:3 f :2 4 :2 d 19 28 36 41 4f
5e 27 :2 19 4 7 :2 11 23 :2 2d
39 3c 4c 4e 4f :2 4c :2 23 :3 7
:2 d 12 1e 5c 5f :2 1e 6c 6f
:2 1e 73 76 :2 1e 80 83 8c 94
:2 9d :2 8c a8 :2 83 :2 1e b0 b3 :2 1e
bb be :2 1e c3 c6 :2 1e ce d1
:2 1e :2 7 52 :3 4 :2 f 21 :2 2a 34
3d :2 4 1 9 12 9 a :2 14
26 :2 30 3c 40 50 52 53 :2 50
:2 26 :3 a :2 10 15 21 5f 62 :2 21
:3 a :2 10 15 39 5c 5f :2 68 :2 39
76 79 :2 39 81 84 :2 8d :2 39 :2 a
56 :3 7 c 15 1e 2c a 13
1e f e 7 e 7 e 7
29 :2 4 :2 9 7 :2 10 1c :2 7 :2 11
23 :2 2d 39 3d 4d 4f 50 :2 4d
:2 23 :3 7 :2 d 12 1e 5c 5f :2 1e
:3 7 :2 d 12 36 42 45 :2 36 4d
50 :2 36 5c 5f 66 6f 72 :2 5f
:2 36 :2 7 53 :2 4 7 c 1b a
13 1e f e 7 e 7 e
7 :2 4 :4 10 :2 4 :8 1 
295
4
0 :2 1 :4 3 :4 4
:4 5 2 :4 6 :2 1
:7 8 :7 9 :7 a :7 b
:6 c :6 d :7 f :b 11
:11 12 13 :2 12 :2 13
:2 12 :2 13 :2 12 :2 14
:2 12 :2 14 :2 12 :2 14
:2 12 :2 14 :2 12 :2 15
:2 12 :2 15 :2 12 :2 15
:2 12 :2 15 :2 12 :2 15
:4 12 :3 11 :11 18 :b 19
:3 18 :16 1c :11 1d :20 1e
:3 1d :11 20 :b 21 :3 20
:9 23 :3 1c :3 28 :3 29
:3 2a :5 2b :6 2e :5 2f
2d :2 31 :5 33 :11 34
:24 35 :3 34 :2 32 :6 31
30 :3 10 :5 3a :9 3c
3d :3 3c :11 3f :30 40
:3 3f :a 42 10 :3 45
:11 46 :b 47 :17 48 :3 46
:2 4a :3 4b :3 4c 4d
4b 4a 4b :3 4e
:3 45 :2 4f :5 51 :11 52
:b 53 :18 54 :3 52 :2 56
57 :3 58 59 57
56 57 :3 5a :2 50
:6 4f 44 :7 1 
938
4
:3 0 1 :3 0 2
:a 0 290 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
:2 0 7 4 :3 0
5 :7 0 9 8
:3 0 4 :3 0 6
:7 0 d c :3 0
7 :3 0 8 :3 0
9 :2 0 4 11
12 0 f 13
0 290 2 14
:2 0 b :2 0 f
4 :3 0 b :2 0
d 17 19 :6 0
1c 1a 0 28e
0 a :6 0 b
:2 0 13 4 :3 0
11 1e 20 :6 0
23 21 0 28e
0 c :6 0 b
:2 0 17 4 :3 0
15 25 27 :6 0
2a 28 0 28e
0 d :6 0 11
:2 0 1b 4 :3 0
19 2c 2e :6 0
31 2f 0 28e
0 e :6 0 11
:2 0 1d 10 :3 0
33 :7 0 37 34
35 28e 0 f
:6 0 3f 40 0
1f 10 :3 0 39
:7 0 3d 3a 3b
28e 0 12 :6 0
45 46 0 21
8 :3 0 9 :2 0
4 41 :7 0 44
42 0 28e 0
13 :6 0 14 :3 0
15 :3 0 14 :3 0
16 :3 0 48 49
0 2 :4 0 23
4a 4c 47 4e
4d :2 0 17 :3 0
18 :3 0 50 51
0 19 :4 0 14
:3 0 1a :3 0 54
55 0 2 :4 0
25 56 58 1b
:4 0 1c :2 0 1d
:3 0 27 5b 5d
:3 0 1e :4 0 1c
:2 0 1f :4 0 2a
60 62 :3 0 1c
:2 0 3 :3 0 2d
64 66 :3 0 1c
:2 0 1f :4 0 30
68 6a :3 0 1c
:2 0 20 :4 0 33
6c 6e :3 0 1c
:2 0 1f :4 0 36
70 72 :3 0 1c
:2 0 5 :3 0 39
74 76 :3 0 1c
:2 0 1f :4 0 3c
78 7a :3 0 1c
:2 0 20 :4 0 3f
7c 7e :3 0 1c
:2 0 1f :4 0 42
80 82 :3 0 1c
:2 0 6 :3 0 45
84 86 :3 0 1c
:2 0 1f :4 0 48
88 8a :3 0 1c
:2 0 21 :4 0 4b
8c 8e :3 0 4e
52 90 :2 0 92
53 93 4f 92
0 94 55 0
1ee 14 :3 0 15
:3 0 95 96 0
14 :3 0 22 :3 0
98 99 0 23
:2 0 2 :4 0 24
:2 0 25 :2 0 23
:2 0 57 9e a0
:3 0 5a 9a a2
97 a4 a3 :2 0
17 :3 0 26 :3 0
a6 a7 0 19
:4 0 27 :4 0 1c
:2 0 1d :3 0 5e
ab ad :3 0 61
a8 af :2 0 b1
64 b2 a5 b1
0 b3 66 0
1ee 3 :3 0 28
:2 0 68 b5 b6
:3 0 b7 :2 0 b8
:2 0 5 :3 0 28
:2 0 6a bb bc
:3 0 bd :2 0 be
:2 0 b9 c0 bf
:2 0 6 :3 0 28
:2 0 6c c3 c4
:3 0 c5 :2 0 c6
:2 0 c1 c8 c7
:2 0 14 :3 0 15
:3 0 ca cb 0
14 :3 0 22 :3 0
cd ce 0 29
:2 0 2 :4 0 2a
:2 0 25 :2 0 23
:2 0 6e d3 d5
:3 0 71 cf d7
cc d9 d8 :2 0
17 :3 0 26 :3 0
db dc 0 19
:4 0 2b :4 0 1c
:2 0 1d :3 0 75
e0 e2 :3 0 1c
:2 0 2c :4 0 78
e4 e6 :3 0 1c
:2 0 2d :4 0 7b
e8 ea :3 0 1c
:2 0 2e :3 0 2f
:3 0 30 :3 0 31
:3 0 ef f0 0
7e ee f2 32
:4 0 80 ed f5
83 ec f7 :3 0
86 dd f9 :2 0
fb 89 fc da
fb 0 fd 8b
0 126 14 :3 0
15 :3 0 fe ff
0 14 :3 0 22
:3 0 101 102 0
23 :2 0 2 :4 0
b :2 0 25 :2 0
23 :2 0 8d 107
109 :3 0 90 103
10b 100 10d 10c
:2 0 17 :3 0 26
:3 0 10f 110 0
19 :4 0 33 :4 0
1c :2 0 1d :3 0
94 114 116 :3 0
97 111 118 :2 0
11a 9a 11b 10e
11a 0 11c 9c
0 126 34 :3 0
35 :3 0 11d 11e
0 30 :3 0 31
:3 0 120 121 0
36 :3 0 9e 11f
124 :2 0 126 a1
127 c9 126 0
128 a5 0 1ee
a :3 0 3 :3 0
129 12a 0 1ee
e :3 0 5 :3 0
12c 12d 0 1ee
d :3 0 6 :3 0
12f 130 0 1ee
f :3 0 30 :3 0
37 :3 0 133 134
0 132 135 0
1ee 38 :3 0 12
:3 0 39 :3 0 3a
:3 0 a :4 0 3b
1 :8 0 142 8
:3 0 3c :3 0 13d
13e 0 3d :3 0
13f 140 0 142
a7 18c 3e :3 0
8 :3 0 3c :3 0
145 146 0 3d
:3 0 147 148 0
182 14 :3 0 15
:3 0 14a 14b 0
14 :3 0 22 :3 0
14d 14e 0 3f
:2 0 2 :4 0 40
:2 0 25 :2 0 23
:2 0 aa 153 155
:3 0 ad 14f 157
14c 159 158 :2 0
17 :3 0 26 :3 0
15b 15c 0 19
:4 0 41 :4 0 1c
:2 0 1d :3 0 b1
160 162 :3 0 1c
:2 0 2c :4 0 b4
164 166 :3 0 1c
:2 0 42 :4 0 b7
168 16a :3 0 1c
:2 0 3d :3 0 ba
16c 16e :3 0 1c
:2 0 43 :4 0 bd
170 172 :3 0 1c
:2 0 44 :3 0 45
:3 0 23 :2 0 46
:2 0 c0 175 179
c4 174 17b :3 0
c7 15d 17d :2 0
17f ca 180 15a
17f 0 181 cc
0 182 ce 185
:3 0 185 0 185
184 182 183 :6 0
187 2 :3 0 d1
189 d3 188 187
:2 0 18a d5 :2 0
18c 0 18c 18b
142 18a :6 0 1ee
1 :3 0 c :3 0
47 :4 0 18f 190
:3 0 18e 191 0
1ee 8 :3 0 3c
:3 0 193 194 0
48 :3 0 f :3 0
12 :3 0 a :3 0
e :3 0 d :3 0
c :3 0 d7 196
19d 195 19e 0
1ee 14 :3 0 15
:3 0 1a0 1a1 0
14 :3 0 22 :3 0
1a3 1a4 0 49
:2 0 2 :4 0 4a
:2 0 25 :2 0 23
:2 0 de 1a9 1ab
:3 0 e1 1a5 1ad
1a2 1af 1ae :2 0
17 :3 0 26 :3 0
1b1 1b2 0 19
:4 0 4b :4 0 1c
:2 0 1d :3 0 e5
1b6 1b8 :3 0 1c
:2 0 2c :4 0 e8
1ba 1bc :3 0 1c
:2 0 2d :4 0 eb
1be 1c0 :3 0 1c
:2 0 2e :3 0 2f
:3 0 8 :3 0 3c
:3 0 1c5 1c6 0
ee 1c4 1c8 32
:4 0 f0 1c3 1cb
f3 1c2 1cd :3 0
1c :2 0 4c :4 0
f6 1cf 1d1 :3 0
1c :2 0 1f :4 0
f9 1d3 1d5 :3 0
1c :2 0 c :3 0
fc 1d7 1d9 :3 0
1c :2 0 1f :4 0
ff 1db 1dd :3 0
102 1b3 1df :2 0
1e1 105 1e2 1b0
1e1 0 1e3 107
0 1ee 34 :3 0
4d :3 0 1e4 1e5
0 8 :3 0 3c
:3 0 1e7 1e8 0
c :3 0 36 :3 0
109 1e6 1ec :2 0
1ee 10d 28f 8
:3 0 4e :2 0 4
1ef 1f0 0 14
:3 0 15 :3 0 1f2
1f3 0 14 :3 0
22 :3 0 1f5 1f6
0 3f :2 0 2
:4 0 4f :2 0 25
:2 0 23 :2 0 11a
1fb 1fd :3 0 11d
1f7 1ff 1f4 201
200 :2 0 17 :3 0
26 :3 0 203 204
0 19 :4 0 50
:4 0 1c :2 0 1d
:3 0 121 208 20a
:3 0 124 205 20c
:2 0 225 17 :3 0
26 :3 0 20e 20f
0 19 :4 0 51
:4 0 1c :2 0 8
:3 0 52 :3 0 214
215 0 127 213
217 :3 0 1c :2 0
4c :4 0 12a 219
21b :3 0 1c :2 0
8 :3 0 53 :3 0
21e 21f 0 12d
21d 221 :3 0 130
210 223 :2 0 225
133 226 202 225
0 227 136 0
237 54 :3 0 13
:3 0 8 :3 0 52
:3 0 55 :3 0 8
:3 0 53 :3 0 56
:3 0 57 :4 0 58
1 :a 0 233 :2 0
237 229 231 :2 0
7 :3 0 13 :3 0
235 :2 0 237 138
239 13c 238 237
:2 0 28d 3e :3 0
8 :3 0 3c :3 0
23c 23d 0 3d
:3 0 23e 23f 0
285 14 :3 0 15
:3 0 241 242 0
14 :3 0 22 :3 0
244 245 0 3f
:2 0 2 :4 0 59
:2 0 25 :2 0 23
:2 0 13e 24a 24c
:3 0 141 246 24e
243 250 24f :2 0
17 :3 0 26 :3 0
252 253 0 19
:4 0 5a :4 0 1c
:2 0 1d :3 0 145
257 259 :3 0 148
254 25b :2 0 275
17 :3 0 26 :3 0
25d 25e 0 19
:4 0 42 :4 0 1c
:2 0 3d :3 0 14b
262 264 :3 0 1c
:2 0 43 :4 0 14e
266 268 :3 0 1c
:2 0 44 :3 0 45
:3 0 23 :2 0 46
:2 0 151 26b 26f
155 26a 271 :3 0
158 25f 273 :2 0
275 15b 276 251
275 0 277 15e
0 285 54 :3 0
13 :3 0 55 :3 0
8 :3 0 53 :3 0
56 :3 0 57 :4 0
5b 1 :a 0 281
:2 0 285 279 27f
:2 0 7 :3 0 13
:3 0 283 :2 0 285
160 288 :3 0 288
0 288 287 285
286 :6 0 28a 1
:3 0 165 28c 167
28b 28a :2 0 28d
169 :2 0 28f 16c
28f 28e 1ee 28d
:6 0 290 :2 0 2
14 28f 293 :3 0
292 290 294 :8 0

174
4
:3 0 1 3 1
7 1 b 3
6 a e 1
18 1 16 1
1f 1 1d 1
26 1 24 1
2d 1 2b 1
32 1 38 1
3e 1 4b 1
57 2 5a 5c
2 5f 61 2
63 65 2 67
69 2 6b 6d
2 6f 71 2
73 75 2 77
79 2 7b 7d
2 7f 81 2
83 85 2 87
89 2 8b 8d
4 53 59 5e
8f 1 91 1
93 2 9d 9f
3 9b 9c a1
2 aa ac 2
a9 ae 1 b0
1 b2 1 b4
1 ba 1 c2
2 d2 d4 3
d0 d1 d6 2
df e1 2 e3
e5 2 e7 e9
1 f1 2 f3
f4 2 eb f6
2 de f8 1
fa 1 fc 2
106 108 3 104
105 10a 2 113
115 2 112 117
1 119 1 11b
2 122 123 3
fd 11c 125 1
127 2 13c 141
2 152 154 3
150 151 156 2
15f 161 2 163
165 2 167 169
2 16b 16d 2
16f 171 3 176
177 178 2 173
17a 2 15e 17c
1 17e 1 180
2 149 181 1
185 1 144 1
189 6 197 198
199 19a 19b 19c
2 1a8 1aa 3
1a6 1a7 1ac 2
1b5 1b7 2 1b9
1bb 2 1bd 1bf
1 1c7 2 1c9
1ca 2 1c1 1cc
2 1ce 1d0 2
1d2 1d4 2 1d6
1d8 2 1da 1dc
2 1b4 1de 1
1e0 1 1e2 3
1e9 1ea 1eb c
94 b3 128 12b
12e 131 136 18c
192 19f 1e3 1ed
2 1fa 1fc 3
1f8 1f9 1fe 2
207 209 2 206
20b 2 212 216
2 218 21a 2
21c 220 2 211
222 2 20d 224
1 226 3 227
232 236 1 1f1
2 249 24b 3
247 248 24d 2
256 258 2 255
25a 2 261 263
2 265 267 3
26c 26d 26e 2
269 270 2 260
272 2 25c 274
1 276 4 240
277 280 284 1
288 1 23b 2
239 28c 7 1b
22 29 30 36
3c 43 
1
4
0 
293
0
1
14
4
b
0 1 2 1 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 
b 1 0
16 1 0
2b 1 0
2 0 1
7 1 0
38 1 0
3 1 0
1d 1 0
32 1 0
24 1 0
3e 1 0
0

/
SHOW ERRORS FUNCTION SP_A_POOLRES;
ALTER FUNCTION SP_A_POOLRES COMPILE DEBUG;
/***************************************************************************************************/
/*
#Stored Procedure  :SP_A_DOCRES
#Short Description :
#Description       :
#Table Name        :
#Parameters        :
#Returns           :
#Errors            :
*/
Prompt == FUNCTION SP_A_DOCRES ==
CREATE OR REPLACE FUNCTION SP_A_DOCRES wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
7d
2 :e:
1FUNCTION:
1SP_A_DOCRES:
1TABLE_TYPE001:
1PLS_INTEGER:
1ID001:
1VARCHAR2:
1RES_ID001:
1REC_USER001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_ELEMENT_ID:
132:
1H_RA_ID:
1H_REC_USER:
1H_RESOURCE_ID:
1H_TABLE_TYPE:
10:
1H_TYPE_ID:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_A_DOCRES(:
1COALESCE:
1TO_CHAR:
1NULL:
1, :
1':
1);:
1CHECK_TRACE:
11:
126:
1+:
1FPUT:
1               ENTER:: SP_A_DOCRES(27) :: cplan.sql(6443) :: :
1IS NULL:
18:
131:
1      RETURN_INVALID:: SP_A_DOCRES(32) :: cplan.sql(6448) :: :
1 :
1STATE:: :
1PMO_CNST:
1INVALID_PARAMS:
134:
1                EXIT:: SP_A_DOCRES(35) :: cplan.sql(6451) :: :
1PMODEFINES:
1PMO_RETURN_INVALID_SP:
1TRUE:
1=:
1SC_TABLE_DOC:
1TYPE_ID:
1TMT_DOCUMENTS:
1ELEMENT_ID:
1SELECT TYPE_ID INTO h_type_id FROM TMT_DOCUMENTS WHERE ELEMENT_ID = h_element+
1_id:
1SC_STATE:
1SQLCODE:
1OTHERS:
116:
155:
1           EXCEPTION:: SP_A_DOCRES(56) :: cplan.sql(6472) :: :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1ELSIF:
1SC_TABLE_SCD:
1TMT_ASSIGNED_SCORECARDS:
1SELECT TYPE_ID INTO h_type_id FROM TMT_ASSIGNED_SCORECARDS WHERE ELEMENT_ID =+
1 h_element_id:
168:
1           EXCEPTION:: SP_A_DOCRES(69) :: cplan.sql(6485) :: :
1SC_TABLE_POL_DOC:
1TMT_POOL_DOCUMENTS:
1SELECT TYPE_ID INTO h_type_id FROM TMT_POOL_DOCUMENTS WHERE ELEMENT_ID = h_el+
1ement_id:
181:
1           EXCEPTION:: SP_A_DOCRES(82) :: cplan.sql(6498) :: :
1SC_TABLE_RES_DOC:
1TMT_RESOURCE_DOCUMENTS:
1SELECT TYPE_ID INTO h_type_id FROM TMT_RESOURCE_DOCUMENTS WHERE ELEMENT_ID = +
1h_element_id:
194:
1           EXCEPTION:: SP_A_DOCRES(95) :: cplan.sql(6511) :: :
1SC_TABLE_CLN_DOC:
1TMT_CLIENT_DOCUMENTS:
1SELECT TYPE_ID INTO h_type_id FROM TMT_CLIENT_DOCUMENTS WHERE ELEMENT_ID = h_+
1element_id:
1107:
1           EXCEPTION:: SP_A_DOCRES(108) :: cplan.sql(6524) :: :
1SC_TABLE_AST_DOC:
1TMT_ASSET_DOCUMENTS:
1SELECT TYPE_ID INTO h_type_id FROM TMT_ASSET_DOCUMENTS WHERE ELEMENT_ID = h_e+
1lement_id:
1120:
1           EXCEPTION:: SP_A_DOCRES(121) :: cplan.sql(6537) :: :
1SC_TABLE_VDR_DOC:
1TMT_VENDOR_DOCUMENTS:
1SELECT TYPE_ID INTO h_type_id FROM TMT_VENDOR_DOCUMENTS WHERE ELEMENT_ID = h_+
1element_id:
1133:
1           EXCEPTION:: SP_A_DOCRES(134) :: cplan.sql(6550) :: :
1SYS_GUID:
1ASSIGNRESOURCE:
14:
1145:
1       RETURN_STATUS:: SP_A_DOCRES(146) :: cplan.sql(6562) :: :
1 ID:: :
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
1152:
1           EXCEPTION:: SP_A_DOCRES(153) :: cplan.sql(6569) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1ID:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
1164:
1           EXCEPTION:: SP_A_DOCRES(165) :: cplan.sql(6581) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
512
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d b4 :3 a0 6b 2c 6a
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 :2 a0 6b 1c 81 b0 :2 a0 6b
:2 a0 6b 6e a5 b a 10 :2 a0
6b 6e :2 a0 6b 6e a5 b 6e
7e a0 b4 2e 6e 7e :3 a0 a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c a0 7e b4 2e :2 5a a0
7e b4 2e :2 5a 52 10 a0 7e
b4 2e :2 5a 52 10 :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b a0 a5 57 b7 19 3c :2 a0
d :2 a0 d :2 a0 d :2 a0 d :2 a0
51 a5 b a0 7e a0 6b b4
2e :5 a0 12a :2 a0 6b a0 d b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f a0 b7 :2 a0 51
a5 b a0 7e a0 6b b4 2e
:5 a0 12a :2 a0 6b a0 d b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f a0 b7 19 :2 a0 51
a5 b a0 7e a0 6b b4 2e
:5 a0 12a :2 a0 6b a0 d b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f a0 b7 19 :2 a0 51
a5 b a0 7e a0 6b b4 2e
:5 a0 12a :2 a0 6b a0 d b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f a0 b7 19 :2 a0 51
a5 b a0 7e a0 6b b4 2e
:5 a0 12a :2 a0 6b a0 d b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f a0 b7 19 :2 a0 51
a5 b a0 7e a0 6b b4 2e
:5 a0 12a :2 a0 6b a0 d b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f a0 b7 19 :2 a0 51
a5 b a0 7e a0 6b b4 2e
:5 a0 12a :2 a0 6b a0 d b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 :2 19 3c :2 a0 b4
2e d :2 a0 6b :7 a0 a5 b d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b :2 a0 a5 57 b7 :2 a0 6b :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 :2 a0
6b :2 6e 7e :2 a0 6b b4 2e 7e
6e b4 2e 7e :2 a0 6b b4 2e
a5 57 b7 19 3c :9 a0 12a e9
dd :2 a0 65 b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c :7 a0 12a e9 dd :2 a0
65 b7 a4 b1 11 4f b7 a6
9 a4 b1 11 68 4f 1d 17
b5 
512
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 5e
5a 30 66 59 6b 6f 73 56
77 7b 98 83 87 8a 8b 93
82 b5 a3 7f a7 a8 b0 a2
d2 c0 9f c4 c5 cd bf ef
dd bc e1 e2 ea dc 10b fa
fe d9 106 f9 127 116 11a f6
122 115 147 132 136 112 13a 142
131 14e 152 12e 156 15a 15e 161
166 167 1 169 16e 172 176 179
17e 182 186 189 18e 18f 191 196
199 19d 19e 1a3 1a8 1ab 1af 1b3
1b7 1b8 1ba 1bf 1c0 1c2 1c3 1c8
1cb 1d0 1d1 1d6 1d9 1de 1df 1e4
1e7 1eb 1ec 1f1 1f4 1f9 1fa 1ff
202 207 208 20d 210 215 216 21b
21e 222 223 228 22b 230 231 236
239 23e 23f 244 247 24c 24d 252
255 259 25a 25f 262 267 268 26d
270 275 276 27b 27c 281 283 287
28a 28e 292 295 299 29d 2a0 2a3
2a8 2ab 2ae 2b1 2b2 2b7 2b8 1
2ba 2bf 2c3 2c7 2ca 2cf 2d4 2d7
2db 2dc 2e1 2e2 2e7 2e9 2ed 2f0
2f4 2f7 2f8 2fd 300 303 307 30a
30b 310 313 1 316 31b 31f 322
323 328 32b 1 32e 333 337 33b
33e 342 346 349 34c 351 354 357
35a 35b 360 361 1 363 368 36c
370 373 378 37d 380 384 385 38a
38d 392 393 398 39b 3a0 3a1 3a6
3a9 3ad 3b1 3b5 3b9 3bc 3bd 3bf
3c4 3c5 3c7 3c8 3cd 3ce 3d3 3d5
3d9 3dc 3e0 3e4 3e7 3eb 3ef 3f2
3f5 3fa 3fd 400 403 404 409 40a
1 40c 411 415 419 41c 421 426
429 42d 42e 433 434 439 43b 43f
442 446 44a 44d 451 455 458 45c
45d 462 464 468 46b 46f 473 477
47b 47f 483 487 48b 48f 493 497
49b 49f 4a3 4a6 4a7 4a9 4ad 4b0
4b4 4b7 4b8 4bd 4c1 4c5 4c9 4cd
4d1 4dd 4e1 4e5 4e8 4ec 4f0 4f2
1 4f6 4fa 4fe 501 505 509 50d
511 514 518 51c 51f 522 527 52a
52d 530 531 536 537 1 539 53e
542 546 549 54e 553 556 55a 55b
560 563 568 569 56e 571 576 577
57c 57f 583 584 589 58c 591 592
597 59a 59e 5a2 5a5 5a8 5a9 5ab
5ac 5b1 5b2 5b7 5b9 5bd 5c0 5c2
5c6 5c8 5d4 5d6 5d8 5d9 5de 5e2
5e4 5f0 5f2 5f6 5f8 5fc 600 603
604 606 60a 60d 611 614 615 61a
61e 622 626 62a 62e 63a 63e 642
645 649 64d 64f 1 653 657 65b
65e 662 666 66a 66e 671 675 679
67c 67f 684 687 68a 68d 68e 693
694 1 696 69b 69f 6a3 6a6 6ab
6b0 6b3 6b7 6b8 6bd 6c0 6c5 6c6
6cb 6ce 6d3 6d4 6d9 6dc 6e0 6e1
6e6 6e9 6ee 6ef 6f4 6f7 6fb 6ff
702 705 706 708 709 70e 70f 714
716 71a 71d 71f 723 725 731 733
735 736 73b 73f 741 74d 74f 753
755 759 75d 761 764 765 767 76b
76e 772 775 776 77b 77f 783 787
78b 78f 79b 79f 7a3 7a6 7aa 7ae
7b0 1 7b4 7b8 7bc 7bf 7c3 7c7
7cb 7cf 7d2 7d6 7da 7dd 7e0 7e5
7e8 7eb 7ee 7ef 7f4 7f5 1 7f7
7fc 800 804 807 80c 811 814 818
819 81e 821 826 827 82c 82f 834
835 83a 83d 841 842 847 84a 84f
850 855 858 85c 860 863 866 867
869 86a 86f 870 875 877 87b 87e
880 884 886 892 894 896 897 89c
8a0 8a2 8ae 8b0 8b4 8b6 8ba 8be
8c2 8c5 8c6 8c8 8cc 8cf 8d3 8d6
8d7 8dc 8e0 8e4 8e8 8ec 8f0 8fc
900 904 907 90b 90f 911 1 915
919 91d 920 924 928 92c 930 933
937 93b 93e 941 946 949 94c 94f
950 955 956 1 958 95d 961 965
968 96d 972 975 979 97a 97f 982
987 988 98d 990 995 996 99b 99e
9a2 9a3 9a8 9ab 9b0 9b1 9b6 9b9
9bd 9c1 9c4 9c7 9c8 9ca 9cb 9d0
9d1 9d6 9d8 9dc 9df 9e1 9e5 9e7
9f3 9f5 9f7 9f8 9fd a01 a03 a0f
a11 a15 a17 a1b a1f a23 a26 a27
a29 a2d a30 a34 a37 a38 a3d a41
a45 a49 a4d a51 a5d a61 a65 a68
a6c a70 a72 1 a76 a7a a7e a81
a85 a89 a8d a91 a94 a98 a9c a9f
aa2 aa7 aaa aad ab0 ab1 ab6 ab7
1 ab9 abe ac2 ac6 ac9 ace ad3
ad6 ada adb ae0 ae3 ae8 ae9 aee
af1 af6 af7 afc aff b03 b04 b09
b0c b11 b12 b17 b1a b1e b22 b25
b28 b29 b2b b2c b31 b32 b37 b39
b3d b40 b42 b46 b48 b54 b56 b58
b59 b5e b62 b64 b70 b72 b76 b78
b7c b80 b84 b87 b88 b8a b8e b91
b95 b98 b99 b9e ba2 ba6 baa bae
bb2 bbe bc2 bc6 bc9 bcd bd1 bd3
1 bd7 bdb bdf be2 be6 bea bee
bf2 bf5 bf9 bfd c00 c03 c08 c0b
c0e c11 c12 c17 c18 1 c1a c1f
c23 c27 c2a c2f c34 c37 c3b c3c
c41 c44 c49 c4a c4f c52 c57 c58
c5d c60 c64 c65 c6a c6d c72 c73
c78 c7b c7f c83 c86 c89 c8a c8c
c8d c92 c93 c98 c9a c9e ca1 ca3
ca7 ca9 cb5 cb7 cb9 cba cbf cc3
cc5 cd1 cd3 cd7 cd9 cdd ce1 ce5
ce8 ce9 ceb cef cf2 cf6 cf9 cfa
cff d03 d07 d0b d0f d13 d1f d23
d27 d2a d2e d32 d34 1 d38 d3c
d40 d43 d47 d4b d4f d53 d56 d5a
d5e d61 d64 d69 d6c d6f d72 d73
d78 d79 1 d7b d80 d84 d88 d8b
d90 d95 d98 d9c d9d da2 da5 daa
dab db0 db3 db8 db9 dbe dc1 dc5
dc6 dcb dce dd3 dd4 dd9 ddc de0
de4 de7 dea deb ded dee df3 df4
df9 dfb dff e02 e04 e08 e0a e16
e18 e1a e1b e20 e24 e26 e32 e34
e36 e3a e3e e41 e45 e49 e4a e4f
e53 e57 e5b e5e e62 e66 e6a e6e
e72 e76 e7a e7b e7d e81 e85 e89
e8c e90 e94 e97 e9a e9f ea2 ea5
ea8 ea9 eae eaf 1 eb1 eb6 eba
ebe ec1 ec6 ecb ece ed2 ed3 ed8
edb ee0 ee1 ee6 ee9 eee eef ef4
ef7 efb eff f03 f07 f0a f0b f0d
f12 f13 f15 f16 f1b f1e f23 f24
f29 f2c f31 f32 f37 f3a f3e f3f
f44 f47 f4c f4d f52 f53 f58 f5a
f5e f61 f65 f69 f6c f70 f74 f77
f7b f7f f80 f85 f87 f8b f8f f92
f96 f9a f9d fa1 fa5 fa8 fab fb0
fb3 fb6 fb9 fba fbf fc0 1 fc2
fc7 fcb fcf fd2 fd7 fdc fdf fe3
fe4 fe9 fea fef ff3 ff7 ffa fff
1004 1007 100b 100f 1012 1013 1018 101b
1020 1021 1026 1029 102d 1031 1034 1035
103a 103b 1040 1042 1046 1049 104d 1051
1055 1059 105d 1061 1065 1069 106d 1079
107e 1082 1086 108a 108e 1090 1091 1096
1 109a 109e 10a2 10a5 10a9 10ad 10b1
10b5 10b8 10bc 10c0 10c3 10c6 10cb 10ce
10d1 10d4 10d5 10da 10db 1 10dd 10e2
10e6 10ea 10ed 10f2 10f7 10fa 10fe 10ff
1104 1105 110a 110e 1112 1115 111a 111f
1122 1126 1127 112c 112f 1134 1135 113a
113d 1141 1145 1148 114b 114c 114e 114f
1154 1155 115a 115c 1160 1163 1167 116b
116f 1173 1177 117b 117f 118b 1190 1194
1198 119c 11a0 11a2 11a6 11a8 11b4 11b6
11b8 11b9 11be 11c2 11c4 11d0 11d4 11d6
11d7 11e0 
512
2
0 1 a 6 14 :3 6 c :3 6
10 :3 6 12 :2 6 1 3 a 13
a :2 1 4 11 1a 19 :2 11 :2 4
c 15 14 :2 c :2 4 f 18 17
:2 f :2 4 12 1b 1a :2 12 :2 4 :2 11
20 11 :2 4 :2 e 1d e :2 4 e
17 :3 e 4 7 :2 11 23 :2 2d 3a
:2 23 :3 7 :2 d 19 25 :2 2f 43 :2 25
53 59 5c :2 53 6a 7f 8 11
19 :2 11 29 :2 8 :2 6a b e :2 6a
13 16 :2 6a 1b 1e :2 6a 24 27
:2 6a b e :2 6a 13 16 :2 6a 1b
1e :2 6a 28 2b :2 6a b e :2 6a
13 16 :2 6a 1b 1e :2 6a 2a 2d
:2 6a 32 35 :2 6a :2 7 49 :2 4 7
:2 11 23 :2 2d 39 3c 4b 4d 4e
:2 4b :2 23 :3 7 :2 d 12 1e 5b 5e
:2 1e :2 7 51 :2 4 :4 9 8 7 :4 1e
1d 1c :2 7 :4 37 36 35 :2 7 a
:2 14 26 :2 30 3c 3f 4e 50 51
:2 4e :2 26 :3 a :2 10 15 21 5e 61
:2 21 6e 71 :2 21 75 78 :2 21 82
85 8e 96 :2 9f :2 8e b0 :2 85 :2 21
:2 a 54 :2 7 a :2 14 26 :2 30 3c
3f 4e 50 51 :2 4e :2 26 :3 a :2 10
15 21 5e 61 :2 21 :2 a 54 :3 7
:2 12 28 :2 31 41 :2 7 4d :3 4 14
:2 4 15 :2 4 12 :2 4 14 4 7
10 1e :2 7 23 21 :2 2c :2 21 11
1e 2d 41 4e :2 a :2 13 1f a
7 :2 f d :2 16 22 d 10 :2 1a
2c :2 36 42 46 55 57 58 :2 55
:2 2c :3 10 :2 16 1b 27 64 67 :2 27
74 77 :2 27 7b 7e :2 27 8a 8d
:2 27 95 98 :2 27 a4 a7 ae b7
ba :2 a7 :2 27 :2 10 5b :2 d :2 a :4 16
:2 a 7 :3 39 4 39 a 13 21
:2 a 26 24 :2 2f :2 24 11 1e 2d
4b 58 :2 a :2 13 1f a 7 :2 f
d :2 16 22 d 10 :2 1a 2c :2 36
42 46 55 57 58 :2 55 :2 2c :3 10
:2 16 1b 27 64 67 :2 27 74 77
:2 27 7b 7e :2 27 8a 8d :2 27 95
98 :2 27 a4 a7 ae b7 ba :2 a7
:2 27 :2 10 5b :2 d :2 a :4 16 :2 a 7
:3 3c 4 3c 39 a 13 21 :2 a
26 24 :2 2f :2 24 11 1e 2d 46
53 :2 a :2 13 1f a 7 :2 f d
:2 16 22 d 10 :2 1a 2c :2 36 42
46 55 57 58 :2 55 :2 2c :3 10 :2 16
1b 27 64 67 :2 27 74 77 :2 27
7b 7e :2 27 8a 8d :2 27 95 98
:2 27 a4 a7 ae b7 ba :2 a7 :2 27
:2 10 5b :2 d :2 a :4 16 :2 a 7 :3 40
4 40 39 a 13 21 :2 a 26
24 :2 2f :2 24 11 1e 2d 4a 57
:2 a :2 13 1f a 7 :2 f d :2 16
22 d 10 :2 1a 2c :2 36 42 46
55 57 58 :2 55 :2 2c :3 10 :2 16 1b
27 64 67 :2 27 74 77 :2 27 7b
7e :2 27 8a 8d :2 27 95 98 :2 27
a4 a7 ae b7 ba :2 a7 :2 27 :2 10
5b :2 d :2 a :4 16 :2 a 7 :3 40 4
40 39 a 13 21 :2 a 26 24
:2 2f :2 24 11 1e 2d 48 55 :2 a
:2 13 1f a 7 :2 f d :2 16 22
d 10 :2 1a 2c :2 36 42 46 55
58 59 :2 55 :2 2c :3 10 :2 16 1b 27
65 68 :2 27 75 78 :2 27 7c 7f
:2 27 8b 8e :2 27 96 99 :2 27 a5
a8 af b8 bb :2 a8 :2 27 :2 10 5c
:2 d :2 a :4 16 :2 a 7 :3 40 4 40
39 a 13 21 :2 a 26 24 :2 2f
:2 24 11 1e 2d 47 54 :2 a :2 13
1f a 7 :2 f d :2 16 22 d
10 :2 1a 2c :2 36 42 46 55 58
59 :2 55 :2 2c :3 10 :2 16 1b 27 65
68 :2 27 75 78 :2 27 7c 7f :2 27
8b 8e :2 27 96 99 :2 27 a5 a8
af b8 bb :2 a8 :2 27 :2 10 5c :2 d
:2 a :4 16 :2 a 7 :3 40 4 40 39
a 13 21 :2 a 26 24 :2 2f :2 24
11 1e 2d 48 55 :2 a :2 13 1f
a 7 :2 f d :2 16 22 d 10
:2 1a 2c :2 36 42 46 55 58 59
:2 55 :2 2c :3 10 :2 16 1b 27 65 68
:2 27 75 78 :2 27 7c 7f :2 27 8b
8e :2 27 96 99 :2 27 a5 a8 af
b8 bb :2 a8 :2 27 :2 10 5c :2 d :2 a
:4 16 :2 a 7 :4 40 39 :3 4 :3 f :2 4
:2 d 19 28 36 41 4f 5e 27
:2 19 4 7 :2 11 23 :2 2d 39 3c
4b 4e 4f :2 4b :2 23 :3 7 :2 d 12
1e 5c 5f :2 1e 6c 6f :2 1e 73
76 :2 1e 80 83 8c 94 :2 9d :2 8c
a8 :2 83 :2 1e b0 b3 :2 1e bb be
:2 1e c3 c6 :2 1e ce d1 :2 1e :2 7
52 :3 4 :2 f 21 :2 2a 34 3d :2 4
1 9 12 9 a :2 14 26 :2 30
3c 40 4f 52 53 :2 4f :2 26 :3 a
:2 10 15 21 5f 62 :2 21 :3 a :2 10
15 39 5c 5f :2 68 :2 39 76 79
:2 39 81 84 :2 8d :2 39 :2 a 56 :3 7
c 15 1e 2c a 13 1e f
e 7 e 7 e 7 29 :2 4
:2 9 7 :2 10 1c :2 7 :2 11 23 :2 2d
39 3d 4c 4f 50 :2 4c :2 23 :3 7
:2 d 12 1e 5c 5f :2 1e :3 7 :2 d
12 36 42 45 :2 36 4d 50 :2 36
5c 5f 66 6f 72 :2 5f :2 36 :2 7
53 :2 4 7 c 1b a 13 1e
f e 7 e 7 e 7 :2 4
:4 10 :2 4 :8 1 
512
4
0 :2 1 :4 3 :4 4
:4 5 :4 6 2 :4 7
:2 1 :7 9 :7 a :7 b
:7 c :6 d :6 e :7 10
:b 12 :11 13 :8 14 :2 13
:2 15 :2 13 :2 15 :2 13
:2 15 :2 13 :2 15 :2 13
:2 16 :2 13 :2 16 :2 13
:2 16 :2 13 :2 16 :2 13
:2 17 :2 13 :2 17 :2 13
:2 17 :2 13 :2 17 :2 13
:2 17 :4 13 :3 12 :11 1a
:b 1b :3 1a :16 1e :11 1f
:20 20 :3 1f :11 22 :b 23
:3 22 :9 25 :3 1e :3 2a
:3 2b :3 2c :3 2d :b 2f
:6 31 :5 32 30 :2 34
:5 36 :11 37 :24 38 :3 37
:2 35 :6 34 33 :3 2f
3c 2f :b 3c :6 3e
:5 3f 3d :2 41 :5 43
:11 44 :24 45 :3 44 :2 42
:6 41 40 :3 3c 49
3c 2f :b 49 :6 4b
:5 4c 4a :2 4e :5 50
:11 51 :24 52 :3 51 :2 4f
:6 4e 4d :3 49 56
49 2f :b 56 :6 58
:5 59 57 :2 5b :5 5d
:11 5e :24 5f :3 5e :2 5c
:6 5b 5a :3 56 63
56 2f :b 63 :6 65
:5 66 64 :2 68 :5 6a
:11 6b :24 6c :3 6b :2 69
:6 68 67 :3 63 70
63 2f :b 70 :6 72
:5 73 71 :2 75 :5 77
:11 78 :24 79 :3 78 :2 76
:6 75 74 :3 70 7d
70 2f :b 7d :6 7f
:5 80 7e :2 82 :5 84
:11 85 :24 86 :3 85 :2 83
:6 82 81 :4 7d :3 2f
:5 8c :9 8e 8f :3 8e
:11 91 :30 92 :3 91 :a 94
11 :3 97 :11 98 :b 99
:17 9a :3 98 :2 9c :3 9d
:3 9e 9f 9d 9c
9d :3 a0 :3 97 :2 a1
:5 a3 :11 a4 :b a5 :18 a6
:3 a4 :2 a8 a9 :3 aa
ab a9 a8 a9
:3 ac :2 a2 :6 a1 96
:7 1 
11e2
4
:3 0 1 :3 0 2
:a 0 50d 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
56 0 7 6
:3 0 5 :7 0 9
8 :3 0 6 :3 0
7 :7 0 d c
:3 0 15 16 0
b 6 :3 0 8
:7 0 11 10 :3 0
9 :3 0 a :3 0
b :2 0 4 13
17 0 50d 2
18 :2 0 d :2 0
12 6 :3 0 d
:2 0 10 1b 1d
:6 0 20 1e 0
50b 0 c :6 0
d :2 0 16 6
:3 0 14 22 24
:6 0 27 25 0
50b 0 e :6 0
d :2 0 1a 6
:3 0 18 29 2b
:6 0 2e 2c 0
50b 0 f :6 0
12 :2 0 1e 6
:3 0 1c 30 32
:6 0 35 33 0
50b 0 10 :6 0
12 :2 0 20 4
:3 0 37 :7 0 3b
38 39 50b 0
11 :6 0 43 44
0 22 4 :3 0
3d :7 0 41 3e
3f 50b 0 13
:6 0 49 4a 0
24 a :3 0 b
:2 0 4 45 :7 0
48 46 0 50b
0 14 :6 0 15
:3 0 16 :3 0 15
:3 0 17 :3 0 4c
4d 0 2 :4 0
26 4e 50 4b
52 51 :2 0 18
:3 0 19 :3 0 54
55 0 1a :4 0
15 :3 0 1b :3 0
58 59 0 2
:4 0 28 5a 5c
1c :4 0 1d :2 0
1e :3 0 2a 5f
61 :3 0 1f :4 0
1d :2 0 20 :3 0
21 :3 0 3 :3 0
2d 66 68 22
:4 0 2f 65 6b
32 64 6d :3 0
1d :2 0 23 :4 0
35 6f 71 :3 0
1d :2 0 24 :4 0
38 73 75 :3 0
1d :2 0 5 :3 0
3b 77 79 :3 0
1d :2 0 24 :4 0
3e 7b 7d :3 0
1d :2 0 23 :4 0
41 7f 81 :3 0
1d :2 0 24 :4 0
44 83 85 :3 0
1d :2 0 7 :3 0
47 87 89 :3 0
1d :2 0 24 :4 0
4a 8b 8d :3 0
1d :2 0 23 :4 0
4d 8f 91 :3 0
1d :2 0 24 :4 0
50 93 95 :3 0
1d :2 0 8 :3 0
53 97 99 :3 0
1d :2 0 24 :4 0
56 9b 9d :3 0
1d :2 0 25 :4 0
59 9f a1 :3 0
5c 56 a3 :2 0
a5 61 a6 53
a5 0 a7 63
0 46b 15 :3 0
16 :3 0 a8 a9
0 15 :3 0 26
:3 0 ab ac 0
27 :2 0 2 :4 0
28 :2 0 29 :2 0
27 :2 0 65 b1
b3 :3 0 68 ad
b5 aa b7 b6
:2 0 18 :3 0 2a
:3 0 b9 ba 0
1a :4 0 2b :4 0
1d :2 0 1e :3 0
6c be c0 :3 0
6f bb c2 :2 0
c4 72 c5 b8
c4 0 c6 74
0 46b 5 :3 0
2c :2 0 76 c8
c9 :3 0 ca :2 0
cb :2 0 7 :3 0
2c :2 0 78 ce
cf :3 0 d0 :2 0
d1 :2 0 cc d3
d2 :2 0 8 :3 0
2c :2 0 7a d6
d7 :3 0 d8 :2 0
d9 :2 0 d4 db
da :2 0 15 :3 0
16 :3 0 dd de
0 15 :3 0 26
:3 0 e0 e1 0
2d :2 0 2 :4 0
2e :2 0 29 :2 0
27 :2 0 7c e6
e8 :3 0 7f e2
ea df ec eb
:2 0 18 :3 0 2a
:3 0 ee ef 0
1a :4 0 2f :4 0
1d :2 0 1e :3 0
83 f3 f5 :3 0
1d :2 0 30 :4 0
86 f7 f9 :3 0
1d :2 0 31 :4 0
89 fb fd :3 0
1d :2 0 20 :3 0
21 :3 0 32 :3 0
33 :3 0 102 103
0 8c 101 105
22 :4 0 8e 100
108 91 ff 10a
:3 0 94 f0 10c
:2 0 10e 97 10f
ed 10e 0 110
99 0 139 15
:3 0 16 :3 0 111
112 0 15 :3 0
26 :3 0 114 115
0 27 :2 0 2
:4 0 34 :2 0 29
:2 0 27 :2 0 9b
11a 11c :3 0 9e
116 11e 113 120
11f :2 0 18 :3 0
2a :3 0 122 123
0 1a :4 0 35
:4 0 1d :2 0 1e
:3 0 a2 127 129
:3 0 a5 124 12b
:2 0 12d a8 12e
121 12d 0 12f
aa 0 139 36
:3 0 37 :3 0 130
131 0 32 :3 0
33 :3 0 133 134
0 38 :3 0 ac
132 137 :2 0 139
af 13a dc 139
0 13b b3 0
46b c :3 0 5
:3 0 13c 13d 0
46b 10 :3 0 7
:3 0 13f 140 0
46b f :3 0 8
:3 0 142 143 0
46b 11 :3 0 3
:3 0 145 146 0
46b 20 :3 0 11
:3 0 12 :2 0 b5
148 14b 32 :3 0
39 :2 0 3a :3 0
14d 14f 0 ba
14e 151 :3 0 3b
:3 0 13 :3 0 3c
:3 0 3d :3 0 c
:4 0 3e 1 :8 0
15e a :3 0 3f
:3 0 159 15a 0
40 :3 0 15b 15c
0 15e bd 1a8
41 :3 0 a :3 0
3f :3 0 161 162
0 40 :3 0 163
164 0 19e 15
:3 0 16 :3 0 166
167 0 15 :3 0
26 :3 0 169 16a
0 42 :2 0 2
:4 0 43 :2 0 29
:2 0 27 :2 0 c0
16f 171 :3 0 c3
16b 173 168 175
174 :2 0 18 :3 0
2a :3 0 177 178
0 1a :4 0 44
:4 0 1d :2 0 1e
:3 0 c7 17c 17e
:3 0 1d :2 0 30
:4 0 ca 180 182
:3 0 1d :2 0 45
:4 0 cd 184 186
:3 0 1d :2 0 40
:3 0 d0 188 18a
:3 0 1d :2 0 46
:4 0 d3 18c 18e
:3 0 1d :2 0 47
:3 0 48 :3 0 27
:2 0 49 :2 0 d6
191 195 da 190
197 :3 0 dd 179
199 :2 0 19b e0
19c 176 19b 0
19d e2 0 19e
e4 1a1 :3 0 1a1
0 1a1 1a0 19e
19f :6 0 1a3 2
:3 0 e7 1a5 e9
1a4 1a3 :2 0 1a6
eb :2 0 1a8 0
1a8 1a7 15e 1a6
:6 0 1ab 1 :3 0
4a :3 0 ed 409
20 :3 0 11 :3 0
12 :2 0 ef 1ac
1af 32 :3 0 39
:2 0 4b :3 0 1b1
1b3 0 f4 1b2
1b5 :3 0 3b :3 0
13 :3 0 4c :3 0
3d :3 0 c :4 0
4d 1 :8 0 1c2
a :3 0 3f :3 0
1bd 1be 0 40
:3 0 1bf 1c0 0
1c2 f7 20c 41
:3 0 a :3 0 3f
:3 0 1c5 1c6 0
40 :3 0 1c7 1c8
0 202 15 :3 0
16 :3 0 1ca 1cb
0 15 :3 0 26
:3 0 1cd 1ce 0
42 :2 0 2 :4 0
4e :2 0 29 :2 0
27 :2 0 fa 1d3
1d5 :3 0 fd 1cf
1d7 1cc 1d9 1d8
:2 0 18 :3 0 2a
:3 0 1db 1dc 0
1a :4 0 4f :4 0
1d :2 0 1e :3 0
101 1e0 1e2 :3 0
1d :2 0 30 :4 0
104 1e4 1e6 :3 0
1d :2 0 45 :4 0
107 1e8 1ea :3 0
1d :2 0 40 :3 0
10a 1ec 1ee :3 0
1d :2 0 46 :4 0
10d 1f0 1f2 :3 0
1d :2 0 47 :3 0
48 :3 0 27 :2 0
49 :2 0 110 1f5
1f9 114 1f4 1fb
:3 0 117 1dd 1fd
:2 0 1ff 11a 200
1da 1ff 0 201
11c 0 202 11e
205 :3 0 205 0
205 204 202 203
:6 0 207 4 :3 0
121 209 123 208
207 :2 0 20a 125
:2 0 20c 0 20c
20b 1c2 20a :6 0
20f 1 :3 0 4a
:3 0 127 210 1b6
20f 0 40a 20
:3 0 11 :3 0 12
:2 0 129 211 214
32 :3 0 39 :2 0
50 :3 0 216 218
0 12e 217 21a
:3 0 3b :3 0 13
:3 0 51 :3 0 3d
:3 0 c :4 0 52
1 :8 0 227 a
:3 0 3f :3 0 222
223 0 40 :3 0
224 225 0 227
131 271 41 :3 0
a :3 0 3f :3 0
22a 22b 0 40
:3 0 22c 22d 0
267 15 :3 0 16
:3 0 22f 230 0
15 :3 0 26 :3 0
232 233 0 42
:2 0 2 :4 0 53
:2 0 29 :2 0 27
:2 0 134 238 23a
:3 0 137 234 23c
231 23e 23d :2 0
18 :3 0 2a :3 0
240 241 0 1a
:4 0 54 :4 0 1d
:2 0 1e :3 0 13b
245 247 :3 0 1d
:2 0 30 :4 0 13e
249 24b :3 0 1d
:2 0 45 :4 0 141
24d 24f :3 0 1d
:2 0 40 :3 0 144
251 253 :3 0 1d
:2 0 46 :4 0 147
255 257 :3 0 1d
:2 0 47 :3 0 48
:3 0 27 :2 0 49
:2 0 14a 25a 25e
14e 259 260 :3 0
151 242 262 :2 0
264 154 265 23f
264 0 266 156
0 267 158 26a
:3 0 26a 0 26a
269 267 268 :6 0
26c 6 :3 0 15b
26e 15d 26d 26c
:2 0 26f 15f :2 0
271 0 271 270
227 26f :6 0 274
1 :3 0 4a :3 0
161 275 21b 274
0 40a 20 :3 0
11 :3 0 12 :2 0
163 276 279 32
:3 0 39 :2 0 55
:3 0 27b 27d 0
168 27c 27f :3 0
3b :3 0 13 :3 0
56 :3 0 3d :3 0
c :4 0 57 1
:8 0 28c a :3 0
3f :3 0 287 288
0 40 :3 0 289
28a 0 28c 16b
2d6 41 :3 0 a
:3 0 3f :3 0 28f
290 0 40 :3 0
291 292 0 2cc
15 :3 0 16 :3 0
294 295 0 15
:3 0 26 :3 0 297
298 0 42 :2 0
2 :4 0 58 :2 0
29 :2 0 27 :2 0
16e 29d 29f :3 0
171 299 2a1 296
2a3 2a2 :2 0 18
:3 0 2a :3 0 2a5
2a6 0 1a :4 0
59 :4 0 1d :2 0
1e :3 0 175 2aa
2ac :3 0 1d :2 0
30 :4 0 178 2ae
2b0 :3 0 1d :2 0
45 :4 0 17b 2b2
2b4 :3 0 1d :2 0
40 :3 0 17e 2b6
2b8 :3 0 1d :2 0
46 :4 0 181 2ba
2bc :3 0 1d :2 0
47 :3 0 48 :3 0
27 :2 0 49 :2 0
184 2bf 2c3 188
2be 2c5 :3 0 18b
2a7 2c7 :2 0 2c9
18e 2ca 2a4 2c9
0 2cb 190 0
2cc 192 2cf :3 0
2cf 0 2cf 2ce
2cc 2cd :6 0 2d1
8 :3 0 195 2d3
197 2d2 2d1 :2 0
2d4 199 :2 0 2d6
0 2d6 2d5 28c
2d4 :6 0 2d9 1
:3 0 4a :3 0 19b
2da 280 2d9 0
40a 20 :3 0 11
:3 0 12 :2 0 19d
2db 2de 32 :3 0
39 :2 0 5a :3 0
2e0 2e2 0 1a2
2e1 2e4 :3 0 3b
:3 0 13 :3 0 5b
:3 0 3d :3 0 c
:4 0 5c 1 :8 0
2f1 a :3 0 3f
:3 0 2ec 2ed 0
40 :3 0 2ee 2ef
0 2f1 1a5 33b
41 :3 0 a :3 0
3f :3 0 2f4 2f5
0 40 :3 0 2f6
2f7 0 331 15
:3 0 16 :3 0 2f9
2fa 0 15 :3 0
26 :3 0 2fc 2fd
0 42 :2 0 2
:4 0 5d :2 0 29
:2 0 27 :2 0 1a8
302 304 :3 0 1ab
2fe 306 2fb 308
307 :2 0 18 :3 0
2a :3 0 30a 30b
0 1a :4 0 5e
:4 0 1d :2 0 1e
:3 0 1af 30f 311
:3 0 1d :2 0 30
:4 0 1b2 313 315
:3 0 1d :2 0 45
:4 0 1b5 317 319
:3 0 1d :2 0 40
:3 0 1b8 31b 31d
:3 0 1d :2 0 46
:4 0 1bb 31f 321
:3 0 1d :2 0 47
:3 0 48 :3 0 27
:2 0 49 :2 0 1be
324 328 1c2 323
32a :3 0 1c5 30c
32c :2 0 32e 1c8
32f 309 32e 0
330 1ca 0 331
1cc 334 :3 0 334
0 334 333 331
332 :6 0 336 a
:3 0 1cf 338 1d1
337 336 :2 0 339
1d3 :2 0 33b 0
33b 33a 2f1 339
:6 0 33e 1 :3 0
4a :3 0 1d5 33f
2e5 33e 0 40a
20 :3 0 11 :3 0
12 :2 0 1d7 340
343 32 :3 0 39
:2 0 5f :3 0 345
347 0 1dc 346
349 :3 0 3b :3 0
13 :3 0 60 :3 0
3d :3 0 c :4 0
61 1 :8 0 356
a :3 0 3f :3 0
351 352 0 40
:3 0 353 354 0
356 1df 3a0 41
:3 0 a :3 0 3f
:3 0 359 35a 0
40 :3 0 35b 35c
0 396 15 :3 0
16 :3 0 35e 35f
0 15 :3 0 26
:3 0 361 362 0
42 :2 0 2 :4 0
62 :2 0 29 :2 0
27 :2 0 1e2 367
369 :3 0 1e5 363
36b 360 36d 36c
:2 0 18 :3 0 2a
:3 0 36f 370 0
1a :4 0 63 :4 0
1d :2 0 1e :3 0
1e9 374 376 :3 0
1d :2 0 30 :4 0
1ec 378 37a :3 0
1d :2 0 45 :4 0
1ef 37c 37e :3 0
1d :2 0 40 :3 0
1f2 380 382 :3 0
1d :2 0 46 :4 0
1f5 384 386 :3 0
1d :2 0 47 :3 0
48 :3 0 27 :2 0
49 :2 0 1f8 389
38d 1fc 388 38f
:3 0 1ff 371 391
:2 0 393 202 394
36e 393 0 395
204 0 396 206
399 :3 0 399 0
399 398 396 397
:6 0 39b c :3 0
209 39d 20b 39c
39b :2 0 39e 20d
:2 0 3a0 0 3a0
39f 356 39e :6 0
3a3 1 :3 0 4a
:3 0 20f 3a4 34a
3a3 0 40a 20
:3 0 11 :3 0 12
:2 0 211 3a5 3a8
32 :3 0 39 :2 0
64 :3 0 3aa 3ac
0 216 3ab 3ae
:3 0 3b :3 0 13
:3 0 65 :3 0 3d
:3 0 c :4 0 66
1 :8 0 3bb a
:3 0 3f :3 0 3b6
3b7 0 40 :3 0
3b8 3b9 0 3bb
219 405 41 :3 0
a :3 0 3f :3 0
3be 3bf 0 40
:3 0 3c0 3c1 0
3fb 15 :3 0 16
:3 0 3c3 3c4 0
15 :3 0 26 :3 0
3c6 3c7 0 42
:2 0 2 :4 0 67
:2 0 29 :2 0 27
:2 0 21c 3cc 3ce
:3 0 21f 3c8 3d0
3c5 3d2 3d1 :2 0
18 :3 0 2a :3 0
3d4 3d5 0 1a
:4 0 68 :4 0 1d
:2 0 1e :3 0 223
3d9 3db :3 0 1d
:2 0 30 :4 0 226
3dd 3df :3 0 1d
:2 0 45 :4 0 229
3e1 3e3 :3 0 1d
:2 0 40 :3 0 22c
3e5 3e7 :3 0 1d
:2 0 46 :4 0 22f
3e9 3eb :3 0 1d
:2 0 47 :3 0 48
:3 0 27 :2 0 49
:2 0 232 3ee 3f2
236 3ed 3f4 :3 0
239 3d6 3f6 :2 0
3f8 23c 3f9 3d3
3f8 0 3fa 23e
0 3fb 240 3fe
:3 0 3fe 0 3fe
3fd 3fb 3fc :6 0
400 e :3 0 243
402 245 401 400
:2 0 403 247 :2 0
405 0 405 404
3bb 403 :6 0 407
1 :3 0 249 408
3af 407 0 40a
152 1ab 0 40a
24b 0 46b e
:3 0 69 :4 0 40c
40d :3 0 40b 40e
0 46b a :3 0
3f :3 0 410 411
0 6a :3 0 11
:3 0 13 :3 0 c
:3 0 10 :3 0 f
:3 0 e :3 0 253
413 41a 412 41b
0 46b 15 :3 0
16 :3 0 41d 41e
0 15 :3 0 26
:3 0 420 421 0
6b :2 0 2 :4 0
6c :2 0 29 :2 0
27 :2 0 25a 426
428 :3 0 25d 422
42a 41f 42c 42b
:2 0 18 :3 0 2a
:3 0 42e 42f 0
1a :4 0 6d :4 0
1d :2 0 1e :3 0
261 433 435 :3 0
1d :2 0 30 :4 0
264 437 439 :3 0
1d :2 0 31 :4 0
267 43b 43d :3 0
1d :2 0 20 :3 0
21 :3 0 a :3 0
3f :3 0 442 443
0 26a 441 445
22 :4 0 26c 440
448 26f 43f 44a
:3 0 1d :2 0 6e
:4 0 272 44c 44e
:3 0 1d :2 0 24
:4 0 275 450 452
:3 0 1d :2 0 e
:3 0 278 454 456
:3 0 1d :2 0 24
:4 0 27b 458 45a
:3 0 27e 430 45c
:2 0 45e 281 45f
42d 45e 0 460
283 0 46b 36
:3 0 6f :3 0 461
462 0 a :3 0
3f :3 0 464 465
0 e :3 0 38
:3 0 285 463 469
:2 0 46b 289 50c
a :3 0 70 :2 0
4 46c 46d 0
15 :3 0 16 :3 0
46f 470 0 15
:3 0 26 :3 0 472
473 0 42 :2 0
2 :4 0 71 :2 0
29 :2 0 27 :2 0
296 478 47a :3 0
299 474 47c 471
47e 47d :2 0 18
:3 0 2a :3 0 480
481 0 1a :4 0
72 :4 0 1d :2 0
1e :3 0 29d 485
487 :3 0 2a0 482
489 :2 0 4a2 18
:3 0 2a :3 0 48b
48c 0 1a :4 0
73 :4 0 1d :2 0
a :3 0 74 :3 0
491 492 0 2a3
490 494 :3 0 1d
:2 0 6e :4 0 2a6
496 498 :3 0 1d
:2 0 a :3 0 75
:3 0 49b 49c 0
2a9 49a 49e :3 0
2ac 48d 4a0 :2 0
4a2 2af 4a3 47f
4a2 0 4a4 2b2
0 4b4 76 :3 0
14 :3 0 a :3 0
74 :3 0 77 :3 0
a :3 0 75 :3 0
78 :3 0 79 :4 0
7a 1 :a 0 4b0
:2 0 4b4 4a6 4ae
:2 0 9 :3 0 14
:3 0 4b2 :2 0 4b4
2b4 4b6 2b8 4b5
4b4 :2 0 50a 41
:3 0 a :3 0 3f
:3 0 4b9 4ba 0
40 :3 0 4bb 4bc
0 502 15 :3 0
16 :3 0 4be 4bf
0 15 :3 0 26
:3 0 4c1 4c2 0
42 :2 0 2 :4 0
7b :2 0 29 :2 0
27 :2 0 2ba 4c7
4c9 :3 0 2bd 4c3
4cb 4c0 4cd 4cc
:2 0 18 :3 0 2a
:3 0 4cf 4d0 0
1a :4 0 7c :4 0
1d :2 0 1e :3 0
2c1 4d4 4d6 :3 0
2c4 4d1 4d8 :2 0
4f2 18 :3 0 2a
:3 0 4da 4db 0
1a :4 0 45 :4 0
1d :2 0 40 :3 0
2c7 4df 4e1 :3 0
1d :2 0 46 :4 0
2ca 4e3 4e5 :3 0
1d :2 0 47 :3 0
48 :3 0 27 :2 0
49 :2 0 2cd 4e8
4ec 2d1 4e7 4ee
:3 0 2d4 4dc 4f0
:2 0 4f2 2d7 4f3
4ce 4f2 0 4f4
2da 0 502 76
:3 0 14 :3 0 77
:3 0 a :3 0 75
:3 0 78 :3 0 79
:4 0 7d 1 :a 0
4fe :2 0 502 4f6
4fc :2 0 9 :3 0
14 :3 0 500 :2 0
502 2dc 505 :3 0
505 0 505 504
502 503 :6 0 507
1 :3 0 2e1 509
2e3 508 507 :2 0
50a 2e5 :2 0 50c
2e8 50c 50b 46b
50a :6 0 50d :2 0
2 18 50c 510
:3 0 50f 50d 511
:8 0 
2f0
4
:3 0 1 3 1
7 1 b 1
f 4 6 a
e 12 1 1c
1 1a 1 23
1 21 1 2a
1 28 1 31
1 2f 1 36
1 3c 1 42
1 4f 1 5b
2 5e 60 1
67 2 69 6a
2 63 6c 2
6e 70 2 72
74 2 76 78
2 7a 7c 2
7e 80 2 82
84 2 86 88
2 8a 8c 2
8e 90 2 92
94 2 96 98
2 9a 9c 2
9e a0 4 57
5d 62 a2 1
a4 1 a6 2
b0 b2 3 ae
af b4 2 bd
bf 2 bc c1
1 c3 1 c5
1 c7 1 cd
1 d5 2 e5
e7 3 e3 e4
e9 2 f2 f4
2 f6 f8 2
fa fc 1 104
2 106 107 2
fe 109 2 f1
10b 1 10d 1
10f 2 119 11b
3 117 118 11d
2 126 128 2
125 12a 1 12c
1 12e 2 135
136 3 110 12f
138 1 13a 2
149 14a 1 150
2 14c 150 2
158 15d 2 16e
170 3 16c 16d
172 2 17b 17d
2 17f 181 2
183 185 2 187
189 2 18b 18d
3 192 193 194
2 18f 196 2
17a 198 1 19a
1 19c 2 165
19d 1 1a1 1
160 1 1a5 1
1a8 2 1ad 1ae
1 1b4 2 1b0
1b4 2 1bc 1c1
2 1d2 1d4 3
1d0 1d1 1d6 2
1df 1e1 2 1e3
1e5 2 1e7 1e9
2 1eb 1ed 2
1ef 1f1 3 1f6
1f7 1f8 2 1f3
1fa 2 1de 1fc
1 1fe 1 200
2 1c9 201 1
205 1 1c4 1
209 1 20c 2
212 213 1 219
2 215 219 2
221 226 2 237
239 3 235 236
23b 2 244 246
2 248 24a 2
24c 24e 2 250
252 2 254 256
3 25b 25c 25d
2 258 25f 2
243 261 1 263
1 265 2 22e
266 1 26a 1
229 1 26e 1
271 2 277 278
1 27e 2 27a
27e 2 286 28b
2 29c 29e 3
29a 29b 2a0 2
2a9 2ab 2 2ad
2af 2 2b1 2b3
2 2b5 2b7 2
2b9 2bb 3 2c0
2c1 2c2 2 2bd
2c4 2 2a8 2c6
1 2c8 1 2ca
2 293 2cb 1
2cf 1 28e 1
2d3 1 2d6 2
2dc 2dd 1 2e3
2 2df 2e3 2
2eb 2f0 2 301
303 3 2ff 300
305 2 30e 310
2 312 314 2
316 318 2 31a
31c 2 31e 320
3 325 326 327
2 322 329 2
30d 32b 1 32d
1 32f 2 2f8
330 1 334 1
2f3 1 338 1
33b 2 341 342
1 348 2 344
348 2 350 355
2 366 368 3
364 365 36a 2
373 375 2 377
379 2 37b 37d
2 37f 381 2
383 385 3 38a
38b 38c 2 387
38e 2 372 390
1 392 1 394
2 35d 395 1
399 1 358 1
39d 1 3a0 2
3a6 3a7 1 3ad
2 3a9 3ad 2
3b5 3ba 2 3cb
3cd 3 3c9 3ca
3cf 2 3d8 3da
2 3dc 3de 2
3e0 3e2 2 3e4
3e6 2 3e8 3ea
3 3ef 3f0 3f1
2 3ec 3f3 2
3d7 3f5 1 3f7
1 3f9 2 3c2
3fa 1 3fe 1
3bd 1 402 1
405 7 409 210
275 2da 33f 3a4
408 6 414 415
416 417 418 419
2 425 427 3
423 424 429 2
432 434 2 436
438 2 43a 43c
1 444 2 446
447 2 43e 449
2 44b 44d 2
44f 451 2 453
455 2 457 459
2 431 45b 1
45d 1 45f 3
466 467 468 c
a7 c6 13b 13e
141 144 147 40a
40f 41c 460 46a
2 477 479 3
475 476 47b 2
484 486 2 483
488 2 48f 493
2 495 497 2
499 49d 2 48e
49f 2 48a 4a1
1 4a3 3 4a4
4af 4b3 1 46e
2 4c6 4c8 3
4c4 4c5 4ca 2
4d3 4d5 2 4d2
4d7 2 4de 4e0
2 4e2 4e4 3
4e9 4ea 4eb 2
4e6 4ed 2 4dd
4ef 2 4d9 4f1
1 4f3 4 4bd
4f4 4fd 501 1
505 1 4b8 2
4b6 509 7 1f
26 2d 34 3a
40 47 
1
4
0 
510
0
1
14
10
c
0 1 2 1 4 1 6 1
8 1 a 1 c 1 e 1
0 0 0 0 
f 1 0
1a 1 0
2f 1 0
b 1 0
3c 1 0
7 1 0
21 1 0
36 1 0
28 1 0
3 1 0
2 0 1
42 1 0
0

/
SHOW ERRORS FUNCTION SP_A_DOCRES;
ALTER FUNCTION SP_A_DOCRES COMPILE DEBUG;
/*****************************************************************************************/
Prompt == FUNCTION FC_U_CREATETMPTABLE ==
CREATE OR REPLACE FUNCTION FC_U_CREATETMPTABLE wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
1f
2 :e:
1FUNCTION:
1FC_U_CREATETMPTABLE:
1RETURN:
1PLS_INTEGER:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= FC_U_CREATETMPTABLE();:
1CHECK_TRACE:
11:
18:
1+:
1FPUT:
1               ENTER:: FC_U_CREATETMPTABLE(9) :: cplan.sql(6606) :: :
1EXECUTE:
1IMMEDIATE:
1DELETE FROM PMO_TMP_CPLN01_TEMP:
1PMO_DB2M:
1SC_STATE:
10:
117:
1                EXIT:: FC_U_CREATETMPTABLE(18) :: cplan.sql(6615) :: :
1 :
1STATE:: :
0

0
0
8c
2
0 a0 8d a0 b4 a0 2c 6a
:2 a0 6b :2 a0 6b 6e a5 b a
10 :2 a0 6b 6e :2 a0 6b 6e a5
b 6e 7e a0 b4 2e 6e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6e 11e 11d :2 a0 6b 51 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :2 a0 6b
b4 2e a5 57 b7 19 3c :3 a0
6b 65 b7 a4 b1 11 68 4f
1d 17 b5 
8c
2
0 3 f b a 23 27 2b
2f 33 7 37 3b 3f 42 47
48 1 4a 4f 53 57 5a 5f
63 67 6a 6f 70 72 77 7a
7e 7f 84 89 8a 8f 91 95
98 9c a0 a3 a7 ab ae b1
b6 b9 bc bf c0 c5 c6 1
c8 cd d1 d5 d8 dd e2 e5
e9 ea ef f0 f5 f7 fb fe
102 106 10b 110 114 118 11c 11f
122 126 12a 12e 131 135 139 13c
13f 144 147 14a 14d 14e 153 154
1 156 15b 15f 163 166 16b 170
173 177 178 17d 180 185 186 18b
18e 193 194 199 19c 1a0 1a4 1a7
1a8 1ad 1ae 1b3 1b5 1b9 1bc 1c0
1c4 1c8 1cb 1cf 1d1 1d5 1d7 1e3
1e7 1e9 1ea 1f3 
8c
2
0 1 a 1e 0 25 :2 1 7
:2 11 23 :2 2d 3a :2 23 :3 7 :2 d 19
25 :2 2f 43 :2 25 5b 61 64 :2 5b
72 :2 7 51 :2 4 7 :2 11 23 :2 2d
39 3c 53 54 55 :2 53 :2 23 :3 7
:2 d 12 1e 62 65 :2 1e :2 7 58
:3 4 c 16 :3 4 :2 d 19 4 7
:2 11 23 :2 2d 39 3c 53 55 56
:2 53 :2 23 :3 7 :2 d 12 1e 63 66
:2 1e 73 76 :2 1e 7a 7d :2 1e 87
8a :2 93 :2 1e :2 7 59 :3 4 b :2 14
4 :9 1 
8c
4
0 :3 1 0 :3 1
:b 4 :12 5 :3 4 :11 8
:b 9 :3 8 :5 e :5 f
:11 11 :19 12 :3 11 :5 14
:2 3 :7 1 
1f5
4
:3 0 1 :3 0 8
9 :2 0 3 :3 0
2 :a 0 87 1
:7 0 4 :3 0 4
5 0 87 2
6 :2 0 5 :3 0
6 :3 0 5 :3 0
7 :3 0 b c
0 2 :4 0 3
d f a 11
10 :2 0 8 :3 0
9 :3 0 13 14
0 a :4 0 5
:3 0 b :3 0 17
18 0 2 :4 0
5 19 1b c
:4 0 d :2 0 e
:3 0 7 1e 20
:3 0 f :4 0 a
15 23 :2 0 25
f 26 12 25
0 27 11 0
83 5 :3 0 6
:3 0 28 29 0
5 :3 0 10 :3 0
2b 2c 0 11
:2 0 2 :4 0 12
:2 0 13 :2 0 11
:2 0 13 31 33
:3 0 16 2d 35
2a 37 36 :2 0
8 :3 0 14 :3 0
39 3a 0 a
:4 0 15 :4 0 d
:2 0 e :3 0 1a
3e 40 :3 0 1d
3b 42 :2 0 44
20 45 38 44
0 46 22 0
83 16 :3 0 17
:3 0 18 :4 0 49
:4 0 4a :2 0 83
19 :3 0 1a :3 0
4c 4d 0 1b
:2 0 4e 4f 0
83 5 :3 0 6
:3 0 51 52 0
5 :3 0 10 :3 0
54 55 0 11
:2 0 2 :4 0 1c
:2 0 13 :2 0 11
:2 0 24 5a 5c
:3 0 27 56 5e
53 60 5f :2 0
8 :3 0 14 :3 0
62 63 0 a
:4 0 1d :4 0 d
:2 0 e :3 0 2b
67 69 :3 0 d
:2 0 1e :4 0 2e
6b 6d :3 0 d
:2 0 1f :4 0 31
6f 71 :3 0 d
:2 0 19 :3 0 1a
:3 0 74 75 0
34 73 77 :3 0
37 64 79 :2 0
7b 3a 7c 61
7b 0 7d 3c
0 83 3 :3 0
19 :3 0 1a :3 0
7f 80 0 81
:2 0 83 3e 86
:3 0 86 0 86
85 83 84 :6 0
87 :2 0 2 6
86 8a :3 0 89
87 8b :8 0 
45
4
:3 0 1 e 1
1a 2 1d 1f
4 16 1c 21
22 1 24 1
26 2 30 32
3 2e 2f 34
2 3d 3f 2
3c 41 1 43
1 45 2 59
5b 3 57 58
5d 2 66 68
2 6a 6c 2
6e 70 2 72
76 2 65 78
1 7a 1 7c
6 27 46 4b
50 7d 82 
1
4
0 
8a
0
1
14
1
1
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 
2 0 1
0

/
SHOW ERRORS FUNCTION FC_U_CREATETMPTABLE;
ALTER FUNCTION FC_U_CREATETMPTABLE COMPILE DEBUG;
/************************************************************************************************/
/*****************************************************************************************/
Prompt == FUNCTION FC_U_TSKRES2 ==
CREATE OR REPLACE FUNCTION FC_U_TSKRES2 wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
ed
2 :e:
1FUNCTION:
1FC_U_TSKRES2:
1H_ASSIGN_ID:
1OUT:
1NOCOPY:
1VARCHAR2:
1H_AND_ROLES:
1H_AND_SKILLS:
1SH_H_WORK_LOCATION:
1PLS_INTEGER:
1H_START_DATE:
1H_FINISH_DATE:
1SH_H_EFFORT:
1SH_H_WORK:
1SH_H_EUNIT:
1SH_H_UNIT:
1SH_H_WORK_TYPE:
1SH_H_BITFLAG:
1SH_H_CONTOUR:
1SH_H_CONTOUR_TYPE:
1SH_H_OCCURRENCE:
1H_ASSIGN_STRING:
1H_REC_USER:
1RETURN:
1H_WORK_LOCATION:
1H_EFFORT:
1H_WORK:
1H_EUNIT:
1H_UNIT:
1H_WORK_TYPE:
1H_BITFLAG:
1H_CONTOUR:
1H_CONTOUR_TYPE:
1H_OCCURRENCE:
1H_TASK_ID:
132:
1H_RES_ID:
1H_START_DT:
126:
1H_FINISH_DT:
1H_DAYOFYEAR:
1DATE:
1H_LAST_SUBMITTED:
1H_TSK_ASSIGNMENT_ID:
1H_PROJECT_ID:
1H_CALENDAR_ID:
1H_SECURITY_ID:
1H_RES_TYPE:
11:
1H_BIT_FLAG:
1H_FULL_NAME:
1255:
1H_NULL_STR:
1H_MIN_PER_DAY:
10:
1H_TYPE:
1H_PER_WEEK:
1H_CONSIDER:
1H_ROLLUP:
1H_CRI:
1H_TEMP_SC_STATE:
1H_TRANSFED_CRI:
1H_WORK_TODATE:
1H_TEMP_VAR:
1H_TEMP_SECURITY_ID:
1H_TEMP2_SECURITY_ID:
1H_SD:
1H_FD:
1H_REG_COST:
1NUMBER:
1H_REG_SALE:
1H_BILLABLE:
1H_CAPITAL_EXPENSE:
1H_TPH_DELETE:
1H_DURATION:
1H_PERCENT_UNITS:
1H_SCHED_WORK:
1H_PRIORITY:
1H_UPDATE:
1H_ZERO:
1H_RES_COST:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= FC_U_TSKRES2(:
1':
1, :
1COALESCE:
1TO_CHAR:
1NULL:
1);:
1CHECK_TRACE:
194:
1+:
1FPUT:
1               ENTER:: FC_U_TSKRES2(95) :: cplan.sql(6722) :: :
1PMO_CNST:
1>=:
1SC_BIT_30:
1PMO_FUNC:
1SHIFTRIGHT:
1BITAND:
1SC_C0000000:
130:
1SC_1FFFFFFF:
1ELSIF:
1SC_BIT_28:
1SC_BIT_NOT_28:
10.00:
1=:
1PROJECT_ID:
1TASK_ID:
1RESOURCE_ID:
1RESOURCE_TYPE:
1LAST_SUBMITTED:
1WORK_TODATE:
1TO_DATE:
1SUBSTR:
1SCHED_START:
1SCHED_FINISH:
1BILLABLE:
1CAPITAL_EXPENSE:
1REGULAR_COST:
1REGULAR_RATE:
1TASK_ASSIGNMENTS:
1TSK_ASSIGNMENT_ID:
1SELECT:n         PROJECT_ID,:n         TASK_ID,:n         RESOURCE_ID,:n     +
1    RESOURCE_TYPE,:n         LAST_SUBMITTED,:n         WORK_TODATE,:n        +
1 TO_DATE(SubStr(SCHED_START, 1, 10)),:n         TO_DATE(SubStr(SCHED_FINISH, +
11, 10)),:n         BILLABLE,:n         CAPITAL_EXPENSE,:n         REGULAR_COS+
1T,:n         REGULAR_RATE:n         INTO:n         h_project_id,:n         h_+
1task_id,:n         h_res_id,:n         h_res_type,:n         h_last_submitted+
1,:n         h_work_todate,:n         h_SD,:n         h_FD,:n         h_billab+
1le,:n         h_capital_expense,:n         h_reg_cost,:n         h_reg_sale:n+
1         FROM TASK_ASSIGNMENTS:n         WHERE TSK_ASSIGNMENT_ID = h_tsk_assi+
1gnment_id:
1PMO_DB2M:
1SC_STATE:
1SQLCODE:
1OTHERS:
116:
1163:
1           EXCEPTION:: FC_U_TSKRES2(164) :: cplan.sql(6791) :: :
1 :
1SQLCODE:: :
1 SQLERR:: :
1SQLERRM:
1500:
1SC_SQL_NO_DATA:
1170:
1                EXIT:: FC_U_TSKRES2(171) :: cplan.sql(6798) :: :
1RECORD_NOT_FOUND:
1ELEMENT_ID:
1ELEMENT_TYPE:
1SECURITY_ID:
1CRI_SECURITY_ID:
1RESOURCE_ASSIGNMENTS:
1RES_ASSIGNMENT_ID:
1SELECT PROJECT_ID, ELEMENT_ID, RESOURCE_ID, ELEMENT_TYPE, :n         RESOURCE+
1_TYPE, SECURITY_ID, CASE WHEN CRI_SECURITY_ID IS NuLL THEN 0 ELSE 1 END:n    +
1     INTO h_project_id, h_task_id, h_res_id, h_type,:n         h_res_type, h_+
1security_id, h_transfed_cri:n         FROM RESOURCE_ASSIGNMENTS :n         WH+
1ERE RES_ASSIGNMENT_ID = h_assign_id:
1188:
1           EXCEPTION:: FC_U_TSKRES2(189) :: cplan.sql(6816) :: :
1195:
1                EXIT:: FC_U_TSKRES2(196) :: cplan.sql(6823) :: :
1ISWBSTRANSFEREDDELIV:
1!=:
1200:
1                EXIT:: FC_U_TSKRES2(201) :: cplan.sql(6828) :: :
1TASK_ASSIGNMENT_ERROR:
1WORK_LOCATION:
1UPDATE RESOURCE_ASSIGNMENTS SET WORK_LOCATION = h_work_location:n         WHE+
1RE RES_ASSIGNMENT_ID = h_assign_id:
1FOUND:
1TRUE:
1100:
1218:
1           EXCEPTION:: FC_U_TSKRES2(219) :: cplan.sql(6846) :: :
1ISPROJECTTYPE:
1NOT:
1SELECT TSK_ASSIGNMENT_ID INTO h_tsk_assignment_id:n            FROM TASK_ASSI+
1GNMENTS WHERE RES_ASSIGNMENT_ID = h_assign_id:
1233:
1           EXCEPTION:: FC_U_TSKRES2(234) :: cplan.sql(6861) :: :
1SC_SQL_SUCCESS:
1240:
1                EXIT:: FC_U_TSKRES2(241) :: cplan.sql(6868) :: :
1RECORD_ALREADY_ASSIGNED:
1FC_AFTER_U_RES_ASSIGN:
1MINUTE_PER_DAY:
1MINUTE_PER_WEEK:
1CALENDAR_ID:
1PRIORITY:
1TMT_WBS:
1SELECT COALESCE(MINUTE_PER_DAY, 480), COALESCE(MINUTE_PER_WEEK, 2400), CALEND+
1AR_ID, PRIORITY:n      INTO h_min_per_day, h_per_week, h_calendar_id, h_prior+
1ity:n      FROM TMT_WBS WHERE ELEMENT_ID = h_project_id:
1260:
1           EXCEPTION:: FC_U_TSKRES2(261) :: cplan.sql(6888) :: :
1>:
15:
1*:
1IS NULL:
1SUM:
1AVAILABLE_MIN:
1CALENDAR_DAY_OF_YEAR:
1DAY_YEAR:
1SELECT SUM(AVAILABLE_MIN) INTO h_effort FROM CALENDAR_DAY_OF_YEAR:n          +
1     WHERE ELEMENT_ID=h_project_id AND DAY_YEAR BETWEEN TO_DATE(SubStr(h_star+
1t_date, 1, 10)) AND TO_DATE(SubStr(h_finish_date, 1, 10)):
1286:
1           EXCEPTION:: FC_U_TSKRES2(287) :: cplan.sql(6914) :: :
160:
12:
13:
1303:
1                EXIT:: FC_U_TSKRES2(304) :: cplan.sql(6931) :: :
1SC_BIT_NOT_30:
1UNRESOLVED_START:
1UNRESOLVED_FINISH:
1PLANNED_WORK:
1SCHED_WORK:
1BIT_FLAG:
1SELECT TSK_ASSIGNMENT_ID, UNRESOLVED_START, UNRESOLVED_FINISH, PLANNED_WORK+S+
1CHED_WORK, BIT_FLAG:n         INTO h_tsk_assignment_id, h_start_DT, h_finish_+
1DT, h_sched_work, h_bit_flag:n         FROM TASK_ASSIGNMENTS:n         WHERE +
1PROJECT_ID = h_project_id AND TASK_ID = h_project_id AND RESOURCE_ID = h_res_+
1id:
1324:
1           EXCEPTION:: FC_U_TSKRES2(325) :: cplan.sql(6952) :: :
1IS NOT NULL:
1PMO_ORASTD:
1STRNCMP:
110:
1BIT_OR:
1<:
1FC_DECLARE_PMO_TMP_SEARCH:
1SC_SRCH_FROM_PROJECT:
1FC_SEARCH_2:
1ETC:
1UPDATE TASK_ASSIGNMENTS SET ETC = h_effort:n                  WHERE RES_ASSIG+
1NMENT_ID = h_assign_id:
1373:
1           EXCEPTION:: FC_U_TSKRES2(374) :: cplan.sql(7001) :: :
1379:
1                EXIT:: FC_U_TSKRES2(380) :: cplan.sql(7007) :: :
1U_TSKRES2:
1110:
1RESOURCE_UNAVAILABLE:
1473:
1                EXIT:: FC_U_TSKRES2(474) :: cplan.sql(7101) :: :
1STATE:: :
0

0
0
aa8
2
0 a0 8d 90 :3 a0 b0 3f 90
:3 a0 b0 3f 90 :3 a0 b0 3f 8f
a0 b0 3d 90 :3 a0 b0 3f 90
:3 a0 b0 3f 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 90
:3 a0 b0 3f 90 :3 a0 b0 3f b4
:2 a0 2c 6a a3 a0 1c a0 81
b0 a3 a0 1c a0 81 b0 a3
a0 1c a0 81 b0 a3 a0 1c
a0 81 b0 a3 a0 1c a0 81
b0 a3 a0 1c a0 81 b0 a3
a0 1c a0 81 b0 a3 a0 1c
a0 81 b0 a3 a0 1c a0 81
b0 a3 a0 1c a0 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 1c 81 b0
a3 a0 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 1c 81 b0 a3 a0 1c 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 :2 a0 6b :2 a0 6b 6e a5 b
a 10 :2 a0 6b 6e :2 a0 6b 6e
a5 b 6e 7e a0 b4 2e 6e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :3 a0 a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :3 a0 a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
:3 a0 a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e :3 a0 a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e :3 a0 a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e :3 a0
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e :3 a0 a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e :3 a0 a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e :3 a0 a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 51 a5 b a0 7e
a0 6b b4 2e :3 a0 6b :3 a0 51
a5 b :2 a0 6b a5 b 5a 51
a5 b d :4 a0 51 a5 b :2 a0
6b a5 b d a0 51 d a0
51 d a0 b7 :2 a0 51 a5 b
a0 7e a0 6b b4 2e :4 a0 51
a5 b :2 a0 6b a5 b 5a d
:4 a0 51 a5 b :2 a0 6b a5 b
5a d a0 51 d b7 19 :3 a0
51 a5 b d a0 51 d a0
51 d b7 :2 19 3c a0 51 d
a0 6e d a0 51 d a0 4d
d a0 4d d a0 4d d a0
4d d a0 51 d :2 a0 51 a5
b 7e 51 b4 2e :2 a0 d :1f a0
12a :2 a0 6b a0 d b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 6b a0 7e a0 6b
b4 2e 5a :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :3 a0 6b
65 b7 19 3c b7 :11 a0 12a :2 a0
6b a0 d b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 6b a0 7e a0 6b b4 2e
5a :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :3 a0 6b 65 a0
b7 :3 a0 51 a5 b a5 b 7e
51 b4 2e :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :3 a0 6b
65 b7 :2 19 3c :5 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :3 a0 51 a5
b a5 b 5a 7e 51 b4 2e
7e b4 2e :5 a0 12a :2 a0 6b a0
d b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
a0 7e a0 6b b4 2e 5a :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :3 a0 6b 65 b7 19 3c
b7 19 3c :3 a0 a5 b d b7
:2 19 3c :d a0 12a :2 a0 6b a0 d
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 51 a5
b 7e 51 b4 2e :2 a0 51 a5
b 7e 51 b4 2e 5a :2 a0 51
a5 b 7e 51 b4 2e 5a a
10 :3 a0 51 a5 b 7e :2 a0 51
a5 b b4 2e d b7 19 3c
:2 a0 51 a5 b 7e 51 b4 2e
a0 7e b4 2e 5a :2 a0 51 a5
b 7e 51 b4 2e :3 a0 51 a5
b 7e :2 a0 51 a5 b b4 2e
d b7 19 3c b7 :d a0 12a :2 a0
6b a0 d b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 :2 19 3c b7 :2 a0 51 a5 b
7e 51 b4 2e :3 a0 51 a5 b
7e 51 b4 2e d a0 b7 :2 a0
51 a5 b 7e 51 b4 2e :3 a0
51 a5 b 7e :2 a0 51 a5 b
b4 2e d a0 b7 19 :2 a0 51
a5 b 7e 51 b4 2e :3 a0 51
a5 b 7e :2 a0 51 a5 b b4
2e d b7 :2 19 3c b7 :2 19 3c
:2 a0 51 a5 b 7e 51 b4 2e
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :3 a0 6b 65 b7 19
3c b7 19 3c :2 a0 51 a5 b
7e 51 b4 2e :4 a0 51 a5 b
:2 a0 6b a5 b 5a d a0 b7
:2 a0 :2 51 a5 b 7e 6e b4 2e
5a :2 a0 51 a5 b 7e 51 b4
2e 5a a 10 :12 a0 12a :2 a0 6b
a0 d b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
6b a0 7e a0 6b b4 2e 5a
a0 7e b4 2e 5a a 10 :4 a0
51 a5 b :2 a0 6b a5 b 5a
d :2 a0 6b :2 a0 51 a5 b 7e
51 b4 2e 5a :2 a0 6b :2 a0 51
a5 b 7e 51 b4 2e 5a a
10 :2 a0 :2 51 a5 b 7e 6e b4
2e :2 a0 51 a5 b 7e 51 b4
2e a0 51 d b7 19 3c a0
51 d b7 19 3c b7 :2 a0 51
a5 b 7e 51 b4 2e :3 a0 6b
:2 a0 51 a5 b :2 a0 6b a5 b
5a d b7 19 3c :2 a0 51 a5
b a0 7e a0 51 a5 b b4
2e :2 a0 51 a5 b 7e 51 b4
2e :2 a0 6b :2 a0 51 a5 b 7e
51 b4 2e a 10 :2 a0 :2 51 a5
b 7e 6e b4 2e a0 51 d
b7 19 3c :2 a0 b4 2e d :3 a0
6b d :20 a0 51 a5 b :3 51 a5
b d b7 19 3c :5 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c a0 51 65 b7 19 3c b7
:2 19 3c b7 19 3c b7 :2 19 3c
:2 a0 51 a5 b 7e 51 b4 2e
5a :2 a0 51 a5 b a0 7e a0
51 a5 b b4 2e 5a 52 10
:2 a0 51 a5 b 7e 51 b4 2e
:3 a0 6b :2 a0 51 a5 b :2 a0 51
a5 b a5 b 5a d b7 19
3c :18 a0 :2 51 a5 b d a0 b7
:2 a0 51 a5 b 7e 51 b4 2e
:2 a0 51 a5 b 7e 51 b4 2e
:3 a0 6b :2 a0 51 a5 b :2 a0 51
a5 b a5 b 5a d b7 19
3c :18 a0 :2 51 a5 b d b7 :2 19
3c :2 a0 51 a5 b 7e 51 b4
2e :2 a0 6b :2 a0 6b d a0 b7
:2 a0 51 a5 b 7e 51 b4 2e
:2 a0 51 a5 b 7e 51 b4 2e
a 10 :2 a0 6b :2 a0 6b d b7
:2 19 3c :2 a0 6b 7e 51 b4 2e
:2 a0 6b 51 d b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :2 a0 6b
b4 2e a5 57 b7 19 3c :3 a0
6b 65 b7 a4 b1 11 68 4f
1d 17 b5 
aa8
2
0 3 7 2b 1f 23 27 1e
32 47 3b 3f 43 1b 4e 5f
53 57 5b 3a 66 73 6f 37
7b 8c 80 84 88 6e 93 a8
9c a0 a4 6b af b8 b4 9b
c0 cd c9 98 d5 de da c8
e6 f3 ef c5 fb 104 100 ee
10c 119 115 eb 121 12a 126 114
132 13f 13b 111 147 150 14c 13a
158 16d 161 165 169 137 174 185
179 17d 181 160 18c 15d 191 195
199 19d 1ba 1a5 1a9 1b1 1b5 1a4
1da 1c5 1c9 1d1 1d5 1a1 1f6 1e1
1e5 1ed 1f1 1c4 216 201 205 20d
211 1c1 232 21d 221 229 22d 200
252 23d 241 249 24d 1fd 26e 259
25d 265 269 23c 28e 279 27d 285
289 239 2aa 295 299 2a1 2a5 278
2ca 2b5 2b9 2c1 2c5 275 2e6 2d1
2d5 2d8 2d9 2e1 2b4 303 2f1 2b1
2f5 2f6 2fe 2f0 320 30e 2ed 312
313 31b 30d 33d 32b 30a 32f 330
338 32a 359 348 34c 354 327 371
360 364 36c 347 38e 37c 344 380
381 389 37b 3ab 399 378 39d 39e
3a6 398 3c8 3b6 395 3ba 3bb 3c3
3b5 3e5 3d3 3b2 3d7 3d8 3e0 3d2
402 3f0 3cf 3f4 3f5 3fd 3ef 41f
40d 3ec 411 412 41a 40c 43c 42a
409 42e 42f 437 429 459 447 426
44b 44c 454 446 475 464 468 443
470 463 491 480 484 460 48c 47f
4ad 49c 4a0 47c 4a8 49b 4c9 4b8
4bc 498 4c4 4b7 4e5 4d4 4d8 4b4
4e0 4d3 501 4f0 4f4 4d0 4fc 4ef
51d 50c 510 4ec 518 50b 539 528
52c 508 534 527 555 544 548 524
550 543 571 560 564 540 56c 55f
58e 57c 55c 580 581 589 57b 5ab
599 578 59d 59e 5a6 598 5c7 5b6
5ba 5c2 595 5df 5ce 5d2 5da 5b5
5fb 5ea 5ee 5b2 5f6 5e9 617 606
60a 5e6 612 605 633 622 626 602
62e 621 64f 63e 642 61e 64a 63d
66b 65a 65e 63a 666 659 687 676
67a 656 682 675 6a3 692 696 672
69e 691 6bf 6ae 6b2 68e 6ba 6ad
6db 6ca 6ce 6aa 6d6 6c9 6f7 6e6
6ea 6c6 6f2 6e5 713 702 706 6e2
70e 701 72f 71e 722 6fe 72a 71d
736 73a 71a 73e 742 746 749 74e
74f 1 751 756 75a 75e 761 766
76a 76e 771 776 777 779 77e 781
785 786 78b 790 793 798 799 79e
7a1 7a5 7a6 7ab 7ae 7b3 7b4 7b9
7bc 7c1 7c2 7c7 7ca 7cf 7d0 7d5
7d8 7dc 7dd 7e2 7e5 7ea 7eb 7f0
7f3 7f8 7f9 7fe 801 806 807 80c
80f 813 814 819 81c 821 822 827
82a 82f 830 835 838 83c 840 844
845 847 84c 84d 84f 850 855 858
85d 85e 863 866 86b 86c 871 874
878 879 87e 881 886 887 88c 88f
894 895 89a 89d 8a2 8a3 8a8 8ab
8af 8b0 8b5 8b8 8bd 8be 8c3 8c6
8cb 8cc 8d1 8d4 8d8 8dc 8e0 8e1
8e3 8e8 8e9 8eb 8ec 8f1 8f4 8f9
8fa 8ff 902 906 90a 90e 90f 911
916 917 919 91a 91f 922 927 928
92d 930 934 938 93c 93d 93f 944
945 947 948 94d 950 955 956 95b
95e 962 966 96a 96b 96d 972 973
975 976 97b 97e 983 984 989 98c
990 994 998 999 99b 9a0 9a1 9a3
9a4 9a9 9ac 9b1 9b2 9b7 9ba 9be
9c2 9c6 9c7 9c9 9ce 9cf 9d1 9d2
9d7 9da 9df 9e0 9e5 9e8 9ec 9f0
9f4 9f5 9f7 9fc 9fd 9ff a00 a05
a08 a0d a0e a13 a16 a1a a1e a22
a23 a25 a2a a2b a2d a2e a33 a36
a3b a3c a41 a44 a48 a4c a50 a51
a53 a58 a59 a5b a5c a61 a64 a69
a6a a6f a72 a77 a78 a7d a80 a84
a85 a8a a8d a92 a93 a98 a9b aa0
aa1 aa6 aa9 aae aaf ab4 ab7 abb
abc ac1 ac4 ac9 aca acf ad2 ad7
ad8 add ade ae3 ae5 ae9 aec af0
af4 af7 afb aff b02 b05 b0a b0d
b10 b13 b14 b19 b1a 1 b1c b21
b25 b29 b2c b31 b36 b39 b3d b3e
b43 b44 b49 b4b b4f b52 b56 b5a
b5d b5e b60 b64 b67 b6b b6e b6f
b74 b78 b7c b80 b83 b87 b8b b8f
b92 b93 b95 b99 b9d ba0 ba1 ba3
ba6 ba9 baa bac bb0 bb4 bb8 bbc
bc0 bc3 bc4 bc6 bca bce bd1 bd2
bd4 bd8 bdc bdf be3 be7 bea bee
bf2 bf4 bf8 bfc bff c00 c02 c06
c09 c0d c10 c11 c16 c1a c1e c22
c26 c29 c2a c2c c30 c34 c37 c38
c3a c3d c41 c45 c49 c4d c51 c54
c55 c57 c5b c5f c62 c63 c65 c68
c6c c70 c73 c77 c79 c7d c81 c85
c89 c8c c8d c8f c93 c97 c9a c9e
ca2 ca5 ca9 cab caf cb3 cb6 cba
cbd cc1 cc5 cca cce cd2 cd5 cd9
cdd cde ce2 ce6 ce7 ceb cef cf0
cf4 cf8 cf9 cfd d01 d04 d08 d0c
d10 d13 d14 d16 d19 d1c d1d d22
d26 d2a d2e d32 d36 d3a d3e d42
d46 d4a d4e d52 d56 d5a d5e d62
d66 d6a d6e d72 d76 d7a d7e d82
d86 d8a d8e d92 d96 d9a d9e da2
da6 daa db6 dba dbe dc1 dc5 dc9
dcb 1 dcf dd3 dd7 dda dde de2
de6 dea ded df1 df5 df8 dfb e00
e03 e06 e09 e0a e0f e10 1 e12
e17 e1b e1f e22 e27 e2c e2f e33
e34 e39 e3c e41 e42 e47 e4a e4f
e50 e55 e58 e5c e5d e62 e65 e6a
e6b e70 e73 e77 e7b e7e e81 e82
e84 e85 e8a e8b e90 e92 e96 e99
e9b e9f ea1 ead eaf eb1 eb2 eb7
ebb ebd ec9 ecb ecf ed3 ed6 eda
edd ee1 ee4 ee5 eea eed ef1 ef5
ef8 efc f00 f03 f06 f0b f0e f11
f14 f15 f1a f1b 1 f1d f22 f26
f2a f2d f32 f37 f3a f3e f3f f44
f45 f4a f4c f50 f53 f57 f5b f5f
f62 f66 f68 f6c f6f f71 f75 f79
f7d f81 f85 f89 f8d f91 f95 f99
f9d fa1 fa5 fa9 fad fb1 fb5 fc1
fc5 fc9 fcc fd0 fd4 fd6 1 fda
fde fe2 fe5 fe9 fed ff1 ff5 ff8
ffc 1000 1003 1006 100b 100e 1011 1014
1015 101a 101b 1 101d 1022 1026 102a
102d 1032 1037 103a 103e 103f 1044 1047
104c 104d 1052 1055 105a 105b 1060 1063
1067 1068 106d 1070 1075 1076 107b 107e
1082 1086 1089 108c 108d 108f 1090 1095
1096 109b 109d 10a1 10a4 10a6 10aa 10ac
10b8 10ba 10bc 10bd 10c2 10c6 10c8 10d4
10d6 10da 10de 10e1 10e5 10e8 10ec 10ef
10f0 10f5 10f8 10fc 1100 1103 1107 110b
110e 1111 1116 1119 111c 111f 1120 1125
1126 1 1128 112d 1131 1135 1138 113d
1142 1145 1149 114a 114f 1150 1155 1157
115b 115e 1162 1166 116a 116d 1171 1175
1177 117b 117f 1183 1186 1187 1189 118a
118c 118f 1192 1193 1198 119c 11a0 11a3
11a7 11ab 11ae 11b1 11b6 11b9 11bc 11bf
11c0 11c5 11c6 1 11c8 11cd 11d1 11d5
11d8 11dd 11e2 11e5 11e9 11ea 11ef 11f0
11f5 11f7 11fb 11fe 1202 1206 120a 120d
1211 1213 1217 121b 121e 1222 1226 122a
122e 1232 123e 1242 1247 124b 124e 124f
1254 1258 125c 125f 1262 1266 1268 126c
1270 1273 1276 127a 127c 1280 1284 1287
1289 1 128d 1291 1295 1298 129c 12a0
12a4 12a8 12ab 12af 12b3 12b6 12b9 12be
12c1 12c4 12c7 12c8 12cd 12ce 1 12d0
12d5 12d9 12dd 12e0 12e5 12ea 12ed 12f1
12f2 12f7 12fa 12ff 1300 1305 1308 130d
130e 1313 1316 131a 131b 1320 1323 1328
1329 132e 1331 1335 1339 133c 133f 1340
1342 1343 1348 1349 134e 1350 1354 1357
1359 135d 135f 136b 136d 136f 1370 1375
1379 137b 1387 1389 138d 1391 1395 1398
1399 139b 139c 139e 13a1 13a4 13a7 13a8
13ad 13b0 13b1 13b6 13ba 13be 13c2 13c6
13ca 13d6 13da 13de 13e1 13e5 13e9 13eb
1 13ef 13f3 13f7 13fa 13fe 1402 1406
140a 140d 1411 1415 1418 141b 1420 1423
1426 1429 142a 142f 1430 1 1432 1437
143b 143f 1442 1447 144c 144f 1453 1454
1459 145c 1461 1462 1467 146a 146f 1470
1475 1478 147c 147d 1482 1485 148a 148b
1490 1493 1497 149b 149e 14a1 14a2 14a4
14a5 14aa 14ab 14b0 14b2 14b6 14b9 14bb
14bf 14c1 14cd 14cf 14d1 14d2 14d7 14db
14dd 14e9 14eb 14ef 14f3 14f6 14fa 14fd
1501 1504 1505 150a 150d 1511 1515 1518
151c 1520 1523 1526 152b 152e 1531 1534
1535 153a 153b 1 153d 1542 1546 154a
154d 1552 1557 155a 155e 155f 1564 1565
156a 156c 1570 1573 1577 157b 157f 1582
1586 1588 158c 158f 1591 1595 1598 159c
15a0 15a4 15a5 15a7 15ab 15ad 15b1 15b5
15b8 15bc 15c0 15c4 15c8 15cc 15d0 15d4
15d8 15dc 15e0 15e4 15e8 15ec 15f8 15fc
1600 1603 1607 160b 160d 1 1611 1615
1619 161c 1620 1624 1628 162c 162f 1633
1637 163a 163d 1642 1645 1648 164b 164c
1651 1652 1 1654 1659 165d 1661 1664
1669 166e 1671 1675 1676 167b 167e 1683
1684 1689 168c 1691 1692 1697 169a 169e
169f 16a4 16a7 16ac 16ad 16b2 16b5 16b9
16bd 16c0 16c3 16c4 16c6 16c7 16cc 16cd
16d2 16d4 16d8 16db 16dd 16e1 16e3 16ef
16f1 16f3 16f4 16f9 16fd 16ff 170b 170d
1711 1715 1718 1719 171b 171e 1721 1722
1727 172b 172f 1732 1733 1735 1738 173b
173c 1741 1744 1748 174c 174f 1750 1752
1755 1758 1759 175e 1 1761 1766 176a
176e 1772 1775 1776 1778 177b 177f 1783
1786 1787 1789 178a 178f 1793 1795 1799
179c 17a0 17a4 17a7 17a8 17aa 17ad 17b0
17b1 17b6 17ba 17bd 17be 17c3 17c6 17ca
17ce 17d1 17d2 17d4 17d7 17da 17db 17e0
17e4 17e8 17ec 17ef 17f0 17f2 17f5 17f9
17fd 1800 1801 1803 1804 1809 180d 180f
1813 1816 1818 181c 1820 1824 1828 182c
1830 1834 1838 183c 1840 1844 1848 184c
1858 185c 1860 1863 1867 186b 186d 1
1871 1875 1879 187c 1880 1884 1888 188c
188f 1893 1897 189a 189d 18a2 18a5 18a8
18ab 18ac 18b1 18b2 1 18b4 18b9 18bd
18c1 18c4 18c9 18ce 18d1 18d5 18d6 18db
18de 18e3 18e4 18e9 18ec 18f1 18f2 18f7
18fa 18fe 18ff 1904 1907 190c 190d 1912
1915 1919 191d 1920 1923 1924 1926 1927
192c 192d 1932 1934 1938 193b 193d 1941
1943 194f 1951 1953 1954 1959 195d 195f
196b 196d 196f 1973 1977 197a 197c 1980
1984 1987 1988 198a 198d 1990 1991 1996
199a 199e 19a2 19a5 19a6 19a8 19ab 19ae
19af 19b4 19b8 19bc 19be 19c2 19c6 19c9
19ca 19cc 19cf 19d2 19d3 19d8 19dc 19e0
19e4 19e7 19e8 19ea 19ed 19f1 19f5 19f8
19f9 19fb 19fc 1a01 1a05 1a09 1a0b 1a0f
1a13 1a17 1a1a 1a1b 1a1d 1a20 1a23 1a24
1a29 1a2d 1a31 1a35 1a38 1a39 1a3b 1a3e
1a42 1a46 1a49 1a4a 1a4c 1a4d 1a52 1a56
1a58 1a5c 1a60 1a63 1a65 1a69 1a6d 1a70
1a74 1a78 1a7b 1a7c 1a7e 1a81 1a84 1a85
1a8a 1a8e 1a92 1a95 1a99 1a9d 1aa0 1aa3
1aa8 1aab 1aae 1ab1 1ab2 1ab7 1ab8 1
1aba 1abf 1ac3 1ac7 1aca 1acf 1ad4 1ad7
1adb 1adc 1ae1 1ae2 1ae7 1ae9 1aed 1af0
1af4 1af8 1afc 1aff 1b03 1b05 1b09 1b0c
1b0e 1b12 1b15 1b19 1b1d 1b20 1b21 1b23
1b26 1b29 1b2a 1b2f 1b33 1b37 1b3b 1b3f
1b42 1b43 1b45 1b49 1b4d 1b50 1b51 1b53
1b56 1b5a 1b5e 1b60 1b64 1b68 1b6b 1b6e
1b6f 1b71 1b74 1b79 1b7a 1b7f 1b82 1b86
1b8a 1b8d 1b8e 1b90 1b93 1b96 1b97 1b9c
1 1b9f 1ba4 1ba8 1bac 1bb0 1bb4 1bb8
1bbc 1bc0 1bc4 1bc8 1bcc 1bd0 1bd4 1bd8
1bdc 1be0 1be4 1be8 1bec 1bf8 1bfc 1c00
1c03 1c07 1c0b 1c0d 1 1c11 1c15 1c19
1c1c 1c20 1c24 1c28 1c2c 1c2f 1c33 1c37
1c3a 1c3d 1c42 1c45 1c48 1c4b 1c4c 1c51
1c52 1 1c54 1c59 1c5d 1c61 1c64 1c69
1c6e 1c71 1c75 1c76 1c7b 1c7e 1c83 1c84
1c89 1c8c 1c91 1c92 1c97 1c9a 1c9e 1c9f
1ca4 1ca7 1cac 1cad 1cb2 1cb5 1cb9 1cbd
1cc0 1cc3 1cc4 1cc6 1cc7 1ccc 1ccd 1cd2
1cd4 1cd8 1cdb 1cdd 1ce1 1ce3 1cef 1cf1
1cf3 1cf4 1cf9 1cfd 1cff 1d0b 1d0d 1d11
1d15 1d18 1d1c 1d1f 1d23 1d26 1d27 1d2c
1d2f 1d33 1d36 1d37 1d3c 1 1d3f 1d44
1d48 1d4c 1d50 1d54 1d57 1d58 1d5a 1d5e
1d62 1d65 1d66 1d68 1d6b 1d6f 1d73 1d77
1d7a 1d7e 1d82 1d85 1d86 1d88 1d8b 1d8e
1d8f 1d94 1d97 1d9b 1d9f 1da2 1da6 1daa
1dad 1dae 1db0 1db3 1db6 1db7 1dbc 1
1dbf 1dc4 1dc8 1dcc 1dcf 1dd2 1dd3 1dd5
1dd8 1ddd 1dde 1de3 1de7 1deb 1dee 1def
1df1 1df4 1df7 1df8 1dfd 1e01 1e04 1e08
1e0a 1e0e 1e11 1e15 1e18 1e1c 1e1e 1e22
1e25 1e27 1e2b 1e2f 1e32 1e33 1e35 1e38
1e3b 1e3c 1e41 1e45 1e49 1e4d 1e50 1e54
1e58 1e5b 1e5c 1e5e 1e62 1e66 1e69 1e6a
1e6c 1e6f 1e73 1e75 1e79 1e7c 1e80 1e84
1e87 1e88 1e8a 1e8e 1e91 1e95 1e98 1e99
1e9b 1e9c 1ea1 1ea5 1ea9 1eac 1ead 1eaf
1eb2 1eb5 1eb6 1ebb 1ebf 1ec3 1ec6 1eca
1ece 1ed1 1ed2 1ed4 1ed7 1eda 1edb 1
1ee0 1ee5 1ee9 1eed 1ef0 1ef3 1ef4 1ef6
1ef9 1efe 1eff 1f04 1f08 1f0b 1f0f 1f11
1f15 1f18 1f1c 1f20 1f21 1f26 1f2a 1f2e
1f32 1f36 1f39 1f3d 1f41 1f45 1f49 1f4d
1f51 1f55 1f59 1f5d 1f61 1f65 1f69 1f6d
1f71 1f75 1f79 1f7d 1f81 1f85 1f89 1f8d
1f91 1f95 1f99 1f9d 1fa1 1fa5 1fa9 1fad
1fb1 1fb5 1fb9 1fbd 1fc0 1fc1 1fc3 1fc6
1fc9 1fcc 1fcd 1fcf 1fd3 1fd5 1fd9 1fdc
1fe0 1fe4 1fe8 1fec 1ff0 1ffc 2000 2005
2009 200c 200d 2012 2016 201a 201d 2020
2024 2026 202a 202e 2031 2034 2038 203a
203e 2042 2045 2047 1 204b 204f 2053
2056 205a 205e 2062 2066 2069 206d 2071
2074 2077 207c 207f 2082 2085 2086 208b
208c 1 208e 2093 2097 209b 209e 20a3
20a8 20ab 20af 20b0 20b5 20b8 20bd 20be
20c3 20c6 20cb 20cc 20d1 20d4 20d8 20d9
20de 20e1 20e6 20e7 20ec 20ef 20f3 20f7
20fa 20fd 20fe 2100 2101 2106 2107 210c
210e 2112 2115 2117 211b 211d 2129 212b
212d 212e 2133 2137 2139 2145 2147 214b
214f 2152 2156 215a 215d 2160 2165 2168
216b 216e 216f 2174 2175 1 2177 217c
2180 2184 2187 218c 2191 2194 2198 2199
219e 219f 21a4 21a6 21aa 21ad 21b1 21b4
21b8 21ba 21be 21c1 21c3 21c7 21cb 21ce
21d0 21d4 21d7 21d9 21dd 21e1 21e4 21e8
21ec 21ef 21f0 21f2 21f5 21f8 21f9 21fe
2201 2205 2209 220c 220d 220f 2213 2216
221a 221d 221e 2220 2221 2226 1 2229
222e 2232 2236 2239 223a 223c 223f 2242
2243 2248 224c 2250 2254 2257 225b 225f
2262 2263 2265 2269 226d 2270 2271 2273
2274 2276 2279 227d 227f 2283 2286 228a
228e 2292 2296 229a 229e 22a2 22a6 22aa
22ae 22b2 22b6 22ba 22be 22c2 22c6 22ca
22ce 22d2 22d6 22da 22de 22e2 22e6 22e9
22ec 22ed 22ef 22f3 22f7 22f9 22fd 2301
2304 2305 2307 230a 230d 230e 2313 2317
231b 231e 231f 2321 2324 2327 2328 232d
2331 2335 2339 233c 2340 2344 2347 2348
234a 234e 2352 2355 2356 2358 2359 235b
235e 2362 2364 2368 236b 236f 2373 2377
237b 237f 2383 2387 238b 238f 2393 2397
239b 239f 23a3 23a7 23ab 23af 23b3 23b7
23bb 23bf 23c3 23c7 23cb 23ce 23d1 23d2
23d4 23d8 23da 23de 23e2 23e5 23e9 23ed
23f0 23f1 23f3 23f6 23f9 23fa 23ff 2403
2407 240a 240e 2412 2415 2419 241d 241f
2423 2427 242a 242b 242d 2430 2433 2434
2439 243d 2441 2444 2445 2447 244a 244d
244e 1 2453 2458 245c 2460 2463 2467
246b 246e 2472 2474 2478 247c 247f 2483
2487 248a 248d 2490 2491 2496 249a 249e
24a1 24a4 24a8 24aa 24ae 24b1 24b5 24b9
24bc 24c0 24c4 24c7 24ca 24cf 24d2 24d5
24d8 24d9 24de 24df 1 24e1 24e6 24ea
24ee 24f1 24f6 24fb 24fe 2502 2503 2508
250b 2510 2511 2516 2519 251e 251f 2524
2527 252b 252f 2532 2533 2538 2539 253e
2540 2544 2547 254b 254f 2553 2556 255a
255c 2560 2562 256e 2572 2574 2575 257e 
aa8
2
0 1 a 6 15 19 20 :3 6
15 19 20 :3 6 16 1a 21 :3 6
19 :3 6 16 1a 21 :3 6 17 1b
22 :3 6 12 :3 6 10 :3 6 11 :3 6
10 :3 6 15 :3 6 13 :3 6 13 :3 6
18 :3 6 16 :3 6 19 1d 24 :3 6
14 18 1f :2 6 1 3 a :2 1
4 :2 14 23 14 :2 4 :2 d 1c d
:2 4 :2 b 1a b :2 4 :2 c 1b c
:2 4 :2 b 1a b :2 4 :2 10 1f 10
:2 4 :2 e 1d e :2 4 :2 e 1d e
:2 4 :2 13 22 13 :2 4 :2 11 20 11
:2 4 e 17 16 :2 e :2 4 d 16
15 :2 d :2 4 f 18 17 :2 f :2 4
10 19 18 :2 10 :2 4 :3 10 :2 4 :3 15
:2 4 18 21 20 :2 18 :2 4 11 1a
19 :2 11 :2 4 12 1b 1a :2 12 :2 4
12 1b 1a :2 12 :2 4 f 18 17
:2 f :2 4 f 18 17 :2 f :2 4 10
19 18 :2 10 :2 4 f 18 17 :2 f
:2 4 :2 12 21 12 :2 4 :2 b 1a b
:2 4 :2 f 1e f :2 4 :2 f 1e f
:2 4 :2 d 1c d :2 4 :2 a 19 a
:2 4 :2 14 23 14 :2 4 :2 13 22 13
:2 4 :2 12 21 12 :2 4 :2 f 1e f
:2 4 17 20 1f :2 17 :2 4 18 21
20 :2 18 :2 4 :3 9 :2 4 :3 9 :2 4 :2 f
19 f :2 4 :2 f 19 f :2 4 :2 f
1e f :2 4 :2 16 25 16 :2 4 :2 11
20 11 :2 4 :2 f 1e f :2 4 :2 14
23 14 :2 4 :2 11 20 11 :2 4 :2 f
1e f :2 4 :2 d 1c d :2 4 :2 b
1a b :2 4 :2 f 19 f 4 7
:2 11 23 :2 2d 3a :2 23 :3 7 :2 d 19
25 :2 2f 43 :2 25 54 5a 5d :2 54
6b 81 8 :2 6b d 10 :2 6b 1c
1f :2 6b b e :2 6b 13 16 :2 6b
1b 1e :2 6b 2a 2d :2 6b b e
:2 6b 13 16 :2 6b 1b 1e :2 6b 2b
2e :2 6b b e :2 6b 13 16 1f
27 :2 1f 3c :2 16 :2 6b b e :2 6b
13 16 :2 6b 1b 1e :2 6b 2b 2e
:2 6b b e :2 6b 13 16 :2 6b 1b
1e :2 6b 2c 2f :2 6b b e :2 6b
13 16 1f 27 :2 1f 35 :2 16 :2 6b
b e :2 6b 13 16 1f 27 :2 1f
33 :2 16 :2 6b b e :2 6b 13 16
1f 27 :2 1f 34 :2 16 :2 6b b e
:2 6b 13 16 1f 27 :2 1f 33 :2 16
:2 6b b e :2 6b 13 16 1f 27
:2 1f 38 :2 16 :2 6b b e :2 6b 13
16 1f 27 :2 1f 36 :2 16 :2 6b b
e :2 6b 13 16 1f 27 :2 1f 36
:2 16 :2 6b b e :2 6b 13 16 1f
27 :2 1f 3b :2 16 :2 6b b e :2 6b
13 16 1f 27 :2 1f 39 :2 16 :2 6b
b e :2 6b 13 16 :2 6b 1b 1e
:2 6b 2e 31 :2 6b b e :2 6b 13
16 :2 6b 1b 1e :2 6b 29 2c :2 6b
31 34 :2 6b :2 7 4a :2 4 7 :2 11
23 :2 2d 39 3c 4c 4e 4f :2 4c
:2 23 :3 7 :2 d 12 1e 5c 5f :2 1e
:2 7 52 :2 4 7 10 1b :2 7 21
1e :2 2a :2 1e 7 10 :2 19 25 2c
35 40 :2 2c 44 :2 4d :2 25 24 5c
:2 10 :2 7 15 1c 25 30 :2 1c 34
:2 3d :2 15 :2 7 14 :2 7 13 7 4
34 a 13 1e :2 a 24 21 :2 2d
:2 21 7 14 1b 24 2f :2 1b 33
:2 3c :2 14 13 :2 7 15 1c 25 30
:2 1c 34 :2 3d :2 15 14 :2 7 15 7
37 34 7 15 1e 29 :2 15 :2 7
14 :2 7 13 7 :5 4 12 :2 4 12
:2 4 15 :2 4 18 :2 4 c :2 4 c
:2 4 12 :2 4 12 4 7 10 1b
:2 7 1e 20 :2 1e 7 1e 7 :7 a
12 19 a 12 19 :10 a f 10
24 fffa a :2 13 1f a 7 :2 f
d :2 16 22 d 10 :2 1a 2c :2 36
42 46 56 59 5a :2 56 :2 2c :3 10
:2 16 1b 27 66 69 :2 27 76 79
:2 27 7d 80 :2 27 8c 8f :2 27 97
9a :2 27 a6 a9 b0 b9 bc :2 a9
:2 27 :2 10 5d :2 d :2 a :4 16 :2 a 7
:3 22 b :2 14 1f 1d :2 28 :2 1d a
d :2 17 29 :2 33 3f 42 52 55
56 :2 52 :2 29 :3 d :2 13 18 24 63
66 :2 24 :2 d 59 :3 a 11 :2 1a a
38 :2 7 22 11 1d 29 36 a
19 30 f 1d 28 32 a 16
25 f 10 24 :2 a :2 13 1f a
7 :2 f d :2 16 22 d 10 :2 1a
2c :2 36 42 46 56 59 5a :2 56
:2 2c :3 10 :2 16 1b 27 66 69 :2 27
76 79 :2 27 7d 80 :2 27 8c 8f
:2 27 97 9a :2 27 a6 a9 b0 b9
bc :2 a9 :2 27 :2 10 5d :2 d :2 a :4 16
:2 a 7 :3 4 b :2 14 1f 1d :2 28
:2 1d a d :2 17 29 :2 33 3f 42
52 55 56 :2 52 :2 29 :3 d :2 13 18
24 63 66 :2 24 :2 d 59 :3 a 11
:2 1a a 7 38 d 22 2b 33
:2 22 :2 d 37 3a :2 37 d :2 17 29
:2 33 3f 42 52 55 56 :2 52 :2 29
:3 d :2 13 18 24 63 66 :2 24 :2 d
59 :3 a 11 :2 1a a 3c 38 :2 7
11 2a 3a 10 24 a 11 d
19 :3 17 d :2 16 22 d 1e d
:2 16 22 d :4 a 7 :2 f d :2 16
22 d 10 :2 1a 2c :2 36 42 46
56 59 5a :2 56 :2 2c :3 10 :2 16 1b
27 66 69 :2 27 76 79 :2 27 7d
80 :2 27 8c 8f :2 27 97 9a :2 27
a6 a9 b0 b9 bc :2 a9 :2 27 :2 10
5d :2 d :2 a :4 16 :2 a 7 :3 4 f
1d 26 2e :2 1d :2 f e 33 36
:2 33 :3 a 14 2b 12 29 3d :2 d
:2 16 22 d a :2 12 10 :2 19 25
10 13 :2 1d 2f :2 39 45 49 59
5c 5d :2 59 :2 2f :3 13 :2 19 1e 2a
69 6c :2 2a 79 7c :2 2a 80 83
:2 2a 8f 92 :2 2a 9a 9d :2 2a a9
ac b3 bc bf :2 ac :2 2a :2 13 60
:2 10 :2 d :4 19 :2 d a :3 38 e :2 17
22 20 :2 2b :2 20 d 10 :2 1a 2c
:2 36 42 45 55 58 59 :2 55 :2 2c
:3 10 :2 16 1b 27 66 69 :2 27 :2 10
5c :3 d 14 :2 1d d 3b :2 a 38
:3 7 1a 30 :2 1a 7 :4 4 e 17
2d 36 4e 5b c 1b 27 36
c 1a 27 :2 7 :2 10 1c 7 4
:2 c a :2 13 1f a d :2 17 29
:2 33 3f 43 53 56 57 :2 53 :2 29
:3 d :2 13 18 24 63 66 :2 24 73
76 :2 24 7a 7d :2 24 89 8c :2 24
94 97 :2 24 a3 a6 ad b6 b9
:2 a6 :2 24 :2 d 5a :2 a :2 7 :4 13 :2 7
4 :3 1 7 10 1a :2 7 1d 1f
:2 1d b 14 1c :2 b 1f 21 :2 1f
a 29 32 3a :2 29 3d 3f :2 3d
28 :3 a 14 1d 2c :2 14 2f 31
3a 42 :2 31 :2 14 a 42 :2 7 a
13 1d :2 a 20 22 :2 20 :4 e d
10 19 21 :2 10 24 26 :2 24 10
1c 25 33 :2 1c 36 38 41 49
:2 38 :2 1c 10 28 :2 d 25 17 1b
2f 3d 16 21 32 43 4b 52
6c 74 7b :2 10 :2 19 25 10 d
:2 15 13 :2 1c 28 13 16 :2 20 32
:2 3c 48 4c 5c 5f 60 :2 5c :2 32
:3 16 :2 1c 21 2d 6c 6f :2 2d 7c
7f :2 2d 83 86 :2 2d 92 95 :2 2d
9d a0 :2 2d ac af b6 bf c2
:2 af :2 2d :2 16 63 :2 13 :2 10 :4 1c :2 10
d :7 a 24 d 16 1f :2 d 22
24 :2 22 d 19 22 2c :2 19 2f
31 :2 19 d a 26 10 19 22
:2 10 25 27 :2 25 d 19 22 31
:2 19 34 36 3f 49 :2 36 :2 19 d
a 29 26 10 19 22 :2 10 25
27 :2 25 d 19 22 2e :2 19 31
33 3c 46 :2 33 :2 19 d 29 26
:2 a :4 7 a 13 1d :2 a 20 22
:2 20 d :2 17 29 :2 33 3f 42 52
55 56 :2 52 :2 29 :3 d :2 13 18 24
63 66 :2 24 :2 d 59 :3 a 11 :2 1a
a 24 :2 7 21 :2 4 7 10 1b
:2 7 1e 20 :2 1e 7 15 1c 25
30 :2 1c 34 :2 3d :2 15 14 7 4
22 b 12 1e 21 :2 b 24 26
:2 24 a 30 39 46 :2 30 49 4b
:2 49 2f :2 a 11 24 36 49 56
62 f 24 30 3d 4b f 10
1d 2e 38 49 57 :2 a :2 13 1f
a 7 :2 f d :2 16 22 d 10
:2 1a 2c :2 36 42 46 56 59 5a
:2 56 :2 2c :3 10 :2 16 1b 27 66 69
:2 27 76 79 :2 27 7d 80 :2 27 8c
8f :2 27 97 9a :2 27 a6 a9 b0
b9 bc :2 a9 :2 27 :2 10 5d :2 d :2 a
:4 16 :2 a 7 :3 4e b :2 14 1f 1d
:2 28 :2 1d a :4 3d 3c :3 a 18 1f
28 33 :2 1f 37 :2 40 :2 18 17 a
e :2 19 21 2f 3b :2 e 3f 42
:2 3f d 4a :2 55 5d 12 21 :2 4a
25 28 :2 25 49 :2 d 10 17 23
26 :2 10 29 2b :2 29 13 1c 26
:2 13 29 2b :2 29 13 20 13 2d
:3 10 1f 10 2f :2 d 2b 10 19
24 :2 10 27 29 :2 27 10 1f :2 28
2f 38 44 :2 2f 48 :2 51 :2 1f 1e
10 2b :2 d 10 19 27 :2 10 2c
2a 35 3f :2 2c :2 2a 13 1c 2a
:2 13 2d 2f :2 2d 35 :2 40 48 56
63 :2 35 67 6a :2 67 :2 13 16 1d
29 2c :2 16 2f 31 :2 2f 16 22
16 35 :3 13 :3 26 :2 13 21 :2 2a :2 13
26 32 3f 4d 58 62 6e 22
2f 3d 49 55 22 2f 37 45
4d 56 5e 22 2e 3a 47 52
22 30 3a 49 55 22 2b 3a
:2 22 3e 41 47 :2 26 13 6c :2 10
1a 2f 35 19 2d 13 1a 16
22 :3 20 16 :2 1f 2b 16 27 16
:2 1f 2b 16 :4 13 10 :2 18 16 :2 1f
2b 16 19 :2 23 35 :2 3f 4b 4f
5f 62 63 :2 5f :2 35 :3 19 :2 1f 24
30 6f 72 :2 30 7f 82 :2 30 86
89 :2 30 95 98 :2 30 a0 a3 :2 30
af b2 b9 c2 c5 :2 b2 :2 30 :2 19
66 :2 16 :2 13 :4 1f :2 13 10 :3 42 13
:2 1d 2f :2 39 45 48 58 5b 5c
:2 58 :2 2f :3 13 :2 19 1e 2a 69 6c
:2 2a :2 13 5f :3 10 17 10 42 :2 d
:4 a 5e :2 7 4e 22 :2 4 8 11
1c :2 8 1f 21 :2 1f 7 28 31
3f :2 28 44 42 4d 5c :2 44 :2 42
27 :2 7 a 13 1d :2 a 20 23
:2 20 a 18 :2 21 28 31 3c :2 28
40 49 53 :2 40 :2 18 17 a 25
:3 7 1a 24 31 3f 4a 54 20
2e 3c 4b 55 5d 20 28 34
41 4c 57 20 2e 3a 4b 57
20 26 :2 1a 7 4 60 a 13
1e :2 a 21 23 :2 21 a 13 1d
:2 a 20 23 :2 20 a 18 :2 21 28
31 3c :2 28 40 49 53 :2 40 :2 18
17 a 25 :3 7 1a 24 39 47
52 5c 20 2e 3c 4b 55 5d
20 28 34 41 4c 57 20 2e
3a 4b 57 20 26 :2 1a 7 25
60 :2 4 7 10 21 :2 7 24 26
:2 24 7 :2 10 1c :2 25 7 4 2a
a 13 24 :2 a 27 2a :2 27 30
39 4a :2 30 4d 50 :2 4d :2 a 7
:2 10 1c :2 25 7 54 2a :2 4 7
:2 10 19 1b :2 19 7 :2 10 1c 7
1f :2 4 7 :2 11 23 :2 2d 39 3c
4c 4f 50 :2 4c :2 23 :3 7 :2 d 12
1e 5d 60 :2 1e 6d 70 :2 1e 74
77 :2 1e 81 84 :2 8d :2 1e :2 7 53
:3 4 b :2 14 4 :9 1 
aa8
4
0 :2 1 :6 3 :6 4
:6 5 :4 6 :6 7 :6 8
:4 9 :4 a :4 b :4 c
:4 d :4 e :4 f :4 10
:4 11 :6 12 :6 13 2
:2 14 :2 1 :6 16 :6 17
:6 18 :6 19 :6 1a :6 1b
:6 1c :6 1d :6 1e :6 1f
:7 20 :7 21 :7 22 :7 23
:5 24 :5 25 :7 26 :7 27
:7 28 :7 29 :7 2a :7 2b
:7 2c :7 2d :6 2e :6 2f
:6 30 :6 31 :6 32 :6 33
:6 34 :6 35 :6 36 :6 37
:7 38 :7 39 :5 3a :5 3b
:6 3c :6 3d :6 3e :6 3f
:6 40 :6 41 :6 42 :6 43
:6 44 :6 45 :6 46 :6 47
:b 49 :11 4a 4b :2 4a
:2 4b :2 4a :2 4b :2 4a
:2 4c :2 4a :2 4c :2 4a
:2 4c :2 4a :2 4c :2 4a
:2 4d :2 4a :2 4d :2 4a
:2 4d :2 4a :2 4d :2 4a
:2 4e :2 4a :9 4e :2 4a
:2 4f :2 4a :2 4f :2 4a
:2 4f :2 4a :2 4f :2 4a
:2 50 :2 4a :2 50 :2 4a
:2 50 :2 4a :2 50 :2 4a
:2 51 :2 4a :9 51 :2 4a
:2 52 :2 4a :9 52 :2 4a
:2 53 :2 4a :9 53 :2 4a
:2 54 :2 4a :9 54 :2 4a
:2 55 :2 4a :9 55 :2 4a
:2 56 :2 4a :9 56 :2 4a
:2 57 :2 4a :9 57 :2 4a
:2 58 :2 4a :9 58 :2 4a
:2 59 :2 4a :9 59 :2 4a
:2 5a :2 4a :2 5a :2 4a
:2 5a :2 4a :2 5a :2 4a
:2 5b :2 4a :2 5b :2 4a
:2 5b :2 4a :2 5b :2 4a
:2 5b :4 4a :3 49 :11 5e
:b 5f :3 5e :b 64 :14 65
:d 67 :3 68 :3 69 6a
64 :b 6a :e 6b :e 6d
:3 6f 6a 64 :7 71
:3 72 :3 73 70 :3 64
:3 76 :3 77 :3 78 :3 79
:3 7a :3 7b :3 7c :3 7d
:9 7f :3 80 83 84
85 86 87 88
:3 89 :3 8a 8b 8c
8d 8e 90 91
92 93 94 95
96 97 98 99
9a 9b 9c :2 9d
83 :5 9e 81 :2 a0
:5 a2 :11 a3 :24 a4 :3 a3
:2 a1 :6 a0 9f :3 7f
:a a9 :11 aa :b ab :3 aa
:5 ad :3 a9 7f :4 b1
:3 b2 :4 b3 :3 b4 b5
:2 b6 b1 :5 b7 b0
:2 b9 :5 bb :11 bc :24 bd
:3 bc :2 ba :6 b9 b8
:3 af :a c2 :11 c3 :b c4
:3 c3 :5 c6 c7 c2
:c c7 :11 c8 :b c9 :3 c8
:5 cb c7 :3 c2 :3 cf
:2 d0 cf :6 d1 :5 d2
d1 :5 d4 d3 :3 d1
ce :2 d7 :5 d9 :11 da
:24 db :3 da :2 d8 :6 d7
d6 :3 af :10 e0 :2 e2
:3 e3 e2 :5 e4 e1
:2 e6 :5 e8 :11 e9 :24 ea
:3 e9 :2 e7 :6 e6 e5
:3 e0 :a ef :11 f0 :b f1
:3 f0 :5 f3 :3 ef :3 e0
:6 f7 af :3 7f :6 fc
:4 fd :3 fe fc :5 ff
fb :2 101 :5 103 :11 104
:24 105 :3 104 :2 102 :6 101
100 :3 48 :9 10a :16 10b
:f 10c :3 10b :9 10f :5 111
:9 112 :f 113 :3 112 111
:4 117 :9 118 117 :5 119
116 :2 11b :5 11d :11 11e
:24 11f :3 11e :2 11c :6 11b
11a :4 115 :3 111 10f
:9 125 :b 126 127 125
:9 127 :f 128 129 127
125 :9 129 :f 12a 129
:3 125 124 :3 10f :9 12e
:11 12f :b 130 :3 12f :5 132
:3 12e :3 10a :9 136 :e 137
139 136 :17 139 :6 13b
:5 13c 13d :6 13e 13b
:5 13f 13a :2 141 :5 143
:11 144 :24 145 :3 144 :2 142
:6 141 140 :3 139 :11 14a
:e 14b :11 14d :2 14e :2 14d
:4 14e :3 14d :a 14f :9 150
:3 151 :3 150 :3 153 :3 14f
14e :9 156 :10 157 :3 156
:d 15a :17 15b :a 15c :3 15d
:3 15c :5 15f :5 160 :8 161
:5 162 :7 163 :5 164 :5 165
:8 166 :3 161 :3 15b :3 16a
:2 16b 16a :6 16c :5 16d
16c :5 16f 16e :3 16c
169 :2 172 :5 174 :11 175
:24 176 :3 175 :2 173 :6 172
171 :3 15a :11 17b :b 17c
:3 17b :3 17e :3 15a 155
:3 14d :3 14a 139 :3 136
:1a 184 :9 185 :12 186 :3 185
:7 18a :6 18b :6 18c :5 18d
:2 18e :3 18a 18f 184
:9 18f :9 190 :12 191 :3 190
:7 1c7 :6 1c8 :6 1c9 :5 1ca
:2 1cb :3 1c7 18f :3 184
:9 1cf :7 1d0 1d1 1cf
:14 1d1 :7 1d2 1d1 :3 1cf
:7 1d5 :5 1d6 :3 1d5 :11 1d9
:19 1da :3 1d9 :5 1dc :2 48
:7 1 
2580
4
:3 0 1 :3 0 2
:a 0 aa3 1 :7 0
5 37 0 3
4 :3 0 5 :3 0
6 :3 0 3 :5 0
1 7 6 :3 0
9 6b 0 7
4 :3 0 5 :3 0
6 :3 0 7 :5 0
1 d c :3 0
4 :3 0 5 :3 0
6 :3 0 8 :5 0
1 13 12 :3 0
d 98 0 b
a :3 0 9 :7 0
17 16 :3 0 4
:3 0 5 :3 0 6
:3 0 b :5 0 1
1d 1c :3 0 11
c5 0 f 4
:3 0 5 :3 0 6
:3 0 c :5 0 1
23 22 :3 0 a
:3 0 d :7 0 27
26 :3 0 15 eb
0 13 a :3 0
e :7 0 2b 2a
:3 0 a :3 0 f
:7 0 2f 2e :3 0
19 111 0 17
a :3 0 10 :7 0
33 32 :3 0 a
:3 0 11 :7 0 37
36 :3 0 1d 137
0 1b a :3 0
12 :7 0 3b 3a
:3 0 a :3 0 13
:7 0 3f 3e :3 0
21 15d 0 1f
a :3 0 14 :7 0
43 42 :3 0 a
:3 0 15 :7 0 47
46 :3 0 25 :2 0
23 4 :3 0 5
:3 0 6 :3 0 16
:5 0 1 4d 4c
:3 0 4 :3 0 5
:3 0 6 :3 0 17
:5 0 1 53 52
:3 0 18 :3 0 a
:3 0 55 57 0
aa3 2 58 :2 0
39 1c1 0 37
a :3 0 5b :7 0
9 :3 0 5f 5c
5d aa1 0 19
:6 0 3d 1fd 0
3b a :3 0 61
:7 0 d :3 0 65
62 63 aa1 0
1a :6 0 a :3 0
67 :7 0 e :3 0
6b 68 69 aa1
0 1b :6 0 41
239 0 3f a
:3 0 6d :7 0 f
:3 0 71 6e 6f
aa1 0 1c :6 0
a :3 0 73 :7 0
10 :3 0 77 74
75 aa1 0 1d
:6 0 45 275 0
43 a :3 0 79
:7 0 11 :3 0 7d
7a 7b aa1 0
1e :6 0 a :3 0
7f :7 0 12 :3 0
83 80 81 aa1
0 1f :6 0 49
2b1 0 47 a
:3 0 85 :7 0 13
:3 0 89 86 87
aa1 0 20 :6 0
a :3 0 8b :7 0
14 :3 0 8f 8c
8d aa1 0 21
:6 0 24 :2 0 4d
a :3 0 91 :7 0
15 :3 0 95 92
93 aa1 0 22
:6 0 6 :3 0 24
:2 0 4b 97 99
:6 0 9c 9a 0
aa1 0 23 :6 0
27 :2 0 51 6
:3 0 4f 9e a0
:6 0 a3 a1 0
aa1 0 25 :6 0
27 :2 0 55 6
:3 0 53 a5 a7
:6 0 aa a8 0
aa1 0 26 :6 0
5b 344 0 59
6 :3 0 57 ac
ae :6 0 b1 af
0 aa1 0 28
:6 0 24 :2 0 5d
2a :3 0 b3 :7 0
b6 b4 0 aa1
0 29 :6 0 2a
:3 0 b8 :7 0 bb
b9 0 aa1 0
2b :6 0 24 :2 0
61 6 :3 0 5f
bd bf :6 0 c2
c0 0 aa1 0
2c :6 0 24 :2 0
65 6 :3 0 63
c4 c6 :6 0 c9
c7 0 aa1 0
2d :6 0 24 :2 0
69 6 :3 0 67
cb cd :6 0 d0
ce 0 aa1 0
2e :6 0 31 :2 0
6d 6 :3 0 6b
d2 d4 :6 0 d7
d5 0 aa1 0
2f :6 0 31 :2 0
71 6 :3 0 6f
d9 db :6 0 de
dc 0 aa1 0
30 :6 0 34 :2 0
75 6 :3 0 73
e0 e2 :6 0 e5
e3 0 aa1 0
32 :6 0 31 :2 0
79 6 :3 0 77
e7 e9 :6 0 ec
ea 0 aa1 0
33 :6 0 37 :2 0
7d 6 :3 0 7b
ee f0 :6 0 f3
f1 0 aa1 0
35 :6 0 37 :2 0
7f a :3 0 f5
:7 0 f9 f6 f7
aa1 0 36 :6 0
37 :2 0 81 a
:3 0 fb :7 0 ff
fc fd aa1 0
38 :6 0 37 :2 0
83 a :3 0 101
:7 0 105 102 103
aa1 0 39 :6 0
37 :2 0 85 a
:3 0 107 :7 0 10b
108 109 aa1 0
3a :6 0 37 :2 0
87 a :3 0 10d
:7 0 111 10e 10f
aa1 0 3b :6 0
37 :2 0 89 a
:3 0 113 :7 0 117
114 115 aa1 0
3c :6 0 37 :2 0
8b a :3 0 119
:7 0 11d 11a 11b
aa1 0 3d :6 0
37 :2 0 8d a
:3 0 11f :7 0 123
120 121 aa1 0
3e :6 0 37 :2 0
8f a :3 0 125
:7 0 129 126 127
aa1 0 3f :6 0
24 :2 0 91 a
:3 0 12b :7 0 12f
12c 12d aa1 0
40 :6 0 24 :2 0
95 6 :3 0 93
131 133 :6 0 136
134 0 aa1 0
41 :6 0 9b 5b2
0 99 6 :3 0
97 138 13a :6 0
13d 13b 0 aa1
0 42 :6 0 37
:2 0 9d 2a :3 0
13f :7 0 142 140
0 aa1 0 43
:6 0 2a :3 0 144
:7 0 147 145 0
aa1 0 44 :6 0
37 :2 0 9f 46
:3 0 149 :7 0 14d
14a 14b aa1 0
45 :6 0 37 :2 0
a1 46 :3 0 14f
:7 0 153 150 151
aa1 0 47 :6 0
37 :2 0 a3 a
:3 0 155 :7 0 159
156 157 aa1 0
48 :6 0 37 :2 0
a5 a :3 0 15b
:7 0 15f 15c 15d
aa1 0 49 :6 0
37 :2 0 a7 a
:3 0 161 :7 0 165
162 163 aa1 0
4a :6 0 37 :2 0
a9 a :3 0 167
:7 0 16b 168 169
aa1 0 4b :6 0
37 :2 0 ab a
:3 0 16d :7 0 171
16e 16f aa1 0
4c :6 0 37 :2 0
ad a :3 0 173
:7 0 177 174 175
aa1 0 4d :6 0
37 :2 0 af a
:3 0 179 :7 0 17d
17a 17b aa1 0
4e :6 0 37 :2 0
b1 a :3 0 17f
:7 0 183 180 181
aa1 0 4f :6 0
37 :2 0 b3 a
:3 0 185 :7 0 189
186 187 aa1 0
50 :6 0 190 191
0 b5 46 :3 0
18b :7 0 18f 18c
18d aa1 0 51
:6 0 52 :3 0 53
:3 0 52 :3 0 54
:3 0 193 194 0
2 :4 0 b7 195
197 192 199 198
:2 0 55 :3 0 56
:3 0 19b 19c 0
57 :4 0 52 :3 0
58 :3 0 19f 1a0
0 2 :4 0 b9
1a1 1a3 59 :4 0
5a :2 0 5b :3 0
bb 1a6 1a8 :3 0
5c :4 0 5a :2 0
5d :4 0 be 1ab
1ad :3 0 5a :2 0
3 :3 0 c1 1af
1b1 :3 0 5a :2 0
5d :4 0 c4 1b3
1b5 :3 0 5a :2 0
5e :4 0 c7 1b7
1b9 :3 0 5a :2 0
5d :4 0 ca 1bb
1bd :3 0 5a :2 0
7 :3 0 cd 1bf
1c1 :3 0 5a :2 0
5d :4 0 d0 1c3
1c5 :3 0 5a :2 0
5e :4 0 d3 1c7
1c9 :3 0 5a :2 0
5d :4 0 d6 1cb
1cd :3 0 5a :2 0
8 :3 0 d9 1cf
1d1 :3 0 5a :2 0
5d :4 0 dc 1d3
1d5 :3 0 5a :2 0
5e :4 0 df 1d7
1d9 :3 0 5a :2 0
5f :3 0 60 :3 0
9 :3 0 e2 1dd
1df 61 :4 0 e4
1dc 1e2 e7 1db
1e4 :3 0 5a :2 0
5e :4 0 ea 1e6
1e8 :3 0 5a :2 0
5d :4 0 ed 1ea
1ec :3 0 5a :2 0
b :3 0 f0 1ee
1f0 :3 0 5a :2 0
5d :4 0 f3 1f2
1f4 :3 0 5a :2 0
5e :4 0 f6 1f6
1f8 :3 0 5a :2 0
5d :4 0 f9 1fa
1fc :3 0 5a :2 0
c :3 0 fc 1fe
200 :3 0 5a :2 0
5d :4 0 ff 202
204 :3 0 5a :2 0
5e :4 0 102 206
208 :3 0 5a :2 0
5f :3 0 60 :3 0
d :3 0 105 20c
20e 61 :4 0 107
20b 211 10a 20a
213 :3 0 5a :2 0
5e :4 0 10d 215
217 :3 0 5a :2 0
5f :3 0 60 :3 0
e :3 0 110 21b
21d 61 :4 0 112
21a 220 115 219
222 :3 0 5a :2 0
5e :4 0 118 224
226 :3 0 5a :2 0
5f :3 0 60 :3 0
f :3 0 11b 22a
22c 61 :4 0 11d
229 22f 120 228
231 :3 0 5a :2 0
5e :4 0 123 233
235 :3 0 5a :2 0
5f :3 0 60 :3 0
10 :3 0 126 239
23b 61 :4 0 128
238 23e 12b 237
240 :3 0 5a :2 0
5e :4 0 12e 242
244 :3 0 5a :2 0
5f :3 0 60 :3 0
11 :3 0 131 248
24a 61 :4 0 133
247 24d 136 246
24f :3 0 5a :2 0
5e :4 0 139 251
253 :3 0 5a :2 0
5f :3 0 60 :3 0
12 :3 0 13c 257
259 61 :4 0 13e
256 25c 141 255
25e :3 0 5a :2 0
5e :4 0 144 260
262 :3 0 5a :2 0
5f :3 0 60 :3 0
13 :3 0 147 266
268 61 :4 0 149
265 26b 14c 264
26d :3 0 5a :2 0
5e :4 0 14f 26f
271 :3 0 5a :2 0
5f :3 0 60 :3 0
14 :3 0 152 275
277 61 :4 0 154
274 27a 157 273
27c :3 0 5a :2 0
5e :4 0 15a 27e
280 :3 0 5a :2 0
5f :3 0 60 :3 0
15 :3 0 15d 284
286 61 :4 0 15f
283 289 162 282
28b :3 0 5a :2 0
5e :4 0 165 28d
28f :3 0 5a :2 0
5d :4 0 168 291
293 :3 0 5a :2 0
16 :3 0 16b 295
297 :3 0 5a :2 0
5d :4 0 16e 299
29b :3 0 5a :2 0
5e :4 0 171 29d
29f :3 0 5a :2 0
5d :4 0 174 2a1
2a3 :3 0 5a :2 0
17 :3 0 177 2a5
2a7 :3 0 5a :2 0
5d :4 0 17a 2a9
2ab :3 0 5a :2 0
62 :4 0 17d 2ad
2af :3 0 180 19d
2b1 :2 0 2b3 185
2b4 19a 2b3 0
2b5 187 0 a9f
52 :3 0 53 :3 0
2b6 2b7 0 52
:3 0 63 :3 0 2b9
2ba 0 31 :2 0
2 :4 0 64 :2 0
65 :2 0 31 :2 0
189 2bf 2c1 :3 0
18c 2bb 2c3 2b8
2c5 2c4 :2 0 55
:3 0 66 :3 0 2c7
2c8 0 57 :4 0
67 :4 0 5a :2 0
5b :3 0 190 2cc
2ce :3 0 193 2c9
2d0 :2 0 2d2 196
2d3 2c6 2d2 0
2d4 198 0 a9f
5f :3 0 1f :3 0
37 :2 0 19a 2d5
2d8 68 :3 0 69
:2 0 6a :3 0 2da
2dc 0 19f 2db
2de :3 0 3c :3 0
6b :3 0 6c :3 0
2e1 2e2 0 6d
:3 0 5f :3 0 1f
:3 0 37 :2 0 1a2
2e5 2e8 68 :3 0
6e :3 0 2ea 2eb
0 1a5 2e4 2ed
2ee :2 0 6f :2 0
1a8 2e3 2f1 2e0
2f2 0 308 3a
:3 0 6d :3 0 5f
:3 0 1f :3 0 37
:2 0 1ab 2f6 2f9
68 :3 0 70 :3 0
2fb 2fc 0 1ae
2f5 2fe 2f4 2ff
0 308 1f :3 0
37 :2 0 301 302
0 308 3b :3 0
37 :2 0 304 305
0 308 71 :3 0
1b1 343 5f :3 0
1f :3 0 37 :2 0
1b6 309 30c 68
:3 0 69 :2 0 72
:3 0 30e 310 0
1bb 30f 312 :3 0
3b :3 0 6d :3 0
5f :3 0 1f :3 0
37 :2 0 1be 316
319 68 :3 0 72
:3 0 31b 31c 0
1c1 315 31e 31f
:2 0 314 320 0
333 1f :3 0 6d
:3 0 5f :3 0 1f
:3 0 37 :2 0 1c4
324 327 68 :3 0
73 :3 0 329 32a
0 1c7 323 32c
32d :2 0 322 32e
0 333 3a :3 0
37 :2 0 330 331
0 333 1ca 334
313 333 0 345
3a :3 0 5f :3 0
1f :3 0 37 :2 0
1ce 336 339 335
33a 0 342 1f
:3 0 37 :2 0 33c
33d 0 342 3b
:3 0 37 :2 0 33f
340 0 342 1d1
344 2df 308 0
345 0 342 0
345 1d5 0 a9f
4b :3 0 37 :2 0
346 347 0 a9f
30 :3 0 37 :4 0
349 34a 0 a9f
3f :3 0 37 :2 0
34c 34d 0 a9f
2b :4 0 34f 350
0 a9f 43 :4 0
352 353 0 a9f
44 :4 0 355 356
0 a9f 35 :4 0
358 359 0 a9f
51 :3 0 74 :2 0
35b 35c 0 a9f
5f :3 0 1f :3 0
37 :2 0 1d9 35e
361 75 :2 0 31
:2 0 1de 363 365
:3 0 2c :3 0 3
:3 0 367 368 0
40c 76 :3 0 77
:3 0 78 :3 0 79
:3 0 7a :3 0 7b
:3 0 7c :3 0 7d
:3 0 7e :3 0 7c
:3 0 7d :3 0 7f
:3 0 80 :3 0 81
:3 0 82 :3 0 83
:3 0 2d :3 0 23
:3 0 25 :3 0 30
:3 0 2b :3 0 3f
:3 0 43 :3 0 44
:3 0 48 :3 0 49
:3 0 45 :3 0 47
:3 0 84 :3 0 85
:3 0 2c :4 0 86
1 :8 0 38f 87
:3 0 88 :3 0 38a
38b 0 89 :3 0
38c 38d 0 38f
1e1 3d9 8a :3 0
87 :3 0 88 :3 0
392 393 0 89
:3 0 394 395 0
3cf 52 :3 0 53
:3 0 397 398 0
52 :3 0 63 :3 0
39a 39b 0 8b
:2 0 2 :4 0 8c
:2 0 65 :2 0 31
:2 0 1e4 3a0 3a2
:3 0 1e7 39c 3a4
399 3a6 3a5 :2 0
55 :3 0 66 :3 0
3a8 3a9 0 57
:4 0 8d :4 0 5a
:2 0 5b :3 0 1eb
3ad 3af :3 0 5a
:2 0 8e :4 0 1ee
3b1 3b3 :3 0 5a
:2 0 8f :4 0 1f1
3b5 3b7 :3 0 5a
:2 0 89 :3 0 1f4
3b9 3bb :3 0 5a
:2 0 90 :4 0 1f7
3bd 3bf :3 0 5a
:2 0 7d :3 0 91
:3 0 31 :2 0 92
:2 0 1fa 3c2 3c6
1fe 3c1 3c8 :3 0
201 3aa 3ca :2 0
3cc 204 3cd 3a7
3cc 0 3ce 206
0 3cf 208 3d2
:3 0 3d2 0 3d2
3d1 3cf 3d0 :6 0
3d4 2 :3 0 20b
3d6 20d 3d5 3d4
:2 0 3d7 20f :2 0
3d9 0 3d9 3d8
38f 3d7 :6 0 40c
1 :3 0 87 :3 0
88 :3 0 3db 3dc
0 87 :3 0 75
:2 0 93 :3 0 3de
3e0 0 213 3df
3e2 :3 0 3e3 :2 0
52 :3 0 53 :3 0
3e5 3e6 0 52
:3 0 63 :3 0 3e8
3e9 0 31 :2 0
2 :4 0 94 :2 0
65 :2 0 31 :2 0
216 3ee 3f0 :3 0
219 3ea 3f2 3e7
3f4 3f3 :2 0 55
:3 0 66 :3 0 3f6
3f7 0 57 :4 0
95 :4 0 5a :2 0
5b :3 0 21d 3fb
3fd :3 0 220 3f8
3ff :2 0 401 223
402 3f5 401 0
403 225 0 409
18 :3 0 68 :3 0
96 :3 0 405 406
0 407 :2 0 409
227 40a 3e4 409
0 40b 22a 0
40c 22c 5dd 76
:3 0 97 :3 0 78
:3 0 98 :3 0 79
:3 0 99 :3 0 9a
:3 0 2d :3 0 23
:3 0 25 :3 0 38
:3 0 30 :3 0 2f
:3 0 3e :3 0 9b
:3 0 9c :3 0 3
:4 0 9d 1 :8 0
424 87 :3 0 88
:3 0 41f 420 0
89 :3 0 421 422
0 424 230 46e
8a :3 0 87 :3 0
88 :3 0 427 428
0 89 :3 0 429
42a 0 464 52
:3 0 53 :3 0 42c
42d 0 52 :3 0
63 :3 0 42f 430
0 8b :2 0 2
:4 0 9e :2 0 65
:2 0 31 :2 0 233
435 437 :3 0 236
431 439 42e 43b
43a :2 0 55 :3 0
66 :3 0 43d 43e
0 57 :4 0 9f
:4 0 5a :2 0 5b
:3 0 23a 442 444
:3 0 5a :2 0 8e
:4 0 23d 446 448
:3 0 5a :2 0 8f
:4 0 240 44a 44c
:3 0 5a :2 0 89
:3 0 243 44e 450
:3 0 5a :2 0 90
:4 0 246 452 454
:3 0 5a :2 0 7d
:3 0 91 :3 0 31
:2 0 92 :2 0 249
457 45b 24d 456
45d :3 0 250 43f
45f :2 0 461 253
462 43c 461 0
463 255 0 464
257 467 :3 0 467
0 467 466 464
465 :6 0 469 4
:3 0 25a 46b 25c
46a 469 :2 0 46c
25e :2 0 46e 0
46e 46d 424 46c
:6 0 5dc 1 :3 0
87 :3 0 88 :3 0
470 471 0 87
:3 0 75 :2 0 93
:3 0 473 475 0
262 474 477 :3 0
478 :2 0 52 :3 0
53 :3 0 47a 47b
0 52 :3 0 63
:3 0 47d 47e 0
31 :2 0 2 :4 0
a0 :2 0 65 :2 0
31 :2 0 265 483
485 :3 0 268 47f
487 47c 489 488
:2 0 55 :3 0 66
:3 0 48b 48c 0
57 :4 0 a1 :4 0
5a :2 0 5b :3 0
26c 490 492 :3 0
26f 48d 494 :2 0
496 272 497 48a
496 0 498 274
0 49f 18 :3 0
68 :3 0 96 :3 0
49a 49b 0 49c
:2 0 49f 71 :3 0
276 4d2 a2 :3 0
5f :3 0 38 :3 0
37 :2 0 279 4a1
4a4 27c 4a0 4a6
a3 :2 0 37 :2 0
280 4a8 4aa :3 0
52 :3 0 53 :3 0
4ac 4ad 0 52
:3 0 63 :3 0 4af
4b0 0 31 :2 0
2 :4 0 a4 :2 0
65 :2 0 31 :2 0
283 4b5 4b7 :3 0
286 4b1 4b9 4ae
4bb 4ba :2 0 55
:3 0 66 :3 0 4bd
4be 0 57 :4 0
a5 :4 0 5a :2 0
5b :3 0 28a 4c2
4c4 :3 0 28d 4bf
4c6 :2 0 4c8 290
4c9 4bc 4c8 0
4ca 292 0 4d0
18 :3 0 68 :3 0
a6 :3 0 4cc 4cd
0 4ce :2 0 4d0
294 4d1 4ab 4d0
0 4d3 479 49f
0 4d3 297 0
5dc 9b :3 0 a7
:3 0 19 :3 0 9c
:3 0 3 :4 0 a8
1 :8 0 4ef a9
:4 0 4da :3 0 aa
:3 0 75 :2 0 29c
4dd 4de :3 0 87
:3 0 88 :3 0 4e0
4e1 0 37 :2 0
4e2 4e3 0 4e5
29f 4ec 87 :3 0
88 :3 0 4e6 4e7
0 ab :2 0 4e8
4e9 0 4eb 2a1
4ed 4df 4e5 0
4ee 0 4eb 0
4ee 2a3 0 4ef
2a6 539 8a :3 0
87 :3 0 88 :3 0
4f2 4f3 0 89
:3 0 4f4 4f5 0
52f 52 :3 0 53
:3 0 4f7 4f8 0
52 :3 0 63 :3 0
4fa 4fb 0 8b
:2 0 2 :4 0 ac
:2 0 65 :2 0 31
:2 0 2a9 500 502
:3 0 2ac 4fc 504
4f9 506 505 :2 0
55 :3 0 66 :3 0
508 509 0 57
:4 0 ad :4 0 5a
:2 0 5b :3 0 2b0
50d 50f :3 0 5a
:2 0 8e :4 0 2b3
511 513 :3 0 5a
:2 0 8f :4 0 2b6
515 517 :3 0 5a
:2 0 89 :3 0 2b9
519 51b :3 0 5a
:2 0 90 :4 0 2bc
51d 51f :3 0 5a
:2 0 7d :3 0 91
:3 0 31 :2 0 92
:2 0 2bf 522 526
2c3 521 528 :3 0
2c6 50a 52a :2 0
52c 2c9 52d 507
52c 0 52e 2cb
0 52f 2cd 532
:3 0 532 0 532
531 52f 530 :6 0
534 6 :3 0 2d0
536 2d2 535 534
:2 0 537 2d4 :2 0
539 0 539 538
4ef 537 :6 0 5dc
1 :3 0 ae :3 0
5f :3 0 38 :3 0
37 :2 0 2d6 53c
53f 2d9 53b 541
542 :2 0 a3 :2 0
37 :2 0 2dd 544
546 :3 0 af :2 0
2e0 548 549 :3 0
85 :3 0 2c :3 0
84 :3 0 9c :3 0
3 :4 0 b0 1
:8 0 556 87 :3 0
88 :3 0 551 552
0 89 :3 0 553
554 0 556 2e2
5a0 8a :3 0 87
:3 0 88 :3 0 559
55a 0 89 :3 0
55b 55c 0 596
52 :3 0 53 :3 0
55e 55f 0 52
:3 0 63 :3 0 561
562 0 8b :2 0
2 :4 0 b1 :2 0
65 :2 0 31 :2 0
2e5 567 569 :3 0
2e8 563 56b 560
56d 56c :2 0 55
:3 0 66 :3 0 56f
570 0 57 :4 0
b2 :4 0 5a :2 0
5b :3 0 2ec 574
576 :3 0 5a :2 0
8e :4 0 2ef 578
57a :3 0 5a :2 0
8f :4 0 2f2 57c
57e :3 0 5a :2 0
89 :3 0 2f5 580
582 :3 0 5a :2 0
90 :4 0 2f8 584
586 :3 0 5a :2 0
7d :3 0 91 :3 0
31 :2 0 92 :2 0
2fb 589 58d 2ff
588 58f :3 0 302
571 591 :2 0 593
305 594 56e 593
0 595 307 0
596 309 599 :3 0
599 0 599 598
596 597 :6 0 59b
8 :3 0 30c 59d
30e 59c 59b :2 0
59e 310 :2 0 5a0
0 5a0 59f 556
59e :6 0 5d3 1
:3 0 87 :3 0 88
:3 0 5a2 5a3 0
87 :3 0 75 :2 0
b3 :3 0 5a5 5a7
0 314 5a6 5a9
:3 0 5aa :2 0 52
:3 0 53 :3 0 5ac
5ad 0 52 :3 0
63 :3 0 5af 5b0
0 31 :2 0 2
:4 0 b4 :2 0 65
:2 0 31 :2 0 317
5b5 5b7 :3 0 31a
5b1 5b9 5ae 5bb
5ba :2 0 55 :3 0
66 :3 0 5bd 5be
0 57 :4 0 b5
:4 0 5a :2 0 5b
:3 0 31e 5c2 5c4
:3 0 321 5bf 5c6
:2 0 5c8 324 5c9
5bc 5c8 0 5ca
326 0 5d0 18
:3 0 68 :3 0 b6
:3 0 5cc 5cd 0
5ce :2 0 5d0 328
5d1 5ab 5d0 0
5d2 32b 0 5d3
32d 5d4 54a 5d3
0 5d5 330 0
5dc 3d :3 0 b7
:3 0 3 :3 0 332
5d7 5d9 5d6 5da
0 5dc 334 5de
366 40c 0 5df
0 5dc 0 5df
33a 0 a9f 5f
:3 0 b8 :3 0 5f
:3 0 b9 :3 0 ba
:3 0 bb :3 0 36
:3 0 39 :3 0 2e
:3 0 4e :3 0 bc
:3 0 97 :3 0 2d
:4 0 bd 1 :8 0
5f3 87 :3 0 88
:3 0 5ee 5ef 0
89 :3 0 5f0 5f1
0 5f3 33d 63d
8a :3 0 87 :3 0
88 :3 0 5f6 5f7
0 89 :3 0 5f8
5f9 0 633 52
:3 0 53 :3 0 5fb
5fc 0 52 :3 0
63 :3 0 5fe 5ff
0 8b :2 0 2
:4 0 be :2 0 65
:2 0 31 :2 0 340
604 606 :3 0 343
600 608 5fd 60a
609 :2 0 55 :3 0
66 :3 0 60c 60d
0 57 :4 0 bf
:4 0 5a :2 0 5b
:3 0 347 611 613
:3 0 5a :2 0 8e
:4 0 34a 615 617
:3 0 5a :2 0 8f
:4 0 34d 619 61b
:3 0 5a :2 0 89
:3 0 350 61d 61f
:3 0 5a :2 0 90
:4 0 353 621 623
:3 0 5a :2 0 7d
:3 0 91 :3 0 31
:2 0 92 :2 0 356
626 62a 35a 625
62c :3 0 35d 60e
62e :2 0 630 360
631 60b 630 0
632 362 0 633
364 636 :3 0 636
0 636 635 633
634 :6 0 638 a
:3 0 367 63a 369
639 638 :2 0 63b
36b :2 0 63d 0
63d 63c 5f3 63b
:6 0 a9f 1 :3 0
5f :3 0 3b :3 0
37 :2 0 36d 63f
642 75 :2 0 37
:2 0 372 644 646
:3 0 5f :3 0 1b
:3 0 37 :2 0 375
648 64b c0 :2 0
37 :2 0 37a 64d
64f :3 0 650 :2 0
5f :3 0 1d :3 0
37 :2 0 37d 652
655 75 :2 0 c1
:2 0 382 657 659
:3 0 65a :2 0 651
65c 65b :2 0 1b
:3 0 5f :3 0 36
:3 0 37 :2 0 385
65f 662 c2 :2 0
5f :3 0 1b :3 0
37 :2 0 388 665
668 38b 664 66a
:3 0 65e 66b 0
66d 38e 66e 65d
66d 0 66f 390
0 77f 5f :3 0
1a :3 0 37 :2 0
392 670 673 75
:2 0 37 :2 0 397
675 677 :3 0 c
:3 0 c3 :2 0 39a
67a 67b :3 0 67c
:2 0 5f :3 0 1b
:3 0 37 :2 0 39c
67e 681 c0 :2 0
37 :2 0 3a1 683
685 :3 0 1a :3 0
5f :3 0 22 :3 0
37 :2 0 3a4 688
68b c2 :2 0 5f
:3 0 1b :3 0 37
:2 0 3a7 68e 691
3aa 68d 693 :3 0
687 694 0 696
3ad 697 686 696
0 698 3af 0
699 3b1 6fa c4
:3 0 c5 :3 0 1a
:3 0 c6 :3 0 97
:3 0 2d :3 0 c7
:3 0 7c :3 0 7d
:3 0 b :3 0 7c
:3 0 7d :3 0 c
:4 0 c8 1 :8 0
6ad 87 :3 0 88
:3 0 6a8 6a9 0
89 :3 0 6aa 6ab
0 6ad 3b3 6f7
8a :3 0 87 :3 0
88 :3 0 6b0 6b1
0 89 :3 0 6b2
6b3 0 6ed 52
:3 0 53 :3 0 6b5
6b6 0 52 :3 0
63 :3 0 6b8 6b9
0 8b :2 0 2
:4 0 c9 :2 0 65
:2 0 31 :2 0 3b6
6be 6c0 :3 0 3b9
6ba 6c2 6b7 6c4
6c3 :2 0 55 :3 0
66 :3 0 6c6 6c7
0 57 :4 0 ca
:4 0 5a :2 0 5b
:3 0 3bd 6cb 6cd
:3 0 5a :2 0 8e
:4 0 3c0 6cf 6d1
:3 0 5a :2 0 8f
:4 0 3c3 6d3 6d5
:3 0 5a :2 0 89
:3 0 3c6 6d7 6d9
:3 0 5a :2 0 90
:4 0 3c9 6db 6dd
:3 0 5a :2 0 7d
:3 0 91 :3 0 31
:2 0 92 :2 0 3cc
6e0 6e4 3d0 6df
6e6 :3 0 3d3 6c8
6e8 :2 0 6ea 3d6
6eb 6c5 6ea 0
6ec 3d8 0 6ed
3da 6f0 :3 0 6f0
0 6f0 6ef 6ed
6ee :6 0 6f2 c
:3 0 3dd 6f4 3df
6f3 6f2 :2 0 6f5
3e1 :2 0 6f7 0
6f7 6f6 6ad 6f5
:6 0 6f9 1 :3 0
3e3 6fb 67d 699
0 6fc 0 6f9
0 6fc 3e5 0
6fd 3e8 74c 5f
:3 0 1c :3 0 37
:2 0 3ea 6fe 701
75 :2 0 31 :2 0
3ef 703 705 :3 0
1a :3 0 5f :3 0
1a :3 0 37 :2 0
3f2 708 70b c2
:2 0 cb :2 0 3f5
70d 70f :3 0 707
710 0 713 71
:3 0 3f8 749 5f
:3 0 1c :3 0 37
:2 0 3fa 714 717
75 :2 0 cc :2 0
3ff 719 71b :3 0
1a :3 0 5f :3 0
36 :3 0 37 :2 0
402 71e 721 c2
:2 0 5f :3 0 1a
:3 0 37 :2 0 405
724 727 408 723
729 :3 0 71d 72a
0 72d 71 :3 0
40b 72e 71c 72d
0 74a 5f :3 0
1c :3 0 37 :2 0
40d 72f 732 75
:2 0 cd :2 0 412
734 736 :3 0 1a
:3 0 5f :3 0 39
:3 0 37 :2 0 415
739 73c c2 :2 0
5f :3 0 1a :3 0
37 :2 0 418 73f
742 41b 73e 744
:3 0 738 745 0
747 41e 748 737
747 0 74a 706
713 0 74a 420
0 74b 424 74d
678 6fd 0 74e
0 74b 0 74e
426 0 77f 5f
:3 0 1a :3 0 37
:2 0 429 74f 752
75 :2 0 37 :2 0
42e 754 756 :3 0
52 :3 0 53 :3 0
758 759 0 52
:3 0 63 :3 0 75b
75c 0 31 :2 0
2 :4 0 ce :2 0
65 :2 0 31 :2 0
431 761 763 :3 0
434 75d 765 75a
767 766 :2 0 55
:3 0 66 :3 0 769
76a 0 57 :4 0
cf :4 0 5a :2 0
5b :3 0 438 76e
770 :3 0 43b 76b
772 :2 0 774 43e
775 768 774 0
776 440 0 77c
18 :3 0 68 :3 0
a6 :3 0 778 779
0 77a :2 0 77c
442 77d 757 77c
0 77e 445 0
77f 447 780 647
77f 0 781 44b
0 a9f 5f :3 0
1f :3 0 37 :2 0
44d 782 785 75
:2 0 cc :2 0 452
787 789 :3 0 1f
:3 0 6d :3 0 5f
:3 0 1f :3 0 37
:2 0 455 78d 790
68 :3 0 d0 :3 0
792 793 0 458
78c 795 796 :2 0
78b 797 0 79a
71 :3 0 45b 98c
7d :3 0 30 :3 0
31 :2 0 31 :2 0
45d 79b 79f 75
:2 0 37 :4 0 463
7a1 7a3 :3 0 7a4
:2 0 5f :3 0 1e
:3 0 37 :2 0 466
7a6 7a9 75 :2 0
37 :2 0 46b 7ab
7ad :3 0 7ae :2 0
7a5 7b0 7af :2 0
85 :3 0 d1 :3 0
d2 :3 0 d3 :3 0
d4 :3 0 d5 :3 0
2c :3 0 26 :3 0
28 :3 0 4d :3 0
32 :3 0 84 :3 0
76 :3 0 2d :3 0
77 :3 0 2d :3 0
78 :3 0 25 :4 0
d6 1 :8 0 7ca
87 :3 0 88 :3 0
7c5 7c6 0 89
:3 0 7c7 7c8 0
7ca 46e 814 8a
:3 0 87 :3 0 88
:3 0 7cd 7ce 0
89 :3 0 7cf 7d0
0 80a 52 :3 0
53 :3 0 7d2 7d3
0 52 :3 0 63
:3 0 7d5 7d6 0
8b :2 0 2 :4 0
d7 :2 0 65 :2 0
31 :2 0 471 7db
7dd :3 0 474 7d7
7df 7d4 7e1 7e0
:2 0 55 :3 0 66
:3 0 7e3 7e4 0
57 :4 0 d8 :4 0
5a :2 0 5b :3 0
478 7e8 7ea :3 0
5a :2 0 8e :4 0
47b 7ec 7ee :3 0
5a :2 0 8f :4 0
47e 7f0 7f2 :3 0
5a :2 0 89 :3 0
481 7f4 7f6 :3 0
5a :2 0 90 :4 0
484 7f8 7fa :3 0
5a :2 0 7d :3 0
91 :3 0 31 :2 0
92 :2 0 487 7fd
801 48b 7fc 803
:3 0 48e 7e5 805
:2 0 807 491 808
7e2 807 0 809
493 0 80a 495
80d :3 0 80d 0
80d 80c 80a 80b
:6 0 80f e :3 0
498 811 49a 810
80f :2 0 812 49c
:2 0 814 0 814
813 7ca 812 :6 0
98a 1 :3 0 87
:3 0 88 :3 0 816
817 0 87 :3 0
75 :2 0 b3 :3 0
819 81b 0 4a0
81a 81d :3 0 81e
:2 0 2c :3 0 d9
:2 0 4a3 821 822
:3 0 823 :2 0 81f
825 824 :2 0 1f
:3 0 6d :3 0 5f
:3 0 1f :3 0 37
:2 0 4a5 829 82c
68 :3 0 d0 :3 0
82e 82f 0 4a8
828 831 832 :2 0
827 833 0 987
da :3 0 db :3 0
835 836 0 b
:3 0 26 :3 0 dc
:2 0 4ab 837 83b
69 :2 0 37 :2 0
4b1 83d 83f :3 0
840 :2 0 da :3 0
db :3 0 842 843
0 28 :3 0 c
:3 0 dc :2 0 4b4
844 848 69 :2 0
37 :2 0 4ba 84a
84c :3 0 84d :2 0
841 84f 84e :2 0
7d :3 0 32 :3 0
31 :2 0 31 :2 0
4bd 851 855 75
:2 0 cc :4 0 4c3
857 859 :3 0 5f
:3 0 3b :3 0 37
:2 0 4c6 85b 85e
75 :2 0 37 :2 0
4cb 860 862 :3 0
1f :3 0 cc :2 0
864 865 0 867
4ce 868 863 867
0 869 4d0 0
86d 1e :3 0 cc
:2 0 86a 86b 0
86d 4d2 86e 85a
86d 0 86f 4d5
0 870 4d7 984
5f :3 0 1f :3 0
37 :2 0 4d9 871
874 75 :2 0 31
:2 0 4de 876 878
:3 0 3a :3 0 6b
:3 0 dd :3 0 87b
87c 0 5f :3 0
3a :3 0 37 :2 0
4e1 87e 881 68
:3 0 6a :3 0 883
884 0 4e4 87d
886 887 :2 0 87a
888 0 88a 4e7
88b 879 88a 0
88c 4e9 0 983
5f :3 0 4d :3 0
37 :2 0 4eb 88d
890 5f :3 0 de
:2 0 1a :3 0 37
:2 0 4ee 892 896
4f3 893 898 :3 0
5f :3 0 4d :3 0
37 :2 0 4f6 89a
89d c0 :2 0 37
:2 0 4fb 89f 8a1
:3 0 da :3 0 db
:3 0 8a3 8a4 0
b :3 0 28 :3 0
dc :2 0 4fe 8a5
8a9 69 :2 0 37
:2 0 504 8ab 8ad
:3 0 8a2 8af 8ae
:2 0 7d :3 0 32
:3 0 31 :2 0 31
:2 0 507 8b1 8b5
75 :2 0 37 :4 0
50d 8b7 8b9 :3 0
4f :3 0 cd :2 0
8bb 8bc 0 8be
510 8bf 8ba 8be
0 8c0 512 0
8f4 3d :3 0 df
:4 0 8c2 8c3 :3 0
8c1 8c4 0 8f4
3a :3 0 68 :3 0
e0 :3 0 8c7 8c8
0 8c6 8c9 0
8f4 3d :3 0 e1
:3 0 3 :3 0 2d
:3 0 23 :3 0 25
:3 0 51 :3 0 38
:3 0 7 :3 0 8
:3 0 35 :3 0 35
:3 0 b :3 0 28
:3 0 50 :3 0 4d
:3 0 1b :3 0 1c
:3 0 1d :3 0 50
:3 0 3a :3 0 30
:3 0 1e :3 0 1f
:3 0 20 :3 0 22
:3 0 4f :3 0 36
:3 0 4e :3 0 17
:3 0 5f :3 0 36
:3 0 37 :2 0 514
8e9 8ec 37 :2 0
74 :2 0 74 :2 0
517 8cc 8f1 8cb
8f2 0 8f4 538
8f5 8b0 8f4 0
8f6 53d 0 980
84 :3 0 e2 :3 0
1a :3 0 9c :3 0
3 :4 0 e3 1
:8 0 912 a9 :4 0
8fd :3 0 aa :3 0
75 :2 0 541 900
901 :3 0 87 :3 0
88 :3 0 903 904
0 37 :2 0 905
906 0 908 544
90f 87 :3 0 88
:3 0 909 90a 0
ab :2 0 90b 90c
0 90e 546 910
902 908 0 911
0 90e 0 911
548 0 912 54b
95c 8a :3 0 87
:3 0 88 :3 0 915
916 0 89 :3 0
917 918 0 952
52 :3 0 53 :3 0
91a 91b 0 52
:3 0 63 :3 0 91d
91e 0 8b :2 0
2 :4 0 e4 :2 0
65 :2 0 31 :2 0
54e 923 925 :3 0
551 91f 927 91c
929 928 :2 0 55
:3 0 66 :3 0 92b
92c 0 57 :4 0
e5 :4 0 5a :2 0
5b :3 0 555 930
932 :3 0 5a :2 0
8e :4 0 558 934
936 :3 0 5a :2 0
8f :4 0 55b 938
93a :3 0 5a :2 0
89 :3 0 55e 93c
93e :3 0 5a :2 0
90 :4 0 561 940
942 :3 0 5a :2 0
7d :3 0 91 :3 0
31 :2 0 92 :2 0
564 945 949 568
944 94b :3 0 56b
92d 94d :2 0 94f
56e 950 92a 94f
0 951 570 0
952 572 955 :3 0
955 0 955 954
952 953 :6 0 957
10 :3 0 575 959
577 958 957 :2 0
95a 579 :2 0 95c
0 95c 95b 912
95a :6 0 980 1
:3 0 52 :3 0 53
:3 0 95e 95f 0
52 :3 0 63 :3 0
961 962 0 31
:2 0 2 :4 0 e6
:2 0 65 :2 0 31
:2 0 57b 967 969
:3 0 57e 963 96b
960 96d 96c :2 0
55 :3 0 66 :3 0
96f 970 0 57
:4 0 e7 :4 0 5a
:2 0 5b :3 0 582
974 976 :3 0 585
971 978 :2 0 97a
588 97b 96e 97a
0 97c 58a 0
980 18 :3 0 37
:2 0 97e :2 0 980
58c 981 899 980
0 982 591 0
983 593 985 850
870 0 986 0
983 0 986 596
0 987 599 988
826 987 0 989
59c 0 98a 59e
98b 7b1 98a 0
98d 78a 79a 0
98d 5a1 0 a9f
5f :3 0 1f :3 0
37 :2 0 5a4 98e
991 75 :2 0 37
:2 0 5a9 993 995
:3 0 996 :2 0 5f
:3 0 22 :3 0 37
:2 0 5ac 998 99b
5f :3 0 75 :2 0
3f :3 0 37 :2 0
5af 99d 9a1 5b4
99e 9a3 :3 0 9a4
:2 0 997 9a6 9a5
:2 0 5f :3 0 3b
:3 0 37 :2 0 5b7
9a8 9ab a3 :2 0
37 :2 0 5bc 9ad
9af :3 0 1f :3 0
6b :3 0 dd :3 0
9b2 9b3 0 5f
:3 0 1f :3 0 37
:2 0 5bf 9b5 9b8
5f :3 0 3b :3 0
37 :2 0 5c2 9ba
9bd 5c5 9b4 9bf
9c0 :2 0 9b1 9c1
0 9c3 5c8 9c4
9b0 9c3 0 9c5
5ca 0 9e4 3d
:3 0 e8 :3 0 3
:3 0 2d :3 0 23
:3 0 25 :3 0 7
:3 0 8 :3 0 b
:3 0 c :3 0 1a
:3 0 1b :3 0 1c
:3 0 1d :3 0 30
:3 0 1e :3 0 1f
:3 0 20 :3 0 21
:3 0 22 :3 0 3a
:3 0 16 :3 0 17
:3 0 36 :3 0 74
:2 0 74 :2 0 5cc
9c7 9e0 9c6 9e1
0 9e4 71 :3 0
5e5 a2b 5f :3 0
1f :3 0 37 :2 0
5e8 9e5 9e8 75
:2 0 31 :2 0 5ed
9ea 9ec :3 0 5f
:3 0 3b :3 0 37
:2 0 5f0 9ee 9f1
a3 :2 0 37 :2 0
5f5 9f3 9f5 :3 0
1f :3 0 6b :3 0
dd :3 0 9f8 9f9
0 5f :3 0 1f
:3 0 37 :2 0 5f8
9fb 9fe 5f :3 0
3b :3 0 37 :2 0
5fb a00 a03 5fe
9fa a05 a06 :2 0
9f7 a07 0 a09
601 a0a 9f6 a09
0 a0b 603 0
a29 3d :3 0 e8
:3 0 2c :3 0 2d
:3 0 23 :3 0 25
:3 0 7 :3 0 8
:3 0 b :3 0 c
:3 0 1a :3 0 1b
:3 0 1c :3 0 1d
:3 0 30 :3 0 1e
:3 0 1f :3 0 20
:3 0 21 :3 0 22
:3 0 3a :3 0 16
:3 0 17 :3 0 36
:3 0 74 :2 0 74
:2 0 605 a0d a26
a0c a27 0 a29
61e a2a 9ed a29
0 a2c 9a7 9e4
0 a2c 621 0
a9f 5f :3 0 3d
:3 0 37 :2 0 624
a2d a30 75 :2 0
e9 :2 0 629 a32
a34 :3 0 87 :3 0
88 :3 0 a36 a37
0 68 :3 0 ea
:3 0 a39 a3a 0
a38 a3b 0 a3e
71 :3 0 62c a5c
5f :3 0 3d :3 0
37 :2 0 62e a3f
a42 a3 :2 0 37
:2 0 633 a44 a46
:3 0 5f :3 0 3d
:3 0 37 :2 0 636
a48 a4b a3 :2 0
ab :2 0 63b a4d
a4f :3 0 a47 a51
a50 :2 0 87 :3 0
88 :3 0 a53 a54
0 68 :3 0 a6
:3 0 a56 a57 0
a55 a58 0 a5a
63e a5b a52 a5a
0 a5d a35 a3e
0 a5d 640 0
a9f 87 :3 0 88
:3 0 a5e a5f 0
75 :2 0 ab :2 0
645 a61 a63 :3 0
87 :3 0 88 :3 0
a65 a66 0 37
:2 0 a67 a68 0
a6a 648 a6b a64
a6a 0 a6c 64a
0 a9f 52 :3 0
53 :3 0 a6d a6e
0 52 :3 0 63
:3 0 a70 a71 0
31 :2 0 2 :4 0
eb :2 0 65 :2 0
31 :2 0 64c a76
a78 :3 0 64f a72
a7a a6f a7c a7b
:2 0 55 :3 0 66
:3 0 a7e a7f 0
57 :4 0 ec :4 0
5a :2 0 5b :3 0
653 a83 a85 :3 0
5a :2 0 8e :4 0
656 a87 a89 :3 0
5a :2 0 ed :4 0
659 a8b a8d :3 0
5a :2 0 87 :3 0
88 :3 0 a90 a91
0 65c a8f a93
:3 0 65f a80 a95
:2 0 a97 662 a98
a7d a97 0 a99
664 0 a9f 18
:3 0 87 :3 0 88
:3 0 a9b a9c 0
a9d :2 0 a9f 666
aa2 :3 0 aa2 67b
aa2 aa1 a9f aa0
:6 0 aa3 :2 0 2
58 aa2 aa6 :3 0
aa5 aa3 aa7 :8 0

6ae
4
:3 0 1 3 1
9 1 f 1
15 1 19 1
1f 1 25 1
29 1 2d 1
31 1 35 1
39 1 3d 1
41 1 45 1
49 1 4f 11
8 e 14 18
1e 24 28 2c
30 34 38 3c
40 44 48 4e
54 1 5a 1
60 1 66 1
6c 1 72 1
78 1 7e 1
84 1 8a 1
90 1 98 1
96 1 9f 1
9d 1 a6 1
a4 1 ad 1
ab 1 b2 1
b7 1 be 1
bc 1 c5 1
c3 1 cc 1
ca 1 d3 1
d1 1 da 1
d8 1 e1 1
df 1 e8 1
e6 1 ef 1
ed 1 f4 1
fa 1 100 1
106 1 10c 1
112 1 118 1
11e 1 124 1
12a 1 132 1
130 1 139 1
137 1 13e 1
143 1 148 1
14e 1 154 1
15a 1 160 1
166 1 16c 1
172 1 178 1
17e 1 184 1
18a 1 196 1
1a2 2 1a5 1a7
2 1aa 1ac 2
1ae 1b0 2 1b2
1b4 2 1b6 1b8
2 1ba 1bc 2
1be 1c0 2 1c2
1c4 2 1c6 1c8
2 1ca 1cc 2
1ce 1d0 2 1d2
1d4 2 1d6 1d8
1 1de 2 1e0
1e1 2 1da 1e3
2 1e5 1e7 2
1e9 1eb 2 1ed
1ef 2 1f1 1f3
2 1f5 1f7 2
1f9 1fb 2 1fd
1ff 2 201 203
2 205 207 1
20d 2 20f 210
2 209 212 2
214 216 1 21c
2 21e 21f 2
218 221 2 223
225 1 22b 2
22d 22e 2 227
230 2 232 234
1 23a 2 23c
23d 2 236 23f
2 241 243 1
249 2 24b 24c
2 245 24e 2
250 252 1 258
2 25a 25b 2
254 25d 2 25f
261 1 267 2
269 26a 2 263
26c 2 26e 270
1 276 2 278
279 2 272 27b
2 27d 27f 1
285 2 287 288
2 281 28a 2
28c 28e 2 290
292 2 294 296
2 298 29a 2
29c 29e 2 2a0
2a2 2 2a4 2a6
2 2a8 2aa 2
2ac 2ae 4 19e
1a4 1a9 2b0 1
2b2 1 2b4 2
2be 2c0 3 2bc
2bd 2c2 2 2cb
2cd 2 2ca 2cf
1 2d1 1 2d3
2 2d6 2d7 1
2dd 2 2d9 2dd
2 2e6 2e7 2
2e9 2ec 2 2ef
2f0 2 2f7 2f8
2 2fa 2fd 4
2f3 300 303 306
2 30a 30b 1
311 2 30d 311
2 317 318 2
31a 31d 2 325
326 2 328 32b
3 321 32f 332
2 337 338 3
33b 33e 341 3
343 334 344 2
35f 360 1 364
2 362 364 2
389 38e 2 39f
3a1 3 39d 39e
3a3 2 3ac 3ae
2 3b0 3b2 2
3b4 3b6 2 3b8
3ba 2 3bc 3be
3 3c3 3c4 3c5
2 3c0 3c7 2
3ab 3c9 1 3cb
1 3cd 2 396
3ce 1 3d2 1
391 1 3d6 1
3e1 2 3dd 3e1
2 3ed 3ef 3
3eb 3ec 3f1 2
3fa 3fc 2 3f9
3fe 1 400 1
402 2 403 408
1 40a 3 369
3d9 40b 2 41e
423 2 434 436
3 432 433 438
2 441 443 2
445 447 2 449
44b 2 44d 44f
2 451 453 3
458 459 45a 2
455 45c 2 440
45e 1 460 1
462 2 42b 463
1 467 1 426
1 46b 1 476
2 472 476 2
482 484 3 480
481 486 2 48f
491 2 48e 493
1 495 1 497
2 498 49d 2
4a2 4a3 1 4a5
1 4a9 2 4a7
4a9 2 4b4 4b6
3 4b2 4b3 4b8
2 4c1 4c3 2
4c0 4c5 1 4c7
1 4c9 2 4ca
4cf 2 4d2 4d1
1 4dc 2 4db
4dc 1 4e4 1
4ea 2 4ec 4ed
2 4d9 4ee 2
4ff 501 3 4fd
4fe 503 2 50c
50e 2 510 512
2 514 516 2
518 51a 2 51c
51e 3 523 524
525 2 520 527
2 50b 529 1
52b 1 52d 2
4f6 52e 1 532
1 4f1 1 536
2 53d 53e 1
540 1 545 2
543 545 1 547
2 550 555 2
566 568 3 564
565 56a 2 573
575 2 577 579
2 57b 57d 2
57f 581 2 583
585 3 58a 58b
58c 2 587 58e
2 572 590 1
592 1 594 2
55d 595 1 599
1 558 1 59d
1 5a8 2 5a4
5a8 2 5b4 5b6
3 5b2 5b3 5b8
2 5c1 5c3 2
5c0 5c5 1 5c7
1 5c9 2 5ca
5cf 1 5d1 2
5a0 5d2 1 5d4
1 5d8 5 46e
4d3 539 5d5 5db
2 5dd 5de 2
5ed 5f2 2 603
605 3 601 602
607 2 610 612
2 614 616 2
618 61a 2 61c
61e 2 620 622
3 627 628 629
2 624 62b 2
60f 62d 1 62f
1 631 2 5fa
632 1 636 1
5f5 1 63a 2
640 641 1 645
2 643 645 2
649 64a 1 64e
2 64c 64e 2
653 654 1 658
2 656 658 2
660 661 2 666
667 2 663 669
1 66c 1 66e
2 671 672 1
676 2 674 676
1 679 2 67f
680 1 684 2
682 684 2 689
68a 2 68f 690
2 68c 692 1
695 1 697 1
698 2 6a7 6ac
2 6bd 6bf 3
6bb 6bc 6c1 2
6ca 6cc 2 6ce
6d0 2 6d2 6d4
2 6d6 6d8 2
6da 6dc 3 6e1
6e2 6e3 2 6de
6e5 2 6c9 6e7
1 6e9 1 6eb
2 6b4 6ec 1
6f0 1 6af 1
6f4 1 6f7 2
6fa 6fb 1 6fc
2 6ff 700 1
704 2 702 704
2 709 70a 2
70c 70e 1 711
2 715 716 1
71a 2 718 71a
2 71f 720 2
725 726 2 722
728 1 72b 2
730 731 1 735
2 733 735 2
73a 73b 2 740
741 2 73d 743
1 746 3 749
72e 748 1 74a
2 74c 74d 2
750 751 1 755
2 753 755 2
760 762 3 75e
75f 764 2 76d
76f 2 76c 771
1 773 1 775
2 776 77b 1
77d 3 66f 74e
77e 1 780 2
783 784 1 788
2 786 788 2
78e 78f 2 791
794 1 798 3
79c 79d 79e 1
7a2 2 7a0 7a2
2 7a7 7a8 1
7ac 2 7aa 7ac
2 7c4 7c9 2
7da 7dc 3 7d8
7d9 7de 2 7e7
7e9 2 7eb 7ed
2 7ef 7f1 2
7f3 7f5 2 7f7
7f9 3 7fe 7ff
800 2 7fb 802
2 7e6 804 1
806 1 808 2
7d1 809 1 80d
1 7cc 1 811
1 81c 2 818
81c 1 820 2
82a 82b 2 82d
830 3 838 839
83a 1 83e 2
83c 83e 3 845
846 847 1 84b
2 849 84b 3
852 853 854 1
858 2 856 858
2 85c 85d 1
861 2 85f 861
1 866 1 868
2 869 86c 1
86e 1 86f 2
872 873 1 877
2 875 877 2
87f 880 2 882
885 1 889 1
88b 2 88e 88f
2 894 895 1
897 2 891 897
2 89b 89c 1
8a0 2 89e 8a0
3 8a6 8a7 8a8
1 8ac 2 8aa
8ac 3 8b2 8b3
8b4 1 8b8 2
8b6 8b8 1 8bd
1 8bf 2 8ea
8eb 20 8cd 8ce
8cf 8d0 8d1 8d2
8d3 8d4 8d5 8d6
8d7 8d8 8d9 8da
8db 8dc 8dd 8de
8df 8e0 8e1 8e2
8e3 8e4 8e5 8e6
8e7 8e8 8ed 8ee
8ef 8f0 4 8c0
8c5 8ca 8f3 1
8f5 1 8ff 2
8fe 8ff 1 907
1 90d 2 90f
910 2 8fc 911
2 922 924 3
920 921 926 2
92f 931 2 933
935 2 937 939
2 93b 93d 2
93f 941 3 946
947 948 2 943
94a 2 92e 94c
1 94e 1 950
2 919 951 1
955 1 914 1
959 2 966 968
3 964 965 96a
2 973 975 2
972 977 1 979
1 97b 4 8f6
95c 97c 97f 1
981 2 88c 982
2 984 985 2
834 986 1 988
2 814 989 2
98c 98b 2 98f
990 1 994 2
992 994 2 999
99a 2 99f 9a0
1 9a2 2 99c
9a2 2 9a9 9aa
1 9ae 2 9ac
9ae 2 9b6 9b7
2 9bb 9bc 2
9b9 9be 1 9c2
1 9c4 18 9c8
9c9 9ca 9cb 9cc
9cd 9ce 9cf 9d0
9d1 9d2 9d3 9d4
9d5 9d6 9d7 9d8
9d9 9da 9db 9dc
9dd 9de 9df 2
9c5 9e2 2 9e6
9e7 1 9eb 2
9e9 9eb 2 9ef
9f0 1 9f4 2
9f2 9f4 2 9fc
9fd 2 a01 a02
2 9ff a04 1
a08 1 a0a 18
a0e a0f a10 a11
a12 a13 a14 a15
a16 a17 a18 a19
a1a a1b a1c a1d
a1e a1f a20 a21
a22 a23 a24 a25
2 a0b a28 2
a2b a2a 2 a2e
a2f 1 a33 2
a31 a33 1 a3c
2 a40 a41 1
a45 2 a43 a45
2 a49 a4a 1
a4e 2 a4c a4e
1 a59 2 a5c
a5b 1 a62 2
a60 a62 1 a69
1 a6b 2 a75
a77 3 a73 a74
a79 2 a82 a84
2 a86 a88 2
a8a a8c 2 a8e
a92 2 a81 a94
1 a96 1 a98
14 2b5 2d4 345
348 34b 34e 351
354 357 35a 35d
5df 63d 781 98d
a2c a5d a6c a99
a9e 32 5e 64
6a 70 76 7c
82 88 8e 94
9b a2 a9 b0
b5 ba c1 c8
cf d6 dd e4
eb f2 f8 fe
104 10a 110 116
11c 122 128 12e
135 13c 141 146
14c 152 158 15e
164 16a 170 176
17c 182 188 18e

1
4
0 
aa6
0
1
14
11
44
0 1 2 1 4 1 6 1
8 1 a 1 c 1 e 1
10 0 0 0 
ca 1 0
2 0 1
12a 1 0
41 1 0
39 1 0
f4 1 0
106 1 0
15 1 0
112 1 0
1f 1 0
bc 1 0
29 1 0
160 1 0
130 1 0
25 1 0
d8 1 0
14e 1 0
3 1 0
17e 1 0
b2 1 0
118 1 0
16c 1 0
10c 1 0
b7 1 0
72 1 0
f 1 0
a4 1 0
60 1 0
3d 1 0
8a 1 0
19 1 0
9 1 0
90 1 0
154 1 0
11e 1 0
d1 1 0
7e 1 0
2d 1 0
184 1 0
172 1 0
143 1 0
ab 1 0
15a 1 0
100 1 0
96 1 0
45 1 0
124 1 0
18a 1 0
6c 1 0
66 1 0
178 1 0
df 1 0
78 1 0
fa 1 0
c3 1 0
9d 1 0
35 1 0
5a 1 0
148 1 0
13e 1 0
31 1 0
e6 1 0
166 1 0
4f 1 0
49 1 0
84 1 0
137 1 0
ed 1 0
0

/
SHOW ERRORS FUNCTION FC_U_TSKRES2;
ALTER FUNCTION FC_U_TSKRES2 COMPILE DEBUG;
/*
#Stored Procedure  :SP_U_TSKRES2
#Short Description :Update resource/profile assignment
#Description       :Gets call from FC_SEARCH_2
#Table Name        :
#Parameters        :
 $$if bitflag  = 0 then insert new assignment (assign_id = RES_ASSIGNMENT_ID)
               = 1 then update an existing assignment (assign_id = TSK_ASSIGNMENT_ID)
               = 2 then insert new assignment using project assignment (assign_id = RES_ASSIGNMENT_ID)
               = 3 then reject a profile replacement, uncommit everything
               = 9 MSP
#Returns           :
#Errors            :
*/
Prompt == FUNCTION SP_U_TSKRES2 ==
CREATE OR REPLACE FUNCTION SP_U_TSKRES2 wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
71
2 :e:
1FUNCTION:
1SP_U_TSKRES2:
1ASSIGN_ID:
1VARCHAR2:
1AND_ROLES:
1AND_SKILLS:
1WORK_LOCATION001:
1PLS_INTEGER:
1START_DATE001:
1FINISH_DATE001:
1EFFORT001:
1WORK001:
1EUNIT:
1UNIT:
1WORK_TYPE:
1BITFLAG001:
1CONTOUR001:
1CONTOUR_TYPE001:
1OCCURRENCE:
1ASSIGN_STRING001:
1REC_USER001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_ASSIGN_ID:
132:
1H_AND_ROLES:
18000:
1H_AND_SKILLS:
1H_WORK_LOCATION:
10:
1H_START_DATE:
126:
1H_FINISH_DATE:
1H_EFFORT:
1H_WORK:
1H_EUNIT:
1H_UNIT:
1H_WORK_TYPE:
1H_BITFLAG:
1H_CONTOUR:
1H_CONTOUR_TYPE:
1H_OCCURRENCE:
1H_ASSIGN_STRING:
18192:
1H_REC_USER:
1H_TEMP_SC_STATE:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_U_TSKRES2(:
1':
1, :
1COALESCE:
1TO_CHAR:
1NULL:
1);:
1CHECK_TRACE:
11:
164:
1+:
1FPUT:
1               ENTER:: SP_U_TSKRES2(65) :: cplan.sql(7189) :: :
1IS NULL:
18:
172:
1      RETURN_INVALID:: SP_U_TSKRES2(73) :: cplan.sql(7197) :: :
1 :
1STATE:: :
1PMO_CNST:
1INVALID_PARAMS:
175:
1                EXIT:: SP_U_TSKRES2(76) :: cplan.sql(7200) :: :
1PMODEFINES:
1PMO_RETURN_INVALID_SP:
1TRUE:
1SC_STATE:
1FC_U_TSKRES2:
14:
1105:
1       RETURN_STATUS:: SP_U_TSKRES2(106) :: cplan.sql(7230) :: :
1 ID:: :
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
116:
1113:
1           EXCEPTION:: SP_U_TSKRES2(114) :: cplan.sql(7238) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1ID:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
1OTHERS:
1SQLCODE:
1125:
1           EXCEPTION:: SP_U_TSKRES2(126) :: cplan.sql(7250) :: :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
3ca
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 1c 51 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 1c 51 81 b0 a3
:2 a0 6b 1c 81 b0 :2 a0 6b :2 a0
6b 6e a5 b a 10 :2 a0 6b
6e :2 a0 6b 6e a5 b 6e 7e
a0 b4 2e 6e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :3 a0 a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :3 a0 a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e :3 a0
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e :3 a0 a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e :3 a0 a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e :3 a0 a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
:3 a0 a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e :3 a0 a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e :3 a0 a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c a0 7e
b4 2e :2 5a a0 7e b4 2e :2 5a
52 10 a0 7e b4 2e :2 5a 52
10 a0 7e b4 2e :2 5a 52 10
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b a0 a5 57 b7
19 3c :2 a0 d :2 a0 d :2 a0 d
:2 a0 d :2 a0 d :2 a0 d :2 a0 d
:2 a0 d :2 a0 d :2 a0 d :2 a0 d
:2 a0 d :2 a0 d :2 a0 d :2 a0 d
:2 a0 d :2 a0 d :2 a0 6b :12 a0 a5
b d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b :2 a0 a5 57 b7 :2 a0
6b :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 :2 a0 6b :2 6e 7e :2 a0 6b b4
2e 7e 6e b4 2e 7e :2 a0 6b
b4 2e a5 57 b7 19 3c :9 a0
12a e9 dd :2 a0 65 b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c :7 a0 12a e9
dd :2 a0 65 b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 68 4f
1d 17 b5 
3ca
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 5e
5a 30 66 6f 6b 59 77 84
80 56 8c 95 91 7f 9d aa
a6 7c b2 bb b7 a5 c3 d0
cc a2 d8 e1 dd cb e9 f6
f2 c8 fe 107 103 f1 10f 11c
118 ee 124 12d 129 117 135 142
13e 114 14a 153 14f 13d 15b 13a
160 164 168 16c 16f 173 190 17b
17f 182 183 18b 17a 1ad 19b 177
19f 1a0 1a8 19a 1ca 1b8 197 1bc
1bd 1c5 1b7 1e6 1d5 1d9 1b4 1e1
1d4 203 1f1 1d1 1f5 1f6 1fe 1f0
220 20e 1ed 212 213 21b 20d 23c
22b 22f 20a 237 22a 258 247 24b
227 253 246 274 263 267 243 26f
262 290 27f 283 25f 28b 27e 2ac
29b 29f 27b 2a7 29a 2c8 2b7 2bb
297 2c3 2b6 2e4 2d3 2d7 2b3 2df
2d2 300 2ef 2f3 2cf 2fb 2ee 31c
30b 30f 2eb 317 30a 339 327 307
32b 32c 334 326 356 344 323 348
349 351 343 372 361 365 340 36d
360 392 37d 381 35d 385 38d 37c
399 39d 379 3a1 3a5 3a9 3ac 3b1
3b2 1 3b4 3b9 3bd 3c1 3c4 3c9
3cd 3d1 3d4 3d9 3da 3dc 3e1 3e4
3e8 3e9 3ee 3f3 3f6 3fb 3fc 401
404 408 409 40e 411 416 417 41c
41f 424 425 42a 42d 432 433 438
43b 43f 440 445 448 44d 44e 453
456 45b 45c 461 464 469 46a 46f
472 476 477 47c 47f 484 485 48a
48d 492 493 498 49b 49f 4a3 4a7
4a8 4aa 4af 4b0 4b2 4b3 4b8 4bb
4c0 4c1 4c6 4c9 4ce 4cf 4d4 4d7
4db 4dc 4e1 4e4 4e9 4ea 4ef 4f2
4f7 4f8 4fd 500 505 506 50b 50e
512 513 518 51b 520 521 526 529
52e 52f 534 537 53b 53f 543 544
546 54b 54c 54e 54f 554 557 55c
55d 562 565 569 56d 571 572 574
579 57a 57c 57d 582 585 58a 58b
590 593 597 59b 59f 5a0 5a2 5a7
5a8 5aa 5ab 5b0 5b3 5b8 5b9 5be
5c1 5c5 5c9 5cd 5ce 5d0 5d5 5d6
5d8 5d9 5de 5e1 5e6 5e7 5ec 5ef
5f3 5f7 5fb 5fc 5fe 603 604 606
607 60c 60f 614 615 61a 61d 621
625 629 62a 62c 631 632 634 635
63a 63d 642 643 648 64b 64f 653
657 658 65a 65f 660 662 663 668
66b 670 671 676 679 67d 681 685
686 688 68d 68e 690 691 696 699
69e 69f 6a4 6a7 6ab 6af 6b3 6b4
6b6 6bb 6bc 6be 6bf 6c4 6c7 6cc
6cd 6d2 6d5 6da 6db 6e0 6e3 6e7
6e8 6ed 6f0 6f5 6f6 6fb 6fe 703
704 709 70c 711 712 717 71a 71e
71f 724 727 72c 72d 732 735 73a
73b 740 741 746 748 74c 74f 753
757 75a 75e 762 765 768 76d 770
773 776 777 77c 77d 1 77f 784
788 78c 78f 794 799 79c 7a0 7a1
7a6 7a7 7ac 7ae 7b2 7b5 7b9 7bc
7bd 7c2 7c5 7c8 7cc 7cf 7d0 7d5
7d8 1 7db 7e0 7e4 7e7 7e8 7ed
7f0 1 7f3 7f8 7fc 7ff 800 805
808 1 80b 810 814 818 81b 81f
823 826 829 82e 831 834 837 838
83d 83e 1 840 845 849 84d 850
855 85a 85d 861 862 867 86a 86f
870 875 878 87d 87e 883 886 88a
88e 892 896 899 89a 89c 8a1 8a2
8a4 8a5 8aa 8ab 8b0 8b2 8b6 8b9
8bd 8c1 8c4 8c8 8cc 8cf 8d2 8d7
8da 8dd 8e0 8e1 8e6 8e7 1 8e9
8ee 8f2 8f6 8f9 8fe 903 906 90a
90b 910 911 916 918 91c 91f 923
927 92a 92e 932 935 939 93a 93f
941 945 948 94c 950 954 958 95c
960 964 968 96c 970 974 978 97c
980 984 988 98c 990 994 998 99c
9a0 9a4 9a8 9ac 9b0 9b4 9b8 9bc
9c0 9c4 9c8 9cc 9d0 9d4 9d8 9dc
9e0 9e4 9e8 9ec 9f0 9f4 9f8 9fc
a00 a04 a08 a0c a10 a14 a18 a1c
a1f a23 a27 a2b a2f a33 a37 a3b
a3f a43 a47 a4b a4f a53 a57 a5b
a5f a63 a67 a68 a6a a6e a72 a76
a79 a7d a81 a84 a87 a8c a8f a92
a95 a96 a9b a9c 1 a9e aa3 aa7
aab aae ab3 ab8 abb abf ac0 ac5
ac8 acd ace ad3 ad6 adb adc ae1
ae4 ae8 aec af0 af4 af7 af8 afa
aff b00 b02 b03 b08 b0b b10 b11
b16 b19 b1e b1f b24 b27 b2b b2c
b31 b34 b39 b3a b3f b40 b45 b47
b4b b4e b52 b56 b59 b5d b61 b64
b68 b6c b6d b72 b74 b78 b7c b7f
b83 b87 b8a b8e b92 b95 b98 b9d
ba0 ba3 ba6 ba7 bac bad 1 baf
bb4 bb8 bbc bbf bc4 bc9 bcc bd0
bd1 bd6 bd7 bdc be0 be4 be7 bec
bf1 bf4 bf8 bfc bff c00 c05 c08
c0d c0e c13 c16 c1a c1e c21 c22
c27 c28 c2d c2f c33 c36 c3a c3e
c42 c46 c4a c4e c52 c56 c5a c66
c6b c6f c73 c77 c7b c7d c7e c83
1 c87 c8b c8f c92 c96 c9a c9e
ca2 ca5 ca9 cad cb0 cb3 cb8 cbb
cbe cc1 cc2 cc7 cc8 1 cca ccf
cd3 cd7 cda cdf ce4 ce7 ceb cec
cf1 cf2 cf7 cfb cff d02 d07 d0c
d0f d13 d14 d19 d1c d21 d22 d27
d2a d2e d32 d35 d38 d39 d3b d3c
d41 d42 d47 d49 d4d d50 d54 d58
d5c d60 d64 d68 d6c d78 d7d d81
d85 d89 d8d d8f d93 d95 da1 da3
da5 da6 dab daf db1 dbd dc1 dc3
dc4 dcd 
3ca
2
0 1 a 6 10 :3 6 10 :3 6
11 :3 6 17 :3 6 14 :3 6 15 :3 6
10 :3 6 e :3 6 c :3 6 b :3 6
10 :3 6 11 :3 6 11 :3 6 16 :3 6
11 :3 6 17 :3 6 12 :2 6 1 3
a 13 a :2 1 4 10 19 18
:2 10 :2 4 10 19 18 :2 10 :2 4 11
1a 19 :2 11 :2 4 :2 14 23 14 :2 4
11 1a 19 :2 11 :2 4 12 1b 1a
:2 12 :2 4 :2 d 1c d :2 4 :2 b 1a
b :2 4 :2 c 1b c :2 4 :2 b 1a
b :2 4 :2 10 1f 10 :2 4 :2 e 1d
e :2 4 :2 e 1d e :2 4 :2 13 22
13 :2 4 :2 11 20 11 :2 4 14 1d
1c :2 14 :2 4 f 18 17 :2 f :2 4
:2 14 23 14 :2 4 e 17 :3 e 4
7 :2 11 23 :2 2d 3a :2 23 :3 7 :2 d
19 25 :2 2f 43 :2 25 54 5a 5d
:2 54 6b 81 8 :2 6b d 10 :2 6b
1a 1d :2 6b b e :2 6b 13 16
:2 6b 1b 1e :2 6b 28 2b :2 6b b
e :2 6b 13 16 :2 6b 1b 1e :2 6b
29 2c :2 6b b e :2 6b 13 16
1f 27 :2 1f 3a :2 16 :2 6b b e
:2 6b 13 16 :2 6b 1b 1e :2 6b 2c
2f :2 6b b e :2 6b 13 16 :2 6b
1b 1e :2 6b 2d 30 :2 6b b e
:2 6b 13 16 1f 27 :2 1f 33 :2 16
:2 6b b e :2 6b 13 16 1f 27
:2 1f 31 :2 16 :2 6b b e :2 6b 13
16 1f 27 :2 1f 2f :2 16 :2 6b b
e :2 6b 13 16 1f 27 :2 1f 2e
:2 16 :2 6b b e :2 6b 13 16 1f
27 :2 1f 33 :2 16 :2 6b b e :2 6b
13 16 1f 27 :2 1f 34 :2 16 :2 6b
b e :2 6b 13 16 1f 27 :2 1f
34 :2 16 :2 6b b e :2 6b 13 16
1f 27 :2 1f 39 :2 16 :2 6b b e
:2 6b 13 16 1f 27 :2 1f 34 :2 16
:2 6b b e :2 6b 13 16 :2 6b 1b
1e :2 6b 2f 32 :2 6b b e :2 6b
13 16 :2 6b 1b 1e :2 6b 2a 2d
:2 6b 32 35 :2 6b :2 7 4a :2 4 7
:2 11 23 :2 2d 39 3c 4c 4e 4f
:2 4c :2 23 :3 7 :2 d 12 1e 5c 5f
:2 1e :2 7 52 :2 4 :4 9 8 7 :4 22
21 20 :2 7 :4 3f 3e 3d :2 7 :4 f
e d :2 7 a :2 14 26 :2 30 3c
3f 4f 51 52 :2 4f :2 26 :3 a :2 10
15 21 5f 62 :2 21 6f 72 :2 21
76 79 :2 21 83 86 8f 97 :2 a0
:2 8f b1 :2 86 :2 21 :2 a 55 :2 7 a
:2 14 26 :2 30 3c 3f 4f 51 52
:2 4f :2 26 :3 a :2 10 15 21 5f 62
:2 21 :2 a 55 :3 7 :2 12 28 :2 31 41
:2 7 2a :3 4 13 :2 4 13 :2 4 14
:2 4 14 :2 4 15 :2 4 17 :2 4 12
:2 4 17 :2 4 10 :2 4 e :2 4 f
:2 4 e :2 4 13 :2 4 11 :2 4 11
:2 4 16 :2 4 14 :2 4 :2 d 19 26
33 40 4e 25 33 42 4c 54
5d 25 32 3d 48 58 25 36
:2 19 4 7 :2 11 23 :2 2d 39 3c
4c 4f 50 :2 4c :2 23 :3 7 :2 d 12
1e 5d 60 :2 1e 6d 70 :2 1e 74
77 :2 1e 81 84 8d 95 :2 9e :2 8d
a9 :2 84 :2 1e b1 b4 :2 1e bc bf
:2 1e c4 c7 :2 1e d3 d6 :2 1e :2 7
53 :3 4 :2 f 21 :2 2a 34 41 :2 4
1 9 12 9 a :2 14 26 :2 30
3c 40 50 53 54 :2 50 :2 26 :3 a
:2 10 15 21 60 63 :2 21 :3 a :2 10
15 39 5c 5f :2 68 :2 39 76 79
:2 39 81 84 :2 8d :2 39 :2 a 57 :3 7
c 15 1e 2c a 13 1e f
e 7 e 7 e 7 29 :2 4
:2 9 7 :2 10 1c :2 7 :2 11 23 :2 2d
39 3d 4d 50 51 :2 4d :2 23 :3 7
:2 d 12 1e 5d 60 :2 1e :3 7 :2 d
12 36 42 45 :2 36 4d 50 :2 36
5c 5f 66 6f 72 :2 5f :2 36 :2 7
54 :2 4 7 c 1b a 13 1e
f e 7 e 7 e 7 :2 4
:4 10 :2 4 :8 1 
3ca
4
0 :2 1 :4 3 :4 4
:4 5 :4 6 :4 7 :4 8
:4 9 :4 a :4 b :4 c
:4 d :4 e :4 f :4 10
:4 11 :4 12 :4 13 2
:4 14 :2 1 :7 16 :7 17
:7 18 :6 19 :7 1a :7 1b
:6 1c :6 1d :6 1e :6 1f
:6 20 :6 21 :6 22 :6 23
:6 24 :7 25 :7 26 :6 27
:7 29 :b 2b :11 2c 2d
:2 2c :2 2d :2 2c :2 2d
:2 2c :2 2e :2 2c :2 2e
:2 2c :2 2e :2 2c :2 2e
:2 2c :2 2f :2 2c :2 2f
:2 2c :2 2f :2 2c :2 2f
:2 2c :2 30 :2 2c :9 30
:2 2c :2 31 :2 2c :2 31
:2 2c :2 31 :2 2c :2 31
:2 2c :2 32 :2 2c :2 32
:2 2c :2 32 :2 2c :2 32
:2 2c :2 33 :2 2c :9 33
:2 2c :2 34 :2 2c :9 34
:2 2c :2 35 :2 2c :9 35
:2 2c :2 36 :2 2c :9 36
:2 2c :2 37 :2 2c :9 37
:2 2c :2 38 :2 2c :9 38
:2 2c :2 39 :2 2c :9 39
:2 2c :2 3a :2 2c :9 3a
:2 2c :2 3b :2 2c :9 3b
:2 2c :2 3c :2 2c :2 3c
:2 2c :2 3c :2 2c :2 3c
:2 2c :2 3d :2 2c :2 3d
:2 2c :2 3d :2 2c :2 3d
:2 2c :2 3d :4 2c :3 2b
:11 40 :b 41 :3 40 :16 46
:6 47 :2 46 :11 48 :20 49
:3 48 :11 4b :b 4c :3 4b
:9 4e 47 :2 46 :3 51
:3 52 :3 53 :3 54 :3 55
:3 56 :3 57 :3 59 :3 5a
:3 5b :3 5c :3 5d :3 5e
:3 5f :3 60 :3 61 :3 62
:8 64 :6 65 :5 66 :2 67
:3 64 :11 69 :30 6a :3 69
:a 6c 2a :3 70 :11 71
:b 72 :17 73 :3 71 :2 75
:3 76 :3 77 78 76
75 76 :3 79 :3 70
:2 7a :5 7c :11 7d :b 7e
:18 7f :3 7d :2 81 82
:3 83 84 82 81
82 :3 85 :2 7b :6 7a
6f :7 1 
dcf
4
:3 0 1 :3 0 2
:a 0 3c5 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
56 0 7 4
:3 0 5 :7 0 9
8 :3 0 4 :3 0
6 :7 0 d c
:3 0 d 7c 0
b 8 :3 0 7
:7 0 11 10 :3 0
4 :3 0 9 :7 0
15 14 :3 0 11
a2 0 f 4
:3 0 a :7 0 19
18 :3 0 8 :3 0
b :7 0 1d 1c
:3 0 15 c8 0
13 8 :3 0 c
:7 0 21 20 :3 0
8 :3 0 d :7 0
25 24 :3 0 19
ee 0 17 8
:3 0 e :7 0 29
28 :3 0 8 :3 0
f :7 0 2d 2c
:3 0 1d 114 0
1b 8 :3 0 10
:7 0 31 30 :3 0
8 :3 0 11 :7 0
35 34 :3 0 21
13a 0 1f 8
:3 0 12 :7 0 39
38 :3 0 8 :3 0
13 :7 0 3d 3c
:3 0 25 :2 0 23
4 :3 0 14 :7 0
41 40 :3 0 4
:3 0 15 :7 0 45
44 :3 0 16 :3 0
17 :3 0 18 :2 0
4 49 4a 0
47 4b 0 3c5
2 4c :2 0 1c
:2 0 39 4 :3 0
1a :2 0 37 4f
51 :6 0 54 52
0 3c3 0 19
:6 0 1c :2 0 3d
4 :3 0 3b 56
58 :6 0 5b 59
0 3c3 0 1b
:6 0 1f :2 0 41
4 :3 0 3f 5d
5f :6 0 62 60
0 3c3 0 1d
:6 0 21 :2 0 43
8 :3 0 64 :7 0
68 65 66 3c3
0 1e :6 0 21
:2 0 47 4 :3 0
45 6a 6c :6 0
6f 6d 0 3c3
0 20 :6 0 1f
:2 0 4b 4 :3 0
49 71 73 :6 0
76 74 0 3c3
0 22 :6 0 1f
:2 0 4d 8 :3 0
78 :7 0 7c 79
7a 3c3 0 23
:6 0 1f :2 0 4f
8 :3 0 7e :7 0
82 7f 80 3c3
0 24 :6 0 1f
:2 0 51 8 :3 0
84 :7 0 88 85
86 3c3 0 25
:6 0 1f :2 0 53
8 :3 0 8a :7 0
8e 8b 8c 3c3
0 26 :6 0 1f
:2 0 55 8 :3 0
90 :7 0 94 91
92 3c3 0 27
:6 0 1f :2 0 57
8 :3 0 96 :7 0
9a 97 98 3c3
0 28 :6 0 1f
:2 0 59 8 :3 0
9c :7 0 a0 9d
9e 3c3 0 29
:6 0 1f :2 0 5b
8 :3 0 a2 :7 0
a6 a3 a4 3c3
0 2a :6 0 2d
:2 0 5d 8 :3 0
a8 :7 0 ac a9
aa 3c3 0 2b
:6 0 1a :2 0 61
4 :3 0 5f ae
b0 :6 0 b3 b1
0 3c3 0 2c
:6 0 1f :2 0 65
4 :3 0 63 b5
b7 :6 0 ba b8
0 3c3 0 2e
:6 0 c2 c3 0
67 8 :3 0 bc
:7 0 c0 bd be
3c3 0 2f :6 0
c8 c9 0 69
17 :3 0 18 :2 0
4 c4 :7 0 c7
c5 0 3c3 0
30 :6 0 31 :3 0
32 :3 0 31 :3 0
33 :3 0 cb cc
0 2 :4 0 6b
cd cf ca d1
d0 :2 0 34 :3 0
35 :3 0 d3 d4
0 36 :4 0 31
:3 0 37 :3 0 d7
d8 0 2 :4 0
6d d9 db 38
:4 0 39 :2 0 3a
:3 0 6f de e0
:3 0 3b :4 0 39
:2 0 3c :4 0 72
e3 e5 :3 0 39
:2 0 3 :3 0 75
e7 e9 :3 0 39
:2 0 3c :4 0 78
eb ed :3 0 39
:2 0 3d :4 0 7b
ef f1 :3 0 39
:2 0 3c :4 0 7e
f3 f5 :3 0 39
:2 0 5 :3 0 81
f7 f9 :3 0 39
:2 0 3c :4 0 84
fb fd :3 0 39
:2 0 3d :4 0 87
ff 101 :3 0 39
:2 0 3c :4 0 8a
103 105 :3 0 39
:2 0 6 :3 0 8d
107 109 :3 0 39
:2 0 3c :4 0 90
10b 10d :3 0 39
:2 0 3d :4 0 93
10f 111 :3 0 39
:2 0 3e :3 0 3f
:3 0 7 :3 0 96
115 117 40 :4 0
98 114 11a 9b
113 11c :3 0 39
:2 0 3d :4 0 9e
11e 120 :3 0 39
:2 0 3c :4 0 a1
122 124 :3 0 39
:2 0 9 :3 0 a4
126 128 :3 0 39
:2 0 3c :4 0 a7
12a 12c :3 0 39
:2 0 3d :4 0 aa
12e 130 :3 0 39
:2 0 3c :4 0 ad
132 134 :3 0 39
:2 0 a :3 0 b0
136 138 :3 0 39
:2 0 3c :4 0 b3
13a 13c :3 0 39
:2 0 3d :4 0 b6
13e 140 :3 0 39
:2 0 3e :3 0 3f
:3 0 b :3 0 b9
144 146 40 :4 0
bb 143 149 be
142 14b :3 0 39
:2 0 3d :4 0 c1
14d 14f :3 0 39
:2 0 3e :3 0 3f
:3 0 c :3 0 c4
153 155 40 :4 0
c6 152 158 c9
151 15a :3 0 39
:2 0 3d :4 0 cc
15c 15e :3 0 39
:2 0 3e :3 0 3f
:3 0 d :3 0 cf
162 164 40 :4 0
d1 161 167 d4
160 169 :3 0 39
:2 0 3d :4 0 d7
16b 16d :3 0 39
:2 0 3e :3 0 3f
:3 0 e :3 0 da
171 173 40 :4 0
dc 170 176 df
16f 178 :3 0 39
:2 0 3d :4 0 e2
17a 17c :3 0 39
:2 0 3e :3 0 3f
:3 0 f :3 0 e5
180 182 40 :4 0
e7 17f 185 ea
17e 187 :3 0 39
:2 0 3d :4 0 ed
189 18b :3 0 39
:2 0 3e :3 0 3f
:3 0 10 :3 0 f0
18f 191 40 :4 0
f2 18e 194 f5
18d 196 :3 0 39
:2 0 3d :4 0 f8
198 19a :3 0 39
:2 0 3e :3 0 3f
:3 0 11 :3 0 fb
19e 1a0 40 :4 0
fd 19d 1a3 100
19c 1a5 :3 0 39
:2 0 3d :4 0 103
1a7 1a9 :3 0 39
:2 0 3e :3 0 3f
:3 0 12 :3 0 106
1ad 1af 40 :4 0
108 1ac 1b2 10b
1ab 1b4 :3 0 39
:2 0 3d :4 0 10e
1b6 1b8 :3 0 39
:2 0 3e :3 0 3f
:3 0 13 :3 0 111
1bc 1be 40 :4 0
113 1bb 1c1 116
1ba 1c3 :3 0 39
:2 0 3d :4 0 119
1c5 1c7 :3 0 39
:2 0 3c :4 0 11c
1c9 1cb :3 0 39
:2 0 14 :3 0 11f
1cd 1cf :3 0 39
:2 0 3c :4 0 122
1d1 1d3 :3 0 39
:2 0 3d :4 0 125
1d5 1d7 :3 0 39
:2 0 3c :4 0 128
1d9 1db :3 0 39
:2 0 15 :3 0 12b
1dd 1df :3 0 39
:2 0 3c :4 0 12e
1e1 1e3 :3 0 39
:2 0 41 :4 0 131
1e5 1e7 :3 0 134
d5 1e9 :2 0 1eb
139 1ec d2 1eb
0 1ed 13b 0
323 31 :3 0 32
:3 0 1ee 1ef 0
31 :3 0 42 :3 0
1f1 1f2 0 43
:2 0 2 :4 0 44
:2 0 45 :2 0 43
:2 0 13d 1f7 1f9
:3 0 140 1f3 1fb
1f0 1fd 1fc :2 0
34 :3 0 46 :3 0
1ff 200 0 36
:4 0 47 :4 0 39
:2 0 3a :3 0 144
204 206 :3 0 147
201 208 :2 0 20a
14a 20b 1fe 20a
0 20c 14c 0
323 3 :3 0 48
:2 0 14e 20e 20f
:3 0 210 :2 0 211
:2 0 9 :3 0 48
:2 0 150 214 215
:3 0 216 :2 0 217
:2 0 212 219 218
:2 0 a :3 0 48
:2 0 152 21c 21d
:3 0 21e :2 0 21f
:2 0 21a 221 220
:2 0 14 :3 0 48
:2 0 154 224 225
:3 0 226 :2 0 227
:2 0 222 229 228
:2 0 31 :3 0 32
:3 0 22b 22c 0
31 :3 0 42 :3 0
22e 22f 0 49
:2 0 2 :4 0 4a
:2 0 45 :2 0 43
:2 0 156 234 236
:3 0 159 230 238
22d 23a 239 :2 0
34 :3 0 46 :3 0
23c 23d 0 36
:4 0 4b :4 0 39
:2 0 3a :3 0 15d
241 243 :3 0 39
:2 0 4c :4 0 160
245 247 :3 0 39
:2 0 4d :4 0 163
249 24b :3 0 39
:2 0 3e :3 0 3f
:3 0 4e :3 0 4f
:3 0 250 251 0
166 24f 253 40
:4 0 168 24e 256
16b 24d 258 :3 0
16e 23e 25a :2 0
25c 171 25d 23b
25c 0 25e 173
0 287 31 :3 0
32 :3 0 25f 260
0 31 :3 0 42
:3 0 262 263 0
43 :2 0 2 :4 0
50 :2 0 45 :2 0
43 :2 0 175 268
26a :3 0 178 264
26c 261 26e 26d
:2 0 34 :3 0 46
:3 0 270 271 0
36 :4 0 51 :4 0
39 :2 0 3a :3 0
17c 275 277 :3 0
17f 272 279 :2 0
27b 182 27c 26f
27b 0 27d 184
0 287 52 :3 0
53 :3 0 27e 27f
0 4e :3 0 4f
:3 0 281 282 0
54 :3 0 186 280
285 :2 0 287 189
288 22a 287 0
289 18d 0 323
19 :3 0 3 :3 0
28a 28b 0 323
1b :3 0 5 :3 0
28d 28e 0 323
1d :3 0 6 :3 0
290 291 0 323
20 :3 0 9 :3 0
293 294 0 323
22 :3 0 a :3 0
296 297 0 323
2c :3 0 14 :3 0
299 29a 0 323
2e :3 0 15 :3 0
29c 29d 0 323
1e :3 0 7 :3 0
29f 2a0 0 323
23 :3 0 b :3 0
2a2 2a3 0 323
24 :3 0 c :3 0
2a5 2a6 0 323
25 :3 0 d :3 0
2a8 2a9 0 323
26 :3 0 e :3 0
2ab 2ac 0 323
27 :3 0 f :3 0
2ae 2af 0 323
28 :3 0 10 :3 0
2b1 2b2 0 323
29 :3 0 11 :3 0
2b4 2b5 0 323
2a :3 0 12 :3 0
2b7 2b8 0 323
2b :3 0 13 :3 0
2ba 2bb 0 323
17 :3 0 55 :3 0
2bd 2be 0 56
:3 0 19 :3 0 1b
:3 0 1d :3 0 1e
:3 0 20 :3 0 22
:3 0 23 :3 0 24
:3 0 25 :3 0 26
:3 0 27 :3 0 28
:3 0 29 :3 0 2a
:3 0 2b :3 0 2c
:3 0 2e :3 0 18f
2c0 2d2 2bf 2d3
0 323 31 :3 0
32 :3 0 2d5 2d6
0 31 :3 0 42
:3 0 2d8 2d9 0
57 :2 0 2 :4 0
58 :2 0 45 :2 0
43 :2 0 1a1 2de
2e0 :3 0 1a4 2da
2e2 2d7 2e4 2e3
:2 0 34 :3 0 46
:3 0 2e6 2e7 0
36 :4 0 59 :4 0
39 :2 0 3a :3 0
1a8 2eb 2ed :3 0
39 :2 0 4c :4 0
1ab 2ef 2f1 :3 0
39 :2 0 4d :4 0
1ae 2f3 2f5 :3 0
39 :2 0 3e :3 0
3f :3 0 17 :3 0
55 :3 0 2fa 2fb
0 1b1 2f9 2fd
40 :4 0 1b3 2f8
300 1b6 2f7 302
:3 0 39 :2 0 5a
:4 0 1b9 304 306
:3 0 39 :2 0 3c
:4 0 1bc 308 30a
:3 0 39 :2 0 19
:3 0 1bf 30c 30e
:3 0 39 :2 0 3c
:4 0 1c2 310 312
:3 0 1c5 2e8 314
:2 0 316 1c8 317
2e5 316 0 318
1ca 0 323 52
:3 0 5b :3 0 319
31a 0 17 :3 0
55 :3 0 31c 31d
0 19 :3 0 54
:3 0 1cc 31b 321
:2 0 323 1d0 3c4
17 :3 0 5c :2 0
4 324 325 0
31 :3 0 32 :3 0
327 328 0 31
:3 0 42 :3 0 32a
32b 0 5d :2 0
2 :4 0 5e :2 0
45 :2 0 43 :2 0
1e8 330 332 :3 0
1eb 32c 334 329
336 335 :2 0 34
:3 0 46 :3 0 338
339 0 36 :4 0
5f :4 0 39 :2 0
3a :3 0 1ef 33d
33f :3 0 1f2 33a
341 :2 0 35a 34
:3 0 46 :3 0 343
344 0 36 :4 0
60 :4 0 39 :2 0
17 :3 0 61 :3 0
349 34a 0 1f5
348 34c :3 0 39
:2 0 5a :4 0 1f8
34e 350 :3 0 39
:2 0 17 :3 0 62
:3 0 353 354 0
1fb 352 356 :3 0
1fe 345 358 :2 0
35a 201 35b 337
35a 0 35c 204
0 36c 63 :3 0
30 :3 0 17 :3 0
61 :3 0 64 :3 0
17 :3 0 62 :3 0
65 :3 0 66 :4 0
67 1 :a 0 368
:2 0 36c 35e 366
:2 0 16 :3 0 30
:3 0 36a :2 0 36c
206 36e 20a 36d
36c :2 0 3c2 68
:3 0 17 :3 0 55
:3 0 371 372 0
69 :3 0 373 374
0 3ba 31 :3 0
32 :3 0 376 377
0 31 :3 0 42
:3 0 379 37a 0
5d :2 0 2 :4 0
6a :2 0 45 :2 0
43 :2 0 20c 37f
381 :3 0 20f 37b
383 378 385 384
:2 0 34 :3 0 46
:3 0 387 388 0
36 :4 0 6b :4 0
39 :2 0 3a :3 0
213 38c 38e :3 0
216 389 390 :2 0
3aa 34 :3 0 46
:3 0 392 393 0
36 :4 0 6c :4 0
39 :2 0 69 :3 0
219 397 399 :3 0
39 :2 0 6d :4 0
21c 39b 39d :3 0
39 :2 0 6e :3 0
6f :3 0 43 :2 0
70 :2 0 21f 3a0
3a4 223 39f 3a6
:3 0 226 394 3a8
:2 0 3aa 229 3ab
386 3aa 0 3ac
22c 0 3ba 63
:3 0 30 :3 0 64
:3 0 17 :3 0 62
:3 0 65 :3 0 66
:4 0 71 1 :a 0
3b6 :2 0 3ba 3ae
3b4 :2 0 16 :3 0
30 :3 0 3b8 :2 0
3ba 22e 3bd :3 0
3bd 0 3bd 3bc
3ba 3bb :6 0 3bf
1 :3 0 233 3c1
235 3c0 3bf :2 0
3c2 237 :2 0 3c4
23a 3c4 3c3 323
3c2 :6 0 3c5 :2 0
2 4c 3c4 3c8
:3 0 3c7 3c5 3c9
:8 0 
24e
4
:3 0 1 3 1
7 1 b 1
f 1 13 1
17 1 1b 1
1f 1 23 1
27 1 2b 1
2f 1 33 1
37 1 3b 1
3f 1 43 11
6 a e 12
16 1a 1e 22
26 2a 2e 32
36 3a 3e 42
46 1 50 1
4e 1 57 1
55 1 5e 1
5c 1 63 1
6b 1 69 1
72 1 70 1
77 1 7d 1
83 1 89 1
8f 1 95 1
9b 1 a1 1
a7 1 af 1
ad 1 b6 1
b4 1 bb 1
c1 1 ce 1
da 2 dd df
2 e2 e4 2
e6 e8 2 ea
ec 2 ee f0
2 f2 f4 2
f6 f8 2 fa
fc 2 fe 100
2 102 104 2
106 108 2 10a
10c 2 10e 110
1 116 2 118
119 2 112 11b
2 11d 11f 2
121 123 2 125
127 2 129 12b
2 12d 12f 2
131 133 2 135
137 2 139 13b
2 13d 13f 1
145 2 147 148
2 141 14a 2
14c 14e 1 154
2 156 157 2
150 159 2 15b
15d 1 163 2
165 166 2 15f
168 2 16a 16c
1 172 2 174
175 2 16e 177
2 179 17b 1
181 2 183 184
2 17d 186 2
188 18a 1 190
2 192 193 2
18c 195 2 197
199 1 19f 2
1a1 1a2 2 19b
1a4 2 1a6 1a8
1 1ae 2 1b0
1b1 2 1aa 1b3
2 1b5 1b7 1
1bd 2 1bf 1c0
2 1b9 1c2 2
1c4 1c6 2 1c8
1ca 2 1cc 1ce
2 1d0 1d2 2
1d4 1d6 2 1d8
1da 2 1dc 1de
2 1e0 1e2 2
1e4 1e6 4 d6
dc e1 1e8 1
1ea 1 1ec 2
1f6 1f8 3 1f4
1f5 1fa 2 203
205 2 202 207
1 209 1 20b
1 20d 1 213
1 21b 1 223
2 233 235 3
231 232 237 2
240 242 2 244
246 2 248 24a
1 252 2 254
255 2 24c 257
2 23f 259 1
25b 1 25d 2
267 269 3 265
266 26b 2 274
276 2 273 278
1 27a 1 27c
2 283 284 3
25e 27d 286 1
288 11 2c1 2c2
2c3 2c4 2c5 2c6
2c7 2c8 2c9 2ca
2cb 2cc 2cd 2ce
2cf 2d0 2d1 2
2dd 2df 3 2db
2dc 2e1 2 2ea
2ec 2 2ee 2f0
2 2f2 2f4 1
2fc 2 2fe 2ff
2 2f6 301 2
303 305 2 307
309 2 30b 30d
2 30f 311 2
2e9 313 1 315
1 317 3 31e
31f 320 17 1ed
20c 289 28c 28f
292 295 298 29b
29e 2a1 2a4 2a7
2aa 2ad 2b0 2b3
2b6 2b9 2bc 2d4
318 322 2 32f
331 3 32d 32e
333 2 33c 33e
2 33b 340 2
347 34b 2 34d
34f 2 351 355
2 346 357 2
342 359 1 35b
3 35c 367 36b
1 326 2 37e
380 3 37c 37d
382 2 38b 38d
2 38a 38f 2
396 398 2 39a
39c 3 3a1 3a2
3a3 2 39e 3a5
2 395 3a7 2
391 3a9 1 3ab
4 375 3ac 3b5
3b9 1 3bd 1
370 2 36e 3c1
13 53 5a 61
67 6e 75 7b
81 87 8d 93
99 9f a5 ab
b2 b9 bf c6

1
4
0 
3c8
0
1
14
2
25
0 1 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 
43 1 0
2b 1 0
b 1 0
70 1 0
3b 1 0
27 1 0
23 1 0
4e 1 0
f 1 0
bb 1 0
2 0 1
1f 1 0
89 1 0
5c 1 0
77 1 0
a1 1 0
69 1 0
55 1 0
1b 1 0
a7 1 0
95 1 0
3 1 0
33 1 0
13 1 0
83 1 0
7d 1 0
8f 1 0
37 1 0
7 1 0
63 1 0
2f 1 0
b4 1 0
3f 1 0
ad 1 0
9b 1 0
17 1 0
c1 1 0
0

/
SHOW ERRORS FUNCTION SP_U_TSKRES2;
ALTER FUNCTION SP_U_TSKRES2 COMPILE DEBUG;
/*
#Stored Procedure  :SP_ASSIGN_MSP
#Short Description :
#Description       :
#Table Name        :
#Parameters        :
#Returns           :
#Errors            :
*/
Prompt == FUNCTION SP_ASSIGN_MSP ==
CREATE OR REPLACE FUNCTION SP_ASSIGN_MSP wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
19e
2 :e:
1FUNCTION:
1SP_ASSIGN_MSP:
1ID001:
1VARCHAR2:
1ACTION_TYPE:
1PLS_INTEGER:
1TASK_ID001:
1START_DT001:
1FINISH_DT001:
1EFFORT001:
1ASSIGN_STRING001:
1WORK_TODATE001:
1PERCENT_COMPLETE001:
1EETC:
1DATA_FLAG:
1UNITS:
1CONTOUR_TYPE001:
1BASELINE_START001:
1BASELINE_FINISH001:
1BASELINE_DURATION001:
1BASELINE_WORK001:
1ACTUAL_START001:
1ACTUAL_FINISH001:
1ACTUAL_EFFORT001:
1REC_USER001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_ELEMENT_NAME:
1255:
1H_FULL_NAME:
1H_MESSAGE:
18192:
1H_SUBJECT:
12048:
1H_REVISION:
116:
1H_TEMP_ID:
132:
1H_TEMP_ID2:
1H_WKF_DEF_ID:
1H_UNIQUEID:
1H_RA_ID:
1H_RESOURCE_ID:
1H_PROJECT_ID:
1H_TASK_ID:
1H_REC_USER:
1H_TYPE_ID:
10:
1H_WORK_LOCATION:
1H_ZERO:
1H_TWO:
12:
1H_WORK:
1H_CONTOUR:
1H_CONTOUR_TYPE:
1H_UNITS:
1H_PER_DAY:
1480:
1H_IMPEX_ROLLUP:
1H_EFFORT:
1H_COUNT:
1H_TOTAL:
1H_MINUTES:
1H_DATA_FLAG:
1H_WORK_TODATE:
1H_DAYOFYEAR:
1DATE:
1H_FINISH_D:
1H_TSK_ASSIGNMENT_ID:
1H_PRJ_ASSIGNMENT_ID:
1H_NULL_STR:
11:
1H_START_DATE:
1TIMESTAMP:
1H_START_DT:
1H_ACTUAL_START:
1H_FINISH_DT:
1H_REC_DT:
1H_LOCK_DT:
1H_ASSIGN_STRING:
1H_TABLE_TYPE:
1H_TEMP_VAR:
1H_TEMP_SC_STATE:
1H_OCCURRENCE:
1H_BIT_MINUTES:
1H_ACTION_TYPE:
1H_ETC:
1H_SD:
1H_FD:
1H_REG_COST:
1NUMBER:
1H_REG_SALE:
1H_BILLABLE:
1H_CAPITAL_EXPENSE:
1H_TPH_DELETE:
1H_PERCENT_UNITS:
1CURSOR:
1C_H_WBS:
1ELEMENT_NAME:
1RTRIM:
1TO_CHAR:
1MAJOR_REVISION:
1MINOR_REVISION:
1TMT_WBS:
1PROJECT_ID:
1ELEMENT_ID:
1REC_DATETIME:
1ROWNUM:
1SELECT * FROM (SELECT ELEMENT_NAME,RTRIM(TO_CHAR(MAJOR_REVISION)) || '.' || R+
1TRIM(TO_CHAR(MINOR_REVISION)):n         FROM TMT_WBS:n         WHERE PROJECT_+
1ID = h_project_id AND ELEMENT_ID = h_task_id:n         ORDER BY REC_DATETIME +
1DESC ) WHERE ROWNUM<=1:
1CAF:
1SCHED_MIN:
1DAY_YEAR:
1ACTUAL_FLAG:
1TASK_DAY_OF_YEAR:
1TSK_ASSIGNMENT_ID:
1ACTUAL_MIN:
1SELECT SCHED_MIN, DAY_YEAR, ACTUAL_FLAG:n         FROM TASK_DAY_OF_YEAR:n    +
1     WHERE PROJECT_ID = h_project_id AND TSK_ASSIGNMENT_ID = h_tsk_assignment+
1_id:n         FOR UPDATE OF ACTUAL_MIN,ACTUAL_FLAG:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_ASSIGN_MSP(:
1':
1, :
1COALESCE:
1NULL:
1);:
1CHECK_TRACE:
1123:
1+:
1FPUT:
1               ENTER:: SP_ASSIGN_MSP(124) :: cplan.sql(7398) :: :
1IS NULL:
1<:
1>:
13:
18:
1129:
1      RETURN_INVALID:: SP_ASSIGN_MSP(130) :: cplan.sql(7404) :: :
1 :
1STATE:: :
1PMO_CNST:
1INVALID_PARAMS:
1132:
1                EXIT:: SP_ASSIGN_MSP(133) :: cplan.sql(7407) :: :
1PMODEFINES:
1PMO_RETURN_INVALID_SP:
1TRUE:
1139:
1      RETURN_INVALID:: SP_ASSIGN_MSP(140) :: cplan.sql(7414) :: :
1142:
1                EXIT:: SP_ASSIGN_MSP(143) :: cplan.sql(7417) :: :
1265:
1LENGTH:
1SC_ASSIGN_STRING_LENGTH:
1=:
1171:
1      RETURN_INVALID:: SP_ASSIGN_MSP(172) :: cplan.sql(7446) :: :
1174:
1                EXIT:: SP_ASSIGN_MSP(175) :: cplan.sql(7449) :: :
1TYPE_ID:
1SELECT PROJECT_ID, TYPE_ID INTO h_project_id, h_type_id:n            FROM TMT+
1_WBS WHERE ELEMENT_ID = h_task_id:
1SC_STATE:
1SQLCODE:
1OTHERS:
1192:
1           EXCEPTION:: SP_ASSIGN_MSP(193) :: cplan.sql(7467) :: :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1SYS_GUID:
1GETTABLE:
1ASSIGNRESOURCE:
1COUNT:
1DUAL:
1PROFILES:
1PROFILE_ID:
1SELECT COUNT('X') INTO h_temp_var FROM DUAL:n               WHERE EXISTS (SEL+
1ECT 'X' FROM PROFILES:n               WHERE PROJECT_ID = h_project_id AND PRO+
1FILE_ID = h_resource_id):
1216:
1           EXCEPTION:: SP_ASSIGN_MSP(217) :: cplan.sql(7491) :: :
1!=:
15:
11*5:
1IS NOT NULL:
1TO_TIMESTAMP:
1PMO_ORASTD:
1DB2TIMESTAMP:
1SELECT TO_TIMESTAMP(PMO_ORASTD.DB2TIMESTAMP(h_start_DT)) + (5 / 1440.0) INTO +
1h_finish_DT FROM DUAL:
1235:
1           EXCEPTION:: SP_ASSIGN_MSP(236) :: cplan.sql(7510) :: :
1ISWBSDELIV:
1TASK_ID:
1RESOURCE_ID:
1WORK_TODATE:
1PROJECT_ASSIGNMENT_ID:
1UNITS_MSP:
1C_EFFORT:
1C_CONTOUR:
1CONTOUR_TYPE:
1TASK_ASSIGNMENTS:
1SELECT PROJECT_ID, TASK_ID, RESOURCE_ID, WORK_TODATE, PROJECT_ASSIGNMENT_ID,+
1:n            UNITS_MSP, C_EFFORT, C_CONTOUR, CONTOUR_TYPE, REC_DATETIME:n   +
1         INTO h_project_id, h_task_id, h_resource_id, h_work_todate, h_prj_as+
1signment_id,:n            h_percent_units, h_work, h_contour, h_contour_type,+
1 h_rec_DT:n            FROM TASK_ASSIGNMENTS WHERE TSK_ASSIGNMENT_ID = h_ra_i+
1d:
1262:
1           EXCEPTION:: SP_ASSIGN_MSP(263) :: cplan.sql(7537) :: :
1SC_SQL_SUCCESS:
1-:
1279:
1        RETURN_ERROR:: SP_ASSIGN_MSP(280) :: cplan.sql(7554) :: :
1 ID:: :
1282:
1                EXIT:: SP_ASSIGN_MSP(283) :: cplan.sql(7557) :: :
1PMO_RETURN_ERROR_SP:
1291:
1      RETURN_INVALID:: SP_ASSIGN_MSP(292) :: cplan.sql(7566) :: :
1294:
1                EXIT:: SP_ASSIGN_MSP(295) :: cplan.sql(7569) :: :
1SC_BIT_28:
1103079040:
1MINUTE_PER_DAY:
1SELECT COALESCE(MINUTE_PER_DAY, 480) INTO h_per_day FROM TMT_WBS WHERE ELEMEN+
1T_ID = h_task_id:
1317:
1           EXCEPTION:: SP_ASSIGN_MSP(318) :: cplan.sql(7592) :: :
1TRUNC:
1TO_NUMBER:
1/:
1*:
110000:
10.4:
1BITAND:
1FC_U_TSKRES2:
1ETC:
1PROPOSED_START:
1SCHED_START:
1PROPOSED_FINISH:
1SCHED_FINISH:
1PROPOSED_WORK:
1SCHED_WORK:
1UPDATE TASK_ASSIGNMENTS SET ETC = eetc,:n                        PROPOSED_STA+
1RT = SCHED_START,PROPOSED_FINISH = SCHED_FINISH,PROPOSED_WORK = SCHED_WORK:n +
1                       WHERE PROJECT_ID = h_project_id AND TASK_ID = h_task_i+
1d AND RESOURCE_ID = h_resource_id:
1FOUND:
1100:
1386:
1           EXCEPTION:: SP_ASSIGN_MSP(387) :: cplan.sql(7661) :: :
1UPDATE TASK_ASSIGNMENTS SET ETC = eetc,:n                        PROPOSED_STA+
1RT = SCHED_START,PROPOSED_FINISH = SCHED_FINISH,PROPOSED_WORK = SCHED_WORK:n +
1                       WHERE TSK_ASSIGNMENT_ID = h_ra_id:
1422:
1           EXCEPTION:: SP_ASSIGN_MSP(423) :: cplan.sql(7697) :: :
1MILESTONE_PERCENT:
1ACTUAL_START:
1ACTUAL_FINISH:
1UPDATE TASK_ASSIGNMENTS SET MILESTONE_PERCENT = percent_complete001,:n       +
1              UNITS_MSP = h_units, CONTOUR_TYPE = h_contour_type,:n          +
1           PROPOSED_START = SCHED_START,PROPOSED_FINISH = SCHED_FINISH,PROPOS+
1ED_WORK = SCHED_WORK,:n                     ACTUAL_START = h_start_DT, ACTUAL+
1_FINISH = h_finish_DT,:n                     WORK_TODATE = work_todate001,:n +
1                    ETC = eetc:n                     WHERE TSK_ASSIGNMENT_ID +
1= h_ra_id:
1457:
1           EXCEPTION:: SP_ASSIGN_MSP(458) :: cplan.sql(7732) :: :
1UPDATE TASK_DAY_OF_YEAR SET ACTUAL_MIN = SCHED_MIN, ACTUAL_FLAG = 1:n        +
1             WHERE PROJECT_ID = h_project_id AND TSK_ASSIGNMENT_ID = h_ra_id:
1475:
1           EXCEPTION:: SP_ASSIGN_MSP(476) :: cplan.sql(7750) :: :
1LAST_SUBMITTED:
1UPDATE TASK_ASSIGNMENTS SET LAST_SUBMITTED = h_finish_DT:n                   +
1  WHERE TSK_ASSIGNMENT_ID = h_ra_id:
1493:
1           EXCEPTION:: SP_ASSIGN_MSP(494) :: cplan.sql(7768) :: :
1UPDATE TASK_ASSIGNMENTS SET ETC = eetc,:n                     PROPOSED_START +
1= SCHED_START,PROPOSED_FINISH = SCHED_FINISH,PROPOSED_WORK = SCHED_WORK:n    +
1                 WHERE TSK_ASSIGNMENT_ID = h_ra_id:
1512:
1           EXCEPTION:: SP_ASSIGN_MSP(513) :: cplan.sql(7787) :: :
1SC_NOT_32:
1UPDATE TASK_ASSIGNMENTS SET ETC = eetc,:n                     PROPOSED_START +
1= SCHED_START,PROPOSED_FINISH = SCHED_FINISH,PROPOSED_WORK = SCHED_WORK:n    +
1                 WHERE PROJECT_ID = h_project_id AND TASK_ID = h_task_id AND +
1RESOURCE_ID = h_resource_id:
1543:
1           EXCEPTION:: SP_ASSIGN_MSP(544) :: cplan.sql(7818) :: :
1SELECT SUBSTR(h_lock_DT,1,10) || '-' || SUBSTR(h_lock_DT,12,2) || '.' || SUBS+
1TR(h_lock_DT,15,2) || '.' || SUBSTR(h_lock_DT,18,9) INTO h_lock_DT FROM DUAL:
1563:
1           EXCEPTION:: SP_ASSIGN_MSP(564) :: cplan.sql(7838) :: :
1STRNCMP:
119:
1SC_TASK:
1TMT_WORKFLOW_CYCLES:
1PARENT_ID:
1SELECT ELEMENT_ID INTO h_wkf_def_id:n                        FROM TMT_WORKFLO+
1W_CYCLES:n                        WHERE PARENT_ID = 'NOTIFICATION':
1582:
1           EXCEPTION:: SP_ASSIGN_MSP(583) :: cplan.sql(7857) :: :
1FC_A_NOTIFICATION:
1OPEN:
1CLOSE:
1614:
1           EXCEPTION:: SP_ASSIGN_MSP(615) :: cplan.sql(7889) :: :
1FULL_NAME:
1RESOURCES:
1SELECT FULL_NAME INTO h_full_name FROM RESOURCES:n                           +
1WHERE RESOURCE_ID = h_resource_id:
1628:
1           EXCEPTION:: SP_ASSIGN_MSP(629) :: cplan.sql(7903) :: :
1Import of assignment failed.:
1Import cannot modify assignment for resource:: :
1 on the task:::
1. Assignment was modified in Timesheets during the time of export of the proj+
1ect.:
1FC_U_WORKFLOW:
1649:
1        RETURN_ERROR:: SP_ASSIGN_MSP(650) :: cplan.sql(7924) :: :
1652:
1                EXIT:: SP_ASSIGN_MSP(653) :: cplan.sql(7927) :: :
1682:
1           EXCEPTION:: SP_ASSIGN_MSP(683) :: cplan.sql(7957) :: :
1693:
1        RETURN_ERROR:: SP_ASSIGN_MSP(694) :: cplan.sql(7968) :: :
1696:
1                EXIT:: SP_ASSIGN_MSP(697) :: cplan.sql(7971) :: :
1RES_ASSIGNMENT_ID:
1UPDATE TASK_ASSIGNMENTS SET MILESTONE_PERCENT = percent_complete001,:n       +
1                 UNITS_MSP = h_units, CONTOUR_TYPE = h_contour_type,:n       +
1                 PROPOSED_START = SCHED_START,PROPOSED_FINISH = SCHED_FINISH,+
1PROPOSED_WORK = SCHED_WORK,:n                        ACTUAL_START = actual_st+
1art001,:n                        ACTUAL_FINISH = actual_finish001,:n         +
1               WORK_TODATE = actual_effort001:n                        WHERE +
1RES_ASSIGNMENT_ID = h_ra_id:
1729:
1           EXCEPTION:: SP_ASSIGN_MSP(730) :: cplan.sql(8004) :: :
1UPDATE TASK_ASSIGNMENTS SET MILESTONE_PERCENT = percent_complete001,:n       +
1                 UNITS_MSP = h_units,:n                        CONTOUR_TYPE =+
1 h_contour_type:n                        WHERE RES_ASSIGNMENT_ID = h_ra_id:
1749:
1           EXCEPTION:: SP_ASSIGN_MSP(750) :: cplan.sql(8024) :: :
1BASELINE3_START:
1BASELINE3_SCH_FLAG:
1BASELINE3_FINISH:
1BASELINE3_DURATION:
1BASELINE3_WORK:
1BASELINE2_START:
1BASELINE1_START:
1BASELINE2_FINISH:
1BASELINE1_FINISH:
1BASELINE2_DURATION:
1BASELINE1_DURATION:
1BASELINE2_WORK:
1BASELINE1_WORK:
1B_REGULAR_COST:
1REGULAR_COST:
1B_REGULAR_RATE:
1REGULAR_RATE:
1B_SPECIAL_COST:
1SPECIAL_COST:
1B_SPECIAL_RATE:
1SPECIAL_RATE:
1UPDATE TASK_ASSIGNMENTS SET MILESTONE_PERCENT = percent_complete001,:n       +
1                 UNITS_MSP = h_units, CONTOUR_TYPE = h_contour_type,:n       +
1                 BASELINE3_START = CASE WHEN BASELINE3_SCH_FLAG = 0 THEN TO_T+
1IMESTAMP(baseline_start001) ELSE BASELINE3_START END,:n                      +
1  BASELINE3_FINISH = CASE WHEN BASELINE3_SCH_FLAG = 0 THEN TO_TIMESTAMP(basel+
1ine_finish001) ELSE BASELINE3_FINISH END,:n                        BASELINE3_+
1DURATION = CASE WHEN BASELINE3_SCH_FLAG = 0 THEN baseline_duration001 ELSE BA+
1SELINE3_DURATION END,:n                        BASELINE3_WORK = CASE WHEN BAS+
1ELINE3_SCH_FLAG = 0 THEN baseline_work001 ELSE BASELINE3_WORK END,:n         +
1               :n                        BASELINE2_START = BASELINE1_START,:n+
1                        BASELINE2_FINISH = BASELINE1_FINISH,:n               +
1         BASELINE2_DURATION = BASELINE1_DURATION,:n                        BA+
1SELINE2_WORK = BASELINE1_WORK,:n                        :n                   +
1     BASELINE1_START = baseline_start001,:n                        BASELINE1_+
1FINISH = baseline_finish001,:n                        BASELINE1_DURATION = ba+
1seline_duration001,:n                        BASELINE1_WORK = baseline_work00+
11,:n                        B_REGULAR_COST = REGULAR_COST, B_REGULAR_RATE = R+
1EGULAR_RATE, B_SPECIAL_COST = SPECIAL_COST, B_SPECIAL_RATE = SPECIAL_RATE,:n +
1                       :n                        BASELINE3_SCH_FLAG = 1,:n   +
1                     PROPOSED_START = SCHED_START,PROPOSED_FINISH = SCHED_FIN+
1ISH,PROPOSED_WORK = SCHED_WORK,:n                        ACTUAL_START = actua+
1l_start001,:n                        ACTUAL_FINISH = actual_finish001,:n     +
1                   WORK_TODATE = actual_effort001:n                        WH+
1ERE RES_ASSIGNMENT_ID = h_ra_id:
1792:
1           EXCEPTION:: SP_ASSIGN_MSP(793) :: cplan.sql(8067) :: :
1UPDATE TASK_ASSIGNMENTS SET MILESTONE_PERCENT = percent_complete001,:n       +
1                 UNITS_MSP = h_units, CONTOUR_TYPE = h_contour_type,:n       +
1                 BASELINE3_START = CASE WHEN BASELINE3_SCH_FLAG = 0 THEN TO_T+
1IMESTAMP(baseline_start001) ELSE BASELINE3_START END,:n                      +
1  BASELINE3_FINISH = CASE WHEN BASELINE3_SCH_FLAG = 0 THEN TO_TIMESTAMP(basel+
1ine_finish001) ELSE BASELINE3_FINISH END,:n                        BASELINE3_+
1DURATION = CASE WHEN BASELINE3_SCH_FLAG = 0 THEN baseline_duration001 ELSE BA+
1SELINE3_DURATION END,:n                        BASELINE3_WORK = CASE WHEN BAS+
1ELINE3_SCH_FLAG = 0 THEN baseline_work001 ELSE BASELINE3_WORK END,:n         +
1               :n                        BASELINE2_START = BASELINE1_START,:n+
1                        BASELINE2_FINISH = BASELINE1_FINISH,:n               +
1         BASELINE2_DURATION = BASELINE1_DURATION,:n                        BA+
1SELINE2_WORK = BASELINE1_WORK,:n                        :n                   +
1     BASELINE1_START = baseline_start001,:n                        BASELINE1_+
1FINISH = baseline_finish001,:n                        BASELINE1_DURATION = ba+
1seline_duration001,:n                        BASELINE1_WORK = baseline_work00+
11,:n                        B_REGULAR_COST = REGULAR_COST, B_REGULAR_RATE = R+
1EGULAR_RATE, B_SPECIAL_COST = SPECIAL_COST, B_SPECIAL_RATE = SPECIAL_RATE,:n +
1                       :n                        BASELINE3_SCH_FLAG = 1:n    +
1                    WHERE RES_ASSIGNMENT_ID = h_ra_id:
1829:
1           EXCEPTION:: SP_ASSIGN_MSP(830) :: cplan.sql(8104) :: :
1ELSIF:
1UPDATE TASK_ASSIGNMENTS SET MILESTONE_PERCENT = percent_complete001,:n       +
1           UNITS_MSP = h_units,:n                  CONTOUR_TYPE = h_contour_t+
1ype:n                  WHERE RES_ASSIGNMENT_ID = h_ra_id:
1851:
1           EXCEPTION:: SP_ASSIGN_MSP(852) :: cplan.sql(8126) :: :
1UPDATE TASK_ASSIGNMENTS SET MILESTONE_PERCENT = percent_complete001,:n       +
1                 UNITS_MSP = h_units, CONTOUR_TYPE = h_contour_type,:n       +
1                 PROPOSED_START = SCHED_START,PROPOSED_FINISH = SCHED_FINISH,+
1PROPOSED_WORK = SCHED_WORK,:n                        ACTUAL_START = actual_st+
1art001,:n                        ACTUAL_FINISH = actual_finish001,:n         +
1               WORK_TODATE = actual_effort001:n                        WHERE +
1TSK_ASSIGNMENT_ID = h_ra_id:
1879:
1           EXCEPTION:: SP_ASSIGN_MSP(880) :: cplan.sql(8154) :: :
1UPDATE TASK_ASSIGNMENTS SET MILESTONE_PERCENT = percent_complete001,:n       +
1                 UNITS_MSP = h_units, CONTOUR_TYPE = h_contour_type,:n       +
1                 WORK_TODATE = work_todate001:n                        WHERE +
1TSK_ASSIGNMENT_ID = h_ra_id:
1899:
1           EXCEPTION:: SP_ASSIGN_MSP(900) :: cplan.sql(8174) :: :
1UPDATE TASK_ASSIGNMENTS SET MILESTONE_PERCENT = percent_complete001,:n       +
1                 UNITS_MSP = h_units, CONTOUR_TYPE = h_contour_type,:n       +
1                 BASELINE3_START = CASE WHEN BASELINE3_SCH_FLAG = 0 THEN TO_T+
1IMESTAMP(baseline_start001) ELSE BASELINE3_START END,:n                      +
1  BASELINE3_FINISH = CASE WHEN BASELINE3_SCH_FLAG = 0 THEN TO_TIMESTAMP(basel+
1ine_finish001) ELSE BASELINE3_FINISH END,:n                        BASELINE3_+
1DURATION = CASE WHEN BASELINE3_SCH_FLAG = 0 THEN baseline_duration001 ELSE BA+
1SELINE3_DURATION END,:n                        BASELINE3_WORK = CASE WHEN BAS+
1ELINE3_SCH_FLAG = 0 THEN baseline_work001 ELSE BASELINE3_WORK END,:n         +
1               :n                        BASELINE2_START = BASELINE1_START,:n+
1                        BASELINE2_FINISH = BASELINE1_FINISH,:n               +
1         BASELINE2_DURATION = BASELINE1_DURATION,:n                        BA+
1SELINE2_WORK = BASELINE1_WORK,:n                        :n                   +
1     BASELINE1_START = baseline_start001,:n                        BASELINE1_+
1FINISH = baseline_finish001,:n                        BASELINE1_DURATION = ba+
1seline_duration001,:n                        BASELINE1_WORK = baseline_work00+
11,:n                        B_REGULAR_COST = REGULAR_COST, B_REGULAR_RATE = R+
1EGULAR_RATE, B_SPECIAL_COST = SPECIAL_COST, B_SPECIAL_RATE = SPECIAL_RATE,:n +
1                       :n                        BASELINE3_SCH_FLAG = 1,:n   +
1                     PROPOSED_START = SCHED_START,PROPOSED_FINISH = SCHED_FIN+
1ISH,PROPOSED_WORK = SCHED_WORK,:n                        ACTUAL_START = actua+
1l_start001,:n                        ACTUAL_FINISH = actual_finish001,:n     +
1                   WORK_TODATE = actual_effort001:n                        WH+
1ERE TSK_ASSIGNMENT_ID = h_ra_id:
1942:
1           EXCEPTION:: SP_ASSIGN_MSP(943) :: cplan.sql(8217) :: :
1UPDATE TASK_ASSIGNMENTS SET MILESTONE_PERCENT = percent_complete001,:n       +
1                 UNITS_MSP = h_units, CONTOUR_TYPE = h_contour_type,:n       +
1                 WORK_TODATE = work_todate001,:n                        BASEL+
1INE3_START = CASE WHEN BASELINE3_SCH_FLAG = 0 THEN TO_TIMESTAMP(baseline_star+
1t001) ELSE BASELINE3_START END,:n                        BASELINE3_FINISH = C+
1ASE WHEN BASELINE3_SCH_FLAG = 0 THEN TO_TIMESTAMP(baseline_finish001) ELSE BA+
1SELINE3_FINISH END,:n                        BASELINE3_DURATION = CASE WHEN B+
1ASELINE3_SCH_FLAG = 0 THEN baseline_duration001 ELSE BASELINE3_DURATION END,+
1:n                        BASELINE3_WORK = CASE WHEN BASELINE3_SCH_FLAG = 0 T+
1HEN baseline_work001 ELSE BASELINE3_WORK END,:n                        :n    +
1                    BASELINE2_START = BASELINE1_START,:n                     +
1   BASELINE2_FINISH = BASELINE1_FINISH,:n                        BASELINE2_DU+
1RATION = BASELINE1_DURATION,:n                        BASELINE2_WORK = BASELI+
1NE1_WORK,:n                        :n                        BASELINE1_START +
1= baseline_start001,:n                        BASELINE1_FINISH = baseline_fin+
1ish001,:n                        BASELINE1_DURATION = baseline_duration001,:n+
1                        BASELINE1_WORK = baseline_work001,:n                 +
1       B_REGULAR_COST = REGULAR_COST, B_REGULAR_RATE = REGULAR_RATE, B_SPECIA+
1L_COST = SPECIAL_COST, B_SPECIAL_RATE = SPECIAL_RATE,:n                      +
1  :n                        BASELINE3_SCH_FLAG = 1:n                        W+
1HERE TSK_ASSIGNMENT_ID = h_ra_id:
1979:
1           EXCEPTION:: SP_ASSIGN_MSP(980) :: cplan.sql(8254) :: :
1UPDATE TASK_ASSIGNMENTS SET MILESTONE_PERCENT = percent_complete001,:n       +
1                 UNITS_MSP = h_units, CONTOUR_TYPE = h_contour_type,:n       +
1                 WORK_TODATE = work_todate001,:n                        ETC =+
1 h_effort - work_todate001:n                        WHERE TSK_ASSIGNMENT_ID =+
1 h_ra_id:
11004:
1           EXCEPTION:: SP_ASSIGN_MSP(1005) :: cplan.sql(8279) :: :
11024:
1           EXCEPTION:: SP_ASSIGN_MSP(1025) :: cplan.sql(8299) :: :
1UPDATE TASK_ASSIGNMENTS SET MILESTONE_PERCENT = percent_complete001,:n       +
1              UNITS_MSP = h_units, CONTOUR_TYPE = h_contour_type,:n          +
1           WORK_TODATE = work_todate001:n                     WHERE TSK_ASSIG+
1NMENT_ID = h_ra_id:
11045:
1           EXCEPTION:: SP_ASSIGN_MSP(1046) :: cplan.sql(8320) :: :
1:
1TO_DATE:
1BILLABLE:
1CAPITAL_EXPENSE:
1SELECT TSK_ASSIGNMENT_ID, SCHED_WORK, TASK_ID, TO_DATE(SubStr(SCHED_START, 1,+
1 10)), TO_DATE(SubStr(SCHED_FINISH, 1, 10)), BILLABLE, CAPITAL_EXPENSE, REGUL+
1AR_COST, REGULAR_RATE:n                  INTO h_tsk_assignment_id, h_effort, +
1h_task_id, h_SD, h_FD, h_billable, h_capital_expense, h_reg_cost, h_reg_sale+
1:n                  FROM TASK_ASSIGNMENTS:n                  WHERE RES_ASSIGN+
1MENT_ID = h_ra_id:
11074:
1           EXCEPTION:: SP_ASSIGN_MSP(1075) :: cplan.sql(8349) :: :
1SELECT SCHED_WORK, TASK_ID, TO_DATE(SubStr(SCHED_START, 1, 10)), TO_DATE(SubS+
1tr(SCHED_FINISH, 1, 10)), BILLABLE, CAPITAL_EXPENSE, REGULAR_COST, REGULAR_RA+
1TE:n                  INTO h_effort, h_task_id, h_SD, h_FD, h_billable, h_cap+
1ital_expense, h_reg_cost, h_reg_sale:n                  FROM TASK_ASSIGNMENTS+
1:n                  WHERE TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
11091:
1           EXCEPTION:: SP_ASSIGN_MSP(1092) :: cplan.sql(8366) :: :
1UPDATE TASK_DAY_OF_YEAR SET ACTUAL_MIN = SCHED_MIN, ACTUAL_FLAG = 1:n        +
1             WHERE PROJECT_ID = h_project_id AND TSK_ASSIGNMENT_ID = h_tsk_as+
1signment_id:
11114:
1           EXCEPTION:: SP_ASSIGN_MSP(1115) :: cplan.sql(8389) :: :
1MAX:
1UPDATE TASK_ASSIGNMENTS SET WORK_TODATE = SCHED_WORK,:n                     L+
1AST_SUBMITTED = (SELECT MAX(DAY_YEAR) FROM TASK_DAY_OF_YEAR:n                +
1     WHERE PROJECT_ID = h_project_id AND TSK_ASSIGNMENT_ID = h_tsk_assignment+
1_id):n                     WHERE TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
11134:
1           EXCEPTION:: SP_ASSIGN_MSP(1135) :: cplan.sql(8409) :: :
1LOOP:
1EXIT:
1>=:
1UPDATE TASK_DAY_OF_YEAR SET ACTUAL_MIN = h_minutes, ACTUAL_FLAG = 1 WHERE CUR+
1RENT OF CAF:
11191:
1           EXCEPTION:: SP_ASSIGN_MSP(1192) :: cplan.sql(8466) :: :
11212:
1           EXCEPTION:: SP_ASSIGN_MSP(1213) :: cplan.sql(8487) :: :
1UPDATE TASK_ASSIGNMENTS SET LAST_SUBMITTED = h_finish_D WHERE TSK_ASSIGNMENT_+
1ID = h_tsk_assignment_id:
11231:
1           EXCEPTION:: SP_ASSIGN_MSP(1232) :: cplan.sql(8506) :: :
1FC_GENERATE_TS_ALL:
1FC_GENERATE_TS_MSP:
14:
11327:
1       RETURN_STATUS:: SP_ASSIGN_MSP(1328) :: cplan.sql(8602) :: :
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
11335:
1           EXCEPTION:: SP_ASSIGN_MSP(1336) :: cplan.sql(8610) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1ERROR:
1ID:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
11347:
1           EXCEPTION:: SP_ASSIGN_MSP(1348) :: cplan.sql(8622) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
1ccb
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 81 b0 a3 a0 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 1c
81 b0 a3 a0 1c 81 b0 a3
a0 1c 81 b0 a3 a0 1c 81
b0 a3 a0 1c 81 b0 a3 a0
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 81
b0 a3 a0 1c 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a0 f4 b4 bf c8 :e a0
12a bd b7 11 a4 b1 a0 f4
b4 bf c8 :a a0 12a bd b7 11
a4 b1 a3 :2 a0 6b 1c 81 b0
:2 a0 6b :2 a0 6b 6e a5 b a
10 :2 a0 6b 6e :2 a0 6b 6e a5
b 6e 7e a0 b4 2e 6e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:3 a0 a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :3 a0 a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :3 a0 a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e :3 a0
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e :3 a0 a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e :3 a0 a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e :3 a0 a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:3 a0 a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e :3 a0 a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :3 a0 a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c a0 7e
b4 2e :2 5a :2 a0 51 a5 b 7e
51 b4 2e 5a :2 a0 51 a5 b
7e 51 b4 2e 5a 52 10 5a
52 10 :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b a0 a5
57 b7 19 3c a0 7e b4 2e
:2 5a a0 7e b4 2e :2 5a 52 10
a0 7e b4 2e :2 5a 52 10 :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b a0 a5 57 b7 19
3c a0 4d d a0 4d d a0
51 d :2 a0 d :2 a0 d :2 a0 d
:2 a0 d :2 a0 d :2 a0 d :2 a0 d
:2 a0 d :2 a0 d :2 a0 d a0 51
d :3 a0 a5 b 51 a5 b a0
7e a0 6b b4 2e :2 a0 51 a5
b 7e 51 b4 2e 5a :2 a0 51
a5 b 7e 51 b4 2e 5a 52
10 a0 7e b4 2e 5a :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b a0 a5 57 b7 19 3c
:2 a0 d :2 a0 d :2 a0 d :7 a0 12a
:2 a0 6b a0 d b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 b4 2e d :4 a0 51 a5
b a5 b d :2 a0 6b :7 a0 a5
b d :2 a0 6b 7e 51 b4 2e
5a :2 a0 51 a5 b 7e 51 b4
2e 5a a 10 :2 a0 51 a5 b
7e 51 b4 2e 5a a 10 a0
51 d :8 a0 12a :2 a0 6b a0 d
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 51 a5
b 7e 51 b4 2e a0 51 d
a0 51 d a0 6e d a0 7e
b4 2e 5a :6 a0 12a :2 a0 6b a0
d b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 19
3c b7 19 3c b7 19 3c :2 a0
51 a5 b 7e 51 b4 2e 5a
:3 a0 51 a5 b a5 b 5a 7e
51 b4 2e a 10 a0 51 d
b7 19 3c b7 :2 a0 d :17 a0 12a
:2 a0 6b a0 d b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6b a0 7e a0 6b b4
2e 5a :2 a0 51 a5 b a0 7e
a0 51 a5 b b4 2e 5a a
10 a0 4d d a0 7e 51 b4
2e d b7 19 3c b7 :2 19 3c
:2 a0 51 a5 b 7e 51 b4 2e
:2 a0 6b 7e 51 b4 2e :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b :2 a0 a5 57 b7 19 3c
a0 7e b4 2e 5a a0 7e b4
2e 5a 52 10 a0 7e b4 2e
5a 52 10 a0 7e b4 2e 5a
52 10 :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b a0 a5
57 b7 19 3c :3 a0 6b d :2 a0
51 a5 b 7e 51 b4 2e a0
51 d b7 19 3c :6 a0 12a :2 a0
6b a0 d b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 51 a5 b 7e 51 b4 2e
:5 a0 a5 b 51 a5 b 7e :3 a0
a5 b 51 a5 b b4 2e 5a
7e 51 b4 2e 5a 7e 51 b4
2e a5 b d :2 a0 51 a5 b
a0 7e a0 51 a5 b b4 2e
a0 51 d a0 51 d b7 a0
51 d b7 :2 19 3c b7 19 3c
a0 4d d :3 a0 51 a5 b 51
a5 b 5a 7e 51 b4 2e :2 a0
51 a5 b 7e 51 b4 2e :2 a0
51 a5 b 7e 51 b4 2e :2 a0
6b :12 a0 a5 b d :2 a0 6b 7e
51 b4 2e :f a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 19 3c b7
:2 a0 6b :12 a0 a5 b d b7 :2 19
3c b7 :3 a0 51 a5 b 7e 51
b4 2e d :2 a0 51 a5 b 7e
51 b4 2e :2 a0 6b :12 a0 a5 b
d :2 a0 6b 7e 51 b4 2e :b a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 19 3c b7 :2 a0 6b :12 a0 a5
b d b7 :2 19 3c b7 :2 19 3c
:2 a0 6b 7e 51 b4 2e 5a :3 a0
51 a5 b 51 a5 b 5a 7e
51 b4 2e 5a a 10 :2 a0 51
a5 b a0 7e a0 51 a5 b
b4 2e 5a :2 a0 51 a5 b 7e
51 b4 2e 5a a 10 :2 a0 51
a5 b 7e 51 b4 2e 5a a
10 :17 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :8 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :5 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 :b a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 :2 19
3c b7 19 3c b7 :4 a0 51 a5
b :2 a0 6b a5 b d :2 a0 51
a5 b 7e 51 b4 2e :2 a0 6b
:12 a0 a5 b d :2 a0 6b 7e 51
b4 2e 5a :2 a0 51 a5 b 7e
51 b4 2e 5a a 10 :2 a0 51
a5 b 7e 51 b4 2e 5a a
10 :f a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 19 3c b7 a0 7e
b4 2e 5a :2 a0 d :a a0 12a :2 a0
6b a0 d b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 6b :2 a0 51 a5 b 7e 51
b4 2e :3 a0 6b d a0 51 d
:4 a0 12a :2 a0 6b a0 d b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :8 a0 a5 b d :2 a0
51 a5 b 7e 51 b4 2e a0
4d d a0 4d d a0 4d d
a0 4d d a0 4d d :2 a0 e9
dd b3 :3 a0 e9 d3 5 :2 a0 f
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c :2 a0 e9 c1 :2 a0
6b a0 d b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:5 a0 12a :2 a0 6b a0 d b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f a0 6e d a0 6e
d :3 a0 7e a0 b4 2e :2 51 a5
b d :3 a0 7e 6e b4 2e :2 51
a5 b d :3 a0 7e a0 b4 2e
:2 51 a5 b d :3 a0 7e 6e b4
2e :2 51 a5 b d :11 a0 a5 b
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:2 a0 51 a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b 51 :2 a0 a5 57 b7
19 3c b7 19 3c b7 19 3c
:3 a0 51 a5 b 7e 51 b4 2e
d :2 a0 6b :12 a0 a5 b d :2 a0
6b 7e 51 b4 2e 5a :2 a0 51
a5 b 7e 51 b4 2e 5a a
10 :2 a0 51 a5 b 7e 51 b4
2e 5a a 10 :b a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 19 3c
b7 :2 19 3c b7 :2 19 3c :2 a0 6b
7e 51 b4 2e :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :4 a0 6b a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
:2 a0 a5 57 b7 19 3c :2 a0 d
:2 a0 51 a5 b 7e 51 b4 2e
5a :2 a0 51 a5 b 7e 51 b4
2e 5a a 10 a0 51 d b7
19 3c :2 a0 51 a5 b 7e 51
b4 2e :3 a0 51 a5 b 51 a5
b 5a 7e 51 b4 2e a0 7e
b4 2e 5a a0 7e b4 2e 5a
:15 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 :9 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 :2 19 3c b7 a0
7e b4 2e 5a :40 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 :34 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
:2 19 3c b7 :2 19 3c a0 b7 :2 a0
51 a5 b 7e 51 b4 2e :9 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 :2 19 3c b7 :3 a0 51 a5 b
51 a5 b 5a 7e 51 b4 2e
a0 7e b4 2e 5a a0 7e b4
2e 5a :15 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 :b a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 :2 19 3c
b7 a0 7e b4 2e 5a :40 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
:36 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 :2 19 3c b7 :2 19 3c a0
b7 :2 a0 51 a5 b 7e 51 b4
2e a0 7e b4 2e 5a :2 a0 51
a5 b 7e 51 b4 2e :e a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
:b a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 :2 19 3c b7 :b a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 :2 19
3c b7 :2 19 3c b7 :2 19 3c a0
7e b4 2e 5a :2 a0 51 a5 b
7e 51 b4 2e 5a a 10 5a
:2 a0 51 a5 b 7e 51 b4 2e
5a 52 10 a0 6e d a0 4d
d a0 51 d a0 51 d :2 a0
51 a5 b 7e 51 b4 2e :19 a0
12a :2 a0 6b a0 d b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 :2 a0 d :17 a0 12a :2 a0
6b a0 d b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 :2 19 3c :2 a0 6b a0 7e a0
6b b4 2e 5a :2 a0 51 a5 b
a0 7e a0 51 a5 b b4 2e
5a :2 a0 51 a5 b 7e 51 b4
2e 5a a 10 :2 a0 51 a5 b
7e 51 b4 2e 5a a 10 :8 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:d a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 :2 a0 e9 dd b3 :5 a0 e9
d3 5 :2 a0 f :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
:2 a0 6b 7e 51 b4 2e a0 2b
b7 19 3c :3 a0 51 a5 b 7e
:2 a0 51 a5 b b4 2e d :2 a0
51 a5 b 7e 51 b4 2e :2 a0
51 a5 b a0 7e a0 51 a5
b b4 2e :2 a0 51 a5 b a0
7e a0 51 a5 b b4 2e :3 a0
51 a5 b d b7 :3 a0 51 a5
b 7e :2 a0 51 a5 b b4 2e
7e :2 a0 51 a5 b b4 2e d
b7 :2 19 3c b7 19 3c :5 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
d b7 19 3c :2 a0 51 a5 b
a0 7e a0 51 a5 b b4 2e
a0 2b b7 19 3c b7 a0 47
:2 a0 e9 c1 :2 a0 6b a0 d b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 51 a5 b
7e 51 b4 2e 5a a0 7e b4
2e :2 5a a 10 :5 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 19 3c
b7 :2 19 3c :2 a0 51 a5 b 7e
51 b4 2e :3 a0 51 a5 b 51
a5 b 5a 7e 51 b4 2e :4 a0
a5 b d b7 :4 a0 a5 b d
b7 :2 19 3c b7 19 3c b7 19
3c b7 19 3c b7 19 3c :2 a0
6b 7e 51 b4 2e :2 a0 6b 51
d b7 19 3c b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
:2 a0 a5 57 b7 :2 a0 6b :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 :2 a0 6b
:2 6e 7e :2 a0 6b b4 2e 7e 6e
b4 2e 7e :2 a0 6b b4 2e a5
57 b7 19 3c :9 a0 12a e9 dd
:2 a0 65 b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c :7 a0 12a e9 dd :2 a0 65
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 68 4f 1d 17 b5 
1ccb
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 5e
5a 30 66 6f 6b 59 77 84
80 56 8c 95 91 7f 9d aa
a6 7c b2 bb b7 a5 c3 d0
cc a2 d8 e1 dd cb e9 f6
f2 c8 fe 107 103 f1 10f 11c
118 ee 124 12d 129 117 135 142
13e 114 14a 153 14f 13d 15b 168
164 13a 170 179 175 163 181 18e
18a 160 196 19f 19b 189 1a7 186
1ac 1b0 1b4 1b8 1bb 1bf 1dc 1c7
1cb 1ce 1cf 1d7 1c6 1f9 1e7 1c3
1eb 1ec 1f4 1e6 216 204 1e3 208
209 211 203 233 221 200 225 226
22e 220 250 23e 21d 242 243 24b
23d 26d 25b 23a 25f 260 268 25a
28a 278 257 27c 27d 285 277 2a7
295 274 299 29a 2a2 294 2c4 2b2
291 2b6 2b7 2bf 2b1 2e1 2cf 2ae
2d3 2d4 2dc 2ce 2fe 2ec 2cb 2f0
2f1 2f9 2eb 31b 309 2e8 30d 30e
316 308 338 326 305 32a 32b 333
325 355 343 322 347 348 350 342
371 360 364 33f 36c 35f 38d 37c
380 35c 388 37b 3a9 398 39c 378
3a4 397 3c5 3b4 3b8 394 3c0 3b3
3e1 3d0 3d4 3b0 3dc 3cf 3fd 3ec
3f0 3cc 3f8 3eb 419 408 40c 3e8
414 407 435 424 428 404 430 423
451 440 444 420 44c 43f 46d 45c
460 43c 468 45b 489 478 47c 458
484 477 4a5 494 498 474 4a0 493
4c1 4b0 4b4 490 4bc 4af 4dd 4cc
4d0 4ac 4d8 4cb 4f9 4e8 4ec 4c8
4f4 4e7 515 504 508 4e4 510 503
531 520 524 52c 500 549 538 53c
544 51f 566 554 51c 558 559 561
553 583 571 550 575 576 57e 570
5a0 58e 56d 592 593 59b 58d 5bc
5ab 5af 5b7 58a 5d4 5c3 5c7 5cf
5aa 5f0 5df 5e3 5eb 5a7 608 5f7
5fb 603 5de 624 613 617 61f 5db
63c 62b 62f 637 612 659 647 60f
64b 64c 654 646 675 664 668 643
670 663 691 680 684 660 68c 67f
6ad 69c 6a0 67c 6a8 69b 6c9 6b8
6bc 698 6c4 6b7 6e5 6d4 6d8 6b4
6e0 6d3 701 6f0 6f4 6d0 6fc 6ef
71d 70c 710 6ec 718 70b 739 728
72c 734 708 751 740 744 74c 727
76d 75c 760 724 768 75b 789 778
77c 758 784 777 7a5 794 798 774
7a0 793 7c1 7b0 7b4 790 7bc 7af
7dd 7cc 7d0 7ac 7d8 7cb 7f9 7e8
7ec 7c8 7f4 7e7 800 804 7e4 815
818 81c 820 824 828 82c 830 834
838 83c 840 844 848 84c 850 854
860 865 867 873 877 879 87d 88e
88f 892 896 89a 89e 8a2 8a6 8aa
8ae 8b2 8b6 8ba 8be 8ca 8cf 8d1
8dd 8e1 8ff 8e7 8eb 8ef 8f2 8fa
8e6 906 90a 8e3 90e 912 916 919
91e 91f 1 921 926 92a 92e 931
936 93a 93e 941 946 947 949 94e
951 955 956 95b 960 963 968 969
96e 971 975 976 97b 97e 983 984
989 98c 991 992 997 99a 99e 9a2
9a6 9a7 9a9 9ae 9af 9b1 9b2 9b7
9ba 9bf 9c0 9c5 9c8 9cd 9ce 9d3
9d6 9da 9db 9e0 9e3 9e8 9e9 9ee
9f1 9f6 9f7 9fc 9ff a04 a05 a0a
a0d a11 a12 a17 a1a a1f a20 a25
a28 a2d a2e a33 a36 a3b a3c a41
a44 a48 a49 a4e a51 a56 a57 a5c
a5f a64 a65 a6a a6d a71 a75 a79
a7a a7c a81 a82 a84 a85 a8a a8d
a92 a93 a98 a9b aa0 aa1 aa6 aa9
aad aae ab3 ab6 abb abc ac1 ac4
ac9 aca acf ad2 ad6 ada ade adf
ae1 ae6 ae7 ae9 aea aef af2 af7
af8 afd b00 b04 b08 b0c b0d b0f
b14 b15 b17 b18 b1d b20 b25 b26
b2b b2e b32 b36 b3a b3b b3d b42
b43 b45 b46 b4b b4e b53 b54 b59
b5c b60 b64 b68 b69 b6b b70 b71
b73 b74 b79 b7c b81 b82 b87 b8a
b8e b92 b96 b97 b99 b9e b9f ba1
ba2 ba7 baa baf bb0 bb5 bb8 bbc
bc0 bc4 bc5 bc7 bcc bcd bcf bd0
bd5 bd8 bdd bde be3 be6 beb bec
bf1 bf4 bf8 bf9 bfe c01 c06 c07
c0c c0f c14 c15 c1a c1d c22 c23
c28 c2b c2f c30 c35 c38 c3d c3e
c43 c46 c4b c4c c51 c54 c58 c5c
c60 c61 c63 c68 c69 c6b c6c c71
c74 c79 c7a c7f c82 c86 c8a c8e
c8f c91 c96 c97 c99 c9a c9f ca2
ca7 ca8 cad cb0 cb5 cb6 cbb cbe
cc2 cc3 cc8 ccb cd0 cd1 cd6 cd9
cde cdf ce4 ce7 cec ced cf2 cf5
cf9 cfa cff d02 d07 d08 d0d d10
d15 d16 d1b d1e d22 d26 d2a d2b
d2d d32 d33 d35 d36 d3b d3e d43
d44 d49 d4c d51 d52 d57 d5a d5e
d5f d64 d67 d6c d6d d72 d75 d7a
d7b d80 d81 d86 d88 d8c d8f d93
d97 d9a d9e da2 da5 da8 dad db0
db3 db6 db7 dbc dbd 1 dbf dc4
dc8 dcc dcf dd4 dd9 ddc de0 de1
de6 de7 dec dee df2 df5 df9 dfc
dfd e02 e05 e08 e0c e10 e13 e14
e16 e19 e1c e1d e22 e25 e29 e2d
e30 e31 e33 e36 e39 e3a e3f 1
e42 e47 1 e4a e4f e53 e57 e5a
e5e e62 e65 e68 e6d e70 e73 e76
e77 e7c e7d 1 e7f e84 e88 e8c
e8f e94 e99 e9c ea0 ea1 ea6 ea9
eae eaf eb4 eb7 ebc ebd ec2 ec5
ec9 ecd ed1 ed5 ed8 ed9 edb ee0
ee1 ee3 ee4 ee9 eea eef ef1 ef5
ef8 efc f00 f03 f07 f0b f0e f11
f16 f19 f1c f1f f20 f25 f26 1
f28 f2d f31 f35 f38 f3d f42 f45
f49 f4a f4f f50 f55 f57 f5b f5e
f62 f66 f69 f6d f71 f74 f78 f79
f7e f80 f84 f87 f8b f8e f8f f94
f97 f9a f9e fa1 fa2 fa7 faa 1
fad fb2 fb6 fb9 fba fbf fc2 1
fc5 fca fce fd2 fd5 fd9 fdd fe0
fe3 fe8 feb fee ff1 ff2 ff7 ff8
1 ffa fff 1003 1007 100a 100f 1014
1017 101b 101c 1021 1024 1029 102a 102f
1032 1037 1038 103d 1040 1044 1048 104c
1050 1053 1054 1056 105b 105c 105e 105f
1064 1065 106a 106c 1070 1073 1077 107b
107e 1082 1086 1089 108c 1091 1094 1097
109a 109b 10a0 10a1 1 10a3 10a8 10ac
10b0 10b3 10b8 10bd 10c0 10c4 10c5 10ca
10cb 10d0 10d2 10d6 10d9 10dd 10e1 10e4
10e8 10ec 10ef 10f3 10f4 10f9 10fb 10ff
1102 1106 1107 110b 110f 1110 1114 1118
111b 111f 1123 1127 112b 112f 1133 1137
113b 113f 1143 1147 114b 114f 1153 1157
115b 115f 1163 1167 116b 116f 1173 1177
117b 117f 1183 1187 118b 118f 1193 1197
119b 119e 11a2 11a6 11aa 11ae 11af 11b1
11b4 11b5 11b7 11bb 11be 11c2 11c5 11c6
11cb 11cf 11d3 11d6 11d7 11d9 11dc 11df
11e0 11e5 11e8 11ec 11f0 11f3 11f4 11f6
11f9 11fc 11fd 1202 1 1205 120a 120e
1211 1212 1217 121a 121e 1222 1225 1229
122d 1230 1233 1238 123b 123e 1241 1242
1247 1248 1 124a 124f 1253 1257 125a
125f 1264 1267 126b 126c 1271 1274 1279
127a 127f 1282 1287 1288 128d 1290 1294
1298 129c 12a0 12a3 12a4 12a6 12ab 12ac
12ae 12af 12b4 12b5 12ba 12bc 12c0 12c3
12c7 12cb 12ce 12d2 12d6 12d9 12dc 12e1
12e4 12e7 12ea 12eb 12f0 12f1 1 12f3
12f8 12fc 1300 1303 1308 130d 1310 1314
1315 131a 131b 1320 1322 1326 1329 132d
1331 1334 1338 133c 133f 1343 1344 1349
134b 134f 1352 1356 135a 135e 1362 1366
136a 136e 1372 1376 137a 137e 1382 1386
138a 138e 1392 139e 13a2 13a6 13a9 13ad
13b1 13b3 1 13b7 13bb 13bf 13c2 13c6
13ca 13ce 13d2 13d5 13d9 13dd 13e0 13e3
13e8 13eb 13ee 13f1 13f2 13f7 13f8 1
13fa 13ff 1403 1407 140a 140f 1414 1417
141b 141c 1421 1424 1429 142a 142f 1432
1437 1438 143d 1440 1444 1445 144a 144d
1452 1453 1458 145b 145f 1463 1466 1469
146a 146c 146d 1472 1473 1478 147a 147e
1481 1483 1487 1489 1495 1497 1499 149a
149f 14a3 14a5 14b1 14b3 14b7 14bb 14bc
14c1 14c5 14c9 14cd 14d1 14d5 14d8 14d9
14db 14dc 14de 14e2 14e6 14ea 14ed 14f1
14f5 14f9 14fd 1501 1505 1509 150a 150c
1510 1514 1518 151b 151e 1521 1522 1527
152a 152e 1532 1535 1536 1538 153b 153e
153f 1544 1 1547 154c 1550 1554 1557
1558 155a 155d 1560 1561 1566 1 1569
156e 1572 1575 1579 157d 1581 1585 1589
158d 1591 1595 1599 15a5 15a9 15ad 15b0
15b4 15b8 15ba 1 15be 15c2 15c6 15c9
15cd 15d1 15d5 15d9 15dc 15e0 15e4 15e7
15ea 15ef 15f2 15f5 15f8 15f9 15fe 15ff
1 1601 1606 160a 160e 1611 1616 161b
161e 1622 1623 1628 162b 1630 1631 1636
1639 163e 163f 1644 1647 164b 164c 1651
1654 1659 165a 165f 1662 1666 166a 166d
1670 1671 1673 1674 1679 167a 167f 1681
1685 1688 168a 168e 1690 169c 169e 16a0
16a1 16a6 16aa 16ac 16b8 16ba 16be 16c2
16c5 16c6 16c8 16cb 16ce 16cf 16d4 16d8
16db 16df 16e3 16e6 16ea 16ee 16f3 16f7
16fb 16fe 16ff 1704 1707 170b 170f 1713
1717 171b 171f 172b 172f 1733 1736 173a
173e 1740 1 1744 1748 174c 174f 1753
1757 175b 175f 1762 1766 176a 176d 1770
1775 1778 177b 177e 177f 1784 1785 1
1787 178c 1790 1794 1797 179c 17a1 17a4
17a8 17a9 17ae 17b1 17b6 17b7 17bc 17bf
17c4 17c5 17ca 17cd 17d1 17d2 17d7 17da
17df 17e0 17e5 17e8 17ec 17f0 17f3 17f6
17f7 17f9 17fa 17ff 1800 1805 1807 180b
180e 1810 1814 1816 1822 1824 1826 1827
182c 1830 1832 183e 1840 1842 1846 1849
184b 184f 1852 1854 1858 185b 185f 1863
1866 1867 1869 186c 186f 1870 1875 1878
187c 1880 1884 1887 1888 188a 188b 188d
1890 1893 1896 1897 1 189c 18a1 18a5
18a8 18ac 18ae 18b2 18b5 18b7 18bb 18bf
18c3 18c7 18cb 18cf 18d3 18d7 18db 18df
18e3 18e7 18eb 18ef 18f3 18f7 18fb 18ff
1903 1907 190b 190f 1913 1917 191b 191f
192b 192f 1933 1936 193a 193e 1940 1
1944 1948 194c 194f 1953 1957 195b 195f
1962 1966 196a 196d 1970 1975 1978 197b
197e 197f 1984 1985 1 1987 198c 1990
1994 1997 199c 19a1 19a4 19a8 19a9 19ae
19b1 19b6 19b7 19bc 19bf 19c4 19c5 19ca
19cd 19d1 19d2 19d7 19da 19df 19e0 19e5
19e8 19ec 19f0 19f3 19f6 19f7 19f9 19fa
19ff 1a00 1a05 1a07 1a0b 1a0e 1a10 1a14
1a16 1a22 1a24 1a26 1a27 1a2c 1a30 1a32
1a3e 1a40 1a44 1a48 1a4b 1a4f 1a52 1a56
1a59 1a5a 1a5f 1a62 1a66 1a6a 1a6d 1a6e
1a70 1a74 1a77 1a7b 1a7e 1a7f 1a81 1a82
1a87 1 1a8a 1a8f 1a93 1a94 1a98 1a9c
1a9f 1aa2 1aa3 1aa8 1aac 1aae 1ab2 1ab5
1ab7 1abb 1abf 1ac2 1ac6 1aca 1acd 1ace
1ad0 1ad3 1ad6 1ad7 1adc 1ae0 1ae4 1ae7
1aea 1aed 1aee 1af3 1af7 1afb 1afe 1b02
1b06 1b09 1b0c 1b11 1b14 1b17 1b1a 1b1b
1b20 1b21 1 1b23 1b28 1b2c 1b30 1b33
1b38 1b3d 1b40 1b44 1b45 1b4a 1b4d 1b52
1b53 1b58 1b5b 1b60 1b61 1b66 1b69 1b6d
1b71 1b75 1b79 1b7c 1b7d 1b7f 1b84 1b85
1b87 1b88 1b8d 1b90 1b95 1b96 1b9b 1b9e
1ba3 1ba4 1ba9 1bac 1bb0 1bb1 1bb6 1bb9
1bbe 1bbf 1bc4 1bc5 1bca 1bcc 1bd0 1bd3
1bd7 1bdb 1bde 1be2 1be6 1be9 1bec 1bf1
1bf4 1bf7 1bfa 1bfb 1c00 1c01 1 1c03
1c08 1c0c 1c10 1c13 1c18 1c1d 1c20 1c24
1c25 1c2a 1c2b 1c30 1c32 1c36 1c39 1c3d
1c41 1c44 1c48 1c4c 1c4f 1c53 1c57 1c58
1c5d 1c5f 1c63 1c66 1c6a 1c6d 1c6e 1c73
1c76 1c7a 1c7d 1c7e 1c83 1 1c86 1c8b
1c8f 1c92 1c93 1c98 1 1c9b 1ca0 1ca4
1ca7 1ca8 1cad 1 1cb0 1cb5 1cb9 1cbd
1cc0 1cc4 1cc8 1ccb 1cce 1cd3 1cd6 1cd9
1cdc 1cdd 1ce2 1ce3 1 1ce5 1cea 1cee
1cf2 1cf5 1cfa 1cff 1d02 1d06 1d07 1d0c
1d0f 1d14 1d15 1d1a 1d1d 1d22 1d23 1d28
1d2b 1d2f 1d33 1d37 1d3b 1d3e 1d3f 1d41
1d46 1d47 1d49 1d4a 1d4f 1d50 1d55 1d57
1d5b 1d5e 1d62 1d66 1d69 1d6d 1d71 1d74
1d77 1d7c 1d7f 1d82 1d85 1d86 1d8b 1d8c
1 1d8e 1d93 1d97 1d9b 1d9e 1da3 1da8
1dab 1daf 1db0 1db5 1db6 1dbb 1dbd 1dc1
1dc4 1dc8 1dcc 1dcf 1dd3 1dd7 1dda 1dde
1ddf 1de4 1de6 1dea 1ded 1df1 1df5 1df9
1dfc 1e00 1e04 1e08 1e0b 1e0c 1e0e 1e11
1e14 1e15 1e1a 1e1e 1e21 1e25 1e27 1e2b
1e2e 1e32 1e36 1e3a 1e3e 1e42 1e46 1e52
1e56 1e5a 1e5d 1e61 1e65 1e67 1 1e6b
1e6f 1e73 1e76 1e7a 1e7e 1e82 1e86 1e89
1e8d 1e91 1e94 1e97 1e9c 1e9f 1ea2 1ea5
1ea6 1eab 1eac 1 1eae 1eb3 1eb7 1ebb
1ebe 1ec3 1ec8 1ecb 1ecf 1ed0 1ed5 1ed8
1edd 1ede 1ee3 1ee6 1eeb 1eec 1ef1 1ef4
1ef8 1ef9 1efe 1f01 1f06 1f07 1f0c 1f0f
1f13 1f17 1f1a 1f1d 1f1e 1f20 1f21 1f26
1f27 1f2c 1f2e 1f32 1f35 1f37 1f3b 1f3d
1f49 1f4b 1f4d 1f4e 1f53 1f57 1f59 1f65
1f67 1f6b 1f6f 1f72 1f73 1f75 1f78 1f7b
1f7c 1f81 1f85 1f89 1f8d 1f91 1f95 1f96
1f98 1f9b 1f9c 1f9e 1fa1 1fa5 1fa9 1fad
1fae 1fb0 1fb3 1fb4 1fb6 1fb7 1fbc 1fbf
1fc2 1fc5 1fc6 1fcb 1fce 1fd1 1fd4 1fd5
1fda 1fdb 1fdd 1fe1 1fe5 1fe9 1fec 1fed
1fef 1ff3 1ff6 1ffa 1ffd 1ffe 2000 2001
2006 200a 200d 2011 2015 2018 201c 201e
2022 2025 2029 202b 202f 2033 2036 2038
203c 203f 2043 2044 2048 204c 2050 2054
2057 2058 205a 205d 205e 2060 2063 2066
2069 206a 206f 2073 2077 207a 207b 207d
2080 2083 2084 2089 208d 2091 2094 2095
2097 209a 209d 209e 20a3 20a7 20ab 20ae
20b2 20b6 20ba 20be 20c2 20c6 20ca 20ce
20d2 20d6 20da 20de 20e2 20e6 20ea 20ee
20f2 20f6 20f7 20f9 20fd 2101 2105 2108
210b 210e 210f 2114 2118 211c 2120 2124
2128 212c 2130 2134 2138 213c 2140 2144
2148 214c 2150 215c 2160 2165 2169 216c
216d 2172 2176 217a 217d 2180 2184 2186
218a 218e 2191 2194 2198 219a 219e 21a2
21a5 21a7 1 21ab 21af 21b3 21b6 21ba
21be 21c2 21c6 21c9 21cd 21d1 21d4 21d7
21dc 21df 21e2 21e5 21e6 21eb 21ec 1
21ee 21f3 21f7 21fb 21fe 2203 2208 220b
220f 2210 2215 2218 221d 221e 2223 2226
222b 222c 2231 2234 2238 2239 223e 2241
2246 2247 224c 224f 2253 2257 225a 225d
225e 2260 2261 2266 2267 226c 226e 2272
2275 2277 227b 227d 2289 228b 228d 228e
2293 2297 2299 22a5 22a7 22a9 22ad 22b0
22b2 22b6 22ba 22bd 22c1 22c5 22c9 22cd
22d1 22d5 22d9 22dd 22e1 22e5 22e9 22ed
22f1 22f5 22f9 22fd 2301 2305 2306 2308
230c 230e 2312 2316 2319 231b 231f 2323
2327 232a 232b 232d 2330 2333 2334 2339
233d 2341 2345 2348 2349 234b 234e 2351
2352 2357 235b 235f 2362 2366 236a 236e
2372 2376 237a 237e 2382 2386 238a 238e
2392 2396 239a 239e 23a2 23a6 23aa 23ab
23ad 23b1 23b5 23b9 23bc 23bf 23c2 23c3
23c8 23cc 23d0 23d4 23d8 23dc 23e0 23e4
23e8 23ec 23f0 23f4 2400 2404 2409 240d
2410 2411 2416 241a 241e 2421 2424 2428
242a 242e 2432 2435 2438 243c 243e 2442
2446 2449 244b 1 244f 2453 2457 245a
245e 2462 2466 246a 246d 2471 2475 2478
247b 2480 2483 2486 2489 248a 248f 2490
1 2492 2497 249b 249f 24a2 24a7 24ac
24af 24b3 24b4 24b9 24bc 24c1 24c2 24c7
24ca 24cf 24d0 24d5 24d8 24dc 24dd 24e2
24e5 24ea 24eb 24f0 24f3 24f7 24fb 24fe
2501 2502 2504 2505 250a 250b 2510 2512
2516 2519 251b 251f 2521 252d 252f 2531
2532 2537 253b 253d 2549 254b 254d 2551
2554 2556 255a 255e 2561 2565 2569 256d
2571 2575 2579 257d 2581 2585 2589 258d
2591 2595 2599 259d 25a1 25a5 25a9 25aa
25ac 25b0 25b2 25b6 25ba 25bd 25bf 25c3
25c7 25ca 25ce 25d2 25d5 25d8 25db 25dc
25e1 25e4 25e8 25ec 25f0 25f3 25f4 25f6
25f9 25fa 25fc 25ff 2602 2605 2606 260b
1 260e 2613 2617 261b 261e 261f 2621
2625 2628 262c 262f 2630 2632 2633 2638
263b 263f 2643 2646 2647 2649 264c 264f
2650 2655 1 2658 265d 2661 2665 2668
2669 266b 266e 2671 2672 2677 1 267a
267f 2683 2687 268b 268f 2693 2697 269b
269f 26a3 26a7 26ab 26af 26b3 26b7 26bb
26bf 26c3 26c7 26cb 26cf 26d3 26d7 26db
26e7 26eb 26f0 26f4 26f7 26f8 26fd 2701
2705 2708 270b 270f 2711 2715 2719 271c
271f 2723 2725 2729 272d 2730 2732 1
2736 273a 273e 2741 2745 2749 274d 2751
2754 2758 275c 275f 2762 2767 276a 276d
2770 2771 2776 2777 1 2779 277e 2782
2786 2789 278e 2793 2796 279a 279b 27a0
27a3 27a8 27a9 27ae 27b1 27b6 27b7 27bc
27bf 27c3 27c4 27c9 27cc 27d1 27d2 27d7
27da 27de 27e2 27e5 27e8 27e9 27eb 27ec
27f1 27f2 27f7 27f9 27fd 2800 2802 2806
2808 2814 2816 2818 2819 281e 2822 2824
2830 2832 2836 283a 283e 2842 2846 284a
284e 2852 285e 2862 2867 286b 286e 286f
2874 2878 287c 287f 2882 2886 2888 288c
2890 2893 2896 289a 289c 28a0 28a4 28a7
28a9 1 28ad 28b1 28b5 28b8 28bc 28c0
28c4 28c8 28cb 28cf 28d3 28d6 28d9 28de
28e1 28e4 28e7 28e8 28ed 28ee 1 28f0
28f5 28f9 28fd 2900 2905 290a 290d 2911
2912 2917 291a 291f 2920 2925 2928 292d
292e 2933 2936 293a 293b 2940 2943 2948
2949 294e 2951 2955 2959 295c 295f 2960
2962 2963 2968 2969 296e 2970 2974 2977
2979 297d 297f 298b 298d 298f 2990 2995
2999 299b 29a7 29a9 29ad 29b1 29b5 29b9
29bd 29c9 29cd 29d2 29d6 29d9 29da 29df
29e3 29e7 29ea 29ed 29f1 29f3 29f7 29fb
29fe 2a01 2a05 2a07 2a0b 2a0f 2a12 2a14
1 2a18 2a1c 2a20 2a23 2a27 2a2b 2a2f
2a33 2a36 2a3a 2a3e 2a41 2a44 2a49 2a4c
2a4f 2a52 2a53 2a58 2a59 1 2a5b 2a60
2a64 2a68 2a6b 2a70 2a75 2a78 2a7c 2a7d
2a82 2a85 2a8a 2a8b 2a90 2a93 2a98 2a99
2a9e 2aa1 2aa5 2aa6 2aab 2aae 2ab3 2ab4
2ab9 2abc 2ac0 2ac4 2ac7 2aca 2acb 2acd
2ace 2ad3 2ad4 2ad9 2adb 2adf 2ae2 2ae4
2ae8 2aea 2af6 2af8 2afa 2afb 2b00 2b04
2b06 2b12 2b14 2b16 2b1a 2b1e 2b22 2b26
2b2a 2b2e 2b32 2b36 2b3a 2b3e 2b42 2b4e
2b52 2b57 2b5b 2b5e 2b5f 2b64 2b68 2b6c
2b6f 2b72 2b76 2b78 2b7c 2b80 2b83 2b86
2b8a 2b8c 2b90 2b94 2b97 2b99 1 2b9d
2ba1 2ba5 2ba8 2bac 2bb0 2bb4 2bb8 2bbb
2bbf 2bc3 2bc6 2bc9 2bce 2bd1 2bd4 2bd7
2bd8 2bdd 2bde 1 2be0 2be5 2be9 2bed
2bf0 2bf5 2bfa 2bfd 2c01 2c02 2c07 2c0a
2c0f 2c10 2c15 2c18 2c1d 2c1e 2c23 2c26
2c2a 2c2b 2c30 2c33 2c38 2c39 2c3e 2c41
2c45 2c49 2c4c 2c4f 2c50 2c52 2c53 2c58
2c59 2c5e 2c60 2c64 2c67 2c69 2c6d 2c6f
2c7b 2c7d 2c7f 2c80 2c85 2c89 2c8b 2c97
2c99 2c9b 2c9f 2ca3 2ca6 2ca8 2cac 2caf
2cb1 2cb5 2cb9 2cbd 2cc1 2cc4 2cc5 2cc7
2ccb 2ccf 2cd2 2cd3 2cd5 2cd9 2cdd 2ce1
2ce4 2ce5 2ce7 2cea 2ced 2cee 2cf3 2cf7
2cfb 2cfe 2d02 2d06 2d0a 2d0e 2d12 2d16
2d1a 2d1e 2d22 2d26 2d2a 2d2e 2d32 2d36
2d3a 2d3e 2d42 2d46 2d47 2d49 2d4d 2d51
2d55 2d58 2d5b 2d5e 2d5f 2d64 2d67 2d6b
2d6f 2d72 2d73 2d75 2d78 2d7b 2d7c 2d81
1 2d84 2d89 2d8d 2d91 2d94 2d95 2d97
2d9a 2d9d 2d9e 2da3 1 2da6 2dab 2daf
2db3 2db7 2dbb 2dbf 2dc3 2dc7 2dcb 2dcf
2dd3 2dd7 2ddb 2ddf 2de3 2de7 2df3 2df7
2dfc 2e00 2e03 2e04 2e09 2e0d 2e11 2e14
2e17 2e1b 2e1d 2e21 2e25 2e28 2e2b 2e2f
2e31 2e35 2e39 2e3c 2e3e 1 2e42 2e46
2e4a 2e4d 2e51 2e55 2e59 2e5d 2e60 2e64
2e68 2e6b 2e6e 2e73 2e76 2e79 2e7c 2e7d
2e82 2e83 1 2e85 2e8a 2e8e 2e92 2e95
2e9a 2e9f 2ea2 2ea6 2ea7 2eac 2eaf 2eb4
2eb5 2eba 2ebd 2ec2 2ec3 2ec8 2ecb 2ecf
2ed0 2ed5 2ed8 2edd 2ede 2ee3 2ee6 2eea
2eee 2ef1 2ef4 2ef5 2ef7 2ef8 2efd 2efe
2f03 2f05 2f09 2f0c 2f0e 2f12 2f14 2f20
2f22 2f24 2f25 2f2a 2f2e 2f30 2f3c 2f3e
2f40 2f44 2f47 2f49 2f4d 2f50 2f51 2f56
2f59 2f5d 2f61 2f65 2f69 2f6d 2f71 2f75
2f79 2f7d 2f81 2f85 2f89 2f8d 2f99 2f9d
2fa1 2fa4 2fa8 2fac 2fae 1 2fb2 2fb6
2fba 2fbd 2fc1 2fc5 2fc9 2fcd 2fd0 2fd4
2fd8 2fdb 2fde 2fe3 2fe6 2fe9 2fec 2fed
2ff2 2ff3 1 2ff5 2ffa 2ffe 3002 3005
300a 300f 3012 3016 3017 301c 301f 3024
3025 302a 302d 3032 3033 3038 303b 303f
3040 3045 3048 304d 304e 3053 3056 305a
305e 3061 3064 3065 3067 3068 306d 306e
3073 3075 3079 307c 307e 3082 3084 3090
3092 3094 3095 309a 309e 30a0 30ac 30ae
30b2 30b6 30b9 30bd 30c1 30c4 30c5 30c7
30ca 30cd 30ce 30d3 30d7 30db 30df 30e2
30e6 30ea 30ed 30f1 30f5 30f9 30fd 3101
310d 3111 3115 3118 311c 3120 3122 1
3126 312a 312e 3131 3135 3139 313d 3141
3144 3148 314c 314f 3152 3157 315a 315d
3160 3161 3166 3167 1 3169 316e 3172
3176 3179 317e 3183 3186 318a 318b 3190
3193 3198 3199 319e 31a1 31a6 31a7 31ac
31af 31b3 31b4 31b9 31bc 31c1 31c2 31c7
31ca 31ce 31d2 31d5 31d8 31d9 31db 31dc
31e1 31e2 31e7 31e9 31ed 31f0 31f2 31f6
31f8 3204 3206 3208 3209 320e 3212 3214
3220 3222 3226 322a 322e 3232 3236 323a
323e 3242 3243 3245 3249 324d 3251 3254
3255 3257 325a 325d 325e 3263 3267 3268
326c 3270 3271 3275 3279 327a 327e 3282
3283 3287 328b 328c 3290 3294 3298 329d
32a1 32a2 32a6 32aa 32ae 32b3 32b8 32bc
32c0 32c4 32c9 32cd 32d1 32d4 32d7 32db
32dd 32e1 32e5 32e8 32eb 32ef 32f1 32f5
32f9 32fc 3300 3304 3309 330b 330f 3313
3316 331a 331e 3320 1 3324 3328 332c
332f 3333 3337 333b 333f 3342 3346 334a
334d 3350 3355 3358 335b 335e 335f 3364
3365 1 3367 336c 3370 3374 3377 337c
3381 3384 3388 3389 338e 3391 3396 3397
339c 339f 33a4 33a5 33aa 33ad 33b1 33b2
33b7 33ba 33bf 33c0 33c5 33c8 33cc 33d0
33d3 33d6 33d7 33d9 33da 33df 33e0 33e5
33e7 33eb 33ee 33f0 33f4 33f6 3402 3404
3406 3407 340c 3410 3412 341e 3420 3424
3428 342c 3430 3434 3440 3444 3448 344b
344f 3453 3455 1 3459 345d 3461 3464
3468 346c 3470 3474 3477 347b 347f 3482
3485 348a 348d 3490 3493 3494 3499 349a
1 349c 34a1 34a5 34a9 34ac 34b1 34b6
34b9 34bd 34be 34c3 34c6 34cb 34cc 34d1
34d4 34d9 34da 34df 34e2 34e6 34e7 34ec
34ef 34f4 34f5 34fa 34fd 3501 3505 3508
350b 350c 350e 350f 3514 3515 351a 351c
3520 3523 3525 3529 352b 3537 3539 353b
353c 3541 3545 3547 3553 3555 3559 355e
3562 3566 356b 356f 3573 3577 357b 357e
3582 3583 3588 358b 358e 358f 3591 3595
3599 359d 35a1 35a4 35a9 35aa 35af 35b2
35b5 35b6 35b8 35bc 35c0 35c4 35c8 35cb
35cf 35d0 35d5 35d8 35db 35dc 35de 35e2
35e6 35ea 35ee 35f1 35f6 35f7 35fc 35ff
3602 3603 3605 3609 360d 3611 3615 3619
361d 3621 3625 3629 362d 3631 3635 3639
363d 3641 3645 3649 364d 364e 3650 3654
3658 365c 365f 3663 3667 366a 366d 3672
3675 3678 367b 367c 3681 3682 1 3684
3689 368d 3691 3694 3699 369e 36a1 36a5
36a6 36ab 36ae 36b3 36b4 36b9 36bc 36c1
36c2 36c7 36ca 36ce 36d2 36d5 36d6 36d8
36dd 36de 36e0 36e1 36e6 36e9 36ee 36ef
36f4 36f7 36fc 36fd 3702 3705 3709 370a
370f 3712 3717 3718 371d 371e 3723 3725
3729 372c 3730 3734 3737 373b 373f 3742
3745 374a 374d 3750 3753 3754 3759 375a
1 375c 3761 3765 3769 376c 3771 3776
3779 377d 377e 3783 3784 3789 378b 378f
3792 3796 379a 379d 37a0 37a4 37a8 37a9
37ae 37b0 37b4 37b7 37b9 37bd 37c0 37c2
37c6 37c9 37cd 37d1 37d5 37d8 37d9 37db
37de 37e1 37e2 37e7 37eb 37ef 37f3 37f6
37fa 37fe 3802 3806 380a 380e 3812 3816
381a 381e 3822 3826 382a 382e 3832 3836
383a 383e 383f 3841 3845 3849 384d 3850
3853 3856 3857 385c 385f 3863 3867 386a
386b 386d 3870 3873 3874 3879 1 387c
3881 3885 3889 388c 388d 388f 3892 3895
3896 389b 1 389e 38a3 38a7 38ab 38af
38b3 38b7 38bb 38bf 38c3 38c7 38cb 38cf
38db 38df 38e4 38e8 38eb 38ec 38f1 38f5
38f9 38fc 38ff 3903 3905 3909 390d 3910
3913 3917 3919 391d 3921 3924 3926 1
392a 392e 3932 3935 3939 393d 3941 3945
3948 394c 3950 3953 3956 395b 395e 3961
3964 3965 396a 396b 1 396d 3972 3976
397a 397d 3982 3987 398a 398e 398f 3994
3997 399c 399d 39a2 39a5 39aa 39ab 39b0
39b3 39b7 39b8 39bd 39c0 39c5 39c6 39cb
39ce 39d2 39d6 39d9 39dc 39dd 39df 39e0
39e5 39e6 39eb 39ed 39f1 39f4 39f6 39fa
39fc 3a08 3a0a 3a0c 3a0d 3a12 3a16 3a18
3a24 3a26 3a28 3a2c 3a2f 3a31 3a35 3a39
3a3c 3a3e 3a42 3a46 3a49 3a4d 3a51 3a54
3a57 3a5a 3a5b 3a60 3a64 3a68 3a6b 3a6f
3a73 3a76 3a79 3a7e 3a81 3a84 3a87 3a88
3a8d 3a8e 1 3a90 3a95 3a99 3a9d 3aa0
3aa5 3aaa 3aad 3ab1 3ab2 3ab7 3aba 3abf
3ac0 3ac5 3ac8 3acd 3ace 3ad3 3ad6 3ada
3ade 3ae2 3ae6 3ae9 3aea 3aec 3af1 3af2
3af4 3af5 3afa 3afd 3b02 3b03 3b08 3b0b
3b10 3b11 3b16 3b19 3b1d 3b1e 3b23 3b26
3b2b 3b2c 3b31 3b32 3b37 3b39 3b3d 3b40
3b44 3b48 3b4b 3b4f 3b53 3b56 3b59 3b5e
3b61 3b64 3b67 3b68 3b6d 3b6e 1 3b70
3b75 3b79 3b7d 3b80 3b85 3b8a 3b8d 3b91
3b92 3b97 3b98 3b9d 3b9f 3ba3 3ba6 3baa
3bae 3bb1 3bb5 3bb9 3bbc 3bc0 3bc4 3bc5
3bca 3bcc 3bd0 3bd3 3bd7 3bdb 3bdf 3be3
3be7 3bea 3beb 3bed 3bf0 3bf3 3bf4 3bf9
3bfc 3c00 3c04 3c07 3c08 3c0a 3c0d 3c10
3c11 3c16 1 3c19 3c1e 3c22 3c25 3c29
3c2b 3c2f 3c32 3c36 3c3a 3c3d 3c3e 3c40
3c43 3c46 3c47 3c4c 3c50 3c54 3c58 3c5b
3c5c 3c5e 3c61 3c62 3c64 3c67 3c6a 3c6d
3c6e 3c73 3c77 3c7a 3c7b 3c80 3c83 3c87
3c8a 3c8b 3c90 3c93 3c97 3c9b 3c9f 3ca3
3ca7 3cab 3caf 3cb3 3cb7 3cbb 3cbf 3cc3
3cc7 3ccb 3ccf 3cd3 3cd7 3cdb 3cdf 3ce3
3ce7 3cf3 3cf7 3cfc 3d00 3d03 3d04 3d09
3d0d 3d11 3d14 3d17 3d1b 3d1d 3d21 3d25
3d28 3d2b 3d2f 3d31 3d35 3d39 3d3c 3d3e
1 3d42 3d46 3d4a 3d4d 3d51 3d55 3d59
3d5d 3d60 3d64 3d68 3d6b 3d6e 3d73 3d76
3d79 3d7c 3d7d 3d82 3d83 1 3d85 3d8a
3d8e 3d92 3d95 3d9a 3d9f 3da2 3da6 3da7
3dac 3daf 3db4 3db5 3dba 3dbd 3dc2 3dc3
3dc8 3dcb 3dcf 3dd0 3dd5 3dd8 3ddd 3dde
3de3 3de6 3dea 3dee 3df1 3df4 3df5 3df7
3df8 3dfd 3dfe 3e03 3e05 3e09 3e0c 3e0e
3e12 3e14 3e20 3e22 3e24 3e25 3e2a 3e2e
3e30 3e3c 3e3e 3e40 3e44 3e48 3e4c 3e50
3e54 3e58 3e5c 3e60 3e64 3e70 3e74 3e79
3e7d 3e80 3e81 3e86 3e8a 3e8e 3e91 3e94
3e98 3e9a 3e9e 3ea2 3ea5 3ea8 3eac 3eae
3eb2 3eb6 3eb9 3ebb 1 3ebf 3ec3 3ec7
3eca 3ece 3ed2 3ed6 3eda 3edd 3ee1 3ee5
3ee8 3eeb 3ef0 3ef3 3ef6 3ef9 3efa 3eff
3f00 1 3f02 3f07 3f0b 3f0f 3f12 3f17
3f1c 3f1f 3f23 3f24 3f29 3f2c 3f31 3f32
3f37 3f3a 3f3f 3f40 3f45 3f48 3f4c 3f4d
3f52 3f55 3f5a 3f5b 3f60 3f63 3f67 3f6b
3f6e 3f71 3f72 3f74 3f75 3f7a 3f7b 3f80
3f82 3f86 3f89 3f8b 3f8f 3f91 3f9d 3f9f
3fa1 3fa2 3fa7 3fab 3fad 3fb9 3fbb 3fbd
3fc1 3fc5 3fc8 3fca 3fce 3fd1 3fd2 3fd7
3fda 3fde 3fe2 3fe6 3fea 3fee 3ff2 3ff6
3ffa 3ffe 4002 4006 400a 400e 4012 4016
401a 401e 4022 4026 402a 402e 4032 4036
403a 403e 4042 4046 404a 404e 4052 4056
405a 405e 4062 4066 406a 406e 4072 4076
407a 407e 4082 4086 408a 408e 4092 4096
409a 409e 40a2 40a6 40aa 40ae 40b2 40b6
40ba 40be 40c2 40c6 40ca 40ce 40d2 40d6
40da 40e6 40ea 40ef 40f3 40f6 40f7 40fc
4100 4104 4107 410a 410e 4110 4114 4118
411b 411e 4122 4124 4128 412c 412f 4131
1 4135 4139 413d 4140 4144 4148 414c
4150 4153 4157 415b 415e 4161 4166 4169
416c 416f 4170 4175 4176 1 4178 417d
4181 4185 4188 418d 4192 4195 4199 419a
419f 41a2 41a7 41a8 41ad 41b0 41b5 41b6
41bb 41be 41c2 41c3 41c8 41cb 41d0 41d1
41d6 41d9 41dd 41e1 41e4 41e7 41e8 41ea
41eb 41f0 41f1 41f6 41f8 41fc 41ff 4201
4205 4207 4213 4215 4217 4218 421d 4221
4223 422f 4231 4233 4237 423b 423f 4243
4247 424b 424f 4253 4257 425b 425f 4263
4267 426b 426f 4273 4277 427b 427f 4283
4287 428b 428f 4293 4297 429b 429f 42a3
42a7 42ab 42af 42b3 42b7 42bb 42bf 42c3
42c7 42cb 42cf 42d3 42d7 42db 42df 42e3
42e7 42eb 42ef 42f3 42f7 42fb 42ff 4303
430f 4313 4318 431c 431f 4320 4325 4329
432d 4330 4333 4337 4339 433d 4341 4344
4347 434b 434d 4351 4355 4358 435a 1
435e 4362 4366 4369 436d 4371 4375 4379
437c 4380 4384 4387 438a 438f 4392 4395
4398 4399 439e 439f 1 43a1 43a6 43aa
43ae 43b1 43b6 43bb 43be 43c2 43c3 43c8
43cb 43d0 43d1 43d6 43d9 43de 43df 43e4
43e7 43eb 43ec 43f1 43f4 43f9 43fa 43ff
4402 4406 440a 440d 4410 4411 4413 4414
4419 441a 441f 4421 4425 4428 442a 442e
4430 443c 443e 4440 4441 4446 444a 444c
4458 445a 445c 4460 4464 4467 4469 446d
4471 4474 4478 447a 447e 4482 4485 4486
4488 448b 448e 448f 4494 4498 449c 44a0
44a4 44a8 44ac 44b0 44b4 44b8 44c4 44c8
44cd 44d1 44d4 44d5 44da 44de 44e2 44e5
44e8 44ec 44ee 44f2 44f6 44f9 44fc 4500
4502 4506 450a 450d 450f 1 4513 4517
451b 451e 4522 4526 452a 452e 4531 4535
4539 453c 453f 4544 4547 454a 454d 454e
4553 4554 1 4556 455b 455f 4563 4566
456b 4570 4573 4577 4578 457d 4580 4585
4586 458b 458e 4593 4594 4599 459c 45a0
45a1 45a6 45a9 45ae 45af 45b4 45b7 45bb
45bf 45c2 45c5 45c6 45c8 45c9 45ce 45cf
45d4 45d6 45da 45dd 45df 45e3 45e5 45f1
45f3 45f5 45f6 45fb 45ff 4601 460d 460f
4611 4615 4619 461c 461e 4622 4626 462a
462d 462e 4630 4633 4634 4636 4639 463c
463f 4640 4645 4649 464c 464d 4652 4655
4659 465c 465d 4662 4665 4669 466d 4671
4675 4679 467d 4681 4685 4689 468d 4691
4695 4699 469d 46a1 46a5 46a9 46ad 46b1
46b5 46b9 46c5 46c9 46ce 46d2 46d5 46d6
46db 46df 46e3 46e6 46e9 46ed 46ef 46f3
46f7 46fa 46fd 4701 4703 4707 470b 470e
4710 1 4714 4718 471c 471f 4723 4727
472b 472f 4732 4736 473a 473d 4740 4745
4748 474b 474e 474f 4754 4755 1 4757
475c 4760 4764 4767 476c 4771 4774 4778
4779 477e 4781 4786 4787 478c 478f 4794
4795 479a 479d 47a1 47a2 47a7 47aa 47af
47b0 47b5 47b8 47bc 47c0 47c3 47c6 47c7
47c9 47ca 47cf 47d0 47d5 47d7 47db 47de
47e0 47e4 47e6 47f2 47f4 47f6 47f7 47fc
4800 4802 480e 4810 4812 4816 481a 481e
4822 4826 482a 482e 4832 4836 483a 483e
484a 484e 4853 4857 485a 485b 4860 4864
4868 486b 486e 4872 4874 4878 487c 487f
4882 4886 4888 488c 4890 4893 4895 1
4899 489d 48a1 48a4 48a8 48ac 48b0 48b4
48b7 48bb 48bf 48c2 48c5 48ca 48cd 48d0
48d3 48d4 48d9 48da 1 48dc 48e1 48e5
48e9 48ec 48f1 48f6 48f9 48fd 48fe 4903
4906 490b 490c 4911 4914 4919 491a 491f
4922 4926 4927 492c 492f 4934 4935 493a
493d 4941 4945 4948 494b 494c 494e 494f
4954 4955 495a 495c 4960 4963 4965 4969
496b 4977 4979 497b 497c 4981 4985 4987
4993 4995 4997 499b 499f 49a2 49a4 49a8
49ab 49ac 49b1 49b4 49b8 49bc 49c0 49c4
49c8 49cc 49d0 49d4 49d8 49dc 49e0 49e4
49e8 49ec 49f0 49f4 49f8 49fc 4a00 4a04
4a08 4a0c 4a10 4a14 4a18 4a1c 4a20 4a24
4a28 4a2c 4a30 4a34 4a38 4a3c 4a40 4a44
4a48 4a4c 4a50 4a54 4a58 4a5c 4a60 4a64
4a68 4a6c 4a70 4a74 4a78 4a7c 4a80 4a84
4a88 4a8c 4a90 4a94 4a98 4a9c 4aa0 4aa4
4aa8 4aac 4ab0 4ab4 4ac0 4ac4 4ac9 4acd
4ad0 4ad1 4ad6 4ada 4ade 4ae1 4ae4 4ae8
4aea 4aee 4af2 4af5 4af8 4afc 4afe 4b02
4b06 4b09 4b0b 1 4b0f 4b13 4b17 4b1a
4b1e 4b22 4b26 4b2a 4b2d 4b31 4b35 4b38
4b3b 4b40 4b43 4b46 4b49 4b4a 4b4f 4b50
1 4b52 4b57 4b5b 4b5f 4b62 4b67 4b6c
4b6f 4b73 4b74 4b79 4b7c 4b81 4b82 4b87
4b8a 4b8f 4b90 4b95 4b98 4b9c 4b9d 4ba2
4ba5 4baa 4bab 4bb0 4bb3 4bb7 4bbb 4bbe
4bc1 4bc2 4bc4 4bc5 4bca 4bcb 4bd0 4bd2
4bd6 4bd9 4bdb 4bdf 4be1 4bed 4bef 4bf1
4bf2 4bf7 4bfb 4bfd 4c09 4c0b 4c0d 4c11
4c15 4c19 4c1d 4c21 4c25 4c29 4c2d 4c31
4c35 4c39 4c3d 4c41 4c45 4c49 4c4d 4c51
4c55 4c59 4c5d 4c61 4c65 4c69 4c6d 4c71
4c75 4c79 4c7d 4c81 4c85 4c89 4c8d 4c91
4c95 4c99 4c9d 4ca1 4ca5 4ca9 4cad 4cb1
4cb5 4cb9 4cbd 4cc1 4cc5 4cc9 4ccd 4cd1
4cd5 4cd9 4cdd 4ce1 4ce5 4cf1 4cf5 4cfa
4cfe 4d01 4d02 4d07 4d0b 4d0f 4d12 4d15
4d19 4d1b 4d1f 4d23 4d26 4d29 4d2d 4d2f
4d33 4d37 4d3a 4d3c 1 4d40 4d44 4d48
4d4b 4d4f 4d53 4d57 4d5b 4d5e 4d62 4d66
4d69 4d6c 4d71 4d74 4d77 4d7a 4d7b 4d80
4d81 1 4d83 4d88 4d8c 4d90 4d93 4d98
4d9d 4da0 4da4 4da5 4daa 4dad 4db2 4db3
4db8 4dbb 4dc0 4dc1 4dc6 4dc9 4dcd 4dce
4dd3 4dd6 4ddb 4ddc 4de1 4de4 4de8 4dec
4def 4df2 4df3 4df5 4df6 4dfb 4dfc 4e01
4e03 4e07 4e0a 4e0c 4e10 4e12 4e1e 4e20
4e22 4e23 4e28 4e2c 4e2e 4e3a 4e3c 4e3e
4e42 4e46 4e49 4e4b 4e4f 4e53 4e56 4e5a
4e5c 4e60 4e64 4e67 4e68 4e6a 4e6d 4e70
4e71 4e76 4e7a 4e7d 4e7e 4e83 4e86 4e8a
4e8e 4e91 4e92 4e94 4e97 4e9a 4e9b 4ea0
4ea4 4ea8 4eac 4eb0 4eb4 4eb8 4ebc 4ec0
4ec4 4ec8 4ecc 4ed0 4ed4 4ed8 4ee4 4ee8
4eed 4ef1 4ef4 4ef5 4efa 4efe 4f02 4f05
4f08 4f0c 4f0e 4f12 4f16 4f19 4f1c 4f20
4f22 4f26 4f2a 4f2d 4f2f 1 4f33 4f37
4f3b 4f3e 4f42 4f46 4f4a 4f4e 4f51 4f55
4f59 4f5c 4f5f 4f64 4f67 4f6a 4f6d 4f6e
4f73 4f74 1 4f76 4f7b 4f7f 4f83 4f86
4f8b 4f90 4f93 4f97 4f98 4f9d 4fa0 4fa5
4fa6 4fab 4fae 4fb3 4fb4 4fb9 4fbc 4fc0
4fc1 4fc6 4fc9 4fce 4fcf 4fd4 4fd7 4fdb
4fdf 4fe2 4fe5 4fe6 4fe8 4fe9 4fee 4fef
4ff4 4ff6 4ffa 4ffd 4fff 5003 5005 5011
5013 5015 5016 501b 501f 5021 502d 502f
5031 5035 5039 503d 5041 5045 5049 504d
5051 5055 5059 505d 5069 506d 5072 5076
5079 507a 507f 5083 5087 508a 508d 5091
5093 5097 509b 509e 50a1 50a5 50a7 50ab
50af 50b2 50b4 1 50b8 50bc 50c0 50c3
50c7 50cb 50cf 50d3 50d6 50da 50de 50e1
50e4 50e9 50ec 50ef 50f2 50f3 50f8 50f9
1 50fb 5100 5104 5108 510b 5110 5115
5118 511c 511d 5122 5125 512a 512b 5130
5133 5138 5139 513e 5141 5145 5146 514b
514e 5153 5154 5159 515c 5160 5164 5167
516a 516b 516d 516e 5173 5174 5179 517b
517f 5182 5184 5188 518a 5196 5198 519a
519b 51a0 51a4 51a6 51b2 51b4 51b6 51ba
51be 51c1 51c3 51c7 51cb 51cf 51d3 51d7
51db 51df 51e3 51e7 51eb 51ef 51fb 51ff
5204 5208 520b 520c 5211 5215 5219 521c
521f 5223 5225 5229 522d 5230 5233 5237
5239 523d 5241 5244 5246 1 524a 524e
5252 5255 5259 525d 5261 5265 5268 526c
5270 5273 5276 527b 527e 5281 5284 5285
528a 528b 1 528d 5292 5296 529a 529d
52a2 52a7 52aa 52ae 52af 52b4 52b7 52bc
52bd 52c2 52c5 52ca 52cb 52d0 52d3 52d7
52d8 52dd 52e0 52e5 52e6 52eb 52ee 52f2
52f6 52f9 52fc 52fd 52ff 5300 5305 5306
530b 530d 5311 5314 5316 531a 531c 5328
532a 532c 532d 5332 5336 5338 5344 5346
5348 534c 5350 5353 5355 5359 535d 5360
5362 5366 536a 536d 5371 5374 5375 537a
537d 5381 5385 5388 5389 538b 538e 5391
5392 5397 1 539a 539f 53a2 53a6 53aa
53ad 53ae 53b0 53b3 53b6 53b7 53bc 1
53bf 53c4 53c8 53cd 53d1 53d5 53d6 53da
53de 53e1 53e5 53e9 53ec 53f0 53f4 53f8
53fb 53fc 53fe 5401 5404 5405 540a 540e
5412 5416 541a 541e 5422 5426 542a 542e
5432 5436 543a 543e 5442 5446 544a 544e
5452 5456 545a 545e 5462 5466 546a 546e
547a 547e 5482 5485 5489 548d 548f 1
5493 5497 549b 549e 54a2 54a6 54aa 54ae
54b1 54b5 54b9 54bc 54bf 54c4 54c7 54ca
54cd 54ce 54d3 54d4 1 54d6 54db 54df
54e3 54e6 54eb 54f0 54f3 54f7 54f8 54fd
5500 5505 5506 550b 550e 5513 5514 5519
551c 5520 5521 5526 5529 552e 552f 5534
5537 553b 553f 5542 5545 5546 5548 5549
554e 554f 5554 5556 555a 555d 555f 5563
5565 5571 5573 5575 5576 557b 557f 5581
558d 558f 5591 5595 5599 559d 55a1 55a5
55a9 55ad 55b1 55b5 55b9 55bd 55c1 55c5
55c9 55cd 55d1 55d5 55d9 55dd 55e1 55e5
55e9 55ed 55f1 55f5 55f9 5605 5609 560d
5610 5614 5618 561a 1 561e 5622 5626
5629 562d 5631 5635 5639 563c 5640 5644
5647 564a 564f 5652 5655 5658 5659 565e
565f 1 5661 5666 566a 566e 5671 5676
567b 567e 5682 5683 5688 568b 5690 5691
5696 5699 569e 569f 56a4 56a7 56ab 56ac
56b1 56b4 56b9 56ba 56bf 56c2 56c6 56ca
56cd 56d0 56d1 56d3 56d4 56d9 56da 56df
56e1 56e5 56e8 56ea 56ee 56f0 56fc 56fe
5700 5701 5706 570a 570c 5718 571a 571c
5720 5724 5727 572b 572f 5732 5736 5739
573d 5740 5741 5746 5749 574d 5751 5754
5755 5757 575b 575e 5762 5765 5766 5768
5769 576e 5771 5775 5779 577c 577d 577f
5782 5785 5786 578b 1 578e 5793 5797
579b 579e 579f 57a1 57a4 57a7 57a8 57ad
1 57b0 57b5 57b9 57bd 57c1 57c5 57c9
57cd 57d1 57d5 57e1 57e5 57ea 57ee 57f1
57f2 57f7 57fb 57ff 5802 5805 5809 580b
580f 5813 5816 5819 581d 581f 5823 5827
582a 582c 1 5830 5834 5838 583b 583f
5843 5847 584b 584e 5852 5856 5859 585c
5861 5864 5867 586a 586b 5870 5871 1
5873 5878 587c 5880 5883 5888 588d 5890
5894 5895 589a 589d 58a2 58a3 58a8 58ab
58b0 58b1 58b6 58b9 58bd 58be 58c3 58c6
58cb 58cc 58d1 58d4 58d8 58dc 58df 58e2
58e3 58e5 58e6 58eb 58ec 58f1 58f3 58f7
58fa 58fc 5900 5902 590e 5910 5912 5913
5918 591c 591e 592a 592c 5930 5934 5938
593c 5940 5944 5948 594c 5950 5954 5958
595c 5960 596c 5970 5975 5979 597c 597d
5982 5986 598a 598d 5990 5994 5996 599a
599e 59a1 59a4 59a8 59aa 59ae 59b2 59b5
59b7 1 59bb 59bf 59c3 59c6 59ca 59ce
59d2 59d6 59d9 59dd 59e1 59e4 59e7 59ec
59ef 59f2 59f5 59f6 59fb 59fc 1 59fe
5a03 5a07 5a0b 5a0e 5a13 5a18 5a1b 5a1f
5a20 5a25 5a28 5a2d 5a2e 5a33 5a36 5a3b
5a3c 5a41 5a44 5a48 5a49 5a4e 5a51 5a56
5a57 5a5c 5a5f 5a63 5a67 5a6a 5a6d 5a6e
5a70 5a71 5a76 5a77 5a7c 5a7e 5a82 5a85
5a87 5a8b 5a8d 5a99 5a9b 5a9d 5a9e 5aa3
5aa7 5aa9 5ab5 5ab7 5ab9 5abd 5ac1 5ac6
5aca 5acb 5acf 5ad3 5ad7 5adb 5adf 5ae4
5ae9 5aed 5af1 5af5 5afa 5afe 5b02 5b05
5b08 5b0c 5b0e 5b12 5b16 5b19 5b1c 5b20
5b22 5b26 5b2a 5b2d 5b31 5b35 5b38 5b3b
5b3e 5b3f 5b44 5b48 5b4e 5b50 5b54 5b57
5b5b 5b5f 5b63 5b66 5b67 5b69 5b6c 5b70
5b74 5b77 5b78 5b7a 5b7b 5b80 5b84 5b88
5b8c 5b8f 5b90 5b92 5b95 5b98 5b99 5b9e
5ba2 5ba6 5ba9 5baa 5bac 5bb0 5bb3 5bb7
5bba 5bbb 5bbd 5bbe 5bc3 5bc7 5bcb 5bce
5bcf 5bd1 5bd5 5bd8 5bdc 5bdf 5be0 5be2
5be3 5be8 5bec 5bf0 5bf4 5bf7 5bf8 5bfa
5bfe 5c00 5c04 5c08 5c0c 5c0f 5c10 5c12
5c15 5c19 5c1d 5c20 5c21 5c23 5c24 5c29
5c2c 5c30 5c34 5c37 5c38 5c3a 5c3b 5c40
5c44 5c46 5c4a 5c4e 5c51 5c53 5c57 5c5a
5c5e 5c62 5c66 5c6a 5c6e 5c7a 5c7e 5c83
5c87 5c8a 5c8b 5c90 5c94 5c98 5c9b 5c9e
5ca2 5ca4 5ca8 5cac 5caf 5cb2 5cb6 5cb8
5cbc 5cc0 5cc3 5cc5 1 5cc9 5ccd 5cd1
5cd4 5cd8 5cdc 5ce0 5ce4 5ce7 5ceb 5cef
5cf2 5cf5 5cfa 5cfd 5d00 5d03 5d04 5d09
5d0a 1 5d0c 5d11 5d15 5d19 5d1c 5d21
5d26 5d29 5d2d 5d2e 5d33 5d36 5d3b 5d3c
5d41 5d44 5d49 5d4a 5d4f 5d52 5d56 5d57
5d5c 5d5f 5d64 5d65 5d6a 5d6d 5d71 5d75
5d78 5d7b 5d7c 5d7e 5d7f 5d84 5d85 5d8a
5d8c 5d90 5d93 5d95 5d99 5d9b 5da7 5da9
5dab 5dac 5db1 5db5 5db7 5dc3 5dc5 5dc9
5dcd 5dd1 5dd3 5dd7 5dda 5dde 5de2 5de5
5de6 5de8 5dec 5def 5df3 5df6 5df7 5df9
5dfa 5dff 5e03 5e09 5e0b 5e0f 5e12 5e14
5e18 5e1f 5e23 5e27 5e2c 5e2e 5e32 5e36
5e39 5e3d 5e41 5e43 1 5e47 5e4b 5e4f
5e52 5e56 5e5a 5e5e 5e62 5e65 5e69 5e6d
5e70 5e73 5e78 5e7b 5e7e 5e81 5e82 5e87
5e88 1 5e8a 5e8f 5e93 5e97 5e9a 5e9f
5ea4 5ea7 5eab 5eac 5eb1 5eb4 5eb9 5eba
5ebf 5ec2 5ec7 5ec8 5ecd 5ed0 5ed4 5ed5
5eda 5edd 5ee2 5ee3 5ee8 5eeb 5eef 5ef3
5ef6 5ef9 5efa 5efc 5efd 5f02 5f03 5f08
5f0a 5f0e 5f11 5f13 5f17 5f19 5f25 5f27
5f29 5f2a 5f2f 5f33 5f35 5f41 5f43 5f47
5f4b 5f4e 5f4f 5f51 5f54 5f57 5f58 5f5d
5f60 5f64 5f67 5f68 5f6d 5f70 1 5f73
5f78 5f7c 5f80 5f84 5f88 5f8c 5f98 5f9c
5fa1 5fa5 5fa8 5fa9 5fae 5fb2 5fb6 5fb9
5fbc 5fc0 5fc2 5fc6 5fca 5fcd 5fd0 5fd4
5fd6 5fda 5fde 5fe1 5fe3 1 5fe7 5feb
5fef 5ff2 5ff6 5ffa 5ffe 6002 6005 6009
600d 6010 6013 6018 601b 601e 6021 6022
6027 6028 1 602a 602f 6033 6037 603a
603f 6044 6047 604b 604c 6051 6054 6059
605a 605f 6062 6067 6068 606d 6070 6074
6075 607a 607d 6082 6083 6088 608b 608f
6093 6096 6099 609a 609c 609d 60a2 60a3
60a8 60aa 60ae 60b1 60b3 60b7 60b9 60c5
60c7 60c9 60ca 60cf 60d3 60d5 60e1 60e3
60e5 60e9 60ec 60ee 60f2 60f6 60f9 60fd
6101 6104 6105 6107 610a 610d 610e 6113
6117 611b 611f 6122 6123 6125 6128 6129
612b 612e 6131 6134 6135 613a 613e 6142
6146 614a 614b 614d 6151 6153 6157 615b
615f 6163 6164 6166 616a 616c 6170 6174
6177 6179 617d 6180 6182 6186 6189 618b
618f 6192 6194 6198 619b 619f 61a3 61a6
61a9 61ac 61ad 61b2 61b6 61ba 61bd 61c0
61c4 61c6 61ca 61cd 61cf 61d3 61d6 61da
61de 61e1 61e5 61e9 61ec 61ef 61f4 61f7
61fa 61fd 61fe 6203 6204 1 6206 620b
620f 6213 6216 621b 6220 6223 6227 6228
622d 6230 6235 6236 623b 623e 6243 6244
6249 624c 6250 6254 6258 625c 625f 6260
6262 6267 6268 626a 626b 6270 6273 6278
6279 627e 6281 6286 6287 628c 628f 6293
6294 6299 629c 62a1 62a2 62a7 62a8 62ad
62af 62b3 62b6 62ba 62be 62c1 62c5 62c9
62cc 62d0 62d4 62d5 62da 62dc 62e0 62e4
62e7 62eb 62ef 62f2 62f6 62fa 62fd 6300
6305 6308 630b 630e 630f 6314 6315 1
6317 631c 6320 6324 6327 632c 6331 6334
6338 6339 633e 633f 6344 6348 634c 634f
6354 6359 635c 6360 6364 6367 6368 636d
6370 6375 6376 637b 637e 6382 6386 6389
638a 638f 6390 6395 6397 639b 639e 63a2
63a6 63aa 63ae 63b2 63b6 63ba 63be 63c2
63ce 63d3 63d7 63db 63df 63e3 63e5 63e6
63eb 1 63ef 63f3 63f7 63fa 63fe 6402
6406 640a 640d 6411 6415 6418 641b 6420
6423 6426 6429 642a 642f 6430 1 6432
6437 643b 643f 6442 6447 644c 644f 6453
6454 6459 645a 645f 6463 6467 646a 646f
6474 6477 647b 647c 6481 6484 6489 648a
648f 6492 6496 649a 649d 64a0 64a1 64a3
64a4 64a9 64aa 64af 64b1 64b5 64b8 64bc
64c0 64c4 64c8 64cc 64d0 64d4 64e0 64e5
64e9 64ed 64f1 64f5 64f7 64fb 64fd 6509
650b 650d 650e 6513 6517 6519 6525 6529
652b 652c 6535 
1ccb
2
0 1 a 6 c :3 6 12 :3 6
11 :3 6 12 :3 6 13 :3 6 10 :3 6
17 :3 6 15 :3 6 1a :3 6 b :3 6
10 :3 6 c :3 6 16 :3 6 18 :3 6
19 :3 6 1b :3 6 17 :3 6 16 :3 6
17 :3 6 17 :3 6 12 :2 6 1 3
a 13 a :2 1 4 13 1c 1b
:2 13 :2 4 10 19 18 :2 10 :2 4 e
17 16 :2 e :2 4 e 17 16 :2 e
:2 4 f 18 17 :2 f :2 4 e 17
16 :2 e :2 4 f 18 17 :2 f :2 4
11 1a 19 :2 11 :2 4 f 18 17
:2 f :2 4 c 15 14 :2 c :2 4 12
1b 1a :2 12 :2 4 11 1a 19 :2 11
:2 4 e 17 16 :2 e :2 4 f 18
17 :2 f :2 4 :2 e 1d e :2 4 :2 14
23 14 :2 4 :2 b 1a b :2 4 :2 a
19 a :2 4 :2 b 1a b :2 4 :2 e
1d e :2 4 :2 13 22 13 :2 4 :2 c
1b c :2 4 :2 e 1d e :2 4 :2 13
22 13 :2 4 :2 d 1c d :2 4 :2 c
1b c :2 4 :2 c 1b c :2 4 :2 e
1d e :2 4 :2 10 1f 10 :2 4 :2 12
21 12 :2 4 :3 10 :2 4 :3 f :2 4 18
21 20 :2 18 :2 4 18 21 20 :2 18
:2 4 f 18 17 :2 f :2 4 :3 11 :2 4
:3 f :2 4 :3 13 :2 4 :3 10 :2 4 :3 d :2 4
:3 e :2 4 14 1d 1c :2 14 :2 4 :2 11
20 11 :2 4 :2 f 1e f :2 4 :2 14
23 14 :2 4 :2 11 20 11 :2 4 :2 12
21 12 :2 4 :2 12 21 12 :2 4 :2 a
19 a :2 4 :3 9 :2 4 :3 9 :2 4 :2 f
19 f :2 4 :2 f 19 f :2 4 :2 f
1e f :2 4 :2 16 25 16 :2 4 :2 11
20 11 :2 4 :2 14 23 14 4 7
e 0 :2 7 20 2d 33 3b 56
5c 64 f 10 1d 2e 3b 13
2d a :6 7 e 0 :2 7 11 1c
26 f 10 1d 2e 42 18 23
a :5 7 4 e 17 :3 e 4 7
:2 11 23 :2 2d 3a :2 23 :3 7 :2 d 19
25 :2 2f 43 :2 25 55 5b 5e :2 55
6c 83 8 :2 6c d 10 :2 6c 16
19 :2 6c b e :2 6c 13 16 1f
27 :2 1f 35 :2 16 :2 6c b e :2 6c
13 16 :2 6c 1b 1e :2 6c 29 2c
:2 6c b e :2 6c 13 16 :2 6c 1b
1e :2 6c 2a 2d :2 6c b e :2 6c
13 16 :2 6c 1b 1e :2 6c 2b 2e
:2 6c b e :2 6c 13 16 1f 27
:2 1f 33 :2 16 :2 6c b e :2 6c 13
16 :2 6c 1b 1e :2 6c 2f 32 :2 6c
b e :2 6c 13 16 1f 27 :2 1f
38 :2 16 :2 6c b e :2 6c 13 16
1f 27 :2 1f 3d :2 16 :2 6c b e
:2 6c 13 16 1f 27 :2 1f 2e :2 16
:2 6c b e :2 6c 13 16 1f 27
:2 1f 33 :2 16 :2 6c b e :2 6c 13
16 1f 27 :2 1f 2f :2 16 :2 6c b
e :2 6c 13 16 1f 27 :2 1f 39
:2 16 :2 6c b e :2 6c 13 16 :2 6c
1b 1e :2 6c 30 33 :2 6c b e
:2 6c 13 16 :2 6c 1b 1e :2 6c 31
34 :2 6c b e :2 6c 13 16 1f
27 :2 1f 3e :2 16 :2 6c b e :2 6c
13 16 1f 27 :2 1f 3a :2 16 :2 6c
b e :2 6c 13 16 :2 6c 1b 1e
:2 6c 2e 31 :2 6c b e :2 6c 13
16 :2 6c 1b 1e :2 6c 2f 32 :2 6c
b e :2 6c 13 16 1f 27 :2 1f
3a :2 16 :2 6c b e :2 6c 13 16
:2 6c 1b 1e :2 6c 2a 2d :2 6c 32
35 :2 6c :2 7 4b :2 4 7 :2 11 23
:2 2d 39 3c 4d 50 51 :2 4d :2 23
:3 7 :2 d 12 1e 5e 61 :2 1e :2 7
54 :2 4 :4 9 8 7 24 2d 3a
:2 24 3d 3f :2 3d 23 46 a 17
:2 46 1a 1c :2 1a 45 :2 23 22 :2 7
a :2 14 26 :2 30 3c 3f 50 53
54 :2 50 :2 26 :3 a :2 10 15 21 61
64 :2 21 71 74 :2 21 78 7b :2 21
85 88 91 99 :2 a2 :2 91 b3 :2 88
:2 21 :2 a 57 :2 7 a :2 14 26 :2 30
3c 3f 50 53 54 :2 50 :2 26 :3 a
:2 10 15 21 61 64 :2 21 :2 a 57
:3 7 :2 12 28 :2 31 41 :2 7 20 :2 4
:4 9 8 7 :4 1e 1d 1c :2 7 :4 37
36 35 :2 7 a :2 14 26 :2 30 3c
3f 50 53 54 :2 50 :2 26 :3 a :2 10
15 21 61 64 :2 21 71 74 :2 21
78 7b :2 21 85 88 91 99 :2 a2
:2 91 b3 :2 88 :2 21 :2 a 57 :2 7 a
:2 14 26 :2 30 3c 3f 50 53 54
:2 50 :2 26 :3 a :2 10 15 21 61 64
:2 21 :2 a 57 :3 7 :2 12 28 :2 31 41
:2 7 4d :3 4 16 :2 4 10 :2 4 17
:2 4 12 :2 4 13 :2 4 17 :2 4 12
:2 4 10 :2 4 13 :2 4 15 :2 4 f
:2 4 16 :2 4 15 :2 4 14 4 7
10 17 :2 10 29 :2 7 2e 2c :2 37
:2 2c b 14 23 :2 b 26 28 :2 26
a 2f 38 47 :2 2f 4a 4c :2 4a
2e :2 a :4 e d 10 :2 1a 2c :2 36
42 45 56 59 5a :2 56 :2 2c :3 10
:2 16 1b 27 67 6a :2 27 77 7a
:2 27 7e 81 :2 27 8b 8e 97 9f
:2 a8 :2 97 b9 :2 8e :2 27 :2 10 5d :2 d
10 :2 1a 2c :2 36 42 45 56 59
5a :2 56 :2 2c :3 10 :2 16 1b 27 67
6a :2 27 :2 10 5d :3 d :2 18 2e :2 37
47 :2 d 22 :3 a 1b :2 a 17 :2 a
18 a 14 20 2d 3b 12 20
2d :2 d :2 16 22 d a :2 12 10
:2 19 25 10 13 :2 1d 2f :2 39 45
49 5a 5d 5e :2 5a :2 2f :3 13 :2 19
1e 2a 6a 6d :2 2a 7a 7d :2 2a
81 84 :2 2a 90 93 :2 2a 9b 9e
:2 2a aa ad b4 bd c0 :2 ad :2 2a
:2 13 61 :2 10 :2 d :4 19 :2 d a :3 4f
a :3 15 :2 a 1a 23 2c 37 :2 23
:2 1a :2 a :2 13 1f 2e 3c 47 52
61 27 :2 1f a e :2 17 20 22
:2 20 d 2a 33 42 :2 2a 45 47
:2 45 29 :2 d 4f 58 62 :2 4f 65
67 :2 65 4e :3 d 1b d 17 27
37 2e 16 23 34 41 :2 10 :2 19
25 10 d :2 15 13 :2 1c 28 13
16 :2 20 32 :2 3c 48 4c 5d 60
61 :2 5d :2 32 :3 16 :2 1c 21 2d 6d
70 :2 2d 7d 80 :2 2d 84 87 :2 2d
93 96 :2 2d 9e a1 :2 2d ad b0
b7 c0 c3 :2 b0 :2 2d :2 16 64 :2 13
:2 10 :4 1c :2 10 d :3 6a 10 19 25
:2 10 28 2b :2 28 10 21 :2 10 1c
:2 10 23 10 :4 14 13 1d 2a 35
42 63 74 :2 16 :2 1f 2b 16 13
:2 1b 19 :2 22 2e 19 1c :2 26 38
:2 42 4e 52 63 66 67 :2 63 :2 38
:3 1c :2 22 27 33 73 76 :2 33 83
86 :2 33 8a 8d :2 33 99 9c :2 33
a4 a7 :2 33 b3 b6 bd c6 c9
:2 b6 :2 33 :2 1c 6a :2 19 :2 16 :4 22 :2 16
13 :4 2c :2 10 2d :2 d 6a :2 a e
17 26 :2 e 29 2b :2 29 d 33
3e 47 52 :2 3e :2 33 32 57 5a
:2 57 :3 d 1e d 5c :2 a 4f a
15 a 14 20 29 36 43 d
18 22 2d 3b 12 20 2b 3a
49 d 1e 26 31 41 12 29
3d :2 d :2 16 22 d a :2 12 10
:2 19 25 10 13 :2 1d 2f :2 39 45
49 5a 5d 5e :2 5a :2 2f :3 13 :2 19
1e 2a 6a 6d :2 2a 7a 7d :2 2a
81 84 :2 2a 90 93 :2 2a 9b 9e
:2 2a aa ad b4 bd c0 :2 ad :2 2a
:2 13 61 :2 10 :2 d :4 19 :2 d a :3 7
e :2 17 22 20 :2 2b :2 20 d 40
49 59 :2 40 5f 5c 10 1f :2 5f
:2 5c 3f :3 d 1f :2 d 18 19 :2 18
d 23 :2 a :4 7 a 13 22 :2 a
25 28 :2 25 d :2 16 1f 22 :2 1f
10 :2 1a 2c :2 36 42 46 57 5a
5b :2 57 :2 2c :3 10 :2 16 1b 27 67
6a :2 27 77 7a :2 27 7e 81 :2 27
8b 8e 97 9f :2 a8 :2 97 b3 :2 8e
:2 27 bb be :2 27 c6 c9 :2 27 ce
d1 :2 27 d9 dc :2 27 :2 10 5e :2 d
10 :2 1a 2c :2 36 42 45 56 59
5a :2 56 :2 2c :3 10 :2 16 1b 27 67
6a :2 27 :2 10 5d :3 d :2 18 2c :2 35
3f 48 :2 d 24 :2 a :4 e d :4 26
25 :2 d :4 3f 3e :2 d :4 14 13 :2 d
10 :2 1a 2c :2 36 42 45 56 59
5a :2 56 :2 2c :3 10 :2 16 1b 27 67
6a :2 27 77 7a :2 27 7e 81 :2 27
8b 8e 97 9f :2 a8 :2 97 b9 :2 8e
:2 27 :2 10 5d :2 d 10 :2 1a 2c :2 36
42 45 56 59 5a :2 56 :2 2c :3 10
:2 16 1b 27 67 6a :2 27 :2 10 5d
:3 d :2 18 2e :2 37 47 :2 d 2d :3 a
1c :2 25 a d 16 1f :2 d 22
24 :2 22 d 18 d 2e :2 a 14
1d 37 46 54 61 :2 d :2 16 22
d a :2 12 10 :2 19 25 10 13
:2 1d 2f :2 39 45 49 5a 5d 5e
:2 5a :2 2f :3 13 :2 19 1e 2a 6a 6d
:2 2a 7a 7d :2 2a 81 84 :2 2a 90
93 :2 2a 9b 9e :2 2a aa ad b4
bd c0 :2 ad :2 2a :2 13 61 :2 10 :2 d
:4 19 :2 d a :3 2a d 16 1e :2 d
21 23 :2 21 d 1b 23 2c 36
:2 2c 3f :2 23 42 44 4d 57 :2 4d
63 :2 44 :2 23 22 67 69 :2 22 21
20 22 :2 21 :2 1b d 10 19 22
:2 10 28 25 31 3d :2 28 :2 25 10
1a :2 10 1d 10 40 10 1b 10
:4 d 25 :3 a 18 a e 15 1e
29 :2 15 2d :2 e d 32 34 :2 32
10 19 28 :2 10 2b 2d :2 2b 13
1c 2c :2 13 2f 31 :2 2f 13 :2 1c
28 35 3e 4a 56 67 25 32
3c 44 4c 54 25 35 40 50
25 36 :2 28 13 16 :2 1f 28 2a
:2 28 20 35 3b 19 2a 36 48
55 65 1f 2c 3d 47 55 63
19 20 1c 28 :3 26 1c :2 25 31
1c 2d 1c :2 25 31 1c :4 19 16
:2 1e 1c :2 25 31 1c 1f :2 29 3b
:2 45 51 55 66 69 6a :2 66 :2 3b
:3 1f :2 25 2a 36 76 79 :2 36 86
89 :2 36 8d 90 :2 36 9c 9f :2 36
a7 aa :2 36 b6 b9 c0 c9 cc
:2 b9 :2 36 :2 1f 6d :2 1c :2 19 :4 25 :2 19
16 :4 2c :2 13 33 13 :2 1c 28 35
3e 4a 56 67 25 32 3c 44
4c 54 25 35 40 50 25 36
:2 28 13 :4 10 2f 10 22 2b 3b
:2 22 3e 40 :2 22 10 13 1c 2c
:2 13 2f 31 :2 2f 13 :2 1c 28 35
3e 4a 56 67 25 32 3c 44
4c 54 25 35 40 50 25 36
:2 28 13 16 :2 1f 28 2a :2 28 20
35 3b 19 2a 36 48 55 65
1f 33 19 20 1c 28 :3 26 1c
:2 25 31 1c 2d 1c :2 25 31 1c
:4 19 16 :2 1e 1c :2 25 31 1c 1f
:2 29 3b :2 45 51 55 66 69 6a
:2 66 :2 3b :3 1f :2 25 2a 36 76 79
:2 36 86 89 :2 36 8d 90 :2 36 9c
9f :2 36 a7 aa :2 36 b6 b9 c0
c9 cc :2 b9 :2 36 :2 1f 6d :2 1c :2 19
:4 25 :2 19 16 :4 2c :2 13 33 13 :2 1c
28 35 3e 4a 56 67 25 32
3c 44 4c 54 25 35 40 50
25 36 :2 28 13 :4 10 :4 d 11 :2 1a
23 25 :2 23 10 2e 35 3e 49
:2 35 4d :2 2e 2d 51 53 :2 51 2c
:2 10 14 1d 2d :2 14 32 30 3b
46 :2 32 :2 30 13 4f 58 5e :2 4f
61 63 :2 61 4e :2 13 6b 2c 41
:2 6b 44 46 :2 44 6a :2 13 1d 32
46 16 22 2b 3a 16 27 33
45 52 62 16 25 31 41 16
24 16 :2 1c 30 16 1d 19 25
:3 23 19 :2 22 2e 19 2a 19 :2 22
2e 19 :4 16 13 :2 1b 19 :2 22 2e
19 1c :2 26 38 :2 42 4e 52 63
66 67 :2 63 :2 38 :3 1c :2 22 27 33
73 76 :2 33 83 86 :2 33 8a 8d
:2 33 99 9c :2 33 a4 a7 :2 33 b3
b6 bd c6 c9 :2 b6 :2 33 :2 1c 6a
:2 19 :2 16 :4 22 :2 16 13 :3 4d 1d 32
3f 4a 1c 29 3a 4e 16 1d
19 25 :3 23 19 :2 22 2e 19 2a
19 :2 22 2e 19 :4 16 13 :2 1b 19
:2 22 2e 19 1c :2 26 38 :2 42 4e
52 63 66 67 :2 63 :2 38 :3 1c :2 22
27 33 73 76 :2 33 83 86 :2 33
8a 8d :2 33 99 9c :2 33 a4 a7
:2 33 b3 b6 bd c6 c9 :2 b6 :2 33
:2 1c 6a :2 19 :2 16 :4 22 :2 16 13 :3 4d
1d 32 43 1c 30 16 1d 19
25 :3 23 19 :2 22 2e 19 2a 19
:2 22 2e 19 :4 16 13 :2 1b 19 :2 22
2e 19 1c :2 26 38 :2 42 4e 52
63 66 67 :2 63 :2 38 :3 1c :2 22 27
33 73 76 :2 33 83 86 :2 33 8a
8d :2 33 99 9c :2 33 a4 a7 :2 33
b3 b6 bd c6 c9 :2 b6 :2 33 :2 1c
6a :2 19 :2 16 :4 22 :2 16 13 :4 4d 1d
32 38 16 27 33 45 52 62
1c 30 16 1d 19 25 :3 23 19
:2 22 2e 19 2a 19 :2 22 2e 19
:4 16 13 :2 1b 19 :2 22 2e 19 1c
:2 26 38 :2 42 4e 52 63 66 67
:2 63 :2 38 :3 1c :2 22 27 33 73 76
:2 33 83 86 :2 33 8a 8d :2 33 99
9c :2 33 a4 a7 :2 33 b3 b6 bd
c6 c9 :2 b6 :2 33 :2 1c 6a :2 19 :2 16
:4 22 :2 16 13 :7 10 56 :2 d 37 d
1c 23 2c 39 :2 23 3d :2 46 :2 1c
d 10 19 28 :2 10 2b 2d :2 2b
10 :2 19 25 32 3b 47 53 64
25 32 3c 44 4c 54 25 35
40 50 25 36 :2 25 10 14 :2 1d
26 28 :2 26 13 30 39 44 :2 30
47 49 :2 47 2f :2 13 51 5a 63
:2 51 66 68 :2 66 50 :2 13 1d 32
38 16 27 33 45 52 62 1c
29 3a 44 52 60 16 1d 19
25 :3 23 19 :2 22 2e 19 2a 19
:2 22 2e 19 :4 16 13 :2 1b 19 :2 22
2e 19 1c :2 26 38 :2 42 4e 52
63 66 67 :2 63 :2 38 :3 1c :2 22 27
33 73 76 :2 33 83 86 :2 33 8a
8d :2 33 99 9c :2 33 a4 a7 :2 33
b3 b6 bd c6 c9 :2 b6 :2 33 :2 1c
6a :2 19 :2 16 :4 22 :2 16 13 :4 6b :2 10
2f :4 14 :2 13 20 13 1d 24 3e
45 5f 66 80 87 9c ab :2 16
:2 1f 2b 16 13 :2 1b 19 :2 22 2e
19 1c :2 26 38 :2 42 4e 52 63
66 67 :2 63 :2 38 :3 1c :2 22 27 33
73 76 :2 33 83 86 :2 33 8a 8d
:2 33 99 9c :2 33 a4 a7 :2 33 b3
b6 bd c6 c9 :2 b6 :2 33 :2 1c 6a
:2 19 :2 16 :4 22 :2 16 13 :3 33 16 :2 21
29 34 3e :2 16 42 44 :2 42 16
23 :2 2c :2 16 26 16 20 30 1e
1f :2 19 :2 22 2e 19 16 :2 1e 1c
:2 25 31 1c 1f :2 29 3b :2 45 51
55 66 69 6a :2 66 :2 3b :3 1f :2 25
2a 36 76 79 :2 36 86 89 :2 36
8d 90 :2 36 9c 9f :2 36 a7 aa
:2 36 b6 b9 c0 c9 cc :2 b9 :2 36
:2 1f 6d :2 1c :2 19 :4 25 :2 19 16 :3 46
16 29 3b 49 54 62 6d 28
:2 29 16 19 22 33 :2 19 36 38
:2 36 19 26 :2 19 27 :2 19 2b :2 19
27 :2 19 28 :2 19 1e :3 19 1f 2c
3c :3 19 1c 24 :2 1c :2 25 31 1c
2a 1c :2 25 31 1c :4 19 1c 22
:3 1c :2 25 31 1c 19 :2 21 1f :2 28
34 1f 22 :2 2c 3e :2 48 54 58
69 6c 6d :2 69 :2 3e :3 22 :2 28 2d
39 79 7c :2 39 89 8c :2 39 90
93 :2 39 9f a2 :2 39 aa ad :2 39
b9 bc c3 cc cf :2 bc :2 39 :2 22
70 :2 1f :2 1c :4 28 :2 1c 19 :3 3a 23
32 43 22 30 :2 1c :2 25 31 1c
19 :2 21 1f :2 28 34 1f 22 :2 2c
3e :2 48 54 58 69 6c 6d :2 69
:2 3e :3 22 :2 28 2d 39 79 7c :2 39
89 8c :2 39 90 93 :2 39 9f a2
:2 39 aa ad :2 39 b9 bc c3 cc
cf :2 bc :2 39 :2 22 70 :2 1f :2 1c :4 28
:2 1c 19 :3 3a 19 26 :2 19 26 :2 19
26 2d 37 3a :2 2d 47 4a :2 26
:2 19 26 2d 37 3a :2 2d 4b 4e
:2 26 :2 19 26 2d 37 3a :2 2d 4a
4d :2 26 :2 19 26 2d 37 22 :2 2d
24 27 :2 26 :2 19 2c 3a 46 52
5a 62 6e 24 2f 3a 46 52
5e 24 2f 3b :2 2c 19 1c :2 26
38 :2 42 4e 52 63 66 67 :2 63
:2 38 :3 1c :2 22 27 33 73 76 :2 33
83 86 :2 33 8a 8d :2 33 97 9a
a3 ab :2 a3 af :2 9a :2 33 b7 ba
:2 33 c2 c5 :2 33 ca cd :2 33 d5
d8 :2 33 :2 1c 6a :2 19 1c :2 26 38
:2 42 4e 51 62 65 66 :2 62 :2 38
:3 1c :2 22 27 33 73 76 :2 33 :2 1c
69 :3 19 :2 24 38 3b 44 :2 19 3a
:2 16 46 :2 13 33 :3 10 22 2b 3b
:2 22 3e 40 :2 22 :2 10 :2 19 25 32
3b 47 53 64 25 32 3c 44
4c 54 25 35 40 50 25 36
:2 25 10 14 :2 1d 26 28 :2 26 13
30 39 44 :2 30 47 49 :2 47 2f
:2 13 51 5a 63 :2 51 66 68 :2 66
50 :2 13 1d 32 38 16 27 33
45 52 62 1c 30 16 1d 19
25 :3 23 19 :2 22 2e 19 2a 19
:2 22 2e 19 :4 16 13 :2 1b 19 :2 22
2e 19 1c :2 26 38 :2 42 4e 52
63 66 67 :2 63 :2 38 :3 1c :2 22 27
33 73 76 :2 33 83 86 :2 33 8a
8d :2 33 99 9c :2 33 a4 a7 :2 33
b3 b6 bd c6 c9 :2 b6 :2 33 :2 1c
6a :2 19 :2 16 :4 22 :2 16 13 :4 6b :2 10
:4 d :4 a d :2 16 1f 22 :2 1f 10
:2 1a 2c :2 36 42 46 57 5a 5b
:2 57 :2 2c :3 10 :2 16 1b 27 67 6a
:2 27 77 7a :2 27 7e 81 :2 27 8b
8e 97 9f :2 a8 :2 97 b3 :2 8e :2 27
bb be :2 27 c6 c9 :2 27 ce d1
:2 27 d9 dc :2 27 :2 10 5e :2 d 10
:2 1a 2c :2 36 42 45 56 59 5a
:2 56 :2 2c :3 10 :2 16 1b 27 67 6a
:2 27 :2 10 5d :3 d :2 18 2c :2 35 3f
48 :2 d 24 :3 a 1c a e 17
20 :2 e 23 26 :2 23 d 32 3b
4b :2 32 4e 50 :2 4e 31 :3 d 1f
d 53 :2 a d 16 25 :2 d 28
2a :2 28 11 18 21 2c :2 18 30
:2 11 10 35 37 :2 35 :4 14 13 :4 17
16 20 35 49 19 25 2e 3d
19 2a 36 48 55 65 19 28
19 29 19 27 1f 33 19 20
1c 28 :3 26 1c :2 25 31 1c 2d
1c :2 25 31 1c :4 19 16 :2 1e 1c
:2 25 31 1c 1f :2 29 3b :2 45 51
55 66 69 6a :2 66 :2 3b :3 1f :2 25
2a 36 76 79 :2 36 86 89 :2 36
8d 90 :2 36 9c 9f :2 36 a7 aa
:2 36 b6 b9 c0 c9 cc :2 b9 :2 36
:2 1f 6d :2 1c :2 19 :4 25 :2 19 16 :4 33
20 35 49 19 25 19 28 1f
33 19 20 1c 28 :3 26 1c :2 25
31 1c 2d 1c :2 25 31 1c :4 19
16 :2 1e 1c :2 25 31 1c 1f :2 29
3b :2 45 51 55 66 69 6a :2 66
:2 3b :3 1f :2 25 2a 36 76 79 :2 36
86 89 :2 36 8d 90 :2 36 9c 9f
:2 36 a7 aa :2 36 b6 b9 c0 c9
cc :2 b9 :2 36 :2 1f 6d :2 1c :2 19 :4 25
:2 19 16 :7 13 2f :4 17 16 20 35
49 19 25 2e 3d 19 35 51
5e 76 19 36 52 5f 78 19
38 54 6e 19 34 50 66 19
2b 19 2c 19 2e 19 2a 19
2b 19 2c 19 2e 19 2a 19
2a 38 49 57 68 76 87 :2 19
2a 36 48 55 65 19 28 19
29 19 27 1f 33 19 20 1c
28 :3 26 1c :2 25 31 1c 2d 1c
:2 25 31 1c :4 19 16 :2 1e 1c :2 25
31 1c 1f :2 29 3b :2 45 51 55
66 69 6a :2 66 :2 3b :3 1f :2 25 2a
36 76 79 :2 36 86 89 :2 36 8d
90 :2 36 9c 9f :2 36 a7 aa :2 36
b6 b9 c0 c9 cc :2 b9 :2 36 :2 1f
6d :2 1c :2 19 :4 25 :2 19 16 :4 33 20
35 49 19 25 2e 3d 19 35
51 5e 76 19 36 52 5f 78
19 38 54 6e 19 34 50 66
19 2b 19 2c 19 2e 19 2a
19 2b 19 2c 19 2e 19 2a
19 2a 38 49 57 68 76 87
19 1f 33 19 20 1c 28 :3 26
1c :2 25 31 1c 2d 1c :2 25 31
1c :4 19 16 :2 1e 1c :2 25 31 1c
1f :2 29 3b :2 45 51 55 66 69
6a :2 66 :2 3b :3 1f :2 25 2a 36 76
79 :2 36 86 89 :2 36 8d 90 :2 36
9c 9f :2 36 a7 aa :2 36 b6 b9
c0 c9 cc :2 b9 :2 36 :2 1f 6d :2 1c
:2 19 :4 25 :2 19 16 :7 13 :4 10 d 3a
13 1c 25 :2 13 28 2a :2 28 1a
2f 43 13 1f 13 22 19 2d
13 1a 16 22 :3 20 16 :2 1f 2b
16 27 16 :2 1f 2b 16 :4 13 10
:2 18 16 :2 1f 2b 16 19 :2 23 35
:2 3f 4b 4f 60 63 64 :2 60 :2 35
:3 19 :2 1f 24 30 70 73 :2 30 80
83 :2 30 87 8a :2 30 96 99 :2 30
a1 a4 :2 30 b0 b3 ba c3 c6
:2 b3 :2 30 :2 19 67 :2 16 :2 13 :4 1f :2 13
10 :4 2c 3a :2 d 2c 11 18 21
2c :2 18 30 :2 11 10 35 37 :2 35
:4 14 13 :4 17 16 20 35 49 19
25 2e 3d 19 2a 36 48 55
65 19 28 19 29 19 27 1f
33 19 20 1c 28 :3 26 1c :2 25
31 1c 2d 1c :2 25 31 1c :4 19
16 :2 1e 1c :2 25 31 1c 1f :2 29
3b :2 45 51 55 66 69 6a :2 66
:2 3b :3 1f :2 25 2a 36 76 79 :2 36
86 89 :2 36 8d 90 :2 36 9c 9f
:2 36 a7 aa :2 36 b6 b9 c0 c9
cc :2 b9 :2 36 :2 1f 6d :2 1c :2 19 :4 25
:2 19 16 :4 33 20 35 49 19 25
2e 3d 19 27 1f 33 19 20
1c 28 :3 26 1c :2 25 31 1c 2d
1c :2 25 31 1c :4 19 16 :2 1e 1c
:2 25 31 1c 1f :2 29 3b :2 45 51
55 66 69 6a :2 66 :2 3b :3 1f :2 25
2a 36 76 79 :2 36 86 89 :2 36
8d 90 :2 36 9c 9f :2 36 a7 aa
:2 36 b6 b9 c0 c9 cc :2 b9 :2 36
:2 1f 6d :2 1c :2 19 :4 25 :2 19 16 :7 13
2f :4 17 16 20 35 49 19 25
2e 3d 19 35 51 5e 76 19
36 52 5f 78 19 38 54 6e
19 34 50 66 19 2b 19 2c
19 2e 19 2a 19 2b 19 2c
19 2e 19 2a 19 2a 38 49
57 68 76 87 :2 19 2a 36 48
55 65 19 28 19 29 19 27
1f 33 19 20 1c 28 :3 26 1c
:2 25 31 1c 2d 1c :2 25 31 1c
:4 19 16 :2 1e 1c :2 25 31 1c 1f
:2 29 3b :2 45 51 55 66 69 6a
:2 66 :2 3b :3 1f :2 25 2a 36 76 79
:2 36 86 89 :2 36 8d 90 :2 36 9c
9f :2 36 a7 aa :2 36 b6 b9 c0
c9 cc :2 b9 :2 36 :2 1f 6d :2 1c :2 19
:4 25 :2 19 16 :4 33 20 35 49 19
25 2e 3d 19 27 19 35 51
5e 76 19 36 52 5f 78 19
38 54 6e 19 34 50 66 19
2b 19 2c 19 2e 19 2a 19
2b 19 2c 19 2e 19 2a 19
2a 38 49 57 68 76 87 19
1f 33 19 20 1c 28 :3 26 1c
:2 25 31 1c 2d 1c :2 25 31 1c
:4 19 16 :2 1e 1c :2 25 31 1c 1f
:2 29 3b :2 45 51 55 66 69 6a
:2 66 :2 3b :3 1f :2 25 2a 36 76 79
:2 36 86 89 :2 36 8d 90 :2 36 9c
9f :2 36 a7 aa :2 36 b6 b9 c0
c9 cc :2 b9 :2 36 :2 1f 6d :2 1c :2 19
:4 25 :2 19 16 :7 13 :4 10 d 3a 13
1c 25 :2 13 28 2a :2 28 :4 14 13
16 1f 25 :2 16 28 2a :2 28 20
35 49 19 25 2e 3d 19 27
19 1f 2a 1f 33 19 20 1c
28 :3 26 1c :2 25 31 1c 2d 1c
:2 25 31 1c :4 19 16 :2 1e 1c :2 25
31 1c 1f :2 29 3b :2 45 51 55
66 6a 6b :2 66 :2 3b :3 1f :2 25 2a
36 77 7a :2 36 87 8a :2 36 8e
91 :2 36 9d a0 :2 36 a8 ab :2 36
b7 ba c1 ca cd :2 ba :2 36 :2 1f
6e :2 1c :2 19 :4 25 :2 19 16 :4 2c 20
35 49 19 25 2e 3d 19 27
1f 33 19 20 1c 28 :3 26 1c
:2 25 31 1c 2d 1c :2 25 31 1c
:4 19 16 :2 1e 1c :2 25 31 1c 1f
:2 29 3b :2 45 51 55 66 6a 6b
:2 66 :2 3b :3 1f :2 25 2a 36 77 7a
:2 36 87 8a :2 36 8e 91 :2 36 9d
a0 :2 36 a8 ab :2 36 b7 ba c1
ca cd :2 ba :2 36 :2 1f 6e :2 1c :2 19
:4 25 :2 19 16 :7 13 31 1d 32 46
16 22 2b 3a 16 24 1c 30
16 1d 19 25 :3 23 19 :2 22 2e
19 2a 19 :2 22 2e 19 :4 16 13
:2 1b 19 :2 22 2e 19 1c :2 26 38
:2 42 4e 52 63 67 68 :2 63 :2 38
:3 1c :2 22 27 33 74 77 :2 33 84
87 :2 33 8b 8e :2 33 9a 9d :2 33
a5 a8 :2 33 b4 b7 be c7 ca
:2 b7 :2 33 :2 1c 6b :2 19 :2 16 :4 22 :2 16
13 :7 10 2c 3a :2 d :4 a :4 f e
30 39 4b :2 30 4e 50 :2 4e 2f
:2 e d 58 10 20 :2 58 23 25
:2 23 57 :3 d 1b :2 d 1b :2 d 18
:2 d 18 d 10 19 28 :2 10 2b
2d :2 2b 1a 2d 39 42 4a 51
67 6f 76 8d 97 a8 b6 18
2d 37 42 48 4e 5a 6d 79
18 19 2d :2 13 :2 1c 28 13 10
:2 18 16 :2 1f 2b 16 19 :2 23 35
:2 3f 4b 4f 60 64 65 :2 60 :2 35
:3 19 :2 1f 24 30 71 74 :2 30 81
84 :2 30 88 8b :2 30 97 9a :2 30
a2 a5 :2 30 b1 b4 bb c4 c7
:2 b4 :2 30 :2 19 68 :2 16 :2 13 :4 1f :2 13
10 :4 2f 10 27 10 1a 26 2f
37 3e 54 5c 63 7a 84 95
a3 18 22 2d 33 39 45 58
64 18 19 2d :2 13 :2 1c 28 13
10 :2 18 16 :2 1f 2b 16 19 :2 23
35 :2 3f 4b 4f 60 64 65 :2 60
:2 35 :3 19 :2 1f 24 30 71 74 :2 30
81 84 :2 30 88 8b :2 30 97 9a
:2 30 a2 a5 :2 30 b1 b4 bb c4
c7 :2 b4 :2 30 :2 19 68 :2 16 :2 13 :4 1f
:2 13 10 :7 d 11 :2 1a 25 23 :2 2e
:2 23 10 14 1d 2d :2 14 32 30
3b 46 :2 32 :2 30 13 4f 58 5e
:2 4f 61 63 :2 61 4e :2 13 6b 2c
41 :2 6b 44 46 :2 44 6a :2 13 1d
32 3f 4a 1c 29 3a 4e 16
1d 19 25 :3 23 19 :2 22 2e 19
2a 19 :2 22 2e 19 :4 16 13 :2 1b
19 :2 22 2e 19 1c :2 26 38 :2 42
4e 52 63 67 68 :2 63 :2 38 :3 1c
:2 22 27 33 74 77 :2 33 84 87
:2 33 8b 8e :2 33 9a 9d :2 33 a5
a8 :2 33 b4 b7 be c7 ca :2 b7
:2 33 :2 1c 6b :2 19 :2 16 :4 22 :2 16 13
:3 4d 1d 32 40 16 2f 33 42
1c 29 3a 4e 1c 30 16 1d
19 25 :3 23 19 :2 22 2e 19 2a
19 :2 22 2e 19 :4 16 13 :2 1b 19
:2 22 2e 19 1c :2 26 38 :2 42 4e
52 63 67 68 :2 63 :2 38 :3 1c :2 22
27 33 74 77 :2 33 84 87 :2 33
8b 8e :2 33 9a 9d :2 33 a5 a8
:2 33 b4 b7 be c7 ca :2 b7 :2 33
:2 1c 6b :2 19 :2 16 :4 22 :2 16 13 :4 4d
13 18 :4 13 1c 25 30 3d :3 16
19 1d :2 19 :2 22 2e 19 23 19
:2 22 2e 19 :4 16 19 :2 22 2b 2e
:2 2b :2 19 30 :3 16 21 2a 33 :2 21
36 38 41 4c :2 38 :2 21 16 19
22 2b :2 19 2e 30 :2 2e 1c 25
2e :2 1c 33 31 3c 4b :2 33 :2 31
1f 28 33 :2 1f 39 36 42 51
:2 39 :2 36 1f 2c 35 44 :2 2c 1f
54 1f 2c 35 44 :2 2c 47 49
52 5b :2 49 :2 2c 5e 60 69 74
:2 60 :2 2c 1f :4 1c 4e :2 19 23 38
45 50 71 1c 23 1f 2b :3 29
1f :2 28 34 1f 30 1f :2 28 34
1f :4 1c 19 :2 21 1f :2 28 34 1f
22 :2 2c 3e :2 48 54 58 69 6d
6e :2 69 :2 3e :3 22 :2 28 2d 39 7a
7d :2 39 8a 8d :2 39 91 94 :2 39
a0 a3 :2 39 ab ae :2 39 ba bd
c4 cd d0 :2 bd :2 39 :2 22 71 :2 1f
:2 1c :4 28 :2 1c 19 :3 32 19 27 19
32 :2 16 19 22 2b :2 19 31 2e
3a 49 :2 31 :2 2e :2 19 4c :2 16 13
17 10 16 1c :3 16 :2 1f 2b 16
13 :2 1b 19 :2 22 2e 19 1c :2 26
38 :2 42 4e 52 63 67 68 :2 63
:2 38 :3 1c :2 22 27 33 74 77 :2 33
84 87 :2 33 8b 8e :2 33 9a 9d
:2 33 a5 a8 :2 33 b4 b7 be c7
ca :2 b7 :2 33 :2 1c 6b :2 19 :2 16 :4 22
:2 16 13 :3 10 17 20 29 :2 17 2c
2e :2 2c 16 :4 37 36 35 :2 16 20
35 46 57 6b 19 20 1c 28
:3 26 1c :2 25 31 1c 2d 1c :2 25
31 1c :4 19 16 :2 1e 1c :2 25 31
1c 1f :2 29 3b :2 45 51 55 66
6a 6b :2 66 :2 3b :3 1f :2 25 2a 36
77 7a :2 36 87 8a :2 36 8e 91
:2 36 9d a0 :2 36 a8 ab :2 36 b7
ba c1 ca cd :2 ba :2 36 :2 1f 6e
:2 1c :2 19 :4 25 :2 19 16 :4 50 :2 13 :4 10
13 1c 2b :2 13 2e 30 :2 2e 17
1e 27 32 :2 1e 36 :2 17 16 3b
3d :2 3b 16 29 3c 51 :2 29 16
40 16 29 3c 51 :2 29 16 :4 13
32 :2 10 3e :2 d 28 :2 a 2a :2 7
a :2 13 1c 1e :2 1c a :2 13 1f
a 22 :2 7 4f :2 4 7 :2 11 23
:2 2d 39 3c 4d 51 52 :2 4d :2 23
:3 7 :2 d 12 1e 5f 62 :2 1e 6f
72 :2 1e 76 79 :2 1e 83 86 8f
97 :2 a0 :2 8f ab :2 86 :2 1e b3 b6
:2 1e be c1 :2 1e c6 c9 :2 1e cf
d2 :2 1e :2 7 55 :3 4 :2 f 21 :2 2a
34 3b :2 4 1 9 12 9 a
:2 14 26 :2 30 3c 40 51 55 56
:2 51 :2 26 :3 a :2 10 15 21 62 65
:2 21 :3 a :2 10 15 39 5c 5f :2 68
:2 39 76 79 :2 39 81 84 :2 8d :2 39
:2 a 59 :3 7 c 15 1e 2c a
13 1e f e 7 e 7 e
7 29 :2 4 :2 9 7 :2 10 1c :2 7
:2 11 23 :2 2d 39 3d 4e 52 53
:2 4e :2 23 :3 7 :2 d 12 1e 5f 62
:2 1e :3 7 :2 d 12 36 42 45 :2 36
4d 50 :2 36 5c 5f 66 6f 72
:2 5f :2 36 :2 7 56 :2 4 7 c 1b
a 13 1e f e 7 e 7
e 7 :2 4 :4 10 :2 4 :8 1 
1ccb
4
0 :2 1 :4 3 :4 4
:4 5 :4 6 :4 7 :4 8
:4 9 :4 a :4 b :4 c
:4 d :4 e :4 f :4 10
:4 11 :4 12 :4 13 :4 14
:4 15 :4 16 :4 17 2
:4 18 :2 1 :7 1a :7 1b
:7 1c :7 1d :7 1e :7 1f
:7 20 :7 21 :7 22 :7 23
:7 24 :7 25 :7 26 :7 27
:6 28 :6 29 :6 2a :6 2b
:6 2c :6 2d :6 2e :6 2f
:6 30 :6 31 :6 32 :6 33
:6 34 :6 35 :6 36 :6 37
:5 38 :5 39 :7 3a :7 3b
:7 3c :5 3d :5 3e :5 3f
:5 40 :5 41 :5 42 :7 43
:6 44 :6 45 :6 46 :6 47
:6 48 :6 49 :6 4a :5 4b
:5 4c :6 4d :6 4e :6 4f
:6 50 :6 51 :6 52 :2 54
0 :2 54 :7 55 56
:4 57 :2 58 55 :5 54
:2 5a 0 :2 5a :3 5b
5c :4 5d :2 5e 5b
:5 5a :7 60 :b 62 :11 63
64 :2 63 :2 64 :2 63
:2 64 :2 63 :2 65 :2 63
:9 65 :2 63 :2 66 :2 63
:2 66 :2 63 :2 66 :2 63
:2 66 :2 63 :2 67 :2 63
:2 67 :2 63 :2 67 :2 63
:2 67 :2 63 :2 68 :2 63
:2 68 :2 63 :2 68 :2 63
:2 68 :2 63 :2 69 :2 63
:9 69 :2 63 :2 6a :2 63
:2 6a :2 63 :2 6a :2 63
:2 6a :2 63 :2 6b :2 63
:9 6b :2 63 :2 6c :2 63
:9 6c :2 63 :2 6d :2 63
:9 6d :2 63 :2 6e :2 63
:9 6e :2 63 :2 6f :2 63
:9 6f :2 63 :2 70 :2 63
:9 70 :2 63 :2 71 :2 63
:2 71 :2 63 :2 71 :2 63
:2 71 :2 63 :2 72 :2 63
:2 72 :2 63 :2 72 :2 63
:2 72 :2 63 :2 73 :2 63
:9 73 :2 63 :2 74 :2 63
:9 74 :2 63 :2 75 :2 63
:2 75 :2 63 :2 75 :2 63
:2 75 :2 63 :2 76 :2 63
:2 76 :2 63 :2 76 :2 63
:2 76 :2 63 :2 77 :2 63
:9 77 :2 63 :2 78 :2 63
:2 78 :2 63 :2 78 :2 63
:2 78 :2 63 :2 78 :4 63
:3 62 :11 7b :b 7c :3 7b
:11 7f :2 80 :2 7f :4 80
:6 7f :11 81 :20 82 :3 81
:11 84 :b 85 :3 84 :9 87
80 :2 7f :16 8a :11 8b
:20 8c :3 8b :11 8e :b 8f
:3 8e :9 91 :3 8a :3 96
:3 97 :3 98 :3 99 :3 9a
:3 9b :3 9c :3 9d :3 9e
:3 9f :3 a0 :3 a1 :3 a2
:3 a3 :e a7 :16 a8 :5 aa
:11 ab :20 ac :3 ab :11 ae
:b af :3 ae :9 b1 :3 aa
:3 b4 :3 b5 :3 b6 :4 b9
:3 ba b9 :5 bb b8
:2 bd :5 bf :11 c0 :24 c1
:3 c0 :2 be :6 bd bc
:3 a8 :5 c6 :a c7 :9 c9
ca :3 c9 :20 cd :3 ce
:3 d0 d1 :4 d2 d0
:5 d3 cf :2 d5 :5 d7
:11 d8 :24 d9 :3 d8 :2 d6
:6 d5 d4 :3 cd :9 de
:3 df :3 e0 :3 e1 :5 e3
:7 e5 :5 e6 e4 :2 e8
:5 ea :11 eb :24 ec :3 eb
:2 e9 :6 e8 e7 :6 e3
:3 de :3 cd :19 f5 :3 f6
:3 f5 a8 :3 f9 :5 fc
:5 fd :5 fe :5 ff :3 100
fc :5 101 fb :2 103
:5 105 :11 106 :24 107 :3 106
:2 104 :6 103 102 :3 f8
:11 10d :2 10e :7 10d :3 10f
:6 110 10e :2 10d f8
:3 a8 :9 115 :7 116 :11 117
:30 118 :3 117 :11 11a :b 11b
:3 11a :a 11d :3 116 :13 121
:5 122 :2 121 :11 123 :20 124
:3 123 :11 126 :b 127 :3 126
:9 129 122 :2 121 :5 12c
:9 12f :3 130 :3 12f :7 137
:5 138 136 :2 13a :5 13c
:11 13d :24 13e :3 13d :2 13b
:6 13a 139 :3 115 :9 143
:1b 145 :2 146 :5 145 :d 148
:3 149 :3 14a 148 :3 14c
14b :3 148 :3 143 :3 169
:e 16b :9 16c :9 16d :9 16e
:6 16f :4 170 :2 171 :3 16e
:7 174 :3 176 :6 177 :6 178
176 :6 179 :5 17a 179
:5 17c 17b :3 179 175
:2 17f :5 181 :11 182 :24 183
:3 182 :2 180 :6 17f 17e
:6 174 16d :9 189 :6 18a
:4 18b :2 18c :3 189 188
:3 16d 16c :b 190 :9 191
:9 192 :6 193 :4 194 :2 195
:3 192 :7 198 :3 19a :6 19b
:2 19c 19a :6 19d :5 19e
19d :5 1a0 19f :3 19d
199 :2 1a3 :5 1a5 :11 1a6
:24 1a7 :3 1a6 :2 1a4 :6 1a3
1a2 :6 198 191 :9 1ad
:6 1ae :4 1af :2 1b0 :3 1ad
1ac :3 191 18f :3 16c
:19 1b5 :1b 1b6 :2 1b7 :2 1b6
:4 1b7 :3 1b6 :3 1b9 :4 1ba
:6 1bb :4 1bc :2 1bd :2 1be
:2 1bf 1b9 :6 1c0 :5 1c1
1c0 :5 1c3 1c2 :3 1c0
1b8 :2 1c6 :5 1c8 :11 1c9
:24 1ca :3 1c9 :2 1c7 :6 1c6
1c5 :3 1b7 :4 1d0 :4 1d1
1d0 :6 1d2 :5 1d3 1d2
:5 1d5 1d4 :3 1d2 1cf
:2 1d8 :5 1da :11 1db :24 1dc
:3 1db :2 1d9 :6 1d8 1d7
:3 1b7 :3 1e2 :2 1e3 1e2
:6 1e4 :5 1e5 1e4 :5 1e7
1e6 :3 1e4 1e1 :2 1ea
:5 1ec :11 1ed :24 1ee :3 1ed
:2 1eb :6 1ea 1e9 :4 1b7
:3 1f4 :6 1f5 :2 1f6 1f4
:6 1f7 :5 1f8 1f7 :5 1fa
1f9 :3 1f7 1f3 :2 1fd
:5 1ff :11 200 :24 201 :3 200
:2 1fe :6 1fd 1fc :4 1f2
:3 1b6 :3 1b5 16b :d 208
:9 20a :9 20b :6 20c :4 20d
:2 20e :3 20b :20 211 :3 213
:6 214 :6 215 213 :6 216
:5 217 216 :5 219 218
:3 216 212 :2 21c :5 21e
:11 21f :24 220 :3 21f :2 21d
:6 21c 21b :6 211 20a
:5 226 :3 227 :b 22d :5 22e
22c :2 230 :5 232 :11 233
:24 234 :3 233 :2 231 :6 230
22f :3 226 :c 239 :5 23a
:3 23b :2 23e 23f 240
23e :5 241 23d :2 243
:5 245 :11 246 :24 247 :3 246
:2 244 :6 243 242 :3 239
:7 24c 24d :3 24c :9 24f
:3 250 :3 251 :3 252 :3 253
:3 254 :5 256 :6 258 :3 259
:5 25a 259 :5 25c 25b
:3 259 :4 260 :5 261 25f
:2 263 :5 265 :11 266 :24 267
:3 266 :2 264 :6 263 262
:3 24f :3 26d :2 26e 26d
:5 26f 26c :2 271 :5 273
:11 274 :24 275 :3 274 :2 272
:6 271 270 :3 24f :3 27b
:3 27d :c 27e :c 27f :c 280
:4 281 282 :2 281 :2 283
:3 281 :8 285 :6 286 :3 287
:3 285 :11 289 :2e 28a :3 289
:11 28c :b 28d :3 28c :8 28f
:3 24f :3 239 :3 226 :b 294
:9 295 :6 296 :4 297 :2 298
:3 295 :20 29c :3 29e :6 29f
:2 2a0 29e :6 2a1 :5 2a2
2a1 :5 2a4 2a3 :3 2a1
29d :2 2a7 :5 2a9 :11 2aa
:24 2ab :3 2aa :2 2a8 :6 2a7
2a6 :6 29c 225 :3 20a
207 :3 16b :7 2b4 :11 2b5
:30 2b6 :3 2b5 :11 2b8 :b 2b9
:3 2b8 :a 2bb :3 2b4 :3 2be
:16 2bf :3 2c0 :3 2bf :9 2c3
:e 2c4 :5 2c5 :5 2c7 :3 2c9
:4 2ca :6 2cb :2 2cc :2 2cd
:2 2ce :2 2cf 2c9 :6 2d0
:5 2d1 2d0 :5 2d3 2d2
:3 2d0 2c8 :2 2d6 :5 2d8
:11 2d9 :24 2da :3 2d9 :2 2d7
:6 2d6 2d5 :4 2c7 :3 2e0
:2 2e1 :2 2e2 :2 2e3 2e0
:6 2e4 :5 2e5 2e4 :5 2e7
2e6 :3 2e4 2df :2 2ea
:5 2ec :11 2ed :24 2ee :3 2ed
:2 2eb :6 2ea 2e9 :4 2de
:3 2c7 2c5 :5 2f5 :3 2f7
:4 2f8 :5 2f9 :5 2fa :4 2fb
:4 2fc :2 2fe :2 2ff :2 300
:2 301 :2 303 :2 304 :2 305
:2 306 :8 307 309 :6 30a
:2 30b :2 30c :2 30d :2 30e
2f7 :6 30f :5 310 30f
:5 312 311 :3 30f 2f6
:2 315 :5 317 :11 318 :24 319
:3 318 :2 316 :6 315 314
:4 2f5 :3 320 :4 321 :5 322
:5 323 :4 324 :4 325 :2 327
:2 328 :2 329 :2 32a :2 32c
:2 32d :2 32e :2 32f :8 330
332 :2 333 320 :6 334
:5 335 334 :5 337 336
:3 334 31f :2 33a :5 33c
:11 33d :24 33e :3 33d :2 33b
:6 33a 339 :4 31e :3 2f5
2f3 :3 2c5 344 2c4
:9 344 :3 346 :2 347 :2 348
:2 349 346 :6 34a :5 34b
34a :5 34d 34c :3 34a
345 :2 350 :5 352 :11 353
:24 354 :3 353 :2 351 :6 350
34f :4 344 :3 2c4 2c3
:e 35a :5 35b :5 35d :3 35f
:4 360 :6 361 :2 362 :2 363
:2 364 :2 365 35f :6 366
:5 367 366 :5 369 368
:3 366 35e :2 36c :5 36e
:11 36f :24 370 :3 36f :2 36d
:6 36c 36b :4 35d :3 376
:4 377 :2 378 :2 379 376
:6 37a :5 37b 37a :5 37d
37c :3 37a 375 :2 380
:5 382 :11 383 :24 384 :3 383
:2 381 :6 380 37f :4 374
:3 35d 35b :5 38b :3 38d
:4 38e :5 38f :5 390 :4 391
:4 392 :2 394 :2 395 :2 396
:2 397 :2 399 :2 39a :2 39b
:2 39c :8 39d 39f :6 3a0
:2 3a1 :2 3a2 :2 3a3 :2 3a4
38d :6 3a5 :5 3a6 3a5
:5 3a8 3a7 :3 3a5 38c
:2 3ab :5 3ad :11 3ae :24 3af
:3 3ae :2 3ac :6 3ab 3aa
:4 38b :3 3b5 :4 3b6 :2 3b7
:5 3b8 :5 3b9 :4 3ba :4 3bb
:2 3bd :2 3be :2 3bf :2 3c0
:2 3c2 :2 3c3 :2 3c4 :2 3c5
:8 3c6 3c8 :2 3c9 3b5
:6 3ca :5 3cb 3ca :5 3cd
3cc :3 3ca 3b4 :2 3d0
:5 3d2 :11 3d3 :24 3d4 :3 3d3
:2 3d1 :6 3d0 3cf :4 3b3
:3 38b 389 :3 35b 3da
35a :9 3da :5 3db :9 3dc
:3 3de :4 3df :2 3e0 :3 3e1
:2 3e2 3de :6 3e3 :5 3e4
3e3 :5 3e6 3e5 :3 3e3
3dd :2 3e9 :5 3eb :11 3ec
:24 3ed :3 3ec :2 3ea :6 3e9
3e8 :4 3dc :3 3f3 :4 3f4
:2 3f5 :2 3f6 3f3 :6 3f7
:5 3f8 3f7 :5 3fa 3f9
:3 3f7 3f2 :2 3fd :5 3ff
:11 400 :24 401 :3 400 :2 3fe
:6 3fd 3fc :4 3f1 :3 3dc
3db :3 408 :4 409 :2 40a
:2 40b 408 :6 40c :5 40d
40c :5 40f 40e :3 40c
407 :2 412 :5 414 :11 415
:24 416 :3 415 :2 413 :6 412
411 :4 406 :3 3db 3da
:3 35a 359 :3 2c3 :13 420
:2 421 :2 420 :4 421 :3 420
:3 422 :3 423 :3 424 :3 425
:9 427 :d 429 :9 42a 42b
:2 42c 429 :5 42d 428
:2 42f :5 431 :11 432 :24 433
:3 432 :2 430 :6 42f 42e
:4 427 :3 438 :c 43a :8 43b
43c :2 43d 43a :5 43e
439 :2 440 :5 442 :11 443
:24 444 :3 443 :2 441 :6 440
43f :4 437 :3 427 :a 44b
:1b 44c :2 44d :2 44c :4 44d
:3 44c :4 44f :4 450 44f
:6 451 :5 452 451 :5 454
453 :3 451 44e :2 457
:5 459 :11 45a :24 45b :3 45a
:2 458 :6 457 456 :3 44d
:3 461 :4 462 :4 463 :2 464
461 :6 465 :5 466 465
:5 468 467 :3 465 460
:2 46b :5 46d :11 46e :24 46f
:3 46e :2 46c :6 46b 46a
:4 44d :5 483 485 :7 486
:3 487 :5 488 487 :5 48a
489 :3 487 :7 48c :2 48d
:3 48c :f 491 :9 493 :d 494
:d 495 :7 496 495 :17 498
497 :3 495 :3 494 :6 49d
:6 49e :5 49f 49e :5 4a1
4a0 :3 49e 49c :2 4a4
:5 4a6 :11 4a7 :24 4a8 :3 4a7
:2 4a5 :6 4a4 4a3 :3 493
:3 4ad :3 493 :d 4b0 :2 4b1
:3 4b0 485 4b3 482
:4 4b6 :5 4b7 4b5 :2 4b9
:5 4bb :11 4bc :24 4bd :3 4bc
:2 4ba :6 4b9 4b8 :3 482
:12 4c3 :6 4c5 :6 4c6 :5 4c7
4c6 :5 4c9 4c8 :3 4c6
4c4 :2 4cc :5 4ce :11 4cf
:24 4d0 :3 4cf :2 4cd :6 4cc
4cb :6 4c3 482 :3 44c
:9 51d :e 51e :7 51f 51e
:7 521 520 :3 51e :3 51d
:3 44b 421 :2 420 :3 115
:7 528 :5 529 :3 528 :3 a7
:11 52f :30 530 :3 52f :a 532
61 :3 536 :11 537 :b 538
:17 539 :3 537 :2 53b :3 53c
:3 53d 53e 53c 53b
53c :3 53f :3 536 :2 540
:5 542 :11 543 :b 544 :18 545
:3 543 :2 547 548 :3 549
54a 548 547 548
:3 54b :2 541 :6 540 535
:7 1 
6537
4
:3 0 1 :3 0 2
:a 0 1cc6 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
56 0 7 6
:3 0 5 :7 0 9
8 :3 0 4 :3 0
7 :7 0 d c
:3 0 d 7c 0
b 4 :3 0 8
:7 0 11 10 :3 0
4 :3 0 9 :7 0
15 14 :3 0 11
a2 0 f 6
:3 0 a :7 0 19
18 :3 0 4 :3 0
b :7 0 1d 1c
:3 0 15 c8 0
13 6 :3 0 c
:7 0 21 20 :3 0
6 :3 0 d :7 0
25 24 :3 0 19
ee 0 17 6
:3 0 e :7 0 29
28 :3 0 6 :3 0
f :7 0 2d 2c
:3 0 1d 114 0
1b 6 :3 0 10
:7 0 31 30 :3 0
6 :3 0 11 :7 0
35 34 :3 0 21
13a 0 1f 4
:3 0 12 :7 0 39
38 :3 0 4 :3 0
13 :7 0 3d 3c
:3 0 25 160 0
23 6 :3 0 14
:7 0 41 40 :3 0
6 :3 0 15 :7 0
45 44 :3 0 29
186 0 27 4
:3 0 16 :7 0 49
48 :3 0 4 :3 0
17 :7 0 4d 4c
:3 0 2d :2 0 2b
6 :3 0 18 :7 0
51 50 :3 0 4
:3 0 19 :7 0 55
54 :3 0 1a :3 0
1b :3 0 1c :2 0
4 59 5a 0
57 5b 0 1cc6
2 5c :2 0 1e
:2 0 45 4 :3 0
1e :2 0 43 5f
61 :6 0 64 62
0 1cc4 0 1d
:6 0 21 :2 0 49
4 :3 0 47 66
68 :6 0 6b 69
0 1cc4 0 1f
:6 0 23 :2 0 4d
4 :3 0 4b 6d
6f :6 0 72 70
0 1cc4 0 20
:6 0 25 :2 0 51
4 :3 0 4f 74
76 :6 0 79 77
0 1cc4 0 22
:6 0 27 :2 0 55
4 :3 0 53 7b
7d :6 0 80 7e
0 1cc4 0 24
:6 0 27 :2 0 59
4 :3 0 57 82
84 :6 0 87 85
0 1cc4 0 26
:6 0 27 :2 0 5d
4 :3 0 5b 89
8b :6 0 8e 8c
0 1cc4 0 28
:6 0 27 :2 0 61
4 :3 0 5f 90
92 :6 0 95 93
0 1cc4 0 29
:6 0 27 :2 0 65
4 :3 0 63 97
99 :6 0 9c 9a
0 1cc4 0 2a
:6 0 27 :2 0 69
4 :3 0 67 9e
a0 :6 0 a3 a1
0 1cc4 0 2b
:6 0 27 :2 0 6d
4 :3 0 6b a5
a7 :6 0 aa a8
0 1cc4 0 2c
:6 0 27 :2 0 71
4 :3 0 6f ac
ae :6 0 b1 af
0 1cc4 0 2d
:6 0 27 :2 0 75
4 :3 0 73 b3
b5 :6 0 b8 b6
0 1cc4 0 2e
:6 0 31 :2 0 79
4 :3 0 77 ba
bc :6 0 bf bd
0 1cc4 0 2f
:6 0 31 :2 0 7b
6 :3 0 c1 :7 0
c5 c2 c3 1cc4
0 30 :6 0 31
:2 0 7d 6 :3 0
c7 :7 0 cb c8
c9 1cc4 0 32
:6 0 35 :2 0 7f
6 :3 0 cd :7 0
d1 ce cf 1cc4
0 33 :6 0 31
:2 0 81 6 :3 0
d3 :7 0 d7 d4
d5 1cc4 0 34
:6 0 31 :2 0 83
6 :3 0 d9 :7 0
dd da db 1cc4
0 36 :6 0 31
:2 0 85 6 :3 0
df :7 0 e3 e0
e1 1cc4 0 37
:6 0 31 :2 0 87
6 :3 0 e5 :7 0
e9 e6 e7 1cc4
0 38 :6 0 3b
:2 0 89 6 :3 0
eb :7 0 ef ec
ed 1cc4 0 39
:6 0 31 :2 0 8b
6 :3 0 f1 :7 0
f5 f2 f3 1cc4
0 3a :6 0 31
:2 0 8d 6 :3 0
f7 :7 0 fb f8
f9 1cc4 0 3c
:6 0 31 :2 0 8f
6 :3 0 fd :7 0
101 fe ff 1cc4
0 3d :6 0 31
:2 0 91 6 :3 0
103 :7 0 107 104
105 1cc4 0 3e
:6 0 31 :2 0 93
6 :3 0 109 :7 0
10d 10a 10b 1cc4
0 3f :6 0 31
:2 0 95 6 :3 0
10f :7 0 113 110
111 1cc4 0 40
:6 0 31 :2 0 97
6 :3 0 115 :7 0
119 116 117 1cc4
0 41 :6 0 9b
51c 0 99 6
:3 0 11b :7 0 11f
11c 11d 1cc4 0
42 :6 0 27 :2 0
9d 44 :3 0 121
:7 0 124 122 0
1cc4 0 43 :6 0
44 :3 0 126 :7 0
129 127 0 1cc4
0 45 :6 0 27
:2 0 a1 4 :3 0
9f 12b 12d :6 0
130 12e 0 1cc4
0 46 :6 0 49
:2 0 a5 4 :3 0
a3 132 134 :6 0
137 135 0 1cc4
0 47 :6 0 ab
5a7 0 a9 4
:3 0 a7 139 13b
:6 0 13e 13c 0
1cc4 0 48 :6 0
af 5db 0 ad
4b :3 0 140 :7 0
143 141 0 1cc4
0 4a :6 0 4b
:3 0 145 :7 0 148
146 0 1cc4 0
4c :6 0 b3 60f
0 b1 4b :3 0
14a :7 0 14d 14b
0 1cc4 0 4d
:6 0 4b :3 0 14f
:7 0 152 150 0
1cc4 0 4e :6 0
21 :2 0 b5 4b
:3 0 154 :7 0 157
155 0 1cc4 0
4f :6 0 4b :3 0
159 :7 0 15c 15a
0 1cc4 0 50
:6 0 31 :2 0 b9
4 :3 0 b7 15e
160 :6 0 163 161
0 1cc4 0 51
:6 0 31 :2 0 bb
6 :3 0 165 :7 0
169 166 167 1cc4
0 52 :6 0 31
:2 0 bd 6 :3 0
16b :7 0 16f 16c
16d 1cc4 0 53
:6 0 31 :2 0 bf
6 :3 0 171 :7 0
175 172 173 1cc4
0 54 :6 0 31
:2 0 c1 6 :3 0
177 :7 0 17b 178
179 1cc4 0 55
:6 0 31 :2 0 c3
6 :3 0 17d :7 0
181 17e 17f 1cc4
0 56 :6 0 31
:2 0 c5 6 :3 0
183 :7 0 187 184
185 1cc4 0 57
:6 0 c9 724 0
c7 6 :3 0 189
:7 0 18d 18a 18b
1cc4 0 58 :6 0
31 :2 0 cb 44
:3 0 18f :7 0 192
190 0 1cc4 0
59 :6 0 44 :3 0
194 :7 0 197 195
0 1cc4 0 5a
:6 0 31 :2 0 cd
5c :3 0 199 :7 0
19d 19a 19b 1cc4
0 5b :6 0 31
:2 0 cf 5c :3 0
19f :7 0 1a3 1a0
1a1 1cc4 0 5d
:6 0 31 :2 0 d1
6 :3 0 1a5 :7 0
1a9 1a6 1a7 1cc4
0 5e :6 0 31
:2 0 d3 6 :3 0
1ab :7 0 1af 1ac
1ad 1cc4 0 5f
:6 0 31 :2 0 d5
6 :3 0 1b1 :7 0
1b5 1b2 1b3 1cc4
0 60 :9 0 d7
6 :3 0 1b7 :7 0
1bb 1b8 1b9 1cc4
0 61 :6 0 62
:3 0 63 :a 0 2
1d0 :4 0 1bd 1c0
0 1be :3 0 64
:3 0 65 :3 0 66
:3 0 67 :3 0 65
:3 0 66 :3 0 68
:3 0 69 :3 0 6a
:3 0 2d :3 0 6b
:3 0 2e :3 0 6c
:3 0 6d :4 0 6e
1 :8 0 1d1 1bd
1c0 1d2 0 1cc4
d9 1d2 1d4 1d1
1d3 :6 0 1d0 :7 0
1d2 62 :3 0 6f
:a 0 3 1e5 :5 0
1d6 1d9 0 1d7
:3 0 70 :3 0 71
:3 0 72 :3 0 73
:3 0 6a :3 0 2d
:3 0 74 :3 0 46
:3 0 75 :3 0 72
:4 0 76 1 :8 0
1e6 1d6 1d9 1e7
0 1cc4 db 1e7
1e9 1e6 1e8 :6 0
1e5 :7 0 1e7 1f1
1f2 0 dd 1b
:3 0 1c :2 0 4
1eb 1ec 0 1ed
:7 0 1f0 1ee 0
1cc4 0 77 :6 0
78 :3 0 79 :3 0
78 :3 0 7a :3 0
1f4 1f5 0 2
:4 0 df 1f6 1f8
1f3 1fa 1f9 :2 0
7b :3 0 7c :3 0
1fc 1fd 0 7d
:4 0 78 :3 0 7e
:3 0 200 201 0
2 :4 0 e1 202
204 7f :4 0 80
:2 0 81 :3 0 e3
207 209 :3 0 82
:4 0 80 :2 0 83
:4 0 e6 20c 20e
:3 0 80 :2 0 3
:3 0 e9 210 212
:3 0 80 :2 0 83
:4 0 ec 214 216
:3 0 80 :2 0 84
:4 0 ef 218 21a
:3 0 80 :2 0 85
:3 0 66 :3 0 5
:3 0 f2 21e 220
86 :4 0 f4 21d
223 f7 21c 225
:3 0 80 :2 0 84
:4 0 fa 227 229
:3 0 80 :2 0 83
:4 0 fd 22b 22d
:3 0 80 :2 0 7
:3 0 100 22f 231
:3 0 80 :2 0 83
:4 0 103 233 235
:3 0 80 :2 0 84
:4 0 106 237 239
:3 0 80 :2 0 83
:4 0 109 23b 23d
:3 0 80 :2 0 8
:3 0 10c 23f 241
:3 0 80 :2 0 83
:4 0 10f 243 245
:3 0 80 :2 0 84
:4 0 112 247 249
:3 0 80 :2 0 83
:4 0 115 24b 24d
:3 0 80 :2 0 9
:3 0 118 24f 251
:3 0 80 :2 0 83
:4 0 11b 253 255
:3 0 80 :2 0 84
:4 0 11e 257 259
:3 0 80 :2 0 85
:3 0 66 :3 0 a
:3 0 121 25d 25f
86 :4 0 123 25c
262 126 25b 264
:3 0 80 :2 0 84
:4 0 129 266 268
:3 0 80 :2 0 83
:4 0 12c 26a 26c
:3 0 80 :2 0 b
:3 0 12f 26e 270
:3 0 80 :2 0 83
:4 0 132 272 274
:3 0 80 :2 0 84
:4 0 135 276 278
:3 0 80 :2 0 85
:3 0 66 :3 0 c
:3 0 138 27c 27e
86 :4 0 13a 27b
281 13d 27a 283
:3 0 80 :2 0 84
:4 0 140 285 287
:3 0 80 :2 0 85
:3 0 66 :3 0 d
:3 0 143 28b 28d
86 :4 0 145 28a
290 148 289 292
:3 0 80 :2 0 84
:4 0 14b 294 296
:3 0 80 :2 0 85
:3 0 66 :3 0 e
:3 0 14e 29a 29c
86 :4 0 150 299
29f 153 298 2a1
:3 0 80 :2 0 84
:4 0 156 2a3 2a5
:3 0 80 :2 0 85
:3 0 66 :3 0 f
:3 0 159 2a9 2ab
86 :4 0 15b 2a8
2ae 15e 2a7 2b0
:3 0 80 :2 0 84
:4 0 161 2b2 2b4
:3 0 80 :2 0 85
:3 0 66 :3 0 10
:3 0 164 2b8 2ba
86 :4 0 166 2b7
2bd 169 2b6 2bf
:3 0 80 :2 0 84
:4 0 16c 2c1 2c3
:3 0 80 :2 0 85
:3 0 66 :3 0 11
:3 0 16f 2c7 2c9
86 :4 0 171 2c6
2cc 174 2c5 2ce
:3 0 80 :2 0 84
:4 0 177 2d0 2d2
:3 0 80 :2 0 83
:4 0 17a 2d4 2d6
:3 0 80 :2 0 12
:3 0 17d 2d8 2da
:3 0 80 :2 0 83
:4 0 180 2dc 2de
:3 0 80 :2 0 84
:4 0 183 2e0 2e2
:3 0 80 :2 0 83
:4 0 186 2e4 2e6
:3 0 80 :2 0 13
:3 0 189 2e8 2ea
:3 0 80 :2 0 83
:4 0 18c 2ec 2ee
:3 0 80 :2 0 84
:4 0 18f 2f0 2f2
:3 0 80 :2 0 85
:3 0 66 :3 0 14
:3 0 192 2f6 2f8
86 :4 0 194 2f5
2fb 197 2f4 2fd
:3 0 80 :2 0 84
:4 0 19a 2ff 301
:3 0 80 :2 0 85
:3 0 66 :3 0 15
:3 0 19d 305 307
86 :4 0 19f 304
30a 1a2 303 30c
:3 0 80 :2 0 84
:4 0 1a5 30e 310
:3 0 80 :2 0 83
:4 0 1a8 312 314
:3 0 80 :2 0 16
:3 0 1ab 316 318
:3 0 80 :2 0 83
:4 0 1ae 31a 31c
:3 0 80 :2 0 84
:4 0 1b1 31e 320
:3 0 80 :2 0 83
:4 0 1b4 322 324
:3 0 80 :2 0 17
:3 0 1b7 326 328
:3 0 80 :2 0 83
:4 0 1ba 32a 32c
:3 0 80 :2 0 84
:4 0 1bd 32e 330
:3 0 80 :2 0 85
:3 0 66 :3 0 18
:3 0 1c0 334 336
86 :4 0 1c2 333
339 1c5 332 33b
:3 0 80 :2 0 84
:4 0 1c8 33d 33f
:3 0 80 :2 0 83
:4 0 1cb 341 343
:3 0 80 :2 0 19
:3 0 1ce 345 347
:3 0 80 :2 0 83
:4 0 1d1 349 34b
:3 0 80 :2 0 87
:4 0 1d4 34d 34f
:3 0 1d7 1fe 351
:2 0 353 1dc 354
1fb 353 0 355
1de 0 1c24 78
:3 0 79 :3 0 356
357 0 78 :3 0
88 :3 0 359 35a
0 49 :2 0 2
:4 0 89 :2 0 8a
:2 0 49 :2 0 1e0
35f 361 :3 0 1e3
35b 363 358 365
364 :2 0 7b :3 0
8b :3 0 367 368
0 7d :4 0 8c
:4 0 80 :2 0 81
:3 0 1e7 36c 36e
:3 0 1ea 369 370
:2 0 372 1ed 373
366 372 0 374
1ef 0 1c24 5
:3 0 8d :2 0 1f1
376 377 :3 0 378
:2 0 379 :2 0 85
:3 0 5 :3 0 31
:2 0 1f3 37b 37e
8e :2 0 49 :2 0
1f8 380 382 :3 0
383 :2 0 85 :3 0
5 :3 0 31 :2 0
1fb 385 388 8f
:2 0 90 :2 0 200
38a 38c :3 0 38d
:2 0 384 38f 38e
:2 0 390 :2 0 37a
392 391 :2 0 78
:3 0 79 :3 0 394
395 0 78 :3 0
88 :3 0 397 398
0 91 :2 0 2
:4 0 92 :2 0 8a
:2 0 49 :2 0 203
39d 39f :3 0 206
399 3a1 396 3a3
3a2 :2 0 7b :3 0
8b :3 0 3a5 3a6
0 7d :4 0 93
:4 0 80 :2 0 81
:3 0 20a 3aa 3ac
:3 0 80 :2 0 94
:4 0 20d 3ae 3b0
:3 0 80 :2 0 95
:4 0 210 3b2 3b4
:3 0 80 :2 0 85
:3 0 66 :3 0 96
:3 0 97 :3 0 3b9
3ba 0 213 3b8
3bc 86 :4 0 215
3b7 3bf 218 3b6
3c1 :3 0 21b 3a7
3c3 :2 0 3c5 21e
3c6 3a4 3c5 0
3c7 220 0 3f0
78 :3 0 79 :3 0
3c8 3c9 0 78
:3 0 88 :3 0 3cb
3cc 0 49 :2 0
2 :4 0 98 :2 0
8a :2 0 49 :2 0
222 3d1 3d3 :3 0
225 3cd 3d5 3ca
3d7 3d6 :2 0 7b
:3 0 8b :3 0 3d9
3da 0 7d :4 0
99 :4 0 80 :2 0
81 :3 0 229 3de
3e0 :3 0 22c 3db
3e2 :2 0 3e4 22f
3e5 3d8 3e4 0
3e6 231 0 3f0
9a :3 0 9b :3 0
3e7 3e8 0 96
:3 0 97 :3 0 3ea
3eb 0 9c :3 0
233 3e9 3ee :2 0
3f0 236 3f1 393
3f0 0 3f2 23a
0 1c24 3 :3 0
8d :2 0 23c 3f4
3f5 :3 0 3f6 :2 0
3f7 :2 0 f :3 0
8d :2 0 23e 3fa
3fb :3 0 3fc :2 0
3fd :2 0 3f8 3ff
3fe :2 0 19 :3 0
8d :2 0 240 402
403 :3 0 404 :2 0
405 :2 0 400 407
406 :2 0 78 :3 0
79 :3 0 409 40a
0 78 :3 0 88
:3 0 40c 40d 0
91 :2 0 2 :4 0
9d :2 0 8a :2 0
49 :2 0 242 412
414 :3 0 245 40e
416 40b 418 417
:2 0 7b :3 0 8b
:3 0 41a 41b 0
7d :4 0 9e :4 0
80 :2 0 81 :3 0
249 41f 421 :3 0
80 :2 0 94 :4 0
24c 423 425 :3 0
80 :2 0 95 :4 0
24f 427 429 :3 0
80 :2 0 85 :3 0
66 :3 0 96 :3 0
97 :3 0 42e 42f
0 252 42d 431
86 :4 0 254 42c
434 257 42b 436
:3 0 25a 41c 438
:2 0 43a 25d 43b
419 43a 0 43c
25f 0 465 78
:3 0 79 :3 0 43d
43e 0 78 :3 0
88 :3 0 440 441
0 49 :2 0 2
:4 0 9f :2 0 8a
:2 0 49 :2 0 261
446 448 :3 0 264
442 44a 43f 44c
44b :2 0 7b :3 0
8b :3 0 44e 44f
0 7d :4 0 a0
:4 0 80 :2 0 81
:3 0 268 453 455
:3 0 26b 450 457
:2 0 459 26e 45a
44d 459 0 45b
270 0 465 9a
:3 0 9b :3 0 45c
45d 0 96 :3 0
97 :3 0 45f 460
0 9c :3 0 272
45e 463 :2 0 465
275 466 408 465
0 467 279 0
1c24 4d :4 0 468
469 0 1c24 4f
:4 0 46b 46c 0
1c24 32 :3 0 a1
:2 0 46e 46f 0
1c24 4c :3 0 8
:3 0 471 472 0
1c24 4e :3 0 9
:3 0 474 475 0
1c24 51 :3 0 b
:3 0 477 478 0
1c24 2f :3 0 19
:3 0 47a 47b 0
1c24 3d :3 0 a
:3 0 47d 47e 0
1c24 41 :3 0 f
:3 0 480 481 0
1c24 57 :3 0 5
:3 0 483 484 0
1c24 39 :3 0 10
:3 0 486 487 0
1c24 4d :3 0 16
:3 0 489 48a 0
1c24 42 :3 0 c
:3 0 48c 48d 0
1c24 55 :3 0 31
:2 0 48f 490 0
1c24 85 :3 0 a2
:3 0 51 :3 0 27b
493 495 31 :2 0
27d 492 498 96
:3 0 8e :2 0 a3
:3 0 49a 49c 0
282 49b 49e :3 0
85 :3 0 57 :3 0
31 :2 0 285 4a0
4a3 a4 :2 0 49
:2 0 28a 4a5 4a7
:3 0 4a8 :2 0 85
:3 0 57 :3 0 31
:2 0 28d 4aa 4ad
a4 :2 0 90 :2 0
292 4af 4b1 :3 0
4b2 :2 0 4a9 4b4
4b3 :2 0 7 :3 0
8d :2 0 295 4b7
4b8 :3 0 4b9 :2 0
78 :3 0 79 :3 0
4bb 4bc 0 78
:3 0 88 :3 0 4be
4bf 0 91 :2 0
2 :4 0 a5 :2 0
8a :2 0 49 :2 0
297 4c4 4c6 :3 0
29a 4c0 4c8 4bd
4ca 4c9 :2 0 7b
:3 0 8b :3 0 4cc
4cd 0 7d :4 0
a6 :4 0 80 :2 0
81 :3 0 29e 4d1
4d3 :3 0 80 :2 0
94 :4 0 2a1 4d5
4d7 :3 0 80 :2 0
95 :4 0 2a4 4d9
4db :3 0 80 :2 0
85 :3 0 66 :3 0
96 :3 0 97 :3 0
4e0 4e1 0 2a7
4df 4e3 86 :4 0
2a9 4de 4e6 2ac
4dd 4e8 :3 0 2af
4ce 4ea :2 0 4ec
2b2 4ed 4cb 4ec
0 4ee 2b4 0
517 78 :3 0 79
:3 0 4ef 4f0 0
78 :3 0 88 :3 0
4f2 4f3 0 49
:2 0 2 :4 0 a7
:2 0 8a :2 0 49
:2 0 2b6 4f8 4fa
:3 0 2b9 4f4 4fc
4f1 4fe 4fd :2 0
7b :3 0 8b :3 0
500 501 0 7d
:4 0 a8 :4 0 80
:2 0 81 :3 0 2bd
505 507 :3 0 2c0
502 509 :2 0 50b
2c3 50c 4ff 50b
0 50d 2c5 0
517 9a :3 0 9b
:3 0 50e 50f 0
96 :3 0 97 :3 0
511 512 0 9c
:3 0 2c7 510 515
:2 0 517 2ca 518
4ba 517 0 519
2ce 0 6ac 2c
:3 0 3 :3 0 51a
51b 0 6ac 2e
:3 0 7 :3 0 51d
51e 0 6ac 2f
:3 0 19 :3 0 520
521 0 6ac 6a
:3 0 a9 :3 0 2d
:3 0 30 :3 0 69
:3 0 6b :3 0 2e
:4 0 aa 1 :8 0
530 1b :3 0 ab
:3 0 52b 52c 0
ac :3 0 52d 52e
0 530 2d0 57a
ad :3 0 1b :3 0
ab :3 0 533 534
0 ac :3 0 535
536 0 570 78
:3 0 79 :3 0 538
539 0 78 :3 0
88 :3 0 53b 53c
0 25 :2 0 2
:4 0 ae :2 0 8a
:2 0 49 :2 0 2d3
541 543 :3 0 2d6
53d 545 53a 547
546 :2 0 7b :3 0
8b :3 0 549 54a
0 7d :4 0 af
:4 0 80 :2 0 81
:3 0 2da 54e 550
:3 0 80 :2 0 94
:4 0 2dd 552 554
:3 0 80 :2 0 b0
:4 0 2e0 556 558
:3 0 80 :2 0 ac
:3 0 2e3 55a 55c
:3 0 80 :2 0 b1
:4 0 2e6 55e 560
:3 0 80 :2 0 b2
:3 0 b3 :3 0 49
:2 0 b4 :2 0 2e9
563 567 2ed 562
569 :3 0 2f0 54b
56b :2 0 56d 2f3
56e 548 56d 0
56f 2f5 0 570
2f7 573 :3 0 573
0 573 572 570
571 :6 0 575 4
:3 0 2fa 577 2fc
576 575 :2 0 578
2fe :2 0 57a 0
57a 579 530 578
:6 0 6ac 1 :3 0
2b :3 0 b5 :4 0
57d 57e :3 0 57c
57f 0 6ac 52
:3 0 b6 :3 0 85
:3 0 30 :3 0 31
:2 0 300 583 586
303 582 588 581
589 0 6ac 1b
:3 0 ab :3 0 58b
58c 0 b7 :3 0
52 :3 0 30 :3 0
2e :3 0 2c :3 0
2f :3 0 2b :3 0
305 58e 595 58d
596 0 6ac 1b
:3 0 ab :3 0 598
599 0 a4 :2 0
31 :2 0 30e 59b
59d :3 0 59e :2 0
85 :3 0 57 :3 0
31 :2 0 311 5a0
5a3 a4 :2 0 90
:2 0 316 5a5 5a7
:3 0 5a8 :2 0 59f
5aa 5a9 :2 0 85
:3 0 3d :3 0 31
:2 0 319 5ac 5af
a4 :2 0 31 :2 0
31e 5b1 5b3 :3 0
5b4 :2 0 5ab 5b6
5b5 :2 0 53 :3 0
31 :2 0 5b8 5b9
0 68a b8 :3 0
53 :3 0 b9 :3 0
ba :3 0 6a :3 0
2d :3 0 bb :3 0
2c :4 0 bc 1
:8 0 5c9 1b :3 0
ab :3 0 5c4 5c5
0 ac :3 0 5c6
5c7 0 5c9 321
613 ad :3 0 1b
:3 0 ab :3 0 5cc
5cd 0 ac :3 0
5ce 5cf 0 609
78 :3 0 79 :3 0
5d1 5d2 0 78
:3 0 88 :3 0 5d4
5d5 0 25 :2 0
2 :4 0 bd :2 0
8a :2 0 49 :2 0
324 5da 5dc :3 0
327 5d6 5de 5d3
5e0 5df :2 0 7b
:3 0 8b :3 0 5e2
5e3 0 7d :4 0
be :4 0 80 :2 0
81 :3 0 32b 5e7
5e9 :3 0 80 :2 0
94 :4 0 32e 5eb
5ed :3 0 80 :2 0
b0 :4 0 331 5ef
5f1 :3 0 80 :2 0
ac :3 0 334 5f3
5f5 :3 0 80 :2 0
b1 :4 0 337 5f7
5f9 :3 0 80 :2 0
b2 :3 0 b3 :3 0
49 :2 0 b4 :2 0
33a 5fc 600 33e
5fb 602 :3 0 341
5e4 604 :2 0 606
344 607 5e1 606
0 608 346 0
609 348 60c :3 0
60c 0 60c 60b
609 60a :6 0 60e
6 :3 0 34b 610
34d 60f 60e :2 0
611 34f :2 0 613
0 613 612 5c9
611 :6 0 68a 1
:3 0 85 :3 0 53
:3 0 31 :2 0 351
615 618 bf :2 0
31 :2 0 356 61a
61c :3 0 57 :3 0
49 :2 0 61e 61f
0 687 3d :3 0
c0 :2 0 621 622
0 687 51 :3 0
c1 :4 0 624 625
0 687 4c :3 0
c2 :2 0 359 628
629 :3 0 62a :2 0
c3 :3 0 c4 :3 0
c5 :3 0 4c :3 0
4e :3 0 b9 :4 0
c6 1 :8 0 638
1b :3 0 ab :3 0
633 634 0 ac
:3 0 635 636 0
638 35b 682 ad
:3 0 1b :3 0 ab
:3 0 63b 63c 0
ac :3 0 63d 63e
0 678 78 :3 0
79 :3 0 640 641
0 78 :3 0 88
:3 0 643 644 0
25 :2 0 2 :4 0
c7 :2 0 8a :2 0
49 :2 0 35e 649
64b :3 0 361 645
64d 642 64f 64e
:2 0 7b :3 0 8b
:3 0 651 652 0
7d :4 0 c8 :4 0
80 :2 0 81 :3 0
365 656 658 :3 0
80 :2 0 94 :4 0
368 65a 65c :3 0
80 :2 0 b0 :4 0
36b 65e 660 :3 0
80 :2 0 ac :3 0
36e 662 664 :3 0
80 :2 0 b1 :4 0
371 666 668 :3 0
80 :2 0 b2 :3 0
b3 :3 0 49 :2 0
b4 :2 0 374 66b
66f 378 66a 671
:3 0 37b 653 673
:2 0 675 37e 676
650 675 0 677
380 0 678 382
67b :3 0 67b 0
67b 67a 678 679
:6 0 67d 8 :3 0
385 67f 387 67e
67d :2 0 680 389
:2 0 682 0 682
681 638 680 :6 0
684 1 :3 0 38b
685 62b 684 0
686 38d 0 687
38f 688 61d 687
0 689 394 0
68a 396 68b 5b7
68a 0 68c 39a
0 6ac 85 :3 0
57 :3 0 31 :2 0
39c 68d 690 a4
:2 0 49 :2 0 3a1
692 694 :3 0 695
:2 0 c9 :3 0 85
:3 0 30 :3 0 31
:2 0 3a4 698 69b
3a7 697 69d 69e
:2 0 bf :2 0 31
:2 0 3ab 6a0 6a2
:3 0 696 6a4 6a3
:2 0 57 :3 0 90
:2 0 6a6 6a7 0
6a9 3ae 6aa 6a5
6a9 0 6ab 3b0
0 6ac 3b2 740
2b :3 0 3 :3 0
6ad 6ae 0 73f
6a :3 0 ca :3 0
cb :3 0 cc :3 0
cd :3 0 ce :3 0
cf :3 0 d0 :3 0
d1 :3 0 6c :3 0
2d :3 0 2e :3 0
2c :3 0 42 :3 0
47 :3 0 61 :3 0
36 :3 0 37 :3 0
38 :3 0 4f :3 0
d2 :3 0 74 :3 0
2b :4 0 d3 1
:8 0 6cd 1b :3 0
ab :3 0 6c8 6c9
0 ac :3 0 6ca
6cb 0 6cd 3bd
717 ad :3 0 1b
:3 0 ab :3 0 6d0
6d1 0 ac :3 0
6d2 6d3 0 70d
78 :3 0 79 :3 0
6d5 6d6 0 78
:3 0 88 :3 0 6d8
6d9 0 25 :2 0
2 :4 0 d4 :2 0
8a :2 0 49 :2 0
3c0 6de 6e0 :3 0
3c3 6da 6e2 6d7
6e4 6e3 :2 0 7b
:3 0 8b :3 0 6e6
6e7 0 7d :4 0
d5 :4 0 80 :2 0
81 :3 0 3c7 6eb
6ed :3 0 80 :2 0
94 :4 0 3ca 6ef
6f1 :3 0 80 :2 0
b0 :4 0 3cd 6f3
6f5 :3 0 80 :2 0
ac :3 0 3d0 6f7
6f9 :3 0 80 :2 0
b1 :4 0 3d3 6fb
6fd :3 0 80 :2 0
b2 :3 0 b3 :3 0
49 :2 0 b4 :2 0
3d6 700 704 3da
6ff 706 :3 0 3dd
6e8 708 :2 0 70a
3e0 70b 6e5 70a
0 70c 3e2 0
70d 3e4 710 :3 0
710 0 710 70f
70d 70e :6 0 712
a :3 0 3e7 714
3e9 713 712 :2 0
715 3eb :2 0 717
0 717 716 6cd
715 :6 0 73f 1
:3 0 1b :3 0 ab
:3 0 719 71a 0
1b :3 0 a4 :2 0
d6 :3 0 71c 71e
0 3ef 71d 720
:3 0 721 :2 0 85
:3 0 c :3 0 31
:2 0 3f2 723 726
85 :3 0 bf :2 0
42 :3 0 31 :2 0
3f5 728 72c 3fa
729 72e :3 0 72f
:2 0 722 731 730
:2 0 4d :4 0 733
734 0 73c 3e
:3 0 d7 :2 0 49
:2 0 3fd 737 739
:3 0 736 73a 0
73c 3ff 73d 732
73c 0 73e 402
0 73f 404 741
4b5 6ac 0 742
0 73f 0 742
408 0 1bd3 85
:3 0 57 :3 0 31
:2 0 40b 743 746
bf :2 0 90 :2 0
410 748 74a :3 0
1b :3 0 ab :3 0
74c 74d 0 bf
:2 0 31 :2 0 415
74f 751 :3 0 78
:3 0 79 :3 0 753
754 0 78 :3 0
88 :3 0 756 757
0 27 :2 0 2
:4 0 d8 :2 0 8a
:2 0 49 :2 0 418
75c 75e :3 0 41b
758 760 755 762
761 :2 0 7b :3 0
8b :3 0 764 765
0 7d :4 0 d9
:4 0 80 :2 0 81
:3 0 41f 769 76b
:3 0 80 :2 0 94
:4 0 422 76d 76f
:3 0 80 :2 0 95
:4 0 425 771 773
:3 0 80 :2 0 85
:3 0 66 :3 0 1b
:3 0 ab :3 0 778
779 0 428 777
77b 86 :4 0 42a
776 77e 42d 775
780 :3 0 80 :2 0
da :4 0 430 782
784 :3 0 80 :2 0
83 :4 0 433 786
788 :3 0 80 :2 0
2b :3 0 436 78a
78c :3 0 80 :2 0
83 :4 0 439 78e
790 :3 0 43c 766
792 :2 0 794 43f
795 763 794 0
796 441 0 7c0
78 :3 0 79 :3 0
797 798 0 78
:3 0 88 :3 0 79a
79b 0 49 :2 0
2 :4 0 db :2 0
8a :2 0 49 :2 0
443 7a0 7a2 :3 0
446 79c 7a4 799
7a6 7a5 :2 0 7b
:3 0 8b :3 0 7a8
7a9 0 7d :4 0
dc :4 0 80 :2 0
81 :3 0 44a 7ad
7af :3 0 44d 7aa
7b1 :2 0 7b3 450
7b4 7a7 7b3 0
7b5 452 0 7c0
9a :3 0 dd :3 0
7b6 7b7 0 1b
:3 0 ab :3 0 7b9
7ba 0 2b :3 0
9c :3 0 454 7b8
7be :2 0 7c0 458
7c1 752 7c0 0
7c2 45c 0 1bc1
4c :3 0 8d :2 0
45e 7c4 7c5 :3 0
7c6 :2 0 4e :3 0
8d :2 0 460 7c9
7ca :3 0 7cb :2 0
7c7 7cd 7cc :2 0
3d :3 0 8d :2 0
462 7d0 7d1 :3 0
7d2 :2 0 7ce 7d4
7d3 :2 0 51 :3 0
8d :2 0 464 7d7
7d8 :3 0 7d9 :2 0
7d5 7db 7da :2 0
78 :3 0 79 :3 0
7dd 7de 0 78
:3 0 88 :3 0 7e0
7e1 0 91 :2 0
2 :4 0 de :2 0
8a :2 0 49 :2 0
466 7e6 7e8 :3 0
469 7e2 7ea 7df
7ec 7eb :2 0 7b
:3 0 8b :3 0 7ee
7ef 0 7d :4 0
df :4 0 80 :2 0
81 :3 0 46d 7f3
7f5 :3 0 80 :2 0
94 :4 0 470 7f7
7f9 :3 0 80 :2 0
95 :4 0 473 7fb
7fd :3 0 80 :2 0
85 :3 0 66 :3 0
96 :3 0 97 :3 0
802 803 0 476
801 805 86 :4 0
478 800 808 47b
7ff 80a :3 0 47e
7f0 80c :2 0 80e
481 80f 7ed 80e
0 810 483 0
839 78 :3 0 79
:3 0 811 812 0
78 :3 0 88 :3 0
814 815 0 49
:2 0 2 :4 0 e0
:2 0 8a :2 0 49
:2 0 485 81a 81c
:3 0 488 816 81e
813 820 81f :2 0
7b :3 0 8b :3 0
822 823 0 7d
:4 0 e1 :4 0 80
:2 0 81 :3 0 48c
827 829 :3 0 48f
824 82b :2 0 82d
492 82e 821 82d
0 82f 494 0
839 9a :3 0 9b
:3 0 830 831 0
96 :3 0 97 :3 0
833 834 0 9c
:3 0 496 832 837
:2 0 839 499 83a
7dc 839 0 83b
49d 0 1bc1 3c
:3 0 96 :3 0 e2
:3 0 83d 83e 0
83c 83f 0 1bc1
85 :3 0 39 :3 0
31 :2 0 49f 841
844 8f :2 0 e3
:2 0 4a4 846 848
:3 0 39 :3 0 e3
:2 0 84a 84b 0
84d 4a7 84e 849
84d 0 84f 4a9
0 1bc1 85 :3 0
e4 :3 0 3a :3 0
69 :3 0 6b :3 0
2e :4 0 e5 1
:8 0 85c 1b :3 0
ab :3 0 857 858
0 ac :3 0 859
85a 0 85c 4ab
8a6 ad :3 0 1b
:3 0 ab :3 0 85f
860 0 ac :3 0
861 862 0 89c
78 :3 0 79 :3 0
864 865 0 78
:3 0 88 :3 0 867
868 0 25 :2 0
2 :4 0 e6 :2 0
8a :2 0 49 :2 0
4ae 86d 86f :3 0
4b1 869 871 866
873 872 :2 0 7b
:3 0 8b :3 0 875
876 0 7d :4 0
e7 :4 0 80 :2 0
81 :3 0 4b5 87a
87c :3 0 80 :2 0
94 :4 0 4b8 87e
880 :3 0 80 :2 0
b0 :4 0 4bb 882
884 :3 0 80 :2 0
ac :3 0 4be 886
888 :3 0 80 :2 0
b1 :4 0 4c1 88a
88c :3 0 80 :2 0
b2 :3 0 b3 :3 0
49 :2 0 b4 :2 0
4c4 88f 893 4c8
88e 895 :3 0 4cb
877 897 :2 0 899
4ce 89a 874 899
0 89b 4d0 0
89c 4d2 89f :3 0
89f 0 89f 89e
89c 89d :6 0 8a1
c :3 0 4d5 8a3
4d7 8a2 8a1 :2 0
8a4 4d9 :2 0 8a6
0 8a6 8a5 85c
8a4 :6 0 1bc1 1
:3 0 85 :3 0 36
:3 0 31 :2 0 4db
8a8 8ab 8f :2 0
31 :2 0 4e0 8ad
8af :3 0 53 :3 0
e8 :3 0 85 :3 0
e9 :3 0 36 :3 0
4e3 8b4 8b6 31
:2 0 4e5 8b3 8b9
ea :2 0 85 :3 0
e9 :3 0 3a :3 0
4e8 8bd 8bf 31
:2 0 4ea 8bc 8c2
4ed 8bb 8c4 :3 0
8c5 :2 0 eb :2 0
ec :2 0 4f0 8c7
8c9 :3 0 8ca :2 0
8a :2 0 ed :2 0
4f3 8cc 8ce :3 0
4f6 8b2 8d0 8b1
8d1 0 8ee 85
:3 0 39 :3 0 31
:2 0 4f8 8d3 8d6
85 :3 0 bf :2 0
53 :3 0 31 :2 0
4fb 8d8 8dc 500
8d9 8de :3 0 36
:3 0 31 :2 0 8e0
8e1 0 8e6 37
:3 0 31 :2 0 8e3
8e4 0 8e6 503
8eb 39 :3 0 31
:2 0 8e7 8e8 0
8ea 506 8ec 8df
8e6 0 8ed 0
8ea 0 8ed 508
0 8ee 50b 8ef
8b0 8ee 0 8f0
50e 0 1bc1 48
:4 0 8f1 8f2 0
1bc1 ee :3 0 85
:3 0 f :3 0 31
:2 0 510 8f5 8f8
25 :2 0 513 8f4
8fb 8fc :2 0 a4
:2 0 25 :2 0 518
8fe 900 :3 0 85
:3 0 57 :3 0 31
:2 0 51b 902 905
a4 :2 0 49 :2 0
520 907 909 :3 0
85 :3 0 c :3 0
31 :2 0 523 90b
90e 8f :2 0 31
:2 0 528 910 912
:3 0 1b :3 0 ab
:3 0 914 915 0
ef :3 0 2b :3 0
48 :3 0 48 :3 0
32 :3 0 4c :3 0
4e :3 0 3d :3 0
36 :3 0 33 :3 0
33 :3 0 34 :3 0
3c :3 0 37 :3 0
38 :3 0 55 :3 0
51 :3 0 2f :3 0
52b 917 929 916
92a 0 9a7 1b
:3 0 ab :3 0 92c
92d 0 a4 :2 0
31 :2 0 53f 92f
931 :3 0 d2 :3 0
f0 :3 0 e :3 0
f1 :3 0 f2 :3 0
f3 :3 0 f4 :3 0
f5 :3 0 f6 :3 0
6a :3 0 2d :3 0
ca :3 0 2e :3 0
cb :3 0 2c :4 0
f7 1 :8 0 958
f8 :4 0 943 :3 0
9c :3 0 a4 :2 0
544 946 947 :3 0
1b :3 0 ab :3 0
949 94a 0 31
:2 0 94b 94c 0
94e 547 955 1b
:3 0 ab :3 0 94f
950 0 f9 :2 0
951 952 0 954
549 956 948 94e
0 957 0 954
0 957 54b 0
958 54e 9a2 ad
:3 0 1b :3 0 ab
:3 0 95b 95c 0
ac :3 0 95d 95e
0 998 78 :3 0
79 :3 0 960 961
0 78 :3 0 88
:3 0 963 964 0
25 :2 0 2 :4 0
fa :2 0 8a :2 0
49 :2 0 551 969
96b :3 0 554 965
96d 962 96f 96e
:2 0 7b :3 0 8b
:3 0 971 972 0
7d :4 0 fb :4 0
80 :2 0 81 :3 0
558 976 978 :3 0
80 :2 0 94 :4 0
55b 97a 97c :3 0
80 :2 0 b0 :4 0
55e 97e 980 :3 0
80 :2 0 ac :3 0
561 982 984 :3 0
80 :2 0 b1 :4 0
564 986 988 :3 0
80 :2 0 b2 :3 0
b3 :3 0 49 :2 0
b4 :2 0 567 98b
98f 56b 98a 991
:3 0 56e 973 993
:2 0 995 571 996
970 995 0 997
573 0 998 575
99b :3 0 99b 0
99b 99a 998 999
:6 0 99d e :3 0
578 99f 57a 99e
99d :2 0 9a0 57c
:2 0 9a2 0 9a2
9a1 958 9a0 :6 0
9a4 1 :3 0 57e
9a5 932 9a4 0
9a6 580 0 9a7
582 9c1 1b :3 0
ab :3 0 9a8 9a9
0 ef :3 0 2b
:3 0 48 :3 0 48
:3 0 32 :3 0 4c
:3 0 4e :3 0 3d
:3 0 36 :3 0 33
:3 0 33 :3 0 33
:3 0 3c :3 0 37
:3 0 38 :3 0 55
:3 0 51 :3 0 2f
:3 0 585 9ab 9bd
9aa 9be 0 9c0
597 9c2 913 9a7
0 9c3 0 9c0
0 9c3 599 0
9c4 59c a86 3c
:3 0 85 :3 0 3c
:3 0 31 :2 0 59e
9c6 9c9 8a :2 0
49 :2 0 5a1 9cb
9cd :3 0 9c5 9ce
0 a85 85 :3 0
c :3 0 31 :2 0
5a4 9d0 9d3 8f
:2 0 31 :2 0 5a9
9d5 9d7 :3 0 1b
:3 0 ab :3 0 9d9
9da 0 ef :3 0
2b :3 0 48 :3 0
48 :3 0 32 :3 0
4c :3 0 4e :3 0
3d :3 0 36 :3 0
33 :3 0 33 :3 0
34 :3 0 3c :3 0
37 :3 0 38 :3 0
55 :3 0 51 :3 0
2f :3 0 5ac 9dc
9ee 9db 9ef 0
a68 1b :3 0 ab
:3 0 9f1 9f2 0
a4 :2 0 31 :2 0
5c0 9f4 9f6 :3 0
d2 :3 0 f0 :3 0
e :3 0 f1 :3 0
f2 :3 0 f3 :3 0
f4 :3 0 f5 :3 0
f6 :3 0 74 :3 0
2b :4 0 fc 1
:8 0 a19 f8 :4 0
a04 :3 0 9c :3 0
a4 :2 0 5c5 a07
a08 :3 0 1b :3 0
ab :3 0 a0a a0b
0 31 :2 0 a0c
a0d 0 a0f 5c8
a16 1b :3 0 ab
:3 0 a10 a11 0
f9 :2 0 a12 a13
0 a15 5ca a17
a09 a0f 0 a18
0 a15 0 a18
5cc 0 a19 5cf
a63 ad :3 0 1b
:3 0 ab :3 0 a1c
a1d 0 ac :3 0
a1e a1f 0 a59
78 :3 0 79 :3 0
a21 a22 0 78
:3 0 88 :3 0 a24
a25 0 25 :2 0
2 :4 0 fd :2 0
8a :2 0 49 :2 0
5d2 a2a a2c :3 0
5d5 a26 a2e a23
a30 a2f :2 0 7b
:3 0 8b :3 0 a32
a33 0 7d :4 0
fe :4 0 80 :2 0
81 :3 0 5d9 a37
a39 :3 0 80 :2 0
94 :4 0 5dc a3b
a3d :3 0 80 :2 0
b0 :4 0 5df a3f
a41 :3 0 80 :2 0
ac :3 0 5e2 a43
a45 :3 0 80 :2 0
b1 :4 0 5e5 a47
a49 :3 0 80 :2 0
b2 :3 0 b3 :3 0
49 :2 0 b4 :2 0
5e8 a4c a50 5ec
a4b a52 :3 0 5ef
a34 a54 :2 0 a56
5f2 a57 a31 a56
0 a58 5f4 0
a59 5f6 a5c :3 0
a5c 0 a5c a5b
a59 a5a :6 0 a5e
10 :3 0 5f9 a60
5fb a5f a5e :2 0
a61 5fd :2 0 a63
0 a63 a62 a19
a61 :6 0 a65 1
:3 0 5ff a66 9f7
a65 0 a67 601
0 a68 603 a82
1b :3 0 ab :3 0
a69 a6a 0 ef
:3 0 2b :3 0 48
:3 0 48 :3 0 32
:3 0 4c :3 0 4e
:3 0 3d :3 0 36
:3 0 33 :3 0 33
:3 0 33 :3 0 3c
:3 0 37 :3 0 38
:3 0 55 :3 0 51
:3 0 2f :3 0 606
a6c a7e a6b a7f
0 a81 618 a83
9d8 a68 0 a84
0 a81 0 a84
61a 0 a85 61d
a87 90a 9c4 0
a88 0 a85 0
a88 620 0 c87
1b :3 0 ab :3 0
a89 a8a 0 a4
:2 0 31 :2 0 625
a8c a8e :3 0 a8f
:2 0 ee :3 0 85
:3 0 f :3 0 31
:2 0 628 a92 a95
35 :2 0 62b a91
a98 a99 :2 0 a4
:2 0 35 :2 0 630
a9b a9d :3 0 a9e
:2 0 a90 aa0 a9f
:2 0 85 :3 0 c
:3 0 31 :2 0 633
aa2 aa5 85 :3 0
a4 :2 0 a :3 0
31 :2 0 636 aa7
aab 63b aa8 aad
:3 0 aae :2 0 85
:3 0 e :3 0 31
:2 0 63e ab0 ab3
a4 :2 0 31 :2 0
643 ab5 ab7 :3 0
ab8 :2 0 aaf aba
ab9 :2 0 85 :3 0
d :3 0 31 :2 0
646 abc abf a4
:2 0 ec :2 0 64b
ac1 ac3 :3 0 ac4
:2 0 abb ac6 ac5
:2 0 d2 :3 0 ff
:3 0 d :3 0 ce
:3 0 39 :3 0 d1
:3 0 38 :3 0 f1
:3 0 f2 :3 0 f3
:3 0 f4 :3 0 f5
:3 0 f6 :3 0 100
:3 0 4c :3 0 101
:3 0 4e :3 0 cc
:3 0 c :3 0 f0
:3 0 e :3 0 74
:3 0 2b :4 0 102
1 :8 0 af5 f8
:4 0 ae0 :3 0 9c
:3 0 a4 :2 0 650
ae3 ae4 :3 0 1b
:3 0 ab :3 0 ae6
ae7 0 31 :2 0
ae8 ae9 0 aeb
653 af2 1b :3 0
ab :3 0 aec aed
0 f9 :2 0 aee
aef 0 af1 655
af3 ae5 aeb 0
af4 0 af1 0
af4 657 0 af5
65a b3f ad :3 0
1b :3 0 ab :3 0
af8 af9 0 ac
:3 0 afa afb 0
b35 78 :3 0 79
:3 0 afd afe 0
78 :3 0 88 :3 0
b00 b01 0 25
:2 0 2 :4 0 103
:2 0 8a :2 0 49
:2 0 65d b06 b08
:3 0 660 b02 b0a
aff b0c b0b :2 0
7b :3 0 8b :3 0
b0e b0f 0 7d
:4 0 104 :4 0 80
:2 0 81 :3 0 664
b13 b15 :3 0 80
:2 0 94 :4 0 667
b17 b19 :3 0 80
:2 0 b0 :4 0 66a
b1b b1d :3 0 80
:2 0 ac :3 0 66d
b1f b21 :3 0 80
:2 0 b1 :4 0 670
b23 b25 :3 0 80
:2 0 b2 :3 0 b3
:3 0 49 :2 0 b4
:2 0 673 b28 b2c
677 b27 b2e :3 0
67a b10 b30 :2 0
b32 67d b33 b0d
b32 0 b34 67f
0 b35 681 b38
:3 0 b38 0 b38
b37 b35 b36 :6 0
b3a 12 :3 0 684
b3c 686 b3b b3a
:2 0 b3d 688 :2 0
b3f 0 b3f b3e
af5 b3d :6 0 c12
1 :3 0 73 :3 0
75 :3 0 70 :3 0
72 :3 0 6a :3 0
2d :3 0 74 :3 0
2b :4 0 105 1
:8 0 b5f f8 :4 0
b4a :3 0 9c :3 0
a4 :2 0 68c b4d
b4e :3 0 1b :3 0
ab :3 0 b50 b51
0 31 :2 0 b52
b53 0 b55 68f
b5c 1b :3 0 ab
:3 0 b56 b57 0
f9 :2 0 b58 b59
0 b5b 691 b5d
b4f b55 0 b5e
0 b5b 0 b5e
693 0 b5f 696
ba9 ad :3 0 1b
:3 0 ab :3 0 b62
b63 0 ac :3 0
b64 b65 0 b9f
78 :3 0 79 :3 0
b67 b68 0 78
:3 0 88 :3 0 b6a
b6b 0 25 :2 0
2 :4 0 106 :2 0
8a :2 0 49 :2 0
699 b70 b72 :3 0
69c b6c b74 b69
b76 b75 :2 0 7b
:3 0 8b :3 0 b78
b79 0 7d :4 0
107 :4 0 80 :2 0
81 :3 0 6a0 b7d
b7f :3 0 80 :2 0
94 :4 0 6a3 b81
b83 :3 0 80 :2 0
b0 :4 0 6a6 b85
b87 :3 0 80 :2 0
ac :3 0 6a9 b89
b8b :3 0 80 :2 0
b1 :4 0 6ac b8d
b8f :3 0 80 :2 0
b2 :3 0 b3 :3 0
49 :2 0 b4 :2 0
6af b92 b96 6b3
b91 b98 :3 0 6b6
b7a b9a :2 0 b9c
6b9 b9d b77 b9c
0 b9e 6bb 0
b9f 6bd ba2 :3 0
ba2 0 ba2 ba1
b9f ba0 :6 0 ba4
14 :3 0 6c0 ba6
6c2 ba5 ba4 :2 0
ba7 6c4 :2 0 ba9
0 ba9 ba8 b5f
ba7 :6 0 c12 1
:3 0 d2 :3 0 108
:3 0 4e :3 0 74
:3 0 2b :4 0 109
1 :8 0 bc6 f8
:4 0 bb1 :3 0 9c
:3 0 a4 :2 0 6c8
bb4 bb5 :3 0 1b
:3 0 ab :3 0 bb7
bb8 0 31 :2 0
bb9 bba 0 bbc
6cb bc3 1b :3 0
ab :3 0 bbd bbe
0 f9 :2 0 bbf
bc0 0 bc2 6cd
bc4 bb6 bbc 0
bc5 0 bc2 0
bc5 6cf 0 bc6
6d2 c10 ad :3 0
1b :3 0 ab :3 0
bc9 bca 0 ac
:3 0 bcb bcc 0
c06 78 :3 0 79
:3 0 bce bcf 0
78 :3 0 88 :3 0
bd1 bd2 0 25
:2 0 2 :4 0 10a
:2 0 8a :2 0 49
:2 0 6d5 bd7 bd9
:3 0 6d8 bd3 bdb
bd0 bdd bdc :2 0
7b :3 0 8b :3 0
bdf be0 0 7d
:4 0 10b :4 0 80
:2 0 81 :3 0 6dc
be4 be6 :3 0 80
:2 0 94 :4 0 6df
be8 bea :3 0 80
:2 0 b0 :4 0 6e2
bec bee :3 0 80
:2 0 ac :3 0 6e5
bf0 bf2 :3 0 80
:2 0 b1 :4 0 6e8
bf4 bf6 :3 0 80
:2 0 b2 :3 0 b3
:3 0 49 :2 0 b4
:2 0 6eb bf9 bfd
6ef bf8 bff :3 0
6f2 be1 c01 :2 0
c03 6f5 c04 bde
c03 0 c05 6f7
0 c06 6f9 c09
:3 0 c09 0 c09
c08 c06 c07 :6 0
c0b 16 :3 0 6fc
c0d 6fe c0c c0b
:2 0 c0e 700 :2 0
c10 0 c10 c0f
bc6 c0e :6 0 c12
1 :3 0 702 c81
d2 :3 0 f0 :3 0
e :3 0 f1 :3 0
f2 :3 0 f3 :3 0
f4 :3 0 f5 :3 0
f6 :3 0 74 :3 0
2b :4 0 10c 1
:8 0 c34 f8 :4 0
c1f :3 0 9c :3 0
a4 :2 0 708 c22
c23 :3 0 1b :3 0
ab :3 0 c25 c26
0 31 :2 0 c27
c28 0 c2a 70b
c31 1b :3 0 ab
:3 0 c2b c2c 0
f9 :2 0 c2d c2e
0 c30 70d c32
c24 c2a 0 c33
0 c30 0 c33
70f 0 c34 712
c7e ad :3 0 1b
:3 0 ab :3 0 c37
c38 0 ac :3 0
c39 c3a 0 c74
78 :3 0 79 :3 0
c3c c3d 0 78
:3 0 88 :3 0 c3f
c40 0 25 :2 0
2 :4 0 10d :2 0
8a :2 0 49 :2 0
715 c45 c47 :3 0
718 c41 c49 c3e
c4b c4a :2 0 7b
:3 0 8b :3 0 c4d
c4e 0 7d :4 0
10e :4 0 80 :2 0
81 :3 0 71c c52
c54 :3 0 80 :2 0
94 :4 0 71f c56
c58 :3 0 80 :2 0
b0 :4 0 722 c5a
c5c :3 0 80 :2 0
ac :3 0 725 c5e
c60 :3 0 80 :2 0
b1 :4 0 728 c62
c64 :3 0 80 :2 0
b2 :3 0 b3 :3 0
49 :2 0 b4 :2 0
72b c67 c6b 72f
c66 c6d :3 0 732
c4f c6f :2 0 c71
735 c72 c4c c71
0 c73 737 0
c74 739 c77 :3 0
c77 0 c77 c76
c74 c75 :6 0 c79
18 :3 0 73c c7b
73e c7a c79 :2 0
c7c 740 :2 0 c7e
0 c7e c7d c34
c7c :6 0 c80 1
:3 0 742 c82 ac7
c12 0 c83 0
c80 0 c83 744
0 c84 747 c85
aa1 c84 0 c86
749 0 c87 74b
1079 41 :3 0 ee
:3 0 85 :3 0 41
:3 0 31 :2 0 74e
c8a c8d 96 :3 0
10f :3 0 c8f c90
0 751 c89 c92
c88 c93 0 1078
85 :3 0 57 :3 0
31 :2 0 754 c95
c98 a4 :2 0 49
:2 0 759 c9a c9c
:3 0 1b :3 0 ab
:3 0 c9e c9f 0
ef :3 0 2b :3 0
48 :3 0 48 :3 0
32 :3 0 4c :3 0
4e :3 0 3d :3 0
36 :3 0 33 :3 0
33 :3 0 41 :3 0
3c :3 0 37 :3 0
38 :3 0 55 :3 0
51 :3 0 2f :3 0
75c ca1 cb3 ca0
cb4 0 d4a 1b
:3 0 ab :3 0 cb6
cb7 0 a4 :2 0
31 :2 0 770 cb9
cbb :3 0 cbc :2 0
85 :3 0 f :3 0
31 :2 0 773 cbe
cc1 a4 :2 0 35
:2 0 778 cc3 cc5
:3 0 cc6 :2 0 cbd
cc8 cc7 :2 0 85
:3 0 3e :3 0 31
:2 0 77b cca ccd
a4 :2 0 31 :2 0
780 ccf cd1 :3 0
cd2 :2 0 cc9 cd4
cd3 :2 0 d2 :3 0
f0 :3 0 e :3 0
f1 :3 0 f2 :3 0
f3 :3 0 f4 :3 0
f5 :3 0 f6 :3 0
6a :3 0 2d :3 0
ca :3 0 2e :3 0
cb :3 0 2c :4 0
110 1 :8 0 cfb
f8 :4 0 ce6 :3 0
9c :3 0 a4 :2 0
785 ce9 cea :3 0
1b :3 0 ab :3 0
cec ced 0 31
:2 0 cee cef 0
cf1 788 cf8 1b
:3 0 ab :3 0 cf2
cf3 0 f9 :2 0
cf4 cf5 0 cf7
78a cf9 ceb cf1
0 cfa 0 cf7
0 cfa 78c 0
cfb 78f d45 ad
:3 0 1b :3 0 ab
:3 0 cfe cff 0
ac :3 0 d00 d01
0 d3b 78 :3 0
79 :3 0 d03 d04
0 78 :3 0 88
:3 0 d06 d07 0
25 :2 0 2 :4 0
111 :2 0 8a :2 0
49 :2 0 792 d0c
d0e :3 0 795 d08
d10 d05 d12 d11
:2 0 7b :3 0 8b
:3 0 d14 d15 0
7d :4 0 112 :4 0
80 :2 0 81 :3 0
799 d19 d1b :3 0
80 :2 0 94 :4 0
79c d1d d1f :3 0
80 :2 0 b0 :4 0
79f d21 d23 :3 0
80 :2 0 ac :3 0
7a2 d25 d27 :3 0
80 :2 0 b1 :4 0
7a5 d29 d2b :3 0
80 :2 0 b2 :3 0
b3 :3 0 49 :2 0
b4 :2 0 7a8 d2e
d32 7ac d2d d34
:3 0 7af d16 d36
:2 0 d38 7b2 d39
d13 d38 0 d3a
7b4 0 d3b 7b6
d3e :3 0 d3e 0
d3e d3d d3b d3c
:6 0 d40 1a :3 0
7b9 d42 7bb d41
d40 :2 0 d43 7bd
:2 0 d45 0 d45
d44 cfb d43 :6 0
d47 1 :3 0 7bf
d48 cd5 d47 0
d49 7c1 0 d4a
7c3 1075 12 :3 0
c2 :2 0 7c6 d4c
d4d :3 0 d4e :2 0
50 :3 0 12 :3 0
d50 d51 0 fbe
b2 :3 0 50 :3 0
b2 :3 0 50 :3 0
b2 :3 0 50 :3 0
b2 :3 0 50 :3 0
50 :3 0 b9 :4 0
113 1 :8 0 d63
1b :3 0 ab :3 0
d5e d5f 0 ac
:3 0 d60 d61 0
d63 7c8 dad ad
:3 0 1b :3 0 ab
:3 0 d66 d67 0
ac :3 0 d68 d69
0 da3 78 :3 0
79 :3 0 d6b d6c
0 78 :3 0 88
:3 0 d6e d6f 0
25 :2 0 2 :4 0
114 :2 0 8a :2 0
49 :2 0 7cb d74
d76 :3 0 7ce d70
d78 d6d d7a d79
:2 0 7b :3 0 8b
:3 0 d7c d7d 0
7d :4 0 115 :4 0
80 :2 0 81 :3 0
7d2 d81 d83 :3 0
80 :2 0 94 :4 0
7d5 d85 d87 :3 0
80 :2 0 b0 :4 0
7d8 d89 d8b :3 0
80 :2 0 ac :3 0
7db d8d d8f :3 0
80 :2 0 b1 :4 0
7de d91 d93 :3 0
80 :2 0 b2 :3 0
b3 :3 0 49 :2 0
b4 :2 0 7e1 d96
d9a 7e5 d95 d9c
:3 0 7e8 d7e d9e
:2 0 da0 7eb da1
d7b da0 0 da2
7ed 0 da3 7ef
da6 :3 0 da6 0
da6 da5 da3 da4
:6 0 da8 1c :3 0
7f2 daa 7f4 da9
da8 :2 0 dab 7f6
:2 0 dad 0 dad
dac d63 dab :6 0
fbe 1 :3 0 c4
:3 0 116 :3 0 daf
db0 0 50 :3 0
4f :3 0 117 :2 0
7f8 db1 db5 8e
:2 0 31 :2 0 7fe
db7 db9 :3 0 30
:3 0 96 :3 0 118
:3 0 dbc dbd 0
dbb dbe 0 fbb
52 :3 0 49 :2 0
dc0 dc1 0 fbb
6b :3 0 29 :3 0
119 :3 0 11a :4 0
11b 1 :8 0 dcd
1b :3 0 ab :3 0
dc8 dc9 0 ac
:3 0 dca dcb 0
dcd 801 e17 ad
:3 0 1b :3 0 ab
:3 0 dd0 dd1 0
ac :3 0 dd2 dd3
0 e0d 78 :3 0
79 :3 0 dd5 dd6
0 78 :3 0 88
:3 0 dd8 dd9 0
25 :2 0 2 :4 0
11c :2 0 8a :2 0
49 :2 0 804 dde
de0 :3 0 807 dda
de2 dd7 de4 de3
:2 0 7b :3 0 8b
:3 0 de6 de7 0
7d :4 0 11d :4 0
80 :2 0 81 :3 0
80b deb ded :3 0
80 :2 0 94 :4 0
80e def df1 :3 0
80 :2 0 b0 :4 0
811 df3 df5 :3 0
80 :2 0 ac :3 0
814 df7 df9 :3 0
80 :2 0 b1 :4 0
817 dfb dfd :3 0
80 :2 0 b2 :3 0
b3 :3 0 49 :2 0
b4 :2 0 81a e00
e04 81e dff e06
:3 0 821 de8 e08
:2 0 e0a 824 e0b
de5 e0a 0 e0c
826 0 e0d 828
e10 :3 0 e10 0
e10 e0f e0d e0e
:6 0 e12 1e :3 0
82b e14 82d e13
e12 :2 0 e15 82f
:2 0 e17 0 e17
e16 dcd e15 :6 0
fbb 1 :3 0 54
:3 0 11e :3 0 52
:3 0 2e :3 0 29
:3 0 30 :3 0 2f
:3 0 2a :3 0 831
e1a e21 e19 e22
0 fbb 85 :3 0
54 :3 0 31 :2 0
838 e24 e27 a4
:2 0 31 :2 0 83d
e29 e2b :3 0 26
:4 0 e2d e2e 0
fb8 28 :4 0 e30
e31 0 fb8 1d
:4 0 e33 e34 0
fb8 24 :4 0 e36
e37 0 fb8 1f
:4 0 e39 e3a 0
fb8 11f :3 0 63
:4 0 e3f :2 0 fb8
e3d e40 :3 0 63
:3 0 1d :3 0 24
:4 0 e45 :2 0 fb8
e41 e46 :3 0 840
:3 0 63 :3 0 f8
:3 0 e47 e48 :3 0
1b :3 0 ab :3 0
e4a e4b 0 31
:2 0 e4c e4d 0
e4f 843 e56 1b
:3 0 ab :3 0 e50
e51 0 f9 :2 0
e52 e53 0 e55
845 e57 e49 e4f
0 e58 0 e55
0 e58 847 0
fb8 120 :3 0 63
:4 0 e5c :2 0 e62
e5a 0 1b :3 0
ab :3 0 e5d e5e
0 ac :3 0 e5f
e60 0 e62 84a
eac ad :3 0 1b
:3 0 ab :3 0 e65
e66 0 ac :3 0
e67 e68 0 ea2
78 :3 0 79 :3 0
e6a e6b 0 78
:3 0 88 :3 0 e6d
e6e 0 25 :2 0
2 :4 0 121 :2 0
8a :2 0 49 :2 0
84d e73 e75 :3 0
850 e6f e77 e6c
e79 e78 :2 0 7b
:3 0 8b :3 0 e7b
e7c 0 7d :4 0
122 :4 0 80 :2 0
81 :3 0 854 e80
e82 :3 0 80 :2 0
94 :4 0 857 e84
e86 :3 0 80 :2 0
b0 :4 0 85a e88
e8a :3 0 80 :2 0
ac :3 0 85d e8c
e8e :3 0 80 :2 0
b1 :4 0 860 e90
e92 :3 0 80 :2 0
b2 :3 0 b3 :3 0
49 :2 0 b4 :2 0
863 e95 e99 867
e94 e9b :3 0 86a
e7d e9d :2 0 e9f
86d ea0 e7a e9f
0 ea1 86f 0
ea2 871 ea5 :3 0
ea5 0 ea5 ea4
ea2 ea3 :6 0 ea7
20 :3 0 874 ea9
876 ea8 ea7 :2 0
eaa 878 :2 0 eac
0 eac eab e62
eaa :6 0 fb8 1
:3 0 123 :3 0 1f
:3 0 124 :3 0 cb
:3 0 2c :4 0 125
1 :8 0 eb9 1b
:3 0 ab :3 0 eb4
eb5 0 ac :3 0
eb6 eb7 0 eb9
87a f03 ad :3 0
1b :3 0 ab :3 0
ebc ebd 0 ac
:3 0 ebe ebf 0
ef9 78 :3 0 79
:3 0 ec1 ec2 0
78 :3 0 88 :3 0
ec4 ec5 0 25
:2 0 2 :4 0 126
:2 0 8a :2 0 49
:2 0 87d eca ecc
:3 0 880 ec6 ece
ec3 ed0 ecf :2 0
7b :3 0 8b :3 0
ed2 ed3 0 7d
:4 0 127 :4 0 80
:2 0 81 :3 0 884
ed7 ed9 :3 0 80
:2 0 94 :4 0 887
edb edd :3 0 80
:2 0 b0 :4 0 88a
edf ee1 :3 0 80
:2 0 ac :3 0 88d
ee3 ee5 :3 0 80
:2 0 b1 :4 0 890
ee7 ee9 :3 0 80
:2 0 b2 :3 0 b3
:3 0 49 :2 0 b4
:2 0 893 eec ef0
897 eeb ef2 :3 0
89a ed4 ef4 :2 0
ef6 89d ef7 ed1
ef6 0 ef8 89f
0 ef9 8a1 efc
:3 0 efc 0 efc
efb ef9 efa :6 0
efe 22 :3 0 8a4
f00 8a6 eff efe
:2 0 f01 8a8 :2 0
f03 0 f03 f02
eb9 f01 :6 0 fb8
1 :3 0 22 :3 0
128 :4 0 f05 f06
0 fb8 20 :3 0
129 :4 0 f08 f09
0 fb8 20 :3 0
b2 :3 0 20 :3 0
80 :2 0 1f :3 0
8aa f0e f10 :3 0
49 :2 0 21 :2 0
8ad f0c f14 f0b
f15 0 fb8 20
:3 0 b2 :3 0 20
:3 0 80 :2 0 12a
:4 0 8b1 f1a f1c
:3 0 49 :2 0 21
:2 0 8b4 f18 f20
f17 f21 0 fb8
20 :3 0 b2 :3 0
20 :3 0 80 :2 0
1d :3 0 8b8 f26
f28 :3 0 49 :2 0
21 :2 0 8bb f24
f2c f23 f2d 0
fb8 20 :3 0 b2
:3 0 20 :3 0 80
:2 0 12b :4 0 8bf
f32 f34 :3 0 49
:2 0 21 :2 0 8c2
f30 f38 f2f f39
0 fb8 54 :3 0
12c :3 0 2a :3 0
24 :3 0 33 :3 0
33 :3 0 48 :3 0
33 :3 0 22 :3 0
20 :3 0 2f :3 0
48 :3 0 48 :3 0
33 :3 0 26 :3 0
28 :3 0 2f :3 0
8c6 f3c f4c f3b
f4d 0 fb8 78
:3 0 79 :3 0 f4f
f50 0 78 :3 0
88 :3 0 f52 f53
0 27 :2 0 2
:4 0 12d :2 0 8a
:2 0 49 :2 0 8d6
f58 f5a :3 0 8d9
f54 f5c f51 f5e
f5d :2 0 7b :3 0
8b :3 0 f60 f61
0 7d :4 0 12e
:4 0 80 :2 0 81
:3 0 8dd f65 f67
:3 0 80 :2 0 94
:4 0 8e0 f69 f6b
:3 0 80 :2 0 95
:4 0 8e3 f6d f6f
:3 0 80 :2 0 85
:3 0 66 :3 0 31
:2 0 8e6 f73 f75
86 :4 0 8e8 f72
f78 8eb f71 f7a
:3 0 80 :2 0 da
:4 0 8ee f7c f7e
:3 0 80 :2 0 83
:4 0 8f1 f80 f82
:3 0 80 :2 0 2b
:3 0 8f4 f84 f86
:3 0 80 :2 0 83
:4 0 8f7 f88 f8a
:3 0 8fa f62 f8c
:2 0 f8e 8fd f8f
f5f f8e 0 f90
8ff 0 fb8 78
:3 0 79 :3 0 f91
f92 0 78 :3 0
88 :3 0 f94 f95
0 49 :2 0 2
:4 0 12f :2 0 8a
:2 0 49 :2 0 901
f9a f9c :3 0 904
f96 f9e f93 fa0
f9f :2 0 7b :3 0
8b :3 0 fa2 fa3
0 7d :4 0 130
:4 0 80 :2 0 81
:3 0 908 fa7 fa9
:3 0 90b fa4 fab
:2 0 fad 90e fae
fa1 fad 0 faf
910 0 fb8 9a
:3 0 dd :3 0 fb0
fb1 0 31 :2 0
2b :3 0 9c :3 0
912 fb2 fb6 :2 0
fb8 916 fb9 e2c
fb8 0 fba 92b
0 fbb 92d fbc
dba fbb 0 fbd
933 0 fbe 935
fbf d4f fbe 0
fc0 939 0 1074
3c :3 0 85 :3 0
3c :3 0 31 :2 0
93b fc2 fc5 8a
:2 0 49 :2 0 93e
fc7 fc9 :3 0 fc1
fca 0 1074 1b
:3 0 ab :3 0 fcc
fcd 0 ef :3 0
2b :3 0 48 :3 0
48 :3 0 32 :3 0
4c :3 0 4e :3 0
3d :3 0 36 :3 0
33 :3 0 33 :3 0
41 :3 0 3c :3 0
37 :3 0 38 :3 0
55 :3 0 51 :3 0
2f :3 0 941 fcf
fe1 fce fe2 0
1074 1b :3 0 ab
:3 0 fe4 fe5 0
a4 :2 0 31 :2 0
955 fe7 fe9 :3 0
fea :2 0 85 :3 0
f :3 0 31 :2 0
958 fec fef a4
:2 0 35 :2 0 95d
ff1 ff3 :3 0 ff4
:2 0 feb ff6 ff5
:2 0 85 :3 0 3e
:3 0 31 :2 0 960
ff8 ffb a4 :2 0
31 :2 0 965 ffd
fff :3 0 1000 :2 0
ff7 1002 1001 :2 0
d2 :3 0 f0 :3 0
e :3 0 f1 :3 0
f2 :3 0 f3 :3 0
f4 :3 0 f5 :3 0
f6 :3 0 74 :3 0
2b :4 0 10c 1
:8 0 1025 f8 :4 0
1010 :3 0 9c :3 0
a4 :2 0 96a 1013
1014 :3 0 1b :3 0
ab :3 0 1016 1017
0 31 :2 0 1018
1019 0 101b 96d
1022 1b :3 0 ab
:3 0 101c 101d 0
f9 :2 0 101e 101f
0 1021 96f 1023
1015 101b 0 1024
0 1021 0 1024
971 0 1025 974
106f ad :3 0 1b
:3 0 ab :3 0 1028
1029 0 ac :3 0
102a 102b 0 1065
78 :3 0 79 :3 0
102d 102e 0 78
:3 0 88 :3 0 1030
1031 0 25 :2 0
2 :4 0 131 :2 0
8a :2 0 49 :2 0
977 1036 1038 :3 0
97a 1032 103a 102f
103c 103b :2 0 7b
:3 0 8b :3 0 103e
103f 0 7d :4 0
132 :4 0 80 :2 0
81 :3 0 97e 1043
1045 :3 0 80 :2 0
94 :4 0 981 1047
1049 :3 0 80 :2 0
b0 :4 0 984 104b
104d :3 0 80 :2 0
ac :3 0 987 104f
1051 :3 0 80 :2 0
b1 :4 0 98a 1053
1055 :3 0 80 :2 0
b2 :3 0 b3 :3 0
49 :2 0 b4 :2 0
98d 1058 105c 991
1057 105e :3 0 994
1040 1060 :2 0 1062
997 1063 103d 1062
0 1064 999 0
1065 99b 1068 :3 0
1068 0 1068 1067
1065 1066 :6 0 106a
24 :3 0 99e 106c
9a0 106b 106a :2 0
106d 9a2 :2 0 106f
0 106f 106e 1025
106d :6 0 1071 1
:3 0 9a4 1072 1003
1071 0 1073 9a6
0 1074 9a8 1076
c9d d4a 0 1077
0 1074 0 1077
9ad 0 1078 9b0
107a 901 c87 0
107b 0 1078 0
107b 9b3 0 1bc1
1b :3 0 ab :3 0
107c 107d 0 bf
:2 0 31 :2 0 9b8
107f 1081 :3 0 78
:3 0 79 :3 0 1083
1084 0 78 :3 0
88 :3 0 1086 1087
0 27 :2 0 2
:4 0 133 :2 0 8a
:2 0 49 :2 0 9bb
108c 108e :3 0 9be
1088 1090 1085 1092
1091 :2 0 7b :3 0
8b :3 0 1094 1095
0 7d :4 0 134
:4 0 80 :2 0 81
:3 0 9c2 1099 109b
:3 0 80 :2 0 94
:4 0 9c5 109d 109f
:3 0 80 :2 0 95
:4 0 9c8 10a1 10a3
:3 0 80 :2 0 85
:3 0 66 :3 0 1b
:3 0 ab :3 0 10a8
10a9 0 9cb 10a7
10ab 86 :4 0 9cd
10a6 10ae 9d0 10a5
10b0 :3 0 80 :2 0
da :4 0 9d3 10b2
10b4 :3 0 80 :2 0
83 :4 0 9d6 10b6
10b8 :3 0 80 :2 0
2b :3 0 9d9 10ba
10bc :3 0 80 :2 0
83 :4 0 9dc 10be
10c0 :3 0 9df 1096
10c2 :2 0 10c4 9e2
10c5 1093 10c4 0
10c6 9e4 0 10f0
78 :3 0 79 :3 0
10c7 10c8 0 78
:3 0 88 :3 0 10ca
10cb 0 49 :2 0
2 :4 0 135 :2 0
8a :2 0 49 :2 0
9e6 10d0 10d2 :3 0
9e9 10cc 10d4 10c9
10d6 10d5 :2 0 7b
:3 0 8b :3 0 10d8
10d9 0 7d :4 0
136 :4 0 80 :2 0
81 :3 0 9ed 10dd
10df :3 0 9f0 10da
10e1 :2 0 10e3 9f3
10e4 10d7 10e3 0
10e5 9f5 0 10f0
9a :3 0 dd :3 0
10e6 10e7 0 1b
:3 0 ab :3 0 10e9
10ea 0 2b :3 0
9c :3 0 9f7 10e8
10ee :2 0 10f0 9fb
10f1 1082 10f0 0
10f2 9ff 0 1bc1
38 :3 0 11 :3 0
10f3 10f4 0 1bc1
85 :3 0 39 :3 0
31 :2 0 a01 10f6
10f9 bf :2 0 ec
:2 0 a06 10fb 10fd
:3 0 10fe :2 0 85
:3 0 38 :3 0 31
:2 0 a09 1100 1103
a4 :2 0 31 :2 0
a0e 1105 1107 :3 0
1108 :2 0 10ff 110a
1109 :2 0 38 :3 0
49 :2 0 110c 110d
0 110f a11 1110
110b 110f 0 1111
a13 0 1bc1 85
:3 0 57 :3 0 31
:2 0 a15 1112 1115
a4 :2 0 49 :2 0
a1a 1117 1119 :3 0
ee :3 0 85 :3 0
f :3 0 31 :2 0
a1d 111c 111f 25
:2 0 a20 111b 1122
1123 :2 0 a4 :2 0
25 :2 0 a25 1125
1127 :3 0 12 :3 0
8d :2 0 a28 112a
112b :3 0 112c :2 0
4d :3 0 c2 :2 0
a2a 112f 1130 :3 0
1131 :2 0 d2 :3 0
ff :3 0 d :3 0
ce :3 0 39 :3 0
d1 :3 0 38 :3 0
f1 :3 0 f2 :3 0
f3 :3 0 f4 :3 0
f5 :3 0 f6 :3 0
100 :3 0 16 :3 0
101 :3 0 17 :3 0
cc :3 0 18 :3 0
137 :3 0 2b :4 0
138 1 :8 0 115e
f8 :4 0 1149 :3 0
9c :3 0 a4 :2 0
a2e 114c 114d :3 0
1b :3 0 ab :3 0
114f 1150 0 31
:2 0 1151 1152 0
1154 a31 115b 1b
:3 0 ab :3 0 1155
1156 0 f9 :2 0
1157 1158 0 115a
a33 115c 114e 1154
0 115d 0 115a
0 115d a35 0
115e a38 11a8 ad
:3 0 1b :3 0 ab
:3 0 1161 1162 0
ac :3 0 1163 1164
0 119e 78 :3 0
79 :3 0 1166 1167
0 78 :3 0 88
:3 0 1169 116a 0
25 :2 0 2 :4 0
139 :2 0 8a :2 0
49 :2 0 a3b 116f
1171 :3 0 a3e 116b
1173 1168 1175 1174
:2 0 7b :3 0 8b
:3 0 1177 1178 0
7d :4 0 13a :4 0
80 :2 0 81 :3 0
a42 117c 117e :3 0
80 :2 0 94 :4 0
a45 1180 1182 :3 0
80 :2 0 b0 :4 0
a48 1184 1186 :3 0
80 :2 0 ac :3 0
a4b 1188 118a :3 0
80 :2 0 b1 :4 0
a4e 118c 118e :3 0
80 :2 0 b2 :3 0
b3 :3 0 49 :2 0
b4 :2 0 a51 1191
1195 a55 1190 1197
:3 0 a58 1179 1199
:2 0 119b a5b 119c
1176 119b 0 119d
a5d 0 119e a5f
11a1 :3 0 11a1 0
11a1 11a0 119e 119f
:6 0 11a3 26 :3 0
a62 11a5 a64 11a4
11a3 :2 0 11a6 a66
:2 0 11a8 0 11a8
11a7 115e 11a6 :6 0
11aa 1 :3 0 a68
1217 d2 :3 0 ff
:3 0 d :3 0 ce
:3 0 39 :3 0 d1
:3 0 38 :3 0 137
:3 0 2b :4 0 13b
1 :8 0 11ca f8
:4 0 11b5 :3 0 9c
:3 0 a4 :2 0 a6c
11b8 11b9 :3 0 1b
:3 0 ab :3 0 11bb
11bc 0 31 :2 0
11bd 11be 0 11c0
a6f 11c7 1b :3 0
ab :3 0 11c1 11c2
0 f9 :2 0 11c3
11c4 0 11c6 a71
11c8 11ba 11c0 0
11c9 0 11c6 0
11c9 a73 0 11ca
a76 1214 ad :3 0
1b :3 0 ab :3 0
11cd 11ce 0 ac
:3 0 11cf 11d0 0
120a 78 :3 0 79
:3 0 11d2 11d3 0
78 :3 0 88 :3 0
11d5 11d6 0 25
:2 0 2 :4 0 13c
:2 0 8a :2 0 49
:2 0 a79 11db 11dd
:3 0 a7c 11d7 11df
11d4 11e1 11e0 :2 0
7b :3 0 8b :3 0
11e3 11e4 0 7d
:4 0 13d :4 0 80
:2 0 81 :3 0 a80
11e8 11ea :3 0 80
:2 0 94 :4 0 a83
11ec 11ee :3 0 80
:2 0 b0 :4 0 a86
11f0 11f2 :3 0 80
:2 0 ac :3 0 a89
11f4 11f6 :3 0 80
:2 0 b1 :4 0 a8c
11f8 11fa :3 0 80
:2 0 b2 :3 0 b3
:3 0 49 :2 0 b4
:2 0 a8f 11fd 1201
a93 11fc 1203 :3 0
a96 11e5 1205 :2 0
1207 a99 1208 11e2
1207 0 1209 a9b
0 120a a9d 120d
:3 0 120d 0 120d
120c 120a 120b :6 0
120f 28 :3 0 aa0
1211 aa2 1210 120f
:2 0 1212 aa4 :2 0
1214 0 1214 1213
11ca 1212 :6 0 1216
1 :3 0 aa6 1218
1132 11aa 0 1219
0 1216 0 1219
aa8 0 121a aab
135e 4d :3 0 c2
:2 0 aad 121c 121d
:3 0 121e :2 0 d2
:3 0 ff :3 0 d
:3 0 ce :3 0 39
:3 0 d1 :3 0 38
:3 0 13e :3 0 13f
:3 0 c3 :3 0 12
:3 0 13e :3 0 140
:3 0 13f :3 0 c3
:3 0 13 :3 0 140
:3 0 141 :3 0 13f
:3 0 14 :3 0 141
:3 0 142 :3 0 13f
:3 0 15 :3 0 142
:3 0 143 :3 0 144
:3 0 145 :3 0 146
:3 0 147 :3 0 148
:3 0 149 :3 0 14a
:3 0 144 :3 0 12
:3 0 146 :3 0 13
:3 0 148 :3 0 14
:3 0 14a :3 0 15
:3 0 14b :3 0 14c
:3 0 14d :3 0 14e
:3 0 14f :3 0 150
:3 0 151 :3 0 152
:3 0 13f :3 0 f1
:3 0 f2 :3 0 f3
:3 0 f4 :3 0 f5
:3 0 f6 :3 0 100
:3 0 16 :3 0 101
:3 0 17 :3 0 cc
:3 0 18 :3 0 137
:3 0 2b :4 0 153
1 :8 0 1276 f8
:4 0 1261 :3 0 9c
:3 0 a4 :2 0 ab1
1264 1265 :3 0 1b
:3 0 ab :3 0 1267
1268 0 31 :2 0
1269 126a 0 126c
ab4 1273 1b :3 0
ab :3 0 126d 126e
0 f9 :2 0 126f
1270 0 1272 ab6
1274 1266 126c 0
1275 0 1272 0
1275 ab8 0 1276
abb 12c0 ad :3 0
1b :3 0 ab :3 0
1279 127a 0 ac
:3 0 127b 127c 0
12b6 78 :3 0 79
:3 0 127e 127f 0
78 :3 0 88 :3 0
1281 1282 0 25
:2 0 2 :4 0 154
:2 0 8a :2 0 49
:2 0 abe 1287 1289
:3 0 ac1 1283 128b
1280 128d 128c :2 0
7b :3 0 8b :3 0
128f 1290 0 7d
:4 0 155 :4 0 80
:2 0 81 :3 0 ac5
1294 1296 :3 0 80
:2 0 94 :4 0 ac8
1298 129a :3 0 80
:2 0 b0 :4 0 acb
129c 129e :3 0 80
:2 0 ac :3 0 ace
12a0 12a2 :3 0 80
:2 0 b1 :4 0 ad1
12a4 12a6 :3 0 80
:2 0 b2 :3 0 b3
:3 0 49 :2 0 b4
:2 0 ad4 12a9 12ad
ad8 12a8 12af :3 0
adb 1291 12b1 :2 0
12b3 ade 12b4 128e
12b3 0 12b5 ae0
0 12b6 ae2 12b9
:3 0 12b9 0 12b9
12b8 12b6 12b7 :6 0
12bb 2a :3 0 ae5
12bd ae7 12bc 12bb
:2 0 12be ae9 :2 0
12c0 0 12c0 12bf
1276 12be :6 0 12c2
1 :3 0 aeb 135a
d2 :3 0 ff :3 0
d :3 0 ce :3 0
39 :3 0 d1 :3 0
38 :3 0 13e :3 0
13f :3 0 c3 :3 0
12 :3 0 13e :3 0
140 :3 0 13f :3 0
c3 :3 0 13 :3 0
140 :3 0 141 :3 0
13f :3 0 14 :3 0
141 :3 0 142 :3 0
13f :3 0 15 :3 0
142 :3 0 143 :3 0
144 :3 0 145 :3 0
146 :3 0 147 :3 0
148 :3 0 149 :3 0
14a :3 0 144 :3 0
12 :3 0 146 :3 0
13 :3 0 148 :3 0
14 :3 0 14a :3 0
15 :3 0 14b :3 0
14c :3 0 14d :3 0
14e :3 0 14f :3 0
150 :3 0 151 :3 0
152 :3 0 13f :3 0
137 :3 0 2b :4 0
156 1 :8 0 130d
f8 :4 0 12f8 :3 0
9c :3 0 a4 :2 0
aef 12fb 12fc :3 0
1b :3 0 ab :3 0
12fe 12ff 0 31
:2 0 1300 1301 0
1303 af2 130a 1b
:3 0 ab :3 0 1304
1305 0 f9 :2 0
1306 1307 0 1309
af4 130b 12fd 1303
0 130c 0 1309
0 130c af6 0
130d af9 1357 ad
:3 0 1b :3 0 ab
:3 0 1310 1311 0
ac :3 0 1312 1313
0 134d 78 :3 0
79 :3 0 1315 1316
0 78 :3 0 88
:3 0 1318 1319 0
25 :2 0 2 :4 0
157 :2 0 8a :2 0
49 :2 0 afc 131e
1320 :3 0 aff 131a
1322 1317 1324 1323
:2 0 7b :3 0 8b
:3 0 1326 1327 0
7d :4 0 158 :4 0
80 :2 0 81 :3 0
b03 132b 132d :3 0
80 :2 0 94 :4 0
b06 132f 1331 :3 0
80 :2 0 b0 :4 0
b09 1333 1335 :3 0
80 :2 0 ac :3 0
b0c 1337 1339 :3 0
80 :2 0 b1 :4 0
b0f 133b 133d :3 0
80 :2 0 b2 :3 0
b3 :3 0 49 :2 0
b4 :2 0 b12 1340
1344 b16 133f 1346
:3 0 b19 1328 1348
:2 0 134a b1c 134b
1325 134a 0 134c
b1e 0 134d b20
1350 :3 0 1350 0
1350 134f 134d 134e
:6 0 1352 2c :3 0
b23 1354 b25 1353
1352 :2 0 1355 b27
:2 0 1357 0 1357
1356 130d 1355 :6 0
1359 1 :3 0 b29
135b 121f 12c2 0
135c 0 1359 0
135c b2b 0 135d
b2e 135f 112d 121a
0 1360 0 135d
0 1360 b30 0
1362 159 :3 0 b33
13d9 85 :3 0 3e
:3 0 31 :2 0 b35
1363 1366 a4 :2 0
31 :2 0 b3a 1368
136a :3 0 d2 :3 0
ff :3 0 d :3 0
ce :3 0 39 :3 0
d1 :3 0 38 :3 0
137 :3 0 2b :4 0
15a 1 :8 0 138b
f8 :4 0 1376 :3 0
9c :3 0 a4 :2 0
b3f 1379 137a :3 0
1b :3 0 ab :3 0
137c 137d 0 31
:2 0 137e 137f 0
1381 b42 1388 1b
:3 0 ab :3 0 1382
1383 0 f9 :2 0
1384 1385 0 1387
b44 1389 137b 1381
0 138a 0 1387
0 138a b46 0
138b b49 13d5 ad
:3 0 1b :3 0 ab
:3 0 138e 138f 0
ac :3 0 1390 1391
0 13cb 78 :3 0
79 :3 0 1393 1394
0 78 :3 0 88
:3 0 1396 1397 0
25 :2 0 2 :4 0
15b :2 0 8a :2 0
49 :2 0 b4c 139c
139e :3 0 b4f 1398
13a0 1395 13a2 13a1
:2 0 7b :3 0 8b
:3 0 13a4 13a5 0
7d :4 0 15c :4 0
80 :2 0 81 :3 0
b53 13a9 13ab :3 0
80 :2 0 94 :4 0
b56 13ad 13af :3 0
80 :2 0 b0 :4 0
b59 13b1 13b3 :3 0
80 :2 0 ac :3 0
b5c 13b5 13b7 :3 0
80 :2 0 b1 :4 0
b5f 13b9 13bb :3 0
80 :2 0 b2 :3 0
b3 :3 0 49 :2 0
b4 :2 0 b62 13be
13c2 b66 13bd 13c4
:3 0 b69 13a6 13c6
:2 0 13c8 b6c 13c9
13a3 13c8 0 13ca
b6e 0 13cb b70
13ce :3 0 13ce 0
13ce 13cd 13cb 13cc
:6 0 13d0 2e :3 0
b73 13d2 b75 13d1
13d0 :2 0 13d3 b77
:2 0 13d5 0 13d5
13d4 138b 13d3 :6 0
13d7 1 :3 0 b79
13d8 136b 13d7 0
13da 1128 1362 0
13da b7b 0 13db
b7e 1798 ee :3 0
85 :3 0 f :3 0
31 :2 0 b80 13dd
13e0 25 :2 0 b83
13dc 13e3 13e4 :2 0
a4 :2 0 25 :2 0
b88 13e6 13e8 :3 0
12 :3 0 8d :2 0
b8b 13eb 13ec :3 0
13ed :2 0 4d :3 0
c2 :2 0 b8d 13f0
13f1 :3 0 13f2 :2 0
d2 :3 0 ff :3 0
d :3 0 ce :3 0
39 :3 0 d1 :3 0
38 :3 0 f1 :3 0
f2 :3 0 f3 :3 0
f4 :3 0 f5 :3 0
f6 :3 0 100 :3 0
16 :3 0 101 :3 0
17 :3 0 cc :3 0
18 :3 0 74 :3 0
2b :4 0 15d 1
:8 0 141f f8 :4 0
140a :3 0 9c :3 0
a4 :2 0 b91 140d
140e :3 0 1b :3 0
ab :3 0 1410 1411
0 31 :2 0 1412
1413 0 1415 b94
141c 1b :3 0 ab
:3 0 1416 1417 0
f9 :2 0 1418 1419
0 141b b96 141d
140f 1415 0 141e
0 141b 0 141e
b98 0 141f b9b
1469 ad :3 0 1b
:3 0 ab :3 0 1422
1423 0 ac :3 0
1424 1425 0 145f
78 :3 0 79 :3 0
1427 1428 0 78
:3 0 88 :3 0 142a
142b 0 25 :2 0
2 :4 0 15e :2 0
8a :2 0 49 :2 0
b9e 1430 1432 :3 0
ba1 142c 1434 1429
1436 1435 :2 0 7b
:3 0 8b :3 0 1438
1439 0 7d :4 0
15f :4 0 80 :2 0
81 :3 0 ba5 143d
143f :3 0 80 :2 0
94 :4 0 ba8 1441
1443 :3 0 80 :2 0
b0 :4 0 bab 1445
1447 :3 0 80 :2 0
ac :3 0 bae 1449
144b :3 0 80 :2 0
b1 :4 0 bb1 144d
144f :3 0 80 :2 0
b2 :3 0 b3 :3 0
49 :2 0 b4 :2 0
bb4 1452 1456 bb8
1451 1458 :3 0 bbb
143a 145a :2 0 145c
bbe 145d 1437 145c
0 145e bc0 0
145f bc2 1462 :3 0
1462 0 1462 1461
145f 1460 :6 0 1464
30 :3 0 bc5 1466
bc7 1465 1464 :2 0
1467 bc9 :2 0 1469
0 1469 1468 141f
1467 :6 0 146b 1
:3 0 bcb 14da d2
:3 0 ff :3 0 d
:3 0 ce :3 0 39
:3 0 d1 :3 0 38
:3 0 cc :3 0 c
:3 0 74 :3 0 2b
:4 0 160 1 :8 0
148d f8 :4 0 1478
:3 0 9c :3 0 a4
:2 0 bcf 147b 147c
:3 0 1b :3 0 ab
:3 0 147e 147f 0
31 :2 0 1480 1481
0 1483 bd2 148a
1b :3 0 ab :3 0
1484 1485 0 f9
:2 0 1486 1487 0
1489 bd4 148b 147d
1483 0 148c 0
1489 0 148c bd6
0 148d bd9 14d7
ad :3 0 1b :3 0
ab :3 0 1490 1491
0 ac :3 0 1492
1493 0 14cd 78
:3 0 79 :3 0 1495
1496 0 78 :3 0
88 :3 0 1498 1499
0 25 :2 0 2
:4 0 161 :2 0 8a
:2 0 49 :2 0 bdc
149e 14a0 :3 0 bdf
149a 14a2 1497 14a4
14a3 :2 0 7b :3 0
8b :3 0 14a6 14a7
0 7d :4 0 162
:4 0 80 :2 0 81
:3 0 be3 14ab 14ad
:3 0 80 :2 0 94
:4 0 be6 14af 14b1
:3 0 80 :2 0 b0
:4 0 be9 14b3 14b5
:3 0 80 :2 0 ac
:3 0 bec 14b7 14b9
:3 0 80 :2 0 b1
:4 0 bef 14bb 14bd
:3 0 80 :2 0 b2
:3 0 b3 :3 0 49
:2 0 b4 :2 0 bf2
14c0 14c4 bf6 14bf
14c6 :3 0 bf9 14a8
14c8 :2 0 14ca bfc
14cb 14a5 14ca 0
14cc bfe 0 14cd
c00 14d0 :3 0 14d0
0 14d0 14cf 14cd
14ce :6 0 14d2 32
:3 0 c03 14d4 c05
14d3 14d2 :2 0 14d5
c07 :2 0 14d7 0
14d7 14d6 148d 14d5
:6 0 14d9 1 :3 0
c09 14db 13f3 146b
0 14dc 0 14d9
0 14dc c0b 0
14dd c0e 1623 4d
:3 0 c2 :2 0 c10
14df 14e0 :3 0 14e1
:2 0 d2 :3 0 ff
:3 0 d :3 0 ce
:3 0 39 :3 0 d1
:3 0 38 :3 0 13e
:3 0 13f :3 0 c3
:3 0 12 :3 0 13e
:3 0 140 :3 0 13f
:3 0 c3 :3 0 13
:3 0 140 :3 0 141
:3 0 13f :3 0 14
:3 0 141 :3 0 142
:3 0 13f :3 0 15
:3 0 142 :3 0 143
:3 0 144 :3 0 145
:3 0 146 :3 0 147
:3 0 148 :3 0 149
:3 0 14a :3 0 144
:3 0 12 :3 0 146
:3 0 13 :3 0 148
:3 0 14 :3 0 14a
:3 0 15 :3 0 14b
:3 0 14c :3 0 14d
:3 0 14e :3 0 14f
:3 0 150 :3 0 151
:3 0 152 :3 0 13f
:3 0 f1 :3 0 f2
:3 0 f3 :3 0 f4
:3 0 f5 :3 0 f6
:3 0 100 :3 0 16
:3 0 101 :3 0 17
:3 0 cc :3 0 18
:3 0 74 :3 0 2b
:4 0 163 1 :8 0
1539 f8 :4 0 1524
:3 0 9c :3 0 a4
:2 0 c14 1527 1528
:3 0 1b :3 0 ab
:3 0 152a 152b 0
31 :2 0 152c 152d
0 152f c17 1536
1b :3 0 ab :3 0
1530 1531 0 f9
:2 0 1532 1533 0
1535 c19 1537 1529
152f 0 1538 0
1535 0 1538 c1b
0 1539 c1e 1583
ad :3 0 1b :3 0
ab :3 0 153c 153d
0 ac :3 0 153e
153f 0 1579 78
:3 0 79 :3 0 1541
1542 0 78 :3 0
88 :3 0 1544 1545
0 25 :2 0 2
:4 0 164 :2 0 8a
:2 0 49 :2 0 c21
154a 154c :3 0 c24
1546 154e 1543 1550
154f :2 0 7b :3 0
8b :3 0 1552 1553
0 7d :4 0 165
:4 0 80 :2 0 81
:3 0 c28 1557 1559
:3 0 80 :2 0 94
:4 0 c2b 155b 155d
:3 0 80 :2 0 b0
:4 0 c2e 155f 1561
:3 0 80 :2 0 ac
:3 0 c31 1563 1565
:3 0 80 :2 0 b1
:4 0 c34 1567 1569
:3 0 80 :2 0 b2
:3 0 b3 :3 0 49
:2 0 b4 :2 0 c37
156c 1570 c3b 156b
1572 :3 0 c3e 1554
1574 :2 0 1576 c41
1577 1551 1576 0
1578 c43 0 1579
c45 157c :3 0 157c
0 157c 157b 1579
157a :6 0 157e 34
:3 0 c48 1580 c4a
157f 157e :2 0 1581
c4c :2 0 1583 0
1583 1582 1539 1581
:6 0 1585 1 :3 0
c4e 161f d2 :3 0
ff :3 0 d :3 0
ce :3 0 39 :3 0
d1 :3 0 38 :3 0
cc :3 0 c :3 0
13e :3 0 13f :3 0
c3 :3 0 12 :3 0
13e :3 0 140 :3 0
13f :3 0 c3 :3 0
13 :3 0 140 :3 0
141 :3 0 13f :3 0
14 :3 0 141 :3 0
142 :3 0 13f :3 0
15 :3 0 142 :3 0
143 :3 0 144 :3 0
145 :3 0 146 :3 0
147 :3 0 148 :3 0
149 :3 0 14a :3 0
144 :3 0 12 :3 0
146 :3 0 13 :3 0
148 :3 0 14 :3 0
14a :3 0 15 :3 0
14b :3 0 14c :3 0
14d :3 0 14e :3 0
14f :3 0 150 :3 0
151 :3 0 152 :3 0
13f :3 0 74 :3 0
2b :4 0 166 1
:8 0 15d2 f8 :4 0
15bd :3 0 9c :3 0
a4 :2 0 c52 15c0
15c1 :3 0 1b :3 0
ab :3 0 15c3 15c4
0 31 :2 0 15c5
15c6 0 15c8 c55
15cf 1b :3 0 ab
:3 0 15c9 15ca 0
f9 :2 0 15cb 15cc
0 15ce c57 15d0
15c2 15c8 0 15d1
0 15ce 0 15d1
c59 0 15d2 c5c
161c ad :3 0 1b
:3 0 ab :3 0 15d5
15d6 0 ac :3 0
15d7 15d8 0 1612
78 :3 0 79 :3 0
15da 15db 0 78
:3 0 88 :3 0 15dd
15de 0 25 :2 0
2 :4 0 167 :2 0
8a :2 0 49 :2 0
c5f 15e3 15e5 :3 0
c62 15df 15e7 15dc
15e9 15e8 :2 0 7b
:3 0 8b :3 0 15eb
15ec 0 7d :4 0
168 :4 0 80 :2 0
81 :3 0 c66 15f0
15f2 :3 0 80 :2 0
94 :4 0 c69 15f4
15f6 :3 0 80 :2 0
b0 :4 0 c6c 15f8
15fa :3 0 80 :2 0
ac :3 0 c6f 15fc
15fe :3 0 80 :2 0
b1 :4 0 c72 1600
1602 :3 0 80 :2 0
b2 :3 0 b3 :3 0
49 :2 0 b4 :2 0
c75 1605 1609 c79
1604 160b :3 0 c7c
15ed 160d :2 0 160f
c7f 1610 15ea 160f
0 1611 c81 0
1612 c83 1615 :3 0
1615 0 1615 1614
1612 1613 :6 0 1617
36 :3 0 c86 1619
c88 1618 1617 :2 0
161a c8a :2 0 161c
0 161c 161b 15d2
161a :6 0 161e 1
:3 0 c8c 1620 14e2
1585 0 1621 0
161e 0 1621 c8e
0 1622 c91 1624
13ee 14dd 0 1625
0 1622 0 1625
c93 0 1627 159
:3 0 c96 1795 85
:3 0 3e :3 0 31
:2 0 c98 1628 162b
a4 :2 0 31 :2 0
c9d 162d 162f :3 0
47 :3 0 8d :2 0
ca0 1632 1633 :3 0
1634 :2 0 85 :3 0
e :3 0 31 :2 0
ca2 1636 1639 a4
:2 0 31 :2 0 ca7
163b 163d :3 0 d2
:3 0 ff :3 0 d
:3 0 ce :3 0 39
:3 0 d1 :3 0 38
:3 0 cc :3 0 c
:3 0 f0 :3 0 3d
:3 0 c :3 0 74
:3 0 2b :4 0 169
1 :8 0 1663 f8
:4 0 164e :3 0 9c
:3 0 a4 :2 0 cac
1651 1652 :3 0 1b
:3 0 ab :3 0 1654
1655 0 31 :2 0
1656 1657 0 1659
caf 1660 1b :3 0
ab :3 0 165a 165b
0 f9 :2 0 165c
165d 0 165f cb1
1661 1653 1659 0
1662 0 165f 0
1662 cb3 0 1663
cb6 16ad ad :3 0
1b :3 0 ab :3 0
1666 1667 0 ac
:3 0 1668 1669 0
16a3 78 :3 0 79
:3 0 166b 166c 0
78 :3 0 88 :3 0
166e 166f 0 25
:2 0 2 :4 0 16a
:2 0 8a :2 0 49
:2 0 cb9 1674 1676
:3 0 cbc 1670 1678
166d 167a 1679 :2 0
7b :3 0 8b :3 0
167c 167d 0 7d
:4 0 16b :4 0 80
:2 0 81 :3 0 cc0
1681 1683 :3 0 80
:2 0 94 :4 0 cc3
1685 1687 :3 0 80
:2 0 b0 :4 0 cc6
1689 168b :3 0 80
:2 0 ac :3 0 cc9
168d 168f :3 0 80
:2 0 b1 :4 0 ccc
1691 1693 :3 0 80
:2 0 b2 :3 0 b3
:3 0 49 :2 0 b4
:2 0 ccf 1696 169a
cd3 1695 169c :3 0
cd6 167e 169e :2 0
16a0 cd9 16a1 167b
16a0 0 16a2 cdb
0 16a3 cdd 16a6
:3 0 16a6 0 16a6
16a5 16a3 16a4 :6 0
16a8 38 :3 0 ce0
16aa ce2 16a9 16a8
:2 0 16ab ce4 :2 0
16ad 0 16ad 16ac
1663 16ab :6 0 16af
1 :3 0 ce6 171e
d2 :3 0 ff :3 0
d :3 0 ce :3 0
39 :3 0 d1 :3 0
38 :3 0 cc :3 0
c :3 0 74 :3 0
2b :4 0 160 1
:8 0 16d1 f8 :4 0
16bc :3 0 9c :3 0
a4 :2 0 cea 16bf
16c0 :3 0 1b :3 0
ab :3 0 16c2 16c3
0 31 :2 0 16c4
16c5 0 16c7 ced
16ce 1b :3 0 ab
:3 0 16c8 16c9 0
f9 :2 0 16ca 16cb
0 16cd cef 16cf
16c1 16c7 0 16d0
0 16cd 0 16d0
cf1 0 16d1 cf4
171b ad :3 0 1b
:3 0 ab :3 0 16d4
16d5 0 ac :3 0
16d6 16d7 0 1711
78 :3 0 79 :3 0
16d9 16da 0 78
:3 0 88 :3 0 16dc
16dd 0 25 :2 0
2 :4 0 16c :2 0
8a :2 0 49 :2 0
cf7 16e2 16e4 :3 0
cfa 16de 16e6 16db
16e8 16e7 :2 0 7b
:3 0 8b :3 0 16ea
16eb 0 7d :4 0
16d :4 0 80 :2 0
81 :3 0 cfe 16ef
16f1 :3 0 80 :2 0
94 :4 0 d01 16f3
16f5 :3 0 80 :2 0
b0 :4 0 d04 16f7
16f9 :3 0 80 :2 0
ac :3 0 d07 16fb
16fd :3 0 80 :2 0
b1 :4 0 d0a 16ff
1701 :3 0 80 :2 0
b2 :3 0 b3 :3 0
49 :2 0 b4 :2 0
d0d 1704 1708 d11
1703 170a :3 0 d14
16ec 170c :2 0 170e
d17 170f 16e9 170e
0 1710 d19 0
1711 d1b 1714 :3 0
1714 0 1714 1713
1711 1712 :6 0 1716
3a :3 0 d1e 1718
d20 1717 1716 :2 0
1719 d22 :2 0 171b
0 171b 171a 16d1
1719 :6 0 171d 1
:3 0 d24 171f 163e
16af 0 1720 0
171d 0 1720 d26
0 1721 d29 1790
d2 :3 0 ff :3 0
d :3 0 ce :3 0
39 :3 0 d1 :3 0
38 :3 0 cc :3 0
c :3 0 74 :3 0
2b :4 0 16e 1
:8 0 1743 f8 :4 0
172e :3 0 9c :3 0
a4 :2 0 d2d 1731
1732 :3 0 1b :3 0
ab :3 0 1734 1735
0 31 :2 0 1736
1737 0 1739 d30
1740 1b :3 0 ab
:3 0 173a 173b 0
f9 :2 0 173c 173d
0 173f d32 1741
1733 1739 0 1742
0 173f 0 1742
d34 0 1743 d37
178d ad :3 0 1b
:3 0 ab :3 0 1746
1747 0 ac :3 0
1748 1749 0 1783
78 :3 0 79 :3 0
174b 174c 0 78
:3 0 88 :3 0 174e
174f 0 25 :2 0
2 :4 0 16f :2 0
8a :2 0 49 :2 0
d3a 1754 1756 :3 0
d3d 1750 1758 174d
175a 1759 :2 0 7b
:3 0 8b :3 0 175c
175d 0 7d :4 0
170 :4 0 80 :2 0
81 :3 0 d41 1761
1763 :3 0 80 :2 0
94 :4 0 d44 1765
1767 :3 0 80 :2 0
b0 :4 0 d47 1769
176b :3 0 80 :2 0
ac :3 0 d4a 176d
176f :3 0 80 :2 0
b1 :4 0 d4d 1771
1773 :3 0 80 :2 0
b2 :3 0 b3 :3 0
49 :2 0 b4 :2 0
d50 1776 177a d54
1775 177c :3 0 d57
175e 177e :2 0 1780
d5a 1781 175b 1780
0 1782 d5c 0
1783 d5e 1786 :3 0
1786 0 1786 1785
1783 1784 :6 0 1788
3c :3 0 d61 178a
d63 1789 1788 :2 0
178b d65 :2 0 178d
0 178d 178c 1743
178b :6 0 178f 1
:3 0 d67 1791 1635
1721 0 1792 0
178f 0 1792 d69
0 1793 d6c 1794
1630 1793 0 1796
13e9 1627 0 1796
d6e 0 1797 d71
1799 111a 13db 0
179a 0 1797 0
179a d73 0 1bc1
4d :3 0 c2 :2 0
d76 179c 179d :3 0
179e :2 0 85 :3 0
18 :3 0 31 :2 0
d78 17a0 17a3 8f
:2 0 31 :2 0 d7d
17a5 17a7 :3 0 17a8
:2 0 179f 17aa 17a9
:2 0 17ab :2 0 85
:3 0 c :3 0 31
:2 0 d80 17ad 17b0
8f :2 0 31 :2 0
d85 17b2 17b4 :3 0
17b5 :2 0 17ac 17b7
17b6 :2 0 45 :3 0
171 :4 0 17b9 17ba
0 1bbe 45 :4 0
17bc 17bd 0 1bbe
3f :3 0 31 :2 0
17bf 17c0 0 1bbe
3e :3 0 31 :2 0
17c2 17c3 0 1bbe
85 :3 0 57 :3 0
31 :2 0 d88 17c5
17c8 a4 :2 0 49
:2 0 d8d 17ca 17cc
:3 0 74 :3 0 f6
:3 0 ca :3 0 172
:3 0 b2 :3 0 f2
:3 0 172 :3 0 b2
:3 0 f4 :3 0 173
:3 0 174 :3 0 14c
:3 0 14e :3 0 46
:3 0 3d :3 0 2e
:3 0 59 :3 0 5a
:3 0 5e :3 0 5f
:3 0 5b :3 0 5d
:3 0 d2 :3 0 137
:3 0 2b :4 0 175
1 :8 0 17ed 1b
:3 0 ab :3 0 17e8
17e9 0 ac :3 0
17ea 17eb 0 17ed
d90 1837 ad :3 0
1b :3 0 ab :3 0
17f0 17f1 0 ac
:3 0 17f2 17f3 0
182d 78 :3 0 79
:3 0 17f5 17f6 0
78 :3 0 88 :3 0
17f8 17f9 0 25
:2 0 2 :4 0 176
:2 0 8a :2 0 49
:2 0 d93 17fe 1800
:3 0 d96 17fa 1802
17f7 1804 1803 :2 0
7b :3 0 8b :3 0
1806 1807 0 7d
:4 0 177 :4 0 80
:2 0 81 :3 0 d9a
180b 180d :3 0 80
:2 0 94 :4 0 d9d
180f 1811 :3 0 80
:2 0 b0 :4 0 da0
1813 1815 :3 0 80
:2 0 ac :3 0 da3
1817 1819 :3 0 80
:2 0 b1 :4 0 da6
181b 181d :3 0 80
:2 0 b2 :3 0 b3
:3 0 49 :2 0 b4
:2 0 da9 1820 1824
dad 181f 1826 :3 0
db0 1808 1828 :2 0
182a db3 182b 1805
182a 0 182c db5
0 182d db7 1830
:3 0 1830 0 1830
182f 182d 182e :6 0
1832 3e :3 0 dba
1834 dbc 1833 1832
:2 0 1835 dbe :2 0
1837 0 1837 1836
17ed 1835 :6 0 1839
1 :3 0 dc0 18a7
46 :3 0 2b :3 0
183a 183b 0 18a6
f6 :3 0 ca :3 0
172 :3 0 b2 :3 0
f2 :3 0 172 :3 0
b2 :3 0 f4 :3 0
173 :3 0 174 :3 0
14c :3 0 14e :3 0
3d :3 0 2e :3 0
59 :3 0 5a :3 0
5e :3 0 5f :3 0
5b :3 0 5d :3 0
d2 :3 0 74 :3 0
46 :4 0 178 1
:8 0 185a 1b :3 0
ab :3 0 1855 1856
0 ac :3 0 1857
1858 0 185a dc2
18a4 ad :3 0 1b
:3 0 ab :3 0 185d
185e 0 ac :3 0
185f 1860 0 189a
78 :3 0 79 :3 0
1862 1863 0 78
:3 0 88 :3 0 1865
1866 0 25 :2 0
2 :4 0 179 :2 0
8a :2 0 49 :2 0
dc5 186b 186d :3 0
dc8 1867 186f 1864
1871 1870 :2 0 7b
:3 0 8b :3 0 1873
1874 0 7d :4 0
17a :4 0 80 :2 0
81 :3 0 dcc 1878
187a :3 0 80 :2 0
94 :4 0 dcf 187c
187e :3 0 80 :2 0
b0 :4 0 dd2 1880
1882 :3 0 80 :2 0
ac :3 0 dd5 1884
1886 :3 0 80 :2 0
b1 :4 0 dd8 1888
188a :3 0 80 :2 0
b2 :3 0 b3 :3 0
49 :2 0 b4 :2 0
ddb 188d 1891 ddf
188c 1893 :3 0 de2
1875 1895 :2 0 1897
de5 1898 1872 1897
0 1899 de7 0
189a de9 189d :3 0
189d 0 189d 189c
189a 189b :6 0 189f
40 :3 0 dec 18a1
dee 18a0 189f :2 0
18a2 df0 :2 0 18a4
0 18a4 18a3 185a
18a2 :6 0 18a6 1
:3 0 df2 18a8 17cd
1839 0 18a9 0
18a6 0 18a9 df5
0 1bbe 1b :3 0
ab :3 0 18aa 18ab
0 1b :3 0 a4
:2 0 d6 :3 0 18ad
18af 0 dfa 18ae
18b1 :3 0 18b2 :2 0
85 :3 0 c :3 0
31 :2 0 dfd 18b4
18b7 85 :3 0 a4
:2 0 a :3 0 31
:2 0 e00 18b9 18bd
e05 18ba 18bf :3 0
18c0 :2 0 85 :3 0
e :3 0 31 :2 0
e08 18c2 18c5 a4
:2 0 31 :2 0 e0d
18c7 18c9 :3 0 18ca
:2 0 18c1 18cc 18cb
:2 0 85 :3 0 d
:3 0 31 :2 0 e10
18ce 18d1 a4 :2 0
ec :2 0 e15 18d3
18d5 :3 0 18d6 :2 0
18cd 18d8 18d7 :2 0
73 :3 0 75 :3 0
70 :3 0 72 :3 0
6a :3 0 2d :3 0
74 :3 0 46 :4 0
17b 1 :8 0 18f8
f8 :4 0 18e3 :3 0
9c :3 0 a4 :2 0
e1a 18e6 18e7 :3 0
1b :3 0 ab :3 0
18e9 18ea 0 31
:2 0 18eb 18ec 0
18ee e1d 18f5 1b
:3 0 ab :3 0 18ef
18f0 0 f9 :2 0
18f1 18f2 0 18f4
e1f 18f6 18e8 18ee
0 18f7 0 18f4
0 18f7 e21 0
18f8 e24 1942 ad
:3 0 1b :3 0 ab
:3 0 18fb 18fc 0
ac :3 0 18fd 18fe
0 1938 78 :3 0
79 :3 0 1900 1901
0 78 :3 0 88
:3 0 1903 1904 0
25 :2 0 2 :4 0
17c :2 0 8a :2 0
49 :2 0 e27 1909
190b :3 0 e2a 1905
190d 1902 190f 190e
:2 0 7b :3 0 8b
:3 0 1911 1912 0
7d :4 0 17d :4 0
80 :2 0 81 :3 0
e2e 1916 1918 :3 0
80 :2 0 94 :4 0
e31 191a 191c :3 0
80 :2 0 b0 :4 0
e34 191e 1920 :3 0
80 :2 0 ac :3 0
e37 1922 1924 :3 0
80 :2 0 b1 :4 0
e3a 1926 1928 :3 0
80 :2 0 b2 :3 0
b3 :3 0 49 :2 0
b4 :2 0 e3d 192b
192f e41 192a 1931
:3 0 e44 1913 1933
:2 0 1935 e47 1936
1910 1935 0 1937
e49 0 1938 e4b
193b :3 0 193b 0
193b 193a 1938 1939
:6 0 193d 42 :3 0
e4e 193f e50 193e
193d :2 0 1940 e52
:2 0 1942 0 1942
1941 18f8 1940 :6 0
19b3 1 :3 0 d2
:3 0 cc :3 0 f6
:3 0 108 :3 0 17e
:3 0 71 :3 0 73
:3 0 6a :3 0 2d
:3 0 74 :3 0 46
:3 0 74 :3 0 46
:4 0 17f 1 :8 0
1967 f8 :4 0 1952
:3 0 9c :3 0 a4
:2 0 e56 1955 1956
:3 0 1b :3 0 ab
:3 0 1958 1959 0
31 :2 0 195a 195b
0 195d e59 1964
1b :3 0 ab :3 0
195e 195f 0 f9
:2 0 1960 1961 0
1963 e5b 1965 1957
195d 0 1966 0
1963 0 1966 e5d
0 1967 e60 19b1
ad :3 0 1b :3 0
ab :3 0 196a 196b
0 ac :3 0 196c
196d 0 19a7 78
:3 0 79 :3 0 196f
1970 0 78 :3 0
88 :3 0 1972 1973
0 25 :2 0 2
:4 0 180 :2 0 8a
:2 0 49 :2 0 e63
1978 197a :3 0 e66
1974 197c 1971 197e
197d :2 0 7b :3 0
8b :3 0 1980 1981
0 7d :4 0 181
:4 0 80 :2 0 81
:3 0 e6a 1985 1987
:3 0 80 :2 0 94
:4 0 e6d 1989 198b
:3 0 80 :2 0 b0
:4 0 e70 198d 198f
:3 0 80 :2 0 ac
:3 0 e73 1991 1993
:3 0 80 :2 0 b1
:4 0 e76 1995 1997
:3 0 80 :2 0 b2
:3 0 b3 :3 0 49
:2 0 b4 :2 0 e79
199a 199e e7d 1999
19a0 :3 0 e80 1982
19a2 :2 0 19a4 e83
19a5 197f 19a4 0
19a6 e85 0 19a7
e87 19aa :3 0 19aa
0 19aa 19a9 19a7
19a8 :6 0 19ac 44
:3 0 e8a 19ae e8c
19ad 19ac :2 0 19af
e8e :2 0 19b1 0
19b1 19b0 1967 19af
:6 0 19b3 1 :3 0
e90 1b8b 11f :3 0
6f :4 0 19b7 :2 0
1b8a 19b5 19b8 :3 0
182 :3 0 6f :3 0
40 :3 0 43 :3 0
3e :4 0 19bf :2 0
1ab6 19ba 19c0 :3 0
e93 :3 0 6f :3 0
f8 :3 0 19c1 19c2
:3 0 1b :3 0 ab
:3 0 19c4 19c5 0
31 :2 0 19c6 19c7
0 19c9 e97 19d0
1b :3 0 ab :3 0
19ca 19cb 0 f9
:2 0 19cc 19cd 0
19cf e99 19d1 19c3
19c9 0 19d2 0
19cf 0 19d2 e9b
0 1ab6 1b :3 0
ab :3 0 19d3 19d4
0 bf :2 0 31
:2 0 ea0 19d6 19d8
:3 0 183 :8 0 19dc
ea3 19dd 19d9 19dc
0 19de ea5 0
1ab6 3f :3 0 85
:3 0 3f :3 0 31
:2 0 ea7 19e0 19e3
8a :2 0 85 :3 0
40 :3 0 31 :2 0
eaa 19e6 19e9 ead
19e5 19eb :3 0 19df
19ec 0 1ab6 85
:3 0 3e :3 0 31
:2 0 eb0 19ee 19f1
a4 :2 0 31 :2 0
eb5 19f3 19f5 :3 0
85 :3 0 3f :3 0
31 :2 0 eb8 19f7
19fa 85 :3 0 8f
:2 0 42 :3 0 31
:2 0 ebb 19fc 1a00
ec0 19fd 1a02 :3 0
85 :3 0 40 :3 0
31 :2 0 ec3 1a04
1a07 85 :3 0 184
:2 0 42 :3 0 31
:2 0 ec6 1a09 1a0d
ecb 1a0a 1a0f :3 0
40 :3 0 85 :3 0
42 :3 0 31 :2 0
ece 1a12 1a15 1a11
1a16 0 1a18 ed1
1a31 40 :3 0 85
:3 0 42 :3 0 31
:2 0 ed3 1a1a 1a1d
d7 :2 0 85 :3 0
3f :3 0 31 :2 0
ed6 1a20 1a23 ed9
1a1f 1a25 :3 0 8a
:2 0 85 :3 0 40
:3 0 31 :2 0 edc
1a28 1a2b edf 1a27
1a2d :3 0 1a19 1a2e
0 1a30 ee2 1a32
1a10 1a18 0 1a33
0 1a30 0 1a33
ee4 0 1a34 ee7
1a35 1a03 1a34 0
1a36 ee9 0 1aa1
73 :3 0 75 :3 0
40 :3 0 72 :3 0
6f :4 0 185 1
:8 0 1a52 f8 :4 0
1a3d :3 0 9c :3 0
a4 :2 0 eed 1a40
1a41 :3 0 1b :3 0
ab :3 0 1a43 1a44
0 31 :2 0 1a45
1a46 0 1a48 ef0
1a4f 1b :3 0 ab
:3 0 1a49 1a4a 0
f9 :2 0 1a4b 1a4c
0 1a4e ef2 1a50
1a42 1a48 0 1a51
0 1a4e 0 1a51
ef4 0 1a52 ef7
1a9c ad :3 0 1b
:3 0 ab :3 0 1a55
1a56 0 ac :3 0
1a57 1a58 0 1a92
78 :3 0 79 :3 0
1a5a 1a5b 0 78
:3 0 88 :3 0 1a5d
1a5e 0 25 :2 0
2 :4 0 186 :2 0
8a :2 0 49 :2 0
efa 1a63 1a65 :3 0
efd 1a5f 1a67 1a5c
1a69 1a68 :2 0 7b
:3 0 8b :3 0 1a6b
1a6c 0 7d :4 0
187 :4 0 80 :2 0
81 :3 0 f01 1a70
1a72 :3 0 80 :2 0
94 :4 0 f04 1a74
1a76 :3 0 80 :2 0
b0 :4 0 f07 1a78
1a7a :3 0 80 :2 0
ac :3 0 f0a 1a7c
1a7e :3 0 80 :2 0
b1 :4 0 f0d 1a80
1a82 :3 0 80 :2 0
b2 :3 0 b3 :3 0
49 :2 0 b4 :2 0
f10 1a85 1a89 f14
1a84 1a8b :3 0 f17
1a6d 1a8d :2 0 1a8f
f1a 1a90 1a6a 1a8f
0 1a91 f1c 0
1a92 f1e 1a95 :3 0
1a95 0 1a95 1a94
1a92 1a93 :6 0 1a97
47 :3 0 f21 1a99
f23 1a98 1a97 :2 0
1a9a f25 :2 0 1a9c
0 1a9c 1a9b 1a52
1a9a :6 0 1aa1 46
:3 0 45 :3 0 43
:3 0 1a9e 1a9f 0
1aa1 f27 1aa2 19f6
1aa1 0 1aa3 f2b
0 1ab6 85 :3 0
3f :3 0 31 :2 0
f2d 1aa4 1aa7 85
:3 0 184 :2 0 42
:3 0 31 :2 0 f30
1aa9 1aad f35 1aaa
1aaf :3 0 183 :8 0
1ab3 f38 1ab4 1ab0
1ab3 0 1ab5 f3a
0 1ab6 f3c 1ab8
182 :4 0 1ab6 :4 0
1b8a 120 :3 0 6f
:4 0 1abc :2 0 1ac2
1aba 0 1b :3 0
ab :3 0 1abd 1abe
0 ac :3 0 1abf
1ac0 0 1ac2 f43
1b0c ad :3 0 1b
:3 0 ab :3 0 1ac5
1ac6 0 ac :3 0
1ac7 1ac8 0 1b02
78 :3 0 79 :3 0
1aca 1acb 0 78
:3 0 88 :3 0 1acd
1ace 0 25 :2 0
2 :4 0 188 :2 0
8a :2 0 49 :2 0
f46 1ad3 1ad5 :3 0
f49 1acf 1ad7 1acc
1ad9 1ad8 :2 0 7b
:3 0 8b :3 0 1adb
1adc 0 7d :4 0
189 :4 0 80 :2 0
81 :3 0 f4d 1ae0
1ae2 :3 0 80 :2 0
94 :4 0 f50 1ae4
1ae6 :3 0 80 :2 0
b0 :4 0 f53 1ae8
1aea :3 0 80 :2 0
ac :3 0 f56 1aec
1aee :3 0 80 :2 0
b1 :4 0 f59 1af0
1af2 :3 0 80 :2 0
b2 :3 0 b3 :3 0
49 :2 0 b4 :2 0
f5c 1af5 1af9 f60
1af4 1afb :3 0 f63
1add 1afd :2 0 1aff
f66 1b00 1ada 1aff
0 1b01 f68 0
1b02 f6a 1b05 :3 0
1b05 0 1b05 1b04
1b02 1b03 :6 0 1b07
49 :3 0 f6d 1b09
f6f 1b08 1b07 :2 0
1b0a f71 :2 0 1b0c
0 1b0c 1b0b 1ac2
1b0a :6 0 1b8a 1
:3 0 85 :3 0 3f
:3 0 31 :2 0 f73
1b0e 1b11 8f :2 0
31 :2 0 f78 1b13
1b15 :3 0 1b16 :2 0
45 :3 0 c2 :2 0
f7b 1b19 1b1a :3 0
1b1b :2 0 1b1c :2 0
1b17 1b1e 1b1d :2 0
d2 :3 0 108 :3 0
45 :3 0 74 :3 0
46 :4 0 18a 1
:8 0 1b3b f8 :4 0
1b26 :3 0 9c :3 0
a4 :2 0 f7f 1b29
1b2a :3 0 1b :3 0
ab :3 0 1b2c 1b2d
0 31 :2 0 1b2e
1b2f 0 1b31 f82
1b38 1b :3 0 ab
:3 0 1b32 1b33 0
f9 :2 0 1b34 1b35
0 1b37 f84 1b39
1b2b 1b31 0 1b3a
0 1b37 0 1b3a
f86 0 1b3b f89
1b85 ad :3 0 1b
:3 0 ab :3 0 1b3e
1b3f 0 ac :3 0
1b40 1b41 0 1b7b
78 :3 0 79 :3 0
1b43 1b44 0 78
:3 0 88 :3 0 1b46
1b47 0 25 :2 0
2 :4 0 18b :2 0
8a :2 0 49 :2 0
f8c 1b4c 1b4e :3 0
f8f 1b48 1b50 1b45
1b52 1b51 :2 0 7b
:3 0 8b :3 0 1b54
1b55 0 7d :4 0
18c :4 0 80 :2 0
81 :3 0 f93 1b59
1b5b :3 0 80 :2 0
94 :4 0 f96 1b5d
1b5f :3 0 80 :2 0
b0 :4 0 f99 1b61
1b63 :3 0 80 :2 0
ac :3 0 f9c 1b65
1b67 :3 0 80 :2 0
b1 :4 0 f9f 1b69
1b6b :3 0 80 :2 0
b2 :3 0 b3 :3 0
49 :2 0 b4 :2 0
fa2 1b6e 1b72 fa6
1b6d 1b74 :3 0 fa9
1b56 1b76 :2 0 1b78
fac 1b79 1b53 1b78
0 1b7a fae 0
1b7b fb0 1b7e :3 0
1b7e 0 1b7e 1b7d
1b7b 1b7c :6 0 1b80
4b :3 0 fb3 1b82
fb5 1b81 1b80 :2 0
1b83 fb7 :2 0 1b85
0 1b85 1b84 1b3b
1b83 :6 0 1b87 1
:3 0 fb9 1b88 1b1f
1b87 0 1b89 fbb
0 1b8a fbd 1b8c
18d9 19b3 0 1b8d
0 1b8a 0 1b8d
fc2 0 1bbb 85
:3 0 57 :3 0 31
:2 0 fc5 1b8e 1b91
a4 :2 0 49 :2 0
fca 1b93 1b95 :3 0
ee :3 0 85 :3 0
f :3 0 31 :2 0
fcd 1b98 1b9b 27
:2 0 fd0 1b97 1b9e
1b9f :2 0 a4 :2 0
27 :2 0 fd5 1ba1
1ba3 :3 0 54 :3 0
18d :3 0 46 :3 0
2f :3 0 fd8 1ba6
1ba9 1ba5 1baa 0
1bac fdb 1bb5 54
:3 0 18e :3 0 46
:3 0 2f :3 0 fdd
1bae 1bb1 1bad 1bb2
0 1bb4 fe0 1bb6
1ba4 1bac 0 1bb7
0 1bb4 0 1bb7
fe2 0 1bb8 fe5
1bb9 1b96 1bb8 0
1bba fe7 0 1bbb
fe9 1bbc 18b3 1bbb
0 1bbd fec 0
1bbe fee 1bbf 17b8
1bbe 0 1bc0 ff5
0 1bc1 ff7 1bc2
74b 1bc1 0 1bc3
1005 0 1bd3 1b
:3 0 ab :3 0 1bc4
1bc5 0 a4 :2 0
f9 :2 0 1009 1bc7
1bc9 :3 0 1b :3 0
ab :3 0 1bcb 1bcc
0 31 :2 0 1bcd
1bce 0 1bd0 100c
1bd1 1bca 1bd0 0
1bd2 100e 0 1bd3
1010 1bd4 49f 1bd3
0 1bd5 1014 0
1c24 78 :3 0 79
:3 0 1bd6 1bd7 0
78 :3 0 88 :3 0
1bd9 1bda 0 18f
:2 0 2 :4 0 190
:2 0 8a :2 0 49
:2 0 1016 1bdf 1be1
:3 0 1019 1bdb 1be3
1bd8 1be5 1be4 :2 0
7b :3 0 8b :3 0
1be7 1be8 0 7d
:4 0 191 :4 0 80
:2 0 81 :3 0 101d
1bec 1bee :3 0 80
:2 0 94 :4 0 1020
1bf0 1bf2 :3 0 80
:2 0 95 :4 0 1023
1bf4 1bf6 :3 0 80
:2 0 85 :3 0 66
:3 0 1b :3 0 ab
:3 0 1bfb 1bfc 0
1026 1bfa 1bfe 86
:4 0 1028 1bf9 1c01
102b 1bf8 1c03 :3 0
80 :2 0 da :4 0
102e 1c05 1c07 :3 0
80 :2 0 83 :4 0
1031 1c09 1c0b :3 0
80 :2 0 3 :3 0
1034 1c0d 1c0f :3 0
80 :2 0 83 :4 0
1037 1c11 1c13 :3 0
103a 1be9 1c15 :2 0
1c17 103d 1c18 1be6
1c17 0 1c19 103f
0 1c24 9a :3 0
192 :3 0 1c1a 1c1b
0 1b :3 0 ab
:3 0 1c1d 1c1e 0
3 :3 0 9c :3 0
1041 1c1c 1c22 :2 0
1c24 1045 1cc5 1b
:3 0 193 :2 0 4
1c25 1c26 0 78
:3 0 79 :3 0 1c28
1c29 0 78 :3 0
88 :3 0 1c2b 1c2c
0 25 :2 0 2
:4 0 194 :2 0 8a
:2 0 49 :2 0 105b
1c31 1c33 :3 0 105e
1c2d 1c35 1c2a 1c37
1c36 :2 0 7b :3 0
8b :3 0 1c39 1c3a
0 7d :4 0 195
:4 0 80 :2 0 81
:3 0 1062 1c3e 1c40
:3 0 1065 1c3b 1c42
:2 0 1c5b 7b :3 0
8b :3 0 1c44 1c45
0 7d :4 0 196
:4 0 80 :2 0 1b
:3 0 197 :3 0 1c4a
1c4b 0 1068 1c49
1c4d :3 0 80 :2 0
da :4 0 106b 1c4f
1c51 :3 0 80 :2 0
1b :3 0 198 :3 0
1c54 1c55 0 106e
1c53 1c57 :3 0 1071
1c46 1c59 :2 0 1c5b
1074 1c5c 1c38 1c5b
0 1c5d 1077 0
1c6d 11f :3 0 77
:3 0 1b :3 0 197
:3 0 199 :3 0 1b
:3 0 198 :3 0 19a
:3 0 b9 :4 0 19b
1 :a 0 1c69 :2 0
1c6d 1c5f 1c67 :2 0
1a :3 0 77 :3 0
1c6b :2 0 1c6d 1079
1c6f 107d 1c6e 1c6d
:2 0 1cc3 ad :3 0
1b :3 0 ab :3 0
1c72 1c73 0 ac
:3 0 1c74 1c75 0
1cbb 78 :3 0 79
:3 0 1c77 1c78 0
78 :3 0 88 :3 0
1c7a 1c7b 0 25
:2 0 2 :4 0 19c
:2 0 8a :2 0 49
:2 0 107f 1c80 1c82
:3 0 1082 1c7c 1c84
1c79 1c86 1c85 :2 0
7b :3 0 8b :3 0
1c88 1c89 0 7d
:4 0 19d :4 0 80
:2 0 81 :3 0 1086
1c8d 1c8f :3 0 1089
1c8a 1c91 :2 0 1cab
7b :3 0 8b :3 0
1c93 1c94 0 7d
:4 0 b0 :4 0 80
:2 0 ac :3 0 108c
1c98 1c9a :3 0 80
:2 0 b1 :4 0 108f
1c9c 1c9e :3 0 80
:2 0 b2 :3 0 b3
:3 0 49 :2 0 b4
:2 0 1092 1ca1 1ca5
1096 1ca0 1ca7 :3 0
1099 1c95 1ca9 :2 0
1cab 109c 1cac 1c87
1cab 0 1cad 109f
0 1cbb 11f :3 0
77 :3 0 199 :3 0
1b :3 0 198 :3 0
19a :3 0 b9 :4 0
19e 1 :a 0 1cb7
:2 0 1cbb 1caf 1cb5
:2 0 1a :3 0 77
:3 0 1cb9 :2 0 1cbb
10a1 1cbe :3 0 1cbe
0 1cbe 1cbd 1cbb
1cbc :6 0 1cc0 1
:3 0 10a6 1cc2 10a8
1cc1 1cc0 :2 0 1cc3
10aa :2 0 1cc5 10ad
1cc5 1cc4 1c24 1cc3
:6 0 1cc6 :2 0 2
5c 1cc5 1cc9 :3 0
1cc8 1cc6 1cca :8 0

10ea
4
:3 0 1 3 1
7 1 b 1
f 1 13 1
17 1 1b 1
1f 1 23 1
27 1 2b 1
2f 1 33 1
37 1 3b 1
3f 1 43 1
47 1 4b 1
4f 1 53 15
6 a e 12
16 1a 1e 22
26 2a 2e 32
36 3a 3e 42
46 4a 4e 52
56 1 60 1
5e 1 67 1
65 1 6e 1
6c 1 75 1
73 1 7c 1
7a 1 83 1
81 1 8a 1
88 1 91 1
8f 1 98 1
96 1 9f 1
9d 1 a6 1
a4 1 ad 1
ab 1 b4 1
b2 1 bb 1
b9 1 c0 1
c6 1 cc 1
d2 1 d8 1
de 1 e4 1
ea 1 f0 1
f6 1 fc 1
102 1 108 1
10e 1 114 1
11a 1 120 1
125 1 12c 1
12a 1 133 1
131 1 13a 1
138 1 13f 1
144 1 149 1
14e 1 153 1
158 1 15f 1
15d 1 164 1
16a 1 170 1
176 1 17c 1
182 1 188 1
18e 1 193 1
198 1 19e 1
1a4 1 1aa 1
1b0 1 1b6 1
1cf 1 1e4 1
1ea 1 1f7 1
203 2 206 208
2 20b 20d 2
20f 211 2 213
215 2 217 219
1 21f 2 221
222 2 21b 224
2 226 228 2
22a 22c 2 22e
230 2 232 234
2 236 238 2
23a 23c 2 23e
240 2 242 244
2 246 248 2
24a 24c 2 24e
250 2 252 254
2 256 258 1
25e 2 260 261
2 25a 263 2
265 267 2 269
26b 2 26d 26f
2 271 273 2
275 277 1 27d
2 27f 280 2
279 282 2 284
286 1 28c 2
28e 28f 2 288
291 2 293 295
1 29b 2 29d
29e 2 297 2a0
2 2a2 2a4 1
2aa 2 2ac 2ad
2 2a6 2af 2
2b1 2b3 1 2b9
2 2bb 2bc 2
2b5 2be 2 2c0
2c2 1 2c8 2
2ca 2cb 2 2c4
2cd 2 2cf 2d1
2 2d3 2d5 2
2d7 2d9 2 2db
2dd 2 2df 2e1
2 2e3 2e5 2
2e7 2e9 2 2eb
2ed 2 2ef 2f1
1 2f7 2 2f9
2fa 2 2f3 2fc
2 2fe 300 1
306 2 308 309
2 302 30b 2
30d 30f 2 311
313 2 315 317
2 319 31b 2
31d 31f 2 321
323 2 325 327
2 329 32b 2
32d 32f 1 335
2 337 338 2
331 33a 2 33c
33e 2 340 342
2 344 346 2
348 34a 2 34c
34e 4 1ff 205
20a 350 1 352
1 354 2 35e
360 3 35c 35d
362 2 36b 36d
2 36a 36f 1
371 1 373 1
375 2 37c 37d
1 381 2 37f
381 2 386 387
1 38b 2 389
38b 2 39c 39e
3 39a 39b 3a0
2 3a9 3ab 2
3ad 3af 2 3b1
3b3 1 3bb 2
3bd 3be 2 3b5
3c0 2 3a8 3c2
1 3c4 1 3c6
2 3d0 3d2 3
3ce 3cf 3d4 2
3dd 3df 2 3dc
3e1 1 3e3 1
3e5 2 3ec 3ed
3 3c7 3e6 3ef
1 3f1 1 3f3
1 3f9 1 401
2 411 413 3
40f 410 415 2
41e 420 2 422
424 2 426 428
1 430 2 432
433 2 42a 435
2 41d 437 1
439 1 43b 2
445 447 3 443
444 449 2 452
454 2 451 456
1 458 1 45a
2 461 462 3
43c 45b 464 1
466 1 494 2
496 497 1 49d
2 499 49d 2
4a1 4a2 1 4a6
2 4a4 4a6 2
4ab 4ac 1 4b0
2 4ae 4b0 1
4b6 2 4c3 4c5
3 4c1 4c2 4c7
2 4d0 4d2 2
4d4 4d6 2 4d8
4da 1 4e2 2
4e4 4e5 2 4dc
4e7 2 4cf 4e9
1 4eb 1 4ed
2 4f7 4f9 3
4f5 4f6 4fb 2
504 506 2 503
508 1 50a 1
50c 2 513 514
3 4ee 50d 516
1 518 2 52a
52f 2 540 542
3 53e 53f 544
2 54d 54f 2
551 553 2 555
557 2 559 55b
2 55d 55f 3
564 565 566 2
561 568 2 54c
56a 1 56c 1
56e 2 537 56f
1 573 1 532
1 577 2 584
585 1 587 6
58f 590 591 592
593 594 1 59c
2 59a 59c 2
5a1 5a2 1 5a6
2 5a4 5a6 2
5ad 5ae 1 5b2
2 5b0 5b2 2
5c3 5c8 2 5d9
5db 3 5d7 5d8
5dd 2 5e6 5e8
2 5ea 5ec 2
5ee 5f0 2 5f2
5f4 2 5f6 5f8
3 5fd 5fe 5ff
2 5fa 601 2
5e5 603 1 605
1 607 2 5d0
608 1 60c 1
5cb 1 610 2
616 617 1 61b
2 619 61b 1
627 2 632 637
2 648 64a 3
646 647 64c 2
655 657 2 659
65b 2 65d 65f
2 661 663 2
665 667 3 66c
66d 66e 2 669
670 2 654 672
1 674 1 676
2 63f 677 1
67b 1 63a 1
67f 1 682 1
685 4 620 623
626 686 1 688
3 5ba 613 689
1 68b 2 68e
68f 1 693 2
691 693 2 699
69a 1 69c 1
6a1 2 69f 6a1
1 6a8 1 6aa
a 519 51c 51f
522 57a 580 58a
597 68c 6ab 2
6c7 6cc 2 6dd
6df 3 6db 6dc
6e1 2 6ea 6ec
2 6ee 6f0 2
6f2 6f4 2 6f6
6f8 2 6fa 6fc
3 701 702 703
2 6fe 705 2
6e9 707 1 709
1 70b 2 6d4
70c 1 710 1
6cf 1 714 1
71f 2 71b 71f
2 724 725 2
72a 72b 1 72d
2 727 72d 1
738 2 735 73b
1 73d 3 6af
717 73e 2 740
741 2 744 745
1 749 2 747
749 1 750 2
74e 750 2 75b
75d 3 759 75a
75f 2 768 76a
2 76c 76e 2
770 772 1 77a
2 77c 77d 2
774 77f 2 781
783 2 785 787
2 789 78b 2
78d 78f 2 767
791 1 793 1
795 2 79f 7a1
3 79d 79e 7a3
2 7ac 7ae 2
7ab 7b0 1 7b2
1 7b4 3 7bb
7bc 7bd 3 796
7b5 7bf 1 7c1
1 7c3 1 7c8
1 7cf 1 7d6
2 7e5 7e7 3
7e3 7e4 7e9 2
7f2 7f4 2 7f6
7f8 2 7fa 7fc
1 804 2 806
807 2 7fe 809
2 7f1 80b 1
80d 1 80f 2
819 81b 3 817
818 81d 2 826
828 2 825 82a
1 82c 1 82e
2 835 836 3
810 82f 838 1
83a 2 842 843
1 847 2 845
847 1 84c 1
84e 2 856 85b
2 86c 86e 3
86a 86b 870 2
879 87b 2 87d
87f 2 881 883
2 885 887 2
889 88b 3 890
891 892 2 88d
894 2 878 896
1 898 1 89a
2 863 89b 1
89f 1 85e 1
8a3 2 8a9 8aa
1 8ae 2 8ac
8ae 1 8b5 2
8b7 8b8 1 8be
2 8c0 8c1 2
8ba 8c3 2 8c6
8c8 2 8cb 8cd
1 8cf 2 8d4
8d5 2 8da 8db
1 8dd 2 8d7
8dd 2 8e2 8e5
1 8e9 2 8eb
8ec 2 8d2 8ed
1 8ef 2 8f6
8f7 2 8f9 8fa
1 8ff 2 8fd
8ff 2 903 904
1 908 2 906
908 2 90c 90d
1 911 2 90f
911 11 918 919
91a 91b 91c 91d
91e 91f 920 921
922 923 924 925
926 927 928 1
930 2 92e 930
1 945 2 944
945 1 94d 1
953 2 955 956
2 942 957 2
968 96a 3 966
967 96c 2 975
977 2 979 97b
2 97d 97f 2
981 983 2 985
987 3 98c 98d
98e 2 989 990
2 974 992 1
994 1 996 2
95f 997 1 99b
1 95a 1 99f
1 9a2 1 9a5
2 92b 9a6 11
9ac 9ad 9ae 9af
9b0 9b1 9b2 9b3
9b4 9b5 9b6 9b7
9b8 9b9 9ba 9bb
9bc 1 9bf 2
9c1 9c2 1 9c3
2 9c7 9c8 2
9ca 9cc 2 9d1
9d2 1 9d6 2
9d4 9d6 11 9dd
9de 9df 9e0 9e1
9e2 9e3 9e4 9e5
9e6 9e7 9e8 9e9
9ea 9eb 9ec 9ed
1 9f5 2 9f3
9f5 1 a06 2
a05 a06 1 a0e
1 a14 2 a16
a17 2 a03 a18
2 a29 a2b 3
a27 a28 a2d 2
a36 a38 2 a3a
a3c 2 a3e a40
2 a42 a44 2
a46 a48 3 a4d
a4e a4f 2 a4a
a51 2 a35 a53
1 a55 1 a57
2 a20 a58 1
a5c 1 a1b 1
a60 1 a63 1
a66 2 9f0 a67
11 a6d a6e a6f
a70 a71 a72 a73
a74 a75 a76 a77
a78 a79 a7a a7b
a7c a7d 1 a80
2 a82 a83 2
9cf a84 2 a86
a87 1 a8d 2
a8b a8d 2 a93
a94 2 a96 a97
1 a9c 2 a9a
a9c 2 aa3 aa4
2 aa9 aaa 1
aac 2 aa6 aac
2 ab1 ab2 1
ab6 2 ab4 ab6
2 abd abe 1
ac2 2 ac0 ac2
1 ae2 2 ae1
ae2 1 aea 1
af0 2 af2 af3
2 adf af4 2
b05 b07 3 b03
b04 b09 2 b12
b14 2 b16 b18
2 b1a b1c 2
b1e b20 2 b22
b24 3 b29 b2a
b2b 2 b26 b2d
2 b11 b2f 1
b31 1 b33 2
afc b34 1 b38
1 af7 1 b3c
1 b4c 2 b4b
b4c 1 b54 1
b5a 2 b5c b5d
2 b49 b5e 2
b6f b71 3 b6d
b6e b73 2 b7c
b7e 2 b80 b82
2 b84 b86 2
b88 b8a 2 b8c
b8e 3 b93 b94
b95 2 b90 b97
2 b7b b99 1
b9b 1 b9d 2
b66 b9e 1 ba2
1 b61 1 ba6
1 bb3 2 bb2
bb3 1 bbb 1
bc1 2 bc3 bc4
2 bb0 bc5 2
bd6 bd8 3 bd4
bd5 bda 2 be3
be5 2 be7 be9
2 beb bed 2
bef bf1 2 bf3
bf5 3 bfa bfb
bfc 2 bf7 bfe
2 be2 c00 1
c02 1 c04 2
bcd c05 1 c09
1 bc8 1 c0d
3 b3f ba9 c10
1 c21 2 c20
c21 1 c29 1
c2f 2 c31 c32
2 c1e c33 2
c44 c46 3 c42
c43 c48 2 c51
c53 2 c55 c57
2 c59 c5b 2
c5d c5f 2 c61
c63 3 c68 c69
c6a 2 c65 c6c
2 c50 c6e 1
c70 1 c72 2
c3b c73 1 c77
1 c36 1 c7b
1 c7e 2 c81
c82 1 c83 1
c85 2 a88 c86
2 c8b c8c 2
c8e c91 2 c96
c97 1 c9b 2
c99 c9b 11 ca2
ca3 ca4 ca5 ca6
ca7 ca8 ca9 caa
cab cac cad cae
caf cb0 cb1 cb2
1 cba 2 cb8
cba 2 cbf cc0
1 cc4 2 cc2
cc4 2 ccb ccc
1 cd0 2 cce
cd0 1 ce8 2
ce7 ce8 1 cf0
1 cf6 2 cf8
cf9 2 ce5 cfa
2 d0b d0d 3
d09 d0a d0f 2
d18 d1a 2 d1c
d1e 2 d20 d22
2 d24 d26 2
d28 d2a 3 d2f
d30 d31 2 d2c
d33 2 d17 d35
1 d37 1 d39
2 d02 d3a 1
d3e 1 cfd 1
d42 1 d45 1
d48 2 cb5 d49
1 d4b 2 d5d
d62 2 d73 d75
3 d71 d72 d77
2 d80 d82 2
d84 d86 2 d88
d8a 2 d8c d8e
2 d90 d92 3
d97 d98 d99 2
d94 d9b 2 d7f
d9d 1 d9f 1
da1 2 d6a da2
1 da6 1 d65
1 daa 3 db2
db3 db4 1 db8
2 db6 db8 2
dc7 dcc 2 ddd
ddf 3 ddb ddc
de1 2 dea dec
2 dee df0 2
df2 df4 2 df6
df8 2 dfa dfc
3 e01 e02 e03
2 dfe e05 2
de9 e07 1 e09
1 e0b 2 dd4
e0c 1 e10 1
dcf 1 e14 6
e1b e1c e1d e1e
e1f e20 2 e25
e26 1 e2a 2
e28 e2a 2 e42
e43 1 e4e 1
e54 2 e56 e57
2 e5b e61 2
e72 e74 3 e70
e71 e76 2 e7f
e81 2 e83 e85
2 e87 e89 2
e8b e8d 2 e8f
e91 3 e96 e97
e98 2 e93 e9a
2 e7e e9c 1
e9e 1 ea0 2
e69 ea1 1 ea5
1 e64 1 ea9
2 eb3 eb8 2
ec9 ecb 3 ec7
ec8 ecd 2 ed6
ed8 2 eda edc
2 ede ee0 2
ee2 ee4 2 ee6
ee8 3 eed eee
eef 2 eea ef1
2 ed5 ef3 1
ef5 1 ef7 2
ec0 ef8 1 efc
1 ebb 1 f00
2 f0d f0f 3
f11 f12 f13 2
f19 f1b 3 f1d
f1e f1f 2 f25
f27 3 f29 f2a
f2b 2 f31 f33
3 f35 f36 f37
f f3d f3e f3f
f40 f41 f42 f43
f44 f45 f46 f47
f48 f49 f4a f4b
2 f57 f59 3
f55 f56 f5b 2
f64 f66 2 f68
f6a 2 f6c f6e
1 f74 2 f76
f77 2 f70 f79
2 f7b f7d 2
f7f f81 2 f83
f85 2 f87 f89
2 f63 f8b 1
f8d 1 f8f 2
f99 f9b 3 f97
f98 f9d 2 fa6
fa8 2 fa5 faa
1 fac 1 fae
3 fb3 fb4 fb5
14 e2f e32 e35
e38 e3b e3e e44
e58 eac f03 f07
f0a f16 f22 f2e
f3a f4e f90 faf
fb7 1 fb9 5
dbf dc2 e17 e23
fba 1 fbc 3
d52 dad fbd 1
fbf 2 fc3 fc4
2 fc6 fc8 11
fd0 fd1 fd2 fd3
fd4 fd5 fd6 fd7
fd8 fd9 fda fdb
fdc fdd fde fdf
fe0 1 fe8 2
fe6 fe8 2 fed
fee 1 ff2 2
ff0 ff2 2 ff9
ffa 1 ffe 2
ffc ffe 1 1012
2 1011 1012 1
101a 1 1020 2
1022 1023 2 100f
1024 2 1035 1037
3 1033 1034 1039
2 1042 1044 2
1046 1048 2 104a
104c 2 104e 1050
2 1052 1054 3
1059 105a 105b 2
1056 105d 2 1041
105f 1 1061 1
1063 2 102c 1064
1 1068 1 1027
1 106c 1 106f
1 1072 4 fc0
fcb fe3 1073 2
1075 1076 2 c94
1077 2 1079 107a
1 1080 2 107e
1080 2 108b 108d
3 1089 108a 108f
2 1098 109a 2
109c 109e 2 10a0
10a2 1 10aa 2
10ac 10ad 2 10a4
10af 2 10b1 10b3
2 10b5 10b7 2
10b9 10bb 2 10bd
10bf 2 1097 10c1
1 10c3 1 10c5
2 10cf 10d1 3
10cd 10ce 10d3 2
10dc 10de 2 10db
10e0 1 10e2 1
10e4 3 10eb 10ec
10ed 3 10c6 10e5
10ef 1 10f1 2
10f7 10f8 1 10fc
2 10fa 10fc 2
1101 1102 1 1106
2 1104 1106 1
110e 1 1110 2
1113 1114 1 1118
2 1116 1118 2
111d 111e 2 1120
1121 1 1126 2
1124 1126 1 1129
1 112e 1 114b
2 114a 114b 1
1153 1 1159 2
115b 115c 2 1148
115d 2 116e 1170
3 116c 116d 1172
2 117b 117d 2
117f 1181 2 1183
1185 2 1187 1189
2 118b 118d 3
1192 1193 1194 2
118f 1196 2 117a
1198 1 119a 1
119c 2 1165 119d
1 11a1 1 1160
1 11a5 1 11a8
1 11b7 2 11b6
11b7 1 11bf 1
11c5 2 11c7 11c8
2 11b4 11c9 2
11da 11dc 3 11d8
11d9 11de 2 11e7
11e9 2 11eb 11ed
2 11ef 11f1 2
11f3 11f5 2 11f7
11f9 3 11fe 11ff
1200 2 11fb 1202
2 11e6 1204 1
1206 1 1208 2
11d1 1209 1 120d
1 11cc 1 1211
1 1214 2 1217
1218 1 1219 1
121b 1 1263 2
1262 1263 1 126b
1 1271 2 1273
1274 2 1260 1275
2 1286 1288 3
1284 1285 128a 2
1293 1295 2 1297
1299 2 129b 129d
2 129f 12a1 2
12a3 12a5 3 12aa
12ab 12ac 2 12a7
12ae 2 1292 12b0
1 12b2 1 12b4
2 127d 12b5 1
12b9 1 1278 1
12bd 1 12c0 1
12fa 2 12f9 12fa
1 1302 1 1308
2 130a 130b 2
12f7 130c 2 131d
131f 3 131b 131c
1321 2 132a 132c
2 132e 1330 2
1332 1334 2 1336
1338 2 133a 133c
3 1341 1342 1343
2 133e 1345 2
1329 1347 1 1349
1 134b 2 1314
134c 1 1350 1
130f 1 1354 1
1357 2 135a 135b
1 135c 2 135e
135f 1 1360 2
1364 1365 1 1369
2 1367 1369 1
1378 2 1377 1378
1 1380 1 1386
2 1388 1389 2
1375 138a 2 139b
139d 3 1399 139a
139f 2 13a8 13aa
2 13ac 13ae 2
13b0 13b2 2 13b4
13b6 2 13b8 13ba
3 13bf 13c0 13c1
2 13bc 13c3 2
13a7 13c5 1 13c7
1 13c9 2 1392
13ca 1 13ce 1
138d 1 13d2 1
13d5 2 13d9 13d8
1 13da 2 13de
13df 2 13e1 13e2
1 13e7 2 13e5
13e7 1 13ea 1
13ef 1 140c 2
140b 140c 1 1414
1 141a 2 141c
141d 2 1409 141e
2 142f 1431 3
142d 142e 1433 2
143c 143e 2 1440
1442 2 1444 1446
2 1448 144a 2
144c 144e 3 1453
1454 1455 2 1450
1457 2 143b 1459
1 145b 1 145d
2 1426 145e 1
1462 1 1421 1
1466 1 1469 1
147a 2 1479 147a
1 1482 1 1488
2 148a 148b 2
1477 148c 2 149d
149f 3 149b 149c
14a1 2 14aa 14ac
2 14ae 14b0 2
14b2 14b4 2 14b6
14b8 2 14ba 14bc
3 14c1 14c2 14c3
2 14be 14c5 2
14a9 14c7 1 14c9
1 14cb 2 1494
14cc 1 14d0 1
148f 1 14d4 1
14d7 2 14da 14db
1 14dc 1 14de
1 1526 2 1525
1526 1 152e 1
1534 2 1536 1537
2 1523 1538 2
1549 154b 3 1547
1548 154d 2 1556
1558 2 155a 155c
2 155e 1560 2
1562 1564 2 1566
1568 3 156d 156e
156f 2 156a 1571
2 1555 1573 1
1575 1 1577 2
1540 1578 1 157c
1 153b 1 1580
1 1583 1 15bf
2 15be 15bf 1
15c7 1 15cd 2
15cf 15d0 2 15bc
15d1 2 15e2 15e4
3 15e0 15e1 15e6
2 15ef 15f1 2
15f3 15f5 2 15f7
15f9 2 15fb 15fd
2 15ff 1601 3
1606 1607 1608 2
1603 160a 2 15ee
160c 1 160e 1
1610 2 15d9 1611
1 1615 1 15d4
1 1619 1 161c
2 161f 1620 1
1621 2 1623 1624
1 1625 2 1629
162a 1 162e 2
162c 162e 1 1631
2 1637 1638 1
163c 2 163a 163c
1 1650 2 164f
1650 1 1658 1
165e 2 1660 1661
2 164d 1662 2
1673 1675 3 1671
1672 1677 2 1680
1682 2 1684 1686
2 1688 168a 2
168c 168e 2 1690
1692 3 1697 1698
1699 2 1694 169b
2 167f 169d 1
169f 1 16a1 2
166a 16a2 1 16a6
1 1665 1 16aa
1 16ad 1 16be
2 16bd 16be 1
16c6 1 16cc 2
16ce 16cf 2 16bb
16d0 2 16e1 16e3
3 16df 16e0 16e5
2 16ee 16f0 2
16f2 16f4 2 16f6
16f8 2 16fa 16fc
2 16fe 1700 3
1705 1706 1707 2
1702 1709 2 16ed
170b 1 170d 1
170f 2 16d8 1710
1 1714 1 16d3
1 1718 1 171b
2 171e 171f 1
1720 1 1730 2
172f 1730 1 1738
1 173e 2 1740
1741 2 172d 1742
2 1753 1755 3
1751 1752 1757 2
1760 1762 2 1764
1766 2 1768 176a
2 176c 176e 2
1770 1772 3 1777
1778 1779 2 1774
177b 2 175f 177d
1 177f 1 1781
2 174a 1782 1
1786 1 1745 1
178a 1 178d 2
1790 1791 1 1792
2 1795 1794 1
1796 2 1798 1799
1 179b 2 17a1
17a2 1 17a6 2
17a4 17a6 2 17ae
17af 1 17b3 2
17b1 17b3 2 17c6
17c7 1 17cb 2
17c9 17cb 2 17e7
17ec 2 17fd 17ff
3 17fb 17fc 1801
2 180a 180c 2
180e 1810 2 1812
1814 2 1816 1818
2 181a 181c 3
1821 1822 1823 2
181e 1825 2 1809
1827 1 1829 1
182b 2 17f4 182c
1 1830 1 17ef
1 1834 1 1837
2 1854 1859 2
186a 186c 3 1868
1869 186e 2 1877
1879 2 187b 187d
2 187f 1881 2
1883 1885 2 1887
1889 3 188e 188f
1890 2 188b 1892
2 1876 1894 1
1896 1 1898 2
1861 1899 1 189d
1 185c 1 18a1
2 183c 18a4 2
18a7 18a8 1 18b0
2 18ac 18b0 2
18b5 18b6 2 18bb
18bc 1 18be 2
18b8 18be 2 18c3
18c4 1 18c8 2
18c6 18c8 2 18cf
18d0 1 18d4 2
18d2 18d4 1 18e5
2 18e4 18e5 1
18ed 1 18f3 2
18f5 18f6 2 18e2
18f7 2 1908 190a
3 1906 1907 190c
2 1915 1917 2
1919 191b 2 191d
191f 2 1921 1923
2 1925 1927 3
192c 192d 192e 2
1929 1930 2 1914
1932 1 1934 1
1936 2 18ff 1937
1 193b 1 18fa
1 193f 1 1954
2 1953 1954 1
195c 1 1962 2
1964 1965 2 1951
1966 2 1977 1979
3 1975 1976 197b
2 1984 1986 2
1988 198a 2 198c
198e 2 1990 1992
2 1994 1996 3
199b 199c 199d 2
1998 199f 2 1983
19a1 1 19a3 1
19a5 2 196e 19a6
1 19aa 1 1969
1 19ae 2 1942
19b1 3 19bb 19bc
19bd 1 19c8 1
19ce 2 19d0 19d1
1 19d7 2 19d5
19d7 1 19db 1
19dd 2 19e1 19e2
2 19e7 19e8 2
19e4 19ea 2 19ef
19f0 1 19f4 2
19f2 19f4 2 19f8
19f9 2 19fe 19ff
1 1a01 2 19fb
1a01 2 1a05 1a06
2 1a0b 1a0c 1
1a0e 2 1a08 1a0e
2 1a13 1a14 1
1a17 2 1a1b 1a1c
2 1a21 1a22 2
1a1e 1a24 2 1a29
1a2a 2 1a26 1a2c
1 1a2f 2 1a31
1a32 1 1a33 1
1a35 1 1a3f 2
1a3e 1a3f 1 1a47
1 1a4d 2 1a4f
1a50 2 1a3c 1a51
2 1a62 1a64 3
1a60 1a61 1a66 2
1a6f 1a71 2 1a73
1a75 2 1a77 1a79
2 1a7b 1a7d 2
1a7f 1a81 3 1a86
1a87 1a88 2 1a83
1a8a 2 1a6e 1a8c
1 1a8e 1 1a90
2 1a59 1a91 1
1a95 1 1a54 1
1a99 3 1a36 1a9c
1aa0 1 1aa2 2
1aa5 1aa6 2 1aab
1aac 1 1aae 2
1aa8 1aae 1 1ab2
1 1ab4 6 19be
19d2 19de 19ed 1aa3
1ab5 2 1abb 1ac1
2 1ad2 1ad4 3
1ad0 1ad1 1ad6 2
1adf 1ae1 2 1ae3
1ae5 2 1ae7 1ae9
2 1aeb 1aed 2
1aef 1af1 3 1af6
1af7 1af8 2 1af3
1afa 2 1ade 1afc
1 1afe 1 1b00
2 1ac9 1b01 1
1b05 1 1ac4 1
1b09 2 1b0f 1b10
1 1b14 2 1b12
1b14 1 1b18 1
1b28 2 1b27 1b28
1 1b30 1 1b36
2 1b38 1b39 2
1b25 1b3a 2 1b4b
1b4d 3 1b49 1b4a
1b4f 2 1b58 1b5a
2 1b5c 1b5e 2
1b60 1b62 2 1b64
1b66 2 1b68 1b6a
3 1b6f 1b70 1b71
2 1b6c 1b73 2
1b57 1b75 1 1b77
1 1b79 2 1b42
1b7a 1 1b7e 1
1b3d 1 1b82 1
1b85 1 1b88 4
19b6 1ab8 1b0c 1b89
2 1b8b 1b8c 2
1b8f 1b90 1 1b94
2 1b92 1b94 2
1b99 1b9a 2 1b9c
1b9d 1 1ba2 2
1ba0 1ba2 2 1ba7
1ba8 1 1bab 2
1baf 1bb0 1 1bb3
2 1bb5 1bb6 1
1bb7 1 1bb9 2
1b8d 1bba 1 1bbc
6 17bb 17be 17c1
17c4 18a9 1bbd 1
1bbf d 7c2 83b
840 84f 8a6 8f0
8f3 107b 10f2 10f5
1111 179a 1bc0 1
1bc2 1 1bc8 2
1bc6 1bc8 1 1bcf
1 1bd1 3 742
1bc3 1bd2 1 1bd4
2 1bde 1be0 3
1bdc 1bdd 1be2 2
1beb 1bed 2 1bef
1bf1 2 1bf3 1bf5
1 1bfd 2 1bff
1c00 2 1bf7 1c02
2 1c04 1c06 2
1c08 1c0a 2 1c0c
1c0e 2 1c10 1c12
2 1bea 1c14 1
1c16 1 1c18 3
1c1f 1c20 1c21 15
355 374 3f2 467
46a 46d 470 473
476 479 47c 47f
482 485 488 48b
48e 491 1bd5 1c19
1c23 2 1c30 1c32
3 1c2e 1c2f 1c34
2 1c3d 1c3f 2
1c3c 1c41 2 1c48
1c4c 2 1c4e 1c50
2 1c52 1c56 2
1c47 1c58 2 1c43
1c5a 1 1c5c 3
1c5d 1c68 1c6c 1
1c27 2 1c7f 1c81
3 1c7d 1c7e 1c83
2 1c8c 1c8e 2
1c8b 1c90 2 1c97
1c99 2 1c9b 1c9d
3 1ca2 1ca3 1ca4
2 1c9f 1ca6 2
1c96 1ca8 2 1c92
1caa 1 1cac 4
1c76 1cad 1cb6 1cba
1 1cbe 1 1c71
2 1c6f 1cc2 3c
63 6a 71 78
7f 86 8d 94
9b a2 a9 b0
b7 be c4 ca
d0 d6 dc e2
e8 ee f4 fa
100 106 10c 112
118 11e 123 128
12f 136 13d 142
147 14c 151 156
15b 162 168 16e
174 17a 180 186
18c 191 196 19c
1a2 1a8 1ae 1b4
1ba 1d0 1e5 1ef

1
4
0 
1cc9
0
1
50
4d
52
0 1 1 1 4 1 6 1
8 1 a 1 c 1 e 1
10 1 12 1 14 1 16 1
18 1 1a 1 1c 1 1e 1
20 1 22 1 24 1 26 1
28 1 2a 1 2c 1 2e 1
30 1 32 1 34 1 36 1
38 1 3a 1 3c 1 3e 1
40 1 42 1 44 1 46 47
1 49 1 4b 1 0 0 0

d2 1 0
53 1 0
1bd 1 2
3b 1 0
23 1 0
13 1 0
7a 1 0
a4 1 0
16a 1 0
182 1 0
43 1 0
f6 1 0
12a 1 0
1b0 1 0
131 1 0
188 1 0
2f 1 0
102 1 0
19e 1 0
88 1 0
114 1 0
37 1 0
120 1 0
170 1 0
10e 1 0
7 1 0
c0 1 0
81 1 0
1b6 1 0
17c 1 0
1f 1 0
2 0 1
144 1 0
fc 1 0
e4 1 0
f 1 0
3 1 0
13f 1 0
4b 1 0
17 1 0
8f 1 0
176 1 0
158 1 0
1a4 1 0
96 1 0
5e 1 0
153 1 0
47 1 0
b 1 0
cc 1 0
27 1 0
193 1 0
14e 1 0
108 1 0
73 1 0
1aa 1 0
1d6 1 3
2b 1 0
b2 1 0
149 1 0
11a 1 0
4f 1 0
9d 1 0
ea 1 0
d8 1 0
33 1 0
164 1 0
ab 1 0
f0 1 0
c6 1 0
3f 1 0
198 1 0
18e 1 0
125 1 0
6c 1 0
65 1 0
b9 1 0
1b 1 0
15d 1 0
de 1 0
1ea 1 0
138 1 0
0

/
SHOW ERRORS FUNCTION SP_ASSIGN_MSP;
ALTER FUNCTION SP_ASSIGN_MSP COMPILE DEBUG;
/*
#Stored Procedure  :SP_A_RESTOPROF
#Short Description :Replace a profile with a resource
#Description       :
#Table Name        :
#Parameters        :
#Returns           :
#Errors            :
*/
Prompt == FUNCTION SP_A_RESTOPROF ==
CREATE OR REPLACE FUNCTION SP_A_RESTOPROF wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
342
2 :e:
1FUNCTION:
1SP_A_RESTOPROF:
1PRJ_ID:
1VARCHAR2:
1PROFILE_ID001:
1RES_ID001:
1START_DATE001:
1FINISH_DATE001:
1EFFORT001:
1PLS_INTEGER:
1WORK001:
1BITFLAG001:
1EUNIT:
1UNIT:
1CONTOUR001:
1OCCURRENCE:
1CONSIDER_PLANNED_SCHED:
1WORK_TYPE:
1REC_USER001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_ID:
132:
1H_SECURITY_ID:
1H_REC_USER:
1H_ASSIGN_ID:
1H_PRJ_ASSIGN_ID:
1H_TSK_ASSIGNMENT_ID:
1H_PRJ_ASSIGNMENT_ID:
1H_CUR_PRJ_ASSIGN_ID:
1H_TASK_ID:
1H_RES_ID:
1H_PROJECT_ID:
1H_PROFILE_ID:
1H_START_DATE:
1TIMESTAMP:
1H_FINISH_DATE:
1H_TASK_START_DT:
1H_TASK_FINISH_DT:
1H_NULL_STR:
11:
1H_START_D:
1DATE:
1H_FINISH_D:
1H_RES_TYPE:
1H_RANK:
1200:
1H_START_DT:
1H_FINISH_DT:
1H_SCHED_START:
1H_SCHED_FINISH:
1H_ROLE_ID:
1H_FULL_NAME:
1255:
1H_IN:
1H_PROFILE_NAME:
1H_LABOR_CODE:
150:
1H_PARTICIPANT:
10:
1H_EVERY:
1H_EFFORT:
1H_CRI:
1H_TYPE:
1H_TYPE_ID:
1H_TOTAL:
1H_WORK:
1H_OCCURRENCE:
1H_EUNIT:
1H_UNIT:
1H_CONTOUR:
1H_DURATION:
1H_WORK_TYPE:
1H_PASSED:
1H_ASSIGNED:
1H_REMAINING:
1H_BITFLAG:
1H_PER_DAY:
1H_PER_WEEK:
1H_UPDATE:
1H_CONSIDER:
1H_PRIORITY:
1H_DAYS:
1H_OWNER:
1H_COUNT:
1H_CONTOUR_CHANGED:
1H_REG_COST:
1NUMBER:
10.00:
1H_REG_SALE:
1H_SPEC_COST:
1H_SPEC_SALE:
1H_RATE_ECHANGE:
1H_CURRENCY_ID:
1H_DONOT_REPLACE_BITS:
1H_DONOT_REPLACE_RATE:
1H_DONOT_REPLACE_COST:
1H_FROM_PRJ:
1H_SAME_LABOR:
1H_FS_PROJECT:
1I_RETURN:
1H_AND_ROLES:
14000:
1H_AND_SKILLS:
1H_TEMP_RES_COST:
1H_TEMP_VAR:
1H_TEMP_RES_TYPE:
1H_TEMP_PARTICIPANT:
1H_TEMP_SECURITY_ID:
1H_PA_TIMEPHASE:
1H_TEMP_BITFLAG:
1H_TEMP_SC_STATE:
1H_SD:
1H_FD:
1H_OLD_COST:
1H_OLD_SALE:
1H_PA_COUNT:
1H_TA_COUNT:
1H_BILLABLE:
1H_CAPITAL_EXPENSE:
1H_TPH_DELETE:
1H_TABLE_TYPE:
1H_PLANNED_EFFORT:
1H_TASK_TYPE:
1H_PERCENT_UNITS:
1H_TIMECODE_1_ID:
1H_TIMECODE_2_ID:
1H_OLD_PRJ_ASSIGN_ID:
1I_ISTASK:
1ISWBSTASK:
1COALESCE:
1L_DATA_FLAG:
1I_MANY:
1CURSOR:
1CRCAL1:
1AVAILABLE_MIN:
1CALENDAR_DAY_OF_YEAR:
1ELEMENT_ID:
1ROWNUM:
1SELECT * FROM (SELECT AVAILABLE_MIN FROM CALENDAR_DAY_OF_YEAR:n         WHERE+
1 ELEMENT_ID = h_res_id ) WHERE ROWNUM<=1:
1CSA1:
1BAK_WORK:
1TASK_ASSIGNMENTS:
1PROJECT_ID:
1RESOURCE_ID:
1RESOURCE_TYPE:
1PROJECT_ASSIGNMENT_ID:
1SELECT * FROM (SELECT BAK_WORK FROM TASK_ASSIGNMENTS:n         WHERE PROJECT_+
1ID = h_project_id AND RESOURCE_ID = h_res_id AND RESOURCE_TYPE = '0' AND:n   +
1      PROJECT_ASSIGNMENT_ID IS NuLL ) WHERE ROWNUM<=1:
1C6A:
1R:
1RES_ASSIGNMENT_ID:
1T:
1TSK_ASSIGNMENT_ID:
1TASK_ID:
1ELEMENT_TYPE:
1PLANNED_WORK:
1UNITS_MSP:
1TO_DATE:
1SUBSTR:
1PLANNED_START:
1PLANNED_FINISH:
1PLANNED_DURATION:
1W:
1BILLABLE:
1CAPITAL_EXPENSE:
1REGULAR_COST:
1REGULAR_RATE:
1C_EFFORT:
1T_UNIT:
1C_UNIT:
1C_CONTOUR:
1CONTOUR_TYPE:
1TMT_WBS:
1RESOURCE_ASSIGNMENTS:
1PMO_CNST:
1SC_TASK:
1SC_TASK_TYPE1:
1SC_TASK_TYPE2:
1SC_TASK_TYPE3:
1SC_MILESTONE:
1SC_PERSONAL_TASK:
1SC_ACTIVE_ADM_TASK:
1SC_INACTIVE_ADM_TASK:
1SC_WBS_CHANGE_REQUEST_TASK:
1SC_WBS_ACTION_ITEM_TASK:
1SC_WBS_RISK_TASK:
1SC_WBS_ISSUE_TASK:
1SC_WBS_REQUIREMENT_TASK:
1SC_WBS_DEFECT_TASK:
1SC_WBS_SERVICE_REQUEST_TASK:
1RANK:
1SELECT r.RES_ASSIGNMENT_ID, t.TSK_ASSIGNMENT_ID, t.TASK_ID, r.ELEMENT_TYPE, t+
1.PLANNED_WORK, t.UNITS_MSP,:n         TO_DATE(SubStr(t.PLANNED_START, 1, 10))+
1, TO_DATE(SubStr(t.PLANNED_FINISH, 1, 10)),t.PLANNED_START, t.PLANNED_FINISH,+
1 CASE WHEN t.PLANNED_DURATION = 0 THEN w.PLANNED_DURATION ELSE t.PLANNED_DURA+
1TION END,:n         t.PROJECT_ASSIGNMENT_ID, t.BILLABLE, t.CAPITAL_EXPENSE, t+
1.REGULAR_COST, t.REGULAR_RATE,:n         t.C_EFFORT, t.T_UNIT, t.C_UNIT, t.C_+
1CONTOUR, t.CONTOUR_TYPE:n         FROM TMT_WBS w, RESOURCE_ASSIGNMENTS r, TAS+
1K_ASSIGNMENTS t:n         WHERE r.PROJECT_ID = h_project_id AND r.RESOURCE_ID+
1 = h_profile_id AND r.RESOURCE_TYPE = '1' :n         AND t.RES_ASSIGNMENT_ID +
1= r.RES_ASSIGNMENT_ID AND r.ELEMENT_ID = w.ELEMENT_ID :n         AND r.ELEMEN+
1T_TYPE IN (PMO_CNST.SC_TASK,PMO_CNST.SC_TASK_TYPE1,PMO_CNST.SC_TASK_TYPE2,PMO+
1_CNST.SC_TASK_TYPE3,PMO_CNST.SC_MILESTONE,PMO_CNST.SC_PERSONAL_TASK,PMO_CNST.+
1SC_ACTIVE_ADM_TASK,PMO_CNST.SC_INACTIVE_ADM_TASK,PMO_CNST.SC_WBS_CHANGE_REQUE+
1ST_TASK,PMO_CNST.SC_WBS_ACTION_ITEM_TASK,PMO_CNST.SC_WBS_RISK_TASK,PMO_CNST.S+
1C_WBS_ISSUE_TASK,PMO_CNST.SC_WBS_REQUIREMENT_TASK,PMO_CNST.SC_WBS_DEFECT_TASK+
1,PMO_CNST.SC_WBS_SERVICE_REQUEST_TASK) AND w.RANK LIKE h_rank:n         ORDER+
1 BY t.PLANNED_START:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_A_RESTOPROF(:
1':
1, :
1TO_CHAR:
1NULL:
1);:
1CHECK_TRACE:
1161:
1+:
1FPUT:
1               ENTER:: SP_A_RESTOPROF(162) :: cplan.sql(8808) :: :
1BITAND:
1SC_1FFFFFFF:
1=:
1SC_SRCH_PROFILE:
1SC_SRCH_FROM_PROJECT:
17:
1:
1OPEN:
1FOUND:
1SC_STATE:
1100:
1CLOSE:
1SQLCODE:
1OTHERS:
116:
1210:
1           EXCEPTION:: SP_A_RESTOPROF(211) :: cplan.sql(8857) :: :
1 :
1SQLCODE:: :
1 SQLERR:: :
1SQLERRM:
1500:
1217:
1        RETURN_ERROR:: SP_A_RESTOPROF(218) :: cplan.sql(8864) :: :
1STATE:: :
1RECORD_NOT_FOUND:
1 ID:: :
1220:
1                EXIT:: SP_A_RESTOPROF(221) :: cplan.sql(8867) :: :
1PMODEFINES:
1PMO_RETURN_ERROR_SP:
1TRUE:
1TYPE_ID:
1TIMECODE_1_ID:
1TIMECODE_2_ID:
1TASK_TYPE:
1UNRESOLVED_DURATION:
1SELECT TYPE_ID, RANK, PROJECT_ID, TIMECODE_1_ID, TIMECODE_2_ID, TASK_TYPE, UN+
1RESOLVED_DURATION:n      INTO h_type_id, h_rank, h_project_id, h_timecode_1_i+
1d, h_timecode_2_id, h_task_type, h_duration:n      FROM TMT_WBS WHERE ELEMENT+
1_ID = h_task_id:
1235:
1           EXCEPTION:: SP_A_RESTOPROF(236) :: cplan.sql(8882) :: :
1SC_SQL_NO_DATA:
1243:
1        RETURN_ERROR:: SP_A_RESTOPROF(244) :: cplan.sql(8890) :: :
1246:
1                EXIT:: SP_A_RESTOPROF(247) :: cplan.sql(8893) :: :
1LEVEL_LOCK:
1PROJECT_DETAILS:
1SELECT LEVEL_LOCK INTO h_temp_var:n      FROM PROJECT_DETAILS:n      WHERE PR+
1OJECT_ID = h_project_id:
1262:
1           EXCEPTION:: SP_A_RESTOPROF(263) :: cplan.sql(8909) :: :
1>:
1269:
1        RETURN_ERROR:: SP_A_RESTOPROF(270) :: cplan.sql(8916) :: :
1LEV_LOCKED_BY_LEVEL:
1272:
1                EXIT:: SP_A_RESTOPROF(273) :: cplan.sql(8919) :: :
1TW:
1FS_CODE:
1MINUTE_PER_DAY:
1MINUTE_PER_WEEK:
1PRIORITY:
1CURRENCY_ID:
1PMO_ORASTD:
1TODECIMAL:
1TD:
1ELEMENT_NAME:
1JOIN:
1TMT_DATAFIELDS:
1SELECT tw.TYPE_ID, CASE WHEN tw.FS_CODE IS NuLL THEN 0 ELSE 1 END, COALESCE(t+
1w.MINUTE_PER_DAY, 480), COALESCE(tw.MINUTE_PER_WEEK, 2400), tw.PRIORITY, tw.C+
1URRENCY_ID, PMO_ORASTD.TODECIMAL(td.ELEMENT_NAME,20,4):n      INTO h_type, h_+
1fs_project, h_per_day, h_per_week, h_priority, h_currency_id, h_rate_echange+
1:n      FROM TMT_WBS tw JOIN TMT_DATAFIELDS td on tw.CURRENCY_ID = td.ELEMENT+
1_ID WHERE tw.ELEMENT_ID = h_project_id:
1287:
1           EXCEPTION:: SP_A_RESTOPROF(288) :: cplan.sql(8934) :: :
1294:
1        RETURN_ERROR:: SP_A_RESTOPROF(295) :: cplan.sql(8941) :: :
1297:
1                EXIT:: SP_A_RESTOPROF(298) :: cplan.sql(8944) :: :
1NICK_NAME:
1FS_LABOR_CODE:
1RESOURCES:
1SELECT NICK_NAME,FS_LABOR_CODE INTO h_full_name,h_labor_code FROM RESOURCES W+
1HERE RESOURCE_ID = h_res_id:
1310:
1           EXCEPTION:: SP_A_RESTOPROF(311) :: cplan.sql(8957) :: :
1317:
1        RETURN_ERROR:: SP_A_RESTOPROF(318) :: cplan.sql(8964) :: :
1320:
1                EXIT:: SP_A_RESTOPROF(321) :: cplan.sql(8967) :: :
1ROLE_ID:
1PROFILES:
1PROFILE_ID:
1SELECT ROLE_ID INTO h_role_id FROM PROFILES WHERE PROFILE_ID = h_profile_id:
1333:
1           EXCEPTION:: SP_A_RESTOPROF(334) :: cplan.sql(8980) :: :
1STRCMP:
1DEFAULTLEVEL:
1344:
1        RETURN_ERROR:: SP_A_RESTOPROF(345) :: cplan.sql(8991) :: :
1347:
1                EXIT:: SP_A_RESTOPROF(348) :: cplan.sql(8994) :: :
14:
12:
1!=:
1COUNT:
1SELECT COUNT(TSK_ASSIGNMENT_ID) INTO h_temp_var FROM TASK_ASSIGNMENTS:n      +
1      WHERE PROJECT_ID = h_project_id AND TASK_ID = h_project_id AND:n       +
1     RESOURCE_ID = h_res_id AND RESOURCE_TYPE = '0':
1377:
1           EXCEPTION:: SP_A_RESTOPROF(378) :: cplan.sql(9024) :: :
1ELSIF:
1SELECT COUNT(TSK_ASSIGNMENT_ID) INTO h_temp_var FROM TASK_ASSIGNMENTS:n      +
1      WHERE PROJECT_ID = h_project_id AND TASK_ID <> PROJECT_ID AND:n        +
1    RESOURCE_ID = h_res_id AND RESOURCE_TYPE = '0':
1392:
1           EXCEPTION:: SP_A_RESTOPROF(393) :: cplan.sql(9039) :: :
1400:
1        RETURN_ERROR:: SP_A_RESTOPROF(401) :: cplan.sql(9047) :: :
1CHILD_TASK_ASSIGNMENT_ALREADY_:
1403:
1                EXIT:: SP_A_RESTOPROF(404) :: cplan.sql(9050) :: :
1SELECT COUNT(TSK_ASSIGNMENT_ID) INTO h_ta_count FROM TASK_ASSIGNMENTS:n      +
1   WHERE PROJECT_ID = h_project_id AND PROJECT_ID <> TASK_ID AND RESOURCE_ID +
1= h_profile_id AND RESOURCE_TYPE = '1':
1418:
1           EXCEPTION:: SP_A_RESTOPROF(419) :: cplan.sql(9065) :: :
1SELECT COUNT(TSK_ASSIGNMENT_ID) INTO h_pa_count FROM TASK_ASSIGNMENTS:n      +
1   WHERE PROJECT_ID = h_project_id AND PROJECT_ID = TASK_ID AND RESOURCE_ID =+
1 h_profile_id AND RESOURCE_TYPE = '1':
1432:
1           EXCEPTION:: SP_A_RESTOPROF(433) :: cplan.sql(9079) :: :
1ISPROJECTTYPE:
1SELECT COUNT(TSK_ASSIGNMENT_ID) INTO h_temp_var FROM TASK_ASSIGNMENTS:n      +
1      WHERE PROJECT_ID = h_project_id AND RESOURCE_ID = h_res_id AND RESOURCE+
1_TYPE = '0':n            AND PROJECT_ASSIGNMENT_ID IS NuLL:
1449:
1           EXCEPTION:: SP_A_RESTOPROF(450) :: cplan.sql(9096) :: :
1456:
1        RETURN_ERROR:: SP_A_RESTOPROF(457) :: cplan.sql(9103) :: :
1459:
1                EXIT:: SP_A_RESTOPROF(460) :: cplan.sql(9106) :: :
1SC_SQL_SUCCESS:
1516:
1           EXCEPTION:: SP_A_RESTOPROF(517) :: cplan.sql(9163) :: :
1SELECT COUNT(TSK_ASSIGNMENT_ID) INTO h_count FROM TASK_ASSIGNMENTS WHERE PROJ+
1ECT_ID = h_project_id AND:n         RESOURCE_ID = h_res_id AND RESOURCE_TYPE +
1= '0' AND TASK_ID = h_project_id:
1532:
1           EXCEPTION:: SP_A_RESTOPROF(533) :: cplan.sql(9179) :: :
1BIT_FLAG:
1SELECT PLANNED_START, PLANNED_FINISH INTO h_sched_start, h_sched_finish:n    +
1        FROM TASK_ASSIGNMENTS WHERE PROJECT_ID = h_project_id AND BIT_FLAG = +
1'0' AND:n            RESOURCE_ID = h_res_id AND RESOURCE_TYPE = '0' AND TASK_+
1ID = h_project_id:
1549:
1           EXCEPTION:: SP_A_RESTOPROF(550) :: cplan.sql(9196) :: :
1557:
1        RETURN_ERROR:: SP_A_RESTOPROF(558) :: cplan.sql(9204) :: :
1560:
1                EXIT:: SP_A_RESTOPROF(561) :: cplan.sql(9207) :: :
1IS NOT NULL:
1STRNCMP:
110:
1<:
1568:
1        RETURN_ERROR:: SP_A_RESTOPROF(569) :: cplan.sql(9215) :: :
1571:
1                EXIT:: SP_A_RESTOPROF(572) :: cplan.sql(9218) :: :
1PARTICIPANT:
1SELECT RES_ASSIGNMENT_ID, PARTICIPANT INTO h_prj_assign_id, h_owner:n        +
1    FROM RESOURCE_ASSIGNMENTS:n            WHERE ELEMENT_ID = h_project_id :n+
1            AND RESOURCE_TYPE = h_res_type :n            AND RESOURCE_ID = h_+
1res_id:
1597:
1           EXCEPTION:: SP_A_RESTOPROF(598) :: cplan.sql(9244) :: :
1SYS_GUID:
1GETSECURITYID:
1SC_TEAMMEMBER_GROUP:
1SC_AFFECTED:
1FC_BEFORE_I_RES_ASSIGN:
1GETTABLE:
1SECURITY_ID:
1TABLE_TYPE:
1REC_USER:
1REC_DATETIME:
1INSERT INTO RESOURCE_ASSIGNMENTS(RES_ASSIGNMENT_ID, PROJECT_ID, ELEMENT_ID, E+
1LEMENT_TYPE,:n               RESOURCE_TYPE, RESOURCE_ID, PROFILE_ID, PARTICIP+
1ANT, SECURITY_ID, TABLE_TYPE,:n               REC_USER, REC_DATETIME):n      +
1         VALUES (h_prj_assign_id, h_project_id, h_project_id, h_type,:n      +
1         h_res_type, h_res_id, h_profile_id, PMO_CNST.SC_AFFECTED, h_temp_sec+
1urity_id, h_table_type,:n               rec_user001, SYSTIMESTAMP):
1634:
1           EXCEPTION:: SP_A_RESTOPROF(635) :: cplan.sql(9281) :: :
1PROFILE_NAME:
1SELECT PROFILE_NAME INTO h_profile_name FROM PROFILES WHERE PROFILE_ID = h_pr+
1ofile_id:
1648:
1           EXCEPTION:: SP_A_RESTOPROF(649) :: cplan.sql(9295) :: :
1SELECT COUNT(TSK_ASSIGNMENT_ID) INTO h_total FROM TASK_ASSIGNMENTS:n         +
1         WHERE PROJECT_ID = h_project_id AND TASK_ID <> h_task_id AND RESOURC+
1E_TYPE = '1' AND RESOURCE_ID = h_profile_id AND BIT_FLAG = '0':
1665:
1           EXCEPTION:: SP_A_RESTOPROF(666) :: cplan.sql(9312) :: :
1ASSIGN_NAMES:
1REPLACE:
1UPDATE TMT_WBS SET ASSIGN_NAMES = REPLACE (ASSIGN_NAMES, h_profile_name, h_fu+
1ll_name):n                  WHERE ELEMENT_ID = h_project_id AND PROJECT_ID = +
1h_project_id:
1687:
1           EXCEPTION:: SP_A_RESTOPROF(688) :: cplan.sql(9334) :: :
1INSTR:
1LENGTH:
1UPDATE TMT_WBS SET ASSIGN_NAMES =:n                  CASE:n                  +
1WHEN InStr( ASSIGN_NAMES, h_full_name || ';') > 0 THEN ASSIGN_NAMES:n        +
1          ELSE:n                  CASE:n                  WHEN LENGTH(h_full_+
1name) + LENGTH(ASSIGN_NAMES) > 2040 THEN ASSIGN_NAMES:n                  ELSE+
1 ASSIGN_NAMES || h_full_name || ';':n                  END:n                 +
1 END:n                  WHERE PROJECT_ID = h_project_id AND ELEMENT_ID = h_pr+
1oject_id:
1714:
1           EXCEPTION:: SP_A_RESTOPROF(715) :: cplan.sql(9361) :: :
1741:
1           EXCEPTION:: SP_A_RESTOPROF(742) :: cplan.sql(9388) :: :
1SELECT TSK_ASSIGNMENT_ID INTO h_prj_assignment_id FROM TASK_ASSIGNMENTS:n    +
1           WHERE RES_ASSIGNMENT_ID = h_prj_assign_id AND BIT_FLAG = '0':
1756:
1           EXCEPTION:: SP_A_RESTOPROF(757) :: cplan.sql(9403) :: :
1SC_PARTICIPANT:
1UPDATE RESOURCE_ASSIGNMENTS SET PROFILE_ID = h_profile_id,:n                 +
1 PARTICIPANT = PMO_CNST.SC_AFFECTED, SECURITY_ID = h_temp_security_id:n      +
1            WHERE RES_ASSIGNMENT_ID = h_prj_assign_id:
1779:
1           EXCEPTION:: SP_A_RESTOPROF(780) :: cplan.sql(9426) :: :
1FC_AFTER_U_RES_ASSIGN:
1PMO_STPU:
1BIT_OR:
1UPDATE RESOURCE_ASSIGNMENTS SET PROFILE_ID = h_profile_id,:n                 +
1 PARTICIPANT=PMO_STPU.BIT_OR(PARTICIPANT, PMO_CNST.SC_AFFECTED):n            +
1      WHERE RES_ASSIGNMENT_ID = h_prj_assign_id:
1800:
1           EXCEPTION:: SP_A_RESTOPROF(801) :: cplan.sql(9447) :: :
1SC_TEAMMEMBER:
1UPDATE RESOURCE_ASSIGNMENTS SET PROFILE_ID = h_profile_id,:n                 +
1 PARTICIPANT=PMO_STPU.BIT_OR(PARTICIPANT, PMO_CNST.SC_TEAMMEMBER):n          +
1        WHERE RES_ASSIGNMENT_ID = h_prj_assign_id:
1821:
1           EXCEPTION:: SP_A_RESTOPROF(822) :: cplan.sql(9468) :: :
1FC_DECLARE_PMO_TMP_SEARCH:
1FC_GET_RES_RATES:
1RS:
1SELECT CASE WHEN h_currency_id = rs.CURRENCY_ID THEN 1:n      ELSE h_rate_ech+
1ange / PMO_ORASTD.TODECIMAL(td.ELEMENT_NAME,20,4) END:n      INTO h_rate_echa+
1nge:n      FROM RESOURCES rs JOIN TMT_DATAFIELDS td ON rs.CURRENCY_ID = td.EL+
1EMENT_ID AND rs.CURRENCY_ID > 0:n      WHERE RESOURCE_ID=h_res_id:
1861:
1           EXCEPTION:: SP_A_RESTOPROF(862) :: cplan.sql(9508) :: :
11.00:
1ASSIGNMENT_BILLABLE_FLAG:
1TIMEPHASE_PROJECT_ASSIGNMENT:
1SELECT ASSIGNMENT_BILLABLE_FLAG, TIMEPHASE_PROJECT_ASSIGNMENT INTO h_billable+
1, h_pa_timephase:n      FROM PROJECT_DETAILS WHERE PROJECT_ID = h_project_id:
1886:
1           EXCEPTION:: SP_A_RESTOPROF(887) :: cplan.sql(9533) :: :
1SUM:
1SCHED_MIN:
1TASK_DAY_OF_YEAR:
1SELECT SUM(SCHED_MIN) INTO h_total FROM TASK_DAY_OF_YEAR:n         WHERE PROJ+
1ECT_ID = h_project_id AND TASK_ID = h_project_id AND RESOURCE_ID = h_profile_+
1id:
1902:
1           EXCEPTION:: SP_A_RESTOPROF(903) :: cplan.sql(9549) :: :
1SELECT TSK_ASSIGNMENT_ID,RES_ASSIGNMENT_ID,PLANNED_WORK, TO_DATE(SubStr(PLANN+
1ED_START, 1, 10)), TO_DATE(SubStr(PLANNED_FINISH, 1, 10)), BILLABLE, CAPITAL_+
1EXPENSE,:n            REGULAR_COST, REGULAR_RATE, TASK_ID, UNITS_MSP, C_EFFOR+
1T, T_UNIT, C_UNIT, C_CONTOUR:n            INTO h_prj_assignment_id, h_id, h_p+
1lanned_effort, h_start_D, h_finish_D, h_billable, h_capital_expense,:n       +
1     h_old_cost, h_old_sale, h_task_id, h_percent_units, h_work, h_eunit, h_u+
1nit, h_contour:n            FROM TASK_ASSIGNMENTS:n            WHERE TASK_ID +
1= h_project_id AND RESOURCE_ID = h_profile_id AND RESOURCE_TYPE = '1':
1931:
1           EXCEPTION:: SP_A_RESTOPROF(932) :: cplan.sql(9578) :: :
1SC_0000FFFF:
1947:
1        RETURN_ERROR:: SP_A_RESTOPROF(948) :: cplan.sql(9594) :: :
1TASK_ASSIGNMENT_ERROR:
1950:
1                EXIT:: SP_A_RESTOPROF(951) :: cplan.sql(9597) :: :
1Y:
1-:
1FC_TPHASE_SCHED_ASSIGN:
1DELETE FROM TASK_ASSIGNMENTS WHERE TSK_ASSIGNMENT_ID = h_prj_assignment_id:
1997:
1           EXCEPTION:: SP_A_RESTOPROF(998) :: cplan.sql(9644) :: :
1DELETE FROM TASK_DAY_OF_YEAR WHERE PROJECT_ID = h_project_id AND TSK_ASSIGNME+
1NT_ID = h_prj_assignment_id:
11015:
1           EXCEPTION:: SP_A_RESTOPROF(1016) :: cplan.sql(9662) :: :
1MAX:
1DAY_YEAR:
1SELECT MAX(DAY_YEAR) INTO h_start_D FROM TASK_DAY_OF_YEAR:n                  +
1WHERE PROJECT_ID = h_project_id AND TSK_ASSIGNMENT_ID = h_prj_assignment_id:
11031:
1           EXCEPTION:: SP_A_RESTOPROF(1032) :: cplan.sql(9678) :: :
1<=:
1DB2TIMESTAMP:
1TIME:
1DUAL:
1SELECT PMO_ORASTD.DB2TIMESTAMP(TO_DATE(SubStr(h_start_D, 1, 10)) + 1     , PM+
1O_ORASTD.TIME(h_start_date)):n                     INTO h_start_date:n       +
1              FROM DUAL:
11047:
1           EXCEPTION:: SP_A_RESTOPROF(1048) :: cplan.sql(9694) :: :
1*:
1SPECIAL_COST:
1SPECIAL_RATE:
1ESTIMATION_LABOR_COST:
1SCHED_WORK:
1ROLLUP_BITS:
1SC_LABOR_BIT:
1UPDATE TASK_ASSIGNMENTS SET RES_ASSIGNMENT_ID = h_prj_assign_id,:n           +
1             RESOURCE_ID = h_res_id, RESOURCE_TYPE = '0',:n                  +
1      REGULAR_COST = h_reg_cost,:n                        SPECIAL_COST = h_sp+
1ec_cost,:n                        REGULAR_RATE = h_reg_sale,:n               +
1         SPECIAL_RATE = h_spec_sale,:n                        UNITS_MSP = CAS+
1E WHEN h_contour_changed = 0 THEN UNITS_MSP ELSE h_percent_units END,:n      +
1                  ESTIMATION_LABOR_COST = ((PLANNED_WORK+SCHED_WORK)/60.00) *+
1 h_reg_cost,:n                        ROLLUP_BITS = PMO_STPU.BIT_OR(ROLLUP_BI+
1TS, PMO_CNST.SC_LABOR_BIT):n                        WHERE TSK_ASSIGNMENT_ID =+
1 h_prj_assignment_id:
11081:
1           EXCEPTION:: SP_A_RESTOPROF(1082) :: cplan.sql(9728) :: :
1ESTIMATION_LABOR_REVENUE:
1UPDATE TASK_ASSIGNMENTS SET RES_ASSIGNMENT_ID = h_prj_assign_id,:n           +
1             RESOURCE_ID = h_res_id, RESOURCE_TYPE = '0',:n                  +
1      REGULAR_COST = h_reg_cost,:n                        SPECIAL_COST = h_sp+
1ec_cost,:n                        REGULAR_RATE = h_reg_sale,:n               +
1         SPECIAL_RATE = h_spec_sale,:n                        UNITS_MSP = CAS+
1E WHEN h_contour_changed = 0 THEN UNITS_MSP ELSE h_percent_units END,:n      +
1                  ESTIMATION_LABOR_COST = ((PLANNED_WORK+SCHED_WORK)/60.00) *+
1 h_reg_cost,:n                        ESTIMATION_LABOR_REVENUE = ((PLANNED_WO+
1RK+PLANNED_WORK)/60.00) * h_reg_sale,:n                        ROLLUP_BITS = +
1PMO_STPU.BIT_OR(ROLLUP_BITS, PMO_CNST.SC_LABOR_BIT):n                        +
1WHERE TSK_ASSIGNMENT_ID = h_prj_assignment_id:
11108:
1           EXCEPTION:: SP_A_RESTOPROF(1109) :: cplan.sql(9755) :: :
1UPDATE TASK_ASSIGNMENTS SET RES_ASSIGNMENT_ID = h_prj_assign_id,:n           +
1          RESOURCE_ID = h_res_id, RESOURCE_TYPE = '0',:n                     +
1REGULAR_COST = h_reg_cost,:n                     SPECIAL_COST = h_spec_cost,+
1:n                     UNITS_MSP = CASE WHEN h_contour_changed = 0 THEN UNITS+
1_MSP ELSE h_percent_units END,:n                     ESTIMATION_LABOR_COST = +
1((PLANNED_WORK+SCHED_WORK)/60.00) * h_reg_cost,:n                     ROLLUP_+
1BITS = PMO_STPU.BIT_OR(ROLLUP_BITS, PMO_CNST.SC_LABOR_BIT):n                 +
1    WHERE TSK_ASSIGNMENT_ID = h_prj_assignment_id:
11136:
1           EXCEPTION:: SP_A_RESTOPROF(1137) :: cplan.sql(9783) :: :
1UPDATE TASK_ASSIGNMENTS SET RES_ASSIGNMENT_ID = h_prj_assign_id,:n           +
1             RESOURCE_ID = h_res_id, RESOURCE_TYPE = '0',:n                  +
1      REGULAR_RATE = h_reg_sale,:n                        SPECIAL_RATE = h_sp+
1ec_sale,:n                        UNITS_MSP = CASE WHEN h_contour_changed = 0+
1 THEN UNITS_MSP ELSE h_percent_units END,:n                        ROLLUP_BIT+
1S = PMO_STPU.BIT_OR(ROLLUP_BITS, PMO_CNST.SC_LABOR_BIT):n                    +
1    WHERE TSK_ASSIGNMENT_ID = h_prj_assignment_id:
11163:
1           EXCEPTION:: SP_A_RESTOPROF(1164) :: cplan.sql(9810) :: :
1UPDATE TASK_ASSIGNMENTS SET RES_ASSIGNMENT_ID = h_prj_assign_id,:n           +
1             RESOURCE_ID = h_res_id, RESOURCE_TYPE = '0',:n                  +
1      REGULAR_RATE = h_reg_sale,:n                        SPECIAL_RATE = h_sp+
1ec_sale,:n                        UNITS_MSP = CASE WHEN h_contour_changed = 0+
1 THEN UNITS_MSP ELSE h_percent_units END,:n                        ESTIMATION+
1_LABOR_REVENUE = ((PLANNED_WORK+PLANNED_WORK)/60.00) * h_reg_sale,:n         +
1               ROLLUP_BITS = PMO_STPU.BIT_OR(ROLLUP_BITS, PMO_CNST.SC_LABOR_B+
1IT):n                        WHERE TSK_ASSIGNMENT_ID = h_prj_assignment_id:
11187:
1           EXCEPTION:: SP_A_RESTOPROF(1188) :: cplan.sql(9834) :: :
1UPDATE TASK_ASSIGNMENTS SET RES_ASSIGNMENT_ID = h_prj_assign_id,:n           +
1          UNITS_MSP = CASE WHEN h_contour_changed = 0 THEN UNITS_MSP ELSE h_p+
1ercent_units END,:n                     RESOURCE_ID = h_res_id, RESOURCE_TYPE+
1 = '0':n                     WHERE TSK_ASSIGNMENT_ID = h_prj_assignment_id:
11208:
1           EXCEPTION:: SP_A_RESTOPROF(1209) :: cplan.sql(9855) :: :
11226:
1           EXCEPTION:: SP_A_RESTOPROF(1227) :: cplan.sql(9873) :: :
1RESOURCE_ASSIGN_SKILLS:
1SKILL_ID:
1PROFICIENCY_LEVEL_ID:
1EXPERIENCE_ID:
1PREFERENCE_LEVEL_ID:
1LAST_USED_DATETIME:
1PRIMARY_SKILL:
1INSERT INTO RESOURCE_ASSIGN_SKILLS:n                  SELECT h_prj_assignment+
1_id, SKILL_ID, PROFICIENCY_LEVEL_ID, EXPERIENCE_ID, PREFERENCE_LEVEL_ID, LAST+
1_USED_DATETIME, PRIMARY_SKILL:n                  FROM RESOURCE_ASSIGN_SKILLS +
1WHERE RES_ASSIGNMENT_ID = h_profile_id:
11245:
1           EXCEPTION:: SP_A_RESTOPROF(1246) :: cplan.sql(9892) :: :
1DELETE FROM RESOURCE_ASSIGNMENTS WHERE RES_ASSIGNMENT_ID = h_id:
11267:
1           EXCEPTION:: SP_A_RESTOPROF(1268) :: cplan.sql(9914) :: :
1PROJECT_ASSIGNMENTS:
1DELETE FROM PROJECT_ASSIGNMENTS WHERE PROJECT_ID = h_project_id AND RESOURCE_+
1ID = h_profile_id:
11285:
1           EXCEPTION:: SP_A_RESTOPROF(1286) :: cplan.sql(9932) :: :
1PMO_FUNC:
1ASSIGNLONG:
1FC_CALC_DURATION:
1INVALID_PARAMS:
18:
11310:
1      RETURN_INVALID:: SP_A_RESTOPROF(1311) :: cplan.sql(9957) :: :
11313:
1                EXIT:: SP_A_RESTOPROF(1314) :: cplan.sql(9960) :: :
1PMO_RETURN_INVALID_SP:
11318:
1        RETURN_ERROR:: SP_A_RESTOPROF(1319) :: cplan.sql(9965) :: :
11321:
1                EXIT:: SP_A_RESTOPROF(1322) :: cplan.sql(9968) :: :
1SC_BIT_27:
1FC_SEARCH_2:
1110:
11349:
1        RETURN_ERROR:: SP_A_RESTOPROF(1350) :: cplan.sql(9996) :: :
1RESOURCE_UNAVAILABLE:
11352:
1                EXIT:: SP_A_RESTOPROF(1353) :: cplan.sql(9999) :: :
11357:
1        RETURN_ERROR:: SP_A_RESTOPROF(1358) :: cplan.sql(10004) :: :
11360:
1                EXIT:: SP_A_RESTOPROF(1361) :: cplan.sql(10007) :: :
1U_ASSIGN_STRING:
1SELECT TSK_ASSIGNMENT_ID, TO_DATE(SubStr(PLANNED_START, 1, 10)), TO_DATE(SubS+
1tr(PLANNED_FINISH, 1, 10)), BILLABLE, CAPITAL_EXPENSE, REGULAR_COST, REGULAR_+
1RATE:n            INTO h_old_prj_assign_id, h_start_D, h_finish_D, h_billable+
1, h_capital_expense, h_old_cost, h_old_sale:n            FROM TASK_ASSIGNMENT+
1S:n            WHERE PROJECT_ID = h_project_id AND TASK_ID = h_project_id :n +
1           AND RESOURCE_TYPE = '1' AND RESOURCE_ID = h_profile_id:
11385:
1           EXCEPTION:: SP_A_RESTOPROF(1386) :: cplan.sql(10032) :: :
1SELECT TSK_ASSIGNMENT_ID, BILLABLE INTO h_old_prj_assign_id, h_billable:n    +
1        FROM TASK_ASSIGNMENTS:n            WHERE PROJECT_ID = h_project_id AN+
1D TASK_ID = h_project_id :n            AND RESOURCE_ID = h_profile_id AND RES+
1OURCE_TYPE = '1':
11410:
1           EXCEPTION:: SP_A_RESTOPROF(1411) :: cplan.sql(10057) :: :
1SELECT TSK_ASSIGNMENT_ID, TO_DATE(SubStr(PLANNED_START, 1, 10)), TO_DATE(SubS+
1tr(PLANNED_FINISH, 1, 10)), BILLABLE, CAPITAL_EXPENSE, REGULAR_COST, REGULAR_+
1RATE:n         INTO h_old_prj_assign_id, h_start_D, h_finish_D, h_billable, h+
1_capital_expense, h_old_cost, h_old_sale:n         FROM TASK_ASSIGNMENTS:n   +
1      WHERE PROJECT_ID = h_project_id AND TASK_ID = h_project_id :n         A+
1ND RESOURCE_ID = h_profile_id AND RESOURCE_TYPE = '1':
11430:
1           EXCEPTION:: SP_A_RESTOPROF(1431) :: cplan.sql(10077) :: :
1SELECT TSK_ASSIGNMENT_ID, BILLABLE INTO h_old_prj_assign_id, h_billable:n    +
1     FROM TASK_ASSIGNMENTS:n         WHERE PROJECT_ID = h_project_id AND TASK+
1_ID = h_project_id :n         AND RESOURCE_ID = h_profile_id AND RESOURCE_TYP+
1E = '1':
11455:
1           EXCEPTION:: SP_A_RESTOPROF(1456) :: cplan.sql(10102) :: :
1IS NULL:
1SD:
1FD:
1START_DT:
1FINISH_DT:
1BAK_START_DT:
1BAK_FINISH_DT:
1SC_NS:
1SC_NF:
1INSERT INTO TASK_ASSIGNMENTS(TSK_ASSIGNMENT_ID,RES_ASSIGNMENT_ID,TASK_ID,PROJ+
1ECT_ID,SD,FD,START_DT,FINISH_DT,:n               PLANNED_START, PLANNED_FINIS+
1H, BIT_FLAG, BAK_START_DT, BAK_FINISH_DT, RESOURCE_ID,RESOURCE_TYPE,PROJECT_A+
1SSIGNMENT_ID,:n               BILLABLE, CAPITAL_EXPENSE, REGULAR_COST,SPECIAL+
1_COST,REGULAR_RATE,SPECIAL_RATE, TIMECODE_1_ID, TIMECODE_2_ID, TABLE_TYPE):n +
1              VALUES(h_prj_assignment_id, h_prj_assign_id, h_project_id, h_pr+
1oject_id, PMO_CNST.SC_NS,PMO_CNST.SC_NF,h_start_DT, h_finish_DT,:n           +
1    h_start_DT, h_finish_DT, '0', h_start_DT, h_finish_DT, h_res_id,h_res_typ+
1e, h_prj_assignment_id,:n               h_billable, h_capital_expense,h_reg_c+
1ost,h_spec_cost,h_reg_sale,h_spec_sale,h_timecode_1_id, h_timecode_2_id, h_ta+
1ble_type):
11501:
1           EXCEPTION:: SP_A_RESTOPROF(1502) :: cplan.sql(10148) :: :
1INSERT INTO TASK_ASSIGNMENTS(TSK_ASSIGNMENT_ID,RES_ASSIGNMENT_ID,TASK_ID,PROJ+
1ECT_ID,SD,FD,START_DT,FINISH_DT,:n               PLANNED_START, PLANNED_FINIS+
1H, BIT_FLAG, BAK_START_DT, BAK_FINISH_DT, RESOURCE_ID,RESOURCE_TYPE,PROJECT_A+
1SSIGNMENT_ID,:n               BILLABLE, CAPITAL_EXPENSE, REGULAR_COST,SPECIAL+
1_COST,REGULAR_RATE,SPECIAL_RATE, TIMECODE_1_ID, TIMECODE_2_ID, TABLE_TYPE):n +
1              VALUES(h_prj_assignment_id, h_prj_assign_id, h_project_id, h_pr+
1oject_id, PMO_CNST.SC_NS,PMO_CNST.SC_NF,h_start_DT, h_finish_DT,:n           +
1    h_start_DT, h_finish_DT, '0', h_start_DT, h_finish_DT, h_res_id,h_res_typ+
1e, h_prj_assignment_id,:n               h_billable, h_capital_expense,h_reg_c+
1ost,h_spec_cost,h_reg_sale,h_spec_sale, h_timecode_1_id, h_timecode_2_id, h_t+
1able_type):
11526:
1           EXCEPTION:: SP_A_RESTOPROF(1527) :: cplan.sql(10173) :: :
11551:
1           EXCEPTION:: SP_A_RESTOPROF(1552) :: cplan.sql(10198) :: :
1INSERT INTO TASK_ASSIGNMENTS(TSK_ASSIGNMENT_ID,RES_ASSIGNMENT_ID,TASK_ID,PROJ+
1ECT_ID,SD,FD,START_DT,FINISH_DT,:n            PLANNED_START,PLANNED_FINISH,BI+
1T_FLAG,BAK_START_DT,BAK_FINISH_DT,RESOURCE_ID,RESOURCE_TYPE,PROJECT_ASSIGNMEN+
1T_ID,:n            BILLABLE, CAPITAL_EXPENSE, REGULAR_COST,SPECIAL_COST,REGUL+
1AR_RATE,SPECIAL_RATE, TIMECODE_1_ID, TIMECODE_2_ID, TABLE_TYPE):n            +
1VALUES(h_prj_assignment_id, h_prj_assign_id, h_project_id, h_project_id, PMO_+
1CNST.SC_NS,PMO_CNST.SC_NF,h_start_DT, h_finish_DT,:n            h_start_DT, h+
1_finish_DT, '0', h_start_DT, h_finish_DT, h_res_id,h_res_type, h_prj_assignme+
1nt_id,:n            h_billable, h_capital_expense,h_reg_cost,h_spec_cost,h_re+
1g_sale,h_spec_sale, h_timecode_1_id, h_timecode_2_id, h_table_type):
11574:
1           EXCEPTION:: SP_A_RESTOPROF(1575) :: cplan.sql(10221) :: :
1%:
11600:
1           EXCEPTION:: SP_A_RESTOPROF(1601) :: cplan.sql(10247) :: :
1MIN:
1SELECT MIN(t.PLANNED_START) INTO h_start_date:n         FROM TMT_WBS w, TASK_+
1ASSIGNMENTS t:n         WHERE t.PROJECT_ID = h_project_id AND t.RESOURCE_ID =+
1 h_profile_id AND:n         t.TASK_ID = w.ELEMENT_ID AND w.TYPE_ID IN (PMO_CN+
1ST.SC_TASK,PMO_CNST.SC_TASK_TYPE1,PMO_CNST.SC_TASK_TYPE2,PMO_CNST.SC_TASK_TYP+
1E3,PMO_CNST.SC_MILESTONE,PMO_CNST.SC_PERSONAL_TASK,PMO_CNST.SC_ACTIVE_ADM_TAS+
1K,PMO_CNST.SC_INACTIVE_ADM_TASK,PMO_CNST.SC_WBS_CHANGE_REQUEST_TASK,PMO_CNST.+
1SC_WBS_ACTION_ITEM_TASK,PMO_CNST.SC_WBS_RISK_TASK,PMO_CNST.SC_WBS_ISSUE_TASK,+
1PMO_CNST.SC_WBS_REQUIREMENT_TASK,PMO_CNST.SC_WBS_DEFECT_TASK,PMO_CNST.SC_WBS_+
1SERVICE_REQUEST_TASK) AND w.RANK LIKE h_rank:
11622:
1           EXCEPTION:: SP_A_RESTOPROF(1623) :: cplan.sql(10269) :: :
1LOOP:
1EXIT:
1FC_BEFORE_D_RES_ASSIGN:
1DELETE FROM RESOURCE_ASSIGNMENTS WHERE RES_ASSIGNMENT_ID = h_assign_id:
11672:
1           EXCEPTION:: SP_A_RESTOPROF(1673) :: cplan.sql(10319) :: :
1DELETE FROM TASK_ASSIGNMENTS WHERE TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
11689:
1           EXCEPTION:: SP_A_RESTOPROF(1690) :: cplan.sql(10336) :: :
1EFFORT_WEEK:
1DELETE FROM EFFORT_WEEK WHERE TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
11706:
1           EXCEPTION:: SP_A_RESTOPROF(1707) :: cplan.sql(10353) :: :
1DELETE FROM TASK_DAY_OF_YEAR WHERE PROJECT_ID = h_project_id AND TSK_ASSIGNME+
1NT_ID = h_tsk_assignment_id:
11723:
1           EXCEPTION:: SP_A_RESTOPROF(1724) :: cplan.sql(10370) :: :
1RESOURCE_ASSIGN_ROLES:
1DELETE FROM RESOURCE_ASSIGN_ROLES WHERE RES_ASSIGNMENT_ID = h_tsk_assignment_+
1id:
11740:
1           EXCEPTION:: SP_A_RESTOPROF(1741) :: cplan.sql(10387) :: :
1DELETE FROM RESOURCE_ASSIGN_SKILLS WHERE RES_ASSIGNMENT_ID = h_tsk_assignment+
1_id:
11757:
1           EXCEPTION:: SP_A_RESTOPROF(1758) :: cplan.sql(10404) :: :
1SUMMARY_TIMESHEETS:
1UPDATE SUMMARY_TIMESHEETS SET RESOURCE_ID = h_res_id :n            WHERE TSK_+
1ASSIGNMENT_ID = h_tsk_assignment_id :n            AND PROJECT_ID = h_project_+
1id :n            AND RESOURCE_ID = h_profile_id:
11777:
1           EXCEPTION:: SP_A_RESTOPROF(1778) :: cplan.sql(10424) :: :
1SELECT TSK_ASSIGNMENT_ID INTO h_id FROM TASK_ASSIGNMENTS:n            WHERE P+
1ROJECT_ID = h_project_id AND TASK_ID = h_task_id AND RESOURCE_ID = h_res_id:n+
1            AND RESOURCE_TYPE ='0':
11792:
1           EXCEPTION:: SP_A_RESTOPROF(1793) :: cplan.sql(10439) :: :
1SELECT RES_ASSIGNMENT_ID, PARTICIPANT, SECURITY_ID INTO h_id, h_participant, +
1h_security_id:n               FROM RESOURCE_ASSIGNMENTS :n               WHER+
1E ELEMENT_ID = h_task_id AND RESOURCE_ID = h_res_id AND RESOURCE_TYPE='0':
11815:
1           EXCEPTION:: SP_A_RESTOPROF(1816) :: cplan.sql(10462) :: :
1UPDATE RESOURCE_ASSIGNMENTS SET :n                     PROFILE_ID		= h_profil+
1e_id,:n                     RESOURCE_ID		= h_res_id, :n                     R+
1ESOURCE_TYPE	= '0':n                     WHERE RES_ASSIGNMENT_ID = h_assign_i+
1d:
11841:
1           EXCEPTION:: SP_A_RESTOPROF(1842) :: cplan.sql(10488) :: :
1UPDATE RESOURCE_ASSIGNMENTS SET :n                     PARTICIPANT		= PMO_CNS+
1T.SC_TEAMMEMBER, :n                     SECURITY_ID		= h_temp_security_id, :n+
1                     PROFILE_ID		= h_profile_id,:n                     RESOUR+
1CE_ID		= h_res_id, :n                     RESOURCE_TYPE	= '0':n              +
1       WHERE RES_ASSIGNMENT_ID = h_assign_id:
11867:
1           EXCEPTION:: SP_A_RESTOPROF(1868) :: cplan.sql(10514) :: :
1UPDATE RESOURCE_ASSIGNMENTS SET :n                     PARTICIPANT		= PMO_STP+
1U.BIT_OR(h_participant,PMO_CNST.SC_TEAMMEMBER), :n                     SECURI+
1TY_ID		= h_security_id, :n                     PROFILE_ID		= h_profile_id,:n +
1                    RESOURCE_ID		= h_res_id, :n                     RESOURCE_+
1TYPE	= '0':n                     WHERE RES_ASSIGNMENT_ID = h_assign_id:
11890:
1           EXCEPTION:: SP_A_RESTOPROF(1891) :: cplan.sql(10537) :: :
11909:
1           EXCEPTION:: SP_A_RESTOPROF(1910) :: cplan.sql(10556) :: :
1RA:
1CREATED_BY:
1TA:
1SELECT ra.RES_ASSIGNMENT_ID, SUBSTR(tw.ASSIGN_NAMES,1,InStr(tw.ASSIGN_NAMES, +
1';') - 1):n                  INTO h_id,h_in FROM TMT_WBS tw, RESOURCE_ASSIGNM+
1ENTS ra:n                  WHERE tw.ELEMENT_ID = h_task_id AND tw.ELEMENT_ID +
1= ra.ELEMENT_ID AND ra.PARTICIPANT = 32 :n                  AND ra.RESOURCE_I+
1D = tw.CREATED_BY AND NOT EXISTS(:n                  SELECT TSK_ASSIGNMENT_ID+
1 FROM TASK_ASSIGNMENTS ta WHERE ta.RES_ASSIGNMENT_ID = ra.RES_ASSIGNMENT_ID):
11927:
1           EXCEPTION:: SP_A_RESTOPROF(1928) :: cplan.sql(10574) :: :
1SC_RESPONSIBLE_GROUP:
11949:
1           EXCEPTION:: SP_A_RESTOPROF(1950) :: cplan.sql(10596) :: :
1UPDATE RESOURCE_ASSIGNMENTS SET RESOURCE_ID = h_res_id, RESOURCE_TYPE='0',:n +
1                    PROFILE_ID = h_profile_id, PARTICIPANT = 48, SECURITY_ID=+
1h_temp_security_id:n                     WHERE RES_ASSIGNMENT_ID = h_assign_i+
1d:
11968:
1           EXCEPTION:: SP_A_RESTOPROF(1969) :: cplan.sql(10615) :: :
1UPDATE TMT_WBS SET ASSIGN_NAMES = REPLACE (ASSIGN_NAMES, h_in, h_full_name) +
1:n                     WHERE ELEMENT_ID = h_task_id:
11986:
1           EXCEPTION:: SP_A_RESTOPROF(1987) :: cplan.sql(10633) :: :
1UPDATE TMT_WBS SET ASSIGN_NAMES = REPLACE (ASSIGN_NAMES, h_profile_name, h_fu+
1ll_name) WHERE ELEMENT_ID = h_task_id:
12006:
1           EXCEPTION:: SP_A_RESTOPROF(2007) :: cplan.sql(10653) :: :
1UPDATE RESOURCE_ASSIGNMENTS SET RESOURCE_ID = h_res_id, RESOURCE_TYPE = '0',+
1:n                     PROFILE_ID = h_profile_id, PARTICIPANT = 16, SECURITY_+
1ID=h_temp_security_id:n                     WHERE RES_ASSIGNMENT_ID = h_assig+
1n_id:
12025:
1           EXCEPTION:: SP_A_RESTOPROF(2026) :: cplan.sql(10672) :: :
1SELECT CASE WHEN FS_LABOR_CODE IS NuLL THEN 0 WHEN FS_LABOR_CODE = h_labor_co+
1de THEN 1 ELSE 2 END:n                     INTO h_same_labor FROM TMT_WBS WHE+
1RE ELEMENT_ID=h_task_id:
12045:
1           EXCEPTION:: SP_A_RESTOPROF(2046) :: cplan.sql(10692) :: :
1UPDATE TMT_WBS SET FS_LABOR_CODE = h_labor_code WHERE ELEMENT_ID=h_task_id:
12064:
1           EXCEPTION:: SP_A_RESTOPROF(2065) :: cplan.sql(10711) :: :
12077:
1           EXCEPTION:: SP_A_RESTOPROF(2078) :: cplan.sql(10724) :: :
12083:
1        RETURN_ERROR:: SP_A_RESTOPROF(2084) :: cplan.sql(10730) :: :
1CANNOT_ASSIGN_LABOR_CODE:
12086:
1                EXIT:: SP_A_RESTOPROF(2087) :: cplan.sql(10733) :: :
12163:
1           EXCEPTION:: SP_A_RESTOPROF(2164) :: cplan.sql(10810) :: :
1ETC:
1UPDATE TASK_ASSIGNMENTS SET:n                           RESOURCE_ID = h_res_i+
1d, RESOURCE_TYPE='0', PROJECT_ASSIGNMENT_ID =:n                           CAS+
1E WHEN h_assigned = 0 THEN NuLL ELSE h_prj_assignment_id END,:n              +
1             REGULAR_COST = CASE WHEN h_donot_replace_cost = 0 THEN h_reg_cos+
1t  ELSE REGULAR_COST END,:n                           SPECIAL_COST = CASE WHE+
1N h_donot_replace_cost = 0 THEN h_spec_cost ELSE SPECIAL_COST END,:n         +
1                  REGULAR_RATE = CASE WHEN h_donot_replace_rate = 0 THEN h_re+
1g_sale  ELSE REGULAR_RATE END,:n                           SPECIAL_RATE = CAS+
1E WHEN h_donot_replace_rate = 0 THEN h_spec_sale ELSE SPECIAL_RATE END,:n    +
1                       UNITS_MSP    = work001, ETC = h_effort,:n             +
1              C_CONTOUR    = contour001,:n                           ROLLUP_B+
1ITS  = PMO_STPU.BIT_OR(ROLLUP_BITS, PMO_CNST.SC_LABOR_BIT):n                 +
1          WHERE TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
12211:
1           EXCEPTION:: SP_A_RESTOPROF(2212) :: cplan.sql(10858) :: :
1UPDATE TASK_ASSIGNMENTS SET:n                           RESOURCE_ID = h_res_i+
1d, RESOURCE_TYPE='0', PROJECT_ASSIGNMENT_ID =:n                           CAS+
1E WHEN h_assigned = 0 THEN NuLL ELSE h_prj_assignment_id END,:n              +
1             REGULAR_COST = CASE WHEN h_donot_replace_cost = 0 THEN h_reg_cos+
1t  ELSE REGULAR_COST END,:n                           SPECIAL_COST = CASE WHE+
1N h_donot_replace_cost = 0 THEN h_spec_cost ELSE SPECIAL_COST END,:n         +
1                  REGULAR_RATE = CASE WHEN h_donot_replace_rate = 0 THEN h_re+
1g_sale  ELSE REGULAR_RATE END,:n                           SPECIAL_RATE = CAS+
1E WHEN h_donot_replace_rate = 0 THEN h_spec_sale ELSE SPECIAL_RATE END,:n    +
1                       C_EFFORT     = work001, ETC = h_effort,:n             +
1              C_UNIT       = unit,:n                           C_CONTOUR    =+
1 contour001,:n                           ROLLUP_BITS  = PMO_STPU.BIT_OR(ROLLU+
1P_BITS, PMO_CNST.SC_LABOR_BIT):n                           WHERE TSK_ASSIGNME+
1NT_ID = h_tsk_assignment_id:
12239:
1           EXCEPTION:: SP_A_RESTOPROF(2240) :: cplan.sql(10886) :: :
1UPDATE TASK_ASSIGNMENTS SET:n                        RESOURCE_ID = h_res_id, +
1RESOURCE_TYPE='0', PROJECT_ASSIGNMENT_ID =:n                        CASE WHEN+
1 h_assigned = 0 THEN NuLL ELSE h_prj_assignment_id END,:n                    +
1    REGULAR_COST = CASE WHEN h_donot_replace_cost = 0 THEN h_reg_cost  ELSE R+
1EGULAR_COST END,:n                        SPECIAL_COST = CASE WHEN h_donot_re+
1place_cost = 0 THEN h_spec_cost ELSE SPECIAL_COST END,:n                     +
1   REGULAR_RATE = CASE WHEN h_donot_replace_rate = 0 THEN h_reg_sale  ELSE RE+
1GULAR_RATE END,:n                        SPECIAL_RATE = CASE WHEN h_donot_rep+
1lace_rate = 0 THEN h_spec_sale ELSE SPECIAL_RATE END,:n                      +
1  ROLLUP_BITS  = PMO_STPU.BIT_OR(ROLLUP_BITS, PMO_CNST.SC_LABOR_BIT), ETC = h+
1_effort:n                        WHERE TSK_ASSIGNMENT_ID = h_tsk_assignment_i+
1d:
12267:
1           EXCEPTION:: SP_A_RESTOPROF(2268) :: cplan.sql(10914) :: :
12293:
1           EXCEPTION:: SP_A_RESTOPROF(2294) :: cplan.sql(10940) :: :
12299:
1      RETURN_INVALID:: SP_A_RESTOPROF(2300) :: cplan.sql(10946) :: :
12302:
1                EXIT:: SP_A_RESTOPROF(2303) :: cplan.sql(10949) :: :
12314:
1           EXCEPTION:: SP_A_RESTOPROF(2315) :: cplan.sql(10961) :: :
12320:
1        RETURN_ERROR:: SP_A_RESTOPROF(2321) :: cplan.sql(10967) :: :
12323:
1                EXIT:: SP_A_RESTOPROF(2324) :: cplan.sql(10970) :: :
1TRUNC:
1/:
130:
1TO_NUMBER:
11.5:
1UPDATE TASK_ASSIGNMENTS SET:n                     RESOURCE_ID = h_res_id, RES+
1OURCE_TYPE='0', PROJECT_ASSIGNMENT_ID =:n                     CASE WHEN h_ass+
1igned = 0 THEN NuLL ELSE h_prj_assignment_id END,:n                     REGUL+
1AR_COST = CASE WHEN h_donot_replace_cost = 0 THEN h_reg_cost  ELSE REGULAR_CO+
1ST END,:n                     SPECIAL_COST = CASE WHEN h_donot_replace_cost =+
1 0 THEN h_spec_cost ELSE SPECIAL_COST END,:n                     REGULAR_RATE+
1 = CASE WHEN h_donot_replace_rate = 0 THEN h_reg_sale  ELSE REGULAR_RATE END,+
1:n                     SPECIAL_RATE = CASE WHEN h_donot_replace_rate = 0 THEN+
1 h_spec_sale ELSE SPECIAL_RATE END,:n                     ROLLUP_BITS  = PMO_+
1STPU.BIT_OR(ROLLUP_BITS, PMO_CNST.SC_LABOR_BIT):n                     WHERE T+
1SK_ASSIGNMENT_ID = h_tsk_assignment_id:
12377:
1           EXCEPTION:: SP_A_RESTOPROF(2378) :: cplan.sql(11024) :: :
12419:
1           EXCEPTION:: SP_A_RESTOPROF(2420) :: cplan.sql(11066) :: :
12425:
1        RETURN_ERROR:: SP_A_RESTOPROF(2426) :: cplan.sql(11072) :: :
12428:
1                EXIT:: SP_A_RESTOPROF(2429) :: cplan.sql(11075) :: :
12440:
1           EXCEPTION:: SP_A_RESTOPROF(2441) :: cplan.sql(11087) :: :
12446:
1        RETURN_ERROR:: SP_A_RESTOPROF(2447) :: cplan.sql(11093) :: :
12449:
1                EXIT:: SP_A_RESTOPROF(2450) :: cplan.sql(11096) :: :
1UPDATE TMT_WBS SET ASSIGN_NAMES = REPLACE(ASSIGN_NAMES,h_profile_name || ';',+
1'') WHERE ELEMENT_ID=h_task_id:
12473:
1           EXCEPTION:: SP_A_RESTOPROF(2474) :: cplan.sql(11120) :: :
1C:
1TMT_COMPETENCIES:
1P:
1INSERT INTO RESOURCE_ASSIGN_ROLES:n                  SELECT h_tsk_assignment_+
1id, c.ELEMENT_ID, c.PROFICIENCY_LEVEL_ID, c.EXPERIENCE_ID, c.PREFERENCE_LEVEL+
1_ID, c.LAST_USED_DATETIME, '0':n                  FROM TMT_COMPETENCIES c JOI+
1N PROFILES p ON c.ELEMENT_ID = p.ROLE_ID WHERE p.PROFILE_ID = h_profile_id:
12493:
1           EXCEPTION:: SP_A_RESTOPROF(2494) :: cplan.sql(11140) :: :
1PRIMARY_ROLE:
1INSERT INTO RESOURCE_ASSIGN_ROLES:n                  SELECT h_tsk_assignment_+
1id, ROLE_ID, PROFICIENCY_LEVEL_ID, EXPERIENCE_ID, PREFERENCE_LEVEL_ID, LAST_U+
1SED_DATETIME, PRIMARY_ROLE:n                  FROM RESOURCE_ASSIGN_ROLES WHER+
1E RES_ASSIGNMENT_ID = h_profile_id:
12513:
1           EXCEPTION:: SP_A_RESTOPROF(2514) :: cplan.sql(11160) :: :
1INSERT INTO RESOURCE_ASSIGN_SKILLS:n                  SELECT h_tsk_assignment+
1_id, SKILL_ID, PROFICIENCY_LEVEL_ID, EXPERIENCE_ID, PREFERENCE_LEVEL_ID, LAST+
1_USED_DATETIME, PRIMARY_SKILL:n                  FROM RESOURCE_ASSIGN_SKILLS +
1WHERE RES_ASSIGNMENT_ID = h_profile_id:
12532:
1           EXCEPTION:: SP_A_RESTOPROF(2533) :: cplan.sql(11179) :: :
1FC_AFTER_REPLACE_RES_ASSIGN:
1UPDATE EFFORT_WEEK SET RESOURCE_ID = h_res_id:n                  WHERE PROJEC+
1T_ID = h_project_id AND TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
12559:
1           EXCEPTION:: SP_A_RESTOPROF(2560) :: cplan.sql(11206) :: :
1ACTUAL_REGULAR_COST:
1ACTUAL_SPECIAL_COST:
1ACTUAL_REGULAR_RATE:
1ACTUAL_SPECIAL_RATE:
1UPDATE SUMMARY_TIMESHEETS SET RESOURCE_ID = h_res_id,:n                     A+
1CTUAL_REGULAR_COST = h_reg_cost  ,:n                     ACTUAL_SPECIAL_COST +
1= h_spec_cost ,:n                     ACTUAL_REGULAR_RATE = h_reg_sale  ,:n  +
1                   ACTUAL_SPECIAL_RATE = h_spec_sale ,:n                     +
1REC_USER = h_rec_user, REC_DATETIME = SYSTIMESTAMP:n                     WHER+
1E TSK_ASSIGNMENT_ID = h_id:
12584:
1           EXCEPTION:: SP_A_RESTOPROF(2585) :: cplan.sql(11231) :: :
1UPDATE SUMMARY_TIMESHEETS SET RESOURCE_ID = h_res_id,:n                     A+
1CTUAL_REGULAR_COST = h_reg_cost  ,:n                     ACTUAL_SPECIAL_COST +
1= h_spec_cost ,:n                     REC_USER = h_rec_user, REC_DATETIME = S+
1YSTIMESTAMP:n                     WHERE TSK_ASSIGNMENT_ID = h_id:
12605:
1           EXCEPTION:: SP_A_RESTOPROF(2606) :: cplan.sql(11252) :: :
1UPDATE SUMMARY_TIMESHEETS SET RESOURCE_ID = h_res_id,:n                     A+
1CTUAL_REGULAR_RATE = h_reg_sale  ,:n                     ACTUAL_SPECIAL_RATE +
1= h_spec_sale ,:n                     REC_USER = h_rec_user, REC_DATETIME = S+
1YSTIMESTAMP:n                     WHERE TSK_ASSIGNMENT_ID = h_id:
12628:
1           EXCEPTION:: SP_A_RESTOPROF(2629) :: cplan.sql(11275) :: :
1UPDATE SUMMARY_TIMESHEETS SET RESOURCE_ID = h_res_id,:n                     R+
1EC_USER = h_rec_user, REC_DATETIME = SYSTIMESTAMP:n                     WHERE+
1 TSK_ASSIGNMENT_ID = h_id:
12649:
1           EXCEPTION:: SP_A_RESTOPROF(2650) :: cplan.sql(11296) :: :
1FC_D_RA_AFTER_REPLACE:
12687:
1           EXCEPTION:: SP_A_RESTOPROF(2688) :: cplan.sql(11334) :: :
1>=:
12733:
1      RETURN_INVALID:: SP_A_RESTOPROF(2734) :: cplan.sql(11380) :: :
12736:
1                EXIT:: SP_A_RESTOPROF(2737) :: cplan.sql(11383) :: :
12741:
1        RETURN_ERROR:: SP_A_RESTOPROF(2742) :: cplan.sql(11388) :: :
12744:
1                EXIT:: SP_A_RESTOPROF(2745) :: cplan.sql(11391) :: :
1EXECUTE:
1IMMEDIATE:
1DELETE FROM PMO_TMP_PA_SUM:
1PMO_TMP_PA_SUM:
1PARENT_ID:
1INSERT INTO PMO_TMP_PA_SUM SELECT DAY_YEAR, SUM(SCHED_MIN):n               FR+
1OM TASK_DAY_OF_YEAR:n               WHERE PROJECT_ID = h_project_id AND PAREN+
1T_ID = h_prj_assignment_id:n               GROUP BY DAY_YEAR:
12768:
1           EXCEPTION:: SP_A_RESTOPROF(2769) :: cplan.sql(11415) :: :
1SC_BIT_30:
12807:
1        RETURN_ERROR:: SP_A_RESTOPROF(2808) :: cplan.sql(11454) :: :
12810:
1                EXIT:: SP_A_RESTOPROF(2811) :: cplan.sql(11457) :: :
12815:
1        RETURN_ERROR:: SP_A_RESTOPROF(2816) :: cplan.sql(11462) :: :
12818:
1                EXIT:: SP_A_RESTOPROF(2819) :: cplan.sql(11465) :: :
1UPDATE TASK_ASSIGNMENTS SET RES_ASSIGNMENT_ID = h_prj_assign_id,:n           +
1       RESOURCE_ID  = h_res_id, RESOURCE_TYPE = '0',:n                  REGUL+
1AR_COST = CASE WHEN h_donot_replace_rate = 0 THEN h_reg_cost  * h_rate_echang+
1e ELSE REGULAR_COST END,:n                  SPECIAL_COST = CASE WHEN h_donot_+
1replace_rate = 0 THEN h_spec_cost * h_rate_echange ELSE SPECIAL_COST END,:n  +
1                REGULAR_RATE = CASE WHEN h_donot_replace_cost = 0 THEN h_reg_+
1sale  * h_rate_echange ELSE REGULAR_RATE END,:n                  SPECIAL_RATE+
1 = CASE WHEN h_donot_replace_cost = 0 THEN h_spec_sale * h_rate_echange ELSE +
1SPECIAL_RATE END:n                  WHERE TSK_ASSIGNMENT_ID = h_prj_assignmen+
1t_id:
12841:
1           EXCEPTION:: SP_A_RESTOPROF(2842) :: cplan.sql(11488) :: :
1SELECT COUNT(*) INTO h_count FROM RESOURCE_ASSIGNMENTS:n         WHERE ELEMEN+
1T_ID = h_project_id AND RESOURCE_ID = h_profile_id AND RESOURCE_TYPE = '1':
12858:
1           EXCEPTION:: SP_A_RESTOPROF(2859) :: cplan.sql(11505) :: :
1UPDATE TMT_WBS SET ASSIGN_NAMES = REPLACE(ASSIGN_NAMES,h_profile_name || ';',+
1''):n            WHERE PROJECT_ID = h_project_id AND ELEMENT_ID = h_project_i+
1d:
12878:
1           EXCEPTION:: SP_A_RESTOPROF(2879) :: cplan.sql(11525) :: :
1SC_ASSIGNMENT_BIT:
1UPDATE TMT_WBS SET ROLLUP_BITS = PMO_STPU.BIT_OR(ROLLUP_BITS, PMO_CNST.SC_ASS+
1IGNMENT_BIT) WHERE ELEMENT_ID = h_project_id:
12901:
1           EXCEPTION:: SP_A_RESTOPROF(2902) :: cplan.sql(11548) :: :
1SELECT COUNT(*) INTO h_count FROM TASK_ASSIGNMENTS:n            WHERE PROJECT+
1_ID = h_project_id AND PROJECT_ASSIGNMENT_ID = h_old_prj_assign_id:
12917:
1           EXCEPTION:: SP_A_RESTOPROF(2918) :: cplan.sql(11564) :: :
1DELETE FROM RESOURCE_ASSIGNMENTS WHERE PROJECT_ID = h_project_id AND:n       +
1        ELEMENT_ID = h_project_id AND RESOURCE_ID = h_profile_id AND RESOURCE+
1_TYPE = '1':
12937:
1           EXCEPTION:: SP_A_RESTOPROF(2938) :: cplan.sql(11584) :: :
12954:
1           EXCEPTION:: SP_A_RESTOPROF(2955) :: cplan.sql(11601) :: :
13:
1BEST:
1SELECT PLANNED_START, PLANNED_FINISH, BEST, TO_DATE(SubStr(BAK_START_DT, 1, 1+
10)), TO_DATE(SubStr(BAK_FINISH_DT, 1, 10)), BILLABLE, CAPITAL_EXPENSE, REGULA+
1R_COST, REGULAR_RATE:n            INTO h_start_DT, h_finish_DT, h_effort, h_s+
1tart_D, h_finish_D, h_billable, h_capital_expense, h_old_cost, h_old_sale:n  +
1          FROM TASK_ASSIGNMENTS WHERE TSK_ASSIGNMENT_ID = h_old_prj_assign_id:
12976:
1           EXCEPTION:: SP_A_RESTOPROF(2977) :: cplan.sql(11623) :: :
1ESTIMATED_PLANNED_START:
1ESTIMATED_PLANNED_FINISH:
1ESTIMATED_PLANNED_EFFORT:
1ESTIMATED_PLANNED_COST:
1ESTIMATED_PLANNED_REVENUE:
1UPDATE PROJECT_ASSIGNMENTS SET:n                  ESTIMATED_PLANNED_START = h+
1_start_DT,:n                  ESTIMATED_PLANNED_FINISH = h_finish_DT,:n      +
1            ESTIMATED_PLANNED_EFFORT = h_effort,:n                  ESTIMATED+
1_PLANNED_COST = (h_effort/60.00) * h_old_cost,:n                  ESTIMATED_P+
1LANNED_REVENUE = 0.00:n                  WHERE PROJECT_ID = h_project_id AND +
1RESOURCE_ID = h_profile_id:
13002:
1           EXCEPTION:: SP_A_RESTOPROF(3003) :: cplan.sql(11649) :: :
1UPDATE PROJECT_ASSIGNMENTS SET:n                  ESTIMATED_PLANNED_START = h+
1_start_DT,:n                  ESTIMATED_PLANNED_FINISH = h_finish_DT,:n      +
1            ESTIMATED_PLANNED_EFFORT = h_effort,:n                  ESTIMATED+
1_PLANNED_COST = (h_effort/60.00) * h_old_cost,:n                  ESTIMATED_P+
1LANNED_REVENUE = (h_effort/60.00) * h_old_sale:n                  WHERE PROJE+
1CT_ID = h_project_id AND RESOURCE_ID = h_profile_id:
13025:
1           EXCEPTION:: SP_A_RESTOPROF(3026) :: cplan.sql(11672) :: :
1SELECT COUNT(*) INTO h_count FROM TASK_ASSIGNMENTS:n            WHERE PROJECT+
1_ID = h_project_id AND PROJECT_ASSIGNMENT_ID = h_prj_assignment_id:n         +
1   AND RESOURCE_ID = h_profile_id AND RESOURCE_TYPE = '1':
13062:
1           EXCEPTION:: SP_A_RESTOPROF(3063) :: cplan.sql(11709) :: :
1UPDATE TASK_ASSIGNMENTS:n               SET PROJECT_ASSIGNMENT_ID = Null:n   +
1            WHERE PROJECT_ID = h_project_id AND PROJECT_ASSIGNMENT_ID = h_prj+
1_assignment_id:n               AND RESOURCE_ID = h_profile_id AND RESOURCE_TY+
1PE = '1':
13084:
1           EXCEPTION:: SP_A_RESTOPROF(3085) :: cplan.sql(11731) :: :
1UPDATE TASK_DAY_OF_YEAR:n               SET PARENT_ID = TSK_ASSIGNMENT_ID:n  +
1             WHERE PROJECT_ID = h_project_id AND PARENT_ID = h_prj_assignment+
1_id:n               AND RESOURCE_ID = h_profile_id:
13104:
1           EXCEPTION:: SP_A_RESTOPROF(3105) :: cplan.sql(11751) :: :
1SELECT PLANNED_START, PLANNED_FINISH, BEST, TO_DATE(SubStr(BAK_START_DT, 1, 1+
10)), TO_DATE(SubStr(BAK_FINISH_DT, 1, 10)), BILLABLE, CAPITAL_EXPENSE, REGULA+
1R_COST, REGULAR_RATE:n         INTO h_start_DT, h_finish_DT, h_effort, h_star+
1t_D, h_finish_D, h_billable, h_capital_expense, h_reg_cost, h_reg_sale:n     +
1    FROM TASK_ASSIGNMENTS WHERE TSK_ASSIGNMENT_ID = h_prj_assignment_id:
13125:
1           EXCEPTION:: SP_A_RESTOPROF(3126) :: cplan.sql(11772) :: :
1UPDATE PROJECT_ASSIGNMENTS SET:n               ESTIMATED_PLANNED_START  = h_s+
1tart_DT,:n               ESTIMATED_PLANNED_FINISH = h_finish_DT,:n           +
1    ESTIMATED_PLANNED_EFFORT = h_effort,:n               ESTIMATED_PLANNED_CO+
1ST   = (h_effort/60.00) * h_reg_cost,:n               ESTIMATED_PLANNED_REVEN+
1UE = 0.00:n               WHERE PROJECT_ID = h_project_id AND RESOURCE_ID = h+
1_res_id:
13151:
1           EXCEPTION:: SP_A_RESTOPROF(3152) :: cplan.sql(11798) :: :
1UPDATE PROJECT_ASSIGNMENTS SET:n               ESTIMATED_PLANNED_START  = h_s+
1tart_DT,:n               ESTIMATED_PLANNED_FINISH = h_finish_DT,:n           +
1    ESTIMATED_PLANNED_EFFORT = h_effort,:n               ESTIMATED_PLANNED_CO+
1ST   = (h_effort/60.00) * h_reg_cost,:n               ESTIMATED_PLANNED_REVEN+
1UE = (h_effort/60.00) * h_reg_sale:n               WHERE PROJECT_ID = h_proje+
1ct_id AND RESOURCE_ID = h_res_id:
13174:
1           EXCEPTION:: SP_A_RESTOPROF(3175) :: cplan.sql(11821) :: :
1FC_ROLLUP:
13200:
1       RETURN_STATUS:: SP_A_RESTOPROF(3201) :: cplan.sql(11847) :: :
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
13207:
1           EXCEPTION:: SP_A_RESTOPROF(3208) :: cplan.sql(11854) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1ERROR:
1ID:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
13219:
1           EXCEPTION:: SP_A_RESTOPROF(3220) :: cplan.sql(11866) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
4bc9
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 1c 81 b0 a3 a0 1c
81 b0 a3 a0 1c 81 b0 a3
a0 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 1c 81 b0
a3 a0 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 1c 81 b0
a3 a0 1c 81 b0 a3 a0 1c
81 b0 a3 a0 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 1c 51 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 81 b0
a3 a0 1c 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 1c :3 a0
51 a5 b a5 b 5a 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a0 f4 b4 bf
c8 :5 a0 12a bd b7 11 a4 b1
a0 f4 b4 bf c8 :9 a0 12a bd
b7 11 a4 b1 a0 f4 b4 bf
c8 :6d a0 12a bd b7 11 a4 b1
a3 :2 a0 6b 1c 81 b0 :2 a0 6b
:2 a0 6b 6e a5 b a 10 :2 a0
6b 6e :2 a0 6b 6e a5 b 6e
7e a0 b4 2e 6e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :3 a0 a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
:3 a0 a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e :3 a0 a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e :3 a0 a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e :3 a0
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e :3 a0 a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e :3 a0 a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e :3 a0 a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 d :2 a0 d :2 a0 d
:2 a0 d :2 a0 d :2 a0 d :4 a0 51
a5 b :2 a0 6b a5 b d :2 a0
51 a5 b a0 7e a0 6b b4
2e 5a :2 a0 51 a5 b a0 7e
a0 6b b4 2e 5a 52 10 a0
51 d b7 19 3c :2 a0 d a0
6e d a0 6e d a0 51 d
a0 6e d a0 4d d a0 4d
d :2 a0 e9 dd b3 :2 a0 e9 d3
:2 a0 f :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c :3 a0 6b
d :2 a0 e9 c1 :2 a0 6b a0 d
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 51 a5
b 7e 51 b4 2e :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b :2 a0 a5 57 b7 19 3c :11 a0
12a :2 a0 6b a0 d b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 6b a0 7e a0 6b
b4 2e 5a :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b :2 a0
a5 57 b7 19 3c a0 51 d
:5 a0 12a :2 a0 6b a0 d b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 51 a5 b 7e
51 b4 2e :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b :2 a0
a5 57 b7 19 3c :25 a0 12a :2 a0
6b a0 d b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 6b a0 7e a0 6b b4 2e
5a :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b :2 a0 a5 57
b7 19 3c :7 a0 12a :2 a0 6b a0
d b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
a0 7e a0 6b b4 2e 5a :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b :2 a0 a5 57 b7 19
3c :5 a0 12a :2 a0 6b a0 d b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 6b a0 6e
a5 b 7e 51 b4 2e a0 6e
d b7 19 3c :2 a0 6b a0 7e
a0 6b b4 2e 5a :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b :2 a0 a5 57 b7 19 3c :2 a0
d :4 a0 51 a5 b 51 a5 b
d :4 a0 51 a5 b 51 a5 b
d :4 a0 51 a5 b 51 a5 b
d a0 7e 51 b4 2e :2 a0 51
a5 b 7e 51 b4 2e :b a0 12a
:2 a0 6b a0 d b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f a0 b7 :2 a0 51 a5 b 7e
51 b4 2e :b a0 12a :2 a0 6b a0
d b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 :2 19
3c :2 a0 51 a5 b 7e 51 b4
2e :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b :2 a0 a5 57
b7 19 3c b7 :b a0 12a :2 a0 6b
a0 d b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :b a0
12a :2 a0 6b a0 d b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :3 a0 51 a5 b a5 b
5a 7e 51 b4 2e :2 a0 51 a5
b 7e 51 b4 2e 5a :2 a0 51
a5 b 7e 51 b4 2e 5a 52
10 5a a 10 :a a0 12a :2 a0 6b
a0 d b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
51 a5 b 7e 51 b4 2e :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b :2 a0 a5 57 b7 19
3c b7 19 3c b7 :2 19 3c a0
6e d a0 6e d a0 6e d
a0 4d d a0 4d d :2 a0 e9
dd b3 :2 a0 e9 d3 :2 a0 f :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c :2 a0 6b a0 7e a0
6b b4 2e 5a a0 51 d b7
a0 51 d b7 :2 19 3c :2 a0 e9
c1 :2 a0 6b a0 d b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 51 a5 b 7e 51
b4 2e :b a0 12a :2 a0 6b a0 d
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 51 a5
b 7e 51 b4 2e a0 51 d
:d a0 12a :2 a0 6b a0 d b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 6b a0 7e a0
6b b4 2e 5a :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :4 a0 6b a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
:2 a0 a5 57 a0 b7 a0 7e b4
2e :2 5a a0 7e b4 2e :2 5a a
10 :2 a0 6b :2 a0 51 a5 b 7e
51 b4 2e 5a :2 a0 6b :2 a0 51
a5 b 7e 51 b4 2e 5a 52
10 :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b :2 a0 a5 57
b7 19 3c b7 :2 19 3c b7 19
3c :2 a0 51 a5 b 7e 51 b4
2e a0 51 d :2 a0 d b7 :b a0
12a :2 a0 6b a0 d b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 6b a0 7e a0 6b
b4 2e 5a a0 6e d :2 a0 b4
2e d :2 a0 51 :2 a0 51 a5 b
:2 a0 6b a0 a5 b d :3 a0 6b
d a0 6e d a0 51 d :9 a0
a5 b d :4 a0 51 a5 b a5
b d :1a a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :5 a0 12a :2 a0 6b a0
d b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
:2 a0 a5 b 7e 51 b4 2e a0
51 d b7 :c a0 12a :2 a0 6b a0
d b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 :2 19
3c :2 a0 51 a5 b 7e 51 b4
2e :a a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :11 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 :11 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 :2 19 3c
a0 b7 :2 a0 6b a0 7e a0 6b
b4 2e 5a :6 a0 12a :2 a0 6b a0
d b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 51
a5 b a0 7e a0 6b b4 2e
:2 a0 51 :2 a0 51 a5 b :2 a0 6b
a0 a5 b d :a a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :3 a0 a5 b
d a0 b7 :3 a0 51 a5 b :2 a0
6b a5 b 5a a0 7e a0 6b
b4 2e :b a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :3 a0 a5 b d b7
19 :b a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :3 a0 a5 b d b7 :2 19
3c b7 :2 19 3c b7 :2 19 3c b7
:2 a0 d b7 :2 19 3c a0 6e d
a0 6e d a0 6e d :2 a0 b4
2e d :2 a0 51 a5 b 7e 51
b4 2e 5a :2 a0 51 a5 b 7e
51 b4 2e 5a 52 10 :c a0 a5
b d b7 19 3c :16 a0 12a :2 a0
6b a0 d b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 6b a0 7e a0 6b b4 2e
5a a0 51 d b7 19 3c a0
51 d a0 51 d a0 4d d
:7 a0 12a :2 a0 6b a0 d b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 6b :2 a0 a5 b
7e 51 b4 2e :a a0 12a :2 a0 6b
a0 d b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
51 a5 b 7e 51 b4 2e :2 a0
d b7 a0 51 d b7 :2 19 3c
b7 19 3c :2 a0 51 a5 b 7e
51 b4 2e :2 a0 6b :2 a0 a5 b
7e 51 b4 2e :28 a0 12a :2 a0 6b
a0 d b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
d a0 51 d :2 a0 51 a5 b
7e 51 b4 2e :2 a0 51 a5 b
a0 7e a0 51 a5 b b4 2e
5a :2 a0 51 a5 b a0 7e a0
51 a5 b b4 2e 5a 52 10
:2 a0 51 a5 b 7e 51 b4 2e
5a :3 a0 51 a5 b :2 a0 6b a5
b 5a 7e 51 b4 2e 5a a
10 :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b :2 a0 a5 57
b7 a0 51 d :2 a0 51 a5 b
7e 51 b4 2e a0 51 d b7
19 3c b7 :2 19 3c b7 19 3c
:2 a0 d :2 a0 d :2 a0 d :2 a0 d
:2 a0 d :2 a0 d :2 a0 d :2 a0 d
:2 a0 d b7 19 3c :2 a0 6b a0
7e a0 6b b4 2e 5a a0 7e
b4 2e :2 5a a 10 :2 a0 :2 51 a5
b 7e 6e b4 2e a0 7e 51
b4 2e d :2 a0 6b :b a0 a5 b
d b7 19 3c :2 a0 51 a5 b
7e 51 b4 2e :3 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :5 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 d
:8 a0 12a :2 a0 6b a0 d b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 6b :2 a0 51 a5
b 7e 51 b4 2e :a a0 12a :2 a0
6b a0 d b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 19 3c b7 :2 a0 51 a5 b
7e 51 b4 2e 5a :2 a0 51 a5
b 7e 51 b4 2e 5a a 10
:3 a0 51 a5 b 7e :2 a0 51 a5
b b4 2e d :3 a0 51 a5 b
7e :2 a0 51 a5 b b4 2e d
:3 a0 51 a5 b 7e :2 a0 51 a5
b b4 2e d :3 a0 51 a5 b
7e :2 a0 51 a5 b b4 2e d
:2 a0 51 a5 b 7e 51 b4 2e
:1e a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 :22 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 :2 19 3c a0 b7
:2 a0 51 a5 b 7e 51 b4 2e
:3 a0 51 a5 b 7e :2 a0 51 a5
b b4 2e d :3 a0 51 a5 b
7e :2 a0 51 a5 b b4 2e d
:1a a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f a0 b7 19 :2 a0 51 a5 b
7e 51 b4 2e :3 a0 51 a5 b
7e :2 a0 51 a5 b b4 2e d
:3 a0 51 a5 b 7e :2 a0 51 a5
b b4 2e d :2 a0 51 a5 b
7e 51 b4 2e :16 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 :1a a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
:2 19 3c b7 19 :c a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 :2 19 3c
:5 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :b a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 :2 19 3c a0 51 d
:3 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :5 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 51 a5 b 7e 51
b4 2e 5a :2 a0 51 a5 b 7e
51 b4 2e 5a a 10 a0 51
d a0 51 d :2 a0 6b a0 51
a5 b 7e 51 b4 2e a0 51
d b7 a0 51 d b7 :2 19 3c
:2 a0 51 a5 b 7e 51 b4 2e
a0 51 d b7 19 3c :6 a0 51
a5 b :2 a0 51 a5 b :2 a0 51
a5 b :2 a0 51 a5 b :2 a0 51
a5 b :2 a0 51 a5 b :2 a0 51
a5 b :2 a0 51 a5 b :3 a0 a5
b d :2 a0 51 a5 b a0 7e
a0 6b b4 2e :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :4 a0 6b a5 b 6e
a5 b b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
a0 a5 57 a0 b7 :2 a0 51 a5
b 7e 51 b4 2e :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :3 a0 a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 51
a5 b :2 a0 a5 57 b7 :2 19 3c
:2 a0 51 a5 b 7e 51 b4 2e
:3 a0 6b d b7 :3 a0 6b :2 a0 51
a5 b :2 a0 6b a5 b d b7
:2 19 3c a0 51 d :1e a0 :4 51 a5
b d :2 a0 51 a5 b 7e 51
b4 2e :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b :2 a0 a5
57 a0 b7 :2 a0 51 a5 b 7e
51 b4 2e :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b :2 a0
a5 57 b7 19 a0 51 d :7 a0
51 a5 b :2 a0 51 a5 b a5
b d b7 :2 19 3c b7 19 3c
b7 19 3c a0 b7 :2 a0 :2 51 a5
b 7e 6e b4 2e :1a a0 12a :2 a0
6b a0 d b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 6b a0 7e a0 6b b4 2e
5a a0 7e b4 2e :2 5a a 10
a0 7e 51 b4 2e d :2 a0 6b
:b a0 a5 b d b7 19 3c b7
19 :c a0 12a :2 a0 6b a0 d b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 :2 19 3c a0
b7 :2 a0 :2 51 a5 b 7e 6e b4
2e :1a a0 12a :2 a0 6b a0 d b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 6b a0 7e
a0 6b b4 2e 5a a0 7e b4
2e :2 5a a 10 a0 7e 51 b4
2e d :2 a0 6b :b a0 a5 b d
b7 19 3c b7 19 :c a0 12a :2 a0
6b a0 d b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 :2 19 3c a0 7e b4 2e :2 5a
:2 a0 51 a5 b 7e 51 b4 2e
5a a 10 :2 a0 51 a5 b 7e
51 b4 2e 5a a 10 a0 6e
d :2 a0 b4 2e d :2 a0 51 a5
b 7e 51 b4 2e :3 a0 51 a5
b d b7 19 3c :2 a0 51 a5
b 7e 51 b4 2e 5a :2 a0 51
a5 b 7e 51 b4 2e 5a 52
10 :2 a0 51 a5 b 7e 51 b4
2e 5a :2 a0 51 a5 b 7e 51
b4 2e 5a a 10 :3 a0 51 a5
b 7e :2 a0 51 a5 b b4 2e
d :3 a0 51 a5 b 7e :2 a0 51
a5 b b4 2e d :3 a0 51 a5
b 7e :2 a0 51 a5 b b4 2e
d :3 a0 51 a5 b 7e :2 a0 51
a5 b b4 2e d :34 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f a0 b7
:2 a0 51 a5 b 7e 51 b4 2e
:3 a0 51 a5 b 7e :2 a0 51 a5
b b4 2e d :3 a0 51 a5 b
7e :2 a0 51 a5 b b4 2e d
:34 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 19 :3 a0 51 a5 b 7e
:2 a0 51 a5 b b4 2e d :3 a0
51 a5 b 7e :2 a0 51 a5 b
b4 2e d :34 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 :2 19 3c b7
:34 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 :2 19 3c a0 51 d b7
19 3c :3 a0 7e 6e b4 2e :2 51
a5 b d a0 6e d :2 a0 d
:5 a0 12a :2 a0 6b a0 d b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f a0 51 d a0 51
d a0 51 d a0 7e 51 b4
2e 5a :2 a0 51 a5 b 7e 51
b4 2e 5a a 10 :35 a0 12a :2 a0
6b a0 d b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 19 3c :2 a0 d :2 a0 e9 dd
b3 :17 a0 e9 d3 5 :2 a0 f :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c :2 a0 6b a0 7e a0
6b b4 2e 5a a0 2b b7 19
3c :2 a0 51 a5 b 7e 51 b4
2e :3 a0 51 a5 b d :3 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :3 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:3 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :5 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :3 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :3 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 :9 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :a a0 12a
:2 a0 6b a0 d b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6b a0 7e a0 6b b4
2e 5a :2 a0 51 a5 b 7e 51
b4 2e :2 a0 d b7 19 3c :c a0
12a :2 a0 6b a0 d b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 6b a0 7e a0 6b
b4 2e 5a :3 a0 51 a5 b :2 a0
6b a5 b 5a a0 7e a0 6b
b4 2e a0 51 d :8 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f a0 b7
:2 a0 51 a5 b a0 7e a0 6b
b4 2e :2 a0 51 :2 a0 51 a5 b
:2 a0 6b a0 a5 b d :d a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
19 :10 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 :2 19 3c :2 a0 6b a0
7e a0 6b b4 2e 5a :2 a0 51
a5 b 7e 51 b4 2e 5a a
10 :3 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 19 3c b7 :22 a0 12a
:2 a0 6b a0 d b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6b a0 7e a0 6b b4
2e 5a a0 7e b4 2e :2 5a a
10 :2 a0 51 :2 a0 51 a5 b :2 a0
6b a0 a5 b d :3 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :b a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :8 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 :2 a0 51 :2 a0 51 a5 b :2 a0
6b a0 a5 b d :8 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :b a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
:2 19 3c b7 :2 19 3c :2 a0 51 a5
b 7e 51 b4 2e :2 a0 51 a5
b 7e 51 b4 2e 5a a0 7e
b4 2e :2 5a a 10 :7 a0 12a :2 a0
6b a0 d b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 6b a0 7e a0 6b b4 2e
5a :2 a0 51 a5 b 7e 51 b4
2e 5a a 10 :5 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f a0 b7 :2 a0
6b a0 7e a0 6b b4 2e 5a
:2 a0 51 a5 b 7e 51 b4 2e
5a a 10 :2 a0 e9 c1 :2 a0 6b
a0 d b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b :2 a0 a5 57 b7 :2 19
3c b7 19 3c a0 7e 51 b4
2e d :2 a0 6b :b a0 a5 b d
:5 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f a0 6e d a0 7e 51 b4
2e :2 a0 d :2 a0 d :2 a0 d :2 a0
d :2 a0 d :2 a0 d :2 a0 d :2 a0
d :2 a0 d :3 a0 51 a5 b :2 a0
6b a5 b 5a 7e 51 b4 2e
5a :2 a0 51 a5 b a0 7e a0
51 a5 b b4 2e 5a :2 a0 51
a5 b a0 7e a0 51 a5 b
b4 2e 5a 52 10 5a a 10
5a :2 a0 51 a5 b 7e 51 b4
2e :25 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 :27 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 :2 19 3c b7
:21 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 :2 19 3c :2 a0 51 a5 b
7e 51 b4 2e 5a :2 a0 51 a5
b 7e 51 b4 2e 5a a 10
a0 51 d a0 b7 :2 a0 51 a5
b 7e 51 b4 2e :3 a0 51 a5
b d b7 :2 19 3c :6 a0 51 a5
b :2 a0 51 a5 b :2 a0 51 a5
b :2 a0 51 a5 b :2 a0 51 a5
b :2 a0 51 a5 b :2 a0 51 a5
b :2 a0 51 a5 b :3 a0 a5 b
d :2 a0 51 a5 b a0 7e a0
6b b4 2e :2 a0 e9 c1 :2 a0 6b
a0 d b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b a0 a5 57 a0 b7
:2 a0 51 a5 b 7e 51 b4 2e
:2 a0 e9 c1 :2 a0 6b a0 d b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 51 a5
b :2 a0 a5 57 b7 :2 19 3c b7
:2 a0 51 a5 b 7e 51 b4 2e
:2 a0 51 a5 b 7e 51 b4 2e
a 10 :2 a0 51 a5 b 7e 51
b4 2e a 10 a0 51 d :3 a0
51 a5 b d b7 19 3c :2 a0
51 a5 b 7e 51 b4 2e 5a
:2 a0 51 a5 b a0 7e a0 51
a5 b b4 2e 5a 52 10 :3 a0
51 a5 b d b7 :4 a0 51 a5
b 7e :2 a0 51 a5 b b4 2e
a5 b d b7 :2 19 3c :2 a0 51
a5 b 7e 51 b4 2e :3 a0 51
a5 b 7e 51 b4 2e d b7
:5 a0 51 a5 b a5 b 7e 51
b4 2e a5 b d b7 :2 19 3c
:1f a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 :2 19 3c a0 51 d a0
51 d a0 51 d :2 a0 51 a5
b 7e 51 b4 2e :2 a0 51 a5
b 7e 51 b4 2e :2 a0 51 a5
b 7e 51 b4 2e 52 10 5a
a 10 :3 a0 6b d b7 :3 a0 6b
:2 a0 51 a5 b :2 a0 6b a5 b
d b7 :2 19 3c a0 51 d a0
51 d :1e a0 :4 51 a5 b d :2 a0
51 a5 b 7e 51 b4 2e :2 a0
e9 c1 :2 a0 6b a0 d b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b :2 a0
a5 57 a0 b7 :2 a0 51 a5 b
7e 51 b4 2e :2 a0 e9 c1 :2 a0
6b a0 d b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b :2 a0 a5 57 b7
:2 19 3c :7 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :18 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :b a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :b a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :3 a0 51
a5 b 7e 51 b4 2e d :3 a0
51 a5 b 7e :2 a0 51 a5 b
b4 2e d a0 6e d :5 a0 a5
b d a0 6e d :5 a0 a5 b
d :7 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 51 a5 b 7e 51
b4 2e 5a :2 a0 51 a5 b 7e
51 b4 2e 5a a 10 :11 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f a0
b7 :2 a0 51 a5 b 7e 51 b4
2e :d a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :3 a0 51 a5 b d a0
b7 19 :2 a0 51 a5 b 7e 51
b4 2e :d a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :3 a0 51 a5 b d
b7 19 :9 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :3 a0 51 a5 b d
:3 a0 51 a5 b d b7 :2 19 3c
b7 19 3c b7 19 3c b7 :2 19
3c :2 a0 6b :4 a0 a5 b d b7
a0 47 :2 a0 e9 c1 :2 a0 6b a0
d b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f a0 51
d :2 a0 51 a5 b 7e 51 b4
2e :2 a0 d :2 a0 51 a5 b a0
7e a0 51 a5 b b4 2e :3 a0
51 a5 b 7e :2 a0 51 a5 b
b4 2e d :2 a0 51 a5 b 7e
51 b4 2e 5a :2 a0 51 a5 b
7e 51 b4 2e 5a a 10 a0
7e b4 2e :2 5a a 10 :2 a0 d
:2 a0 d :2 a0 d :2 a0 d :2 a0 d
:2 a0 d :2 a0 d :2 a0 d :2 a0 51
a5 b 7e 51 b4 2e :2 a0 51
a5 b 7e 51 b4 2e a 10
a0 51 d a0 b7 :2 a0 51 a5
b 7e 51 b4 2e :3 a0 51 a5
b d b7 :2 19 3c :6 a0 51 a5
b :2 a0 51 a5 b :2 a0 51 a5
b :2 a0 51 a5 b :2 a0 51 a5
b :2 a0 51 a5 b :2 a0 51 a5
b :2 a0 51 a5 b :3 a0 a5 b
d :2 a0 51 a5 b a0 7e a0
6b b4 2e :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b a0
a5 57 a0 b7 :2 a0 51 a5 b
7e 51 b4 2e :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 51 a5
b :2 a0 a5 57 b7 :2 19 3c :2 a0
6e 11e 11d :2 a0 6b 51 d :a a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
a0 6e d a0 51 d a0 51
d a0 51 d a0 51 d :2 a0
51 a5 b 7e 51 b4 2e :2 a0
51 a5 b 7e 51 b4 2e :2 a0
51 a5 b 7e 51 b4 2e a
10 5a 52 10 :2 a0 51 a5 b
7e 51 b4 2e :2 a0 51 a5 b
7e 51 b4 2e a 10 :2 a0 51
a5 b 7e 51 b4 2e a 10
a0 51 d :3 a0 51 a5 b d
b7 19 3c :3 a0 6b :2 a0 51 a5
b :2 a0 6b a5 b d a0 51
d b7 a0 51 d b7 :2 19 3c
a0 51 d :1e a0 :4 51 a5 b d
:2 a0 51 a5 b 7e 51 b4 2e
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b :2 a0 a5 57 a0
b7 :2 a0 51 a5 b 7e 51 b4
2e :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b :2 a0 a5 57
b7 19 :1c a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 :2 19 3c b7 19
3c b7 19 3c :8 a0 12a :2 a0 6b
a0 d b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
51 a5 b 7e 51 b4 2e :9 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 19 3c b7 19 3c a0 51
d a0 7e b4 2e 5a :9 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
51 a5 b 7e 51 b4 2e :7 a0
12a :2 a0 6b a0 d b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 51 a5 b 7e 51
b4 2e :8 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :5 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 19 3c b7
19 3c :2 a0 51 a5 b 7e 51
b4 2e a0 51 d :5 a0 :2 51 a5
b d :19 a0 12a :2 a0 6b a0 d
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 6b a0
7e a0 6b b4 2e 5a :2 a0 51
a5 b 7e 51 b4 2e :f a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
:11 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 :2 19 3c :2 a0 :2 51 a5 b
7e 6e b4 2e 5a a0 51 d
:2 a0 6b :b a0 a5 b d b7 19
3c b7 19 3c a0 7e b4 2e
:2 5a :2 a0 6b :2 a0 a5 b 7e 51
b4 2e 5a a 10 a0 51 d
b7 19 3c b7 19 3c b7 19
3c :2 a0 51 a5 b 7e 51 b4
2e 5a a0 7e b4 2e :2 5a a
10 :2 a0 51 a5 b 7e 51 b4
2e :a a0 12a :2 a0 6b a0 d b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 51 a5 b
7e 51 b4 2e :9 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :9 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 19
3c b7 19 3c a0 51 d :5 a0
:2 51 a5 b d :19 a0 12a :2 a0 6b
a0 d b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
6b a0 7e a0 6b b4 2e 5a
:2 a0 51 a5 b 7e 51 b4 2e
:f a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 :11 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 :2 19 3c :2 a0 :2 51
a5 b 7e 6e b4 2e 5a :2 a0
51 a5 b 7e 51 b4 2e 5a
a 10 a0 51 d :2 a0 6b :b a0
a5 b d b7 19 3c b7 19
3c b7 19 3c :3 a0 a5 b d
:2 a0 6b 7e 51 b4 2e :2 a0 6b
51 d b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b :2 a0 a5
57 b7 :2 a0 6b :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 :2 a0 6b :2 6e 7e
:2 a0 6b b4 2e 7e 6e b4 2e
7e :2 a0 6b b4 2e a5 57 b7
19 3c :9 a0 12a e9 dd :2 a0 65
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
:7 a0 12a e9 dd :2 a0 65 b7 a4
b1 11 4f b7 a6 9 a4 b1
11 68 4f 1d 17 b5 
4bc9
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 5e
5a 30 66 6f 6b 59 77 84
80 56 8c 95 91 7f 9d aa
a6 7c b2 bb b7 a5 c3 d0
cc a2 d8 e1 dd cb e9 f6
f2 c8 fe 107 103 f1 10f 11c
118 ee 124 12d 129 117 135 114
13a 13e 142 146 149 14d 16a 155
159 15c 15d 165 154 187 175 151
179 17a 182 174 1a4 192 171 196
197 19f 191 1c1 1af 18e 1b3 1b4
1bc 1ae 1de 1cc 1ab 1d0 1d1 1d9
1cb 1fb 1e9 1c8 1ed 1ee 1f6 1e8
218 206 1e5 20a 20b 213 205 235
223 202 227 228 230 222 252 240
21f 244 245 24d 23f 26f 25d 23c
261 262 26a 25c 28c 27a 259 27e
27f 287 279 2a9 297 276 29b 29c
2a4 296 2c5 2b4 2b8 2c0 293 2dd
2cc 2d0 2d8 2b3 2f9 2e8 2ec 2f4
2b0 311 300 304 30c 2e7 32e 31c
2e4 320 321 329 31b 34a 339 33d
345 318 362 351 355 35d 338 37f
36d 335 371 372 37a 36c 39c 38a
369 38e 38f 397 389 3b8 3a7 3ab
3b3 386 3d0 3bf 3c3 3cb 3a6 3ec
3db 3df 3e7 3a3 404 3f3 3f7 3ff
3da 421 40f 3d7 413 414 41c 40e
43e 42c 40b 430 431 439 42b 45b
449 428 44d 44e 456 448 478 466
445 46a 46b 473 465 495 483 462
487 488 490 482 4b1 4a0 4a4 47f
4ac 49f 4cd 4bc 4c0 49c 4c8 4bb
4e9 4d8 4dc 4b8 4e4 4d7 505 4f4
4f8 4d4 500 4f3 521 510 514 4f0
51c 50f 53d 52c 530 50c 538 52b
559 548 54c 528 554 547 575 564
568 544 570 563 591 580 584 560
58c 57f 5ad 59c 5a0 57c 5a8 59b
5c9 5b8 5bc 598 5c4 5b7 5e5 5d4
5d8 5b4 5e0 5d3 601 5f0 5f4 5d0
5fc 5ef 61d 60c 610 5ec 618 60b
639 628 62c 608 634 627 655 644
648 624 650 643 671 660 664 640
66c 65f 68d 67c 680 65c 688 67b
6a9 698 69c 678 6a4 697 6c5 6b4
6b8 694 6c0 6b3 6e1 6d0 6d4 6b0
6dc 6cf 6fd 6ec 6f0 6cc 6f8 6eb
719 708 70c 6e8 714 707 735 724
728 704 730 723 751 740 744 720
74c 73f 76d 75c 760 73c 768 75b
789 778 77c 758 784 777 7a5 794
798 774 7a0 793 7c1 7b0 7b4 790
7bc 7af 7dd 7cc 7d0 7ac 7d8 7cb
7f9 7e8 7ec 7c8 7f4 7e7 815 804
808 7e4 810 803 831 820 824 800
82c 81f 84d 83c 840 81c 848 83b
869 858 85c 838 864 857 885 874
878 854 880 873 8a1 890 894 870
89c 88f 8bd 8ac 8b0 88c 8b8 8ab
8d9 8c8 8cc 8a8 8d4 8c7 8f5 8e4
8e8 8c4 8f0 8e3 912 900 8e0 904
905 90d 8ff 92f 91d 8fc 921 922
92a 91c 94b 93a 93e 919 946 939
967 956 95a 936 962 955 984 972
952 976 977 97f 971 9a0 98f 993
96e 99b 98e 9bd 9ab 98b 9af 9b0
9b8 9aa 9da 9c8 9a7 9cc 9cd 9d5
9c7 9f6 9e5 9e9 9c4 9f1 9e4 a12
a01 a05 9e1 a0d a00 a2e a1d a21
a29 9fd a46 a35 a39 a41 a1c a62
a51 a55 a19 a5d a50 a7e a6d a71
a4d a79 a6c a9a a89 a8d a69 a95
a88 ab6 aa5 aa9 a85 ab1 aa4 ad2
ac1 ac5 aa1 acd ac0 aee add ae1
abd ae9 adc b0a af9 afd ad9 b05
af8 b26 b15 b19 af5 b21 b14 b42
b31 b35 b11 b3d b30 b5e b4d b51
b2d b59 b4c b7a b69 b6d b49 b75
b68 b97 b85 b65 b89 b8a b92 b84
bb4 ba2 b81 ba6 ba7 baf ba1 bd1
bbf b9e bc3 bc4 bcc bbe c02 bdc
be0 be8 bec bf0 bbb bf4 bf5 bf7
bf8 bfa bfd bdb c1e c0d c11 bd8
c19 c0c c3a c29 c2d c09 c35 c28
c41 c45 c25 c56 c59 c5d c61 c65
c69 c6d c71 c7d c82 c84 c90 c94
c96 c9a cab cac caf cb3 cb7 cbb
cbf cc3 cc7 ccb ccf cd3 cd7 ce3
ce8 cea cf6 cfa cfc d00 d11 d12
d15 d19 d1d d21 d25 d29 d2d d31
d35 d39 d3d d41 d45 d49 d4d d51
d55 d59 d5d d61 d65 d69 d6d d71
d75 d79 d7d d81 d85 d89 d8d d91
d95 d99 d9d da1 da5 da9 dad db1
db5 db9 dbd dc1 dc5 dc9 dcd dd1
dd5 dd9 ddd de1 de5 de9 ded df1
df5 df9 dfd e01 e05 e09 e0d e11
e15 e19 e1d e21 e25 e29 e2d e31
e35 e39 e3d e41 e45 e49 e4d e51
e55 e59 e5d e61 e65 e69 e6d e71
e75 e79 e7d e81 e85 e89 e8d e91
e95 e99 e9d ea1 ea5 ea9 ead eb1
eb5 eb9 ebd ec1 ec5 ec9 ecd ed9
ede ee0 eec ef0 f0e ef6 efa efe
f01 f09 ef5 f15 f19 ef2 f1d f21
f25 f28 f2d f2e 1 f30 f35 f39
f3d f40 f45 f49 f4d f50 f55 f56
f58 f5d f60 f64 f65 f6a f6f f72
f77 f78 f7d f80 f84 f85 f8a f8d
f92 f93 f98 f9b fa0 fa1 fa6 fa9
fae faf fb4 fb7 fbb fbc fc1 fc4
fc9 fca fcf fd2 fd7 fd8 fdd fe0
fe5 fe6 feb fee ff2 ff3 ff8 ffb
1000 1001 1006 1009 100e 100f 1014 1017
101c 101d 1022 1025 1029 102a 102f 1032
1037 1038 103d 1040 1045 1046 104b 104e
1053 1054 1059 105c 1060 1061 1066 1069
106e 106f 1074 1077 107c 107d 1082 1085
1089 108d 1091 1092 1094 1099 109a 109c
109d 10a2 10a5 10aa 10ab 10b0 10b3 10b7
10bb 10bf 10c0 10c2 10c7 10c8 10ca 10cb
10d0 10d3 10d8 10d9 10de 10e1 10e5 10e9
10ed 10ee 10f0 10f5 10f6 10f8 10f9 10fe
1101 1106 1107 110c 110f 1113 1117 111b
111c 111e 1123 1124 1126 1127 112c 112f
1134 1135 113a 113d 1141 1145 1149 114a
114c 1151 1152 1154 1155 115a 115d 1162
1163 1168 116b 116f 1173 1177 1178 117a
117f 1180 1182 1183 1188 118b 1190 1191
1196 1199 119d 11a1 11a5 11a6 11a8 11ad
11ae 11b0 11b1 11b6 11b9 11be 11bf 11c4
11c7 11cb 11cf 11d3 11d4 11d6 11db 11dc
11de 11df 11e4 11e7 11ec 11ed 11f2 11f5
11f9 11fd 1201 1202 1204 1209 120a 120c
120d 1212 1215 121a 121b 1220 1223 1228
1229 122e 1231 1235 1236 123b 123e 1243
1244 1249 124c 1251 1252 1257 1258 125d
125f 1263 1266 126a 126e 1271 1275 1279
127c 127f 1284 1287 128a 128d 128e 1293
1294 1 1296 129b 129f 12a3 12a6 12ab
12b0 12b3 12b7 12b8 12bd 12be 12c3 12c5
12c9 12cc 12d0 12d4 12d8 12dc 12e0 12e4
12e8 12ec 12f0 12f4 12f8 12fc 1300 1304
1308 130c 1310 1314 1318 131c 1320 1324
1327 1328 132a 132e 1332 1335 1336 1338
133c 1340 1344 1347 1348 134a 134e 1351
1355 1358 1359 135e 1361 1365 1369 136c
136d 136f 1373 1376 137a 137d 137e 1383
1 1386 138b 138f 1392 1396 1398 139c
139f 13a3 13a7 13ab 13af 13b4 13b8 13bc
13c1 13c5 13c9 13cc 13d0 13d4 13d9 13dd
13e1 13e2 13e6 13ea 13eb 13ef 13f3 13f7
13fc 1400 1401 1405 1409 140e 1413 1417
141b 1420 1424 1428 142b 142e 1432 1434
1438 143c 143f 1442 1446 1448 144c 1450
1453 1457 145b 145f 1462 1466 146a 146e
1473 1475 1479 147d 1480 1484 1488 148a
1 148e 1492 1496 1499 149d 14a1 14a5
14a9 14ac 14b0 14b4 14b7 14ba 14bf 14c2
14c5 14c8 14c9 14ce 14cf 1 14d1 14d6
14da 14de 14e1 14e6 14eb 14ee 14f2 14f3
14f8 14fb 1500 1501 1506 1509 150e 150f
1514 1517 151b 151c 1521 1524 1529 152a
152f 1532 1536 153a 153d 1540 1541 1543
1544 1549 154a 154f 1551 1555 1558 155a
155e 1560 156c 156e 1570 1571 1576 157a
157c 1588 158a 158e 1592 1595 1596 1598
159b 159e 159f 15a4 15a8 15ac 15af 15b3
15b7 15ba 15bd 15c2 15c5 15c8 15cb 15cc
15d1 15d2 1 15d4 15d9 15dd 15e1 15e4
15e9 15ee 15f1 15f5 15f6 15fb 15fe 1603
1604 1609 160c 1611 1612 1617 161a 161e
1622 1626 162a 162d 162e 1630 1635 1636
1638 1639 163e 1641 1646 1647 164c 164f
1654 1655 165a 165d 1661 1662 1667 166a
166f 1670 1675 1676 167b 167d 1681 1684
1688 168c 168f 1693 1697 169a 169d 16a2
16a5 16a8 16ab 16ac 16b1 16b2 1 16b4
16b9 16bd 16c1 16c4 16c9 16ce 16d1 16d5
16d6 16db 16dc 16e1 16e3 16e7 16ea 16ee
16f2 16f5 16f9 16fd 1700 1704 1708 1709
170e 1710 1714 1717 171b 171f 1723 1727
172b 172f 1733 1737 173b 173f 1743 1747
174b 174f 1753 1757 175b 1767 176b 176f
1772 1776 177a 177c 1 1780 1784 1788
178b 178f 1793 1797 179b 179e 17a2 17a6
17a9 17ac 17b1 17b4 17b7 17ba 17bb 17c0
17c1 1 17c3 17c8 17cc 17d0 17d3 17d8
17dd 17e0 17e4 17e5 17ea 17ed 17f2 17f3
17f8 17fb 1800 1801 1806 1809 180d 180e
1813 1816 181b 181c 1821 1824 1828 182c
182f 1832 1833 1835 1836 183b 183c 1841
1843 1847 184a 184c 1850 1852 185e 1860
1862 1863 1868 186c 186e 187a 187c 1880
1884 1887 188b 188e 1892 1895 1896 189b
189e 18a2 18a6 18a9 18ad 18b1 18b4 18b7
18bc 18bf 18c2 18c5 18c6 18cb 18cc 1
18ce 18d3 18d7 18db 18de 18e3 18e8 18eb
18ef 18f0 18f5 18f8 18fd 18fe 1903 1906
190b 190c 1911 1914 1918 191c 1920 1924
1927 1928 192a 192f 1930 1932 1933 1938
193b 1940 1941 1946 1949 194e 194f 1954
1957 195b 195c 1961 1964 1969 196a 196f
1970 1975 1977 197b 197e 1982 1986 1989
198d 1991 1994 1997 199c 199f 19a2 19a5
19a6 19ab 19ac 1 19ae 19b3 19b7 19bb
19be 19c3 19c8 19cb 19cf 19d0 19d5 19d6
19db 19dd 19e1 19e4 19e8 19ec 19ef 19f3
19f7 19fa 19fe 1a02 1a03 1a08 1a0a 1a0e
1a11 1a15 1a18 1a1c 1a20 1a24 1a28 1a2c
1a30 1a3c 1a40 1a44 1a47 1a4b 1a4f 1a51
1 1a55 1a59 1a5d 1a60 1a64 1a68 1a6c
1a70 1a73 1a77 1a7b 1a7e 1a81 1a86 1a89
1a8c 1a8f 1a90 1a95 1a96 1 1a98 1a9d
1aa1 1aa5 1aa8 1aad 1ab2 1ab5 1ab9 1aba
1abf 1ac2 1ac7 1ac8 1acd 1ad0 1ad5 1ad6
1adb 1ade 1ae2 1ae3 1ae8 1aeb 1af0 1af1
1af6 1af9 1afd 1b01 1b04 1b07 1b08 1b0a
1b0b 1b10 1b11 1b16 1b18 1b1c 1b1f 1b21
1b25 1b27 1b33 1b35 1b37 1b38 1b3d 1b41
1b43 1b4f 1b51 1b55 1b59 1b5c 1b5d 1b5f
1b62 1b65 1b66 1b6b 1b6f 1b73 1b76 1b7a
1b7e 1b81 1b84 1b89 1b8c 1b8f 1b92 1b93
1b98 1b99 1 1b9b 1ba0 1ba4 1ba8 1bab
1bb0 1bb5 1bb8 1bbc 1bbd 1bc2 1bc5 1bca
1bcb 1bd0 1bd3 1bd8 1bd9 1bde 1be1 1be5
1be9 1bed 1bf1 1bf4 1bf5 1bf7 1bfc 1bfd
1bff 1c00 1c05 1c08 1c0d 1c0e 1c13 1c16
1c1b 1c1c 1c21 1c24 1c28 1c29 1c2e 1c31
1c36 1c37 1c3c 1c3d 1c42 1c44 1c48 1c4b
1c4f 1c53 1c56 1c5a 1c5e 1c61 1c64 1c69
1c6c 1c6f 1c72 1c73 1c78 1c79 1 1c7b
1c80 1c84 1c88 1c8b 1c90 1c95 1c98 1c9c
1c9d 1ca2 1ca3 1ca8 1caa 1cae 1cb1 1cb5
1cb9 1cbc 1cc0 1cc4 1cc7 1ccb 1ccf 1cd0
1cd5 1cd7 1cdb 1cde 1ce2 1ce6 1cea 1cee
1cf2 1cf6 1cfa 1cfe 1d02 1d06 1d0a 1d0e
1d12 1d16 1d1a 1d1e 1d22 1d26 1d2a 1d2e
1d32 1d36 1d3a 1d3e 1d42 1d46 1d4a 1d4e
1d52 1d56 1d5a 1d5e 1d62 1d66 1d6a 1d6e
1d72 1d7e 1d82 1d86 1d89 1d8d 1d91 1d93
1 1d97 1d9b 1d9f 1da2 1da6 1daa 1dae
1db2 1db5 1db9 1dbd 1dc0 1dc3 1dc8 1dcb
1dce 1dd1 1dd2 1dd7 1dd8 1 1dda 1ddf
1de3 1de7 1dea 1def 1df4 1df7 1dfb 1dfc
1e01 1e04 1e09 1e0a 1e0f 1e12 1e17 1e18
1e1d 1e20 1e24 1e25 1e2a 1e2d 1e32 1e33
1e38 1e3b 1e3f 1e43 1e46 1e49 1e4a 1e4c
1e4d 1e52 1e53 1e58 1e5a 1e5e 1e61 1e63
1e67 1e69 1e75 1e77 1e79 1e7a 1e7f 1e83
1e85 1e91 1e93 1e97 1e9b 1e9e 1ea2 1ea5
1ea9 1eac 1ead 1eb2 1eb5 1eb9 1ebd 1ec0
1ec4 1ec8 1ecb 1ece 1ed3 1ed6 1ed9 1edc
1edd 1ee2 1ee3 1 1ee5 1eea 1eee 1ef2
1ef5 1efa 1eff 1f02 1f06 1f07 1f0c 1f0f
1f14 1f15 1f1a 1f1d 1f22 1f23 1f28 1f2b
1f2f 1f33 1f37 1f3b 1f3e 1f3f 1f41 1f46
1f47 1f49 1f4a 1f4f 1f52 1f57 1f58 1f5d
1f60 1f65 1f66 1f6b 1f6e 1f72 1f73 1f78
1f7b 1f80 1f81 1f86 1f87 1f8c 1f8e 1f92
1f95 1f99 1f9d 1fa0 1fa4 1fa8 1fab 1fae
1fb3 1fb6 1fb9 1fbc 1fbd 1fc2 1fc3 1
1fc5 1fca 1fce 1fd2 1fd5 1fda 1fdf 1fe2
1fe6 1fe7 1fec 1fed 1ff2 1ff4 1ff8 1ffb
1fff 2003 2006 200a 200e 2011 2015 2019
201a 201f 2021 2025 2028 202c 2030 2034
2038 203c 2040 2044 2050 2054 2058 205b
205f 2063 2065 1 2069 206d 2071 2074
2078 207c 2080 2084 2087 208b 208f 2092
2095 209a 209d 20a0 20a3 20a4 20a9 20aa
1 20ac 20b1 20b5 20b9 20bc 20c1 20c6
20c9 20cd 20ce 20d3 20d6 20db 20dc 20e1
20e4 20e9 20ea 20ef 20f2 20f6 20f7 20fc
20ff 2104 2105 210a 210d 2111 2115 2118
211b 211c 211e 211f 2124 2125 212a 212c
2130 2133 2135 2139 213b 2147 2149 214b
214c 2151 2155 2157 2163 2165 2169 216d
2170 2174 2177 217b 217e 217f 2184 2187
218b 218f 2192 2196 219a 219d 21a0 21a5
21a8 21ab 21ae 21af 21b4 21b5 1 21b7
21bc 21c0 21c4 21c7 21cc 21d1 21d4 21d8
21d9 21de 21e1 21e6 21e7 21ec 21ef 21f4
21f5 21fa 21fd 2201 2205 2209 220d 2210
2211 2213 2218 2219 221b 221c 2221 2224
2229 222a 222f 2232 2237 2238 223d 2240
2244 2245 224a 224d 2252 2253 2258 2259
225e 2260 2264 2267 226b 226f 2272 2276
227a 227d 2280 2285 2288 228b 228e 228f
2294 2295 1 2297 229c 22a0 22a4 22a7
22ac 22b1 22b4 22b8 22b9 22be 22bf 22c4
22c6 22ca 22cd 22d1 22d5 22d8 22dc 22e0
22e3 22e7 22eb 22ec 22f1 22f3 22f7 22fa
22fe 2302 2306 230a 230e 231a 231e 2322
2325 2329 232d 232f 1 2333 2337 233b
233e 2342 2346 234a 234e 2351 2355 2359
235c 235f 2364 2367 236a 236d 236e 2373
2374 1 2376 237b 237f 2383 2386 238b
2390 2393 2397 2398 239d 23a0 23a5 23a6
23ab 23ae 23b3 23b4 23b9 23bc 23c0 23c1
23c6 23c9 23ce 23cf 23d4 23d7 23db 23df
23e2 23e5 23e6 23e8 23e9 23ee 23ef 23f4
23f6 23fa 23fd 23ff 2403 2405 2411 2413
2415 2416 241b 241f 2421 242d 242f 2433
2437 243a 243e 2443 2444 2446 2449 244c
244d 2452 2456 245b 245f 2461 2465 2468
246c 2470 2473 2477 247a 247e 2481 2482
2487 248a 248e 2492 2495 2499 249d 24a0
24a3 24a8 24ab 24ae 24b1 24b2 24b7 24b8
1 24ba 24bf 24c3 24c7 24ca 24cf 24d4
24d7 24db 24dc 24e1 24e4 24e9 24ea 24ef
24f2 24f7 24f8 24fd 2500 2504 2508 250c
2510 2513 2514 2516 251b 251c 251e 251f
2524 2527 252c 252d 2532 2535 253a 253b
2540 2543 2547 2548 254d 2550 2555 2556
255b 255c 2561 2563 2567 256a 256e 2572
2575 2579 257d 2580 2583 2588 258b 258e
2591 2592 2597 2598 1 259a 259f 25a3
25a7 25aa 25af 25b4 25b7 25bb 25bc 25c1
25c2 25c7 25c9 25cd 25d0 25d4 25d8 25db
25df 25e3 25e6 25ea 25ee 25ef 25f4 25f6
25fa 25fd 2601 2605 2609 260d 2611 2615
2619 261c 261d 261f 2622 2623 2625 2629
262d 2631 2635 2639 263c 263d 263f 2642
2643 2645 2649 264d 2651 2655 2659 265c
265d 265f 2662 2663 2665 2669 266d 2670
2673 2674 2679 267d 2681 2684 2685 2687
268a 268d 268e 2693 2697 269b 269f 26a3
26a7 26ab 26af 26b3 26b7 26bb 26bf 26cb
26cf 26d3 26d6 26da 26de 26e0 1 26e4
26e8 26ec 26ef 26f3 26f7 26fb 26ff 2702
2706 270a 270d 2710 2715 2718 271b 271e
271f 2724 2725 1 2727 272c 2730 2734
2737 273c 2741 2744 2748 2749 274e 2751
2756 2757 275c 275f 2764 2765 276a 276d
2771 2772 2777 277a 277f 2780 2785 2788
278c 2790 2793 2796 2797 2799 279a 279f
27a0 27a5 27a7 27ab 27ae 27b0 27b4 27b6
27c2 27c4 27c6 27c7 27cc 27d0 27d2 27de
27e0 27e4 27e6 27ea 27ee 27f1 27f2 27f4
27f7 27fa 27fb 2800 2804 2808 280c 2810
2814 2818 281c 2820 2824 2828 282c 2838
283c 2840 2843 2847 284b 284d 1 2851
2855 2859 285c 2860 2864 2868 286c 286f
2873 2877 287a 287d 2882 2885 2888 288b
288c 2891 2892 1 2894 2899 289d 28a1
28a4 28a9 28ae 28b1 28b5 28b6 28bb 28be
28c3 28c4 28c9 28cc 28d1 28d2 28d7 28da
28de 28df 28e4 28e7 28ec 28ed 28f2 28f5
28f9 28fd 2900 2903 2904 2906 2907 290c
290d 2912 2914 2918 291b 291d 2921 2923
292f 2931 2933 2934 2939 293d 293f 294b
294d 294f 2953 2957 295a 295e 2962 2965
2966 2968 296b 296e 296f 2974 2978 297c
297f 2983 2987 298a 298d 2992 2995 2998
299b 299c 29a1 29a2 1 29a4 29a9 29ad
29b1 29b4 29b9 29be 29c1 29c5 29c6 29cb
29ce 29d3 29d4 29d9 29dc 29e1 29e2 29e7
29ea 29ee 29f2 29f6 29fa 29fd 29fe 2a00
2a05 2a06 2a08 2a09 2a0e 2a11 2a16 2a17
2a1c 2a1f 2a24 2a25 2a2a 2a2d 2a31 2a32
2a37 2a3a 2a3f 2a40 2a45 2a46 2a4b 2a4d
2a51 2a54 2a58 2a5c 2a5f 2a63 2a67 2a6a
2a6d 2a72 2a75 2a78 2a7b 2a7c 2a81 2a82
1 2a84 2a89 2a8d 2a91 2a94 2a99 2a9e
2aa1 2aa5 2aa6 2aab 2aac 2ab1 2ab3 2ab7
2aba 2abe 2ac2 2ac5 2ac9 2acd 2ad0 2ad4
2ad8 2ad9 2ade 2ae0 2ae4 2ae7 2ae9 2aed
2af1 2af5 2af9 2afd 2b01 2b05 2b09 2b0d
2b11 2b15 2b21 2b25 2b29 2b2c 2b30 2b34
2b36 1 2b3a 2b3e 2b42 2b45 2b49 2b4d
2b51 2b55 2b58 2b5c 2b60 2b63 2b66 2b6b
2b6e 2b71 2b74 2b75 2b7a 2b7b 1 2b7d
2b82 2b86 2b8a 2b8d 2b92 2b97 2b9a 2b9e
2b9f 2ba4 2ba7 2bac 2bad 2bb2 2bb5 2bba
2bbb 2bc0 2bc3 2bc7 2bc8 2bcd 2bd0 2bd5
2bd6 2bdb 2bde 2be2 2be6 2be9 2bec 2bed
2bef 2bf0 2bf5 2bf6 2bfb 2bfd 2c01 2c04
2c06 2c0a 2c0c 2c18 2c1a 2c1c 2c1d 2c22
2c26 2c28 2c34 2c36 2c3a 2c3e 2c42 2c46
2c4a 2c4e 2c52 2c56 2c5a 2c5e 2c62 2c6e
2c72 2c76 2c79 2c7d 2c81 2c83 1 2c87
2c8b 2c8f 2c92 2c96 2c9a 2c9e 2ca2 2ca5
2ca9 2cad 2cb0 2cb3 2cb8 2cbb 2cbe 2cc1
2cc2 2cc7 2cc8 1 2cca 2ccf 2cd3 2cd7
2cda 2cdf 2ce4 2ce7 2ceb 2cec 2cf1 2cf4
2cf9 2cfa 2cff 2d02 2d07 2d08 2d0d 2d10
2d14 2d15 2d1a 2d1d 2d22 2d23 2d28 2d2b
2d2f 2d33 2d36 2d39 2d3a 2d3c 2d3d 2d42
2d43 2d48 2d4a 2d4e 2d51 2d53 2d57 2d59
2d65 2d67 2d69 2d6a 2d6f 2d73 2d75 2d81
2d83 2d87 2d8b 2d8f 2d92 2d93 2d95 2d96
2d98 2d9b 2d9e 2da1 2da2 2da7 2dab 2daf
2db2 2db3 2db5 2db8 2dbb 2dbc 2dc1 2dc4
2dc8 2dcc 2dcf 2dd0 2dd2 2dd5 2dd8 2dd9
2dde 1 2de1 2de6 1 2de9 2dee 2df2
2df6 2dfa 2dfe 2e02 2e06 2e0a 2e0e 2e12
2e16 2e22 2e26 2e2a 2e2d 2e31 2e35 2e37
1 2e3b 2e3f 2e43 2e46 2e4a 2e4e 2e52
2e56 2e59 2e5d 2e61 2e64 2e67 2e6c 2e6f
2e72 2e75 2e76 2e7b 2e7c 1 2e7e 2e83
2e87 2e8b 2e8e 2e93 2e98 2e9b 2e9f 2ea0
2ea5 2ea8 2ead 2eae 2eb3 2eb6 2ebb 2ebc
2ec1 2ec4 2ec8 2ec9 2ece 2ed1 2ed6 2ed7
2edc 2edf 2ee3 2ee7 2eea 2eed 2eee 2ef0
2ef1 2ef6 2ef7 2efc 2efe 2f02 2f05 2f07
2f0b 2f0d 2f19 2f1b 2f1d 2f1e 2f23 2f27
2f29 2f35 2f37 2f3b 2f3f 2f42 2f43 2f45
2f48 2f4b 2f4c 2f51 2f55 2f59 2f5c 2f60
2f64 2f67 2f6a 2f6f 2f72 2f75 2f78 2f79
2f7e 2f7f 1 2f81 2f86 2f8a 2f8e 2f91
2f96 2f9b 2f9e 2fa2 2fa3 2fa8 2fab 2fb0
2fb1 2fb6 2fb9 2fbe 2fbf 2fc4 2fc7 2fcb
2fcf 2fd3 2fd7 2fda 2fdb 2fdd 2fe2 2fe3
2fe5 2fe6 2feb 2fee 2ff3 2ff4 2ff9 2ffc
3001 3002 3007 300a 300e 300f 3014 3017
301c 301d 3022 3023 3028 302a 302e 3031
3035 3039 303c 3040 3044 3047 304a 304f
3052 3055 3058 3059 305e 305f 1 3061
3066 306a 306e 3071 3076 307b 307e 3082
3083 3088 3089 308e 3090 3094 3097 309b
309f 30a2 30a6 30aa 30ad 30b1 30b5 30b6
30bb 30bd 30c1 30c4 30c6 30ca 30cd 30cf
30d3 30d7 30da 30de 30e3 30e7 30eb 30f0
30f4 30f8 30fd 3101 3105 3106 310a 310e
310f 3113 3117 311b 3120 3124 3125 3129
312d 3132 3137 313b 313f 3144 3148 314c
314f 3152 3156 3158 315c 3160 3163 3166
316a 316c 3170 3174 3177 317b 317f 3182
3186 3189 318d 3190 3191 3196 3199 319d
31a0 31a4 31a6 31aa 31ad 31b1 31b3 31b7
31bb 31be 31c2 31c6 31cb 31cd 31d1 31d5
31d8 31dc 31e0 31e2 1 31e6 31ea 31ee
31f1 31f5 31f9 31fd 3201 3204 3208 320c
320f 3212 3217 321a 321d 3220 3221 3226
3227 1 3229 322e 3232 3236 3239 323e
3243 3246 324a 324b 3250 3253 3258 3259
325e 3261 3266 3267 326c 326f 3273 3274
3279 327c 3281 3282 3287 328a 328e 3292
3295 3298 3299 329b 329c 32a1 32a2 32a7
32a9 32ad 32b0 32b2 32b6 32b8 32c4 32c6
32c8 32c9 32ce 32d2 32d4 32e0 32e2 32e6
32ea 32ed 32ee 32f0 32f3 32f6 32f7 32fc
3300 3304 3308 330c 3310 3314 3318 331c
3320 3324 3328 3334 3338 333c 333f 3343
3347 3349 1 334d 3351 3355 3358 335c
3360 3364 3368 336b 336f 3373 3376 3379
337e 3381 3384 3387 3388 338d 338e 1
3390 3395 3399 339d 33a0 33a5 33aa 33ad
33b1 33b2 33b7 33ba 33bf 33c0 33c5 33c8
33cd 33ce 33d3 33d6 33da 33db 33e0 33e3
33e8 33e9 33ee 33f1 33f5 33f9 33fc 33ff
3400 3402 3403 3408 3409 340e 3410 3414
3417 3419 341d 341f 342b 342d 342f 3430
3435 3439 343b 3447 3449 344d 3451 3454
3455 3457 345a 345d 345e 3463 3467 346a
346e 3472 3476 347a 347e 3482 3486 348a
348e 3492 3496 349a 349e 34a2 34ae 34b2
34b6 34b9 34bd 34c1 34c3 1 34c7 34cb
34cf 34d2 34d6 34da 34de 34e2 34e5 34e9
34ed 34f0 34f3 34f8 34fb 34fe 3501 3502
3507 3508 1 350a 350f 3513 3517 351a
351f 3524 3527 352b 352c 3531 3534 3539
353a 353f 3542 3547 3548 354d 3550 3554
3555 355a 355d 3562 3563 3568 356b 356f
3573 3576 3579 357a 357c 357d 3582 3583
3588 358a 358e 3591 3593 3597 3599 35a5
35a7 35a9 35aa 35af 35b3 35b5 35c1 35c3
35c7 35cb 35ce 35d2 35d5 35d9 35dc 35dd
35e2 35e5 35e9 35ed 35f0 35f4 35f8 35fb
35fe 3603 3606 3609 360c 360d 3612 3613
1 3615 361a 361e 3622 3625 362a 362f
3632 3636 3637 363c 363f 3644 3645 364a
364d 3652 3653 3658 365b 365f 3663 3667
366b 366e 366f 3671 3676 3677 3679 367a
367f 3682 3687 3688 368d 3690 3695 3696
369b 369e 36a2 36a3 36a8 36ab 36b0 36b1
36b6 36b7 36bc 36be 36c2 36c5 36c9 36cd
36d0 36d4 36d8 36db 36de 36e3 36e6 36e9
36ec 36ed 36f2 36f3 1 36f5 36fa 36fe
3702 3705 370a 370f 3712 3716 3717 371c
371d 3722 3724 3728 372b 372f 3733 3736
373a 373e 3741 3745 3749 374a 374f 3753
3755 3759 375c 375d 3762 3765 3768 376c
376f 3770 3775 3778 1 377b 3780 3784
3788 378b 378f 3793 3796 3797 3799 379c
379f 37a0 37a5 37a8 37ac 37b0 37b3 37b7
37bb 37be 37bf 37c1 37c4 37c7 37c8 37cd
1 37d0 37d5 37d9 37dd 37e0 37e4 37e8
37eb 37ee 37f3 37f6 37f9 37fc 37fd 3802
3803 1 3805 380a 380e 3812 3815 381a
381f 3822 3826 3827 382c 382f 3834 3835
383a 383d 3842 3843 3848 384b 384f 3853
3857 385b 385e 385f 3861 3866 3867 3869
386a 386f 3872 3877 3878 387d 3880 3885
3886 388b 388e 3892 3893 3898 389b 38a0
38a1 38a6 38a7 38ac 38ae 38b2 38b5 38b9
38bd 38c0 38c4 38c8 38cb 38ce 38d3 38d6
38d9 38dc 38dd 38e2 38e3 1 38e5 38ea
38ee 38f2 38f5 38fa 38ff 3902 3906 3907
390c 390d 3912 3914 3918 391b 391f 3923
3926 392a 392e 3931 3935 3939 393a 393f
3941 3945 3948 394a 394e 3952 3955 3957
395b 395e 3962 3966 3969 396a 396c 396f
3972 3973 3978 397c 397f 3983 3987 398b
398f 3991 3995 3999 399d 39a1 39a5 39a9
39ad 39b1 39b5 39b9 39bd 39c9 39cd 39d1
39d4 39d8 39dc 39de 1 39e2 39e6 39ea
39ed 39f1 39f5 39f9 39fd 3a00 3a04 3a08
3a0b 3a0e 3a13 3a16 3a19 3a1c 3a1d 3a22
3a23 1 3a25 3a2a 3a2e 3a32 3a35 3a3a
3a3f 3a42 3a46 3a47 3a4c 3a4f 3a54 3a55
3a5a 3a5d 3a62 3a63 3a68 3a6b 3a6f 3a70
3a75 3a78 3a7d 3a7e 3a83 3a86 3a8a 3a8e
3a91 3a94 3a95 3a97 3a98 3a9d 3a9e 3aa3
3aa5 3aa9 3aac 3aae 3ab2 3ab4 3ac0 3ac2
3ac4 3ac5 3aca 3ace 3ad0 3adc 3ade 3ae2
3ae6 3ae9 3aed 3af0 3af4 3af7 3af8 3afd
3b00 3b04 3b09 3b0d 3b11 3b15 3b16 3b1b
3b1f 3b23 3b27 3b2a 3b2e 3b32 3b35 3b36
3b38 3b3c 3b40 3b43 3b47 3b48 3b4a 3b4e
3b52 3b56 3b5a 3b5d 3b61 3b65 3b6a 3b6e
3b72 3b75 3b79 3b7d 3b81 3b85 3b89 3b8d
3b91 3b95 3b99 3b9d 3b9e 3ba0 3ba4 3ba8
3bac 3bb0 3bb4 3bb7 3bb8 3bba 3bbb 3bbd
3bc1 3bc5 3bc9 3bcd 3bd1 3bd5 3bd9 3bdd
3be1 3be5 3be9 3bed 3bf1 3bf5 3bf9 3bfd
3c01 3c05 3c09 3c0d 3c11 3c15 3c19 3c1d
3c21 3c25 3c29 3c35 3c39 3c3e 3c42 3c45
3c46 3c4b 3c4f 3c53 3c56 3c59 3c5d 3c5f
3c63 3c67 3c6a 3c6d 3c71 3c73 3c77 3c7b
3c7e 3c80 1 3c84 3c88 3c8c 3c8f 3c93
3c97 3c9b 3c9f 3ca2 3ca6 3caa 3cad 3cb0
3cb5 3cb8 3cbb 3cbe 3cbf 3cc4 3cc5 1
3cc7 3ccc 3cd0 3cd4 3cd7 3cdc 3ce1 3ce4
3ce8 3ce9 3cee 3cf1 3cf6 3cf7 3cfc 3cff
3d04 3d05 3d0a 3d0d 3d11 3d12 3d17 3d1a
3d1f 3d20 3d25 3d28 3d2c 3d30 3d33 3d36
3d37 3d39 3d3a 3d3f 3d40 3d45 3d47 3d4b
3d4e 3d50 3d54 3d56 3d62 3d64 3d66 3d67
3d6c 3d70 3d72 3d7e 3d80 3d84 3d88 3d8c
3d90 3d94 3da0 3da4 3da8 3dab 3daf 3db3
3db5 1 3db9 3dbd 3dc1 3dc4 3dc8 3dcc
3dd0 3dd4 3dd7 3ddb 3ddf 3de2 3de5 3dea
3ded 3df0 3df3 3df4 3df9 3dfa 1 3dfc
3e01 3e05 3e09 3e0c 3e11 3e16 3e19 3e1d
3e1e 3e23 3e26 3e2b 3e2c 3e31 3e34 3e39
3e3a 3e3f 3e42 3e46 3e47 3e4c 3e4f 3e54
3e55 3e5a 3e5d 3e61 3e65 3e68 3e6b 3e6c
3e6e 3e6f 3e74 3e75 3e7a 3e7c 3e80 3e83
3e85 3e89 3e8b 3e97 3e99 3e9b 3e9c 3ea1
3ea5 3ea7 3eb3 3eb5 3eb9 3ebd 3ec0 3ec4
3ec8 3ec9 3ecb 3ece 3ed1 3ed2 3ed7 3edb
3ede 3ee2 3ee4 3ee8 3eec 3ef0 3ef4 3ef8
3efc 3f00 3f04 3f08 3f0c 3f10 3f14 3f20
3f24 3f28 3f2b 3f2f 3f33 3f35 1 3f39
3f3d 3f41 3f44 3f48 3f4c 3f50 3f54 3f57
3f5b 3f5f 3f62 3f65 3f6a 3f6d 3f70 3f73
3f74 3f79 3f7a 1 3f7c 3f81 3f85 3f89
3f8c 3f91 3f96 3f99 3f9d 3f9e 3fa3 3fa6
3fab 3fac 3fb1 3fb4 3fb9 3fba 3fbf 3fc2
3fc6 3fc7 3fcc 3fcf 3fd4 3fd5 3fda 3fdd
3fe1 3fe5 3fe8 3feb 3fec 3fee 3fef 3ff4
3ff5 3ffa 3ffc 4000 4003 4005 4009 400b
4017 4019 401b 401c 4021 4025 4027 4033
4035 4037 403b 403f 4042 4046 404a 404d
404e 4050 4053 4056 4057 405c 4060 4064
4068 406c 4070 4074 4078 407c 4080 4084
4090 4094 4099 409d 40a0 40a1 40a6 40aa
40ae 40b1 40b4 40b8 40ba 40be 40c2 40c5
40c8 40cc 40ce 40d2 40d6 40d9 40db 1
40df 40e3 40e7 40ea 40ee 40f2 40f6 40fa
40fd 4101 4105 4108 410b 4110 4113 4116
4119 411a 411f 4120 1 4122 4127 412b
412f 4132 4137 413c 413f 4143 4144 4149
414c 4151 4152 4157 415a 415f 4160 4165
4168 416c 416d 4172 4175 417a 417b 4180
4183 4187 418b 418e 4191 4192 4194 4195
419a 419b 41a0 41a2 41a6 41a9 41ab 41af
41b1 41bd 41bf 41c1 41c2 41c7 41cb 41cd
41d9 41db 41df 41e3 41e7 41eb 41ef 41f3
41f7 41fb 41ff 4203 4207 420b 420f 4213
4217 421b 421f 422b 422f 4234 4238 423b
423c 4241 4245 4249 424c 424f 4253 4255
4259 425d 4260 4263 4267 4269 426d 4271
4274 4276 1 427a 427e 4282 4285 4289
428d 4291 4295 4298 429c 42a0 42a3 42a6
42ab 42ae 42b1 42b4 42b5 42ba 42bb 1
42bd 42c2 42c6 42ca 42cd 42d2 42d7 42da
42de 42df 42e4 42e7 42ec 42ed 42f2 42f5
42fa 42fb 4300 4303 4307 4308 430d 4310
4315 4316 431b 431e 4322 4326 4329 432c
432d 432f 4330 4335 4336 433b 433d 4341
4344 4346 434a 434c 4358 435a 435c 435d
4362 4366 4368 4374 4376 4378 437c 4380
4384 4388 438c 4390 4394 4398 439c 43a0
43a4 43a8 43ac 43b0 43b4 43b8 43bc 43c8
43cc 43d1 43d5 43d8 43d9 43de 43e2 43e6
43e9 43ec 43f0 43f2 43f6 43fa 43fd 4400
4404 4406 440a 440e 4411 4413 1 4417
441b 441f 4422 4426 442a 442e 4432 4435
4439 443d 4440 4443 4448 444b 444e 4451
4452 4457 4458 1 445a 445f 4463 4467
446a 446f 4474 4477 447b 447c 4481 4484
4489 448a 448f 4492 4497 4498 449d 44a0
44a4 44a5 44aa 44ad 44b2 44b3 44b8 44bb
44bf 44c3 44c6 44c9 44ca 44cc 44cd 44d2
44d3 44d8 44da 44de 44e1 44e3 44e7 44e9
44f5 44f7 44f9 44fa 44ff 4503 4505 4511
4513 4515 4519 451d 4520 4524 4526 452a
452e 4531 4535 4538 453c 453f 4540 4545
4548 454c 4550 4554 4558 455c 4560 456c
4570 4574 4577 457b 457f 4581 1 4585
4589 458d 4590 4594 4598 459c 45a0 45a3
45a7 45ab 45ae 45b1 45b6 45b9 45bc 45bf
45c0 45c5 45c6 1 45c8 45cd 45d1 45d5
45d8 45dd 45e2 45e5 45e9 45ea 45ef 45f2
45f7 45f8 45fd 4600 4605 4606 460b 460e
4612 4613 4618 461b 4620 4621 4626 4629
462d 4631 4634 4637 4638 463a 463b 4640
4641 4646 4648 464c 464f 4651 4655 4657
4663 4665 4667 4668 466d 4671 4673 467f
4681 4685 4689 468c 468d 468f 4693 4696
469a 469d 469e 46a3 46a7 46ab 46ae 46b2
46b6 46b9 46ba 46bc 46c0 46c4 46c7 46cb
46cc 46ce 46d2 46d6 46da 46de 46e2 46e6
46ea 46ee 46f2 46f6 46fa 4706 470a 470f
4713 4716 4717 471c 4720 4724 4727 472a
472e 4730 4734 4738 473b 473e 4742 4744
4748 474c 474f 4751 1 4755 4759 475d
4760 4764 4768 476c 4770 4773 4777 477b
477e 4781 4786 4789 478c 478f 4790 4795
4796 1 4798 479d 47a1 47a5 47a8 47ad
47b2 47b5 47b9 47ba 47bf 47c2 47c7 47c8
47cd 47d0 47d5 47d6 47db 47de 47e2 47e3
47e8 47eb 47f0 47f1 47f6 47f9 47fd 4801
4804 4807 4808 480a 480b 4810 4811 4816
4818 481c 481f 4821 4825 4827 4833 4835
4837 4838 483d 4841 4843 484f 4851 4855
4859 485d 485e 4860 4864 4868 486a 486e
4872 4876 4879 487a 487c 4880 4884 4887
4888 488a 488d 4891 4894 4898 489b 489c
48a1 48a5 48a9 48ad 48b1 48b5 48b9 48bd
48c1 48c5 48c9 48cd 48d9 48dd 48e2 48e6
48e9 48ea 48ef 48f3 48f7 48fa 48fd 4901
4903 4907 490b 490e 4911 4915 4917 491b
491f 4922 4924 1 4928 492c 4930 4933
4937 493b 493f 4943 4946 494a 494e 4951
4954 4959 495c 495f 4962 4963 4968 4969
1 496b 4970 4974 4978 497b 4980 4985
4988 498c 498d 4992 4995 499a 499b 49a0
49a3 49a8 49a9 49ae 49b1 49b5 49b6 49bb
49be 49c3 49c4 49c9 49cc 49d0 49d4 49d7
49da 49db 49dd 49de 49e3 49e4 49e9 49eb
49ef 49f2 49f4 49f8 49fa 4a06 4a08 4a0a
4a0b 4a10 4a14 4a16 4a22 4a24 4a28 4a2c
4a30 4a31 4a33 4a37 4a39 4a3d 4a41 4a45
4a49 4a4d 4a51 4a55 4a59 4a5d 4a61 4a65
4a69 4a75 4a79 4a7e 4a82 4a85 4a86 4a8b
4a8f 4a93 4a96 4a99 4a9d 4a9f 4aa3 4aa7
4aaa 4aad 4ab1 4ab3 4ab7 4abb 4abe 4ac0
1 4ac4 4ac8 4acc 4acf 4ad3 4ad7 4adb
4adf 4ae2 4ae6 4aea 4aed 4af0 4af5 4af8
4afb 4afe 4aff 4b04 4b05 1 4b07 4b0c
4b10 4b14 4b17 4b1c 4b21 4b24 4b28 4b29
4b2e 4b31 4b36 4b37 4b3c 4b3f 4b44 4b45
4b4a 4b4d 4b51 4b52 4b57 4b5a 4b5f 4b60
4b65 4b68 4b6c 4b70 4b73 4b76 4b77 4b79
4b7a 4b7f 4b80 4b85 4b87 4b8b 4b8e 4b90
4b94 4b96 4ba2 4ba4 4ba6 4ba7 4bac 4bb0
4bb2 4bbe 4bc0 4bc4 4bc8 4bcc 4bcd 4bcf
4bd3 4bd5 4bd9 4bdd 4be0 4be2 4be6 4bea
4bed 4bef 4bf3 4bf7 4bfa 4bfc 4c00 4c04
4c08 4c0a 4c0e 4c12 4c15 4c19 4c1e 4c22
4c26 4c2b 4c2f 4c33 4c38 4c3c 4c40 4c44
4c45 4c4a 4c4e 4c52 4c56 4c59 4c5a 4c5c
4c5f 4c62 4c63 4c68 4c6b 4c6f 4c73 4c76
4c77 4c79 4c7c 4c7f 4c80 4c85 1 4c88
4c8d 4c91 4c95 4c99 4c9d 4ca1 4ca5 4ca9
4cad 4cb1 4cb5 4cb9 4cbd 4cbe 4cc0 4cc4
4cc6 4cca 4ccd 4cd1 4cd5 4cd9 4cdd 4ce1
4ce5 4ce9 4ced 4cf1 4cf5 4cf9 4cfd 4d01
4d05 4d09 4d0d 4d11 4d15 4d19 4d1d 4d21
4d25 4d31 4d35 4d39 4d3c 4d40 4d44 4d46
1 4d4a 4d4e 4d52 4d55 4d59 4d5d 4d61
4d65 4d68 4d6c 4d70 4d73 4d76 4d7b 4d7e
4d81 4d84 4d85 4d8a 4d8b 1 4d8d 4d92
4d96 4d9a 4d9d 4da2 4da7 4daa 4dae 4daf
4db4 4db7 4dbc 4dbd 4dc2 4dc5 4dca 4dcb
4dd0 4dd3 4dd7 4dd8 4ddd 4de0 4de5 4de6
4deb 4dee 4df2 4df6 4df9 4dfc 4dfd 4dff
4e00 4e05 4e06 4e0b 4e0d 4e11 4e14 4e16
4e1a 4e1c 4e28 4e2a 4e2c 4e2d 4e32 4e36
4e38 4e44 4e46 4e4a 4e4e 4e51 4e55 4e58
4e5c 4e5f 4e60 4e65 4e68 4e6c 4e6f 4e73
4e75 4e79 4e7c 4e80 4e83 4e87 4e8b 4e8e
4e92 4e96 4e97 4e9b 4e9f 4ea3 4ea7 4eab
4eaf 4eb3 4eb7 4ec3 4ec7 4ecb 4ece 4ed2
4ed6 4ed8 1 4edc 4ee0 4ee4 4ee7 4eeb
4eef 4ef3 4ef7 4efa 4efe 4f02 4f05 4f08
4f0d 4f10 4f13 4f16 4f17 4f1c 4f1d 1
4f1f 4f24 4f28 4f2c 4f2f 4f34 4f39 4f3c
4f40 4f41 4f46 4f49 4f4e 4f4f 4f54 4f57
4f5c 4f5d 4f62 4f65 4f69 4f6a 4f6f 4f72
4f77 4f78 4f7d 4f80 4f84 4f88 4f8b 4f8e
4f8f 4f91 4f92 4f97 4f98 4f9d 4f9f 4fa3
4fa6 4fa8 4fac 4fae 4fba 4fbc 4fbe 4fbf
4fc4 4fc8 4fca 4fd6 4fd8 4fdc 4fe0 4fe3
4fe7 4feb 4fec 4fee 4ff1 4ff4 4ff5 4ffa
4ffe 5002 5006 500a 500e 5012 5016 501a
501e 5022 502e 5032 5036 5039 503d 5041
5043 1 5047 504b 504f 5052 5056 505a
505e 5062 5065 5069 506d 5070 5073 5078
507b 507e 5081 5082 5087 5088 1 508a
508f 5093 5097 509a 509f 50a4 50a7 50ab
50ac 50b1 50b4 50b9 50ba 50bf 50c2 50c7
50c8 50cd 50d0 50d4 50d5 50da 50dd 50e2
50e3 50e8 50eb 50ef 50f3 50f6 50f9 50fa
50fc 50fd 5102 5103 5108 510a 510e 5111
5113 5117 5119 5125 5127 5129 512a 512f
5133 5135 5141 5143 5147 514b 514e 514f
5151 5154 5157 5158 515d 5161 5165 5169
516b 516f 5172 5176 5178 517c 5180 5183
5185 5189 518c 5190 5194 5197 5198 519a
519d 51a0 51a1 51a6 51aa 51ae 51b1 51b5
51b9 51ba 51bc 51bf 51c2 51c3 51c8 51cc
51d0 51d4 51d8 51dc 51e0 51e4 51e8 51ec
51f0 51f4 51f8 51fc 5200 5204 5208 520c
5210 5214 5218 521c 5220 5224 5228 522c
5230 5234 5238 523c 5240 5244 5248 524c
5250 5254 5258 525c 5260 5264 5268 5274
5278 527c 527f 5283 5287 5289 1 528d
5291 5295 5298 529c 52a0 52a4 52a8 52ab
52af 52b3 52b6 52b9 52be 52c1 52c4 52c7
52c8 52cd 52ce 1 52d0 52d5 52d9 52dd
52e0 52e5 52ea 52ed 52f1 52f2 52f7 52fa
52ff 5300 5305 5308 530d 530e 5313 5316
531a 531b 5320 5323 5328 5329 532e 5331
5335 5339 533c 533f 5340 5342 5343 5348
5349 534e 5350 5354 5357 5359 535d 535f
536b 536d 536f 5370 5375 5379 537b 5387
5389 538d 5391 5395 5399 539c 53a0 53a4
53a8 53ab 53ac 53ae 53b1 53b4 53b5 53ba
53be 53c2 53c5 53c6 53c8 53cc 53cf 53d3
53d6 53d7 53d9 53da 53df 53e2 53e6 53ea
53ed 53ee 53f0 53f4 53f7 53fb 53fe 53ff
5401 5402 5407 1 540a 540f 5413 5417
541a 541b 541d 5420 5423 5424 5429 542c
5430 5434 5438 543b 543c 543e 5442 5446
5449 544a 544c 544f 5452 5455 5456 545b
1 545e 5463 5467 546b 546e 5472 5476
5479 547c 5481 5484 5487 548a 548b 5490
5491 1 5493 5498 549c 54a0 54a3 54a8
54ad 54b0 54b4 54b5 54ba 54bd 54c2 54c3
54c8 54cb 54d0 54d1 54d6 54d9 54dd 54e1
54e5 54e9 54ec 54ed 54ef 54f4 54f5 54f7
54f8 54fd 5500 5505 5506 550b 550e 5513
5514 5519 551c 5520 5521 5526 5529 552e
552f 5534 5535 553a 553c 5540 5543 5547
554b 554e 5552 5556 5559 555c 5561 5564
5567 556a 556b 5570 5571 1 5573 5578
557c 5580 5583 5588 558d 5590 5594 5595
559a 559b 55a0 55a2 55a6 55a9 55ad 55b1
55b4 55b8 55bc 55bf 55c3 55c7 55c8 55cd
55cf 55d3 55d6 55da 55de 55e2 55e5 55e6
55e8 55eb 55ee 55ef 55f4 55f8 55fb 55ff
5601 5605 5608 560a 560e 5612 5615 5617
561b 561e 5622 5626 562a 562e 5632 5636
563a 563e 5642 5646 564a 564e 5652 5656
565a 565e 5662 5666 566a 566e 5672 5676
567a 567e 5682 5686 568a 568c 5690 5693
5697 569b 569e 56a2 56a5 56a9 56ac 56ad
56b2 56b5 56b9 56bc 56bd 56c2 56c5 1
56c8 56cd 56d1 56d5 56d8 56db 56dc 56de
56e1 56e6 56e7 56ec 56f0 56f3 56f6 56f7
56fc 5700 5704 5708 570b 570f 5713 5717
571b 571f 5723 5727 572b 572f 5733 5737
5738 573a 573e 5740 5744 5747 574b 574f
5752 5753 5755 5758 575b 575c 5761 5765
5769 576d 5779 577d 5782 5786 5789 578a
578f 5793 5797 579a 579d 57a1 57a3 57a7
57ab 57ae 57b1 57b5 57b7 57bb 57bf 57c2
57c4 1 57c8 57cc 57d0 57d3 57d7 57db
57df 57e3 57e6 57ea 57ee 57f1 57f4 57f9
57fc 57ff 5802 5803 5808 5809 1 580b
5810 5814 5818 581b 5820 5825 5828 582c
582d 5832 5835 583a 583b 5840 5843 5848
5849 584e 5851 5855 5856 585b 585e 5863
5864 5869 586c 5870 5874 5877 587a 587b
587d 587e 5883 5884 5889 588b 588f 5892
5894 5898 589a 58a6 58a8 58aa 58ab 58b0
58b4 58b6 58c2 58c4 58c8 58cc 58d0 58d4
58d8 58e4 58e8 58ed 58f1 58f4 58f5 58fa
58fe 5902 5905 5908 590c 590e 5912 5916
5919 591c 5920 5922 5926 592a 592d 592f
1 5933 5937 593b 593e 5942 5946 594a
594e 5951 5955 5959 595c 595f 5964 5967
596a 596d 596e 5973 5974 1 5976 597b
597f 5983 5986 598b 5990 5993 5997 5998
599d 59a0 59a5 59a6 59ab 59ae 59b3 59b4
59b9 59bc 59c0 59c1 59c6 59c9 59ce 59cf
59d4 59d7 59db 59df 59e2 59e5 59e6 59e8
59e9 59ee 59ef 59f4 59f6 59fa 59fd 59ff
5a03 5a05 5a11 5a13 5a15 5a16 5a1b 5a1f
5a21 5a2d 5a2f 5a33 5a37 5a3b 5a3f 5a43
5a47 5a4b 5a4f 5a53 5a57 5a5b 5a67 5a6b
5a6f 5a72 5a76 5a7a 5a7c 1 5a80 5a84
5a88 5a8b 5a8f 5a93 5a97 5a9b 5a9e 5aa2
5aa6 5aa9 5aac 5ab1 5ab4 5ab7 5aba 5abb
5ac0 5ac1 1 5ac3 5ac8 5acc 5ad0 5ad3
5ad8 5add 5ae0 5ae4 5ae5 5aea 5aed 5af2
5af3 5af8 5afb 5b00 5b01 5b06 5b09 5b0d
5b0e 5b13 5b16 5b1b 5b1c 5b21 5b24 5b28
5b2c 5b2f 5b32 5b33 5b35 5b36 5b3b 5b3c
5b41 5b43 5b47 5b4a 5b4c 5b50 5b52 5b5e
5b60 5b62 5b63 5b68 5b6c 5b6e 5b7a 5b7c
5b80 5b84 5b87 5b8b 5b8f 5b92 5b93 5b95
5b98 5b9b 5b9c 5ba1 5ba5 5ba9 5bad 5bb1
5bb5 5bb9 5bbd 5bc1 5bc5 5bc9 5bd5 5bd9
5bdd 5be0 5be4 5be8 5bea 1 5bee 5bf2
5bf6 5bf9 5bfd 5c01 5c05 5c09 5c0c 5c10
5c14 5c17 5c1a 5c1f 5c22 5c25 5c28 5c29
5c2e 5c2f 1 5c31 5c36 5c3a 5c3e 5c41
5c46 5c4b 5c4e 5c52 5c53 5c58 5c5b 5c60
5c61 5c66 5c69 5c6e 5c6f 5c74 5c77 5c7b
5c7c 5c81 5c84 5c89 5c8a 5c8f 5c92 5c96
5c9a 5c9d 5ca0 5ca1 5ca3 5ca4 5ca9 5caa
5caf 5cb1 5cb5 5cb8 5cba 5cbe 5cc0 5ccc
5cce 5cd0 5cd1 5cd6 5cda 5cdc 5ce8 5cea
5cec 5cf0 5cf3 5cf5 5cf9 5cfd 5d00 5d01
5d03 5d06 5d09 5d0a 5d0f 5d12 5d16 5d1a
5d1d 5d1e 5d20 5d23 5d26 5d27 5d2c 1
5d2f 5d34 5d38 5d3c 5d40 5d43 5d44 5d46
5d49 5d4d 5d51 5d54 5d55 5d57 5d58 5d5d
5d61 5d65 5d69 5d6d 5d70 5d71 5d73 5d76
5d7a 5d7e 5d81 5d82 5d84 5d85 5d8a 5d8e
5d92 5d96 5d9a 5d9d 5d9e 5da0 5da3 5da7
5dab 5dae 5daf 5db1 5db2 5db7 5dbb 5dbf
5dc3 5dc7 5dca 5dcb 5dcd 5dd0 5dd4 5dd8
5ddb 5ddc 5dde 5ddf 5de4 5de8 5dec 5df0
5df3 5df4 5df6 5df9 5dfc 5dfd 5e02 5e06
5e0a 5e0e 5e12 5e16 5e1a 5e1e 5e22 5e26
5e2a 5e2e 5e32 5e36 5e3a 5e3e 5e42 5e46
5e4a 5e4e 5e52 5e56 5e5a 5e5e 5e62 5e66
5e6a 5e6e 5e72 5e76 5e7a 5e86 5e8a 5e8f
5e93 5e96 5e97 5e9c 5ea0 5ea4 5ea7 5eaa
5eae 5eb0 5eb4 5eb8 5ebb 5ebe 5ec2 5ec4
5ec8 5ecc 5ecf 5ed1 1 5ed5 5ed9 5edd
5ee0 5ee4 5ee8 5eec 5ef0 5ef3 5ef7 5efb
5efe 5f01 5f06 5f09 5f0c 5f0f 5f10 5f15
5f16 1 5f18 5f1d 5f21 5f25 5f28 5f2d
5f32 5f35 5f39 5f3a 5f3f 5f42 5f47 5f48
5f4d 5f50 5f55 5f56 5f5b 5f5e 5f62 5f63
5f68 5f6b 5f70 5f71 5f76 5f79 5f7d 5f81
5f84 5f87 5f88 5f8a 5f8b 5f90 5f91 5f96
5f98 5f9c 5f9f 5fa1 5fa5 5fa7 5fb3 5fb5
5fb7 5fb8 5fbd 5fc1 5fc3 5fcf 5fd1 5fd3
5fd7 5fdb 5fdf 5fe3 5fe7 5feb 5fef 5ff3
5ff7 5ffb 5fff 6003 6007 600b 600f 6013
6017 601b 601f 6023 6027 602b 602f 6033
6037 603b 603f 6043 6047 604b 604f 6053
6057 605b 6067 606b 6070 6074 6077 6078
607d 6081 6085 6088 608b 608f 6091 6095
6099 609c 609f 60a3 60a5 60a9 60ad 60b0
60b2 1 60b6 60ba 60be 60c1 60c5 60c9
60cd 60d1 60d4 60d8 60dc 60df 60e2 60e7
60ea 60ed 60f0 60f1 60f6 60f7 1 60f9
60fe 6102 6106 6109 610e 6113 6116 611a
611b 6120 6123 6128 6129 612e 6131 6136
6137 613c 613f 6143 6144 6149 614c 6151
6152 6157 615a 615e 6162 6165 6168 6169
616b 616c 6171 6172 6177 6179 617d 6180
6182 6186 6188 6194 6196 6198 6199 619e
61a2 61a4 61b0 61b2 61b4 61b8 61bc 61bf
61c3 61c5 61c9 61cd 61d0 61d1 61d3 61d6
61d9 61da 61df 61e3 61e7 61eb 61ee 61ef
61f1 61f4 61f8 61fc 61ff 6200 6202 6203
6208 620c 6210 6214 6218 621b 621c 621e
6221 6225 6229 622c 622d 622f 6230 6235
6239 623d 6241 6245 6249 624d 6251 6255
6259 625d 6261 6265 6269 626d 6271 6275
6279 627d 6281 6285 6289 628d 6291 6295
6299 629d 62a1 62ad 62b1 62b6 62ba 62bd
62be 62c3 62c7 62cb 62ce 62d1 62d5 62d7
62db 62df 62e2 62e5 62e9 62eb 62ef 62f3
62f6 62f8 1 62fc 6300 6304 6307 630b
630f 6313 6317 631a 631e 6322 6325 6328
632d 6330 6333 6336 6337 633c 633d 1
633f 6344 6348 634c 634f 6354 6359 635c
6360 6361 6366 6369 636e 636f 6374 6377
637c 637d 6382 6385 6389 638a 638f 6392
6397 6398 639d 63a0 63a4 63a8 63ab 63ae
63af 63b1 63b2 63b7 63b8 63bd 63bf 63c3
63c6 63c8 63cc 63ce 63da 63dc 63de 63df
63e4 63e8 63ea 63f6 63f8 63fc 63fe 6402
6406 640a 640d 640e 6410 6413 6416 6417
641c 6420 6424 6428 642b 642c 642e 6431
6435 6439 643c 643d 643f 6440 6445 6449
644d 6451 6455 6458 6459 645b 645e 6462
6466 6469 646a 646c 646d 6472 6476 647a
647e 6481 6482 6484 6487 648a 648b 6490
6494 6498 649c 64a0 64a4 64a8 64ac 64b0
64b4 64b8 64bc 64c0 64c4 64c8 64cc 64d0
64d4 64d8 64dc 64e0 64e4 64e8 64f4 64f8
64fd 6501 6504 6505 650a 650e 6512 6515
6518 651c 651e 6522 6526 6529 652c 6530
6532 6536 653a 653d 653f 1 6543 6547
654b 654e 6552 6556 655a 655e 6561 6565
6569 656c 656f 6574 6577 657a 657d 657e
6583 6584 1 6586 658b 658f 6593 6596
659b 65a0 65a3 65a7 65a8 65ad 65b0 65b5
65b6 65bb 65be 65c3 65c4 65c9 65cc 65d0
65d1 65d6 65d9 65de 65df 65e4 65e7 65eb
65ef 65f2 65f5 65f6 65f8 65f9 65fe 65ff
6604 6606 660a 660d 660f 6613 6615 6621
6623 6625 6626 662b 662f 6631 663d 663f
6641 6645 6649 664d 6651 6655 6659 665d
6661 6665 6669 666d 6671 6675 6679 667d
6681 6685 6689 668d 6691 6695 6699 669d
66a1 66a5 66a9 66b5 66b9 66be 66c2 66c5
66c6 66cb 66cf 66d3 66d6 66d9 66dd 66df
66e3 66e7 66ea 66ed 66f1 66f3 66f7 66fb
66fe 6700 1 6704 6708 670c 670f 6713
6717 671b 671f 6722 6726 672a 672d 6730
6735 6738 673b 673e 673f 6744 6745 1
6747 674c 6750 6754 6757 675c 6761 6764
6768 6769 676e 6771 6776 6777 677c 677f
6784 6785 678a 678d 6791 6792 6797 679a
679f 67a0 67a5 67a8 67ac 67b0 67b3 67b6
67b7 67b9 67ba 67bf 67c0 67c5 67c7 67cb
67ce 67d0 67d4 67d6 67e2 67e4 67e6 67e7
67ec 67f0 67f2 67fe 6800 6802 6806 680a
680d 680f 6813 6817 681b 681f 6823 6827
682b 682f 6833 6837 683b 683f 6843 684f
6853 6858 685c 685f 6860 6865 6869 686d
6870 6873 6877 6879 687d 6881 6884 6887
688b 688d 6891 6895 6898 689a 1 689e
68a2 68a6 68a9 68ad 68b1 68b5 68b9 68bc
68c0 68c4 68c7 68ca 68cf 68d2 68d5 68d8
68d9 68de 68df 1 68e1 68e6 68ea 68ee
68f1 68f6 68fb 68fe 6902 6903 6908 690b
6910 6911 6916 6919 691e 691f 6924 6927
692b 692c 6931 6934 6939 693a 693f 6942
6946 694a 694d 6950 6951 6953 6954 6959
695a 695f 6961 6965 6968 696a 696e 6970
697c 697e 6980 6981 6986 698a 698c 6998
699a 699c 69a0 69a4 69a7 69ab 69af 69b3
69b7 69bb 69c7 69cb 69d0 69d4 69d7 69d8
69dd 69e1 69e5 69e8 69eb 69ef 69f1 69f5
69f9 69fc 69ff 6a03 6a05 6a09 6a0d 6a10
6a12 1 6a16 6a1a 6a1e 6a21 6a25 6a29
6a2d 6a31 6a34 6a38 6a3c 6a3f 6a42 6a47
6a4a 6a4d 6a50 6a51 6a56 6a57 1 6a59
6a5e 6a62 6a66 6a69 6a6e 6a73 6a76 6a7a
6a7b 6a80 6a83 6a88 6a89 6a8e 6a91 6a96
6a97 6a9c 6a9f 6aa3 6aa4 6aa9 6aac 6ab1
6ab2 6ab7 6aba 6abe 6ac2 6ac5 6ac8 6ac9
6acb 6acc 6ad1 6ad2 6ad7 6ad9 6add 6ae0
6ae2 6ae6 6ae8 6af4 6af6 6af8 6af9 6afe
6b02 6b04 6b10 6b12 6b16 6b1a 6b1e 6b22
6b26 6b2a 6b2e 6b32 6b36 6b3a 6b3e 6b4a
6b4e 6b53 6b57 6b5a 6b5b 6b60 6b64 6b68
6b6b 6b6e 6b72 6b74 6b78 6b7c 6b7f 6b82
6b86 6b88 6b8c 6b90 6b93 6b95 1 6b99
6b9d 6ba1 6ba4 6ba8 6bac 6bb0 6bb4 6bb7
6bbb 6bbf 6bc2 6bc5 6bca 6bcd 6bd0 6bd3
6bd4 6bd9 6bda 1 6bdc 6be1 6be5 6be9
6bec 6bf1 6bf6 6bf9 6bfd 6bfe 6c03 6c06
6c0b 6c0c 6c11 6c14 6c19 6c1a 6c1f 6c22
6c26 6c27 6c2c 6c2f 6c34 6c35 6c3a 6c3d
6c41 6c45 6c48 6c4b 6c4c 6c4e 6c4f 6c54
6c55 6c5a 6c5c 6c60 6c63 6c65 6c69 6c6b
6c77 6c79 6c7b 6c7c 6c81 6c85 6c87 6c93
6c95 6c97 6c9b 6c9f 6ca2 6ca6 6ca9 6cad
6cb1 6cb5 6cb9 6cc5 6cc9 6cce 6cd2 6cd5
6cd6 6cdb 6cdf 6ce3 6ce6 6ce9 6ced 6cef
6cf3 6cf7 6cfa 6cfd 6d01 6d03 6d07 6d0b
6d0e 6d10 1 6d14 6d18 6d1c 6d1f 6d23
6d27 6d2b 6d2f 6d32 6d36 6d3a 6d3d 6d40
6d45 6d48 6d4b 6d4e 6d4f 6d54 6d55 1
6d57 6d5c 6d60 6d64 6d67 6d6c 6d71 6d74
6d78 6d79 6d7e 6d81 6d86 6d87 6d8c 6d8f
6d94 6d95 6d9a 6d9d 6da1 6da2 6da7 6daa
6daf 6db0 6db5 6db8 6dbc 6dc0 6dc3 6dc6
6dc7 6dc9 6dca 6dcf 6dd0 6dd5 6dd7 6ddb
6dde 6de0 6de4 6de6 6df2 6df4 6df6 6df7
6dfc 6e00 6e02 6e0e 6e10 6e14 6e18 6e1c
6e20 6e24 6e30 6e34 6e39 6e3d 6e40 6e41
6e46 6e4a 6e4e 6e51 6e54 6e58 6e5a 6e5e
6e62 6e65 6e68 6e6c 6e6e 6e72 6e76 6e79
6e7b 1 6e7f 6e83 6e87 6e8a 6e8e 6e92
6e96 6e9a 6e9d 6ea1 6ea5 6ea8 6eab 6eb0
6eb3 6eb6 6eb9 6eba 6ebf 6ec0 1 6ec2
6ec7 6ecb 6ecf 6ed2 6ed7 6edc 6edf 6ee3
6ee4 6ee9 6eec 6ef1 6ef2 6ef7 6efa 6eff
6f00 6f05 6f08 6f0c 6f0d 6f12 6f15 6f1a
6f1b 6f20 6f23 6f27 6f2b 6f2e 6f31 6f32
6f34 6f35 6f3a 6f3b 6f40 6f42 6f46 6f49
6f4b 6f4f 6f51 6f5d 6f5f 6f61 6f62 6f67
6f6b 6f6d 6f79 6f7b 6f7f 6f83 6f86 6f87
6f89 6f8c 6f8f 6f90 6f95 6f98 6f9c 6fa0
6fa3 6fa4 6fa6 6fa9 6fac 6fad 6fb2 1
6fb5 6fba 6fbe 6fc1 6fc5 6fc9 6fcc 6fd0
6fd4 6fd8 6fdb 6fdf 6fe2 6fe3 6fe5 6fe8
6feb 6fec 6ff1 6ff5 6ff8 6ffc 6ffe 7002
7005 7009 700b 700f 7013 7016 701a 701e
7021 7022 7024 7027 702a 702b 7030 7034
7037 703b 703d 7041 7044 7048 704c 7050
7054 7058 705c 705f 7060 7062 7066 706a
706d 706e 7070 7074 7078 707b 707c 707e
7082 7086 7089 708a 708c 7090 7094 7097
7098 709a 709e 70a2 70a5 70a6 70a8 70ac
70b0 70b3 70b4 70b6 70ba 70be 70c1 70c2
70c4 70c8 70cc 70d0 70d1 70d3 70d7 70db
70df 70e2 70e3 70e5 70e9 70ec 70f0 70f3
70f4 70f9 70fd 7101 7104 7108 710c 710f
7112 7117 711a 711d 7120 7121 7126 7127
1 7129 712e 7132 7136 7139 713e 7143
7146 714a 714b 7150 7153 7158 7159 715e
7161 7166 7167 716c 716f 7173 7177 717b
717f 7182 7183 7185 718a 718b 718d 718e
7193 7194 7199 719b 719f 71a2 71a6 71aa
71ad 71b1 71b5 71b8 71bb 71c0 71c3 71c6
71c9 71ca 71cf 71d0 1 71d2 71d7 71db
71df 71e2 71e7 71ec 71ef 71f3 71f4 71f9
71fa 71ff 7201 7205 7208 720c 7210 7213
7217 721b 721e 7222 7223 7228 722c 722e
7232 7236 7239 723a 723c 723f 7242 7243
7248 724c 7250 7253 7257 725b 725e 7261
7266 7269 726c 726f 7270 7275 7276 1
7278 727d 7281 7285 7288 728d 7292 7295
7299 729a 729f 72a2 72a7 72a8 72ad 72b0
72b5 72b6 72bb 72be 72c2 72c6 72ca 72cb
72cd 72d2 72d3 72d5 72d6 72db 72de 72e3
72e4 72e9 72ec 72f1 72f2 72f7 72fa 72fe
72ff 7304 7307 730c 730d 7312 7313 7318
731a 731e 7321 7325 7329 732c 7330 7334
7337 733a 733f 7342 7345 7348 7349 734e
734f 1 7351 7356 735a 735e 7361 7366
736b 736e 7372 7373 7378 7379 737e 7380
7384 7387 738b 738f 7392 7396 739a 739d
739e 73a0 73a4 73a8 73a9 73ae 73b0 73b4
73b8 73bb 73bf 73c3 73c6 73c7 73c9 73cc
73cf 73d0 73d5 73d9 73dd 73e1 73e4 73e8
73ea 73ee 73f2 73f6 73f9 73fd 7401 7404
7405 7407 740b 740f 7412 7413 7415 7419
741b 741f 7423 7426 742a 742d 7431 7435
7439 743d 7441 7445 7449 744d 7451 7455
7459 745d 7461 7465 7469 746d 7471 7475
7479 747d 7481 7485 7489 748d 7491 7495
7499 749d 74a1 74a5 74a9 74ac 74af 74b2
74b5 74b6 74b8 74bc 74c0 74c4 74c7 74c8
74ca 74cd 74d0 74d1 74d6 74da 74de 74e1
74e5 74e9 74ec 74ef 74f4 74f7 74fa 74fd
74fe 7503 7504 1 7506 750b 750f 7513
7516 751b 7520 7523 7527 7528 752d 7530
7535 7536 753b 753e 7543 7544 7549 754c
7550 7554 7558 755c 755f 7560 7562 7567
7568 756a 756b 7570 7573 7578 7579 757e
7581 7586 7587 758c 758f 7593 7594 7599
759c 75a1 75a2 75a7 75a8 75ad 75af 75b3
75b6 75ba 75be 75c1 75c5 75c9 75cc 75cf
75d4 75d7 75da 75dd 75de 75e3 75e4 1
75e6 75eb 75ef 75f3 75f6 75fb 7600 7603
7607 7608 760d 760e 7613 7615 7619 761c
7620 7624 7627 762b 762f 7632 7636 763a
763b 7640 7644 7646 764a 764e 7651 7652
7654 7657 765a 765b 7660 7664 7668 766b
766f 7673 7676 7679 767e 7681 7684 7687
7688 768d 768e 1 7690 7695 7699 769d
76a0 76a5 76aa 76ad 76b1 76b2 76b7 76ba
76bf 76c0 76c5 76c8 76cd 76ce 76d3 76d6
76da 76de 76e2 76e6 76e9 76ea 76ec 76f1
76f2 76f4 76f5 76fa 76fd 7702 7703 7708
770b 7710 7711 7716 7719 771d 771e 7723
7726 772b 772c 7731 7732 7737 7739 773d
7740 7744 7748 774b 774f 7753 7756 7759
775e 7761 7764 7767 7768 776d 776e 1
7770 7775 7779 777d 7780 7785 778a 778d
7791 7792 7797 7798 779d 779f 77a3 77a6
77aa 77ae 77b1 77b5 77b9 77bc 77c0 77c4
77c5 77ca 77cc 77d0 77d4 77d7 77db 77df
77e3 77e7 77eb 77ef 77f3 77f7 77fa 77fb
77fd 7801 7805 7808 7809 780b 780c 780e
7812 7814 7818 781c 781f 7821 7825 7828
782a 782e 7831 7835 7837 783b 783f 7842
7845 7846 7848 784b 7850 7851 7856 785a
785e 7862 7866 786a 786e 7872 7876 787a
787e 7882 7886 788a 788e 7892 7896 789a
789e 78a2 78a6 78aa 78ae 78b2 78b6 78ba
78be 78ca 78ce 78d2 78d5 78d9 78dd 78df
1 78e3 78e7 78eb 78ee 78f2 78f6 78fa
78fe 7901 7905 7909 790c 790f 7914 7917
791a 791d 791e 7923 7924 1 7926 792b
792f 7933 7936 793b 7940 7943 7947 7948
794d 7950 7955 7956 795b 795e 7963 7964
7969 796c 7970 7971 7976 7979 797e 797f
7984 7987 798b 798f 7992 7995 7996 7998
7999 799e 799f 79a4 79a6 79aa 79ad 79af
79b3 79b5 79c1 79c3 79c5 79c6 79cb 79cf
79d1 79dd 79df 79e3 79e7 79ea 79ee 79f1
79f5 79f8 79f9 79fe 7a01 7a05 7a08 7a09
7a0e 7a11 1 7a14 7a19 7a1d 7a20 7a23
7a24 7a29 7a2d 7a31 7a35 7a38 7a3c 7a40
7a44 7a48 7a4c 7a50 7a54 7a58 7a5c 7a60
7a64 7a65 7a67 7a6b 7a6d 7a71 7a74 7a76
7a7a 7a7e 7a82 7a86 7a8a 7a8e 7a92 7a96
7a9a 7a9e 7aa2 7aa6 7aaa 7ab6 7aba 7abe
7ac1 7ac5 7ac9 7acb 1 7acf 7ad3 7ad7
7ada 7ade 7ae2 7ae6 7aea 7aed 7af1 7af5
7af8 7afb 7b00 7b03 7b06 7b09 7b0a 7b0f
7b10 1 7b12 7b17 7b1b 7b1f 7b22 7b27
7b2c 7b2f 7b33 7b34 7b39 7b3c 7b41 7b42
7b47 7b4a 7b4f 7b50 7b55 7b58 7b5c 7b5d
7b62 7b65 7b6a 7b6b 7b70 7b73 7b77 7b7b
7b7e 7b81 7b82 7b84 7b85 7b8a 7b8b 7b90
7b92 7b96 7b99 7b9b 7b9f 7ba1 7bad 7baf
7bb1 7bb2 7bb7 7bbb 7bbd 7bc9 7bcb 7bcd
7bd1 7bd5 7bd8 7bdc 7bde 7be2 7be6 7be9
7bec 7bed 7bef 7bf2 7bf7 7bf8 7bfd 7c01
7c05 7c09 7c0d 7c11 7c15 7c19 7c1d 7c21
7c25 7c29 7c2d 7c31 7c35 7c39 7c3d 7c41
7c45 7c49 7c4d 7c51 7c55 7c59 7c5d 7c61
7c65 7c71 7c75 7c79 7c7c 7c80 7c84 7c86
1 7c8a 7c8e 7c92 7c95 7c99 7c9d 7ca1
7ca5 7ca8 7cac 7cb0 7cb3 7cb6 7cbb 7cbe
7cc1 7cc4 7cc5 7cca 7ccb 1 7ccd 7cd2
7cd6 7cda 7cdd 7ce2 7ce7 7cea 7cee 7cef
7cf4 7cf7 7cfc 7cfd 7d02 7d05 7d0a 7d0b
7d10 7d13 7d17 7d18 7d1d 7d20 7d25 7d26
7d2b 7d2e 7d32 7d36 7d39 7d3c 7d3d 7d3f
7d40 7d45 7d46 7d4b 7d4d 7d51 7d54 7d56
7d5a 7d5c 7d68 7d6a 7d6c 7d6d 7d72 7d76
7d78 7d84 7d86 7d8a 7d8e 7d91 7d95 7d98
7d9c 7d9f 7da0 7da5 7da8 7dac 7daf 7db0
7db5 7db8 1 7dbb 7dc0 7dc4 7dc7 7dca
7dcb 7dd0 7dd4 7dd8 7ddc 7ddf 7de3 7de7
7deb 7def 7df3 7df7 7dfb 7dff 7e03 7e07
7e0b 7e0c 7e0e 7e12 7e14 7e18 7e1b 7e1d
7e21 7e25 7e29 7e2d 7e31 7e35 7e39 7e3d
7e41 7e45 7e49 7e4d 7e51 7e5d 7e61 7e65
7e68 7e6c 7e70 7e72 1 7e76 7e7a 7e7e
7e81 7e85 7e89 7e8d 7e91 7e94 7e98 7e9c
7e9f 7ea2 7ea7 7eaa 7ead 7eb0 7eb1 7eb6
7eb7 1 7eb9 7ebe 7ec2 7ec6 7ec9 7ece
7ed3 7ed6 7eda 7edb 7ee0 7ee3 7ee8 7ee9
7eee 7ef1 7ef6 7ef7 7efc 7eff 7f03 7f04
7f09 7f0c 7f11 7f12 7f17 7f1a 7f1e 7f22
7f25 7f28 7f29 7f2b 7f2c 7f31 7f32 7f37
7f39 7f3d 7f40 7f42 7f46 7f48 7f54 7f56
7f58 7f59 7f5e 7f62 7f64 7f70 7f72 7f74
7f78 7f7c 7f7f 7f83 7f86 7f87 7f8c 7f8f
7f92 7f96 7f9a 7f9d 7f9e 7fa0 7fa3 7fa6
7fa7 7fac 1 7faf 7fb4 7fb8 7fbc 7fbf
7fc0 7fc2 7fc5 7fc8 7fc9 7fce 1 7fd1
7fd6 7fda 7fdf 7fe3 7fe7 7feb 7fec 7ff1
7ff5 7ff9 7ffd 8000 8001 8003 8006 8009
800a 800f 8013 8017 801b 801e 801f 8021
8025 8027 802b 802e 8032 8036 8039 803a
803c 803f 8042 8043 8048 804b 804f 8053
8056 8057 8059 805c 805f 8060 8065 1
8068 806d 8071 8075 8078 8079 807b 807e
8081 8082 8087 808a 808e 8092 8095 8096
8098 809b 809e 809f 80a4 1 80a7 80ac
80b0 80b4 80b8 80bb 80bc 80be 80c1 80c5
80c9 80cc 80cd 80cf 80d0 80d5 80d9 80dd
80e1 80e5 80e8 80e9 80eb 80ee 80f2 80f6
80f9 80fa 80fc 80fd 8102 8106 810a 810e
8112 8115 8116 8118 811b 811f 8123 8126
8127 8129 812a 812f 8133 8137 813b 813f
8142 8143 8145 8148 814c 8150 8153 8154
8156 8157 815c 8160 8164 8168 816c 8170
8174 8178 817c 8180 8184 8188 818c 8190
8194 8198 819c 81a0 81a4 81a8 81ac 81b0
81b4 81b8 81bc 81c0 81c4 81c8 81cc 81d0
81d4 81d8 81dc 81e0 81e4 81e8 81ec 81f0
81f4 81f8 81fc 8200 8204 8208 820c 8210
8214 8218 821c 8220 8224 8228 822c 8230
823c 8240 8245 8249 824c 824d 8252 8256
825a 825d 8260 8264 8266 826a 826e 8271
8274 8278 827a 827e 8282 8285 8287 1
828b 828f 8293 8296 829a 829e 82a2 82a6
82a9 82ad 82b1 82b4 82b7 82bc 82bf 82c2
82c5 82c6 82cb 82cc 1 82ce 82d3 82d7
82db 82de 82e3 82e8 82eb 82ef 82f0 82f5
82f8 82fd 82fe 8303 8306 830b 830c 8311
8314 8318 8319 831e 8321 8326 8327 832c
832f 8333 8337 833a 833d 833e 8340 8341
8346 8347 834c 834e 8352 8355 8357 835b
835d 8369 836b 836d 836e 8373 8377 8379
8385 8387 838b 838d 8391 8395 8398 8399
839b 839e 83a1 83a2 83a7 83ab 83af 83b3
83b6 83b7 83b9 83bc 83c0 83c4 83c7 83c8
83ca 83cb 83d0 83d4 83d8 83dc 83e0 83e3
83e4 83e6 83e9 83ed 83f1 83f4 83f5 83f7
83f8 83fd 8401 8405 8409 840d 8411 8415
8419 841d 8421 8425 8429 842d 8431 8435
8439 843d 8441 8445 8449 844d 8451 8455
8459 845d 8461 8465 8469 846d 8471 8475
8479 847d 8481 8485 8489 848d 8491 8495
8499 849d 84a1 84a5 84a9 84ad 84b1 84b5
84b9 84bd 84c1 84c5 84c9 84cd 84d1 84dd
84e1 84e6 84ea 84ed 84ee 84f3 84f7 84fb
84fe 8501 8505 8507 850b 850f 8512 8515
8519 851b 851f 8523 8526 8528 1 852c
8530 8534 8537 853b 853f 8543 8547 854a
854e 8552 8555 8558 855d 8560 8563 8566
8567 856c 856d 1 856f 8574 8578 857c
857f 8584 8589 858c 8590 8591 8596 8599
859e 859f 85a4 85a7 85ac 85ad 85b2 85b5
85b9 85ba 85bf 85c2 85c7 85c8 85cd 85d0
85d4 85d8 85db 85de 85df 85e1 85e2 85e7
85e8 85ed 85ef 85f3 85f6 85f8 85fc 85fe
860a 860c 860e 860f 8614 8618 861a 8626
8628 862a 862e 8632 8636 863a 863d 863e
8640 8643 8647 864b 864e 864f 8651 8652
8657 865b 865f 8663 8667 866a 866b 866d
8670 8674 8678 867b 867c 867e 867f 8684
8688 868c 8690 8694 8698 869c 86a0 86a4
86a8 86ac 86b0 86b4 86b8 86bc 86c0 86c4
86c8 86cc 86d0 86d4 86d8 86dc 86e0 86e4
86e8 86ec 86f0 86f4 86f8 86fc 8700 8704
8708 870c 8710 8714 8718 871c 8720 8724
8728 872c 8730 8734 8738 873c 8740 8744
8748 874c 8750 8754 8758 8764 8768 876d
8771 8774 8775 877a 877e 8782 8785 8788
878c 878e 8792 8796 8799 879c 87a0 87a2
87a6 87aa 87ad 87af 1 87b3 87b7 87bb
87be 87c2 87c6 87ca 87ce 87d1 87d5 87d9
87dc 87df 87e4 87e7 87ea 87ed 87ee 87f3
87f4 1 87f6 87fb 87ff 8803 8806 880b
8810 8813 8817 8818 881d 8820 8825 8826
882b 882e 8833 8834 8839 883c 8840 8841
8846 8849 884e 884f 8854 8857 885b 885f
8862 8865 8866 8868 8869 886e 886f 8874
8876 887a 887d 887f 8883 8885 8891 8893
8895 8896 889b 889f 88a1 88ad 88af 88b1
88b5 88b9 88bc 88be 88c2 88c6 88ca 88ce
88d2 88d6 88da 88de 88e2 88e6 88ea 88ee
88f2 88f6 88fa 88fe 8902 8906 890a 890e
8912 8916 891a 891e 8922 8926 892a 892e
8932 8936 893a 893e 8942 8946 894a 894e
8952 8956 895a 895e 8962 8966 896a 896e
8972 8976 897a 897e 8982 8986 898a 898e
899a 899e 89a3 89a7 89aa 89ab 89b0 89b4
89b8 89bb 89be 89c2 89c4 89c8 89cc 89cf
89d2 89d6 89d8 89dc 89e0 89e3 89e5 1
89e9 89ed 89f1 89f4 89f8 89fc 8a00 8a04
8a07 8a0b 8a0f 8a12 8a15 8a1a 8a1d 8a20
8a23 8a24 8a29 8a2a 1 8a2c 8a31 8a35
8a39 8a3c 8a41 8a46 8a49 8a4d 8a4e 8a53
8a56 8a5b 8a5c 8a61 8a64 8a69 8a6a 8a6f
8a72 8a76 8a77 8a7c 8a7f 8a84 8a85 8a8a
8a8d 8a91 8a95 8a98 8a9b 8a9c 8a9e 8a9f
8aa4 8aa5 8aaa 8aac 8ab0 8ab3 8ab5 8ab9
8abb 8ac7 8ac9 8acb 8acc 8ad1 8ad5 8ad7
8ae3 8ae5 8ae7 8aeb 8aef 8af2 8af6 8af9
8afd 8aff 8b03 8b06 8b0a 8b0e 8b12 8b15
8b1a 8b1b 8b20 8b23 8b26 8b27 8b29 8b2d
8b31 8b36 8b3a 8b3e 8b42 8b46 8b4a 8b4e
8b52 8b56 8b5a 8b66 8b6a 8b6e 8b71 8b75
8b79 8b7b 1 8b7f 8b83 8b87 8b8a 8b8e
8b92 8b96 8b9a 8b9d 8ba1 8ba5 8ba8 8bab
8bb0 8bb3 8bb6 8bb9 8bba 8bbf 8bc0 1
8bc2 8bc7 8bcb 8bcf 8bd2 8bd7 8bdc 8bdf
8be3 8be4 8be9 8bec 8bf1 8bf2 8bf7 8bfa
8bff 8c00 8c05 8c08 8c0c 8c0d 8c12 8c15
8c1a 8c1b 8c20 8c23 8c27 8c2b 8c2e 8c31
8c32 8c34 8c35 8c3a 8c3b 8c40 8c42 8c46
8c49 8c4b 8c4f 8c51 8c5d 8c5f 8c61 8c62
8c67 8c6b 8c6d 8c79 8c7b 8c7f 8c82 8c86
8c8a 8c8d 8c91 8c95 8c98 8c9c 8ca0 8ca3
8ca6 8ca7 8cac 8caf 8cb3 8cb7 8cba 8cbb
8cbd 8cc0 8cc3 8cc4 8cc9 1 8ccc 8cd1
8cd5 8cd9 8cdd 8ce1 8ce5 8ce9 8ced 8cf1
8cf5 8cf9 8cfd 8d01 8d05 8d09 8d0d 8d11
8d15 8d19 8d1d 8d21 8d25 8d29 8d2d 8d31
8d35 8d39 8d3d 8d41 8d45 8d49 8d4d 8d51
8d55 8d59 8d5d 8d61 8d65 8d69 8d6d 8d71
8d75 8d79 8d7d 8d81 8d85 8d89 8d8d 8d91
8d95 8d99 8d9d 8da1 8da5 8db1 8db5 8db9
8dbc 8dc0 8dc4 8dc6 1 8dca 8dce 8dd2
8dd5 8dd9 8ddd 8de1 8de5 8de8 8dec 8df0
8df3 8df6 8dfb 8dfe 8e01 8e04 8e05 8e0a
8e0b 1 8e0d 8e12 8e16 8e1a 8e1d 8e22
8e27 8e2a 8e2e 8e2f 8e34 8e37 8e3c 8e3d
8e42 8e45 8e4a 8e4b 8e50 8e53 8e57 8e58
8e5d 8e60 8e65 8e66 8e6b 8e6e 8e72 8e76
8e79 8e7c 8e7d 8e7f 8e80 8e85 8e86 8e8b
8e8d 8e91 8e94 8e96 8e9a 8e9c 8ea8 8eaa
8eac 8ead 8eb2 8eb6 8eb8 8ec4 8ec6 8ec8
8ecc 8ecf 8ed3 8ed7 8edb 8edf 8ee3 8ee8
8eec 8eed 8ef1 8ef5 8ef9 8efd 8f01 8f05
8f09 8f0d 8f11 8f15 8f19 8f1d 8f21 8f25
8f29 8f2d 8f31 8f35 8f39 8f3d 8f41 8f45
8f49 8f4e 8f53 8f57 8f5b 8f5f 8f64 8f68
8f6c 8f6f 8f72 8f76 8f78 8f7c 8f80 8f83
8f86 8f8a 8f8c 8f90 8f94 8f97 8f9b 8f9f
8fa2 8fa6 8fa9 8fad 8fb0 8fb1 8fb6 8fb9
8fbd 8fc3 8fc5 8fc9 8fcc 8fd0 8fd4 8fd7
8fd8 8fda 8fdd 8fe0 8fe1 8fe6 8fea 8fee
8ff2 8ff5 8ff6 8ff8 8ffc 9000 9004 9008
9014 9018 901d 9021 9024 9025 902a 902e
9032 9035 9038 903c 903e 9042 9046 9049
904c 9050 9052 9056 905a 905d 905f 1
9063 9067 906b 906e 9072 9076 907a 907e
9081 9085 9089 908c 908f 9094 9097 909a
909d 909e 90a3 90a4 1 90a6 90ab 90af
90b3 90b6 90bb 90c0 90c3 90c7 90c8 90cd
90d0 90d5 90d6 90db 90de 90e3 90e4 90e9
90ec 90f0 90f1 90f6 90f9 90fe 90ff 9104
9107 910b 910f 9112 9115 9116 9118 9119
911e 911f 9124 9126 912a 912d 912f 9133
9135 9141 9143 9145 9146 914b 914f 9151
915d 915f 9163 9167 916b 9177 917b 9180
9184 9187 9188 918d 9191 9195 9198 919b
919f 91a1 91a5 91a9 91ac 91af 91b3 91b5
91b9 91bd 91c0 91c2 1 91c6 91ca 91ce
91d1 91d5 91d9 91dd 91e1 91e4 91e8 91ec
91ef 91f2 91f7 91fa 91fd 9200 9201 9206
9207 1 9209 920e 9212 9216 9219 921e
9223 9226 922a 922b 9230 9233 9238 9239
923e 9241 9246 9247 924c 924f 9253 9254
9259 925c 9261 9262 9267 926a 926e 9272
9275 9278 9279 927b 927c 9281 9282 9287
9289 928d 9290 9292 9296 9298 92a4 92a6
92a8 92a9 92ae 92b2 92b4 92c0 92c2 92c6
92ca 92ce 92da 92de 92e3 92e7 92ea 92eb
92f0 92f4 92f8 92fb 92fe 9302 9304 9308
930c 930f 9312 9316 9318 931c 9320 9323
9325 1 9329 932d 9331 9334 9338 933c
9340 9344 9347 934b 934f 9352 9355 935a
935d 9360 9363 9364 9369 936a 1 936c
9371 9375 9379 937c 9381 9386 9389 938d
938e 9393 9396 939b 939c 93a1 93a4 93a9
93aa 93af 93b2 93b6 93b7 93bc 93bf 93c4
93c5 93ca 93cd 93d1 93d5 93d8 93db 93dc
93de 93df 93e4 93e5 93ea 93ec 93f0 93f3
93f5 93f9 93fb 9407 9409 940b 940c 9411
9415 9417 9423 9425 9429 942d 9431 9435
9439 9445 9449 944e 9452 9455 9456 945b
945f 9463 9466 9469 946d 946f 9473 9477
947a 947d 9481 9483 9487 948b 948e 9490
1 9494 9498 949c 949f 94a3 94a7 94ab
94af 94b2 94b6 94ba 94bd 94c0 94c5 94c8
94cb 94ce 94cf 94d4 94d5 1 94d7 94dc
94e0 94e4 94e7 94ec 94f1 94f4 94f8 94f9
94fe 9501 9506 9507 950c 950f 9514 9515
951a 951d 9521 9522 9527 952a 952f 9530
9535 9538 953c 9540 9543 9546 9547 9549
954a 954f 9550 9555 9557 955b 955e 9560
9564 9566 9572 9574 9576 9577 957c 9580
9582 958e 9590 9594 9598 959c 95a8 95ac
95b1 95b5 95b8 95b9 95be 95c2 95c6 95c9
95cc 95d0 95d2 95d6 95da 95dd 95e0 95e4
95e6 95ea 95ee 95f1 95f3 1 95f7 95fb
95ff 9602 9606 960a 960e 9612 9615 9619
961d 9620 9623 9628 962b 962e 9631 9632
9637 9638 1 963a 963f 9643 9647 964a
964f 9654 9657 965b 965c 9661 9664 9669
966a 966f 9672 9677 9678 967d 9680 9684
9685 968a 968d 9692 9693 9698 969b 969f
96a3 96a6 96a9 96aa 96ac 96ad 96b2 96b3
96b8 96ba 96be 96c1 96c3 96c7 96c9 96d5
96d7 96d9 96da 96df 96e3 96e5 96f1 96f3
96f7 96fb 96ff 970b 970f 9714 9718 971b
971c 9721 9725 9729 972c 972f 9733 9735
9739 973d 9740 9743 9747 9749 974d 9751
9754 9756 1 975a 975e 9762 9765 9769
976d 9771 9775 9778 977c 9780 9783 9786
978b 978e 9791 9794 9795 979a 979b 1
979d 97a2 97a6 97aa 97ad 97b2 97b7 97ba
97be 97bf 97c4 97c7 97cc 97cd 97d2 97d5
97da 97db 97e0 97e3 97e7 97e8 97ed 97f0
97f5 97f6 97fb 97fe 9802 9806 9809 980c
980d 980f 9810 9815 9816 981b 981d 9821
9824 9826 982a 982c 9838 983a 983c 983d
9842 9846 9848 9854 9856 9858 985c 9860
9864 9868 986c 9870 9874 9878 987c 9888
988c 9891 9895 9898 9899 989e 98a2 98a6
98a9 98ac 98b0 98b2 98b6 98ba 98bd 98c0
98c4 98c6 98ca 98ce 98d1 98d3 1 98d7
98db 98df 98e2 98e6 98ea 98ee 98f2 98f5
98f9 98fd 9900 9903 9908 990b 990e 9911
9912 9917 9918 1 991a 991f 9923 9927
992a 992f 9934 9937 993b 993c 9941 9944
9949 994a 994f 9952 9957 9958 995d 9960
9964 9965 996a 996d 9972 9973 9978 997b
997f 9983 9986 9989 998a 998c 998d 9992
9993 9998 999a 999e 99a1 99a3 99a7 99a9
99b5 99b7 99b9 99ba 99bf 99c3 99c5 99d1
99d3 99d7 99db 99df 99e3 99e7 99eb 99ef
99f3 99f7 99fb 9a07 9a0b 9a0f 9a12 9a16
9a1a 9a1c 1 9a20 9a24 9a28 9a2b 9a2f
9a33 9a37 9a3b 9a3e 9a42 9a46 9a49 9a4c
9a51 9a54 9a57 9a5a 9a5b 9a60 9a61 1
9a63 9a68 9a6c 9a70 9a73 9a78 9a7d 9a80
9a84 9a85 9a8a 9a8d 9a92 9a93 9a98 9a9b
9aa0 9aa1 9aa6 9aa9 9aad 9aae 9ab3 9ab6
9abb 9abc 9ac1 9ac4 9ac8 9acc 9acf 9ad2
9ad3 9ad5 9ad6 9adb 9adc 9ae1 9ae3 9ae7
9aea 9aec 9af0 9af2 9afe 9b00 9b02 9b03
9b08 9b0c 9b0e 9b1a 9b1c 9b20 9b24 9b27
9b2b 9b2e 9b32 9b35 9b36 9b3b 9b3e 9b42
9b46 9b49 9b4a 9b4c 9b4f 9b52 9b53 9b58
9b5c 9b60 9b64 9b66 9b6a 9b6d 9b71 9b75
9b79 9b7d 9b81 9b85 9b89 9b8d 9b91 9b95
9b99 9b9d 9ba9 9bad 9bb1 9bb4 9bb8 9bbc
9bbe 1 9bc2 9bc6 9bca 9bcd 9bd1 9bd5
9bd9 9bdd 9be0 9be4 9be8 9beb 9bee 9bf3
9bf6 9bf9 9bfc 9bfd 9c02 9c03 1 9c05
9c0a 9c0e 9c12 9c15 9c1a 9c1f 9c22 9c26
9c27 9c2c 9c2f 9c34 9c35 9c3a 9c3d 9c42
9c43 9c48 9c4b 9c4f 9c50 9c55 9c58 9c5d
9c5e 9c63 9c66 9c6a 9c6e 9c71 9c74 9c75
9c77 9c78 9c7d 9c7e 9c83 9c85 9c89 9c8c
9c8e 9c92 9c94 9ca0 9ca2 9ca4 9ca5 9caa
9cae 9cb0 9cbc 9cbe 9cc2 9cc6 9cc9 9ccd
9cd0 9cd4 9cd7 9cd8 9cdd 9ce0 9ce4 9ce8
9cec 9cef 9cf0 9cf2 9cf6 9cfa 9cfd 9cfe
9d00 9d03 9d07 9d0a 9d0e 9d11 9d12 9d17
9d1b 9d1e 9d22 9d26 9d2a 9d2e 9d32 9d36
9d3a 9d3e 9d42 9d4e 9d52 9d57 9d5b 9d5e
9d5f 9d64 9d68 9d6c 9d6f 9d72 9d76 9d78
9d7c 9d80 9d83 9d86 9d8a 9d8c 9d90 9d94
9d97 9d99 1 9d9d 9da1 9da5 9da8 9dac
9db0 9db4 9db8 9dbb 9dbf 9dc3 9dc6 9dc9
9dce 9dd1 9dd4 9dd7 9dd8 9ddd 9dde 1
9de0 9de5 9de9 9ded 9df0 9df5 9dfa 9dfd
9e01 9e02 9e07 9e0a 9e0f 9e10 9e15 9e18
9e1d 9e1e 9e23 9e26 9e2a 9e2b 9e30 9e33
9e38 9e39 9e3e 9e41 9e45 9e49 9e4c 9e4f
9e50 9e52 9e53 9e58 9e59 9e5e 9e60 9e64
9e67 9e69 9e6d 9e6f 9e7b 9e7d 9e7f 9e80
9e85 9e89 9e8b 9e97 9e99 9e9d 9e9f 9ea3
9ea7 9eaa 9eab 9ead 9eb1 9eb4 9eb8 9ebb
9ebc 9ec1 9ec5 9ec9 9ecc 9ed0 9ed4 9ed7
9ed8 9eda 9ede 9ee2 9ee5 9ee9 9eea 9eec
9ef0 9ef4 9ef8 9efc 9f00 9f04 9f08 9f0c
9f10 9f14 9f18 9f1c 9f20 9f24 9f30 9f34
9f39 9f3d 9f40 9f41 9f46 9f4a 9f4e 9f51
9f54 9f58 9f5a 9f5e 9f62 9f65 9f68 9f6c
9f6e 9f72 9f76 9f79 9f7b 1 9f7f 9f83
9f87 9f8a 9f8e 9f92 9f96 9f9a 9f9d 9fa1
9fa5 9fa8 9fab 9fb0 9fb3 9fb6 9fb9 9fba
9fbf 9fc0 1 9fc2 9fc7 9fcb 9fcf 9fd2
9fd7 9fdc 9fdf 9fe3 9fe4 9fe9 9fec 9ff1
9ff2 9ff7 9ffa 9fff a000 a005 a008 a00c
a00d a012 a015 a01a a01b a020 a023 a027
a02b a02e a031 a032 a034 a035 a03a a03b
a040 a042 a046 a049 a04b a04f a051 a05d
a05f a061 a062 a067 a06b a06d a079 a07b
a07d a081 a085 a089 a08d a091 a095 a099
a09d a0a1 a0a5 a0a9 a0ad a0b1 a0b5 a0b9
a0bd a0c1 a0cd a0d1 a0d6 a0da a0dd a0de
a0e3 a0e7 a0eb a0ee a0f1 a0f5 a0f7 a0fb
a0ff a102 a105 a109 a10b a10f a113 a116
a118 1 a11c a120 a124 a127 a12b a12f
a133 a137 a13a a13e a142 a145 a148 a14d
a150 a153 a156 a157 a15c a15d 1 a15f
a164 a168 a16c a16f a174 a179 a17c a180
a181 a186 a189 a18e a18f a194 a197 a19c
a19d a1a2 a1a5 a1a9 a1aa a1af a1b2 a1b7
a1b8 a1bd a1c0 a1c4 a1c8 a1cb a1ce a1cf
a1d1 a1d2 a1d7 a1d8 a1dd a1df a1e3 a1e6
a1e8 a1ec a1ee a1fa a1fc a1fe a1ff a204
a208 a20a a216 a218 a21a a21e a222 a225
a229 a22d a230 a234 a237 a23b a23e a23f
a244 a247 a24b a24f a252 a253 a255 a258
a25b a25c a261 1 a264 a269 a26d a271
a275 a281 a285 a28a a28e a291 a292 a297
a29b a29f a2a2 a2a5 a2a9 a2ab a2af a2b3
a2b6 a2b9 a2bd a2bf a2c3 a2c7 a2ca a2cc
1 a2d0 a2d4 a2d8 a2db a2df a2e3 a2e7
a2eb a2ee a2f2 a2f6 a2f9 a2fc a301 a304
a307 a30a a30b a310 a311 1 a313 a318
a31c a320 a323 a328 a32d a330 a334 a335
a33a a33d a342 a343 a348 a34b a350 a351
a356 a359 a35d a35e a363 a366 a36b a36c
a371 a374 a378 a37c a37f a382 a383 a385
a386 a38b a38c a391 a393 a397 a39a a39c
a3a0 a3a2 a3ae a3b0 a3b2 a3b3 a3b8 a3bc
a3be a3ca a3cc a3ce a3d2 a3d5 a3d7 a3db
a3df a3e3 a3e7 a3eb a3ef a3f3 a3f7 a3fb
a3ff a403 a407 a40b a40f a413 a417 a41b
a41f a423 a427 a42b a42f a433 a437 a43b
a43f a443 a447 a44b a44f a453 a457 a45b
a45f a46b a46f a473 a476 a47a a47e a480
1 a484 a488 a48c a48f a493 a497 a49b
a49f a4a2 a4a6 a4aa a4ad a4b0 a4b5 a4b8
a4bb a4be a4bf a4c4 a4c5 1 a4c7 a4cc
a4d0 a4d4 a4d7 a4dc a4e1 a4e4 a4e8 a4e9
a4ee a4f1 a4f6 a4f7 a4fc a4ff a504 a505
a50a a50d a511 a512 a517 a51a a51f a520
a525 a528 a52c a530 a533 a536 a537 a539
a53a a53f a540 a545 a547 a54b a54e a550
a554 a556 a562 a564 a566 a567 a56c a570
a572 a57e a580 a584 a588 a58b a58f a592
a596 a599 a59a a59f a5a2 a5a6 a5a9 a5aa
a5af a5b2 1 a5b5 a5ba a5be a5c2 a5c5
a5c9 a5cd a5d0 a5d1 a5d3 a5d7 a5db a5de
a5e2 a5e3 a5e5 a5e9 a5ed a5f1 a5f5 a601
a605 a60a a60e a611 a612 a617 a61b a61f
a622 a625 a629 a62b a62f a633 a636 a639
a63d a63f a643 a647 a64a a64c 1 a650
a654 a658 a65b a65f a663 a667 a66b a66e
a672 a676 a679 a67c a681 a684 a687 a68a
a68b a690 a691 1 a693 a698 a69c a6a0
a6a3 a6a8 a6ad a6b0 a6b4 a6b5 a6ba a6bd
a6c2 a6c3 a6c8 a6cb a6d0 a6d1 a6d6 a6d9
a6dd a6de a6e3 a6e6 a6eb a6ec a6f1 a6f4
a6f8 a6fc a6ff a702 a703 a705 a706 a70b
a70c a711 a713 a717 a71a a71c a720 a722
a72e a730 a732 a733 a738 a73c a73e a74a
a74c a750 a754 a758 a75c a760 a764 a768
a76c a770 a774 a778 a784 a788 a78d a791
a794 a795 a79a a79e a7a2 a7a5 a7a8 a7ac
a7ae a7b2 a7b6 a7b9 a7bc a7c0 a7c2 a7c6
a7ca a7cd a7cf 1 a7d3 a7d7 a7db a7de
a7e2 a7e6 a7ea a7ee a7f1 a7f5 a7f9 a7fc
a7ff a804 a807 a80a a80d a80e a813 a814
1 a816 a81b a81f a823 a826 a82b a830
a833 a837 a838 a83d a840 a845 a846 a84b
a84e a853 a854 a859 a85c a860 a861 a866
a869 a86e a86f a874 a877 a87b a87f a882
a885 a886 a888 a889 a88e a88f a894 a896
a89a a89d a89f a8a3 a8a5 a8b1 a8b3 a8b5
a8b6 a8bb a8bf a8c1 a8cd a8cf a8d3 a8d7
a8db a8df a8e3 a8e7 a8eb a8ef a8fb a8ff
a904 a908 a90b a90c a911 a915 a919 a91c
a91f a923 a925 a929 a92d a930 a933 a937
a939 a93d a941 a944 a946 1 a94a a94e
a952 a955 a959 a95d a961 a965 a968 a96c
a970 a973 a976 a97b a97e a981 a984 a985
a98a a98b 1 a98d a992 a996 a99a a99d
a9a2 a9a7 a9aa a9ae a9af a9b4 a9b7 a9bc
a9bd a9c2 a9c5 a9ca a9cb a9d0 a9d3 a9d7
a9d8 a9dd a9e0 a9e5 a9e6 a9eb a9ee a9f2
a9f6 a9f9 a9fc a9fd a9ff aa00 aa05 aa06
aa0b aa0d aa11 aa14 aa16 aa1a aa1c aa28
aa2a aa2c aa2d aa32 aa36 aa38 aa44 aa46
aa48 aa4c aa50 aa53 aa57 aa5b aa5e aa5f
aa61 aa65 aa69 aa6c aa70 aa71 aa73 aa77
aa7b aa7f aa83 aa87 aa8b aa8f aa93 aa97
aaa3 aaa7 aaac aab0 aab3 aab4 aab9 aabd
aac1 aac4 aac7 aacb aacd aad1 aad5 aad8
aadb aadf aae1 aae5 aae9 aaec aaee 1
aaf2 aaf6 aafa aafd ab01 ab05 ab09 ab0d
ab10 ab14 ab18 ab1b ab1e ab23 ab26 ab29
ab2c ab2d ab32 ab33 1 ab35 ab3a ab3e
ab42 ab45 ab4a ab4f ab52 ab56 ab57 ab5c
ab5f ab64 ab65 ab6a ab6d ab72 ab73 ab78
ab7b ab7f ab80 ab85 ab88 ab8d ab8e ab93
ab96 ab9a ab9e aba1 aba4 aba5 aba7 aba8
abad abae abb3 abb5 abb9 abbc abbe abc2
abc4 abd0 abd2 abd4 abd5 abda abde abe0
abec abee abf2 abf6 abfa abfe ac02 ac06
ac0a ac0e ac12 ac16 ac1a ac26 ac2a ac2f
ac33 ac36 ac37 ac3c ac40 ac44 ac47 ac4a
ac4e ac50 ac54 ac58 ac5b ac5e ac62 ac64
ac68 ac6c ac6f ac71 1 ac75 ac79 ac7d
ac80 ac84 ac88 ac8c ac90 ac93 ac97 ac9b
ac9e aca1 aca6 aca9 acac acaf acb0 acb5
acb6 1 acb8 acbd acc1 acc5 acc8 accd
acd2 acd5 acd9 acda acdf ace2 ace7 ace8
aced acf0 acf5 acf6 acfb acfe ad02 ad03
ad08 ad0b ad10 ad11 ad16 ad19 ad1d ad21
ad24 ad27 ad28 ad2a ad2b ad30 ad31 ad36
ad38 ad3c ad3f ad41 ad45 ad47 ad53 ad55
ad57 ad58 ad5d ad61 ad63 ad6f ad71 ad73
ad77 ad7b ad7e ad80 ad84 ad88 ad8b ad8f
ad93 ad96 ad97 ad99 ad9c ad9f ada0 ada5
ada9 adad adb0 adb1 adb3 adb6 adb9 adba
adbf adc2 adc6 adc9 adca adcf add2 1
add5 adda adde ade2 ade6 adea adee adf2
adf6 ae02 ae06 ae0a ae0d ae11 ae15 ae17
1 ae1b ae1f ae23 ae26 ae2a ae2e ae32
ae36 ae39 ae3d ae41 ae44 ae47 ae4c ae4f
ae52 ae55 ae56 ae5b ae5c 1 ae5e ae63
ae67 ae6b ae6e ae73 ae78 ae7b ae7f ae80
ae85 ae88 ae8d ae8e ae93 ae96 ae9b ae9c
aea1 aea4 aea8 aea9 aeae aeb1 aeb6 aeb7
aebc aebf aec3 aec7 aeca aecd aece aed0
aed1 aed6 aed7 aedc aede aee2 aee5 aee7
aeeb aeed aef9 aefb aefd aefe af03 af07
af09 af15 af17 af1b af1f af22 af26 af29
af2d af30 af31 af36 af39 af3d af41 af44
af45 af47 af4a af4d af4e af53 1 af56
af5b af5f af63 af67 af6b af6f af7b af7f
af84 af88 af8b af8c af91 af95 af99 af9c
af9f afa3 afa5 afa9 afad afb0 afb3 afb7
afb9 afbd afc1 afc4 afc6 1 afca afce
afd2 afd5 afd9 afdd afe1 afe5 afe8 afec
aff0 aff3 aff6 affb affe b001 b004 b005
b00a b00b 1 b00d b012 b016 b01a b01d
b022 b027 b02a b02e b02f b034 b037 b03c
b03d b042 b045 b04a b04b b050 b053 b057
b058 b05d b060 b065 b066 b06b b06e b072
b076 b079 b07c b07d b07f b080 b085 b086
b08b b08d b091 b094 b096 b09a b09c b0a8
b0aa b0ac b0ad b0b2 b0b6 b0b8 b0c4 b0c6
b0ca b0cc b0d0 b0d4 b0d7 b0db b0de b0e2
b0e5 b0e6 b0eb b0ee b0f2 b0f6 b0f9 b0fa
b0fc b0ff b102 b103 b108 1 b10b b110
b114 b118 b11d b11f b123 b127 b12a b12e
b132 b134 1 b138 b13c b140 b143 b147
b14b b14f b153 b156 b15a b15e b161 b164
b169 b16c b16f b172 b173 b178 b179 1
b17b b180 b184 b188 b18b b190 b195 b198
b19c b19d b1a2 b1a5 b1aa b1ab b1b0 b1b3
b1b8 b1b9 b1be b1c1 b1c5 b1c6 b1cb b1ce
b1d3 b1d4 b1d9 b1dc b1e0 b1e4 b1e7 b1ea
b1eb b1ed b1ee b1f3 b1f4 b1f9 b1fb b1ff
b202 b204 b208 b20a b216 b218 b21a b21b
b220 b224 b226 b232 b234 b238 b23c b23f
b243 b247 b24a b24d b252 b255 b258 b25b
b25c b261 b262 1 b264 b269 b26d b271
b274 b279 b27e b281 b285 b286 b28b b28e
b293 b294 b299 b29c b2a1 b2a2 b2a7 b2aa
b2ae b2b2 b2b6 b2ba b2bd b2be b2c0 b2c5
b2c6 b2c8 b2c9 b2ce b2d1 b2d6 b2d7 b2dc
b2df b2e4 b2e5 b2ea b2ed b2f1 b2f2 b2f7
b2fa b2ff b300 b305 b306 b30b b30d b311
b314 b318 b31c b31f b323 b327 b32a b32d
b332 b335 b338 b33b b33c b341 b342 1
b344 b349 b34d b351 b354 b359 b35e b361
b365 b366 b36b b36c b371 b373 b377 b37a
b37e b382 b385 b389 b38d b390 b394 b398
b399 b39e b3a0 b3a4 b3a8 b3ab b3ad b3b1
b3b4 b3b8 b3bb b3be b3bf b3c4 b3c8 b3cc
b3d0 b3d3 b3d7 b3db b3df b3e3 b3e7 b3eb
b3ef b3f3 b3f7 b3fb b3ff b400 b402 b406
b40a b40e b412 b416 b41a b426 b42a b42f
b433 b436 b437 b43c b440 b444 b447 b44a
b44e b450 b454 b458 b45b b45e b462 b464
b468 b46c b46f b471 1 b475 b479 b47d
b480 b484 b488 b48c b490 b493 b497 b49b
b49e b4a1 b4a6 b4a9 b4ac b4af b4b0 b4b5
b4b6 1 b4b8 b4bd b4c1 b4c5 b4c8 b4cd
b4d2 b4d5 b4d9 b4da b4df b4e2 b4e7 b4e8
b4ed b4f0 b4f5 b4f6 b4fb b4fe b502 b503
b508 b50b b510 b511 b516 b519 b51d b521
b524 b527 b528 b52a b52b b530 b531 b536
b538 b53c b53f b541 b545 b547 b553 b555
b557 b558 b55d b561 b563 b56f b571 b575
b57a b57e b582 b585 b588 b589 b58e b592
b596 b59a b59e b5a2 b5a6 b5aa b5ae b5b2
b5b6 b5ba b5be b5c2 b5c6 b5ca b5ce b5d2
b5d6 b5da b5de b5e2 b5e6 b5ea b5ee b5f2
b5f6 b5fa b5fe b602 b606 b609 b60a b60c
b610 b614 b617 b618 b61a b61d b620 b623
b624 b629 b62c b630 b634 b637 b638 b63a
b63e b641 b645 b648 b649 b64b b64c b651
b654 b658 b65c b65f b660 b662 b666 b669
b66d b670 b671 b673 b674 b679 1 b67c
b681 1 b684 b689 b68c b690 b694 b697
b698 b69a b69d b6a0 b6a1 b6a6 b6aa b6ae
b6b2 b6b6 b6ba b6be b6c2 b6c6 b6ca b6ce
b6d2 b6d6 b6da b6de b6e2 b6e6 b6ea b6ee
b6f2 b6f6 b6fa b6fe b702 b706 b70a b70e
b712 b716 b71a b71e b722 b726 b72a b72e
b732 b736 b73a b746 b74a b74f b753 b756
b757 b75c b760 b764 b767 b76a b76e b770
b774 b778 b77b b77e b782 b784 b788 b78c
b78f b791 1 b795 b799 b79d b7a0 b7a4
b7a8 b7ac b7b0 b7b3 b7b7 b7bb b7be b7c1
b7c6 b7c9 b7cc b7cf b7d0 b7d5 b7d6 1
b7d8 b7dd b7e1 b7e5 b7e8 b7ed b7f2 b7f5
b7f9 b7fa b7ff b802 b807 b808 b80d b810
b815 b816 b81b b81e b822 b823 b828 b82b
b830 b831 b836 b839 b83d b841 b844 b847
b848 b84a b84b b850 b851 b856 b858 b85c
b85f b861 b865 b867 b873 b875 b877 b878
b87d b881 b883 b88f b891 b893 b897 b89b
b89f b8a3 b8a7 b8ab b8af b8b3 b8b7 b8bb
b8bf b8c3 b8c7 b8cb b8cf b8d3 b8d7 b8db
b8df b8e3 b8e7 b8eb b8ef b8f3 b8f7 b8fb
b8ff b903 b907 b90b b90f b913 b917 b91b
b91f b923 b927 b92b b92f b93b b93f b944
b948 b94b b94c b951 b955 b959 b95c b95f
b963 b965 b969 b96d b970 b973 b977 b979
b97d b981 b984 b986 1 b98a b98e b992
b995 b999 b99d b9a1 b9a5 b9a8 b9ac b9b0
b9b3 b9b6 b9bb b9be b9c1 b9c4 b9c5 b9ca
b9cb 1 b9cd b9d2 b9d6 b9da b9dd b9e2
b9e7 b9ea b9ee b9ef b9f4 b9f7 b9fc b9fd
ba02 ba05 ba0a ba0b ba10 ba13 ba17 ba18
ba1d ba20 ba25 ba26 ba2b ba2e ba32 ba36
ba39 ba3c ba3d ba3f ba40 ba45 ba46 ba4b
ba4d ba51 ba54 ba56 ba5a ba5c ba68 ba6a
ba6c ba6d ba72 ba76 ba78 ba84 ba86 ba88
ba8c ba90 ba93 ba95 ba99 ba9d baa1 baa5
baa9 baad bab1 bab5 bab9 babd bac1 bac5
bac9 bacd bad1 bad5 bad9 badd bae1 bae5
bae9 baed baf1 baf5 baf9 bafd bb01 bb05
bb09 bb0d bb11 bb15 bb19 bb25 bb29 bb2e
bb32 bb35 bb36 bb3b bb3f bb43 bb46 bb49
bb4d bb4f bb53 bb57 bb5a bb5d bb61 bb63
bb67 bb6b bb6e bb70 1 bb74 bb78 bb7c
bb7f bb83 bb87 bb8b bb8f bb92 bb96 bb9a
bb9d bba0 bba5 bba8 bbab bbae bbaf bbb4
bbb5 1 bbb7 bbbc bbc0 bbc4 bbc7 bbcc
bbd1 bbd4 bbd8 bbd9 bbde bbe1 bbe6 bbe7
bbec bbef bbf4 bbf5 bbfa bbfd bc01 bc02
bc07 bc0a bc0f bc10 bc15 bc18 bc1c bc20
bc23 bc26 bc27 bc29 bc2a bc2f bc30 bc35
bc37 bc3b bc3e bc40 bc44 bc46 bc52 bc54
bc56 bc57 bc5c bc60 bc62 bc6e bc70 bc72
bc76 bc7a bc7d bc81 bc85 bc88 bc89 bc8b
bc8e bc91 bc92 bc97 bc9a bc9e bca2 bca5
bca6 bca8 bcab bcae bcaf bcb4 1 bcb7
bcbc bcc0 bcc3 bcc7 bccb bccd bcd1 bcd5
bcd8 bcd9 bcdb bcde bce1 bce2 bce7 bceb
bcef bcf3 bcf6 bcf7 bcf9 bcfd bcff bd03
bd07 bd0a bd0e bd12 bd16 bd1a bd1e bd22
bd25 bd26 bd28 bd2c bd30 bd33 bd34 bd36
bd3a bd3e bd41 bd42 bd44 bd48 bd4c bd4f
bd50 bd52 bd56 bd5a bd5d bd5e bd60 bd64
bd68 bd6b bd6c bd6e bd72 bd76 bd79 bd7a
bd7c bd80 bd84 bd87 bd88 bd8a bd8e bd92
bd96 bd97 bd99 bd9d bda1 bda5 bda8 bda9
bdab bdaf bdb2 bdb6 bdb9 bdba bdbf bdc3
bdc7 bdcc bdce bdd2 bdd6 bdd9 bddd bde1
bde3 1 bde7 bdeb bdef bdf2 bdf6 bdfa
bdfe be02 be05 be09 be0d be10 be13 be18
be1b be1e be21 be22 be27 be28 1 be2a
be2f be33 be37 be3a be3f be44 be47 be4b
be4c be51 be54 be59 be5a be5f be62 be67
be68 be6d be70 be74 be75 be7a be7d be82
be83 be88 be8b be8f be93 be96 be99 be9a
be9c be9d bea2 bea3 bea8 beaa beae beb1
beb3 beb7 beb9 bec5 bec7 bec9 beca becf
bed3 bed5 bee1 bee3 bee7 beeb beee bef2
bef6 bef9 befc bf01 bf04 bf07 bf0a bf0b
bf10 bf11 1 bf13 bf18 bf1c bf20 bf23
bf28 bf2d bf30 bf34 bf35 bf3a bf3d bf42
bf43 bf48 bf4b bf50 bf51 bf56 bf59 bf5d
bf61 bf65 bf69 bf6c bf6d bf6f bf74 bf75
bf77 bf78 bf7d bf7e bf83 bf85 bf89 bf8c
bf90 bf94 bf97 bf9b bf9f bfa2 bfa5 bfaa
bfad bfb0 bfb3 bfb4 bfb9 bfba 1 bfbc
bfc1 bfc5 bfc9 bfcc bfd1 bfd6 bfd9 bfdd
bfde bfe3 bfe4 bfe9 bfeb bfef bff2 bff6
bffa bffd c001 c005 c008 c00c c00d c012
c016 c018 c01c c020 c023 c024 c026 c029
c02c c02d c032 c036 c03a c03f c041 c045
c049 c04c c050 c054 c056 1 c05a c05e
c062 c065 c069 c06d c071 c075 c078 c07c
c080 c083 c086 c08b c08e c091 c094 c095
c09a c09b 1 c09d c0a2 c0a6 c0aa c0ad
c0b2 c0b7 c0ba c0be c0bf c0c4 c0c7 c0cc
c0cd c0d2 c0d5 c0da c0db c0e0 c0e3 c0e7
c0e8 c0ed c0f0 c0f5 c0f6 c0fb c0fe c102
c106 c109 c10c c10d c10f c110 c115 c116
c11b c11d c121 c124 c126 c12a c12c c138
c13a c13c c13d c142 c146 c148 c154 c156
c15a c15e c161 c165 c169 c16c c16f c174
c177 c17a c17d c17e c183 c184 1 c186
c18b c18f c193 c196 c19b c1a0 c1a3 c1a7
c1a8 c1ad c1b0 c1b5 c1b6 c1bb c1be c1c3
c1c4 c1c9 c1cc c1d0 c1d4 c1d8 c1d9 c1db
c1e0 c1e1 c1e3 c1e4 c1e9 c1ec c1f1 c1f2
c1f7 c1fa c1ff c200 c205 c208 c20c c20d
c212 c215 c21a c21b c220 c221 c226 c228
c22c c22f c233 c237 c23a c23e c242 c245
c248 c24d c250 c253 c256 c257 c25c c25d
1 c25f c264 c268 c26c c26f c274 c279
c27c c280 c281 c286 c287 c28c c28e c292
c295 c299 c29d c2a0 c2a4 c2a8 c2ab c2ac
c2ae c2b2 c2b6 c2b7 c2bc c2be c2c2 c2c6
c2c9 c2cb c2cf c2d3 c2d6 c2d7 c2d9 c2dc
c2df c2e0 c2e5 c2e9 c2ed c2f0 c2f1 c2f3
c2f6 c2f9 c2fa 1 c2ff c304 c308 c30c
c30f c310 c312 c315 c318 c319 1 c31e
c323 c327 c32a c32e c332 c336 c33a c33d
c33e c340 c344 c346 c34a c34d c351 c355
c358 c359 c35b c35e c361 c362 c367 c36a
c36e c372 c375 c376 c378 c37c c37f c383
c386 c387 c389 c38a c38f 1 c392 c397
c39b c39f c3a3 c3a6 c3a7 c3a9 c3ad c3af
c3b3 c3b7 c3bb c3bf c3c2 c3c3 c3c5 c3c8
c3cc c3d0 c3d3 c3d4 c3d6 c3d7 c3dc c3dd
c3df c3e3 c3e5 c3e9 c3ed c3f0 c3f4 c3f8
c3fb c3fc c3fe c401 c404 c405 c40a c40e
c412 c416 c419 c41a c41c c41f c422 c423
c428 c42c c42e c432 c436 c43a c43e c442
c445 c446 c448 c449 c44b c44e c451 c452
c457 c458 c45a c45e c460 c464 c468 c46b
c46f c473 c477 c47b c47f c483 c487 c48b
c48f c493 c497 c49b c49f c4a3 c4a7 c4ab
c4af c4b3 c4b7 c4bb c4bf c4c3 c4c7 c4cb
c4cf c4d3 c4d7 c4db c4df c4e3 c4e7 c4f3
c4f7 c4fc c500 c503 c504 c509 c50d c511
c514 c517 c51b c51d c521 c525 c528 c52b
c52f c531 c535 c539 c53c c53e 1 c542
c546 c54a c54d c551 c555 c559 c55d c560
c564 c568 c56b c56e c573 c576 c579 c57c
c57d c582 c583 1 c585 c58a c58e c592
c595 c59a c59f c5a2 c5a6 c5a7 c5ac c5af
c5b4 c5b5 c5ba c5bd c5c2 c5c3 c5c8 c5cb
c5cf c5d0 c5d5 c5d8 c5dd c5de c5e3 c5e6
c5ea c5ee c5f1 c5f4 c5f5 c5f7 c5f8 c5fd
c5fe c603 c605 c609 c60c c60e c612 c614
c620 c622 c624 c625 c62a c62e c630 c63c
c63e c640 c644 c648 c64b c64f c652 c656
c65a c65d c661 c665 c668 c66c c670 c674
c677 c678 c67a c67d c680 c681 c686 c68a
c68e c691 c692 c694 c697 c69a c69b c6a0
c6a4 c6a8 c6ab c6ac c6ae c6b1 c6b4 c6b5
1 c6ba c6bf 1 c6c2 c6c7 c6cb c6cf
c6d3 c6d6 c6da c6dc c6e0 c6e4 c6e8 c6eb
c6ef c6f3 c6f6 c6f7 c6f9 c6fd c701 c704
c705 c707 c70b c70d c711 c715 c718 c71c
c71f c723 c727 c72a c72e c732 c736 c73a
c73e c742 c746 c74a c74e c752 c756 c75a
c75e c762 c766 c76a c76e c772 c776 c77a
c77e c782 c786 c78a c78e c792 c796 c79a
c79e c7a2 c7a6 c7a9 c7ac c7af c7b2 c7b3
c7b5 c7b9 c7bd c7c1 c7c4 c7c5 c7c7 c7ca
c7cd c7ce c7d3 c7d7 c7db c7e0 c7e2 c7e6
c7ea c7ed c7f1 c7f5 c7f7 1 c7fb c7ff
c803 c806 c80a c80e c812 c816 c819 c81d
c821 c824 c827 c82c c82f c832 c835 c836
c83b c83c 1 c83e c843 c847 c84b c84e
c853 c858 c85b c85f c860 c865 c868 c86d
c86e c873 c876 c87b c87c c881 c884 c888
c889 c88e c891 c896 c897 c89c c89f c8a3
c8a7 c8aa c8ad c8ae c8b0 c8b1 c8b6 c8b7
c8bc c8be c8c2 c8c5 c8c7 c8cb c8cd c8d9
c8db c8dd c8de c8e3 c8e7 c8e9 c8f5 c8f7
c8fb c8ff c902 c906 c90a c90d c910 c915
c918 c91b c91e c91f c924 c925 1 c927
c92c c930 c934 c937 c93c c941 c944 c948
c949 c94e c951 c956 c957 c95c c95f c964
c965 c96a c96d c971 c975 c979 c97d c980
c981 c983 c988 c989 c98b c98c c991 c994
c999 c99a c99f c9a2 c9a7 c9a8 c9ad c9b0
c9b4 c9b5 c9ba c9bd c9c2 c9c3 c9c8 c9c9
c9ce c9d0 c9d4 c9d7 c9db c9df c9e2 c9e6
c9ea c9ed c9f0 c9f5 c9f8 c9fb c9fe c9ff
ca04 ca05 1 ca07 ca0c ca10 ca14 ca17
ca1c ca21 ca24 ca28 ca29 ca2e ca2f ca34
ca36 ca3a ca3d ca41 ca45 ca48 ca4c ca50
ca53 ca57 ca5b ca5c ca61 ca65 ca67 ca6b
ca6f ca72 ca73 ca75 ca78 ca7b ca7c ca81
ca85 ca89 ca8e ca90 ca94 ca98 ca9b ca9f
caa3 caa5 1 caa9 caad cab1 cab4 cab8
cabc cac0 cac4 cac7 cacb cacf cad2 cad5
cada cadd cae0 cae3 cae4 cae9 caea 1
caec caf1 caf5 caf9 cafc cb01 cb06 cb09
cb0d cb0e cb13 cb16 cb1b cb1c cb21 cb24
cb29 cb2a cb2f cb32 cb36 cb37 cb3c cb3f
cb44 cb45 cb4a cb4d cb51 cb55 cb58 cb5b
cb5c cb5e cb5f cb64 cb65 cb6a cb6c cb70
cb73 cb75 cb79 cb7b cb87 cb89 cb8b cb8c
cb91 cb95 cb97 cba3 cba5 cba9 cbad cbb0
cbb4 cbb8 cbbb cbbe cbc3 cbc6 cbc9 cbcc
cbcd cbd2 cbd3 1 cbd5 cbda cbde cbe2
cbe5 cbea cbef cbf2 cbf6 cbf7 cbfc cbff
cc04 cc05 cc0a cc0d cc12 cc13 cc18 cc1b
cc1f cc23 cc27 cc2b cc2e cc2f cc31 cc36
cc37 cc39 cc3a cc3f cc42 cc47 cc48 cc4d
cc50 cc55 cc56 cc5b cc5e cc62 cc63 cc68
cc6b cc70 cc71 cc76 cc77 cc7c cc7e cc82
cc85 cc89 cc8d cc90 cc94 cc98 cc9b cc9e
cca3 cca6 cca9 ccac ccad ccb2 ccb3 1
ccb5 ccba ccbe ccc2 ccc5 ccca cccf ccd2
ccd6 ccd7 ccdc ccdd cce2 cce4 cce8 cceb
ccef ccf3 ccf6 ccfa ccfe cd01 cd05 cd09
cd0a cd0f cd11 cd15 cd19 cd1c cd20 cd24
cd28 cd2c cd30 cd34 cd38 cd44 cd48 cd4d
cd51 cd54 cd55 cd5a cd5e cd62 cd65 cd68
cd6c cd6e cd72 cd76 cd79 cd7c cd80 cd82
cd86 cd8a cd8d cd8f 1 cd93 cd97 cd9b
cd9e cda2 cda6 cdaa cdae cdb1 cdb5 cdb9
cdbc cdbf cdc4 cdc7 cdca cdcd cdce cdd3
cdd4 1 cdd6 cddb cddf cde3 cde6 cdeb
cdf0 cdf3 cdf7 cdf8 cdfd ce00 ce05 ce06
ce0b ce0e ce13 ce14 ce19 ce1c ce20 ce21
ce26 ce29 ce2e ce2f ce34 ce37 ce3b ce3f
ce42 ce45 ce46 ce48 ce49 ce4e ce4f ce54
ce56 ce5a ce5d ce5f ce63 ce65 ce71 ce73
ce75 ce76 ce7b ce7f ce81 ce8d ce8f ce93
ce97 ce9b ce9f cea3 cea7 ceab ceaf ceb3
ceb7 cebb cebf cec3 cec7 cecb cecf ced3
ced7 cedb cedf cee3 cee7 ceeb ceef cefb
ceff cf04 cf08 cf0b cf0c cf11 cf15 cf19
cf1c cf1f cf23 cf25 cf29 cf2d cf30 cf33
cf37 cf39 cf3d cf41 cf44 cf46 1 cf4a
cf4e cf52 cf55 cf59 cf5d cf61 cf65 cf68
cf6c cf70 cf73 cf76 cf7b cf7e cf81 cf84
cf85 cf8a cf8b 1 cf8d cf92 cf96 cf9a
cf9d cfa2 cfa7 cfaa cfae cfaf cfb4 cfb7
cfbc cfbd cfc2 cfc5 cfca cfcb cfd0 cfd3
cfd7 cfd8 cfdd cfe0 cfe5 cfe6 cfeb cfee
cff2 cff6 cff9 cffc cffd cfff d000 d005
d006 d00b d00d d011 d014 d016 d01a d01c
d028 d02a d02c d02d d032 d036 d038 d044
d046 d04a d04e d052 d056 d05a d05e d062
d066 d06a d06e d072 d07e d082 d087 d08b
d08e d08f d094 d098 d09c d09f d0a2 d0a6
d0a8 d0ac d0b0 d0b3 d0b6 d0ba d0bc d0c0
d0c4 d0c7 d0c9 1 d0cd d0d1 d0d5 d0d8
d0dc d0e0 d0e4 d0e8 d0eb d0ef d0f3 d0f6
d0f9 d0fe d101 d104 d107 d108 d10d d10e
1 d110 d115 d119 d11d d120 d125 d12a
d12d d131 d132 d137 d13a d13f d140 d145
d148 d14d d14e d153 d156 d15a d15b d160
d163 d168 d169 d16e d171 d175 d179 d17c
d17f d180 d182 d183 d188 d189 d18e d190
d194 d197 d199 d19d d19f d1ab d1ad d1af
d1b0 d1b5 d1b9 d1bb d1c7 d1c9 d1cd d1d1
d1d5 d1d9 d1dd d1e1 d1e5 d1e9 d1ed d1f1
d1f5 d201 d205 d20a d20e d211 d212 d217
d21b d21f d222 d225 d229 d22b d22f d233
d236 d239 d23d d23f d243 d247 d24a d24c
1 d250 d254 d258 d25b d25f d263 d267
d26b d26e d272 d276 d279 d27c d281 d284
d287 d28a d28b d290 d291 1 d293 d298
d29c d2a0 d2a3 d2a8 d2ad d2b0 d2b4 d2b5
d2ba d2bd d2c2 d2c3 d2c8 d2cb d2d0 d2d1
d2d6 d2d9 d2dd d2de d2e3 d2e6 d2eb d2ec
d2f1 d2f4 d2f8 d2fc d2ff d302 d303 d305
d306 d30b d30c d311 d313 d317 d31a d31c
d320 d322 d32e d330 d332 d333 d338 d33c
d33e d34a d34c d350 d354 d358 d35b d35c
d35e d361 d364 d365 d36a d36e d372 d376
d37a d37d d37e d380 d383 d387 d38b d38e
d38f d391 d392 d397 d39b d39f d3a4 d3a8
d3ac d3b0 d3b4 d3b8 d3bc d3bd d3bf d3c3
d3c7 d3cc d3d0 d3d4 d3d8 d3dc d3e0 d3e4
d3e5 d3e7 d3eb d3ef d3f3 d3f7 d3fb d3ff
d403 d407 d413 d417 d41c d420 d423 d424
d429 d42d d431 d434 d437 d43b d43d d441
d445 d448 d44b d44f d451 d455 d459 d45c
d45e 1 d462 d466 d46a d46d d471 d475
d479 d47d d480 d484 d488 d48b d48e d493
d496 d499 d49c d49d d4a2 d4a3 1 d4a5
d4aa d4ae d4b2 d4b5 d4ba d4bf d4c2 d4c6
d4c7 d4cc d4cf d4d4 d4d5 d4da d4dd d4e2
d4e3 d4e8 d4eb d4ef d4f0 d4f5 d4f8 d4fd
d4fe d503 d506 d50a d50e d511 d514 d515
d517 d518 d51d d51e d523 d525 d529 d52c
d52e d532 d534 d540 d542 d544 d545 d54a
d54e d550 d55c d55e d562 d566 d569 d56a
d56c d56f d572 d573 d578 d57b d57f d583
d586 d587 d589 d58c d58f d590 d595 1
d598 d59d d5a1 d5a5 d5a9 d5ad d5b1 d5b5
d5b9 d5bd d5c1 d5c5 d5c9 d5cd d5d1 d5d5
d5d9 d5dd d5e1 d5ed d5f1 d5f6 d5fa d5fd
d5fe d603 d607 d60b d60e d611 d615 d617
d61b d61f d622 d625 d629 d62b d62f d633
d636 d638 1 d63c d640 d644 d647 d64b
d64f d653 d657 d65a d65e d662 d665 d668
d66d d670 d673 d676 d677 d67c d67d 1
d67f d684 d688 d68c d68f d694 d699 d69c
d6a0 d6a1 d6a6 d6a9 d6ae d6af d6b4 d6b7
d6bc d6bd d6c2 d6c5 d6c9 d6ca d6cf d6d2
d6d7 d6d8 d6dd d6e0 d6e4 d6e8 d6eb d6ee
d6ef d6f1 d6f2 d6f7 d6f8 d6fd d6ff d703
d706 d708 d70c d70e d71a d71c d71e d71f
d724 d728 d72a d736 d738 d73c d73e d742
d746 d749 d74a d74c d74f d752 d753 d758
d75c d760 d764 d768 d76c d770 d774 d778
d77c d780 d784 d788 d78c d798 d79c d7a1
d7a5 d7a8 d7a9 d7ae d7b2 d7b6 d7b9 d7bc
d7c0 d7c2 d7c6 d7ca d7cd d7d0 d7d4 d7d6
d7da d7de d7e1 d7e3 1 d7e7 d7eb d7ef
d7f2 d7f6 d7fa d7fe d802 d805 d809 d80d
d810 d813 d818 d81b d81e d821 d822 d827
d828 1 d82a d82f d833 d837 d83a d83f
d844 d847 d84b d84c d851 d854 d859 d85a
d85f d862 d867 d868 d86d d870 d874 d875
d87a d87d d882 d883 d888 d88b d88f d893
d896 d899 d89a d89c d89d d8a2 d8a3 d8a8
d8aa d8ae d8b1 d8b3 d8b7 d8b9 d8c5 d8c7
d8c9 d8ca d8cf d8d3 d8d5 d8e1 d8e3 d8e7
d8eb d8ef d8f2 d8f3 d8f5 d8f9 d8fd d8ff
d903 d907 d90b d90e d90f d911 d914 d917
d918 d91d d921 d925 d929 d92d d931 d935
d939 d93d d941 d945 d949 d94d d951 d95d
d961 d966 d96a d96d d96e d973 d977 d97b
d97e d981 d985 d987 d98b d98f d992 d995
d999 d99b d99f d9a3 d9a6 d9a8 1 d9ac
d9b0 d9b4 d9b7 d9bb d9bf d9c3 d9c7 d9ca
d9ce d9d2 d9d5 d9d8 d9dd d9e0 d9e3 d9e6
d9e7 d9ec d9ed 1 d9ef d9f4 d9f8 d9fc
d9ff da04 da09 da0c da10 da11 da16 da19
da1e da1f da24 da27 da2c da2d da32 da35
da39 da3a da3f da42 da47 da48 da4d da50
da54 da58 da5b da5e da5f da61 da62 da67
da68 da6d da6f da73 da76 da78 da7c da7e
da8a da8c da8e da8f da94 da98 da9a daa6
daa8 daac dab0 dab4 dab7 dab8 daba dabe
dac0 dac4 dac8 dacc dad0 dad4 dad8 dadc
dae0 dae4 dae8 daf4 daf8 dafd db01 db04
db05 db0a db0e db12 db15 db18 db1c db1e
db22 db26 db29 db2c db30 db32 db36 db3a
db3d db3f 1 db43 db47 db4b db4e db52
db56 db5a db5e db61 db65 db69 db6c db6f
db74 db77 db7a db7d db7e db83 db84 1
db86 db8b db8f db93 db96 db9b dba0 dba3
dba7 dba8 dbad dbb0 dbb5 dbb6 dbbb dbbe
dbc3 dbc4 dbc9 dbcc dbd0 dbd1 dbd6 dbd9
dbde dbdf dbe4 dbe7 dbeb dbef dbf2 dbf5
dbf6 dbf8 dbf9 dbfe dbff dc04 dc06 dc0a
dc0d dc0f dc13 dc15 dc21 dc23 dc25 dc26
dc2b dc2f dc31 dc3d dc3f dc43 dc47 dc4b
dc4e dc4f dc51 dc55 dc59 dc5d dc61 dc64
dc65 dc67 dc6b dc6d dc71 dc75 dc78 dc7a
dc7e dc81 dc83 dc87 dc8a dc8c dc90 dc94
dc97 dc9b dc9f dca2 dca6 dcaa dcae dcb2
dcb3 dcb5 dcb9 dcbb dcbf dcc6 dcca dcce
dcd3 dcd5 dcd9 dcdd dce0 dce4 dce8 dcea
1 dcee dcf2 dcf6 dcf9 dcfd dd01 dd05
dd09 dd0c dd10 dd14 dd17 dd1a dd1f dd22
dd25 dd28 dd29 dd2e dd2f 1 dd31 dd36
dd3a dd3e dd41 dd46 dd4b dd4e dd52 dd53
dd58 dd5b dd60 dd61 dd66 dd69 dd6e dd6f
dd74 dd77 dd7b dd7c dd81 dd84 dd89 dd8a
dd8f dd92 dd96 dd9a dd9d dda0 dda1 dda3
dda4 dda9 ddaa ddaf ddb1 ddb5 ddb8 ddba
ddbe ddc0 ddcc ddce ddd0 ddd1 ddd6 ddda
dddc dde8 ddea ddee ddf1 ddf5 ddf9 ddfd
de00 de01 de03 de06 de09 de0a de0f de13
de17 de1b de1f de23 de26 de27 de29 de2d
de30 de34 de37 de38 de3a de3b de40 de44
de48 de4c de4f de50 de52 de55 de59 de5d
de60 de61 de63 de64 de69 de6d de71 de75
de78 de79 de7b de7e de81 de82 de87 de8a
de8e de92 de95 de96 de98 de9b de9e de9f
dea4 1 dea7 deac deb0 deb3 deb4 deb9
debc 1 debf dec4 dec8 decc ded0 ded4
ded8 dedc dee0 dee4 dee8 deec def0 def4
def8 defc df00 df04 df08 df0c df10 df14
df18 df1c df20 df24 df28 df2c df2f df30
df32 df35 df38 df39 df3e df42 df46 df49
df4a df4c df4f df52 df53 1 df58 df5d
df61 df64 df68 df6c df6e df72 df76 df79
df7a df7c df7f df82 df83 df88 df8c df90
df94 df97 df98 df9a df9e dfa0 dfa4 dfa8
dfab dfaf dfb3 dfb7 dfbb dfbf dfc3 dfc6
dfc7 dfc9 dfcd dfd1 dfd4 dfd5 dfd7 dfdb
dfdf dfe2 dfe3 dfe5 dfe9 dfed dff0 dff1
dff3 dff7 dffb dffe dfff e001 e005 e009
e00c e00d e00f e013 e017 e01a e01b e01d
e021 e025 e028 e029 e02b e02f e033 e037
e038 e03a e03e e042 e046 e049 e04a e04c
e050 e053 e057 e05a e05b e060 e064 e068
e06b e06f e073 e076 e079 e07e e081 e084
e087 e088 e08d e08e 1 e090 e095 e099
e09d e0a0 e0a5 e0aa e0ad e0b1 e0b2 e0b7
e0ba e0bf e0c0 e0c5 e0c8 e0cd e0ce e0d3
e0d6 e0da e0de e0e2 e0e6 e0e9 e0ea e0ec
e0f1 e0f2 e0f4 e0f5 e0fa e0fb e100 e102
e106 e109 e10d e111 e114 e118 e11c e11f
e122 e127 e12a e12d e130 e131 e136 e137
1 e139 e13e e142 e146 e149 e14e e153
e156 e15a e15b e160 e161 e166 e168 e16c
e16f e173 e177 e17a e17e e182 e185 e189
e18a e18f e193 e195 e199 e19d e1a0 e1a1
e1a3 e1a6 e1a9 e1aa e1af e1b3 e1b7 e1ba
e1be e1c2 e1c5 e1c8 e1cd e1d0 e1d3 e1d6
e1d7 e1dc e1dd 1 e1df e1e4 e1e8 e1ec
e1ef e1f4 e1f9 e1fc e200 e201 e206 e209
e20e e20f e214 e217 e21c e21d e222 e225
e229 e22d e231 e232 e234 e239 e23a e23c
e23d e242 e245 e24a e24b e250 e253 e258
e259 e25e e261 e265 e266 e26b e26e e273
e274 e279 e27a e27f e281 e285 e288 e28c
e290 e293 e297 e29b e29e e2a1 e2a6 e2a9
e2ac e2af e2b0 e2b5 e2b6 1 e2b8 e2bd
e2c1 e2c5 e2c8 e2cd e2d2 e2d5 e2d9 e2da
e2df e2e0 e2e5 e2e7 e2eb e2ee e2f2 e2f6
e2f9 e2fd e301 e304 e305 e307 e30b e30f
e310 e315 e317 e31b e31f e322 e326 e32a
e32f e334 e338 e33c e340 e343 e346 e34a
e34e e352 e356 e35a e35e e362 e366 e36a
e36e e372 e37e e382 e387 e38b e38e e38f
e394 e398 e39c e39f e3a2 e3a6 e3a8 e3ac
e3b0 e3b3 e3b6 e3ba e3bc e3c0 e3c4 e3c7
e3c9 1 e3cd e3d1 e3d5 e3d8 e3dc e3e0
e3e4 e3e8 e3eb e3ef e3f3 e3f6 e3f9 e3fe
e401 e404 e407 e408 e40d e40e 1 e410
e415 e419 e41d e420 e425 e42a e42d e431
e432 e437 e43a e43f e440 e445 e448 e44d
e44e e453 e456 e45a e45b e460 e463 e468
e469 e46e e471 e475 e479 e47c e47f e480
e482 e483 e488 e489 e48e e490 e494 e497
e499 e49d e49f e4ab e4ad e4af e4b0 e4b5
e4b9 e4bb e4c7 e4c9 e4cd e4d2 e4d6 e4da
e4dd e4e1 e4e5 e4e8 e4ec e4f0 e4f3 e4f7
e4fb e4fe e502 e506 e50a e50d e50e e510
e513 e516 e517 e51c e520 e524 e527 e528
e52a e52d e530 e531 e536 e53a e53e e541
e542 e544 e547 e54a e54b 1 e550 e555
1 e558 e55d e561 e565 e568 e569 e56b
e56e e571 e572 e577 e57b e57f e582 e583
e585 e588 e58b e58c 1 e591 e596 e59a
e59e e5a1 e5a2 e5a4 e5a7 e5aa e5ab 1
e5b0 e5b5 e5b9 e5bc e5c0 e5c4 e5c8 e5cc
e5cf e5d0 e5d2 e5d6 e5d8 e5dc e5df e5e3
e5e7 e5eb e5ee e5f2 e5f6 e5f9 e5fa e5fc
e600 e604 e607 e608 e60a e60e e612 e615
e619 e61b e61f e622 e626 e628 e62c e630
e633 e637 e63a e63e e642 e646 e64a e64e
e652 e656 e65a e65e e662 e666 e66a e66e
e672 e676 e67a e67e e682 e686 e68a e68e
e692 e696 e69a e69e e6a2 e6a6 e6aa e6ae
e6b2 e6b6 e6b9 e6bc e6bf e6c2 e6c3 e6c5
e6c9 e6cd e6d1 e6d4 e6d5 e6d7 e6da e6dd
e6de e6e3 e6e7 e6eb e6ee e6f2 e6f6 e6f9
e6fc e701 e704 e707 e70a e70b e710 e711
1 e713 e718 e71c e720 e723 e728 e72d
e730 e734 e735 e73a e73d e742 e743 e748
e74b e750 e751 e756 e759 e75d e761 e765
e769 e76c e76d e76f e774 e775 e777 e778
e77d e780 e785 e786 e78b e78e e793 e794
e799 e79c e7a0 e7a1 e7a6 e7a9 e7ae e7af
e7b4 e7b5 e7ba e7bc e7c0 e7c3 e7c7 e7cb
e7ce e7d2 e7d6 e7d9 e7dc e7e1 e7e4 e7e7
e7ea e7eb e7f0 e7f1 1 e7f3 e7f8 e7fc
e800 e803 e808 e80d e810 e814 e815 e81a
e81b e820 e822 e826 e829 e82d e831 e834
e838 e83c e83f e843 e847 e848 e84d e851
e853 e857 e85b e85e e85f e861 e864 e867
e868 e86d e871 e875 e878 e87c e880 e883
e886 e88b e88e e891 e894 e895 e89a e89b
1 e89d e8a2 e8a6 e8aa e8ad e8b2 e8b7
e8ba e8be e8bf e8c4 e8c7 e8cc e8cd e8d2
e8d5 e8da e8db e8e0 e8e3 e8e7 e8eb e8ef
e8f3 e8f6 e8f7 e8f9 e8fe e8ff e901 e902
e907 e90a e90f e910 e915 e918 e91d e91e
e923 e926 e92a e92b e930 e933 e938 e939
e93e e93f e944 e946 e94a e94d e951 e955
e958 e95c e960 e963 e966 e96b e96e e971
e974 e975 e97a e97b 1 e97d e982 e986
e98a e98d e992 e997 e99a e99e e99f e9a4
e9a5 e9aa e9ac e9b0 e9b3 e9b7 e9bb e9be
e9c2 e9c6 e9c9 e9cd e9d1 e9d2 e9d7 e9d9
e9dd e9e1 e9e5 e9e9 e9ed e9f1 e9f5 e9f9
e9fd ea01 ea05 ea09 ea0d ea11 ea15 ea19
ea1d ea21 ea25 ea29 ea2d ea31 ea35 ea39
ea3d ea41 ea45 ea49 ea4d ea59 ea5d ea62
ea66 ea69 ea6a ea6f ea73 ea77 ea7a ea7d
ea81 ea83 ea87 ea8b ea8e ea91 ea95 ea97
ea9b ea9f eaa2 eaa4 1 eaa8 eaac eab0
eab3 eab7 eabb eabf eac3 eac6 eaca eace
ead1 ead4 ead9 eadc eadf eae2 eae3 eae8
eae9 1 eaeb eaf0 eaf4 eaf8 eafb eb00
eb05 eb08 eb0c eb0d eb12 eb15 eb1a eb1b
eb20 eb23 eb28 eb29 eb2e eb31 eb35 eb36
eb3b eb3e eb43 eb44 eb49 eb4c eb50 eb54
eb57 eb5a eb5b eb5d eb5e eb63 eb64 eb69
eb6b eb6f eb72 eb74 eb78 eb7a eb86 eb88
eb8a eb8b eb90 eb94 eb96 eba2 eba4 eba6
ebaa ebae ebb1 ebb3 ebb7 ebba ebbc ebc0
ebc3 ebc7 ebcb ebcf ebd3 ebd7 ebdb ebdf
ebe3 ebef ebf3 ebf7 ebfa ebfe ec02 ec04
1 ec08 ec0c ec10 ec13 ec17 ec1b ec1f
ec23 ec26 ec2a ec2e ec31 ec34 ec39 ec3c
ec3f ec42 ec43 ec48 ec49 1 ec4b ec50
ec54 ec58 ec5b ec60 ec65 ec68 ec6c ec6d
ec72 ec75 ec7a ec7b ec80 ec83 ec88 ec89
ec8e ec91 ec95 ec96 ec9b ec9e eca3 eca4
eca9 ecac ecb0 ecb4 ecb7 ecba ecbb ecbd
ecbe ecc3 ecc4 ecc9 eccb eccf ecd2 ecd4
ecd8 ecda ece6 ece8 ecea eceb ecf0 ecf4
ecf6 ed02 ed04 ed08 ed0c ed0f ed10 ed12
ed15 ed18 ed19 ed1e ed22 ed26 ed2a ed2e
ed32 ed36 ed3a ed3e ed42 ed4e ed52 ed57
ed5b ed5e ed5f ed64 ed68 ed6c ed6f ed72
ed76 ed78 ed7c ed80 ed83 ed86 ed8a ed8c
ed90 ed94 ed97 ed99 1 ed9d eda1 eda5
eda8 edac edb0 edb4 edb8 edbb edbf edc3
edc6 edc9 edce edd1 edd4 edd7 edd8 eddd
edde 1 ede0 ede5 ede9 eded edf0 edf5
edfa edfd ee01 ee02 ee07 ee0a ee0f ee10
ee15 ee18 ee1d ee1e ee23 ee26 ee2a ee2b
ee30 ee33 ee38 ee39 ee3e ee41 ee45 ee49
ee4c ee4f ee50 ee52 ee53 ee58 ee59 ee5e
ee60 ee64 ee67 ee69 ee6d ee6f ee7b ee7d
ee7f ee80 ee85 ee89 ee8b ee97 ee99 ee9b
ee9f eea2 eea4 eea8 eeab eeaf eeb2 eeb6
eeba eebd eebe eec3 eec6 eeca eece eed2
eed6 eeda eede eee2 eee6 eeea eef6 eefa
eeff ef03 ef06 ef07 ef0c ef10 ef14 ef17
ef1a ef1e ef20 ef24 ef28 ef2b ef2e ef32
ef34 ef38 ef3c ef3f ef41 1 ef45 ef49
ef4d ef50 ef54 ef58 ef5c ef60 ef63 ef67
ef6b ef6e ef71 ef76 ef79 ef7c ef7f ef80
ef85 ef86 1 ef88 ef8d ef91 ef95 ef98
ef9d efa2 efa5 efa9 efaa efaf efb2 efb7
efb8 efbd efc0 efc5 efc6 efcb efce efd2
efd3 efd8 efdb efe0 efe1 efe6 efe9 efed
eff1 eff4 eff7 eff8 effa effb f000 f001
f006 f008 f00c f00f f011 f015 f017 f023
f025 f027 f028 f02d f031 f033 f03f f041
f045 f049 f04c f04d f04f f052 f055 f056
f05b f05f f063 f067 f06b f06f f073 f077
f083 f087 f08b f08e f092 f096 f098 1
f09c f0a0 f0a4 f0a7 f0ab f0af f0b3 f0b7
f0ba f0be f0c2 f0c5 f0c8 f0cd f0d0 f0d3
f0d6 f0d7 f0dc f0dd 1 f0df f0e4 f0e8
f0ec f0ef f0f4 f0f9 f0fc f100 f101 f106
f109 f10e f10f f114 f117 f11c f11d f122
f125 f129 f12a f12f f132 f137 f138 f13d
f140 f144 f148 f14b f14e f14f f151 f152
f157 f158 f15d f15f f163 f166 f168 f16c
f16e f17a f17c f17e f17f f184 f188 f18a
f196 f198 f19c f1a0 f1a3 f1a4 f1a6 f1a9
f1ac f1ad f1b2 f1b6 f1ba f1be f1c2 f1c6
f1ca f1ce f1d2 f1de f1e2 f1e7 f1eb f1ee
f1ef f1f4 f1f8 f1fc f1ff f202 f206 f208
f20c f210 f213 f216 f21a f21c f220 f224
f227 f229 1 f22d f231 f235 f238 f23c
f240 f244 f248 f24b f24f f253 f256 f259
f25e f261 f264 f267 f268 f26d f26e 1
f270 f275 f279 f27d f280 f285 f28a f28d
f291 f292 f297 f29a f29f f2a0 f2a5 f2a8
f2ad f2ae f2b3 f2b6 f2ba f2bb f2c0 f2c3
f2c8 f2c9 f2ce f2d1 f2d5 f2d9 f2dc f2df
f2e0 f2e2 f2e3 f2e8 f2e9 f2ee f2f0 f2f4
f2f7 f2f9 f2fd f2ff f30b f30d f30f f310
f315 f319 f31b f327 f329 f32d f331 f335
f339 f33d f349 f34d f352 f356 f359 f35a
f35f f363 f367 f36a f36d f371 f373 f377
f37b f37e f381 f385 f387 f38b f38f f392
f394 1 f398 f39c f3a0 f3a3 f3a7 f3ab
f3af f3b3 f3b6 f3ba f3be f3c1 f3c4 f3c9
f3cc f3cf f3d2 f3d3 f3d8 f3d9 1 f3db
f3e0 f3e4 f3e8 f3eb f3f0 f3f5 f3f8 f3fc
f3fd f402 f405 f40a f40b f410 f413 f418
f419 f41e f421 f425 f426 f42b f42e f433
f434 f439 f43c f440 f444 f447 f44a f44b
f44d f44e f453 f454 f459 f45b f45f f462
f464 f468 f46a f476 f478 f47a f47b f480
f484 f486 f492 f494 f496 f49a f49d f49f
f4a3 f4a6 f4aa f4ae f4b1 f4b2 f4b4 f4b7
f4ba f4bb f4c0 f4c4 f4c7 f4cb f4cf f4d3
f4d7 f4db f4df f4e2 f4e5 f4e6 f4e8 f4ec
f4f0 f4f4 f4f8 f4fc f500 f504 f508 f50c
f510 f514 f518 f51c f520 f524 f528 f52c
f530 f534 f538 f53c f540 f544 f548 f54c
f550 f55c f560 f564 f567 f56b f56f f571
1 f575 f579 f57d f580 f584 f588 f58c
f590 f593 f597 f59b f59e f5a1 f5a6 f5a9
f5ac f5af f5b0 f5b5 f5b6 1 f5b8 f5bd
f5c1 f5c5 f5c8 f5cd f5d2 f5d5 f5d9 f5da
f5df f5e2 f5e7 f5e8 f5ed f5f0 f5f5 f5f6
f5fb f5fe f602 f603 f608 f60b f610 f611
f616 f619 f61d f621 f624 f627 f628 f62a
f62b f630 f631 f636 f638 f63c f63f f641
f645 f647 f653 f655 f657 f658 f65d f661
f663 f66f f671 f675 f679 f67c f680 f683
f687 f68a f68b f690 f693 f697 f69b f69e
f69f f6a1 f6a4 f6a7 f6a8 f6ad f6b1 f6b5
f6b9 f6bd f6c1 f6c5 f6c9 f6cd f6d1 f6d5
f6d9 f6dd f6e1 f6e5 f6e9 f6f5 f6f9 f6fe
f702 f705 f706 f70b f70f f713 f716 f719
f71d f71f f723 f727 f72a f72d f731 f733
f737 f73b f73e f740 1 f744 f748 f74c
f74f f753 f757 f75b f75f f762 f766 f76a
f76d f770 f775 f778 f77b f77e f77f f784
f785 1 f787 f78c f790 f794 f797 f79c
f7a1 f7a4 f7a8 f7a9 f7ae f7b1 f7b6 f7b7
f7bc f7bf f7c4 f7c5 f7ca f7cd f7d1 f7d2
f7d7 f7da f7df f7e0 f7e5 f7e8 f7ec f7f0
f7f3 f7f6 f7f7 f7f9 f7fa f7ff f800 f805
f807 f80b f80e f810 f814 f816 f822 f824
f826 f827 f82c f830 f832 f83e f840 f842
f846 f84a f84e f852 f856 f85a f85e f862
f866 f86a f86e f872 f876 f87a f87e f882
f886 f892 f896 f89b f89f f8a2 f8a3 f8a8
f8ac f8b0 f8b3 f8b6 f8ba f8bc f8c0 f8c4
f8c7 f8ca f8ce f8d0 f8d4 f8d8 f8db f8dd
1 f8e1 f8e5 f8e9 f8ec f8f0 f8f4 f8f8
f8fc f8ff f903 f907 f90a f90d f912 f915
f918 f91b f91c f921 f922 1 f924 f929
f92d f931 f934 f939 f93e f941 f945 f946
f94b f94e f953 f954 f959 f95c f961 f962
f967 f96a f96e f96f f974 f977 f97c f97d
f982 f985 f989 f98d f990 f993 f994 f996
f997 f99c f99d f9a2 f9a4 f9a8 f9ab f9ad
f9b1 f9b3 f9bf f9c1 f9c3 f9c4 f9c9 f9cd
f9cf f9db f9dd f9df f9e3 f9e7 f9ea f9ee
f9f2 f9f5 f9f8 f9f9 f9fb f9fe fa03 fa04
fa09 fa0c fa10 fa13 fa17 fa1b fa1f fa22
fa26 fa2a fa2e fa32 fa36 fa3a fa3e fa42
fa46 fa4a fa4e fa4f fa51 fa55 fa57 fa5b
fa5e fa60 fa64 fa67 fa6b fa6e fa6f fa74
fa77 fa7a fa7e fa82 fa85 fa89 fa8d fa8e
fa90 fa93 fa96 fa97 fa9c 1 fa9f faa4
faa8 faab faaf fab1 fab5 fab8 faba fabe
fac1 fac3 fac7 faca face fad2 fad5 fad6
fad8 fadb fade fadf fae4 fae7 faeb faee
faef faf4 faf7 1 fafa faff fb03 fb07
fb0a fb0b fb0d fb10 fb13 fb14 fb19 fb1d
fb21 fb25 fb29 fb2d fb31 fb35 fb39 fb3d
fb41 fb4d fb51 fb55 fb58 fb5c fb60 fb62
1 fb66 fb6a fb6e fb71 fb75 fb79 fb7d
fb81 fb84 fb88 fb8c fb8f fb92 fb97 fb9a
fb9d fba0 fba1 fba6 fba7 1 fba9 fbae
fbb2 fbb6 fbb9 fbbe fbc3 fbc6 fbca fbcb
fbd0 fbd3 fbd8 fbd9 fbde fbe1 fbe6 fbe7
fbec fbef fbf3 fbf4 fbf9 fbfc fc01 fc02
fc07 fc0a fc0e fc12 fc15 fc18 fc19 fc1b
fc1c fc21 fc22 fc27 fc29 fc2d fc30 fc32
fc36 fc38 fc44 fc46 fc48 fc49 fc4e fc52
fc54 fc60 fc62 fc66 fc6a fc6d fc6e fc70
fc73 fc76 fc77 fc7c fc80 fc84 fc88 fc8c
fc90 fc94 fc98 fc9c fca0 fcac fcb0 fcb5
fcb9 fcbc fcbd fcc2 fcc6 fcca fccd fcd0
fcd4 fcd6 fcda fcde fce1 fce4 fce8 fcea
fcee fcf2 fcf5 fcf7 1 fcfb fcff fd03
fd06 fd0a fd0e fd12 fd16 fd19 fd1d fd21
fd24 fd27 fd2c fd2f fd32 fd35 fd36 fd3b
fd3c 1 fd3e fd43 fd47 fd4b fd4e fd53
fd58 fd5b fd5f fd60 fd65 fd68 fd6d fd6e
fd73 fd76 fd7b fd7c fd81 fd84 fd88 fd89
fd8e fd91 fd96 fd97 fd9c fd9f fda3 fda7
fdaa fdad fdae fdb0 fdb1 fdb6 fdb7 fdbc
fdbe fdc2 fdc5 fdc7 fdcb fdcd fdd9 fddb
fddd fdde fde3 fde7 fde9 fdf5 fdf7 fdfb
fdff fe03 fe07 fe0b fe0f fe13 fe17 fe1b
fe27 fe2b fe30 fe34 fe37 fe38 fe3d fe41
fe45 fe48 fe4b fe4f fe51 fe55 fe59 fe5c
fe5f fe63 fe65 fe69 fe6d fe70 fe72 1
fe76 fe7a fe7e fe81 fe85 fe89 fe8d fe91
fe94 fe98 fe9c fe9f fea2 fea7 feaa fead
feb0 feb1 feb6 feb7 1 feb9 febe fec2
fec6 fec9 fece fed3 fed6 feda fedb fee0
fee3 fee8 fee9 feee fef1 fef6 fef7 fefc
feff ff03 ff04 ff09 ff0c ff11 ff12 ff17
ff1a ff1e ff22 ff25 ff28 ff29 ff2b ff2c
ff31 ff32 ff37 ff39 ff3d ff40 ff42 ff46
ff48 ff54 ff56 ff58 ff59 ff5e ff62 ff64
ff70 ff72 ff74 ff78 ff7b ff7d ff81 ff84
ff88 ff8b ff8f ff93 ff97 ff9b ff9f ffa3
ffa6 ffa9 ffaa ffac ffb0 ffb4 ffb8 ffbc
ffc0 ffc4 ffc8 ffcc ffd0 ffd4 ffd8 ffdc
ffe0 ffe4 ffe8 ffec fff0 fff4 fff8 fffc
10000 10004 10008 1000c 10010 10014 10020 10024
10028 1002b 1002f 10033 10035 1 10039 1003d
10041 10044 10048 1004c 10050 10054 10057 1005b
1005f 10062 10065 1006a 1006d 10070 10073 10074
10079 1007a 1 1007c 10081 10085 10089 1008c
10091 10096 10099 1009d 1009e 100a3 100a6 100ab
100ac 100b1 100b4 100b9 100ba 100bf 100c2 100c6
100c7 100cc 100cf 100d4 100d5 100da 100dd 100e1
100e5 100e8 100eb 100ec 100ee 100ef 100f4 100f5
100fa 100fc 10100 10103 10105 10109 1010b 10117
10119 1011b 1011c 10121 10125 10127 10133 10135
10139 1013d 10140 10144 10147 1014b 1014e 1014f
10154 10157 1015b 1015f 10162 10163 10165 10168
1016b 1016c 10171 10175 10179 1017d 10181 10185
10189 1018d 10191 10195 10199 1019d 101a1 101a5
101a9 101ad 101b9 101bd 101c2 101c6 101c9 101ca
101cf 101d3 101d7 101da 101dd 101e1 101e3 101e7
101eb 101ee 101f1 101f5 101f7 101fb 101ff 10202
10204 1 10208 1020c 10210 10213 10217 1021b
1021f 10223 10226 1022a 1022e 10231 10234 10239
1023c 1023f 10242 10243 10248 10249 1 1024b
10250 10254 10258 1025b 10260 10265 10268 1026c
1026d 10272 10275 1027a 1027b 10280 10283 10288
10289 1028e 10291 10295 10296 1029b 1029e 102a3
102a4 102a9 102ac 102b0 102b4 102b7 102ba 102bb
102bd 102be 102c3 102c4 102c9 102cb 102cf 102d2
102d4 102d8 102da 102e6 102e8 102ea 102eb 102f0
102f4 102f6 10302 10304 10306 1030a 1030e 10312
10316 1031a 1031e 10322 10326 1032a 1032e 10332
10336 1033a 1033e 10342 10346 1034a 10356 1035a
1035f 10363 10366 10367 1036c 10370 10374 10377
1037a 1037e 10380 10384 10388 1038b 1038e 10392
10394 10398 1039c 1039f 103a1 1 103a5 103a9
103ad 103b0 103b4 103b8 103bc 103c0 103c3 103c7
103cb 103ce 103d1 103d6 103d9 103dc 103df 103e0
103e5 103e6 1 103e8 103ed 103f1 103f5 103f8
103fd 10402 10405 10409 1040a 1040f 10412 10417
10418 1041d 10420 10425 10426 1042b 1042e 10432
10433 10438 1043b 10440 10441 10446 10449 1044d
10451 10454 10457 10458 1045a 1045b 10460 10461
10466 10468 1046c 1046f 10471 10475 10477 10483
10485 10487 10488 1048d 10491 10493 1049f 104a1
104a3 104a7 104ab 104ae 104b2 104b6 104b9 104bc
104bd 104bf 104c2 104c7 104c8 104cd 104d0 104d4
104d8 104db 104dc 104de 104e1 104e4 104e5 104ea
1 104ed 104f2 104f6 104f9 104fd 10501 10505
10508 1050c 10510 10514 10518 1051c 10520 10524
10528 1052c 10530 10534 10535 10537 1053b 1053d
10541 10544 10546 1054a 1054d 1054f 10553 10556
1055a 1055e 10562 10563 10565 10569 1056d 10571
10574 10577 1057a 1057b 10580 10584 10588 1058b
1058e 10592 10594 10598 1059b 1059f 105a3 105a6
105aa 105ae 105b1 105b4 105b9 105bc 105bf 105c2
105c3 105c8 105c9 1 105cb 105d0 105d4 105d8
105db 105e0 105e5 105e8 105ec 105ed 105f2 105f5
105fa 105fb 10600 10603 10608 10609 1060e 10611
10615 10619 1061d 10621 10624 10625 10627 1062c
1062d 1062f 10630 10635 10638 1063d 1063e 10643
10646 1064b 1064c 10651 10654 10658 10659 1065e
10661 10666 10667 1066c 1066d 10672 10674 10678
1067b 1067f 10683 10686 1068a 1068e 10691 10695
10699 1069a 1069f 106a1 106a5 106a9 106ac 106b0
106b4 106b7 106bb 106bf 106c2 106c5 106ca 106cd
106d0 106d3 106d4 106d9 106da 1 106dc 106e1
106e5 106e9 106ec 106f1 106f6 106f9 106fd 106fe
10703 10704 10709 1070d 10711 10714 10719 1071e
10721 10725 10729 1072c 1072d 10732 10735 1073a
1073b 10740 10743 10747 1074b 1074e 1074f 10754
10755 1075a 1075c 10760 10763 10767 1076b 1076f
10773 10777 1077b 1077f 10783 10787 10793 10798
1079c 107a0 107a4 107a8 107aa 107ab 107b0 1
107b4 107b8 107bc 107bf 107c3 107c7 107cb 107cf
107d2 107d6 107da 107dd 107e0 107e5 107e8 107eb
107ee 107ef 107f4 107f5 1 107f7 107fc 10800
10804 10807 1080c 10811 10814 10818 10819 1081e
1081f 10824 10828 1082c 1082f 10834 10839 1083c
10840 10841 10846 10849 1084e 1084f 10854 10857
1085b 1085f 10862 10865 10866 10868 10869 1086e
1086f 10874 10876 1087a 1087d 10881 10885 10889
1088d 10891 10895 10899 108a5 108aa 108ae 108b2
108b6 108ba 108bc 108c0 108c2 108ce 108d0 108d2
108d3 108d8 108dc 108de 108ea 108ee 108f0 108f1
108fa 
4bc9
2
0 1 a 6 d :3 6 14 :3 6
10 :3 6 14 :3 6 15 :3 6 10 :3 6
e :3 6 11 :3 6 c :3 6 b :3 6
11 :3 6 11 :3 6 1d :3 6 10 :3 6
12 :2 6 1 3 a 13 a :2 1
4 9 12 11 :2 9 :2 4 12 1b
1a :2 12 :2 4 f 18 17 :2 f :2 4
10 19 18 :2 10 :2 4 14 1d 1c
:2 14 :2 4 18 21 20 :2 18 :2 4 18
21 20 :2 18 :2 4 18 21 20 :2 18
:2 4 e 17 16 :2 e :2 4 d 16
15 :2 d :2 4 11 1a 19 :2 11 :2 4
11 1a 19 :2 11 :2 4 :3 11 :2 4 :3 12
:2 4 :3 14 :2 4 :3 15 :2 4 f 18 17
:2 f :2 4 :3 e :2 4 :3 f :2 4 f 18
17 :2 f :2 4 b 14 13 :2 b :2 4
:3 f :2 4 :3 10 :2 4 :3 12 :2 4 :3 13 :2 4
e 17 16 :2 e :2 4 10 19 18
:2 10 :2 4 9 12 11 :2 9 :2 4 13
1c 1b :2 13 :2 4 11 1a 19 :2 11
:2 4 :2 12 21 12 :2 4 :2 c 1b c
:2 4 :2 d 1c d :2 4 :2 a 19 a
:2 4 :2 b 1a b :2 4 :2 e 1d e
:2 4 :2 c 1b c :2 4 :2 b 1a b
:2 4 :2 11 20 11 :2 4 :2 c 1b c
:2 4 :2 b 1a b :2 4 :2 e 1d e
:2 4 :2 f 1e f :2 4 :2 10 1f 10
:2 4 :2 d 1c d :2 4 :2 f 1e f
:2 4 :2 10 1f 10 :2 4 :2 e 1d e
:2 4 :2 e 1d e :2 4 :2 f 1e f
:2 4 :2 d 1c d :2 4 :2 f 1e f
:2 4 :2 f 1e f :2 4 :2 b 1a b
:2 4 :2 c 1b c :2 4 :2 c 1b c
:2 4 :2 16 25 16 :2 4 :2 f 19 f
:2 4 :2 f 19 f :2 4 :2 10 1a 10
:2 4 :2 10 1a 10 :2 4 :2 13 1d 13
:2 4 :2 12 21 12 :2 4 :2 19 28 19
:2 4 :2 19 28 19 :2 4 :2 19 28 19
:2 4 :2 f 1e f :2 4 :2 11 20 11
:2 4 :2 11 20 11 :2 4 :2 d 1c d
:2 4 10 19 18 :2 10 :2 4 11 1a
19 :2 11 :2 4 :2 14 1e 14 :2 4 :2 f
1e f :2 4 14 1d 1c :2 14 :2 4
:2 17 26 17 :2 4 17 20 1f :2 17
:2 4 13 1c 1b :2 13 :2 4 :2 13 22
13 :2 4 :2 14 23 14 :2 4 :3 9 :2 4
:3 9 :2 4 :2 f 19 f :2 4 :2 f 19
f :2 4 :2 f 1e f :2 4 :2 f 1e
f :2 4 :2 f 1e f :2 4 :2 16 25
16 :2 4 :2 11 20 11 :2 4 :2 11 20
11 :2 4 :2 15 24 15 :2 4 :2 10 1f
10 :2 4 :2 14 23 14 :2 4 14 1d
1c :2 14 :2 4 14 1d 1c :2 14 :2 4
18 21 20 :2 18 :2 4 :2 d 26 30
39 44 :2 30 :2 26 25 d :2 4 :2 10
28 10 :2 4 :2 b 23 b 4 7
e 0 :2 7 20 33 10 1d 2e
a :6 7 e 0 :2 7 20 2e 10
1d 2e 3c 49 a 30 a :6 7
e 0 :2 7 11 13 26 28 3b
3d 46 48 56 58 66 68 a
12 19 1b 33 3b 42 44 5c
5e 6d 6f 89 8b a5 a7 bd
bf a c 23 25 2f 31 42
44 52 54 a c 16 18 20
22 2a 2c 37 39 f 17 1a
2f 32 43 10 12 1f 30 32
40 51 53 e 10 24 26 3c
3e 4b 4d e 10 21 2a 32
3b 49 52 60 69 77 80 8d
96 a7 b0 c3 cc e1 ea 105
10e 126 12f 140 149 15b 164 17c
185 198 1a1 1c2 1c4 1ce 13 15
a :5 7 4 e 17 :3 e 4 7
:2 11 23 :2 2d 3a :2 23 :3 7 :2 d 19
25 :2 2f 43 :2 25 56 5c 5f :2 56
6d 85 8 :2 6d d 10 :2 6d 17
1a :2 6d b e :2 6d 13 16 :2 6d
1b 1e :2 6d 2c 2f :2 6d b e
:2 6d 13 16 :2 6d 1b 1e :2 6d 28
2b :2 6d b e :2 6d 13 16 :2 6d
1b 1e :2 6d 2c 2f :2 6d b e
:2 6d 13 16 :2 6d 1b 1e :2 6d 2d
30 :2 6d b e :2 6d 13 16 1f
27 :2 1f 33 :2 16 :2 6d b e :2 6d
13 16 1f 27 :2 1f 31 :2 16 :2 6d
b e :2 6d 13 16 1f 27 :2 1f
34 :2 16 :2 6d b e :2 6d 13 16
1f 27 :2 1f 2f :2 16 :2 6d b e
:2 6d 13 16 1f 27 :2 1f 2e :2 16
:2 6d b e :2 6d 13 16 1f 27
:2 1f 34 :2 16 :2 6d b e :2 6d 13
16 1f 27 :2 1f 34 :2 16 :2 6d b
e :2 6d 13 16 1f 27 :2 1f 40
:2 16 :2 6d b e :2 6d 13 16 1f
27 :2 1f 33 :2 16 :2 6d b e :2 6d
13 16 :2 6d 1b 1e :2 6d 2a 2d
:2 6d 32 35 :2 6d :2 7 4c :2 4 7
:2 11 23 :2 2d 39 3c 4e 51 52
:2 4e :2 23 :3 7 :2 d 12 1e 5f 62
:2 1e :2 7 55 :3 4 11 :2 4 14 :2 4
10 :2 4 12 :2 4 12 :2 4 12 :2 4
12 19 22 2e :2 19 32 :2 3b :2 12
4 8 11 1d :2 8 22 20 :2 2b
:2 20 7 40 e 1a :2 40 1f 1d
:2 28 :2 1d 3f :3 7 15 7 3e :3 4
13 :2 4 14 :2 4 12 :2 4 14 :2 4
15 :2 4 15 :2 4 16 :2 4 9 :3 4
a 16 :2 4 7 e :2 7 :2 10 1c
7 14 7 :2 10 1c 7 :5 4 f
:2 18 4 7 d :3 7 :2 10 1c 7
4 :2 c a :2 13 1f a d :2 17
29 :2 33 3f 43 55 58 59 :2 55
:2 29 :3 d :2 13 18 24 65 68 :2 24
75 78 :2 24 7c 7f :2 24 8b 8e
:2 24 96 99 :2 24 a5 a8 af b8
bb :2 a8 :2 24 :2 d 5c :2 a :2 7 :4 13
:2 7 4 :3 1 7 10 19 :2 7 1c
1e :2 1c a :2 14 26 :2 30 3c 40
52 55 56 :2 52 :2 26 :3 a :2 10 15
21 62 65 :2 21 72 75 :2 21 79
7c :2 21 86 89 92 9a :2 a3 :2 92
b6 :2 89 :2 21 be c1 :2 21 c9 cc
:2 21 d1 d4 :2 21 dd e0 :2 21 :2 a
59 :2 7 a :2 14 26 :2 30 3c 3f
51 54 55 :2 51 :2 26 :3 a :2 10 15
21 62 65 :2 21 :2 a 58 :3 7 :2 12
26 :2 2f 41 4b :2 7 22 :2 4 e
17 1d 29 38 47 52 c 17
1f 2d 3e 4f 5c c 1a 27
:2 7 :2 10 1c 7 4 :2 c a :2 13
1f a d :2 17 29 :2 33 3f 43
55 58 59 :2 55 :2 29 :3 d :2 13 18
24 65 68 :2 24 75 78 :2 24 7c
7f :2 24 8b 8e :2 24 96 99 :2 24
a5 a8 af b8 bb :2 a8 :2 24 :2 d
5c :2 a :2 7 :4 13 :2 7 4 :3 1 8
:2 11 1c 1a :2 25 :2 1a 7 a :2 14
26 :2 30 3c 40 52 55 56 :2 52
:2 26 :3 a :2 10 15 21 62 65 :2 21
72 75 :2 21 79 7c :2 21 86 89
92 9a :2 a3 :2 92 b6 :2 89 :2 21 be
c1 :2 21 c9 cc :2 21 d1 d4 :2 21
de e1 :2 21 :2 a 59 :2 7 a :2 14
26 :2 30 3c 3f 51 54 55 :2 51
:2 26 :3 a :2 10 15 21 62 65 :2 21
:2 a 58 :3 7 :2 12 26 :2 2f 41 4c
:2 7 35 :3 4 12 4 e 1e c
d 1a :2 7 :2 10 1c 7 4 :2 c
a :2 13 1f a d :2 17 29 :2 33
3f 43 55 58 59 :2 55 :2 29 :3 d
:2 13 18 24 65 68 :2 24 75 78
:2 24 7c 7f :2 24 8b 8e :2 24 96
99 :2 24 a5 a8 af b8 bb :2 a8
:2 24 :2 d 5c :2 a :2 7 :4 13 :2 7 4
:3 1 7 10 1c :2 7 1f 21 :2 1f
a :2 14 26 :2 30 3c 40 52 55
56 :2 52 :2 26 :3 a :2 10 15 21 62
65 :2 21 72 75 :2 21 79 7c :2 21
86 89 92 9a :2 a3 :2 92 b9 :2 89
:2 21 c1 c4 :2 21 cc cf :2 21 d4
d7 :2 21 e4 e7 :2 21 :2 a 59 :2 7
a :2 14 26 :2 30 3c 3f 51 54
55 :2 51 :2 26 :3 a :2 10 15 21 62
65 :2 21 :2 a 58 :3 7 :2 12 26 :2 2f
44 52 :2 7 23 :2 4 e 11 24
27 4a 53 56 6c 75 78 90
93 9d a0 ad b8 c2 c5 c
14 22 2d 39 45 54 c 14
17 1c 2b 31 34 42 45 56
59 66 :2 7 :2 10 1c 7 4 :2 c
a :2 13 1f a d :2 17 29 :2 33
3f 43 55 58 59 :2 55 :2 29 :3 d
:2 13 18 24 65 68 :2 24 75 78
:2 24 7c 7f :2 24 8b 8e :2 24 96
99 :2 24 a5 a8 af b8 bb :2 a8
:2 24 :2 d 5c :2 a :2 7 :4 13 :2 7 4
:3 1 8 :2 11 1c 1a :2 25 :2 1a 7
a :2 14 26 :2 30 3c 40 52 55
56 :2 52 :2 26 :3 a :2 10 15 21 62
65 :2 21 72 75 :2 21 79 7c :2 21
86 89 92 9a :2 a3 :2 92 b6 :2 89
:2 21 be c1 :2 21 c9 cc :2 21 d1
d4 :2 21 de e1 :2 21 :2 a 59 :2 7
a :2 14 26 :2 30 3c 3f 51 54
55 :2 51 :2 26 :3 a :2 10 15 21 62
65 :2 21 :2 a 58 :3 7 :2 12 26 :2 2f
41 4c :2 7 35 :2 4 e 18 2b
37 49 59 67 :2 7 :2 10 1c 7
4 :2 c a :2 13 1f a d :2 17
29 :2 33 3f 43 55 58 59 :2 55
:2 29 :3 d :2 13 18 24 65 68 :2 24
75 78 :2 24 7c 7f :2 24 8b 8e
:2 24 96 99 :2 24 a5 a8 af b8
bb :2 a8 :2 24 :2 d 5c :2 a :2 7 :4 13
:2 7 4 :3 1 8 :2 11 1c 1a :2 25
:2 1a 7 a :2 14 26 :2 30 3c 40
52 55 56 :2 52 :2 26 :3 a :2 10 15
21 62 65 :2 21 72 75 :2 21 79
7c :2 21 86 89 92 9a :2 a3 :2 92
b6 :2 89 :2 21 be c1 :2 21 c9 cc
:2 21 d1 d4 :2 21 dd e0 :2 21 :2 a
59 :2 7 a :2 14 26 :2 30 3c 3f
51 54 55 :2 51 :2 26 :3 a :2 10 15
21 62 65 :2 21 :2 a 58 :3 7 :2 12
26 :2 2f 41 4b :2 7 35 :2 4 e
1b 2a 39 46 :2 7 :2 10 1c 7
4 :2 c a :2 13 1f a d :2 17
29 :2 33 3f 43 55 58 59 :2 55
:2 29 :3 d :2 13 18 24 65 68 :2 24
75 78 :2 24 7c 7f :2 24 8b 8e
:2 24 96 99 :2 24 a5 a8 af b8
bb :2 a8 :2 24 :2 d 5c :2 a :2 7 :4 13
:2 7 4 :3 1 7 :2 12 19 24 :2 7
34 36 :2 34 7 14 7 38 :2 4
8 :2 11 1c 1a :2 25 :2 1a 7 a
:2 14 26 :2 30 3c 40 52 55 56
:2 52 :2 26 :3 a :2 10 15 21 62 65
:2 21 72 75 :2 21 79 7c :2 21 86
89 92 9a :2 a3 :2 92 b6 :2 89 :2 21
be c1 :2 21 c9 cc :2 21 d1 d4
:2 21 e1 e4 :2 21 :2 a 59 :2 7 a
:2 14 26 :2 30 3c 3f 51 54 55
:2 51 :2 26 :3 a :2 10 15 21 62 65
:2 21 :2 a 58 :3 7 :2 12 26 :2 2f 41
4f :2 7 35 :3 4 1c :2 4 1c 23
2c 42 :2 23 46 :2 1c :2 4 12 19
22 38 :2 19 3c :2 12 :2 4 1c 23
2c 42 :2 23 46 :2 1c 4 7 10
13 :2 10 a 13 1f :2 a 22 24
:2 22 14 1a 32 42 13 20 31
3b d 1b 28 :2 d :2 16 22 d
a :2 12 10 :2 19 25 10 13 :2 1d
2f :2 39 45 49 5b 5e 5f :2 5b
:2 2f :3 13 :2 19 1e 2a 6b 6e :2 2a
7b 7e :2 2a 82 85 :2 2a 91 94
:2 2a 9c 9f :2 2a ab ae b5 be
c1 :2 ae :2 2a :2 13 62 :2 10 :2 d :4 19
:2 d a :3 26 7 26 d 16 22
:2 d 25 27 :2 25 14 1a 32 42
13 20 31 3c d 1b 28 :2 d
:2 16 22 d a :2 12 10 :2 19 25
10 13 :2 1d 2f :2 39 45 49 5b
5e 5f :2 5b :2 2f :3 13 :2 19 1e 2a
6b 6e :2 2a 7b 7e :2 2a 82 85
:2 2a 91 94 :2 2a 9c 9f :2 2a ab
ae b5 be c1 :2 ae :2 2a :2 13 62
:2 10 :2 d :4 19 :2 d a :4 29 26 :2 7
a 13 1f :2 a 22 24 :2 22 d
:2 17 29 :2 33 3f 43 55 58 59
:2 55 :2 29 :3 d :2 13 18 24 65 68
:2 24 75 78 :2 24 7c 7f :2 24 89
8c 95 9d :2 a6 :2 95 c7 :2 8c :2 24
cf d2 :2 24 da dd :2 24 e2 e5
:2 24 ee f1 :2 24 :2 d 5c :2 a d
:2 17 29 :2 33 3f 42 54 57 58
:2 54 :2 29 :3 d :2 13 18 24 65 68
:2 24 :2 d 5b :3 a :2 15 29 :2 32 52
12 :2 a 26 :2 7 15 11 17 2f
3f 10 1d 2e 3c 48 56 67
:2 a :2 13 1f a 7 :2 f d :2 16
22 d 10 :2 1a 2c :2 36 42 46
58 5b 5c :2 58 :2 2c :3 10 :2 16 1b
27 68 6b :2 27 78 7b :2 27 7f
82 :2 27 8e 91 :2 27 99 9c :2 27
a8 ab b2 bb be :2 ab :2 27 :2 10
5f :2 d :2 a :4 16 :2 a 7 :3 4 11
17 2f 3f 10 1d 2e 3b 47
55 66 :2 a :2 13 1f a 7 :2 f
d :2 16 22 d 10 :2 1a 2c :2 36
42 46 58 5b 5c :2 58 :2 2c :3 10
:2 16 1b 27 68 6b :2 27 78 7b
:2 27 7f 82 :2 27 8e 91 :2 27 99
9c :2 27 a8 ab b2 bb be :2 ab
:2 27 :2 10 5f :2 d :2 a :4 16 :2 a 7
:3 4 b 19 22 2d :2 19 :2 b a
32 35 :2 32 3d 46 52 :2 3d 55
57 :2 55 3c 5e d 19 :2 5e 1c
1e :2 1c 5d :2 3c 3b :2 a 14 1a
32 42 13 20 31 3f 4c 11
:2 d :2 16 22 d a :2 12 10 :2 19
25 10 13 :2 1d 2f :2 39 45 49
5b 5e 5f :2 5b :2 2f :3 13 :2 19 1e
2a 6b 6e :2 2a 7b 7e :2 2a 82
85 :2 2a 91 94 :2 2a 9c 9f :2 2a
ab ae b5 be c1 :2 ae :2 2a :2 13
62 :2 10 :2 d :4 19 :2 d a :3 22 d
16 22 :2 d 25 27 :2 25 10 :2 1a
2c :2 36 42 46 58 5b 5c :2 58
:2 2c :3 10 :2 16 1b 27 68 6b :2 27
78 7b :2 27 7f 82 :2 27 8c 8f
98 a0 :2 a9 :2 98 ca :2 8f :2 27 d2
d5 :2 27 dd e0 :2 27 e5 e8 :2 27
f1 f4 :2 27 :2 10 5f :2 d 10 :2 1a
2c :2 36 42 45 57 5a 5b :2 57
:2 2c :3 10 :2 16 1b 27 68 6b :2 27
:2 10 5e :3 d :2 18 2c :2 35 55 15
:2 d 29 :2 a 22 :2 7 :5 4 12 :2 4
13 :2 4 17 :2 4 1b :2 4 14 :2 4
9 :3 4 a 14 :2 4 7 c :2 7
:2 10 1c 7 12 7 :2 10 1c 7
:4 4 8 :2 11 1c 1a :2 25 :2 1a :2 7
15 7 35 7 15 7 :4 4 7
d :3 7 :2 10 1c 7 4 :2 c a
:2 13 1f a d :2 17 29 :2 33 3f
43 55 58 59 :2 55 :2 29 :3 d :2 13
18 24 65 68 :2 24 75 78 :2 24
7c 7f :2 24 8b 8e :2 24 96 99
:2 24 a5 a8 af b8 bb :2 a8 :2 24
:2 d 5c :2 a :2 7 :4 13 :2 7 4 :3 1
7 10 1c :2 7 1f 21 :2 1f 11
17 2f 3c 53 60 a 18 25
3d 47 :2 a :2 13 1f a 7 :2 f
d :2 16 22 d 10 :2 1a 2c :2 36
42 46 58 5b 5c :2 58 :2 2c :3 10
:2 16 1b 27 68 6b :2 27 78 7b
:2 27 7f 82 :2 27 8e 91 :2 27 99
9c :2 27 a8 ab b2 bb be :2 ab
:2 27 :2 10 5f :2 d :2 a :4 16 :2 a 7
:3 23 a 13 1c :2 a 1f 21 :2 1f
a 18 a 14 23 37 46 12
29 36 47 d 1b 28 40 4a
:2 d :2 16 22 d a :2 12 10 :2 19
25 10 13 :2 1d 2f :2 39 45 49
5b 5e 5f :2 5b :2 2f :3 13 :2 19 1e
2a 6b 6e :2 2a 7b 7e :2 2a 82
85 :2 2a 91 94 :2 2a 9c 9f :2 2a
ab ae b5 be c1 :2 ae :2 2a :2 13
62 :2 10 :2 d :4 19 :2 d a :3 23 e
:2 17 22 20 :2 2b :2 20 d 10 :2 1a
2c :2 36 42 46 58 5b 5c :2 58
:2 2c :3 10 :2 16 1b 27 68 6b :2 27
78 7b :2 27 7f 82 :2 27 8c 8f
98 a0 :2 a9 :2 98 ca :2 8f :2 27 d2
d5 :2 27 dd e0 :2 27 e5 e8 :2 27
f1 f4 :2 27 :2 10 5f :2 d 10 :2 1a
2c :2 36 42 45 57 5a 5b :2 57
:2 2c :3 10 :2 16 1b 27 68 6b :2 27
:2 10 5e :3 d :2 18 2c :2 35 55 15
:2 d a 3b :4 12 11 10 :4 34 33
32 :2 10 11 :2 1c 24 33 41 :2 11
45 47 :2 45 10 4e :2 59 61 15
23 :2 4e 27 29 :2 27 4d :2 10 13
:2 1d 2f :2 39 45 49 5b 5e 5f
:2 5b :2 2f :3 13 :2 19 1e 2a 6b 6e
:2 2a 7b 7e :2 2a 82 85 :2 2a 8f
92 9b a3 :2 ac :2 9b cd :2 92 :2 2a
d5 d8 :2 2a e0 e3 :2 2a e8 eb
:2 2a f4 f7 :2 2a :2 13 62 :2 10 13
:2 1d 2f :2 39 45 48 5a 5d 5e
:2 5a :2 2f :3 13 :2 19 1e 2a 6b 6e
:2 2a :2 13 61 :3 10 :2 1b 2f :2 38 58
18 :2 10 2c :2 d 51 3b :2 a 23
:2 7 a 13 1f :2 a 22 24 :2 22
a 18 :2 a 21 a 26 14 27
38 49 12 13 20 11 21 11
1f :2 d :2 16 22 d a :2 12 10
:2 19 25 10 13 :2 1d 2f :2 39 45
49 5b 5e 5f :2 5b :2 2f :3 13 :2 19
1e 2a 6b 6e :2 2a 7b 7e :2 2a
82 85 :2 2a 91 94 :2 2a 9c 9f
:2 2a ab ae b5 be c1 :2 ae :2 2a
:2 13 62 :2 10 :2 d :4 19 :2 d a :3 7
e :2 17 22 20 :2 2b :2 20 :2 d 20
:2 d :3 20 :2 d 20 2e 31 3a 42
:2 31 46 :2 4f 24 :2 20 :2 d 23 :2 2c
:2 d 20 :2 d 1f :2 d 20 37 45
4f 57 2d 41 52 :2 20 :2 d 1d
26 2f 37 :2 26 :2 1d d 1c 31
44 50 5c 10 1f 2c 38 45
52 10 1a 18 29 37 45 10
1c 26 34 3d 4a 5e 10 1d
10 17 13 1f :3 1d 13 :2 1c 28
13 24 13 :2 1c 28 13 :4 10 d
:2 15 13 :2 1c 28 13 16 :2 20 32
:2 3c 48 4c 5e 61 62 :2 5e :2 32
:3 16 :2 1c 21 2d 6e 71 :2 2d 7e
81 :2 2d 85 88 :2 2d 94 97 :2 2d
9f a2 :2 2d ae b1 b8 c1 c4
:2 b1 :2 2d :2 16 65 :2 13 :2 10 :4 1c :2 10
d :3 3b 17 29 3d 4c 59 :2 10
:2 19 25 10 d :2 15 13 :2 1c 28
13 16 :2 20 32 :2 3c 48 4c 5e
61 62 :2 5e :2 32 :3 16 :2 1c 21 2d
6e 71 :2 2d 7e 81 :2 2d 85 88
:2 2d 94 97 :2 2d 9f a2 :2 2d ae
b1 b8 c1 c4 :2 b1 :2 2d :2 16 65
:2 13 :2 10 :4 1c :2 10 d :3 3b 10 :2 1b
22 30 :2 10 3b 3d :2 3b 10 1b
10 3f 1a 20 38 45 19 26
37 42 50 68 76 87 :2 13 :2 1c
28 13 10 :2 18 16 :2 1f 2b 16
19 :2 23 35 :2 3f 4b 4f 61 64
65 :2 61 :2 35 :3 19 :2 1f 24 30 71
74 :2 30 81 84 :2 30 88 8b :2 30
97 9a :2 30 a2 a5 :2 30 b1 b4
bb c4 c7 :2 b4 :2 30 :2 19 68 :2 16
:2 13 :4 1f :2 13 10 :7 d 10 19 22
:2 10 25 27 :2 25 1a 26 35 3e
4c 5c 19 26 37 44 13 1a
16 22 :3 20 16 :2 1f 2b 16 27
16 :2 1f 2b 16 :4 13 10 :2 18 16
:2 1f 2b 16 19 :2 23 35 :2 3f 4b
4f 61 64 65 :2 61 :2 35 :3 19 :2 1f
24 30 71 74 :2 30 81 84 :2 30
88 8b :2 30 97 9a :2 30 a2 a5
:2 30 b1 b4 bb c4 c7 :2 b4 :2 30
:2 19 68 :2 16 :2 13 :4 1f :2 13 10 :3 29
1a 26 18 1f 2d 4a 18 1f
2e 35 4f 18 28 19 26 37
44 13 1a 16 22 :3 20 16 :2 1f
2b 16 27 16 :2 1f 2b 16 :4 13
10 :2 18 16 :2 1f 2b 16 19 :2 23
35 :2 3f 4b 4f 61 64 65 :2 61
:2 35 :3 19 :2 1f 24 30 71 74 :2 30
81 84 :2 30 88 8b :2 30 97 9a
:2 30 a2 a5 :2 30 b1 b4 bb c4
c7 :2 b4 :2 30 :2 19 68 :2 16 :2 13 :4 1f
:2 13 10 :4 29 1a 26 18 1f 2d
4a 18 1f 2e 35 4f 18 28
19 26 37 44 13 1a 16 22
:3 20 16 :2 1f 2b 16 27 16 :2 1f
2b 16 :4 13 10 :2 18 16 :2 1f 2b
16 19 :2 23 35 :2 3f 4b 4f 61
64 65 :2 61 :2 35 :3 19 :2 1f 24 30
71 74 :2 30 81 84 :2 30 88 8b
:2 30 97 9a :2 30 a2 a5 :2 30 b1
b4 bb c4 c7 :2 b4 :2 30 :2 19 68
:2 16 :2 13 :4 1f :2 13 10 :7 d a 3b
11 :2 1a 25 23 :2 2e :2 23 10 17
2e 47 16 2a 3e :2 10 :2 19 25
10 d :2 15 13 :2 1c 28 13 16
:2 20 32 :2 3c 48 4c 5e 61 62
:2 5e :2 32 :3 16 :2 1c 21 2d 6e 71
:2 2d 7e 81 :2 2d 85 88 :2 2d 94
97 :2 2d 9f a2 :2 2d ae b1 b8
c1 c4 :2 b1 :2 2d :2 16 65 :2 13 :2 10
:4 1c :2 10 d :3 3e 10 19 22 :2 10
27 25 :2 30 :2 25 10 23 31 34
3d 45 :2 34 49 :2 52 24 :2 23 10
1a 33 40 13 21 2a 37 45
19 2d 13 1a 16 22 :3 20 16
:2 1f 2b 16 27 16 :2 1f 2b 16
:4 13 10 :2 18 16 :2 1f 2b 16 19
:2 23 35 :2 3f 4b 4f 61 64 65
:2 61 :2 35 :3 19 :2 1f 24 30 71 74
:2 30 81 84 :2 30 88 8b :2 30 97
9a :2 30 a2 a5 :2 30 b1 b4 bb
c4 c7 :2 b4 :2 30 :2 19 68 :2 16 :2 13
:4 1f :2 13 10 :3 3f 10 23 39 :2 23
10 d 3f 14 1b 24 2d :2 1b
31 :2 3a :2 14 13 4b 48 :2 54 :2 48
1a 33 40 13 1f 28 2f 3c
45 19 2d 13 1a 16 22 :3 20
16 :2 1f 2b 16 27 16 :2 1f 2b
16 :4 13 10 :2 18 16 :2 1f 2b 16
19 :2 23 35 :2 3f 4b 4f 61 64
65 :2 61 :2 35 :3 19 :2 1f 24 30 71
74 :2 30 81 84 :2 30 88 8b :2 30
97 9a :2 30 a2 a5 :2 30 b1 b4
bb c4 c7 :2 b4 :2 30 :2 19 68 :2 16
:2 13 :4 1f :2 13 10 :3 60 10 23 39
:2 23 10 60 3f 1a 33 40 13
1f 28 2f 3c 45 19 2d 13
1a 16 22 :3 20 16 :2 1f 2b 16
27 16 :2 1f 2b 16 :4 13 10 :2 18
16 :2 1f 2b 16 19 :2 23 35 :2 3f
4b 4f 61 64 65 :2 61 :2 35 :3 19
:2 1f 24 30 71 74 :2 30 81 84
:2 30 88 8b :2 30 97 9a :2 30 a2
a5 :2 30 b1 b4 bb c4 c7 :2 b4
:2 30 :2 19 68 :2 16 :2 13 :4 1f :2 13 10
:3 d 10 23 39 :2 23 10 :4 d 3e
3b :2 a :4 7 23 7 1e 7 :5 4
13 :2 4 14 :2 4 15 :2 4 :3 17 4
8 11 27 :2 8 2a 2c :2 2a 7
33 3c 52 :2 33 55 57 :2 55 32
:3 7 1a 2b 39 43 4f 5c 27
34 40 4d 59 :2 1a 7 5a :2 4
18 28 2b c 1d 28 32 35
:2 c 16 19 1e 2d 33 36 44
47 56 59 d 19 :2 7 :2 10 1c
7 4 :2 c a :2 13 1f a d
:2 17 29 :2 33 3f 43 55 58 59
:2 55 :2 29 :3 d :2 13 18 24 65 68
:2 24 75 78 :2 24 7c 7f :2 24 8b
8e :2 24 96 99 :2 24 a5 a8 af
b8 bb :2 a8 :2 24 :2 d 5c :2 a :2 7
:4 13 :2 7 4 :3 1 8 :2 11 1d 1a
:2 26 :2 1a :2 7 19 7 36 :3 4 10
:2 4 f :2 4 1b 4 e 28 4a
56 c 22 2f :2 7 :2 10 1c 7
4 :2 c a :2 13 1f a d :2 17
29 :2 33 3f 43 55 58 59 :2 55
:2 29 :3 d :2 13 18 24 65 68 :2 24
75 78 :2 24 7c 7f :2 24 8b 8e
:2 24 96 99 :2 24 a5 a8 af b8
bb :2 a8 :2 24 :2 d 5c :2 a :2 7 :4 13
:2 7 4 :3 1 7 :2 12 19 27 :2 7
32 35 :2 32 11 15 25 32 10
1d 2e 38 49 57 :2 a :2 13 1f
a 7 :2 f d :2 16 22 d 10
:2 1a 2c :2 36 42 46 58 5b 5c
:2 58 :2 2c :3 10 :2 16 1b 27 68 6b
:2 27 78 7b :2 27 7f 82 :2 27 8e
91 :2 27 99 9c :2 27 a8 ab b2
bb be :2 ab :2 27 :2 10 5f :2 d :2 a
:4 16 :2 a 7 :3 37 a 13 1c :2 a
1f 21 :2 1f a 17 a 23 a
15 a :4 7 37 :2 4 7 10 1c
:2 7 1f 21 :2 1f a :2 15 1c 2a
:2 a 35 37 :2 35 14 26 38 46
4e 55 6d 75 7c 95 9f d
1b 29 32 3d 47 4f 57 12
27 2d 3f 4a 56 62 d 19
25 30 41 49 52 5a 12 13
1d 2e 3c 4d :2 d :2 16 22 d
a :2 12 10 :2 19 25 10 13 :2 1d
2f :2 39 45 49 5b 5e 5f :2 5b
:2 2f :3 13 :2 19 1e 2a 6b 6e :2 2a
7b 7e :2 2a 82 85 :2 2a 91 94
:2 2a 9c 9f :2 2a ab ae b5 be
c1 :2 ae :2 2a :2 13 62 :2 10 :2 d :4 19
:2 d a :3 39 a 21 :2 a 1f a
d 16 22 :2 d 25 27 :2 25 11
1a 25 :2 11 2b 28 34 40 :2 2b
:2 28 10 48 51 59 :2 48 5f 5c
28 31 :2 5f :2 5c 47 :2 10 14 1d
29 :2 14 2c 2e :2 2c 13 37 3e
16 22 :2 3e 26 :2 2f :2 37 36 3d
40 :2 3d 35 :2 13 16 :2 20 32 :2 3c
48 4c 5e 61 62 :2 5e :2 32 :3 16
:2 1c 21 2d 6e 71 :2 2d 7e 81
:2 2d 85 88 :2 2d 92 95 9e a6
:2 af :2 9e c7 :2 95 :2 2d cf d2 :2 2d
da dd :2 2d e2 e5 :2 2d ee f1
:2 2d :2 16 65 :2 13 16 :2 20 32 :2 3c
48 4b 5d 60 61 :2 5d :2 32 :3 16
:2 1c 21 2d 6e 71 :2 2d :2 16 64
:3 13 :2 1e 32 :2 3b 52 5c :2 13 43
13 28 13 16 1f 2b :2 16 2e
30 :2 2e 16 29 16 32 :2 13 :4 10
35 :3 d 19 :2 d 1d :2 d 1e :2 d
17 :2 d 1d :2 d 18 :2 d 17 :2 d
1a :2 d 1a d 29 :2 a e :2 17
22 20 :2 2b :2 20 d :4 41 40 3f
:2 d 10 17 27 2a :2 10 2d 2f
:2 2d 10 20 21 :2 20 :2 10 :2 19 25
3c 4a 58 2f 3a 46 52 2f
3d 50 :2 25 10 33 :2 d 10 19
25 :2 10 28 2a :2 28 1f 36 4a
13 1a 16 22 :3 20 16 :2 1f 2b
16 27 16 :2 1f 2b 16 :4 13 10
:2 18 16 :2 1f 2b 16 19 :2 23 35
:2 3f 4b 4f 61 64 65 :2 61 :2 35
:3 19 :2 1f 24 30 71 74 :2 30 81
84 :2 30 88 8b :2 30 97 9a :2 30
a2 a5 :2 30 b1 b4 bb c4 c7
:2 b4 :2 30 :2 19 68 :2 16 :2 13 :4 1f :2 13
10 :3 2c 1f 36 43 54 68 13
1a 16 22 :3 20 16 :2 1f 2b 16
27 16 :2 1f 2b 16 :4 13 10 :2 18
16 :2 1f 2b 16 19 :2 23 35 :2 3f
4b 4f 61 65 66 :2 61 :2 35 :3 19
:2 1f 24 30 72 75 :2 30 82 85
:2 30 89 8c :2 30 98 9b :2 30 a3
a6 :2 30 b2 b5 bc c5 c8 :2 b5
:2 30 :2 19 69 :2 16 :2 13 :4 1f :2 13 10
:3 2c 10 27 10 1a 1e 2d 3c
19 26 37 4b :2 13 :2 1c 28 13
10 :2 18 16 :2 1f 2b 16 19 :2 23
35 :2 3f 4b 4f 61 65 66 :2 61
:2 35 :3 19 :2 1f 24 30 72 75 :2 30
82 85 :2 30 89 8c :2 30 98 9b
:2 30 a3 a6 :2 30 b2 b5 bc c5
c8 :2 b5 :2 30 :2 19 69 :2 16 :2 13 :4 1f
:2 13 10 :3 2c 13 :2 1e 26 34 3f
:2 13 43 46 :2 43 1d 28 35 3d
44 61 6c 71 :2 1b :2 16 :2 1f 2b
16 13 :2 1b 19 :2 22 2e 19 1c
:2 26 38 :2 42 4e 52 64 68 69
:2 64 :2 38 :3 1c :2 22 27 33 75 78
:2 33 85 88 :2 33 8c 8f :2 33 9b
9e :2 33 a6 a9 :2 33 b5 b8 bf
c8 cb :2 b8 :2 33 :2 1c 6c :2 19 :2 16
:4 22 :2 16 13 :4 48 :2 10 2c 14 1d
33 :2 14 36 38 :2 36 13 40 49
5f :2 40 62 64 :2 62 3f :3 13 21
2a 36 :2 21 39 3b 44 54 :2 3b
:2 21 :2 13 22 2b 38 :2 22 3b 3d
46 56 :2 3d :2 22 :2 13 21 2a 36
:2 21 39 3b 44 54 :2 3b :2 21 :2 13
22 2b 38 :2 22 3b 3d 46 56
:2 3d :2 22 13 16 1f 2b :2 16 2e
30 :2 2e 20 35 49 19 27 31
19 28 19 28 19 28 19 28
19 2f 4a 59 19 33 40 55
19 27 30 37 44 4d 1f 33
19 20 1c 28 :3 26 1c :2 25 31
1c 2d 1c :2 25 31 1c :4 19 16
:2 1e 1c :2 25 31 1c 1f :2 29 3b
:2 45 51 55 67 6b 6c :2 67 :2 3b
:3 1f :2 25 2a 36 78 7b :2 36 88
8b :2 36 8f 92 :2 36 9e a1 :2 36
a9 ac :2 36 b8 bb c2 cb ce
:2 bb :2 36 :2 1f 6f :2 1c :2 19 :4 25 :2 19
16 :4 32 20 35 49 19 27 31
19 28 19 28 19 28 19 28
19 2f 4a 59 19 33 40 55
19 36 43 5a 19 27 30 37
44 4d 1f 33 19 20 1c 28
:3 26 1c :2 25 31 1c 2d 1c :2 25
31 1c :4 19 16 :2 1e 1c :2 25 31
1c 1f :2 29 3b :2 45 51 55 67
6b 6c :2 67 :2 3b :3 1f :2 25 2a 36
78 7b :2 36 88 8b :2 36 8f 92
:2 36 9e a1 :2 36 a9 ac :2 36 b8
bb c2 cb ce :2 bb :2 36 :2 1f 6f
:2 1c :2 19 :4 25 :2 19 16 :7 13 10 67
16 1f 35 :2 16 38 3a :2 38 13
21 2a 36 :2 21 39 3b 44 54
:2 3b :2 21 :2 13 22 2b 38 :2 22 3b
3d 46 56 :2 3d :2 22 13 1d 32
46 16 24 2e 16 25 16 25
16 2c 47 56 16 30 3d 52
16 24 2d 34 41 4a 1c 30
16 1d 19 25 :3 23 19 :2 22 2e
19 2a 19 :2 22 2e 19 :4 16 13
:2 1b 19 :2 22 2e 19 1c :2 26 38
:2 42 4e 52 64 68 69 :2 64 :2 38
:3 1c :2 22 27 33 75 78 :2 33 85
88 :2 33 8c 8f :2 33 9b 9e :2 33
a6 a9 :2 33 b5 b8 bf c8 cb
:2 b8 :2 33 :2 1c 6c :2 19 :2 16 :4 22 :2 16
13 :3 3c 10 3c 67 16 1f 35
:2 16 38 3a :2 38 13 21 2a 36
:2 21 39 3b 44 54 :2 3b :2 21 :2 13
22 2b 38 :2 22 3b 3d 46 56
:2 3d :2 22 13 16 1f 2b :2 16 2e
30 :2 2e 20 35 49 19 27 31
19 28 19 28 19 2f 4a 59
19 27 30 37 44 4d 1f 33
19 20 1c 28 :3 26 1c :2 25 31
1c 2d 1c :2 25 31 1c :4 19 16
:2 1e 1c :2 25 31 1c 1f :2 29 3b
:2 45 51 55 67 6b 6c :2 67 :2 3b
:3 1f :2 25 2a 36 78 7b :2 36 88
8b :2 36 8f 92 :2 36 9e a1 :2 36
a9 ac :2 36 b8 bb c2 cb ce
:2 bb :2 36 :2 1f 6f :2 1c :2 19 :4 25 :2 19
16 :4 32 20 35 49 19 27 31
19 28 19 28 19 2f 4a 59
19 36 43 5a 19 27 30 37
44 4d 1f 33 19 20 1c 28
:3 26 1c :2 25 31 1c 2d 1c :2 25
31 1c :4 19 16 :2 1e 1c :2 25 31
1c 1f :2 29 3b :2 45 51 55 67
6b 6c :2 67 :2 3b :3 1f :2 25 2a 36
78 7b :2 36 88 8b :2 36 8f 92
:2 36 9e a1 :2 36 a9 ac :2 36 b8
bb c2 cb ce :2 bb :2 36 :2 1f 6f
:2 1c :2 19 :4 25 :2 19 16 :7 13 3c 67
1d 32 46 16 2c 47 56 16
24 2e 1c 30 16 1d 19 25
:3 23 19 :2 22 2e 19 2a 19 :2 22
2e 19 :4 16 13 :2 1b 19 :2 22 2e
19 1c :2 26 38 :2 42 4e 52 64
68 69 :2 64 :2 38 :3 1c :2 22 27 33
75 78 :2 33 85 88 :2 33 8c 8f
:2 33 9b 9e :2 33 a6 a9 :2 33 b5
b8 bf c8 cb :2 b8 :2 33 :2 1c 6c
:2 19 :2 16 :4 22 :2 16 13 :7 10 1f 36
43 54 68 13 1a 16 22 :3 20
16 :2 1f 2b 16 27 16 :2 1f 2b
16 :4 13 10 :2 18 16 :2 1f 2b 16
19 :2 23 35 :2 3f 4b 4f 61 65
66 :2 61 :2 35 :3 19 :2 1f 24 30 72
75 :2 30 82 85 :2 30 89 8c :2 30
98 9b :2 30 a3 a6 :2 30 b2 b5
bc c5 c8 :2 b5 :2 30 :2 19 69 :2 16
:2 13 :4 1f :2 13 10 :3 d 1f 1a 2f
39 4f 5e 73 87 18 35 49
13 1a 16 22 :3 20 16 :2 1f 2b
16 27 16 :2 1f 2b 16 :4 13 10
:2 18 16 :2 1f 2b 16 19 :2 23 35
:2 3f 4b 4f 61 65 66 :2 61 :2 35
:3 19 :2 1f 24 30 72 75 :2 30 82
85 :2 30 89 8c :2 30 98 9b :2 30
a3 a6 :2 30 b2 b5 bc c5 c8
:2 b5 :2 30 :2 19 69 :2 16 :2 13 :4 1f :2 13
10 :8 d 18 d 1c 37 4b 10
17 13 1f :3 1d 13 :2 1c 28 13
24 13 :2 1c 28 13 :4 10 d :2 15
13 :2 1c 28 13 16 :2 20 32 :2 3c
48 4c 5e 62 63 :2 5e :2 32 :3 16
:2 1c 21 2d 6f 72 :2 2d 7f 82
:2 2d 86 89 :2 2d 95 98 :2 2d a0
a3 :2 2d af b2 b9 c2 c5 :2 b2
:2 2d :2 16 66 :2 13 :2 10 :4 1c :2 10 d
:3 63 1c 36 43 54 62 10 17
13 1f :3 1d 13 :2 1c 28 13 24
13 :2 1c 28 13 :4 10 d :2 15 13
:2 1c 28 13 16 :2 20 32 :2 3c 48
4c 5e 62 63 :2 5e :2 32 :3 16 :2 1c
21 2d 6f 72 :2 2d 7f 82 :2 2d
86 89 :2 2d 95 98 :2 2d a0 a3
:2 2d af b2 b9 c2 c5 :2 b2 :2 2d
:2 16 66 :2 13 :2 10 :4 1c :2 10 d :3 63
11 1a 26 :2 11 29 2b :2 29 10
33 3c 48 :2 33 4b 4d :2 4b 32
:3 10 1f :2 10 19 10 13 :2 1c 27
3a :2 13 3d 40 :2 3d 13 1f 13
42 13 1f 13 :4 10 13 1c 28
:2 13 2b 2d :2 2b 13 1d 13 2f
:3 10 1e 2f 3b 48 51 5a :2 48
5e 67 6f :2 5e 22 2b 37 :2 22
3b 44 4f :2 3b 53 20 2b :2 53
2f 38 46 :2 2f 4a 53 5e :2 4a
22 2b 37 :2 22 3b 43 4d :2 1e
10 13 1c 28 :2 13 2d 2b :2 36
:2 2b 16 :2 20 32 :2 3c 48 4b 5d
61 62 :2 5d :2 32 :3 16 :2 1c 21 2d
6f 72 :2 2d 7f 82 :2 2d 86 89
:2 2d 93 96 9f a7 :2 b0 :2 9f c1
:2 96 :2 2d :2 16 65 :2 13 16 :2 20 32
:2 3c 48 4b 5d 61 62 :2 5d :2 32
:3 16 :2 1c 21 2d 6f 72 :2 2d :2 16
65 :3 13 :2 1e 34 :2 3d 4d :2 13 10
45 16 1f 2b :2 16 2e 31 :2 2e
16 :2 20 32 :2 3c 48 4c 5e 62
63 :2 5e :2 32 :3 16 :2 1c 21 2d 6f
72 :2 2d 7f 82 :2 2d 86 89 :2 2d
93 96 9f a7 :2 9f b4 :2 96 :2 2d
bc bf :2 2d c7 ca :2 2d cf d2
:2 2d df e2 :2 2d :2 16 66 :2 13 16
:2 20 32 :2 3c 48 4b 5d 61 62
:2 5d :2 32 :3 16 :2 1c 21 2d 6f 72
:2 2d :2 16 65 :3 13 :2 1e 32 3b 47
:2 32 4b 59 :2 13 33 45 :2 10 13
1c 24 :2 13 27 29 :2 27 13 20
:2 29 13 2b 13 20 :2 29 30 39
44 :2 30 48 :2 51 :2 20 13 :5 10 23
:2 10 1c 28 3d 4b 59 63 1b
23 2f 3b 47 53 1b 2a 36
40 48 51 59 1b 27 33 40
4b 56 1b 25 30 3c 48 4b
4e 54 :2 1c 10 13 1c 26 :2 13
29 2b :2 29 16 :2 20 32 :2 3c 48
4c 5e 62 63 :2 5e :2 32 :3 16 :2 1c
21 2d 6f 72 :2 2d 7f 82 :2 2d
86 89 :2 2d 93 96 9f a7 :2 b0
:2 9f c7 :2 96 :2 2d cf d2 :2 2d da
dd :2 2d e2 e5 :2 2d ee f1 :2 2d
:2 16 66 :2 13 16 :2 20 32 :2 3c 48
4b 5d 61 62 :2 5d :2 32 :3 16 :2 1c
21 2d 6f 72 :2 2d :2 16 65 :3 13
:2 1e 32 :2 3b 51 5b :2 13 10 2f
16 1f 29 :2 16 2c 2f :2 2c 16
:2 20 32 :2 3c 48 4c 5e 62 63
:2 5e :2 32 :3 16 :2 1c 21 2d 70 73
:2 2d 80 83 :2 2d 87 8a :2 2d 94
97 a0 a8 :2 b1 :2 a0 c9 :2 97 :2 2d
d1 d4 :2 2d dc df :2 2d e4 e7
:2 2d f7 fa :2 2d :2 16 66 :2 13 16
:2 20 32 :2 3c 48 4b 5d 61 62
:2 5d :2 32 :3 16 :2 1c 21 2d 70 73
:2 2d :2 16 65 :3 13 :2 1e 32 :2 3b 52
1b :2 13 31 2f 13 21 :2 13 21
31 3f 54 60 69 74 :2 60 21
2a 34 :4 21 13 :4 10 50 :2 d 63
:2 a 7 39 d 14 24 27 :2 d
2a 2c :2 2a 14 27 2f 36 4e
56 5d 76 80 91 9f 12 27
32 3e 4a 5d 69 12 13 20
31 3b 11 29 37 :2 d :2 16 22
d a :2 12 10 :2 19 25 10 13
:2 1d 2f :2 39 45 49 5b 5f 60
:2 5b :2 2f :3 13 :2 19 1e 2a 6d 70
:2 2a 7d 80 :2 2a 84 87 :2 2a 93
96 :2 2a 9e a1 :2 2a ad b0 b7
c0 c3 :2 b0 :2 2a :2 13 63 :2 10 :2 d
:4 19 :2 d a :3 30 e :2 17 22 20
:2 2b :2 20 d :4 41 40 3f :3 d 1d
1e :2 1d :2 d :2 16 22 39 47 55
2f 3a 46 52 2f 3d 50 :2 22
d 63 :2 a 30 39 14 27 35
4a 12 13 20 31 3b 11 1f
30 :2 d :2 16 22 d a :2 12 10
:2 19 25 10 13 :2 1d 2f :2 39 45
49 5b 5f 60 :2 5b :2 2f :3 13 :2 19
1e 2a 6d 70 :2 2a 7d 80 :2 2a
84 87 :2 2a 93 96 :2 2a 9e a1
:2 2a ad b0 b7 c0 c3 :2 b0 :2 2a
:2 13 63 :2 10 :2 d :4 19 :2 d a :7 7
4 23 a 11 21 24 :2 a 27
29 :2 27 11 24 2c 33 4b 53
5a 73 7d 8e 9c f 24 2f
3b 47 5a 66 f 10 1d 2e
38 e 1c 2d :2 a :2 13 1f a
7 :2 f d :2 16 22 d 10 :2 1a
2c :2 36 42 46 58 5c 5d :2 58
:2 2c :3 10 :2 16 1b 27 6a 6d :2 27
7a 7d :2 27 81 84 :2 27 90 93
:2 27 9b 9e :2 27 aa ad b4 bd
c0 :2 ad :2 27 :2 10 60 :2 d :2 a :4 16
:2 a 7 :3 2d b :2 14 1f 1d :2 28
:2 1d a :4 3e 3d 3c :3 a 1a 1b
:2 1a :2 a :2 13 1f 36 44 52 2f
3a 46 52 2f 3d 50 :2 1f a
60 :2 7 2d 23 11 24 32 47
f 10 1d 2e 38 e 1c 2d
:2 a :2 13 1f a 7 :2 f d :2 16
22 d 10 :2 1a 2c :2 36 42 46
58 5c 5d :2 58 :2 2c :3 10 :2 16 1b
27 6a 6d :2 27 7a 7d :2 27 81
84 :2 27 90 93 :2 27 9b 9e :2 27
aa ad b4 bd c0 :2 ad :2 27 :2 10
60 :2 d :2 a :4 16 :2 a 7 :7 4 :4 9
8 7 2c 35 41 :2 2c 44 46
:2 44 2b :2 7 4e a 16 :2 4e 19
1b :2 19 4d :3 7 1e :2 7 :3 1e 7
a 13 19 :2 a 1c 1e :2 1c a
1d 26 2e :2 1d a 22 :2 7 b
14 2a :2 b 2d 2f :2 2d a 36
3f 55 :2 36 58 5a :2 58 35 :2 a
e 17 2d :2 e 30 32 :2 30 d
3a 43 59 :2 3a 5c 5e :2 5c 39
:3 d 1b 24 30 :2 1b 33 35 3e
4e :2 35 :2 1b :2 d 1c 25 32 :2 1c
35 37 40 50 :2 37 :2 1c :2 d 1b
24 30 :2 1b 33 35 3e 4e :2 35
:2 1b :2 d 1c 25 32 :2 1c 35 37
40 50 :2 37 :2 1c d 1c 2d 3f
51 59 64 67 6a 73 10 1f
2f 39 47 56 62 70 10 1a
2b 38 45 52 60 6f 7e 17
2c 3d 4b 59 62 68 71 77
83 10 1c 2e 3a 47 50 5c
10 1c 2e 39 45 50 5c 6d
7e 10 17 13 1f :3 1d 13 :2 1c
28 13 24 13 :2 1c 28 13 :4 10
d :2 15 13 :2 1c 28 13 16 :2 20
32 :2 3c 48 4c 5e 62 63 :2 5e
:2 32 :3 16 :2 1c 21 2d 70 73 :2 2d
80 83 :2 2d 87 8a :2 2d 96 99
:2 2d a1 a4 :2 2d b0 b3 ba c3
c6 :2 b3 :2 2d :2 16 66 :2 13 :2 10 :4 1c
:2 10 d :3 61 a 61 10 19 2f
:2 10 32 34 :2 32 d 1b 24 30
:2 1b 33 35 3e 4e :2 35 :2 1b :2 d
1c 25 32 :2 1c 35 37 40 50
:2 37 :2 1c d 1c 2d 3f 51 59
64 67 6a 73 10 1f 2f 39
47 56 62 70 10 1a 2b 38
45 52 60 6f 7e 17 2c 3d
4b 59 62 68 71 77 83 10
1c 2e 3a 47 50 5c 10 1c
2e 39 45 50 5d 6e 7f 10
17 13 1f :3 1d 13 :2 1c 28 13
24 13 :2 1c 28 13 :4 10 d :2 15
13 :2 1c 28 13 16 :2 20 32 :2 3c
48 4c 5e 62 63 :2 5e :2 32 :3 16
:2 1c 21 2d 70 73 :2 2d 80 83
:2 2d 87 8a :2 2d 96 99 :2 2d a1
a4 :2 2d b0 b3 ba c3 c6 :2 b3
:2 2d :2 16 66 :2 13 :2 10 :4 1c :2 10 d
:4 36 61 d 1b 24 30 :2 1b 33
35 3e 4e :2 35 :2 1b :2 d 1c 25
32 :2 1c 35 37 40 50 :2 37 :2 1c
d 1c 2d 3f 51 59 64 67
6a 73 10 1f 2f 39 47 56
62 70 10 1a 2b 38 45 52
60 6f 7e 17 2c 3d 4b 59
62 68 71 77 83 10 1c 2e
3a 47 50 5c 10 1c 2e 39
45 50 5d 6e 7f 10 17 13
1f :3 1d 13 :2 1c 28 13 24 13
:2 1c 28 13 :4 10 d :2 15 13 :2 1c
28 13 16 :2 20 32 :2 3c 48 4c
5e 62 63 :2 5e :2 32 :3 16 :2 1c 21
2d 70 73 :2 2d 80 83 :2 2d 87
8a :2 2d 96 99 :2 2d a1 a4 :2 2d
b0 b3 ba c3 c6 :2 b3 :2 2d :2 16
66 :2 13 :2 10 :4 1c :2 10 d :7 a 5d
19 2a 3c 4e 56 61 64 67
70 d 1b 2a 33 40 4e 5a
68 d 17 28 35 42 4f 5d
6c 7b 14 29 3a 48 56 5f
65 6e 74 80 d 19 2b 37
44 4d 59 d 19 2b 36 42
4d 5a 6b 7c d 14 10 1c
:3 1a 10 :2 19 25 10 21 10 :2 19
25 10 :4 d a :2 12 10 :2 19 25
10 13 :2 1d 2f :2 39 45 49 5b
5f 60 :2 5b :2 2f :3 13 :2 19 1e 2a
6d 70 :2 2a 7d 80 :2 2a 84 87
:2 2a 93 96 :2 2a 9e a1 :2 2a ad
b0 b7 c0 c3 :2 b0 :2 2a :2 13 63
:2 10 :2 d :4 19 :2 d a :8 7 12 7
1e :3 4 e 15 1c 1f :2 15 24
27 :2 e :2 4 1b :2 4 10 4 e
20 34 43 50 :2 7 :2 10 1c 7
4 :2 c a :2 13 1f a d :2 17
29 :2 33 3f 43 55 59 5a :2 55
:2 29 :3 d :2 13 18 24 67 6a :2 24
77 7a :2 24 7e 81 :2 24 8d 90
:2 24 98 9b :2 24 a7 aa b1 ba
bd :2 aa :2 24 :2 d 5d :2 a :2 7 :4 13
:2 7 4 :3 1 4 12 :2 4 12 :2 4
f 4 8 11 13 :2 11 7 1b
24 30 :2 1b 33 35 :2 33 1a :2 7
11 15 17 2b f 17 1a 2b
10 12 1f 30 32 40 a c
16 18 27 29 35 3e 46 4f
5d 66 74 7d 8b 94 a1 aa
bb c4 d7 e0 f5 fe 119 122
13a 143 154 15d 16f 178 190 199
1ac 1b5 1d6 1d8 1e2 :2 a :2 13 1f
a 7 :2 f d :2 16 22 d 10
:2 1a 2c :2 36 42 46 58 5c 5d
:2 58 :2 2c :3 10 :2 16 1b 27 6a 6d
:2 27 7a 7d :2 27 81 84 :2 27 90
93 :2 27 9b 9e :2 27 aa ad b4
bd c0 :2 ad :2 27 :2 10 60 :2 d :2 a
:4 16 :2 a 7 :4 38 :3 4 14 :2 4 9
:4 4 d 16 23 38 43 4b 55
7 c 11 21 32 7 1c 27
39 44 7 f 18 20 2b :3 7
a e :2 a :2 13 1f a 14 a
:2 13 1f a :4 7 b :2 14 20 1d
:2 29 :2 1d :3 a 39 :2 7 a 13 1d
:2 a 20 22 :2 20 a 1d 34 41
:2 1d a 19 34 48 d 14 10
1c :3 1a 10 :2 19 25 10 21 10
:2 19 25 10 :4 d a :2 12 10 :2 19
25 10 13 :2 1d 2f :2 39 45 49
5b 5f 60 :2 5b :2 2f :3 13 :2 19 1e
2a 6d 70 :2 2a 7d 80 :2 2a 84
87 :2 2a 93 96 :2 2a 9e a1 :2 2a
ad b0 b7 c0 c3 :2 b0 :2 2a :2 13
63 :2 10 :2 d :4 19 :2 d a :3 24 19
30 44 d 14 10 1c :3 1a 10
:2 19 25 10 21 10 :2 19 25 10
:4 d a :2 12 10 :2 19 25 10 13
:2 1d 2f :2 39 45 49 5b 5f 60
:2 5b :2 2f :3 13 :2 19 1e 2a 6d 70
:2 2a 7d 80 :2 2a 84 87 :2 2a 93
96 :2 2a 9e a1 :2 2a ad b0 b7
c0 c3 :2 b0 :2 2a :2 13 63 :2 10 :2 d
:4 19 :2 d a :3 24 19 2b 3f d
14 10 1c :3 1a 10 :2 19 25 10
21 10 :2 19 25 10 :4 d a :2 12
10 :2 19 25 10 13 :2 1d 2f :2 39
45 49 5b 5f 60 :2 5b :2 2f :3 13
:2 19 1e 2a 6d 70 :2 2a 7d 80
:2 2a 84 87 :2 2a 93 96 :2 2a 9e
a1 :2 2a ad b0 b7 c0 c3 :2 b0
:2 2a :2 13 63 :2 10 :2 d :4 19 :2 d a
:3 24 19 30 3d 4e 62 d 14
10 1c :3 1a 10 :2 19 25 10 21
10 :2 19 25 10 :4 d a :2 12 10
:2 19 25 10 13 :2 1d 2f :2 39 45
49 5b 5f 60 :2 5b :2 2f :3 13 :2 19
1e 2a 6d 70 :2 2a 7d 80 :2 2a
84 87 :2 2a 93 96 :2 2a 9e a1
:2 2a ad b0 b7 c0 c3 :2 b0 :2 2a
:2 13 63 :2 10 :2 d :4 19 :2 d a :3 24
19 35 49 d 14 10 1c :3 1a
10 :2 19 25 10 21 10 :2 19 25
10 :4 d a :2 12 10 :2 19 25 10
13 :2 1d 2f :2 39 45 49 5b 5f
60 :2 5b :2 2f :3 13 :2 19 1e 2a 6d
70 :2 2a 7d 80 :2 2a 84 87 :2 2a
93 96 :2 2a 9e a1 :2 2a ad b0
b7 c0 c3 :2 b0 :2 2a :2 13 63 :2 10
:2 d :4 19 :2 d a :3 24 19 36 4a
d 14 10 1c :3 1a 10 :2 19 25
10 21 10 :2 19 25 10 :4 d a
:2 12 10 :2 19 25 10 13 :2 1d 2f
:2 39 45 49 5b 5f 60 :2 5b :2 2f
:3 13 :2 19 1e 2a 6d 70 :2 2a 7d
80 :2 2a 84 87 :2 2a 93 96 :2 2a
9e a1 :2 2a ad b0 b7 c0 c3
:2 b0 :2 2a :2 13 63 :2 10 :2 d :4 19 :2 d
a :4 24 14 2b 39 13 27 11
1e 11 1f d 14 10 1c :3 1a
10 :2 19 25 10 21 10 :2 19 25
10 :4 d a :2 12 10 :2 19 25 10
13 :2 1d 2f :2 39 45 49 5b 5f
60 :2 5b :2 2f :3 13 :2 19 1e 2a 6d
70 :2 2a 7d 80 :2 2a 84 87 :2 2a
93 96 :2 2a 9e a1 :2 2a ad b0
b7 c0 c3 :2 b0 :2 2a :2 13 63 :2 10
:2 d :4 19 :2 d a :3 7 14 2b 35
13 20 31 3b 49 57 11 :2 d
:2 16 22 d a :2 12 10 :2 19 25
10 13 :2 1d 2f :2 39 45 49 5b
5f 60 :2 5b :2 2f :3 13 :2 19 1e 2a
6d 70 :2 2a 7d 80 :2 2a 84 87
:2 2a 93 96 :2 2a 9e a1 :2 2a ad
b0 b7 c0 c3 :2 b0 :2 2a :2 13 63
:2 10 :2 d :4 19 :2 d a :3 7 e :2 17
22 20 :2 2b :2 20 d 10 19 25
:2 10 28 2a :2 28 10 27 10 2c
:2 d 17 2a 37 48 4e 5d 15
16 23 31 3f 4c :2 10 :2 19 25
10 d :2 15 13 :2 1c 28 13 16
:2 20 32 :2 3c 48 4c 5e 62 63
:2 5e :2 32 :3 16 :2 1c 21 2d 70 73
:2 2d 80 83 :2 2d 87 8a :2 2d 96
99 :2 2d a1 a4 :2 2d b0 b3 ba
c3 c6 :2 b3 :2 2d :2 16 66 :2 13 :2 10
:4 1c :2 10 d :3 3b 11 :2 1a 25 23
:2 2e :2 23 10 14 1b 24 33 :2 1b
37 :2 40 :2 14 13 52 50 :2 5b :2 50
13 1f 13 1d 16 24 16 25
16 1c 30 16 1d 19 25 :3 23
19 :2 22 2e 19 2a 19 :2 22 2e
19 :4 16 13 :2 1b 19 :2 22 2e 19
1c :2 26 38 :2 42 4e 52 64 68
69 :2 64 :2 38 :3 1c :2 22 27 33 76
79 :2 33 86 89 :2 33 8d 90 :2 33
9c 9f :2 33 a7 aa :2 33 b6 b9
c0 c9 cc :2 b9 :2 33 :2 1c 6c :2 19
:2 16 :4 22 :2 16 13 :3 69 10 69 16
1f 2e :2 16 33 31 :2 3c :2 31 13
26 34 37 40 48 :2 37 4c :2 55
24 :2 26 13 1d 16 25 2e 16
25 16 24 16 25 16 1c 30
16 1d 19 25 :3 23 19 :2 22 2e
19 2a 19 :2 22 2e 19 :4 16 13
:2 1b 19 :2 22 2e 19 1c :2 26 38
:2 42 4e 52 64 68 69 :2 64 :2 38
:3 1c :2 22 27 33 76 79 :2 33 86
89 :2 33 8d 90 :2 33 9c 9f :2 33
a7 aa :2 33 b6 b9 c0 c9 cc
:2 b9 :2 33 :2 1c 6c :2 19 :2 16 :4 22 :2 16
13 :4 4b 69 1d 16 25 2e 35
43 4c 16 25 16 24 16 25
16 1c 30 16 1d 19 25 :3 23
19 :2 22 2e 19 2a 19 :2 22 2e
19 :4 16 13 :2 1b 19 :2 22 2e 19
1c :2 26 38 :2 42 4e 52 64 68
69 :2 64 :2 38 :3 1c :2 22 27 33 76
79 :2 33 86 89 :2 33 8d 90 :2 33
9c 9f :2 33 a7 aa :2 33 b6 b9
c0 c9 cc :2 b9 :2 33 :2 1c 6c :2 19
:2 16 :4 22 :2 16 13 :7 10 14 :2 1d 28
26 :2 31 :2 26 13 46 4f 59 :2 46
5c 5e :2 5c 45 :2 13 22 3d 51
16 1d 19 25 :3 23 19 :2 22 2e
19 2a 19 :2 22 2e 19 :4 16 13
:2 1b 19 :2 22 2e 19 1c :2 26 38
:2 42 4e 52 64 68 69 :2 64 :2 38
:3 1c :2 22 27 33 76 79 :2 33 86
89 :2 33 8d 90 :2 33 9c 9f :2 33
a7 aa :2 33 b6 b9 c0 c9 cc
:2 b9 :2 33 :2 1c 6c :2 19 :2 16 :4 22 :2 16
13 :4 61 :2 10 3e 1a 1d 30 37
3a 49 4f 52 18 1d 27 2f
33 48 19 1c 29 37 3a 47
4a 59 5c 17 1a 28 2b 1a
31 42 4b 4e 62 65 :2 13 :2 1c
28 13 10 :2 18 16 :2 1f 2b 16
19 :2 23 35 :2 3f 4b 4f 61 65
66 :2 61 :2 35 :3 19 :2 1f 24 30 73
76 :2 30 83 86 :2 30 8a 8d :2 30
99 9c :2 30 a4 a7 :2 30 b3 b6
bd c6 c9 :2 b6 :2 30 :2 19 69 :2 16
:2 13 :4 1f :2 13 10 :3 d 14 :2 1d 28
26 :2 31 :2 26 13 :4 47 46 45 :3 13
26 34 37 40 48 :2 37 4c :2 55
24 :2 26 13 22 3d 51 16 1d
19 25 :3 23 19 :2 22 2e 19 2a
19 :2 22 2e 19 :4 16 13 :2 1b 19
:2 22 2e 19 1c :2 26 38 :2 42 4e
52 64 68 69 :2 64 :2 38 :3 1c :2 22
27 33 76 79 :2 33 86 89 :2 33
8d 90 :2 33 9c 9f :2 33 a7 aa
:2 33 b6 b9 c0 c9 cc :2 b9 :2 33
:2 1c 6c :2 19 :2 16 :4 22 :2 16 13 :3 5a
1d 36 44 4e 16 23 31 43
4f 1c 30 16 1d 19 25 :3 23
19 :2 22 2e 19 2a 19 :2 22 2e
19 :4 16 13 :2 1b 19 :2 22 2e 19
1c :2 26 38 :2 42 4e 52 64 68
69 :2 64 :2 38 :3 1c :2 22 27 33 76
79 :2 33 86 89 :2 33 8d 90 :2 33
9c 9f :2 33 a7 aa :2 33 b6 b9
c0 c9 cc :2 b9 :2 33 :2 1c 6c :2 19
:2 16 :4 22 :2 16 13 :3 5a 1d 29 38
41 4f 55 1c 29 16 1d 19
25 :3 23 19 :2 22 2e 19 2a 19
:2 22 2e 19 :4 16 13 :2 1b 19 :2 22
2e 19 1c :2 26 38 :2 42 4e 52
64 68 69 :2 64 :2 38 :3 1c :2 22 27
33 76 79 :2 33 86 89 :2 33 8d
90 :2 33 9c 9f :2 33 a7 aa :2 33
b6 b9 c0 c9 cc :2 b9 :2 33 :2 1c
6c :2 19 :2 16 :4 22 :2 16 13 :4 5a 13
26 34 37 40 48 :2 37 4c :2 55
24 :2 26 13 1d 29 38 41 4f
5f 72 7f 16 1d 19 25 :3 23
19 :2 22 2e 19 2a 19 :2 22 2e
19 :4 16 13 :2 1b 19 :2 22 2e 19
1c :2 26 38 :2 42 4e 52 64 68
69 :2 64 :2 38 :3 1c :2 22 27 33 76
79 :2 33 86 89 :2 33 8d 90 :2 33
9c 9f :2 33 a7 aa :2 33 b6 b9
c0 c9 cc :2 b9 :2 33 :2 1c 6c :2 19
:2 16 :4 22 :2 16 13 :3 10 1d 36 44
4e 16 23 31 43 4f 1c 30
16 1d 19 25 :3 23 19 :2 22 2e
19 2a 19 :2 22 2e 19 :4 16 13
:2 1b 19 :2 22 2e 19 1c :2 26 38
:2 42 4e 52 64 68 69 :2 64 :2 38
:3 1c :2 22 27 33 76 79 :2 33 86
89 :2 33 8d 90 :2 33 9c 9f :2 33
a7 aa :2 33 b6 b9 c0 c9 cc
:2 b9 :2 33 :2 1c 6c :2 19 :2 16 :4 22 :2 16
13 :7 10 :4 d 10 19 23 :2 10 26
28 :2 26 14 1d 2b :2 14 2e 30
:2 2e 13 :4 39 38 37 :2 13 27 49
59 1b 2d 3b 46 :2 16 :2 1f 2b
16 13 :2 1b 19 :2 22 2e 19 1c
:2 26 38 :2 42 4e 52 64 68 69
:2 64 :2 38 :3 1c :2 22 27 33 76 79
:2 33 86 89 :2 33 8d 90 :2 33 9c
9f :2 33 a7 aa :2 33 b6 b9 c0
c9 cc :2 b9 :2 33 :2 1c 6c :2 19 :2 16
:4 22 :2 16 13 :3 54 17 :2 20 2b 29
:2 34 :2 29 16 49 52 60 :2 49 63
65 :2 63 48 :2 16 20 2c 3c 4f
5a 19 20 1c 28 :3 26 1c :2 25
31 1c 2d 1c :2 25 31 1c :4 19
16 :2 1e 1c :2 25 31 1c 1f :2 29
3b :2 45 51 55 67 6b 6c :2 67
:2 3b :3 1f :2 25 2a 36 79 7c :2 36
89 8c :2 36 90 93 :2 36 9f a2
:2 36 aa ad :2 36 b9 bc c3 cc
cf :2 bc :2 36 :2 1f 6f :2 1c :2 19 :4 25
:2 19 16 :3 68 13 68 1a :2 23 2e
2c :2 37 :2 2c 19 4c 55 63 :2 4c
66 68 :2 66 4b :3 19 1f :3 19 :2 22
2e 19 16 :2 1e 1c :2 25 31 1c
1f :2 29 3b :2 45 51 55 67 6b
6c :2 67 :2 3b :3 1f :2 25 2a 36 79
7c :2 36 89 8c :2 36 90 93 :2 36
9f a2 :2 36 aa ad :2 36 b9 bc
c3 cc cf :2 bc :2 36 :2 1f 6f :2 1c
:2 19 :4 25 :2 19 16 :3 6b 19 :2 23 35
:2 3f 4b 4f 61 65 66 :2 61 :2 35
:3 19 :2 1f 24 30 73 76 :2 30 83
86 :2 30 8a 8d :2 30 97 9a a3
ab :2 b4 :2 a3 cf :2 9a :2 30 d7 da
:2 30 e2 e5 :2 30 ea ed :2 30 f7
fa :2 30 :2 19 69 :2 16 19 :2 23 35
:2 3f 4b 4e 60 64 65 :2 60 :2 35
:3 19 :2 1f 24 30 73 76 :2 30 :2 19
68 :3 16 :2 21 35 :2 3e 58 1e :2 16
6b 68 :2 13 54 :3 10 20 21 :2 20
:2 10 :2 19 25 3c 4a 55 6a 70
2f 3b 47 2f 42 :2 25 10 1f
36 43 54 68 13 1a 16 22
:3 20 16 :2 1f 2b 16 27 16 :2 1f
2b 16 :4 13 10 :2 18 16 :2 1f 2b
16 19 :2 23 35 :2 3f 4b 4f 61
65 66 :2 61 :2 35 :3 19 :2 1f 24 30
73 76 :2 30 83 86 :2 30 8a 8d
:2 30 99 9c :2 30 a4 a7 :2 30 b3
b6 bd c6 c9 :2 b6 :2 30 :2 19 69
:2 16 :2 13 :4 1f :2 13 10 :3 2a 10 21
10 13 1c 1f :2 1c 13 1f :2 13
23 :2 13 24 :2 13 1d :2 13 23 :2 13
1e :2 13 1d :2 13 20 :2 13 20 13
19 20 29 35 :2 20 39 :2 42 :2 19
18 50 53 :2 50 17 5c 19 24
:2 5c 2a 27 33 3f :2 2a :2 27 5b
47 19 21 :2 47 27 24 30 39
:2 27 :2 24 46 :2 5b 5a :2 17 16 19
22 28 :2 19 2b 2d :2 2b 23 1c
2a 34 47 26 44 1c 35 53
64 1c 35 53 64 1c 35 53
64 1c 35 53 64 1c 2b 34
3a 1c 2b 1c 2b 34 3b 48
51 22 36 1c 23 1f 2b :3 29
1f :2 28 34 1f 30 1f :2 28 34
1f :4 1c 19 :2 21 1f :2 28 34 1f
22 :2 2c 3e :2 48 54 58 6a 6e
6f :2 6a :2 3e :3 22 :2 28 2d 39 7c
7f :2 39 8c 8f :2 39 93 96 :2 39
a2 a5 :2 39 ad b0 :2 39 bc bf
c6 cf d2 :2 bf :2 39 :2 22 72 :2 1f
:2 1c :4 28 :2 1c 19 :4 31 23 1c 2a
34 47 26 44 1c 35 53 64
1c 35 53 64 1c 35 53 64
1c 35 53 64 1c 2b 34 3a
1c 2b 1c 2b 1c 2b 34 3b
48 51 22 36 1c 23 1f 2b
:3 29 1f :2 28 34 1f 30 1f :2 28
34 1f :4 1c 19 :2 21 1f :2 28 34
1f 22 :2 2c 3e :2 48 54 58 6a
6e 6f :2 6a :2 3e :3 22 :2 28 2d 39
7c 7f :2 39 8c 8f :2 39 93 96
:2 39 a2 a5 :2 39 ad b0 :2 39 bc
bf c6 cf d2 :2 bf :2 39 :2 22 72
:2 1f :2 1c :4 28 :2 1c 19 :7 16 3f 20
19 27 31 44 23 41 19 32
50 61 19 32 50 61 19 32
50 61 19 32 50 61 19 28
31 38 45 4e 5d 63 1f 33
19 20 1c 28 :3 26 1c :2 25 31
1c 2d 1c :2 25 31 1c :4 19 16
:2 1e 1c :2 25 31 1c 1f :2 29 3b
:2 45 51 55 67 6b 6c :2 67 :2 3b
:3 1f :2 25 2a 36 79 7c :2 36 89
8c :2 36 90 93 :2 36 9f a2 :2 36
aa ad :2 36 b9 bc c3 cc cf
:2 bc :2 36 :2 1f 6f :2 1c :2 19 :4 25 :2 19
16 :7 13 17 20 2b :2 17 2e 30
:2 2e 16 38 41 49 :2 38 4c 4f
:2 4c 37 :3 16 20 16 13 54 19
22 2a :2 19 2d 2f :2 2d 16 29
32 3a :2 29 16 33 54 :3 13 21
32 3e 4b 54 5d :2 4b 61 6a
72 :2 61 22 2b 37 :2 22 3b 44
4f :2 3b 53 20 2b :2 53 2f 38
46 :2 2f 4a 53 5e :2 4a 22 2b
37 :2 22 3b 43 4d :2 21 13 16
1f 2b :2 16 30 2e :2 39 :2 2e 19
1f :3 19 :2 22 2e 19 16 :2 1e 1c
:2 25 31 1c 1f :2 29 3b :2 45 51
55 67 6b 6c :2 67 :2 3b :3 1f :2 25
2a 36 79 7c :2 36 89 8c :2 36
90 93 :2 36 9f a2 :2 36 aa ad
:2 36 b9 bc c3 cc cf :2 bc :2 36
:2 1f 6f :2 1c :2 19 :4 25 :2 19 16 :3 48
19 :2 23 35 :2 3f 4b 4e 60 64
65 :2 60 :2 35 :3 19 :2 1f 24 30 73
76 :2 30 83 86 :2 30 8a 8d :2 30
97 9a a3 ab :2 b4 :2 a3 c5 :2 9a
:2 30 :2 19 68 :2 16 19 :2 23 35 :2 3f
4b 4e 60 64 65 :2 60 :2 35 :3 19
:2 1f 24 30 73 76 :2 30 :2 19 68
:3 16 :2 21 37 :2 40 50 :2 16 13 48
19 22 2e :2 19 31 34 :2 31 19
1f :3 19 :2 22 2e 19 16 :2 1e 1c
:2 25 31 1c 1f :2 29 3b :2 45 51
55 67 6b 6c :2 67 :2 3b :3 1f :2 25
2a 36 79 7c :2 36 89 8c :2 36
90 93 :2 36 9f a2 :2 36 aa ad
:2 36 b9 bc c3 cc cf :2 bc :2 36
:2 1f 6f :2 1c :2 19 :4 25 :2 19 16 :3 36
19 :2 23 35 :2 3f 4b 4f 61 65
66 :2 61 :2 35 :3 19 :2 1f 24 30 73
76 :2 30 83 86 :2 30 8a 8d :2 30
97 9a a3 ab :2 a3 b8 :2 9a :2 30
c0 c3 :2 30 cb ce :2 30 d3 d6
:2 30 e3 e6 :2 30 :2 19 69 :2 16 19
:2 23 35 :2 3f 4b 4e 60 64 65
:2 60 :2 35 :3 19 :2 1f 24 30 73 76
:2 30 :2 19 68 :3 16 :2 21 35 3e 4a
:2 35 4e 5c :2 16 36 48 :2 13 21
16 1f 27 :2 16 2a 2c :2 2a 32
3b 4c :2 32 4f 52 :2 4f :2 16 5a
19 2a :2 5a 2d 30 :2 2d :3 16 20
:2 16 20 29 3a :2 20 16 32 :2 13
17 20 2c :2 17 2f 31 :2 2f 16
38 41 4d :2 38 52 50 5b 66
:2 52 :2 50 37 :3 16 24 2d 38 :2 24
16 6a 16 24 2a 33 3f :2 2a
42 44 4d 58 :2 44 :2 2a :2 24 16
:4 13 16 1f 2b :2 16 2e 30 :2 2e
16 24 2d 39 :2 24 3c 3e :2 24
16 33 16 24 2a 34 3d 49
:2 34 :2 2a 4d 4f :2 2a :2 24 16 :4 13
1d 16 24 2e 41 20 3e 16
2f 4d 5e 16 2f 4d 5e 16
2f 4d 5e 16 2f 4d 5e 16
25 2e 35 42 4b 1c 30 16
1d 19 25 :3 23 19 :2 22 2e 19
2a 19 :2 22 2e 19 :4 16 13 :2 1b
19 :2 22 2e 19 1c :2 26 38 :2 42
4e 52 64 68 69 :2 64 :2 38 :3 1c
:2 22 27 33 76 79 :2 33 86 89
:2 33 8d 90 :2 33 9c 9f :2 33 a7
aa :2 33 b6 b9 c0 c9 cc :2 b9
:2 33 :2 1c 6c :2 19 :2 16 :4 22 :2 16 13
:8 10 1f :2 10 1c :2 10 19 10 13
1c 24 :2 13 27 29 :2 27 30 39
4a :2 30 4d 4f :2 4d 56 16 27
:2 56 2a 2c :2 2a :2 30 2f :3 13 20
:2 29 13 2f 13 20 :2 29 30 39
44 :2 30 48 :2 51 :2 20 13 :5 10 20
:2 10 23 :2 10 1c 28 3d 4b 56
60 1b 23 2f 3b 47 53 1b
2a 36 40 48 51 59 1b 27
33 40 4b 56 1b 25 30 3c
48 4b 4e 54 :2 1c 10 13 1c
26 :2 13 29 2b :2 29 16 1c :3 16
:2 1f 2b 16 13 :2 1b 19 :2 22 2e
19 1c :2 26 38 :2 42 4e 52 64
68 69 :2 64 :2 38 :3 1c :2 22 27 33
76 79 :2 33 86 89 :2 33 8d 90
:2 33 9c 9f :2 33 a7 aa :2 33 b6
b9 c0 c9 cc :2 b9 :2 33 :2 1c 6c
:2 19 :2 16 :4 22 :2 16 13 :3 2f 16 :2 20
32 :2 3c 48 4c 5e 62 63 :2 5e
:2 32 :3 16 :2 1c 21 2d 70 73 :2 2d
80 83 :2 2d 87 8a :2 2d 94 97
a0 a8 :2 b1 :2 a0 c8 :2 97 :2 2d d0
d3 :2 2d db de :2 2d e3 e6 :2 2d
ef f2 :2 2d :2 16 66 :2 13 16 :2 20
32 :2 3c 48 4b 5d 61 62 :2 5d
:2 32 :3 16 :2 1c 21 2d 70 73 :2 2d
:2 16 65 :3 13 :2 1e 32 :2 3b 51 5b
:2 13 10 2f 16 1f 29 :2 16 2c
2f :2 2c 16 1c :3 16 :2 1f 2b 16
13 :2 1b 19 :2 22 2e 19 1c :2 26
38 :2 42 4e 52 64 68 69 :2 64
:2 38 :3 1c :2 22 27 33 76 79 :2 33
86 89 :2 33 8d 90 :2 33 9c 9f
:2 33 a7 aa :2 33 b6 b9 c0 c9
cc :2 b9 :2 33 :2 1c 6c :2 19 :2 16 :4 22
:2 16 13 :3 31 16 :2 20 32 :2 3c 48
4c 5e 62 63 :2 5e :2 32 :3 16 :2 1c
21 2d 70 73 :2 2d 80 83 :2 2d
87 8a :2 2d 94 97 a0 a8 :2 b1
:2 a0 c9 :2 97 :2 2d d1 d4 :2 2d dc
df :2 2d e4 e7 :2 2d f7 fa :2 2d
:2 16 66 :2 13 16 :2 20 32 :2 3c 48
4b 5d 61 62 :2 5d :2 32 :3 16 :2 1c
21 2d 70 73 :2 2d :2 16 65 :3 13
:2 1e 32 :2 3b 52 1b :2 13 31 2f
:2 10 1a 26 35 3d 4a 6a 75
13 1a 16 22 :3 20 16 :2 1f 2b
16 27 16 :2 1f 2b 16 :4 13 10
:2 18 16 :2 1f 2b 16 19 :2 23 35
:2 3f 4b 4f 61 65 66 :2 61 :2 35
:3 19 :2 1f 24 30 73 76 :2 30 83
86 :2 30 8a 8d :2 30 99 9c :2 30
a4 a7 :2 30 b3 b6 bd c6 c9
:2 b6 :2 30 :2 19 69 :2 16 :2 13 :4 1f :2 13
10 :3 2a 1f 1a 2f 31 3d 3f
55 57 66 68 7d 7f 18 29
2b 30 39 3e 40 4d 4f 5d
5f 6c 13 1a 16 22 :3 20 16
:2 1f 2b 16 27 16 :2 1f 2b 16
:4 13 10 :2 18 16 :2 1f 2b 16 19
:2 23 35 :2 3f 4b 4f 61 65 66
:2 61 :2 35 :3 19 :2 1f 24 30 73 76
:2 30 83 86 :2 30 8a 8d :2 30 99
9c :2 30 a4 a7 :2 30 b3 b6 bd
c6 c9 :2 b6 :2 30 :2 19 69 :2 16 :2 13
:4 1f :2 13 10 :3 2a 1f 1a 2f 38
4e 5d 72 86 18 34 48 13
1a 16 22 :3 20 16 :2 1f 2b 16
27 16 :2 1f 2b 16 :4 13 10 :2 18
16 :2 1f 2b 16 19 :2 23 35 :2 3f
4b 4f 61 65 66 :2 61 :2 35 :3 19
:2 1f 24 30 73 76 :2 30 83 86
:2 30 8a 8d :2 30 99 9c :2 30 a4
a7 :2 30 b3 b6 bd c6 c9 :2 b6
:2 30 :2 19 69 :2 16 :2 13 :4 1f :2 13 10
:3 2a 1f 1a 2f 39 4f 5e 73
87 18 35 49 13 1a 16 22
:3 20 16 :2 1f 2b 16 27 16 :2 1f
2b 16 :4 13 10 :2 18 16 :2 1f 2b
16 19 :2 23 35 :2 3f 4b 4f 61
65 66 :2 61 :2 35 :3 19 :2 1f 24 30
73 76 :2 30 83 86 :2 30 8a 8d
:2 30 99 9c :2 30 a4 a7 :2 30 b3
b6 bd c6 c9 :2 b6 :2 30 :2 19 69
:2 16 :2 13 :4 1f :2 13 10 :3 2a 10 1c
25 2f :2 1c 32 34 :2 1c :2 10 1b
24 2d :2 1b 30 32 3b 45 :2 32
:2 1b :2 10 23 :2 10 23 3f 4d 5b
:2 23 :2 10 23 :2 10 23 3f 4d 57
:2 23 10 1a 2a 38 19 26 37
4b 13 1a 16 22 :3 20 16 :2 1f
2b 16 27 16 :2 1f 2b 16 :4 13
10 :2 18 16 :2 1f 2b 16 19 :2 23
35 :2 3f 4b 4f 61 65 66 :2 61
:2 35 :3 19 :2 1f 24 30 73 76 :2 30
83 86 :2 30 8a 8d :2 30 99 9c
:2 30 a4 a7 :2 30 b3 b6 bd c6
c9 :2 b6 :2 30 :2 19 69 :2 16 :2 13 :4 1f
:2 13 10 :3 2a 14 1d 33 :2 14 36
38 :2 36 13 40 49 5f :2 40 62
64 :2 62 3f :2 13 1d 34 42 16
2c 16 2c 16 2c 16 2c 16
21 2d 3c 1c 30 16 1d 19
25 :3 23 19 :2 22 2e 19 2a 19
:2 22 2e 19 :4 16 13 :2 1b 19 :2 22
2e 19 1c :2 26 38 :2 42 4e 52
64 68 69 :2 64 :2 38 :3 1c :2 22 27
33 76 79 :2 33 86 89 :2 33 8d
90 :2 33 9c 9f :2 33 a7 aa :2 33
b6 b9 c0 c9 cc :2 b9 :2 33 :2 1c
6c :2 19 :2 16 :4 22 :2 16 13 :3 67 10
67 16 1f 35 :2 16 38 3a :2 38
1d 34 42 16 2c 16 2c 16
21 2d 3c 1c 30 16 1d 19
25 :3 23 19 :2 22 2e 19 2a 19
:2 22 2e 19 :4 16 13 :2 1b 19 :2 22
2e 19 1c :2 26 38 :2 42 4e 52
64 68 69 :2 64 :2 38 :3 1c :2 22 27
33 76 79 :2 33 86 89 :2 33 8d
90 :2 33 9c 9f :2 33 a7 aa :2 33
b6 b9 c0 c9 cc :2 b9 :2 33 :2 1c
6c :2 19 :2 16 :4 22 :2 16 13 :3 3c 13
21 2a 36 :2 21 13 10 3c 67
16 1f 35 :2 16 38 3a :2 38 1d
34 42 16 2c 16 2c 16 21
2d 3c 1c 30 16 1d 19 25
:3 23 19 :2 22 2e 19 2a 19 :2 22
2e 19 :4 16 13 :2 1b 19 :2 22 2e
19 1c :2 26 38 :2 42 4e 52 64
68 69 :2 64 :2 38 :3 1c :2 22 27 33
76 79 :2 33 86 89 :2 33 8d 90
:2 33 9c 9f :2 33 a7 aa :2 33 b6
b9 c0 c9 cc :2 b9 :2 33 :2 1c 6c
:2 19 :2 16 :4 22 :2 16 13 :3 3c 13 21
2a 36 :2 21 13 3c 67 1d 34
42 16 21 2d 3c 1c 30 16
1d 19 25 :3 23 19 :2 22 2e 19
2a 19 :2 22 2e 19 :4 16 13 :2 1b
19 :2 22 2e 19 1c :2 26 38 :2 42
4e 52 64 68 69 :2 64 :2 38 :3 1c
:2 22 27 33 76 79 :2 33 86 89
:2 33 8d 90 :2 33 9c 9f :2 33 a7
aa :2 33 b6 b9 c0 c9 cc :2 b9
:2 33 :2 1c 6c :2 19 :2 16 :4 22 :2 16 13
:3 10 13 21 2a 36 :2 21 :2 13 21
2a 36 :2 21 13 :4 10 2a :2 d 3b
:2 a :5 7 :2 10 1c 32 40 4e :2 1c
7 4 8 1 7 d :3 7 :2 10
1c 7 4 :2 c a :2 13 1f a
d :2 17 29 :2 33 3f 43 55 59
5a :2 55 :2 29 :3 d :2 13 18 24 67
6a :2 24 77 7a :2 24 7e 81 :2 24
8d 90 :2 24 98 9b :2 24 a7 aa
b1 ba bd :2 aa :2 24 :2 d 5d :2 a
:2 7 :4 13 :2 7 4 :3 1 4 f 4
7 10 1a :2 7 1d 1f :2 1d 7
13 7 a 13 1d :2 a 23 20
2c 35 :2 23 :2 20 a 16 1f 29
:2 16 2c 2e 37 40 :2 2e :2 16 a
e 17 21 :2 e 24 26 :2 24 d
2e 37 43 :2 2e 46 48 :2 46 2d
:2 d :4 16 15 14 :3 d 1d :2 d 1e
:2 d 17 :2 d 1d :2 d 18 :2 d 17
:2 d 1a :2 d 1a d 10 19 24
:2 10 27 29 :2 27 2f 38 40 :2 2f
43 46 :2 43 :3 10 1a 10 d 4a
13 1c 24 :2 13 27 29 :2 27 10
23 2c 34 :2 23 10 2d 4a :3 d
1b 2c 38 45 4e 57 :2 45 5b
64 6c :2 5b 22 2b 37 :2 22 3b
44 4f :2 3b 53 20 2b :2 53 2f
38 46 :2 2f 4a 53 5e :2 4a 22
2b 37 :2 22 3b 43 4d :2 1b d
10 19 25 :2 10 2a 28 :2 33 :2 28
13 :2 1d 2f :2 39 45 48 5a 5e
5f :2 5a :2 2f :3 13 :2 19 1e 2a 6d
70 :2 2a 7d 80 :2 2a 84 87 :2 2a
91 94 9d a5 :2 ae :2 9d bf :2 94
:2 2a :2 13 62 :2 10 13 :2 1d 2f :2 39
45 48 5a 5e 5f :2 5a :2 2f :3 13
:2 19 1e 2a 6d 70 :2 2a :2 13 62
:3 10 :2 1b 31 :2 3a 4a :2 10 d 42
13 1c 28 :2 13 2b 2e :2 2b 13
:2 1d 2f :2 39 45 49 5b 5f 60
:2 5b :2 2f :3 13 :2 19 1e 2a 6d 70
:2 2a 7d 80 :2 2a 84 87 :2 2a 91
94 9d a5 :2 9d b2 :2 94 :2 2a ba
bd :2 2a c5 c8 :2 2a cd d0 :2 2a
dd e0 :2 2a :2 13 63 :2 10 13 :2 1d
2f :2 39 45 48 5a 5e 5f :2 5a
:2 2f :3 13 :2 19 1e 2a 6d 70 :2 2a
:2 13 62 :3 10 :2 1b 2f 38 44 :2 2f
48 56 :2 10 30 42 :3 d 15 1f
:3 d :2 16 22 d 1c 32 3c 40
15 16 23 34 40 19 10 17
13 1f :3 1d 13 :2 1c 28 13 24
13 :2 1c 28 13 :4 10 d :2 15 13
:2 1c 28 13 16 :2 20 32 :2 3c 48
4c 5e 62 63 :2 5e :2 32 :3 16 :2 1c
21 2d 70 73 :2 2d 80 83 :2 2d
87 8a :2 2d 96 99 :2 2d a1 a4
:2 2d b0 b3 ba c3 c6 :2 b3 :2 2d
:2 16 66 :2 13 :2 10 :4 1c :2 10 d :3 38
d 1e :2 d 1c :2 d 19 :2 d 16
:2 d 17 d 10 19 21 :2 10 24
26 :2 24 2c 35 46 :2 2c 49 4c
:2 49 54 13 24 :2 54 27 2a :2 27
:2 2c 2b :2 10 13 1c 24 :2 13 27
29 :2 27 2f 38 49 :2 2f 4c 4f
:2 4c :2 13 57 16 27 :2 57 2a 2d
:2 2a :3 13 1d :2 13 1d 26 37 :2 1d
13 2f :3 10 1a :2 23 2a 33 3b
:2 2a 3f :2 48 :2 1a :2 10 1d 10 2d
10 1d 10 :5 d 20 :2 d 19 25
36 44 52 5c 1b 23 2f 3b
47 53 1b 2a 36 40 48 51
59 1b 27 33 40 4b 56 1b
25 30 3c 48 4b 4e 54 :2 19
d 10 19 23 :2 10 26 28 :2 26
13 :2 1d 2f :2 39 45 49 5b 5f
60 :2 5b :2 2f :3 13 :2 19 1e 2a 6d
70 :2 2a 7d 80 :2 2a 84 87 :2 2a
91 94 9d a5 :2 ae :2 9d c5 :2 94
:2 2a cd d0 :2 2a d8 db :2 2a e0
e3 :2 2a ec ef :2 2a :2 13 63 :2 10
13 :2 1d 2f :2 39 45 48 5a 5e
5f :2 5a :2 2f :3 13 :2 19 1e 2a 6d
70 :2 2a :2 13 62 :3 10 :2 1b 2f :2 38
4e 58 :2 10 d 2c 13 1c 26
:2 13 29 2c :2 29 13 :2 1d 2f :2 39
45 49 5b 5f 60 :2 5b :2 2f :3 13
:2 19 1e 2a 6d 70 :2 2a 7d 80
:2 2a 84 87 :2 2a 91 94 9d a5
:2 ae :2 9d c6 :2 94 :2 2a ce d1 :2 2a
d9 dc :2 2a e1 e4 :2 2a f4 f7
:2 2a :2 13 63 :2 10 13 :2 1d 2f :2 39
45 48 5a 5e 5f :2 5a :2 2f :3 13
:2 19 1e 2a 6d 70 :2 2a :2 13 62
:3 10 :2 1b 2f :2 38 4f 18 :2 10 2e
2c 1a 2f 43 13 22 2c 13
2c 4a 58 6c 13 2c 4a 58
6c 13 2c 4a 58 6c 13 2c
4a 58 6c 19 2d 13 1a 16
22 :3 20 16 :2 1f 2b 16 27 16
:2 1f 2b 16 :4 13 10 :2 18 16 :2 1f
2b 16 19 :2 23 35 :2 3f 4b 4f
61 65 66 :2 61 :2 35 :3 19 :2 1f 24
30 73 76 :2 30 83 86 :2 30 8a
8d :2 30 99 9c :2 30 a4 a7 :2 30
b3 b6 bd c6 c9 :2 b6 :2 30 :2 19
69 :2 16 :2 13 :4 1f :2 13 10 :7 d 38
:2 a 38 :2 7 11 1f 2c 10 1d
2e 3c 4d :2 a :2 13 1f a 7
:2 f d :2 16 22 d 10 :2 1a 2c
:2 36 42 46 58 5c 5d :2 58 :2 2c
:3 10 :2 16 1b 27 6a 6d :2 27 7a
7d :2 27 81 84 :2 27 90 93 :2 27
9b 9e :2 27 aa ad b4 bd c0
:2 ad :2 27 :2 10 60 :2 d :2 a :4 16 :2 a
7 :3 21 a 13 1c :2 a 1f 21
:2 1f 14 20 2f 37 44 13 20
31 3e d 14 10 1c :3 1a 10
:2 19 25 10 21 10 :2 19 25 10
:4 d a :2 12 10 :2 19 25 10 13
:2 1d 2f :2 39 45 49 5b 5f 60
:2 5b :2 2f :3 13 :2 19 1e 2a 6d 70
:2 2a 7d 80 :2 2a 84 87 :2 2a 93
96 :2 2a 9e a1 :2 2a ad b0 b7
c0 c3 :2 b0 :2 2a :2 13 63 :2 10 :2 d
:4 19 :2 d a :4 23 :2 7 21 :3 4 12
4 :4 8 7 11 1d 2b 34 3b
48 51 6a 77 a 11 d 19
:3 17 d :2 16 22 d 1e d :2 16
22 d :4 a 7 :2 f d :2 16 22
d 10 :2 1a 2c :2 36 42 46 58
5c 5d :2 58 :2 2c :3 10 :2 16 1b 27
6a 6d :2 27 7a 7d :2 27 81 84
:2 27 90 93 :2 27 9b 9e :2 27 aa
ad b4 bd c0 :2 ad :2 27 :2 10 60
:2 d :2 a :4 16 :2 a 7 :3 29 a 13
1f :2 a 22 24 :2 22 14 22 2f
13 20 31 49 :2 d :2 16 22 d
a :2 12 10 :2 19 25 10 13 :2 1d
2f :2 39 45 49 5b 5f 60 :2 5b
:2 2f :3 13 :2 19 1e 2a 6d 70 :2 2a
7d 80 :2 2a 84 87 :2 2a 93 96
:2 2a 9e a1 :2 2a ad b0 b7 c0
c3 :2 b0 :2 2a :2 13 63 :2 10 :2 d :4 19
:2 d a :3 26 d 16 1f :2 d 22
24 :2 22 1c 37 44 10 1d 2e
3c 4d 10 17 13 1f :3 1d 13
:2 1c 28 13 24 13 :2 1c 28 13
:4 10 d :2 15 13 :2 1c 28 13 16
:2 20 32 :2 3c 48 4c 5e 62 63
:2 5e :2 32 :3 16 :2 1c 21 2d 70 73
:2 2d 80 83 :2 2d 87 8a :2 2d 96
99 :2 2d a1 a4 :2 2d b0 b3 ba
c3 c6 :2 b3 :2 2d :2 16 66 :2 13 :2 10
:4 1c :2 10 d :3 26 1c 36 43 54
62 10 17 13 1f :3 1d 13 :2 1c
28 13 24 13 :2 1c 28 13 :4 10
d :2 15 13 :2 1c 28 13 16 :2 20
32 :2 3c 48 4c 5e 62 63 :2 5e
:2 32 :3 16 :2 1c 21 2d 70 73 :2 2d
80 83 :2 2d 87 8a :2 2d 96 99
:2 2d a1 a4 :2 2d b0 b3 ba c3
c6 :2 b3 :2 2d :2 16 66 :2 13 :2 10 :4 1c
:2 10 d :4 26 :2 a 26 :2 7 a 13
1c :2 a 1f 21 :2 1f a 18 :2 a
1d 2d 3b 50 5c 5f :2 1d a
14 23 33 39 41 48 5f 67
6e 86 90 a1 af 12 1e 2b
35 40 4c 58 6b 77 12 29
3d :2 d :2 16 22 d a :2 12 10
:2 19 25 10 13 :2 1d 2f :2 39 45
49 5b 5f 60 :2 5b :2 2f :3 13 :2 19
1e 2a 6d 70 :2 2a 7d 80 :2 2a
84 87 :2 2a 93 96 :2 2a 9e a1
:2 2a ad b0 b7 c0 c3 :2 b0 :2 2a
:2 13 63 :2 10 :2 d :4 19 :2 d a :3 23
e :2 17 22 20 :2 2b :2 20 d 10
19 25 :2 10 28 2a :2 28 1a 13
2d 13 2e 13 2e 13 2d 3f
13 19 26 37 45 13 1a 16
22 :3 20 16 :2 1f 2b 16 27 16
:2 1f 2b 16 :4 13 10 :2 18 16 :2 1f
2b 16 19 :2 23 35 :2 3f 4b 4f
61 65 66 :2 61 :2 35 :3 19 :2 1f 24
30 73 76 :2 30 83 86 :2 30 8a
8d :2 30 99 9c :2 30 a4 a7 :2 30
b3 b6 bd c6 c9 :2 b6 :2 30 :2 19
69 :2 16 :2 13 :4 1f :2 13 10 :4 2c 1a
13 2d 13 2e 13 2e 13 2d
3f 13 30 42 19 26 37 45
13 1a 16 22 :3 20 16 :2 1f 2b
16 27 16 :2 1f 2b 16 :4 13 10
:2 18 16 :2 1f 2b 16 19 :2 23 35
:2 3f 4b 4f 61 65 66 :2 61 :2 35
:3 19 :2 1f 24 30 73 76 :2 30 83
86 :2 30 8a 8d :2 30 99 9c :2 30
a4 a7 :2 30 b3 b6 bd c6 c9
:2 b6 :2 30 :2 19 69 :2 16 :2 13 :4 1f :2 13
10 :7 d 11 18 28 2b :2 11 2e
30 :2 2e :2 10 20 :2 10 :2 19 25 3c
4a 58 2f 3a 46 52 2f 3d
50 :2 25 10 35 :2 d 3b :2 a :4 f
e d 36 :2 41 48 12 :2 36 27
29 :2 27 35 :3 d 1b d 2c :2 a
23 :2 7 29 :2 4 8 11 1d :2 8
20 22 :2 20 7 :4 2b 2a 29 :2 7
a 13 29 :2 a 2c 2e :2 2c 14
22 2f 13 20 31 49 11 1f
30 :2 d :2 16 22 d a :2 12 10
:2 19 25 10 13 :2 1d 2f :2 39 45
49 5b 5f 60 :2 5b :2 2f :3 13 :2 19
1e 2a 6d 70 :2 2a 7d 80 :2 2a
84 87 :2 2a 93 96 :2 2a 9e a1
:2 2a ad b0 b7 c0 c3 :2 b0 :2 2a
:2 13 63 :2 10 :2 d :4 19 :2 d a :3 30
d 16 1f :2 d 22 24 :2 22 17
14 16 23 34 4c 14 22 33
10 17 13 1f :3 1d 13 :2 1c 28
13 24 13 :2 1c 28 13 :4 10 d
:2 15 13 :2 1c 28 13 16 :2 20 32
:2 3c 48 4c 5e 62 63 :2 5e :2 32
:3 16 :2 1c 21 2d 70 73 :2 2d 80
83 :2 2d 87 8a :2 2d 96 99 :2 2d
a1 a4 :2 2d b0 b3 ba c3 c6
:2 b3 :2 2d :2 16 66 :2 13 :2 10 :4 1c :2 10
d :3 26 17 14 20 16 23 34
40 14 22 10 17 13 1f :3 1d
13 :2 1c 28 13 24 13 :2 1c 28
13 :4 10 d :2 15 13 :2 1c 28 13
16 :2 20 32 :2 3c 48 4c 5e 62
63 :2 5e :2 32 :3 16 :2 1c 21 2d 70
73 :2 2d 80 83 :2 2d 87 8a :2 2d
96 99 :2 2d a1 a4 :2 2d b0 b3
ba c3 c6 :2 b3 :2 2d :2 16 66 :2 13
:2 10 :4 1c :2 10 d :4 26 :2 a 30 :3 7
15 :2 7 1a 2a 38 4d 59 5c
:2 1a 7 11 20 30 36 3e 45
5c 64 6b 83 8d 9e ac f
1b 28 32 3d 49 55 68 74
f 26 3a :2 a :2 13 1f a 7
:2 f d :2 16 22 d 10 :2 1a 2c
:2 36 42 46 58 5c 5d :2 58 :2 2c
:3 10 :2 16 1b 27 6a 6d :2 27 7a
7d :2 27 81 84 :2 27 90 93 :2 27
9b 9e :2 27 aa ad b4 bd c0
:2 ad :2 27 :2 10 60 :2 d :2 a :4 16 :2 a
7 :3 4d b :2 14 1f 1d :2 28 :2 1d
a d 16 22 :2 d 25 27 :2 25
17 10 2b 10 2b 10 2b 10
2c 3e 10 16 23 34 42 10
17 13 1f :3 1d 13 :2 1c 28 13
24 13 :2 1c 28 13 :4 10 d :2 15
13 :2 1c 28 13 16 :2 20 32 :2 3c
48 4c 5e 62 63 :2 5e :2 32 :3 16
:2 1c 21 2d 70 73 :2 2d 80 83
:2 2d 87 8a :2 2d 96 99 :2 2d a1
a4 :2 2d b0 b3 ba c3 c6 :2 b3
:2 2d :2 16 66 :2 13 :2 10 :4 1c :2 10 d
:4 29 17 10 2b 10 2b 10 2b
10 2c 3e 10 2d 3f 16 23
34 42 10 17 13 1f :3 1d 13
:2 1c 28 13 24 13 :2 1c 28 13
:4 10 d :2 15 13 :2 1c 28 13 16
:2 20 32 :2 3c 48 4c 5e 62 63
:2 5e :2 32 :3 16 :2 1c 21 2d 70 73
:2 2d 80 83 :2 2d 87 8a :2 2d 96
99 :2 2d a1 a4 :2 2d b0 b3 ba
c3 c6 :2 b3 :2 2d :2 16 66 :2 13 :2 10
:4 1c :2 10 d :7 a e 15 25 28
:2 e 2b 2d :2 2b d 37 40 4c
:2 37 4f 51 :2 4f 36 :3 d 1d :2 d
:2 16 22 39 47 55 2f 3a 46
52 2f 3d 50 :2 22 d 54 :2 a
38 :2 7 4d :3 4 17 21 :2 17 4
7 :2 10 19 1b :2 19 7 :2 10 1c
7 1f :2 4 7 :2 11 23 :2 2d 39
3c 4e 52 53 :2 4e :2 23 :3 7 :2 d
12 1e 61 64 :2 1e 71 74 :2 1e
78 7b :2 1e 85 88 91 99 :2 a2
:2 91 ad :2 88 :2 1e b5 b8 :2 1e c0
c3 :2 1e c8 cb :2 1e df e2 :2 1e
:2 7 56 :3 4 :2 f 21 :2 2a 34 49
:2 4 1 9 12 9 a :2 14 26
:2 30 3c 40 52 56 57 :2 52 :2 26
:3 a :2 10 15 21 64 67 :2 21 :3 a
:2 10 15 39 5c 5f :2 68 :2 39 76
79 :2 39 81 84 :2 8d :2 39 :2 a 5a
:3 7 c 15 1e 2c a 13 1e
f e 7 e 7 e 7 29
:2 4 :2 9 7 :2 10 1c :2 7 :2 11 23
:2 2d 39 3d 4f 53 54 :2 4f :2 23
:3 7 :2 d 12 1e 61 64 :2 1e :3 7
:2 d 12 36 42 45 :2 36 4d 50
:2 36 5c 5f 66 6f 72 :2 5f :2 36
:2 7 57 :2 4 7 c 1b a 13
1e f e 7 e 7 e 7
:2 4 :4 10 :2 4 :8 1 
4bc9
4
0 :2 1 :4 3 :4 4
:4 5 :4 6 :4 7 :4 8
:4 9 :4 a :4 b :4 c
:4 d :4 e :4 f :4 10
:4 11 2 :4 12 :2 1
:7 14 :7 15 :7 16 :7 17
:7 18 :7 19 :7 1a :7 1b
:7 1c :7 1d :7 1e :7 1f
:5 20 :5 21 :5 22 :5 23
:7 24 :5 25 :5 26 :7 27
:7 28 :5 29 :5 2a :5 2b
:5 2c :7 2d :7 2e :7 2f
:7 30 :7 31 :6 32 :6 33
:6 34 :6 35 :6 36 :6 37
:6 38 :6 39 :6 3a :6 3b
:6 3c :6 3d :6 3e :6 3f
:6 40 :6 41 :6 42 :6 43
:6 44 :6 45 :6 46 :6 47
:6 48 :6 49 :6 4a :6 4b
:6 4c :6 4d :6 4e :6 4f
:6 50 :6 51 :6 52 :6 53
:6 54 :6 55 :6 56 :6 57
:6 58 :6 59 :7 5a :7 5b
:6 5c :6 5d :7 5e :6 5f
:7 60 :7 61 :6 62 :6 63
:5 64 :5 65 :6 66 :6 67
:6 68 :6 69 :6 6a :6 6b
:6 6c :6 6d :6 6e :6 6f
:6 70 :7 71 :7 72 :7 73
:e 74 :6 75 :6 76 :2 78
0 :2 78 :2 79 :3 7a
79 :5 78 :2 7c 0
:2 7c :2 7d :5 7e :2 7f
7d :5 7c :2 81 0
:2 81 :c 82 :12 83 :a 84
:a 85 :6 86 :8 87 :8 88
:23 89 :2 8a 82 :5 81
:7 8c :b 8e :11 8f 90
:2 8f :2 90 :2 8f :2 90
:2 8f :2 91 :2 8f :2 91
:2 8f :2 91 :2 8f :2 91
:2 8f :2 92 :2 8f :2 92
:2 8f :2 92 :2 8f :2 92
:2 8f :2 93 :2 8f :2 93
:2 8f :2 93 :2 8f :2 93
:2 8f :2 94 :2 8f :2 94
:2 8f :2 94 :2 8f :2 94
:2 8f :2 95 :2 8f :9 95
:2 8f :2 96 :2 8f :9 96
:2 8f :2 97 :2 8f :9 97
:2 8f :2 98 :2 8f :9 98
:2 8f :2 99 :2 8f :9 99
:2 8f :2 9a :2 8f :9 9a
:2 8f :2 9b :2 8f :9 9b
:2 8f :2 9c :2 8f :9 9c
:2 8f :2 9d :2 8f :9 9d
:2 8f :2 9e :2 8f :2 9e
:2 8f :2 9e :2 8f :2 9e
:2 8f :2 9e :4 8f :3 8e
:11 a1 :b a2 :3 a1 :3 a9
:3 aa :3 ab :3 ac :3 ad
:3 ae :d af :d b0 :2 b1
:2 b0 :6 b1 :3 b0 :3 b2
b1 :2 b0 :3 b5 :3 b6
:3 b8 :3 b9 :3 bb :3 bd
:3 be :5 c0 :4 c2 :3 c3
:5 c4 c3 :5 c6 c5
:3 c3 :5 c9 :4 cc :5 cd
cb :2 cf :5 d1 :11 d2
:24 d3 :3 d2 :2 d0 :6 cf
ce :3 8d :9 d8 :11 d9
:30 da :3 d9 :11 dc :b dd
:3 dc :a df :3 d8 :7 e3
:7 e4 :3 e5 e3 :5 e6
e2 :2 e8 :5 ea :11 eb
:24 ec :3 eb :2 e9 :6 e8
e7 :3 8d :a f2 :11 f3
:30 f4 :3 f3 :11 f6 :b f7
:3 f6 :a f9 :3 f2 :3 fc
:2 fe ff :2 100 fe
:5 101 fd :2 103 :5 105
:11 106 :24 107 :3 106 :2 104
:6 103 102 :3 8d :9 10c
:11 10d :30 10e :3 10d :11 110
:b 111 :3 110 :a 113 :3 10c
:12 117 :7 118 :c 119 117
:5 11a 116 :2 11c :5 11e
:11 11f :24 120 :3 11f :2 11d
:6 11c 11b :3 8d :a 125
:11 126 :30 127 :3 126 :11 129
:b 12a :3 129 :a 12c :3 125
:8 130 :5 131 12f :2 133
:5 135 :11 136 :24 137 :3 136
:2 134 :6 133 132 :3 8d
:a 13c :11 13d :30 13e :3 13d
:11 140 :b 141 :3 140 :a 143
:3 13c :6 147 :5 148 146
:2 14a :5 14c :11 14d :24 14e
:3 14d :2 14b :6 14a 149
:3 8d :b 153 :3 154 :3 153
:a 157 :11 158 :30 159 :3 158
:11 15b :b 15c :3 15b :a 15e
:3 157 :3 161 :b 163 :b 164
:b 165 :5 16e :9 16f :4 171
:4 172 :3 173 171 :5 174
170 :2 176 :5 178 :11 179
:24 17a :3 179 :2 177 :6 176
175 :3 16f 17e 16f
:9 17e :4 180 :4 181 :3 182
180 :5 183 17f :2 185
:5 187 :11 188 :24 189 :3 188
:2 186 :6 185 184 :4 17e
:3 16f :9 18f :11 190 :30 191
:3 190 :11 193 :b 194 :3 193
:7 196 197 :2 196 :3 18f
16e :4 19b :7 19c 19b
:5 19d 19a :2 19f :5 1a1
:11 1a2 :24 1a3 :3 1a2 :2 1a0
:6 19f 19e :3 199 :4 1a9
:7 1aa 1a9 :5 1ab 1a8
:2 1ad :5 1af :11 1b0 :24 1b1
:3 1b0 :2 1ae :6 1ad 1ac
:3 199 :18 1b6 :2 1b7 :2 1b6
:4 1b7 :6 1b6 :4 1b9 :5 1ba
1bb 1b9 :5 1bc 1b8
:2 1be :5 1c0 :11 1c1 :24 1c2
:3 1c1 :2 1bf :6 1be 1bd
:3 1b7 :9 1c7 :11 1c8 :30 1c9
:3 1c8 :11 1cb :b 1cc :3 1cb
:7 1ce 1cf :2 1ce :3 1c7
1b7 :2 1b6 199 :3 16e
:3 1e1 :3 1e2 :3 1e3 :3 1e4
:3 1e5 :5 1ee :4 1f0 :3 1f1
:5 1f2 1f1 :5 1f4 1f3
:3 1f1 :a 1f7 :3 1f8 1f7
:3 1fa 1f9 :3 1f7 :4 1fe
:5 1ff 1fd :2 201 :5 203
:11 204 :24 205 :3 204 :2 202
:6 201 200 :3 8d :9 20b
:6 20d :5 20e 20d :5 20f
20c :2 211 :5 213 :11 214
:24 215 :3 214 :2 212 :6 211
210 :3 20b :9 21a :3 21b
:4 21d :4 21e :5 21f 21d
:5 220 21c :2 222 :5 224
:11 225 :24 226 :3 225 :2 223
:6 222 221 :3 21a :a 22c
:11 22d :30 22e :3 22d :11 230
:b 231 :3 230 :7 233 234
:2 233 235 22c :e 235
:11 236 :2 237 :2 236 :4 237
:3 236 :11 238 :30 239 :3 238
:11 23b :b 23c :3 23b :7 23e
23f :2 23e 237 :2 236
235 :3 22c :3 21a :9 245
:3 246 :3 247 245 :4 24b
24c :2 24d :2 24e :2 24f
24b :5 250 24a :2 252
:5 254 :11 255 :24 256 :3 255
:2 253 :6 252 251 :3 249
:a 25c :3 25d :5 25e :b 260
261 :3 260 :5 262 :3 263
:3 264 :6 266 :3 267 :3 266
:a 269 :5 26b :6 26c :2 26d
:4 26e :7 26f :2 270 26b
:6 271 :5 272 271 :5 274
273 :3 271 26a :2 277
:5 279 :11 27a :24 27b :3 27a
:2 278 :6 277 276 :3 25c
:6 282 :5 283 281 :2 285
:5 287 :11 288 :24 289 :3 288
:2 286 :6 285 284 :3 25c
:b 28e :3 28f 28e :4 292
:8 293 292 :5 294 291
:2 296 :5 298 :11 299 :24 29a
:3 299 :2 297 :6 296 295
:4 290 :3 28e :9 2a1 :6 2a4
:4 2a5 2a4 :6 2a6 :5 2a7
2a6 :5 2a9 2a8 :3 2a6
2a3 :2 2ac :5 2ae :11 2af
:24 2b0 :3 2af :2 2ad :6 2ac
2ab :3 2a1 :2 2b7 :4 2b9
:5 2bc :2 2bd :4 2c0 2b7
:6 2c1 :5 2c2 2c1 :5 2c4
2c3 :3 2c1 2b6 :2 2c7
:5 2c9 :11 2ca :24 2cb :3 2ca
:2 2c8 :6 2c7 2c6 :4 2a1
:2 2d2 :4 2d4 :5 2d7 :2 2d8
:4 2db 2d2 :6 2dc :5 2dd
2dc :5 2df 2de :3 2dc
2d1 :2 2e2 :5 2e4 :11 2e5
:24 2e6 :3 2e5 :2 2e3 :6 2e2
2e1 :4 2cf :3 2a1 2eb
25c :a 2eb :3 2ed :3 2ee
2ed :5 2ef 2ec :2 2f1
:5 2f3 :11 2f4 :24 2f5 :3 2f4
:2 2f2 :6 2f1 2f0 :3 2eb
:b 2fb :b 2fc 2fd :3 2fc
:3 2ff :5 300 :2 301 2ff
:6 302 :5 303 302 :5 305
304 :3 302 2fe :2 308
:5 30a :11 30b :24 30c :3 30b
:2 309 :6 308 307 :3 2fb
:6 311 312 2fb :12 312
:3 314 :6 315 :2 316 314
:6 317 :5 318 317 :5 31a
319 :3 317 313 :2 31d
:5 31f :11 320 :24 321 :3 320
:2 31e :6 31d 31c :3 312
:6 326 312 2fb :3 329
:6 32a :2 32b 329 :6 32c
:5 32d 32c :5 32f 32e
:3 32c 328 :2 332 :5 334
:11 335 :24 336 :3 335 :2 333
:6 332 331 :3 327 :6 33b
327 :3 2fb 2eb :3 25c
249 :3 245 20b :3 341
340 :3 20b :3 347 :3 348
:3 349 :5 34b :16 34d :7 34e
:5 34f :3 34e :3 34d :3 353
:5 354 355 :b 356 :2 357
353 :5 358 352 :2 35a
:5 35c :11 35d :24 35e :3 35d
:2 35b :6 35a 359 :3 8d
:a 363 :3 364 :3 363 :3 369
:3 36a :3 36b :4 36f :3 370
36f :5 371 36e :2 373
:5 375 :11 376 :24 377 :3 376
:2 374 :6 373 372 :3 8d
:b 37d :4 37f :6 380 37f
:5 381 37e :2 383 :5 385
:11 386 :24 387 :3 386 :2 384
:6 383 382 :3 37d :9 38d
:3 38f 38d :3 391 390
:3 38d :3 37d :9 395 :b 396
:b 398 :8 399 :7 39a :8 39b
39c :5 39d 398 :5 39e
397 :2 3a0 :5 3a2 :11 3a3
:24 3a4 :3 3a3 :2 3a1 :6 3a0
39f :3 396 :3 3aa :3 3ad
:9 3ae :15 3af :2 3b0 :7 3af
:c 3b1 :2 3b2 :2 3b1 :3 3b2
:3 3b1 :4 3b2 :3 3b1 :11 3b3
:30 3b4 :3 3b3 :11 3b6 :b 3b7
:3 3b6 :a 3b9 3b2 :3 3bb
:9 3bd :3 3be :3 3bd 3ba
:3 3b1 3b0 :2 3af :3 3c3
:3 3c4 :3 3c5 :3 3c6 :3 3c8
:3 3ca :3 3cb :3 3cc :3 3cd
:3 3ae :12 3d1 :a 3d2 :6 3d3
:7 3d4 :4 3d5 :3 3d6 :3 3d4
:3 3d2 :9 3d9 :4 3db :6 3dc
:5 3dd 3dc :5 3df 3de
:3 3dc 3da :2 3e2 :5 3e4
:11 3e5 :24 3e6 :3 3e5 :2 3e3
:6 3e2 3e1 :3 3d9 :6 3ed
:6 3ee :5 3ef 3ee :5 3f1
3f0 :3 3ee 3ec :2 3f4
:5 3f6 :11 3f7 :24 3f8 :3 3f7
:2 3f5 :6 3f4 3f3 :3 3d9
:3 3fe :4 400 :4 401 400
:5 402 3ff :2 404 :5 406
:11 407 :24 408 :3 407 :2 405
:6 404 403 :3 3d9 :c 40d
:8 40f 410 411 40f
:5 412 40e :2 414 :5 416
:11 417 :24 418 :3 417 :2 415
:6 414 413 :6 40d 3d9
:16 41e :f 41f :f 420 :f 421
:f 422 :9 424 :3 426 :3 427
:2 428 :2 429 :2 42a :2 42b
:4 42c :4 42d :6 42e :2 42f
426 :6 430 :5 431 430
:5 433 432 :3 430 425
:2 436 :5 438 :11 439 :24 43a
:3 439 :2 437 :6 436 435
:4 424 :3 440 :3 441 :2 442
:2 443 :2 444 :2 445 :4 446
:4 447 :4 448 :6 449 :2 44a
440 :6 44b :5 44c 44b
:5 44e 44d :3 44b 43f
:2 451 :5 453 :11 454 :24 455
:3 454 :2 452 :6 451 450
:4 43e :3 424 45a 41e
:9 45a :f 45b :f 45c :3 45f
:3 460 :2 461 :2 462 :4 463
:4 464 :6 465 :2 466 45f
:6 467 :5 468 467 :5 46a
469 :3 467 45e :2 46d
:5 46f :11 470 :24 471 :3 470
:2 46e :6 46d 46c :3 45a
475 45a 41e :9 475
:f 476 :f 477 :9 479 :3 47b
:3 47c :2 47d :2 47e :4 47f
:6 480 :2 481 47b :6 482
:5 483 482 :5 485 484
:3 482 47a :2 488 :5 48a
:11 48b :24 48c :3 48b :2 489
:6 488 487 :4 479 :3 492
:3 493 :2 494 :2 495 :4 496
:4 497 :6 498 :2 499 492
:6 49a :5 49b 49a :5 49d
49c :3 49a 491 :2 4a0
:5 4a2 :11 4a3 :24 4a4 :3 4a3
:2 4a1 :6 4a0 49f :4 490
:3 479 475 41e :3 4ab
:4 4ac :3 4ad :2 4ae 4ab
:6 4af :5 4b0 4af :5 4b2
4b1 :3 4af 4aa :2 4b5
:5 4b7 :11 4b8 :24 4b9 :3 4b8
:2 4b6 :6 4b5 4b4 :4 4a9
:3 41e :6 4c0 :6 4c1 :5 4c2
4c1 :5 4c4 4c3 :3 4c1
4bf :2 4c7 :5 4c9 :11 4ca
:24 4cb :3 4ca :2 4c8 :6 4c7
4c6 :3 41d 4d1 :7 4d2
:3 4d3 4d1 :6 4d4 :5 4d5
4d4 :5 4d7 4d6 :3 4d4
4d0 :2 4da :5 4dc :11 4dd
:24 4de :3 4dd :2 4db :6 4da
4d9 :4 41d :3 3d9 :3 4e5
:4 4e9 :6 4ea :5 4eb 4ea
:5 4ed 4ec :3 4ea 4e8
:2 4f0 :5 4f2 :11 4f3 :24 4f4
:3 4f3 :2 4f1 :6 4f0 4ef
:3 3d1 :6 4fb :6 4fc :5 4fd
4fc :5 4ff 4fe :3 4fc
4fa :2 502 :5 504 :11 505
:24 506 :3 505 :2 503 :6 502
501 :3 3d1 :16 50b :3 50c
:3 50d :b 50e :3 50f 50e
:3 511 510 :3 50e :9 514
:3 515 :3 514 :e 518 :b 519
:2 51a :2 519 :a 51a :8 51b
:3 518 :b 51d :11 51e :20 51f
:3 51e :11 521 :b 522 :3 521
:9 524 525 51d :9 525
:11 526 :2e 527 :3 526 :11 529
:b 52a :3 529 :c 52c 525
:3 51d :9 531 :5 532 531
:f 534 533 :3 531 :3 53b
:7 53c :6 53d :7 53e :6 53f
:8 540 :3 53c :9 544 :11 545
:30 546 :3 545 :11 548 :b 549
:3 548 :a 54b 54c 544
:9 54c :11 54d :30 54e :3 54d
:11 550 :b 551 :3 550 :7 553
554 :2 553 54c 544
:3 556 :a 557 :5 558 :3 557
555 :3 544 :3 50b :3 3d1
55c 396 :a 55c :b 55f
:7 560 561 :4 562 :3 563
55f :5 564 55e :2 566
:5 568 :11 569 :24 56a :3 569
:2 567 :6 566 565 :3 55c
:12 570 :6 571 :7 572 :4 573
:3 574 :3 572 :3 570 55c
396 :4 579 57a :4 57b
:3 57c 579 :5 57d 578
:2 57f :5 581 :11 582 :24 583
:3 582 :2 580 :6 57f 57e
:4 576 :3 396 589 395
:a 589 :b 58c :7 58d 58e
:4 58f :3 590 58c :5 591
58b :2 593 :5 595 :11 596
:24 597 :3 596 :2 594 :6 593
592 :3 589 :12 59d :6 59e
:7 59f :4 5a0 :3 5a1 :3 59f
:3 59d 589 395 :4 5a6
5a7 :4 5a8 :3 5a9 5a6
:5 5aa 5a5 :2 5ac :5 5ae
:11 5af :24 5b0 :3 5af :2 5ad
:6 5ac 5ab :4 5a3 :3 395
:13 5bb :2 5bc :2 5bb :4 5bc
:3 5bb :3 5bd :5 5be :9 5c2
:7 5c3 :3 5c2 :16 5c6 :16 5c7
:f 5c8 :f 5c9 :f 5ca :f 5cb
:9 5ce :8 5cf :9 5d0 :a 5d1
:7 5d2 :9 5d3 5ce :6 5d4
:5 5d5 5d4 :5 5d7 5d6
:3 5d4 5cd :2 5da :5 5dc
:11 5dd :24 5de :3 5dd :2 5db
:6 5da 5d9 :3 5c7 5e2
5c7 :9 5e2 :f 5e3 :f 5e4
:9 5e7 :8 5e8 :9 5e9 :a 5ea
:7 5eb :9 5ec 5e7 :6 5ed
:5 5ee 5ed :5 5f0 5ef
:3 5ed 5e6 :2 5f3 :5 5f5
:11 5f6 :24 5f7 :3 5f6 :2 5f4
:6 5f3 5f2 :4 5e2 5c7
:f 5fc :f 5fd :9 600 :8 601
:9 602 :a 603 :7 604 :9 605
600 :6 606 :5 607 606
:5 609 608 :3 606 5ff
:2 60c :5 60e :11 60f :24 610
:3 60f :2 60d :6 60c 60b
:4 5fb :3 5c7 5c6 :9 617
:8 618 :9 619 :a 61a :7 61b
:9 61c 617 :6 61d :5 61e
61d :5 620 61f :3 61d
616 :2 623 :5 625 :11 626
:24 627 :3 626 :2 624 :6 623
622 :4 615 :3 5c6 :3 62f
5bc :2 5bb :c 631 :3 632
:3 633 :6 63a :5 63b 639
:2 63d :5 63f :11 640 :24 641
:3 640 :2 63e :6 63d 63c
:3 8d :3 646 :3 647 :3 648
:12 64b :4 64d :4 64e :6 64f
:27 650 64d :5 651 64c
:2 653 :5 655 :11 656 :24 657
:3 656 :2 654 :6 653 652
:6 64b :3 662 :5 666 668
:7 669 :5 66a :5 66b :5 66c
:3 669 :3 66d :5 66e 66d
:5 670 66f :3 66d :a 673
:2 674 :3 673 :9 67a :7 67b
:4 67e :6 67f :5 680 67f
:5 682 681 :3 67f 67d
:2 685 :5 687 :11 688 :24 689
:3 688 :2 686 :6 685 684
:3 67a :4 68f :6 690 :5 691
690 :5 693 692 :3 690
68e :2 696 :5 698 :11 699
:24 69a :3 699 :2 697 :6 696
695 :3 67a :4 6a0 :6 6a1
:5 6a2 6a1 :5 6a4 6a3
:3 6a1 69f :2 6a7 :5 6a9
:11 6aa :24 6ab :3 6aa :2 6a8
:6 6a7 6a6 :3 67a :6 6b1
:6 6b2 :5 6b3 6b2 :5 6b5
6b4 :3 6b2 6b0 :2 6b8
:5 6ba :11 6bb :24 6bc :3 6bb
:2 6b9 :6 6b8 6b7 :3 67a
:4 6c2 :6 6c3 :5 6c4 6c3
:5 6c6 6c5 :3 6c3 6c1
:2 6c9 :5 6cb :11 6cc :24 6cd
:3 6cc :2 6ca :6 6c9 6c8
:3 67a :4 6d3 :6 6d4 :5 6d5
6d4 :5 6d7 6d6 :3 6d4
6d2 :2 6da :5 6dc :11 6dd
:24 6de :3 6dd :2 6db :6 6da
6d9 :4 67a :3 6e4 :2 6e5
:2 6e6 :2 6e7 6e4 :6 6e8
:5 6e9 6e8 :5 6eb 6ea
:3 6e8 6e3 :2 6ee :5 6f0
:11 6f1 :24 6f2 :3 6f1 :2 6ef
:6 6ee 6ed :3 6e2 :3 6f8
:6 6f9 6fa 6f8 :5 6fb
6f7 :2 6fd :5 6ff :11 700
:24 701 :3 700 :2 6fe :6 6fd
6fc :3 6e2 :a 708 :9 709
:3 70a :3 709 :6 70f 710
:5 711 70f :5 712 70e
:2 714 :5 716 :11 717 :24 718
:3 717 :2 715 :6 714 713
:3 708 :a 71f :12 720 :3 721
723 :2 724 :2 725 726
:2 727 723 :6 728 :5 729
728 :5 72b 72a :3 728
722 :2 72e :5 730 :11 731
:24 732 :3 731 :2 72f :6 72e
72d :3 720 736 720
:b 736 :b 737 738 :3 737
73b :3 73c :2 73d :2 73e
:2 73f 740 :2 741 73b
:6 742 :5 743 742 :5 745
744 :3 742 73a :2 748
:5 74a :11 74b :24 74c :3 74b
:2 749 :6 748 747 :4 736
720 752 :6 753 :2 754
:2 755 :2 756 757 :2 758
752 :6 759 :5 75a 759
:5 75c 75b :3 759 751
:2 75f :5 761 :11 762 :24 763
:3 762 :2 760 :6 75f 75e
:4 750 :3 720 :16 769 :4 76b
:6 76c :5 76d 76c :5 76f
76e :3 76c 76a :2 772
:5 774 :11 775 :24 776 :3 775
:2 773 :6 772 771 :6 769
71f :8 77d :6 77e :9 77f
:4 780 :7 781 77d :5 782
77c :2 784 :5 786 :11 787
:24 788 :3 787 :2 785 :6 784
783 :3 77b :12 78e :b 78f
790 :3 78f :4 793 :6 794
:5 795 794 :5 797 796
:3 794 792 :2 79a :5 79c
:11 79d :24 79e :3 79d :2 79b
:6 79a 799 :3 78e :4 7a4
:5 7a5 :2 7a6 7a4 :6 7a7
:5 7a8 7a7 :5 7aa 7a9
:3 7a7 7a3 :2 7ad :5 7af
:11 7b0 :24 7b1 :3 7b0 :2 7ae
:6 7ad 7ac :3 78e :6 7b7
:2 7b8 7b7 :6 7b9 :5 7ba
7b9 :5 7bc 7bb :3 7b9
7b6 :2 7bf :5 7c1 :11 7c2
:24 7c3 :3 7c2 :2 7c0 :6 7bf
7be :4 78e :b 7c8 7c9
:3 7c8 :9 7cc :6 7cd :5 7ce
7cd :5 7d0 7cf :3 7cd
7cb :2 7d3 :5 7d5 :11 7d6
:24 7d7 :3 7d6 :2 7d4 :6 7d3
7d2 :3 7c7 :4 7dd :5 7de
:2 7df 7dd :6 7e0 :5 7e1
7e0 :5 7e3 7e2 :3 7e0
7dc :2 7e6 :5 7e8 :11 7e9
:24 7ea :3 7e9 :2 7e7 :6 7e6
7e5 :4 7c7 :3 78e 77b
:3 71f :9 7f3 :12 7f4 :3 7f6
:4 7f7 7f6 :5 7f8 7f5
:2 7fa :5 7fc :11 7fd :24 7fe
:3 7fd :2 7fb :6 7fa 7f9
:3 7f4 :16 804 :6 806 :6 807
:5 808 807 :5 80a 809
:3 807 805 :2 80d :5 80f
:11 810 :24 811 :3 810 :2 80e
:6 80d 80c :3 804 815
804 :16 815 :4 817 :5 818
816 :2 81a :5 81c :11 81d
:24 81e :3 81d :2 81b :6 81a
819 :3 815 :11 823 :30 824
:3 823 :11 826 :b 827 :3 826
:7 829 82a :2 829 815
:3 804 :3 7f4 :6 82e :9 82f
:3 830 :2 831 :3 82f :6 869
:6 86a :5 86b 86a :5 86d
86c :3 86a 868 :2 870
:5 872 :11 873 :24 874 :3 873
:2 871 :6 870 86f :3 7f3
:3 879 :5 87c :3 87e :3 87f
:3 880 :3 881 :3 883 :3 885
:3 886 :3 887 :3 888 :12 88a
:2 88b :2 88a :8 88b 88a
88b :2 88c :2 88b :8 88c
88b :6 88a :9 88d 88f
:4 890 :2 891 :4 892 :4 893
:4 894 :4 895 :4 896 :2 897
:6 898 :2 899 88f :6 89a
:5 89b 89a :5 89d 89c
:3 89a 88e :2 8a0 :5 8a2
:11 8a3 :24 8a4 :3 8a3 :2 8a1
:6 8a0 89f :4 88d 8aa
:4 8ab :2 8ac :4 8ad :4 8ae
:4 8af :4 8b0 :4 8b1 :2 8b2
:2 8b3 :6 8b4 :2 8b5 8aa
:6 8b6 :5 8b7 8b6 :5 8b9
8b8 :3 8b6 8a9 :2 8bc
:5 8be :11 8bf :24 8c0 :3 8bf
:2 8bd :6 8bc 8bb :4 8a8
:3 88d 88c 8c9 :4 8ca
:2 8cb :4 8cc :4 8cd :4 8ce
:4 8cf :8 8d0 :2 8d1 8c9
:6 8d2 :5 8d3 8d2 :5 8d5
8d4 :3 8d2 8c8 :2 8d8
:5 8da :11 8db :24 8dc :3 8db
:2 8d9 :6 8d8 8d7 :4 8c7
:3 88a :16 8e2 :3 8e3 8e4
8e2 :9 8e4 :7 8e5 8e4
:3 8e2 :e 8e8 :b 8e9 :2 8ea
:2 8e9 :a 8ea :8 8eb :3 8e8
:b 8ed :4 8ef :5 8f0 8ee
:2 8f2 :5 8f4 :11 8f5 :24 8f6
:3 8f5 :2 8f3 :6 8f2 8f1
:3 8ed :11 8fb :20 8fc :3 8fb
:11 8fe :b 8ff :3 8fe :9 901
902 8ed :9 902 :4 904
:5 905 903 :2 907 :5 909
:11 90a :24 90b :3 90a :2 908
:6 907 906 :3 902 :11 910
:2e 911 :3 910 :11 913 :b 914
:3 913 :c 916 902 :3 8ed
87c :15 91b :2 91c :2 91b
:4 91c :2 91b :3 91d :7 91e
91c :2 91b :1a 921 :7 922
921 :12 924 923 :3 921
:9 927 :b 928 927 :11 92a
929 :3 927 937 :4 938
:2 939 :4 93a :4 93b :4 93c
:4 93d :6 93e :2 93f 937
:6 940 :5 941 940 :5 943
942 :3 940 936 :2 946
:5 948 :11 949 :24 94a :3 949
:2 947 :6 946 945 :4 918
:3 87c :3 950 :3 951 :3 952
:13 954 :2 955 :2 954 :4 955
:5 954 :5 956 955 :f 958
957 :3 954 :3 95b :3 962
:7 963 :6 964 :7 965 :6 966
:8 967 :3 963 :9 96b :4 96d
:5 96e 96c :2 970 :5 972
:11 973 :24 974 :3 973 :2 971
:6 970 96f :3 96b :11 979
:30 97a :3 979 :11 97c :b 97d
:3 97c :a 97f 980 96b
:9 980 :4 982 :5 983 981
:2 985 :5 987 :11 988 :24 989
:3 988 :2 986 :6 985 984
:3 980 :11 98e :30 98f :3 98e
:11 991 :b 992 :3 991 :7 994
995 :2 994 980 :3 96b
:8 99f :6 9a0 :5 9a1 9a0
:5 9a3 9a2 :3 9a0 99e
:2 9a6 :5 9a8 :11 9a9 :24 9aa
:3 9a9 :2 9a7 :6 9a6 9a5
:3 7f3 9b1 :b 9b2 :c 9b3
9b1 :6 9b4 :5 9b5 9b4
:5 9b7 9b6 :3 9b4 9b0
:2 9ba :5 9bc :11 9bd :24 9be
:3 9bd :2 9bb :6 9ba 9b9
:3 7f3 9c5 :7 9c6 :3 9c7
9c5 :6 9c8 :5 9c9 9c8
:5 9cb 9ca :3 9c8 9c4
:2 9ce :5 9d0 :11 9d1 :24 9d2
:3 9d1 :2 9cf :6 9ce 9cd
:3 7f3 9d8 :7 9d9 :3 9da
9d8 :6 9db :5 9dc 9db
:5 9de 9dd :3 9db 9d7
:2 9e1 :5 9e3 :11 9e4 :24 9e5
:3 9e4 :2 9e2 :6 9e1 9e0
:3 7f3 :b 9ea :f 9eb :3 9ed
:8 9ee :3 9f0 :8 9f1 :3 9f4
:4 9f5 9f4 :6 9f6 :5 9f7
9f6 :5 9f9 9f8 :3 9f6
9f3 :2 9fc :5 9fe :11 9ff
:24 a00 :3 9ff :2 9fd :6 9fc
9fb :3 7f3 :16 a06 :3 a08
:2 a09 :2 a0a :2 a0b :2 a0c
:4 a0d :2 a0e a08 :6 a0f
:5 a10 a0f :5 a12 a11
:3 a0f a07 :2 a15 :5 a17
:11 a18 :24 a19 :3 a18 :2 a16
:6 a15 a14 :3 a06 a1d
a06 :9 a1d :3 a1f :2 a20
:2 a21 :4 a22 :2 a23 a1f
:6 a24 :5 a25 a24 :5 a27
a26 :3 a24 a1e :2 a2a
:5 a2c :11 a2d :24 a2e :3 a2d
:2 a2b :6 a2a a29 :3 a1d
:7 a33 a34 a1d a06
:9 a34 :3 a36 :2 a37 :2 a38
:4 a39 :2 a3a a36 :6 a3b
:5 a3c a3b :5 a3e a3d
:3 a3b a35 :2 a41 :5 a43
:11 a44 :24 a45 :3 a44 :2 a42
:6 a41 a40 :3 a34 :7 a4a
a34 a06 :3 a4d :4 a4e
:2 a4f a4d :6 a50 :5 a51
a50 :5 a53 a52 :3 a50
a4c :2 a56 :5 a58 :11 a59
:24 a5a :3 a59 :2 a57 :6 a56
a55 :3 a4b :7 a5f :7 a60
a4b :3 a06 :3 7f3 :3 708
6e2 :3 67a :a a74 668
a75 8d :4 a79 :5 a7a
a78 :2 a7c :5 a7e :11 a7f
:24 a80 :3 a7f :2 a7d :6 a7c
a7b :3 8d :3 a86 :9 a87
:3 a88 :d a8c :f a8d :16 a94
:6 a95 :2 a94 :3 a96 :3 a97
:3 a98 :3 a9a :3 a9c :3 a9d
:3 a9e :3 a9f :14 aa1 :3 aa2
aa3 aa1 :9 aa3 :7 aa4
aa3 :3 aa1 :e aa7 :b aa8
:2 aa9 :2 aa8 :a aa9 :8 aaa
:3 aa7 :b aac :11 aad :20 aae
:3 aad :11 ab0 :b ab1 :3 ab0
:9 ab3 ab4 aac :9 ab4
:11 ab5 :2e ab6 :3 ab5 :11 ab8
:b ab9 :3 ab8 :c abb ab4
:3 aac :5 abf :5 ac0 :4 ac3
ac4 :4 ac5 ac6 ac3
:6 ac7 :5 ac8 ac7 :5 aca
ac9 :3 ac7 ac2 :2 acd
:5 acf :11 ad0 :24 ad1 :3 ad0
:2 ace :6 acd acc :3 a95
:3 ad7 :3 ada :3 adb :3 adc
:3 add :13 adf :2 ae0 :2 adf
:4 ae0 :5 adf :15 ae1 :2 ae2
:2 ae1 :4 ae2 :2 ae1 :3 ae3
:7 ae4 ae2 :2 ae1 :f ae6
:3 ae7 ae0 :3 ae9 ae8
:3 adf :3 aed :7 aee :6 aef
:7 af0 :6 af1 :8 af2 :3 aee
:9 af6 :11 af7 :30 af8 :3 af7
:11 afa :b afb :3 afa :a afd
afe af6 :9 afe :11 aff
:30 b00 :3 aff :11 b02 :b b03
:3 b02 :7 b05 b06 :2 b05
afe af6 :3 b09 :3 b0a
:5 b0b :5 b0c :5 b0d :5 b0e
:2 b0f b09 :6 b10 :5 b11
b10 :5 b13 b12 :3 b10
b08 :2 b16 :5 b18 :11 b19
:24 b1a :3 b19 :2 b17 :6 b16
b15 :4 b07 :3 af6 a95
:2 a94 :3 a8c :3 b23 :5 b24
b23 :5 b25 b22 :2 b27
:5 b29 :11 b2a :24 b2b :3 b2a
:2 b28 :6 b27 b26 :3 a87
:9 b31 :5 b33 :4 b34 b33
:6 b35 :5 b36 b35 :5 b38
b37 :3 b35 b32 :2 b3b
:5 b3d :11 b3e :24 b3f :3 b3e
:2 b3c :6 b3b b3a :6 b31
:3 a87 :3 b46 :5 b49 :a b4b
:6 b4c :5 b4d b4c :5 b4f
b4e :3 b4c b4a :2 b52
:5 b54 :11 b55 :24 b56 :3 b55
:2 b53 :6 b52 b51 :3 b49
:9 b5c :3 b5e :4 b5f b5e
:5 b60 b5d :2 b62 :5 b64
:11 b65 :24 b66 :3 b65 :2 b63
:6 b62 b61 :3 b5c :9 b6c
:3 b6e :5 b6f b6e :6 b70
:5 b71 b70 :5 b73 b72
:3 b70 b6d :2 b76 :5 b78
:11 b79 :24 b7a :3 b79 :2 b77
:6 b76 b75 :3 b6c :6 b80
:6 b81 :5 b82 b81 :5 b84
b83 :3 b81 b7f :2 b87
:5 b89 :11 b8a :24 b8b :3 b8a
:2 b88 :6 b87 b86 :6 b6c
:3 b5c :9 b92 :3 b94 :a b95
:d b98 :9 b99 :3 b9a b98
:5 b9b b97 :2 b9d :5 b9f
:11 ba0 :24 ba1 :3 ba0 :2 b9e
:6 b9d b9c :3 b92 :a ba7
:9 ba8 baa :2 bab :2 bac
:2 bad :3 bae baf :4 bb0
baa :6 bb1 :5 bb2 bb1
:5 bb4 bb3 :3 bb1 ba9
:2 bb7 :5 bb9 :11 bba :24 bbb
:3 bba :2 bb8 :6 bb7 bb6
:4 ba8 bc1 :2 bc2 :2 bc3
:2 bc4 :3 bc5 :3 bc6 :4 bc7
bc1 :6 bc8 :5 bc9 bc8
:5 bcb bca :3 bc8 bc0
:2 bce :5 bd0 :11 bd1 :24 bd2
:3 bd1 :2 bcf :6 bce bcd
:4 bbf :3 ba8 :b bd9 :3 bda
:7 bdb :4 bdc :3 bdd :3 bdb
:3 bd9 :3 ba7 :a be2 be3
:2 be2 :4 be3 :3 be2 :3 be4
be3 :2 be2 :3 b92 :3 b49
:12 bea :9 bec :3 bee :4 bef
:3 bf0 bee :5 bf1 bed
:2 bf3 :5 bf5 :11 bf6 :24 bf7
:3 bf6 :2 bf4 :6 bf3 bf2
:3 bec :9 bfc bff c00
:4 c01 :3 c02 bff :6 c03
:5 c04 c03 :5 c06 c05
:3 c03 bfe :2 c09 :5 c0b
:11 c0c :24 c0d :3 c0c :2 c0a
:6 c09 c08 :3 bfc c13
:2 c14 :4 c15 :2 c16 c13
:6 c17 :5 c18 c17 :5 c1a
c19 :3 c17 c12 :2 c1d
:5 c1f :11 c20 :24 c21 :3 c20
:2 c1e :6 c1d c1c :6 bfc
:3 bec :3 c29 :a c2a :d c2d
:9 c2e :3 c2f c2d :5 c30
c2c :2 c32 :5 c34 :11 c35
:24 c36 :3 c35 :2 c33 :6 c32
c31 :3 bea :a c3c :9 c3d
c3f :2 c40 :2 c41 :2 c42
:3 c43 c44 :4 c45 c3f
:6 c46 :5 c47 c46 :5 c49
c48 :3 c46 c3e :2 c4c
:5 c4e :11 c4f :24 c50 :3 c4f
:2 c4d :6 c4c c4b :4 c3d
c56 :2 c57 :2 c58 :2 c59
:3 c5a :3 c5b :4 c5c c56
:6 c5d :5 c5e c5d :5 c60
c5f :3 c5d c55 :2 c63
:5 c65 :11 c66 :24 c67 :3 c66
:2 c64 :6 c63 c62 :4 c54
:3 c3d :17 c6e :3 c6f :7 c70
:4 c71 :3 c72 :3 c70 :3 c6e
:3 c3c :3 bea :6 c78 :7 c7b
:5 c7c :3 c7b :11 c80 :30 c81
:3 c80 :a c83 8d :3 c86
:11 c87 :b c88 :17 c89 :3 c87
:2 c8b :3 c8c :3 c8d c8e
c8c c8b c8c :3 c8f
:3 c86 :2 c90 :5 c92 :11 c93
:b c94 :18 c95 :3 c93 :2 c97
c98 :3 c99 c9a c98
c97 c98 :3 c9b :2 c91
:6 c90 c85 :7 1 
108fc
4
:3 0 1 :3 0 2
:a 0 4bc4 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
56 0 7 4
:3 0 5 :7 0 9
8 :3 0 4 :3 0
6 :7 0 d c
:3 0 d 7c 0
b 4 :3 0 7
:7 0 11 10 :3 0
4 :3 0 8 :7 0
15 14 :3 0 11
a2 0 f a
:3 0 9 :7 0 19
18 :3 0 a :3 0
b :7 0 1d 1c
:3 0 15 c8 0
13 a :3 0 c
:7 0 21 20 :3 0
a :3 0 d :7 0
25 24 :3 0 19
ee 0 17 a
:3 0 e :7 0 29
28 :3 0 a :3 0
f :7 0 2d 2c
:3 0 1d 114 0
1b a :3 0 10
:7 0 31 30 :3 0
a :3 0 11 :7 0
35 34 :3 0 21
:2 0 1f a :3 0
12 :7 0 39 38
:3 0 4 :3 0 13
:7 0 3d 3c :3 0
14 :3 0 15 :3 0
16 :2 0 4 41
42 0 3f 43
0 4bc4 2 44
:2 0 18 :2 0 33
4 :3 0 18 :2 0
31 47 49 :6 0
4c 4a 0 4bc2
0 17 :6 0 18
:2 0 37 4 :3 0
35 4e 50 :6 0
53 51 0 4bc2
0 19 :6 0 18
:2 0 3b 4 :3 0
39 55 57 :6 0
5a 58 0 4bc2
0 1a :6 0 18
:2 0 3f 4 :3 0
3d 5c 5e :6 0
61 5f 0 4bc2
0 1b :6 0 18
:2 0 43 4 :3 0
41 63 65 :6 0
68 66 0 4bc2
0 1c :6 0 18
:2 0 47 4 :3 0
45 6a 6c :6 0
6f 6d 0 4bc2
0 1d :6 0 18
:2 0 4b 4 :3 0
49 71 73 :6 0
76 74 0 4bc2
0 1e :6 0 18
:2 0 4f 4 :3 0
4d 78 7a :6 0
7d 7b 0 4bc2
0 1f :6 0 18
:2 0 53 4 :3 0
51 7f 81 :6 0
84 82 0 4bc2
0 20 :6 0 18
:2 0 57 4 :3 0
55 86 88 :6 0
8b 89 0 4bc2
0 21 :6 0 18
:2 0 5b 4 :3 0
59 8d 8f :6 0
92 90 0 4bc2
0 22 :6 0 61
2b0 0 5f 4
:3 0 5d 94 96
:6 0 99 97 0
4bc2 0 23 :6 0
65 2e4 0 63
25 :3 0 9b :7 0
9e 9c 0 4bc2
0 24 :6 0 25
:3 0 a0 :7 0 a3
a1 0 4bc2 0
26 :6 0 2a :2 0
67 25 :3 0 a5
:7 0 a8 a6 0
4bc2 0 27 :6 0
25 :3 0 aa :7 0
ad ab 0 4bc2
0 28 :6 0 6d
335 0 6b 4
:3 0 69 af b1
:6 0 b4 b2 0
4bc2 0 29 :6 0
2a :2 0 6f 2c
:3 0 b6 :7 0 b9
b7 0 4bc2 0
2b :6 0 2c :3 0
bb :7 0 be bc
0 4bc2 0 2d
:6 0 30 :2 0 73
4 :3 0 71 c0
c2 :6 0 c5 c3
0 4bc2 0 2e
:6 0 79 3a3 0
77 4 :3 0 75
c7 c9 :6 0 cc
ca 0 4bc2 0
2f :6 0 7d 3d7
0 7b 25 :3 0
ce :7 0 d1 cf
0 4bc2 0 31
:6 0 25 :3 0 d3
:7 0 d6 d4 0
4bc2 0 32 :6 0
18 :2 0 7f 25
:3 0 d8 :7 0 db
d9 0 4bc2 0
33 :6 0 25 :3 0
dd :7 0 e0 de
0 4bc2 0 34
:6 0 37 :2 0 83
4 :3 0 81 e2
e4 :6 0 e7 e5
0 4bc2 0 35
:6 0 37 :2 0 87
4 :3 0 85 e9
eb :6 0 ee ec
0 4bc2 0 36
:6 0 37 :2 0 8b
4 :3 0 89 f0
f2 :6 0 f5 f3
0 4bc2 0 38
:6 0 3b :2 0 8f
4 :3 0 8d f7
f9 :6 0 fc fa
0 4bc2 0 39
:6 0 3d :2 0 93
4 :3 0 91 fe
100 :6 0 103 101
0 4bc2 0 3a
:6 0 3d :2 0 95
a :3 0 105 :7 0
109 106 107 4bc2
0 3c :6 0 3d
:2 0 97 a :3 0
10b :7 0 10f 10c
10d 4bc2 0 3e
:6 0 3d :2 0 99
a :3 0 111 :7 0
115 112 113 4bc2
0 3f :6 0 3d
:2 0 9b a :3 0
117 :7 0 11b 118
119 4bc2 0 40
:6 0 3d :2 0 9d
a :3 0 11d :7 0
121 11e 11f 4bc2
0 41 :6 0 3d
:2 0 9f a :3 0
123 :7 0 127 124
125 4bc2 0 42
:6 0 3d :2 0 a1
a :3 0 129 :7 0
12d 12a 12b 4bc2
0 43 :6 0 3d
:2 0 a3 a :3 0
12f :7 0 133 130
131 4bc2 0 44
:6 0 3d :2 0 a5
a :3 0 135 :7 0
139 136 137 4bc2
0 45 :6 0 3d
:2 0 a7 a :3 0
13b :7 0 13f 13c
13d 4bc2 0 46
:6 0 3d :2 0 a9
a :3 0 141 :7 0
145 142 143 4bc2
0 47 :6 0 3d
:2 0 ab a :3 0
147 :7 0 14b 148
149 4bc2 0 48
:6 0 3d :2 0 ad
a :3 0 14d :7 0
151 14e 14f 4bc2
0 49 :6 0 3d
:2 0 af a :3 0
153 :7 0 157 154
155 4bc2 0 4a
:6 0 3d :2 0 b1
a :3 0 159 :7 0
15d 15a 15b 4bc2
0 4b :6 0 3d
:2 0 b3 a :3 0
15f :7 0 163 160
161 4bc2 0 4c
:6 0 3d :2 0 b5
a :3 0 165 :7 0
169 166 167 4bc2
0 4d :6 0 3d
:2 0 b7 a :3 0
16b :7 0 16f 16c
16d 4bc2 0 4e
:6 0 3d :2 0 b9
a :3 0 171 :7 0
175 172 173 4bc2
0 4f :6 0 3d
:2 0 bb a :3 0
177 :7 0 17b 178
179 4bc2 0 50
:6 0 3d :2 0 bd
a :3 0 17d :7 0
181 17e 17f 4bc2
0 51 :6 0 3d
:2 0 bf a :3 0
183 :7 0 187 184
185 4bc2 0 52
:6 0 3d :2 0 c1
a :3 0 189 :7 0
18d 18a 18b 4bc2
0 53 :6 0 3d
:2 0 c3 a :3 0
18f :7 0 193 190
191 4bc2 0 54
:6 0 3d :2 0 c5
a :3 0 195 :7 0
199 196 197 4bc2
0 55 :6 0 3d
:2 0 c7 a :3 0
19b :7 0 19f 19c
19d 4bc2 0 56
:6 0 5a :2 0 c9
a :3 0 1a1 :7 0
1a5 1a2 1a3 4bc2
0 57 :6 0 5a
:2 0 cb 59 :3 0
1a7 :7 0 1ab 1a8
1a9 4bc2 0 58
:6 0 5a :2 0 cd
59 :3 0 1ad :7 0
1b1 1ae 1af 4bc2
0 5b :6 0 5a
:2 0 cf 59 :3 0
1b3 :7 0 1b7 1b4
1b5 4bc2 0 5c
:6 0 5a :2 0 d1
59 :3 0 1b9 :7 0
1bd 1ba 1bb 4bc2
0 5d :6 0 3d
:2 0 d3 59 :3 0
1bf :7 0 1c3 1c0
1c1 4bc2 0 5e
:6 0 3d :2 0 d5
a :3 0 1c5 :7 0
1c9 1c6 1c7 4bc2
0 5f :6 0 3d
:2 0 d7 a :3 0
1cb :7 0 1cf 1cc
1cd 4bc2 0 60
:6 0 3d :2 0 d9
a :3 0 1d1 :7 0
1d5 1d2 1d3 4bc2
0 61 :6 0 3d
:2 0 db a :3 0
1d7 :7 0 1db 1d8
1d9 4bc2 0 62
:6 0 3d :2 0 dd
a :3 0 1dd :7 0
1e1 1de 1df 4bc2
0 63 :6 0 3d
:2 0 df a :3 0
1e3 :7 0 1e7 1e4
1e5 4bc2 0 64
:6 0 3d :2 0 e1
a :3 0 1e9 :7 0
1ed 1ea 1eb 4bc2
0 65 :6 0 68
:2 0 e3 a :3 0
1ef :7 0 1f3 1f0
1f1 4bc2 0 66
:6 0 68 :2 0 e7
4 :3 0 e5 1f5
1f7 :6 0 1fa 1f8
0 4bc2 0 67
:6 0 3d :2 0 eb
4 :3 0 e9 1fc
1fe :6 0 201 1ff
0 4bc2 0 69
:6 0 3d :2 0 ed
59 :3 0 203 :7 0
207 204 205 4bc2
0 6a :6 0 2a
:2 0 ef a :3 0
209 :7 0 20d 20a
20b 4bc2 0 6b
:6 0 3d :2 0 f3
4 :3 0 f1 20f
211 :6 0 214 212
0 4bc2 0 6c
:6 0 18 :2 0 f5
a :3 0 216 :7 0
21a 217 218 4bc2
0 6d :6 0 2a
:2 0 f9 4 :3 0
f7 21c 21e :6 0
221 21f 0 4bc2
0 6e :6 0 3d
:2 0 fd 4 :3 0
fb 223 225 :6 0
228 226 0 4bc2
0 6f :6 0 3d
:2 0 ff a :3 0
22a :7 0 22e 22b
22c 4bc2 0 70
:6 0 103 a19 0
101 a :3 0 230
:7 0 234 231 232
4bc2 0 71 :6 0
3d :2 0 105 2c
:3 0 236 :7 0 239
237 0 4bc2 0
72 :6 0 2c :3 0
23b :7 0 23e 23c
0 4bc2 0 73
:6 0 3d :2 0 107
59 :3 0 240 :7 0
244 241 242 4bc2
0 74 :6 0 3d
:2 0 109 59 :3 0
246 :7 0 24a 247
248 4bc2 0 75
:6 0 3d :2 0 10b
a :3 0 24c :7 0
250 24d 24e 4bc2
0 76 :6 0 3d
:2 0 10d a :3 0
252 :7 0 256 253
254 4bc2 0 77
:6 0 3d :2 0 10f
a :3 0 258 :7 0
25c 259 25a 4bc2
0 78 :6 0 3d
:2 0 111 a :3 0
25e :7 0 262 25f
260 4bc2 0 79
:6 0 3d :2 0 113
a :3 0 264 :7 0
268 265 266 4bc2
0 7a :6 0 3d
:2 0 115 a :3 0
26a :7 0 26e 26b
26c 4bc2 0 7b
:6 0 3d :2 0 117
a :3 0 270 :7 0
274 271 272 4bc2
0 7c :6 0 3d
:2 0 119 a :3 0
276 :7 0 27a 277
278 4bc2 0 7d
:6 0 18 :2 0 11b
a :3 0 27c :7 0
280 27d 27e 4bc2
0 7e :6 0 18
:2 0 11f 4 :3 0
11d 282 284 :6 0
287 285 0 4bc2
0 7f :6 0 18
:2 0 123 4 :3 0
121 289 28b :6 0
28e 28c 0 4bc2
0 80 :6 0 3d
:2 0 127 4 :3 0
125 290 292 :6 0
295 293 0 4bc2
0 81 :6 0 3d
:2 0 12e a :3 0
297 0 2 :5 0
83 :3 0 84 :3 0
42 :3 0 129 29a
29d 12c 299 29f
2a0 :2 0 2a3 298
2a1 4bc2 0 82
:6 0 3d :2 0 130
a :3 0 2a5 0
2 :5 0 2a9 2a6
2a7 4bc2 0 85
:9 0 132 a :3 0
2ab 0 2 :5 0
2af 2ac 2ad 4bc2
0 86 :6 0 87
:3 0 88 :a 0 2
2bb :4 0 2b1 2b4
0 2b2 :3 0 89
:3 0 8a :3 0 8b
:3 0 21 :3 0 8c
:4 0 8d 1 :8 0
2bc 2b1 2b4 2bd
0 4bc2 134 2bd
2bf 2bc 2be :6 0
2bb :7 0 2bd 87
:3 0 8e :a 0 3
2cf :5 0 2c1 2c4
0 2c2 :3 0 8f
:3 0 90 :3 0 91
:3 0 22 :3 0 92
:3 0 21 :3 0 93
:3 0 94 :3 0 8c
:4 0 95 1 :8 0
2d0 2c1 2c4 2d1
0 4bc2 136 2d1
2d3 2d0 2d2 :6 0
2cf :7 0 2d1 87
:3 0 96 :a 0 4
347 :5 0 2d5 2d8
0 2d6 :3 0 97
:3 0 98 :3 0 99
:3 0 9a :3 0 99
:3 0 9b :3 0 97
:3 0 9c :3 0 99
:3 0 9d :3 0 99
:3 0 9e :3 0 9f
:3 0 a0 :3 0 99
:3 0 a1 :3 0 9f
:3 0 a0 :3 0 99
:3 0 a2 :3 0 99
:3 0 a1 :3 0 99
:3 0 a2 :3 0 99
:3 0 a3 :3 0 a4
:3 0 a3 :3 0 99
:3 0 a3 :3 0 99
:3 0 94 :3 0 99
:3 0 a5 :3 0 99
:3 0 a6 :3 0 99
:3 0 a7 :3 0 99
:3 0 a8 :3 0 99
:3 0 a9 :3 0 99
:3 0 aa :3 0 99
:3 0 ab :3 0 99
:3 0 ac :3 0 99
:3 0 ad :3 0 ae
:3 0 a4 :3 0 af
:3 0 97 :3 0 90
:3 0 99 :3 0 97
:3 0 91 :3 0 22
:3 0 97 :3 0 92
:3 0 23 :3 0 97
:3 0 93 :3 0 99
:3 0 98 :3 0 97
:3 0 98 :3 0 97
:3 0 8b :3 0 a4
:3 0 8b :3 0 97
:3 0 9c :3 0 b0
:3 0 b1 :3 0 b0
:3 0 b2 :3 0 b0
:3 0 b3 :3 0 b0
:3 0 b4 :3 0 b0
:3 0 b5 :3 0 b0
:3 0 b6 :3 0 b0
:3 0 b7 :3 0 b0
:3 0 b8 :3 0 b0
:3 0 b9 :3 0 b0
:3 0 ba :3 0 b0
:3 0 bb :3 0 b0
:3 0 bc :3 0 b0
:3 0 bd :3 0 b0
:3 0 be :3 0 b0
:3 0 bf :3 0 a4
:3 0 c0 :3 0 2f
:3 0 99 :3 0 a1
:4 0 c1 1 :8 0
348 2d5 2d8 349
0 4bc2 138 349
34b 348 34a :6 0
347 :7 0 349 353
354 0 13a 15
:3 0 16 :2 0 4
34d 34e 0 34f
:7 0 352 350 0
4bc2 0 c2 :6 0
c3 :3 0 c4 :3 0
c3 :3 0 c5 :3 0
356 357 0 2
:4 0 13c 358 35a
355 35c 35b :2 0
c6 :3 0 c7 :3 0
35e 35f 0 c8
:4 0 c3 :3 0 c9
:3 0 362 363 0
2 :4 0 13e 364
366 ca :4 0 cb
:2 0 cc :3 0 140
369 36b :3 0 cd
:4 0 cb :2 0 ce
:4 0 143 36e 370
:3 0 cb :2 0 3
:3 0 146 372 374
:3 0 cb :2 0 ce
:4 0 149 376 378
:3 0 cb :2 0 cf
:4 0 14c 37a 37c
:3 0 cb :2 0 ce
:4 0 14f 37e 380
:3 0 cb :2 0 5
:3 0 152 382 384
:3 0 cb :2 0 ce
:4 0 155 386 388
:3 0 cb :2 0 cf
:4 0 158 38a 38c
:3 0 cb :2 0 ce
:4 0 15b 38e 390
:3 0 cb :2 0 6
:3 0 15e 392 394
:3 0 cb :2 0 ce
:4 0 161 396 398
:3 0 cb :2 0 cf
:4 0 164 39a 39c
:3 0 cb :2 0 ce
:4 0 167 39e 3a0
:3 0 cb :2 0 7
:3 0 16a 3a2 3a4
:3 0 cb :2 0 ce
:4 0 16d 3a6 3a8
:3 0 cb :2 0 cf
:4 0 170 3aa 3ac
:3 0 cb :2 0 ce
:4 0 173 3ae 3b0
:3 0 cb :2 0 8
:3 0 176 3b2 3b4
:3 0 cb :2 0 ce
:4 0 179 3b6 3b8
:3 0 cb :2 0 cf
:4 0 17c 3ba 3bc
:3 0 cb :2 0 84
:3 0 d0 :3 0 9
:3 0 17f 3c0 3c2
d1 :4 0 181 3bf
3c5 184 3be 3c7
:3 0 cb :2 0 cf
:4 0 187 3c9 3cb
:3 0 cb :2 0 84
:3 0 d0 :3 0 b
:3 0 18a 3cf 3d1
d1 :4 0 18c 3ce
3d4 18f 3cd 3d6
:3 0 cb :2 0 cf
:4 0 192 3d8 3da
:3 0 cb :2 0 84
:3 0 d0 :3 0 c
:3 0 195 3de 3e0
d1 :4 0 197 3dd
3e3 19a 3dc 3e5
:3 0 cb :2 0 cf
:4 0 19d 3e7 3e9
:3 0 cb :2 0 84
:3 0 d0 :3 0 d
:3 0 1a0 3ed 3ef
d1 :4 0 1a2 3ec
3f2 1a5 3eb 3f4
:3 0 cb :2 0 cf
:4 0 1a8 3f6 3f8
:3 0 cb :2 0 84
:3 0 d0 :3 0 e
:3 0 1ab 3fc 3fe
d1 :4 0 1ad 3fb
401 1b0 3fa 403
:3 0 cb :2 0 cf
:4 0 1b3 405 407
:3 0 cb :2 0 84
:3 0 d0 :3 0 f
:3 0 1b6 40b 40d
d1 :4 0 1b8 40a
410 1bb 409 412
:3 0 cb :2 0 cf
:4 0 1be 414 416
:3 0 cb :2 0 84
:3 0 d0 :3 0 10
:3 0 1c1 41a 41c
d1 :4 0 1c3 419
41f 1c6 418 421
:3 0 cb :2 0 cf
:4 0 1c9 423 425
:3 0 cb :2 0 84
:3 0 d0 :3 0 11
:3 0 1cc 429 42b
d1 :4 0 1ce 428
42e 1d1 427 430
:3 0 cb :2 0 cf
:4 0 1d4 432 434
:3 0 cb :2 0 84
:3 0 d0 :3 0 12
:3 0 1d7 438 43a
d1 :4 0 1d9 437
43d 1dc 436 43f
:3 0 cb :2 0 cf
:4 0 1df 441 443
:3 0 cb :2 0 ce
:4 0 1e2 445 447
:3 0 cb :2 0 13
:3 0 1e5 449 44b
:3 0 cb :2 0 ce
:4 0 1e8 44d 44f
:3 0 cb :2 0 d2
:4 0 1eb 451 453
:3 0 1ee 360 455
:2 0 457 1f3 458
35d 457 0 459
1f5 0 4b22 c3
:3 0 c4 :3 0 45a
45b 0 c3 :3 0
d3 :3 0 45d 45e
0 2a :2 0 2
:4 0 d4 :2 0 d5
:2 0 2a :2 0 1f7
463 465 :3 0 1fa
45f 467 45c 469
468 :2 0 c6 :3 0
d6 :3 0 46b 46c
0 c8 :4 0 d7
:4 0 cb :2 0 cc
:3 0 1fe 470 472
:3 0 201 46d 474
:2 0 476 204 477
46a 476 0 478
206 0 4b22 20
:3 0 3 :3 0 479
47a 0 4b22 23
:3 0 5 :3 0 47c
47d 0 4b22 21
:3 0 6 :3 0 47f
480 0 4b22 1a
:3 0 13 :3 0 482
483 0 4b22 31
:3 0 7 :3 0 485
486 0 4b22 52
:3 0 11 :3 0 488
489 0 4b22 52
:3 0 d8 :3 0 84
:3 0 52 :3 0 3d
:2 0 208 48d 490
b0 :3 0 d9 :3 0
492 493 0 20b
48c 495 48b 496
0 4b22 84 :3 0
52 :3 0 3d :2 0
20e 498 49b b0
:3 0 da :2 0 db
:3 0 49d 49f 0
213 49e 4a1 :3 0
4a2 :2 0 84 :3 0
52 :3 0 3d :2 0
216 4a4 4a7 b0
:3 0 da :2 0 dc
:3 0 4a9 4ab 0
21b 4aa 4ad :3 0
4ae :2 0 4a3 4b0
4af :2 0 52 :3 0
dd :2 0 4b2 4b3
0 4b5 21e 4b6
4b1 4b5 0 4b7
220 0 4b22 32
:3 0 31 :3 0 4b8
4b9 0 4b22 3a
:3 0 de :4 0 4bb
4bc 0 4b22 29
:3 0 de :4 0 4be
4bf 0 4b22 45
:3 0 3d :2 0 4c1
4c2 0 4b22 26
:3 0 de :4 0 4c4
4c5 0 4b22 33
:4 0 4c7 4c8 0
4b22 34 :4 0 4ca
4cb 0 4b22 df
:3 0 88 :4 0 4d0
:2 0 4b22 4ce 4d1
:3 0 88 :3 0 56
:4 0 4d5 :2 0 4b22
4d2 4d3 :3 0 88
:3 0 e0 :3 0 4d6
4d7 :3 0 15 :3 0
e1 :3 0 4d9 4da
0 3d :2 0 4db
4dc 0 4de 222
4e5 15 :3 0 e1
:3 0 4df 4e0 0
e2 :2 0 4e1 4e2
0 4e4 224 4e6
4d8 4de 0 4e7
0 4e4 0 4e7
226 0 4b22 56
:3 0 15 :3 0 e1
:3 0 4e9 4ea 0
4e8 4eb 0 4b22
e3 :3 0 88 :4 0
4f0 :2 0 4f6 4ee
0 15 :3 0 e1
:3 0 4f1 4f2 0
e4 :3 0 4f3 4f4
0 4f6 229 540
e5 :3 0 15 :3 0
e1 :3 0 4f9 4fa
0 e4 :3 0 4fb
4fc 0 536 c3
:3 0 c4 :3 0 4fe
4ff 0 c3 :3 0
d3 :3 0 501 502
0 e6 :2 0 2
:4 0 e7 :2 0 d5
:2 0 2a :2 0 22c
507 509 :3 0 22f
503 50b 500 50d
50c :2 0 c6 :3 0
d6 :3 0 50f 510
0 c8 :4 0 e8
:4 0 cb :2 0 cc
:3 0 233 514 516
:3 0 cb :2 0 e9
:4 0 236 518 51a
:3 0 cb :2 0 ea
:4 0 239 51c 51e
:3 0 cb :2 0 e4
:3 0 23c 520 522
:3 0 cb :2 0 eb
:4 0 23f 524 526
:3 0 cb :2 0 a0
:3 0 ec :3 0 2a
:2 0 ed :2 0 242
529 52d 246 528
52f :3 0 249 511
531 :2 0 533 24c
534 50e 533 0
535 24e 0 536
250 539 :3 0 539
0 539 538 536
537 :6 0 53b 5
:3 0 253 53d 255
53c 53b :2 0 53e
257 :2 0 540 0
540 53f 4f6 53e
:6 0 4b22 1 :3 0
84 :3 0 56 :3 0
3d :2 0 259 542
545 da :2 0 e2
:2 0 25e 547 549
:3 0 c3 :3 0 c4
:3 0 54b 54c 0
c3 :3 0 d3 :3 0
54e 54f 0 18
:2 0 2 :4 0 ee
:2 0 d5 :2 0 2a
:2 0 261 554 556
:3 0 264 550 558
54d 55a 559 :2 0
c6 :3 0 d6 :3 0
55c 55d 0 c8
:4 0 ef :4 0 cb
:2 0 cc :3 0 268
561 563 :3 0 cb
:2 0 e9 :4 0 26b
565 567 :3 0 cb
:2 0 f0 :4 0 26e
569 56b :3 0 cb
:2 0 84 :3 0 d0
:3 0 b0 :3 0 f1
:3 0 570 571 0
271 56f 573 d1
:4 0 273 56e 576
276 56d 578 :3 0
cb :2 0 f2 :4 0
279 57a 57c :3 0
cb :2 0 ce :4 0
27c 57e 580 :3 0
cb :2 0 21 :3 0
27f 582 584 :3 0
cb :2 0 ce :4 0
282 586 588 :3 0
285 55e 58a :2 0
58c 288 58d 55b
58c 0 58e 28a
0 5b8 c3 :3 0
c4 :3 0 58f 590
0 c3 :3 0 d3
:3 0 592 593 0
2a :2 0 2 :4 0
f3 :2 0 d5 :2 0
2a :2 0 28c 598
59a :3 0 28f 594
59c 591 59e 59d
:2 0 c6 :3 0 d6
:3 0 5a0 5a1 0
c8 :4 0 f4 :4 0
cb :2 0 cc :3 0
293 5a5 5a7 :3 0
296 5a2 5a9 :2 0
5ab 299 5ac 59f
5ab 0 5ad 29b
0 5b8 f5 :3 0
f6 :3 0 5ae 5af
0 b0 :3 0 f1
:3 0 5b1 5b2 0
21 :3 0 f7 :3 0
29d 5b0 5b6 :2 0
5b8 2a1 5b9 54a
5b8 0 5ba 2a5
0 4b22 f8 :3 0
c0 :3 0 91 :3 0
f9 :3 0 fa :3 0
fb :3 0 fc :3 0
42 :3 0 2f :3 0
22 :3 0 7f :3 0
80 :3 0 7d :3 0
49 :3 0 ae :3 0
8b :3 0 20 :4 0
fd 1 :8 0 5d2
15 :3 0 e1 :3 0
5cd 5ce 0 e4
:3 0 5cf 5d0 0
5d2 2a7 61c e5
:3 0 15 :3 0 e1
:3 0 5d5 5d6 0
e4 :3 0 5d7 5d8
0 612 c3 :3 0
c4 :3 0 5da 5db
0 c3 :3 0 d3
:3 0 5dd 5de 0
e6 :2 0 2 :4 0
fe :2 0 d5 :2 0
2a :2 0 2aa 5e3
5e5 :3 0 2ad 5df
5e7 5dc 5e9 5e8
:2 0 c6 :3 0 d6
:3 0 5eb 5ec 0
c8 :4 0 ff :4 0
cb :2 0 cc :3 0
2b1 5f0 5f2 :3 0
cb :2 0 e9 :4 0
2b4 5f4 5f6 :3 0
cb :2 0 ea :4 0
2b7 5f8 5fa :3 0
cb :2 0 e4 :3 0
2ba 5fc 5fe :3 0
cb :2 0 eb :4 0
2bd 600 602 :3 0
cb :2 0 a0 :3 0
ec :3 0 2a :2 0
ed :2 0 2c0 605
609 2c4 604 60b
:3 0 2c7 5ed 60d
:2 0 60f 2ca 610
5ea 60f 0 611
2cc 0 612 2ce
615 :3 0 615 0
615 614 612 613
:6 0 617 7 :3 0
2d1 619 2d3 618
617 :2 0 61a 2d5
:2 0 61c 0 61c
61b 5d2 61a :6 0
4b22 1 :3 0 15
:3 0 e1 :3 0 61e
61f 0 15 :3 0
da :2 0 100 :3 0
621 623 0 2d9
622 625 :3 0 626
:2 0 c3 :3 0 c4
:3 0 628 629 0
c3 :3 0 d3 :3 0
62b 62c 0 18
:2 0 2 :4 0 101
:2 0 d5 :2 0 2a
:2 0 2dc 631 633
:3 0 2df 62d 635
62a 637 636 :2 0
c6 :3 0 d6 :3 0
639 63a 0 c8
:4 0 102 :4 0 cb
:2 0 cc :3 0 2e3
63e 640 :3 0 cb
:2 0 e9 :4 0 2e6
642 644 :3 0 cb
:2 0 f0 :4 0 2e9
646 648 :3 0 cb
:2 0 84 :3 0 d0
:3 0 b0 :3 0 f1
:3 0 64d 64e 0
2ec 64c 650 d1
:4 0 2ee 64b 653
2f1 64a 655 :3 0
cb :2 0 f2 :4 0
2f4 657 659 :3 0
cb :2 0 ce :4 0
2f7 65b 65d :3 0
cb :2 0 20 :3 0
2fa 65f 661 :3 0
cb :2 0 ce :4 0
2fd 663 665 :3 0
300 63b 667 :2 0
669 303 66a 638
669 0 66b 305
0 695 c3 :3 0
c4 :3 0 66c 66d
0 c3 :3 0 d3
:3 0 66f 670 0
2a :2 0 2 :4 0
103 :2 0 d5 :2 0
2a :2 0 307 675
677 :3 0 30a 671
679 66e 67b 67a
:2 0 c6 :3 0 d6
:3 0 67d 67e 0
c8 :4 0 104 :4 0
cb :2 0 cc :3 0
30e 682 684 :3 0
311 67f 686 :2 0
688 314 689 67c
688 0 68a 316
0 695 f5 :3 0
f6 :3 0 68b 68c
0 b0 :3 0 f1
:3 0 68e 68f 0
20 :3 0 f7 :3 0
318 68d 693 :2 0
695 31c 696 627
695 0 697 320
0 4b22 6b :3 0
3d :2 0 698 699
0 4b22 105 :3 0
6b :3 0 106 :3 0
91 :3 0 22 :4 0
107 1 :8 0 6a6
15 :3 0 e1 :3 0
6a1 6a2 0 e4
:3 0 6a3 6a4 0
6a6 322 6f0 e5
:3 0 15 :3 0 e1
:3 0 6a9 6aa 0
e4 :3 0 6ab 6ac
0 6e6 c3 :3 0
c4 :3 0 6ae 6af
0 c3 :3 0 d3
:3 0 6b1 6b2 0
e6 :2 0 2 :4 0
108 :2 0 d5 :2 0
2a :2 0 325 6b7
6b9 :3 0 328 6b3
6bb 6b0 6bd 6bc
:2 0 c6 :3 0 d6
:3 0 6bf 6c0 0
c8 :4 0 109 :4 0
cb :2 0 cc :3 0
32c 6c4 6c6 :3 0
cb :2 0 e9 :4 0
32f 6c8 6ca :3 0
cb :2 0 ea :4 0
332 6cc 6ce :3 0
cb :2 0 e4 :3 0
335 6d0 6d2 :3 0
cb :2 0 eb :4 0
338 6d4 6d6 :3 0
cb :2 0 a0 :3 0
ec :3 0 2a :2 0
ed :2 0 33b 6d9
6dd 33f 6d8 6df
:3 0 342 6c1 6e1
:2 0 6e3 345 6e4
6be 6e3 0 6e5
347 0 6e6 349
6e9 :3 0 6e9 0
6e9 6e8 6e6 6e7
:6 0 6eb 9 :3 0
34c 6ed 34e 6ec
6eb :2 0 6ee 350
:2 0 6f0 0 6f0
6ef 6a6 6ee :6 0
4b22 1 :3 0 84
:3 0 6b :3 0 3d
:2 0 352 6f2 6f5
10a :2 0 3d :2 0
357 6f7 6f9 :3 0
c3 :3 0 c4 :3 0
6fb 6fc 0 c3
:3 0 d3 :3 0 6fe
6ff 0 18 :2 0
2 :4 0 10b :2 0
d5 :2 0 2a :2 0
35a 704 706 :3 0
35d 700 708 6fd
70a 709 :2 0 c6
:3 0 d6 :3 0 70c
70d 0 c8 :4 0
10c :4 0 cb :2 0
cc :3 0 361 711
713 :3 0 cb :2 0
e9 :4 0 364 715
717 :3 0 cb :2 0
f0 :4 0 367 719
71b :3 0 cb :2 0
84 :3 0 d0 :3 0
b0 :3 0 10d :3 0
720 721 0 36a
71f 723 d1 :4 0
36c 71e 726 36f
71d 728 :3 0 cb
:2 0 f2 :4 0 372
72a 72c :3 0 cb
:2 0 ce :4 0 375
72e 730 :3 0 cb
:2 0 22 :3 0 378
732 734 :3 0 cb
:2 0 ce :4 0 37b
736 738 :3 0 37e
70e 73a :2 0 73c
381 73d 70b 73c
0 73e 383 0
768 c3 :3 0 c4
:3 0 73f 740 0
c3 :3 0 d3 :3 0
742 743 0 2a
:2 0 2 :4 0 10e
:2 0 d5 :2 0 2a
:2 0 385 748 74a
:3 0 388 744 74c
741 74e 74d :2 0
c6 :3 0 d6 :3 0
750 751 0 c8
:4 0 10f :4 0 cb
:2 0 cc :3 0 38c
755 757 :3 0 38f
752 759 :2 0 75b
392 75c 74f 75b
0 75d 394 0
768 f5 :3 0 f6
:3 0 75e 75f 0
b0 :3 0 10d :3 0
761 762 0 22
:3 0 f7 :3 0 396
760 766 :2 0 768
39a 769 6fa 768
0 76a 39e 0
4b22 110 :3 0 f8
:3 0 110 :3 0 111
:3 0 84 :3 0 110
:3 0 112 :3 0 84
:3 0 110 :3 0 113
:3 0 110 :3 0 114
:3 0 110 :3 0 115
:3 0 116 :3 0 117
:3 0 118 :3 0 119
:3 0 41 :3 0 65
:3 0 4f :3 0 50
:3 0 53 :3 0 5f
:3 0 5e :3 0 ae
:3 0 110 :3 0 11a
:3 0 11b :3 0 118
:3 0 110 :3 0 115
:3 0 118 :3 0 8b
:3 0 110 :3 0 8b
:3 0 22 :4 0 11c
1 :8 0 796 15
:3 0 e1 :3 0 791
792 0 e4 :3 0
793 794 0 796
3a0 7e0 e5 :3 0
15 :3 0 e1 :3 0
799 79a 0 e4
:3 0 79b 79c 0
7d6 c3 :3 0 c4
:3 0 79e 79f 0
c3 :3 0 d3 :3 0
7a1 7a2 0 e6
:2 0 2 :4 0 11d
:2 0 d5 :2 0 2a
:2 0 3a3 7a7 7a9
:3 0 3a6 7a3 7ab
7a0 7ad 7ac :2 0
c6 :3 0 d6 :3 0
7af 7b0 0 c8
:4 0 11e :4 0 cb
:2 0 cc :3 0 3aa
7b4 7b6 :3 0 cb
:2 0 e9 :4 0 3ad
7b8 7ba :3 0 cb
:2 0 ea :4 0 3b0
7bc 7be :3 0 cb
:2 0 e4 :3 0 3b3
7c0 7c2 :3 0 cb
:2 0 eb :4 0 3b6
7c4 7c6 :3 0 cb
:2 0 a0 :3 0 ec
:3 0 2a :2 0 ed
:2 0 3b9 7c9 7cd
3bd 7c8 7cf :3 0
3c0 7b1 7d1 :2 0
7d3 3c3 7d4 7ae
7d3 0 7d5 3c5
0 7d6 3c7 7d9
:3 0 7d9 0 7d9
7d8 7d6 7d7 :6 0
7db b :3 0 3ca
7dd 3cc 7dc 7db
:2 0 7de 3ce :2 0
7e0 0 7e0 7df
796 7de :6 0 4b22
1 :3 0 15 :3 0
e1 :3 0 7e2 7e3
0 15 :3 0 da
:2 0 100 :3 0 7e5
7e7 0 3d2 7e6
7e9 :3 0 7ea :2 0
c3 :3 0 c4 :3 0
7ec 7ed 0 c3
:3 0 d3 :3 0 7ef
7f0 0 18 :2 0
2 :4 0 11f :2 0
d5 :2 0 2a :2 0
3d5 7f5 7f7 :3 0
3d8 7f1 7f9 7ee
7fb 7fa :2 0 c6
:3 0 d6 :3 0 7fd
7fe 0 c8 :4 0
120 :4 0 cb :2 0
cc :3 0 3dc 802
804 :3 0 cb :2 0
e9 :4 0 3df 806
808 :3 0 cb :2 0
f0 :4 0 3e2 80a
80c :3 0 cb :2 0
84 :3 0 d0 :3 0
b0 :3 0 f1 :3 0
811 812 0 3e5
810 814 d1 :4 0
3e7 80f 817 3ea
80e 819 :3 0 cb
:2 0 f2 :4 0 3ed
81b 81d :3 0 cb
:2 0 ce :4 0 3f0
81f 821 :3 0 cb
:2 0 20 :3 0 3f3
823 825 :3 0 cb
:2 0 ce :4 0 3f6
827 829 :3 0 3f9
7ff 82b :2 0 82d
3fc 82e 7fc 82d
0 82f 3fe 0
859 c3 :3 0 c4
:3 0 830 831 0
c3 :3 0 d3 :3 0
833 834 0 2a
:2 0 2 :4 0 121
:2 0 d5 :2 0 2a
:2 0 400 839 83b
:3 0 403 835 83d
832 83f 83e :2 0
c6 :3 0 d6 :3 0
841 842 0 c8
:4 0 122 :4 0 cb
:2 0 cc :3 0 407
846 848 :3 0 40a
843 84a :2 0 84c
40d 84d 840 84c
0 84e 40f 0
859 f5 :3 0 f6
:3 0 84f 850 0
b0 :3 0 f1 :3 0
852 853 0 20
:3 0 f7 :3 0 411
851 857 :2 0 859
415 85a 7eb 859
0 85b 419 0
4b22 123 :3 0 124
:3 0 36 :3 0 3a
:3 0 125 :3 0 92
:3 0 21 :4 0 126
1 :8 0 869 15
:3 0 e1 :3 0 864
865 0 e4 :3 0
866 867 0 869
41b 8b3 e5 :3 0
15 :3 0 e1 :3 0
86c 86d 0 e4
:3 0 86e 86f 0
8a9 c3 :3 0 c4
:3 0 871 872 0
c3 :3 0 d3 :3 0
874 875 0 e6
:2 0 2 :4 0 127
:2 0 d5 :2 0 2a
:2 0 41e 87a 87c
:3 0 421 876 87e
873 880 87f :2 0
c6 :3 0 d6 :3 0
882 883 0 c8
:4 0 128 :4 0 cb
:2 0 cc :3 0 425
887 889 :3 0 cb
:2 0 e9 :4 0 428
88b 88d :3 0 cb
:2 0 ea :4 0 42b
88f 891 :3 0 cb
:2 0 e4 :3 0 42e
893 895 :3 0 cb
:2 0 eb :4 0 431
897 899 :3 0 cb
:2 0 a0 :3 0 ec
:3 0 2a :2 0 ed
:2 0 434 89c 8a0
438 89b 8a2 :3 0
43b 884 8a4 :2 0
8a6 43e 8a7 881
8a6 0 8a8 440
0 8a9 442 8ac
:3 0 8ac 0 8ac
8ab 8a9 8aa :6 0
8ae d :3 0 445
8b0 447 8af 8ae
:2 0 8b1 449 :2 0
8b3 0 8b3 8b2
869 8b1 :6 0 4b22
1 :3 0 15 :3 0
e1 :3 0 8b5 8b6
0 15 :3 0 da
:2 0 100 :3 0 8b8
8ba 0 44d 8b9
8bc :3 0 8bd :2 0
c3 :3 0 c4 :3 0
8bf 8c0 0 c3
:3 0 d3 :3 0 8c2
8c3 0 18 :2 0
2 :4 0 129 :2 0
d5 :2 0 2a :2 0
450 8c8 8ca :3 0
453 8c4 8cc 8c1
8ce 8cd :2 0 c6
:3 0 d6 :3 0 8d0
8d1 0 c8 :4 0
12a :4 0 cb :2 0
cc :3 0 457 8d5
8d7 :3 0 cb :2 0
e9 :4 0 45a 8d9
8db :3 0 cb :2 0
f0 :4 0 45d 8dd
8df :3 0 cb :2 0
84 :3 0 d0 :3 0
b0 :3 0 f1 :3 0
8e4 8e5 0 460
8e3 8e7 d1 :4 0
462 8e2 8ea 465
8e1 8ec :3 0 cb
:2 0 f2 :4 0 468
8ee 8f0 :3 0 cb
:2 0 ce :4 0 46b
8f2 8f4 :3 0 cb
:2 0 21 :3 0 46e
8f6 8f8 :3 0 cb
:2 0 ce :4 0 471
8fa 8fc :3 0 474
8d2 8fe :2 0 900
477 901 8cf 900
0 902 479 0
92c c3 :3 0 c4
:3 0 903 904 0
c3 :3 0 d3 :3 0
906 907 0 2a
:2 0 2 :4 0 12b
:2 0 d5 :2 0 2a
:2 0 47b 90c 90e
:3 0 47e 908 910
905 912 911 :2 0
c6 :3 0 d6 :3 0
914 915 0 c8
:4 0 12c :4 0 cb
:2 0 cc :3 0 482
919 91b :3 0 485
916 91d :2 0 91f
488 920 913 91f
0 921 48a 0
92c f5 :3 0 f6
:3 0 922 923 0
b0 :3 0 f1 :3 0
925 926 0 21
:3 0 f7 :3 0 48c
924 92a :2 0 92c
490 92d 8be 92c
0 92e 494 0
4b22 12d :3 0 35
:3 0 12e :3 0 12f
:3 0 23 :4 0 130
1 :8 0 93a 15
:3 0 e1 :3 0 935
936 0 e4 :3 0
937 938 0 93a
496 984 e5 :3 0
15 :3 0 e1 :3 0
93d 93e 0 e4
:3 0 93f 940 0
97a c3 :3 0 c4
:3 0 942 943 0
c3 :3 0 d3 :3 0
945 946 0 e6
:2 0 2 :4 0 131
:2 0 d5 :2 0 2a
:2 0 499 94b 94d
:3 0 49c 947 94f
944 951 950 :2 0
c6 :3 0 d6 :3 0
953 954 0 c8
:4 0 132 :4 0 cb
:2 0 cc :3 0 4a0
958 95a :3 0 cb
:2 0 e9 :4 0 4a3
95c 95e :3 0 cb
:2 0 ea :4 0 4a6
960 962 :3 0 cb
:2 0 e4 :3 0 4a9
964 966 :3 0 cb
:2 0 eb :4 0 4ac
968 96a :3 0 cb
:2 0 a0 :3 0 ec
:3 0 2a :2 0 ed
:2 0 4af 96d 971
4b3 96c 973 :3 0
4b6 955 975 :2 0
977 4b9 978 952
977 0 979 4bb
0 97a 4bd 97d
:3 0 97d 0 97d
97c 97a 97b :6 0
97f f :3 0 4c0
981 4c2 980 97f
:2 0 982 4c4 :2 0
984 0 984 983
93a 982 :6 0 4b22
1 :3 0 116 :3 0
133 :3 0 986 987
0 35 :3 0 134
:4 0 4c6 988 98b
da :2 0 3d :2 0
4cb 98d 98f :3 0
35 :3 0 de :4 0
991 992 0 994
4ce 995 990 994
0 996 4d0 0
4b22 15 :3 0 e1
:3 0 997 998 0
15 :3 0 da :2 0
100 :3 0 99a 99c
0 4d4 99b 99e
:3 0 99f :2 0 c3
:3 0 c4 :3 0 9a1
9a2 0 c3 :3 0
d3 :3 0 9a4 9a5
0 18 :2 0 2
:4 0 135 :2 0 d5
:2 0 2a :2 0 4d7
9aa 9ac :3 0 4da
9a6 9ae 9a3 9b0
9af :2 0 c6 :3 0
d6 :3 0 9b2 9b3
0 c8 :4 0 136
:4 0 cb :2 0 cc
:3 0 4de 9b7 9b9
:3 0 cb :2 0 e9
:4 0 4e1 9bb 9bd
:3 0 cb :2 0 f0
:4 0 4e4 9bf 9c1
:3 0 cb :2 0 84
:3 0 d0 :3 0 b0
:3 0 f1 :3 0 9c6
9c7 0 4e7 9c5
9c9 d1 :4 0 4e9
9c4 9cc 4ec 9c3
9ce :3 0 cb :2 0
f2 :4 0 4ef 9d0
9d2 :3 0 cb :2 0
ce :4 0 4f2 9d4
9d6 :3 0 cb :2 0
23 :3 0 4f5 9d8
9da :3 0 cb :2 0
ce :4 0 4f8 9dc
9de :3 0 4fb 9b4
9e0 :2 0 9e2 4fe
9e3 9b1 9e2 0
9e4 500 0 a0e
c3 :3 0 c4 :3 0
9e5 9e6 0 c3
:3 0 d3 :3 0 9e8
9e9 0 2a :2 0
2 :4 0 137 :2 0
d5 :2 0 2a :2 0
502 9ee 9f0 :3 0
505 9ea 9f2 9e7
9f4 9f3 :2 0 c6
:3 0 d6 :3 0 9f6
9f7 0 c8 :4 0
138 :4 0 cb :2 0
cc :3 0 509 9fb
9fd :3 0 50c 9f8
9ff :2 0 a01 50f
a02 9f5 a01 0
a03 511 0 a0e
f5 :3 0 f6 :3 0
a04 a05 0 b0
:3 0 f1 :3 0 a07
a08 0 23 :3 0
f7 :3 0 513 a06
a0c :2 0 a0e 517
a0f 9a0 a0e 0
a10 51b 0 4b22
60 :3 0 12 :3 0
a11 a12 0 4b22
62 :3 0 d8 :3 0
84 :3 0 60 :3 0
3d :2 0 51d a16
a19 139 :2 0 520
a15 a1c a14 a1d
0 4b22 63 :3 0
d8 :3 0 84 :3 0
60 :3 0 3d :2 0
523 a21 a24 13a
:2 0 526 a20 a27
a1f a28 0 4b22
61 :3 0 d8 :3 0
84 :3 0 60 :3 0
3d :2 0 529 a2c
a2f 2a :2 0 52c
a2b a32 a2a a33
0 4b22 82 :3 0
13b :2 0 3d :2 0
531 a36 a38 :3 0
84 :3 0 63 :3 0
3d :2 0 534 a3a
a3d da :2 0 13a
:2 0 539 a3f a41
:3 0 13c :3 0 9a
:3 0 6b :3 0 90
:3 0 91 :3 0 22
:3 0 9b :3 0 22
:3 0 92 :3 0 21
:3 0 93 :4 0 13d
1 :8 0 a54 15
:3 0 e1 :3 0 a4f
a50 0 e4 :3 0
a51 a52 0 a54
53c a9e e5 :3 0
15 :3 0 e1 :3 0
a57 a58 0 e4
:3 0 a59 a5a 0
a94 c3 :3 0 c4
:3 0 a5c a5d 0
c3 :3 0 d3 :3 0
a5f a60 0 e6
:2 0 2 :4 0 13e
:2 0 d5 :2 0 2a
:2 0 53f a65 a67
:3 0 542 a61 a69
a5e a6b a6a :2 0
c6 :3 0 d6 :3 0
a6d a6e 0 c8
:4 0 13f :4 0 cb
:2 0 cc :3 0 546
a72 a74 :3 0 cb
:2 0 e9 :4 0 549
a76 a78 :3 0 cb
:2 0 ea :4 0 54c
a7a a7c :3 0 cb
:2 0 e4 :3 0 54f
a7e a80 :3 0 cb
:2 0 eb :4 0 552
a82 a84 :3 0 cb
:2 0 a0 :3 0 ec
:3 0 2a :2 0 ed
:2 0 555 a87 a8b
559 a86 a8d :3 0
55c a6f a8f :2 0
a91 55f a92 a6c
a91 0 a93 561
0 a94 563 a97
:3 0 a97 0 a97
a96 a94 a95 :6 0
a99 11 :3 0 566
a9b 568 a9a a99
:2 0 a9c 56a :2 0
a9e 0 a9e a9d
a54 a9c :6 0 aa1
1 :3 0 140 :3 0
56c b0a 84 :3 0
63 :3 0 3d :2 0
56e aa2 aa5 da
:2 0 3d :2 0 573
aa7 aa9 :3 0 13c
:3 0 9a :3 0 6b
:3 0 90 :3 0 91
:3 0 22 :3 0 9b
:3 0 91 :3 0 92
:3 0 21 :3 0 93
:4 0 141 1 :8 0
abc 15 :3 0 e1
:3 0 ab7 ab8 0
e4 :3 0 ab9 aba
0 abc 576 b06
e5 :3 0 15 :3 0
e1 :3 0 abf ac0
0 e4 :3 0 ac1
ac2 0 afc c3
:3 0 c4 :3 0 ac4
ac5 0 c3 :3 0
d3 :3 0 ac7 ac8
0 e6 :2 0 2
:4 0 142 :2 0 d5
:2 0 2a :2 0 579
acd acf :3 0 57c
ac9 ad1 ac6 ad3
ad2 :2 0 c6 :3 0
d6 :3 0 ad5 ad6
0 c8 :4 0 143
:4 0 cb :2 0 cc
:3 0 580 ada adc
:3 0 cb :2 0 e9
:4 0 583 ade ae0
:3 0 cb :2 0 ea
:4 0 586 ae2 ae4
:3 0 cb :2 0 e4
:3 0 589 ae6 ae8
:3 0 cb :2 0 eb
:4 0 58c aea aec
:3 0 cb :2 0 a0
:3 0 ec :3 0 2a
:2 0 ed :2 0 58f
aef af3 593 aee
af5 :3 0 596 ad7
af7 :2 0 af9 599
afa ad4 af9 0
afb 59b 0 afc
59d aff :3 0 aff
0 aff afe afc
afd :6 0 b01 13
:3 0 5a0 b03 5a2
b02 b01 :2 0 b04
5a4 :2 0 b06 0
b06 b05 abc b04
:6 0 b08 1 :3 0
5a6 b09 aaa b08
0 b0b a42 aa1
0 b0b 5a8 0
b85 84 :3 0 6b
:3 0 3d :2 0 5ab
b0c b0f 10a :2 0
3d :2 0 5b0 b11
b13 :3 0 c3 :3 0
c4 :3 0 b15 b16
0 c3 :3 0 d3
:3 0 b18 b19 0
18 :2 0 2 :4 0
144 :2 0 d5 :2 0
2a :2 0 5b3 b1e
b20 :3 0 5b6 b1a
b22 b17 b24 b23
:2 0 c6 :3 0 d6
:3 0 b26 b27 0
c8 :4 0 145 :4 0
cb :2 0 cc :3 0
5ba b2b b2d :3 0
cb :2 0 e9 :4 0
5bd b2f b31 :3 0
cb :2 0 f0 :4 0
5c0 b33 b35 :3 0
cb :2 0 84 :3 0
d0 :3 0 b0 :3 0
146 :3 0 b3a b3b
0 5c3 b39 b3d
d1 :4 0 5c5 b38
b40 5c8 b37 b42
:3 0 cb :2 0 f2
:4 0 5cb b44 b46
:3 0 cb :2 0 ce
:4 0 5ce b48 b4a
:3 0 cb :2 0 21
:3 0 5d1 b4c b4e
:3 0 cb :2 0 ce
:4 0 5d4 b50 b52
:3 0 5d7 b28 b54
:2 0 b56 5da b57
b25 b56 0 b58
5dc 0 b82 c3
:3 0 c4 :3 0 b59
b5a 0 c3 :3 0
d3 :3 0 b5c b5d
0 2a :2 0 2
:4 0 147 :2 0 d5
:2 0 2a :2 0 5de
b62 b64 :3 0 5e1
b5e b66 b5b b68
b67 :2 0 c6 :3 0
d6 :3 0 b6a b6b
0 c8 :4 0 148
:4 0 cb :2 0 cc
:3 0 5e5 b6f b71
:3 0 5e8 b6c b73
:2 0 b75 5eb b76
b69 b75 0 b77
5ed 0 b82 f5
:3 0 f6 :3 0 b78
b79 0 b0 :3 0
146 :3 0 b7b b7c
0 21 :3 0 f7
:3 0 5ef b7a b80
:2 0 b82 5f3 b83
b14 b82 0 b84
5f7 0 b85 5f9
d3f 13c :3 0 9a
:3 0 77 :3 0 90
:3 0 91 :3 0 22
:3 0 91 :3 0 9b
:3 0 92 :3 0 23
:3 0 93 :4 0 149
1 :8 0 b97 15
:3 0 e1 :3 0 b92
b93 0 e4 :3 0
b94 b95 0 b97
5fc be1 e5 :3 0
15 :3 0 e1 :3 0
b9a b9b 0 e4
:3 0 b9c b9d 0
bd7 c3 :3 0 c4
:3 0 b9f ba0 0
c3 :3 0 d3 :3 0
ba2 ba3 0 e6
:2 0 2 :4 0 14a
:2 0 d5 :2 0 2a
:2 0 5ff ba8 baa
:3 0 602 ba4 bac
ba1 bae bad :2 0
c6 :3 0 d6 :3 0
bb0 bb1 0 c8
:4 0 14b :4 0 cb
:2 0 cc :3 0 606
bb5 bb7 :3 0 cb
:2 0 e9 :4 0 609
bb9 bbb :3 0 cb
:2 0 ea :4 0 60c
bbd bbf :3 0 cb
:2 0 e4 :3 0 60f
bc1 bc3 :3 0 cb
:2 0 eb :4 0 612
bc5 bc7 :3 0 cb
:2 0 a0 :3 0 ec
:3 0 2a :2 0 ed
:2 0 615 bca bce
619 bc9 bd0 :3 0
61c bb2 bd2 :2 0
bd4 61f bd5 baf
bd4 0 bd6 621
0 bd7 623 bda
:3 0 bda 0 bda
bd9 bd7 bd8 :6 0
bdc 15 :3 0 626
bde 628 bdd bdc
:2 0 bdf 62a :2 0
be1 0 be1 be0
b97 bdf :6 0 d3e
1 :3 0 13c :3 0
9a :3 0 76 :3 0
90 :3 0 91 :3 0
22 :3 0 91 :3 0
9b :3 0 92 :3 0
23 :3 0 93 :4 0
14c 1 :8 0 bf4
15 :3 0 e1 :3 0
bef bf0 0 e4
:3 0 bf1 bf2 0
bf4 62c c3e e5
:3 0 15 :3 0 e1
:3 0 bf7 bf8 0
e4 :3 0 bf9 bfa
0 c34 c3 :3 0
c4 :3 0 bfc bfd
0 c3 :3 0 d3
:3 0 bff c00 0
e6 :2 0 2 :4 0
14d :2 0 d5 :2 0
2a :2 0 62f c05
c07 :3 0 632 c01
c09 bfe c0b c0a
:2 0 c6 :3 0 d6
:3 0 c0d c0e 0
c8 :4 0 14e :4 0
cb :2 0 cc :3 0
636 c12 c14 :3 0
cb :2 0 e9 :4 0
639 c16 c18 :3 0
cb :2 0 ea :4 0
63c c1a c1c :3 0
cb :2 0 e4 :3 0
63f c1e c20 :3 0
cb :2 0 eb :4 0
642 c22 c24 :3 0
cb :2 0 a0 :3 0
ec :3 0 2a :2 0
ed :2 0 645 c27
c2b 649 c26 c2d
:3 0 64c c0f c2f
:2 0 c31 64f c32
c0c c31 0 c33
651 0 c34 653
c37 :3 0 c37 0
c37 c36 c34 c35
:6 0 c39 17 :3 0
656 c3b 658 c3a
c39 :2 0 c3c 65a
:2 0 c3e 0 c3e
c3d bf4 c3c :6 0
d3e 1 :3 0 14f
:3 0 84 :3 0 42
:3 0 3d :2 0 65c
c41 c44 65f c40
c46 c47 :2 0 13b
:2 0 3d :2 0 663
c49 c4b :3 0 84
:3 0 63 :3 0 3d
:2 0 666 c4d c50
da :2 0 3d :2 0
66b c52 c54 :3 0
c55 :2 0 84 :3 0
77 :3 0 3d :2 0
66e c57 c5a da
:2 0 3d :2 0 673
c5c c5e :3 0 c5f
:2 0 c56 c61 c60
:2 0 c62 :2 0 c4c
c64 c63 :2 0 13c
:3 0 9a :3 0 6b
:3 0 90 :3 0 91
:3 0 22 :3 0 92
:3 0 21 :3 0 93
:3 0 94 :4 0 150
1 :8 0 c76 15
:3 0 e1 :3 0 c71
c72 0 e4 :3 0
c73 c74 0 c76
676 cc0 e5 :3 0
15 :3 0 e1 :3 0
c79 c7a 0 e4
:3 0 c7b c7c 0
cb6 c3 :3 0 c4
:3 0 c7e c7f 0
c3 :3 0 d3 :3 0
c81 c82 0 e6
:2 0 2 :4 0 151
:2 0 d5 :2 0 2a
:2 0 679 c87 c89
:3 0 67c c83 c8b
c80 c8d c8c :2 0
c6 :3 0 d6 :3 0
c8f c90 0 c8
:4 0 152 :4 0 cb
:2 0 cc :3 0 680
c94 c96 :3 0 cb
:2 0 e9 :4 0 683
c98 c9a :3 0 cb
:2 0 ea :4 0 686
c9c c9e :3 0 cb
:2 0 e4 :3 0 689
ca0 ca2 :3 0 cb
:2 0 eb :4 0 68c
ca4 ca6 :3 0 cb
:2 0 a0 :3 0 ec
:3 0 2a :2 0 ed
:2 0 68f ca9 cad
693 ca8 caf :3 0
696 c91 cb1 :2 0
cb3 699 cb4 c8e
cb3 0 cb5 69b
0 cb6 69d cb9
:3 0 cb9 0 cb9
cb8 cb6 cb7 :6 0
cbb 19 :3 0 6a0
cbd 6a2 cbc cbb
:2 0 cbe 6a4 :2 0
cc0 0 cc0 cbf
c76 cbe :6 0 d3b
1 :3 0 84 :3 0
6b :3 0 3d :2 0
6a6 cc2 cc5 10a
:2 0 3d :2 0 6ab
cc7 cc9 :3 0 c3
:3 0 c4 :3 0 ccb
ccc 0 c3 :3 0
d3 :3 0 cce ccf
0 18 :2 0 2
:4 0 153 :2 0 d5
:2 0 2a :2 0 6ae
cd4 cd6 :3 0 6b1
cd0 cd8 ccd cda
cd9 :2 0 c6 :3 0
d6 :3 0 cdc cdd
0 c8 :4 0 154
:4 0 cb :2 0 cc
:3 0 6b5 ce1 ce3
:3 0 cb :2 0 e9
:4 0 6b8 ce5 ce7
:3 0 cb :2 0 f0
:4 0 6bb ce9 ceb
:3 0 cb :2 0 84
:3 0 d0 :3 0 b0
:3 0 146 :3 0 cf0
cf1 0 6be cef
cf3 d1 :4 0 6c0
cee cf6 6c3 ced
cf8 :3 0 cb :2 0
f2 :4 0 6c6 cfa
cfc :3 0 cb :2 0
ce :4 0 6c9 cfe
d00 :3 0 cb :2 0
21 :3 0 6cc d02
d04 :3 0 cb :2 0
ce :4 0 6cf d06
d08 :3 0 6d2 cde
d0a :2 0 d0c 6d5
d0d cdb d0c 0
d0e 6d7 0 d38
c3 :3 0 c4 :3 0
d0f d10 0 c3
:3 0 d3 :3 0 d12
d13 0 2a :2 0
2 :4 0 155 :2 0
d5 :2 0 2a :2 0
6d9 d18 d1a :3 0
6dc d14 d1c d11
d1e d1d :2 0 c6
:3 0 d6 :3 0 d20
d21 0 c8 :4 0
156 :4 0 cb :2 0
cc :3 0 6e0 d25
d27 :3 0 6e3 d22
d29 :2 0 d2b 6e6
d2c d1f d2b 0
d2d 6e8 0 d38
f5 :3 0 f6 :3 0
d2e d2f 0 b0
:3 0 146 :3 0 d31
d32 0 21 :3 0
f7 :3 0 6ea d30
d36 :2 0 d38 6ee
d39 cca d38 0
d3a 6f2 0 d3b
6f4 d3c c65 d3b
0 d3d 6f7 0
d3e 6f9 d40 a39
b85 0 d41 0
d3e 0 d41 6fd
0 4b22 2e :3 0
3d :4 0 d42 d43
0 4b22 1b :3 0
de :4 0 d45 d46
0 4b22 1c :3 0
de :4 0 d48 d49
0 4b22 1e :4 0
d4b d4c 0 4b22
24 :4 0 d4e d4f
0 4b22 df :3 0
8e :4 0 d54 :2 0
4b22 d52 d55 :3 0
8e :3 0 56 :4 0
d59 :2 0 4b22 d56
d57 :3 0 8e :3 0
e0 :3 0 d5a d5b
:3 0 15 :3 0 e1
:3 0 d5d d5e 0
3d :2 0 d5f d60
0 d62 700 d69
15 :3 0 e1 :3 0
d63 d64 0 e2
:2 0 d65 d66 0
d68 702 d6a d5c
d62 0 d6b 0
d68 0 d6b 704
0 4b22 15 :3 0
e1 :3 0 d6c d6d
0 15 :3 0 da
:2 0 157 :3 0 d6f
d71 0 709 d70
d73 :3 0 d74 :2 0
4c :3 0 3d :2 0
d76 d77 0 d79
70c d7e 4c :3 0
13a :2 0 d7a d7b
0 d7d 70e d7f
d75 d79 0 d80
0 d7d 0 d80
710 0 4b22 e3
:3 0 8e :4 0 d84
:2 0 d8a d82 0
15 :3 0 e1 :3 0
d85 d86 0 e4
:3 0 d87 d88 0
d8a 713 dd4 e5
:3 0 15 :3 0 e1
:3 0 d8d d8e 0
e4 :3 0 d8f d90
0 dca c3 :3 0
c4 :3 0 d92 d93
0 c3 :3 0 d3
:3 0 d95 d96 0
e6 :2 0 2 :4 0
158 :2 0 d5 :2 0
2a :2 0 716 d9b
d9d :3 0 719 d97
d9f d94 da1 da0
:2 0 c6 :3 0 d6
:3 0 da3 da4 0
c8 :4 0 159 :4 0
cb :2 0 cc :3 0
71d da8 daa :3 0
cb :2 0 e9 :4 0
720 dac dae :3 0
cb :2 0 ea :4 0
723 db0 db2 :3 0
cb :2 0 e4 :3 0
726 db4 db6 :3 0
cb :2 0 eb :4 0
729 db8 dba :3 0
cb :2 0 a0 :3 0
ec :3 0 2a :2 0
ed :2 0 72c dbd
dc1 730 dbc dc3
:3 0 733 da5 dc5
:2 0 dc7 736 dc8
da2 dc7 0 dc9
738 0 dca 73a
dcd :3 0 dcd 0
dcd dcc dca dcb
:6 0 dcf 1b :3 0
73d dd1 73f dd0
dcf :2 0 dd2 741
:2 0 dd4 0 dd4
dd3 d8a dd2 :6 0
4b22 1 :3 0 84
:3 0 4c :3 0 3d
:2 0 743 dd6 dd9
da :2 0 13a :2 0
748 ddb ddd :3 0
13c :3 0 9a :3 0
56 :3 0 90 :3 0
91 :3 0 22 :3 0
92 :3 0 21 :3 0
93 :3 0 9b :3 0
22 :4 0 15a 1
:8 0 df0 15 :3 0
e1 :3 0 deb dec
0 e4 :3 0 ded
dee 0 df0 74b
e3a e5 :3 0 15
:3 0 e1 :3 0 df3
df4 0 e4 :3 0
df5 df6 0 e30
c3 :3 0 c4 :3 0
df8 df9 0 c3
:3 0 d3 :3 0 dfb
dfc 0 e6 :2 0
2 :4 0 15b :2 0
d5 :2 0 2a :2 0
74e e01 e03 :3 0
751 dfd e05 dfa
e07 e06 :2 0 c6
:3 0 d6 :3 0 e09
e0a 0 c8 :4 0
15c :4 0 cb :2 0
cc :3 0 755 e0e
e10 :3 0 cb :2 0
e9 :4 0 758 e12
e14 :3 0 cb :2 0
ea :4 0 75b e16
e18 :3 0 cb :2 0
e4 :3 0 75e e1a
e1c :3 0 cb :2 0
eb :4 0 761 e1e
e20 :3 0 cb :2 0
a0 :3 0 ec :3 0
2a :2 0 ed :2 0
764 e23 e27 768
e22 e29 :3 0 76b
e0b e2b :2 0 e2d
76e e2e e08 e2d
0 e2f 770 0
e30 772 e33 :3 0
e33 0 e33 e32
e30 e31 :6 0 e35
1d :3 0 775 e37
777 e36 e35 :2 0
e38 779 :2 0 e3a
0 e3a e39 df0
e38 :6 0 150c 1
:3 0 84 :3 0 56
:3 0 3d :2 0 77b
e3c e3f 10a :2 0
3d :2 0 780 e41
e43 :3 0 4c :3 0
2a :2 0 e45 e46
0 fbe a1 :3 0
a2 :3 0 33 :3 0
34 :3 0 90 :3 0
91 :3 0 22 :3 0
15d :3 0 92 :3 0
21 :3 0 93 :3 0
9b :3 0 22 :4 0
15e 1 :8 0 e5b
15 :3 0 e1 :3 0
e56 e57 0 e4
:3 0 e58 e59 0
e5b 783 ea5 e5
:3 0 15 :3 0 e1
:3 0 e5e e5f 0
e4 :3 0 e60 e61
0 e9b c3 :3 0
c4 :3 0 e63 e64
0 c3 :3 0 d3
:3 0 e66 e67 0
e6 :2 0 2 :4 0
15f :2 0 d5 :2 0
2a :2 0 786 e6c
e6e :3 0 789 e68
e70 e65 e72 e71
:2 0 c6 :3 0 d6
:3 0 e74 e75 0
c8 :4 0 160 :4 0
cb :2 0 cc :3 0
78d e79 e7b :3 0
cb :2 0 e9 :4 0
790 e7d e7f :3 0
cb :2 0 ea :4 0
793 e81 e83 :3 0
cb :2 0 e4 :3 0
796 e85 e87 :3 0
cb :2 0 eb :4 0
799 e89 e8b :3 0
cb :2 0 a0 :3 0
ec :3 0 2a :2 0
ed :2 0 79c e8e
e92 7a0 e8d e94
:3 0 7a3 e76 e96
:2 0 e98 7a6 e99
e73 e98 0 e9a
7a8 0 e9b 7aa
e9e :3 0 e9e 0
e9e e9d e9b e9c
:6 0 ea0 1f :3 0
7ad ea2 7af ea1
ea0 :2 0 ea3 7b1
:2 0 ea5 0 ea5
ea4 e5b ea3 :6 0
fbe 1 :3 0 15
:3 0 e1 :3 0 ea7
ea8 0 15 :3 0
da :2 0 100 :3 0
eaa eac 0 7b5
eab eae :3 0 eaf
:2 0 c3 :3 0 c4
:3 0 eb1 eb2 0
c3 :3 0 d3 :3 0
eb4 eb5 0 18
:2 0 2 :4 0 161
:2 0 d5 :2 0 2a
:2 0 7b8 eba ebc
:3 0 7bb eb6 ebe
eb3 ec0 ebf :2 0
c6 :3 0 d6 :3 0
ec2 ec3 0 c8
:4 0 162 :4 0 cb
:2 0 cc :3 0 7bf
ec7 ec9 :3 0 cb
:2 0 e9 :4 0 7c2
ecb ecd :3 0 cb
:2 0 f0 :4 0 7c5
ecf ed1 :3 0 cb
:2 0 84 :3 0 d0
:3 0 b0 :3 0 146
:3 0 ed6 ed7 0
7c8 ed5 ed9 d1
:4 0 7ca ed4 edc
7cd ed3 ede :3 0
cb :2 0 f2 :4 0
7d0 ee0 ee2 :3 0
cb :2 0 ce :4 0
7d3 ee4 ee6 :3 0
cb :2 0 21 :3 0
7d6 ee8 eea :3 0
cb :2 0 ce :4 0
7d9 eec eee :3 0
7dc ec4 ef0 :2 0
ef2 7df ef3 ec1
ef2 0 ef4 7e1
0 f1f c3 :3 0
c4 :3 0 ef5 ef6
0 c3 :3 0 d3
:3 0 ef8 ef9 0
2a :2 0 2 :4 0
163 :2 0 d5 :2 0
2a :2 0 7e3 efe
f00 :3 0 7e6 efa
f02 ef7 f04 f03
:2 0 c6 :3 0 d6
:3 0 f06 f07 0
c8 :4 0 164 :4 0
cb :2 0 cc :3 0
7ea f0b f0d :3 0
7ed f08 f0f :2 0
f11 7f0 f12 f05
f11 0 f13 7f2
0 f1f f5 :3 0
f6 :3 0 f14 f15
0 b0 :3 0 146
:3 0 f17 f18 0
21 :3 0 f7 :3 0
7f4 f16 f1c :2 0
f1f 140 :3 0 7f8
fbc 33 :3 0 165
:2 0 7fc f21 f22
:3 0 f23 :2 0 f24
:2 0 34 :3 0 165
:2 0 7fe f27 f28
:3 0 f29 :2 0 f2a
:2 0 f25 f2c f2b
:2 0 116 :3 0 166
:3 0 f2e f2f 0
33 :3 0 24 :3 0
167 :2 0 800 f30
f34 10a :2 0 3d
:2 0 806 f36 f38
:3 0 f39 :2 0 116
:3 0 166 :3 0 f3b
f3c 0 34 :3 0
24 :3 0 167 :2 0
809 f3d f41 168
:2 0 3d :2 0 80f
f43 f45 :3 0 f46
:2 0 f3a f48 f47
:2 0 c3 :3 0 c4
:3 0 f4a f4b 0
c3 :3 0 d3 :3 0
f4d f4e 0 18
:2 0 2 :4 0 169
:2 0 d5 :2 0 2a
:2 0 812 f53 f55
:3 0 815 f4f f57
f4c f59 f58 :2 0
c6 :3 0 d6 :3 0
f5b f5c 0 c8
:4 0 16a :4 0 cb
:2 0 cc :3 0 819
f60 f62 :3 0 cb
:2 0 e9 :4 0 81c
f64 f66 :3 0 cb
:2 0 f0 :4 0 81f
f68 f6a :3 0 cb
:2 0 84 :3 0 d0
:3 0 b0 :3 0 146
:3 0 f6f f70 0
822 f6e f72 d1
:4 0 824 f6d f75
827 f6c f77 :3 0
cb :2 0 f2 :4 0
82a f79 f7b :3 0
cb :2 0 ce :4 0
82d f7d f7f :3 0
cb :2 0 21 :3 0
830 f81 f83 :3 0
cb :2 0 ce :4 0
833 f85 f87 :3 0
836 f5d f89 :2 0
f8b 839 f8c f5a
f8b 0 f8d 83b
0 fb7 c3 :3 0
c4 :3 0 f8e f8f
0 c3 :3 0 d3
:3 0 f91 f92 0
2a :2 0 2 :4 0
16b :2 0 d5 :2 0
2a :2 0 83d f97
f99 :3 0 840 f93
f9b f90 f9d f9c
:2 0 c6 :3 0 d6
:3 0 f9f fa0 0
c8 :4 0 16c :4 0
cb :2 0 cc :3 0
844 fa4 fa6 :3 0
847 fa1 fa8 :2 0
faa 84a fab f9e
faa 0 fac 84c
0 fb7 f5 :3 0
f6 :3 0 fad fae
0 b0 :3 0 146
:3 0 fb0 fb1 0
21 :3 0 f7 :3 0
84e faf fb5 :2 0
fb7 852 fb8 f49
fb7 0 fb9 856
0 fba 858 fbb
f2d fba 0 fbd
eb0 f1f 0 fbd
85a 0 fbe 85d
fbf e44 fbe 0
fc0 861 0 150c
84 :3 0 63 :3 0
3d :2 0 863 fc1
fc4 da :2 0 13a
:2 0 868 fc6 fc8
:3 0 4c :3 0 3d
:2 0 fca fcb 0
fd0 1e :3 0 1e
:3 0 fcd fce 0
fd0 86b 1509 98
:3 0 16d :3 0 1c
:3 0 55 :3 0 af
:3 0 8b :3 0 22
:3 0 93 :3 0 2e
:3 0 92 :3 0 21
:4 0 16e 1 :8 0
fe2 15 :3 0 e1
:3 0 fdd fde 0
e4 :3 0 fdf fe0
0 fe2 86e 102c
e5 :3 0 15 :3 0
e1 :3 0 fe5 fe6
0 e4 :3 0 fe7
fe8 0 1022 c3
:3 0 c4 :3 0 fea
feb 0 c3 :3 0
d3 :3 0 fed fee
0 e6 :2 0 2
:4 0 16f :2 0 d5
:2 0 2a :2 0 871
ff3 ff5 :3 0 874
fef ff7 fec ff9
ff8 :2 0 c6 :3 0
d6 :3 0 ffb ffc
0 c8 :4 0 170
:4 0 cb :2 0 cc
:3 0 878 1000 1002
:3 0 cb :2 0 e9
:4 0 87b 1004 1006
:3 0 cb :2 0 ea
:4 0 87e 1008 100a
:3 0 cb :2 0 e4
:3 0 881 100c 100e
:3 0 cb :2 0 eb
:4 0 884 1010 1012
:3 0 cb :2 0 a0
:3 0 ec :3 0 2a
:2 0 ed :2 0 887
1015 1019 88b 1014
101b :3 0 88e ffd
101d :2 0 101f 891
1020 ffa 101f 0
1021 893 0 1022
895 1025 :3 0 1025
0 1025 1024 1022
1023 :6 0 1027 21
:3 0 898 1029 89a
1028 1027 :2 0 102a
89c :2 0 102c 0
102c 102b fe2 102a
:6 0 1508 1 :3 0
15 :3 0 e1 :3 0
102e 102f 0 15
:3 0 da :2 0 100
:3 0 1031 1033 0
8a0 1032 1035 :3 0
1036 :2 0 1c :3 0
de :4 0 1038 1039
0 1315 1c :3 0
171 :4 0 103c 103d
:3 0 103b 103e 0
1315 71 :3 0 172
:3 0 3d :2 0 84
:3 0 41 :3 0 3d
:2 0 8a3 1043 1046
b0 :3 0 173 :3 0
1048 1049 0 6e
:3 0 8a6 1041 104c
1040 104d 0 1315
6d :3 0 b0 :3 0
174 :3 0 1050 1051
0 104f 1052 0
1315 6c :3 0 3d
:4 0 1054 1055 0
1315 70 :3 0 2a
:2 0 1057 1058 0
1315 71 :3 0 175
:3 0 22 :3 0 21
:3 0 41 :3 0 6d
:3 0 6e :3 0 6c
:3 0 70 :3 0 8ab
105b 1063 105a 1064
0 1315 7b :3 0
176 :3 0 84 :3 0
41 :3 0 3d :2 0
8b3 1068 106b 8b6
1067 106d 1066 106e
0 1315 af :3 0
98 :3 0 91 :3 0
8b :3 0 9c :3 0
93 :3 0 92 :3 0
12f :3 0 16d :3 0
177 :3 0 178 :3 0
179 :3 0 17a :3 0
1c :3 0 22 :3 0
22 :3 0 41 :3 0
2e :3 0 21 :3 0
23 :3 0 b0 :3 0
174 :3 0 6e :3 0
7b :3 0 13 :3 0
cc :4 0 17b 1
:8 0 10a0 e0 :4 0
108b :3 0 f7 :3 0
da :2 0 8ba 108e
108f :3 0 15 :3 0
e1 :3 0 1091 1092
0 3d :2 0 1093
1094 0 1096 8bd
109d 15 :3 0 e1
:3 0 1097 1098 0
e2 :2 0 1099 109a
0 109c 8bf 109e
1090 1096 0 109f
0 109c 0 109f
8c1 0 10a0 8c4
10ea e5 :3 0 15
:3 0 e1 :3 0 10a3
10a4 0 e4 :3 0
10a5 10a6 0 10e0
c3 :3 0 c4 :3 0
10a8 10a9 0 c3
:3 0 d3 :3 0 10ab
10ac 0 e6 :2 0
2 :4 0 17c :2 0
d5 :2 0 2a :2 0
8c7 10b1 10b3 :3 0
8ca 10ad 10b5 10aa
10b7 10b6 :2 0 c6
:3 0 d6 :3 0 10b9
10ba 0 c8 :4 0
17d :4 0 cb :2 0
cc :3 0 8ce 10be
10c0 :3 0 cb :2 0
e9 :4 0 8d1 10c2
10c4 :3 0 cb :2 0
ea :4 0 8d4 10c6
10c8 :3 0 cb :2 0
e4 :3 0 8d7 10ca
10cc :3 0 cb :2 0
eb :4 0 8da 10ce
10d0 :3 0 cb :2 0
a0 :3 0 ec :3 0
2a :2 0 ed :2 0
8dd 10d3 10d7 8e1
10d2 10d9 :3 0 8e4
10bb 10db :2 0 10dd
8e7 10de 10b8 10dd
0 10df 8e9 0
10e0 8eb 10e3 :3 0
10e3 0 10e3 10e2
10e0 10e1 :6 0 10e5
23 :3 0 8ee 10e7
8f0 10e6 10e5 :2 0
10e8 8f2 :2 0 10ea
0 10ea 10e9 10a0
10e8 :6 0 1315 1
:3 0 17e :3 0 39
:3 0 12e :3 0 12f
:3 0 23 :4 0 17f
1 :8 0 10f7 15
:3 0 e1 :3 0 10f2
10f3 0 e4 :3 0
10f4 10f5 0 10f7
8f4 1141 e5 :3 0
15 :3 0 e1 :3 0
10fa 10fb 0 e4
:3 0 10fc 10fd 0
1137 c3 :3 0 c4
:3 0 10ff 1100 0
c3 :3 0 d3 :3 0
1102 1103 0 e6
:2 0 2 :4 0 180
:2 0 d5 :2 0 2a
:2 0 8f7 1108 110a
:3 0 8fa 1104 110c
1101 110e 110d :2 0
c6 :3 0 d6 :3 0
1110 1111 0 c8
:4 0 181 :4 0 cb
:2 0 cc :3 0 8fe
1115 1117 :3 0 cb
:2 0 e9 :4 0 901
1119 111b :3 0 cb
:2 0 ea :4 0 904
111d 111f :3 0 cb
:2 0 e4 :3 0 907
1121 1123 :3 0 cb
:2 0 eb :4 0 90a
1125 1127 :3 0 cb
:2 0 a0 :3 0 ec
:3 0 2a :2 0 ed
:2 0 90d 112a 112e
911 1129 1130 :3 0
914 1112 1132 :2 0
1134 917 1135 110f
1134 0 1136 919
0 1137 91b 113a
:3 0 113a 0 113a
1139 1137 1138 :6 0
113c 25 :3 0 91e
113e 920 113d 113c
:2 0 113f 922 :2 0
1141 0 1141 1140
10f7 113f :6 0 1315
1 :3 0 116 :3 0
133 :3 0 1143 1144
0 22 :3 0 20
:3 0 924 1145 1148
da :2 0 3d :2 0
929 114a 114c :3 0
43 :3 0 3d :2 0
114e 114f 0 1151
92c 11b1 13c :3 0
9a :3 0 43 :3 0
90 :3 0 91 :3 0
22 :3 0 9b :3 0
20 :3 0 93 :3 0
92 :3 0 23 :3 0
15d :4 0 182 1
:8 0 1164 15 :3 0
e1 :3 0 115f 1160
0 e4 :3 0 1161
1162 0 1164 92e
11ae e5 :3 0 15
:3 0 e1 :3 0 1167
1168 0 e4 :3 0
1169 116a 0 11a4
c3 :3 0 c4 :3 0
116c 116d 0 c3
:3 0 d3 :3 0 116f
1170 0 e6 :2 0
2 :4 0 183 :2 0
d5 :2 0 2a :2 0
931 1175 1177 :3 0
934 1171 1179 116e
117b 117a :2 0 c6
:3 0 d6 :3 0 117d
117e 0 c8 :4 0
184 :4 0 cb :2 0
cc :3 0 938 1182
1184 :3 0 cb :2 0
e9 :4 0 93b 1186
1188 :3 0 cb :2 0
ea :4 0 93e 118a
118c :3 0 cb :2 0
e4 :3 0 941 118e
1190 :3 0 cb :2 0
eb :4 0 944 1192
1194 :3 0 cb :2 0
a0 :3 0 ec :3 0
2a :2 0 ed :2 0
947 1197 119b 94b
1196 119d :3 0 94e
117f 119f :2 0 11a1
951 11a2 117c 11a1
0 11a3 953 0
11a4 955 11a7 :3 0
11a7 0 11a7 11a6
11a4 11a5 :6 0 11a9
27 :3 0 958 11ab
95a 11aa 11a9 :2 0
11ac 95c :2 0 11ae
0 11ae 11ad 1164
11ac :6 0 11b0 1
:3 0 95e 11b2 114d
1151 0 11b3 0
11b0 0 11b3 960
0 1315 84 :3 0
43 :3 0 3d :2 0
963 11b4 11b7 da
:2 0 3d :2 0 968
11b9 11bb :3 0 ae
:3 0 185 :3 0 186
:3 0 185 :3 0 39
:3 0 36 :3 0 8b
:3 0 22 :3 0 91
:3 0 22 :4 0 187
1 :8 0 11dd e0
:4 0 11c8 :3 0 f7
:3 0 da :2 0 96d
11cb 11cc :3 0 15
:3 0 e1 :3 0 11ce
11cf 0 3d :2 0
11d0 11d1 0 11d3
970 11da 15 :3 0
e1 :3 0 11d4 11d5
0 e2 :2 0 11d6
11d7 0 11d9 972
11db 11cd 11d3 0
11dc 0 11d9 0
11dc 974 0 11dd
977 1227 e5 :3 0
15 :3 0 e1 :3 0
11e0 11e1 0 e4
:3 0 11e2 11e3 0
121d c3 :3 0 c4
:3 0 11e5 11e6 0
c3 :3 0 d3 :3 0
11e8 11e9 0 e6
:2 0 2 :4 0 188
:2 0 d5 :2 0 2a
:2 0 97a 11ee 11f0
:3 0 97d 11ea 11f2
11e7 11f4 11f3 :2 0
c6 :3 0 d6 :3 0
11f6 11f7 0 c8
:4 0 189 :4 0 cb
:2 0 cc :3 0 981
11fb 11fd :3 0 cb
:2 0 e9 :4 0 984
11ff 1201 :3 0 cb
:2 0 ea :4 0 987
1203 1205 :3 0 cb
:2 0 e4 :3 0 98a
1207 1209 :3 0 cb
:2 0 eb :4 0 98d
120b 120d :3 0 cb
:2 0 a0 :3 0 ec
:3 0 2a :2 0 ed
:2 0 990 1210 1214
994 120f 1216 :3 0
997 11f8 1218 :2 0
121a 99a 121b 11f5
121a 0 121c 99c
0 121d 99e 1220
:3 0 1220 0 1220
121f 121d 121e :6 0
1222 29 :3 0 9a1
1224 9a3 1223 1222
:2 0 1225 9a5 :2 0
1227 0 1227 1226
11dd 1225 :6 0 129c
1 :3 0 ae :3 0
185 :3 0 18a :3 0
185 :3 0 36 :3 0
185 :3 0 18b :3 0
36 :3 0 18b :3 0
185 :3 0 185 :3 0
185 :3 0 36 :3 0
91 :3 0 22 :3 0
8b :3 0 22 :4 0
18c 1 :8 0 1250
e0 :4 0 123b :3 0
f7 :3 0 da :2 0
9a9 123e 123f :3 0
15 :3 0 e1 :3 0
1241 1242 0 3d
:2 0 1243 1244 0
1246 9ac 124d 15
:3 0 e1 :3 0 1247
1248 0 e2 :2 0
1249 124a 0 124c
9ae 124e 1240 1246
0 124f 0 124c
0 124f 9b0 0
1250 9b3 129a e5
:3 0 15 :3 0 e1
:3 0 1253 1254 0
e4 :3 0 1255 1256
0 1290 c3 :3 0
c4 :3 0 1258 1259
0 c3 :3 0 d3
:3 0 125b 125c 0
e6 :2 0 2 :4 0
18d :2 0 d5 :2 0
2a :2 0 9b6 1261
1263 :3 0 9b9 125d
1265 125a 1267 1266
:2 0 c6 :3 0 d6
:3 0 1269 126a 0
c8 :4 0 18e :4 0
cb :2 0 cc :3 0
9bd 126e 1270 :3 0
cb :2 0 e9 :4 0
9c0 1272 1274 :3 0
cb :2 0 ea :4 0
9c3 1276 1278 :3 0
cb :2 0 e4 :3 0
9c6 127a 127c :3 0
cb :2 0 eb :4 0
9c9 127e 1280 :3 0
cb :2 0 a0 :3 0
ec :3 0 2a :2 0
ed :2 0 9cc 1283
1287 9d0 1282 1289
:3 0 9d3 126b 128b
:2 0 128d 9d6 128e
1268 128d 0 128f
9d8 0 1290 9da
1293 :3 0 1293 0
1293 1292 1290 1291
:6 0 1295 2b :3 0
9dd 1297 9df 1296
1295 :2 0 1298 9e1
:2 0 129a 0 129a
1299 1250 1298 :6 0
129c 1 :3 0 9e3
1311 ae :3 0 185
:3 0 18a :3 0 185
:3 0 36 :3 0 185
:3 0 18b :3 0 36
:3 0 18b :3 0 185
:3 0 185 :3 0 185
:3 0 36 :3 0 91
:3 0 22 :3 0 8b
:3 0 22 :4 0 18c
1 :8 0 12c4 e0
:4 0 12af :3 0 f7
:3 0 da :2 0 9e8
12b2 12b3 :3 0 15
:3 0 e1 :3 0 12b5
12b6 0 3d :2 0
12b7 12b8 0 12ba
9eb 12c1 15 :3 0
e1 :3 0 12bb 12bc
0 e2 :2 0 12bd
12be 0 12c0 9ed
12c2 12b4 12ba 0
12c3 0 12c0 0
12c3 9ef 0 12c4
9f2 130e e5 :3 0
15 :3 0 e1 :3 0
12c7 12c8 0 e4
:3 0 12c9 12ca 0
1304 c3 :3 0 c4
:3 0 12cc 12cd 0
c3 :3 0 d3 :3 0
12cf 12d0 0 e6
:2 0 2 :4 0 18f
:2 0 d5 :2 0 2a
:2 0 9f5 12d5 12d7
:3 0 9f8 12d1 12d9
12ce 12db 12da :2 0
c6 :3 0 d6 :3 0
12dd 12de 0 c8
:4 0 190 :4 0 cb
:2 0 cc :3 0 9fc
12e2 12e4 :3 0 cb
:2 0 e9 :4 0 9ff
12e6 12e8 :3 0 cb
:2 0 ea :4 0 a02
12ea 12ec :3 0 cb
:2 0 e4 :3 0 a05
12ee 12f0 :3 0 cb
:2 0 eb :4 0 a08
12f2 12f4 :3 0 cb
:2 0 a0 :3 0 ec
:3 0 2a :2 0 ed
:2 0 a0b 12f7 12fb
a0f 12f6 12fd :3 0
a12 12df 12ff :2 0
1301 a15 1302 12dc
1301 0 1303 a17
0 1304 a19 1307
:3 0 1307 0 1307
1306 1304 1305 :6 0
1309 2d :3 0 a1c
130b a1e 130a 1309
:2 0 130c a20 :2 0
130e 0 130e 130d
12c4 130c :6 0 1310
1 :3 0 a22 1312
11bc 129c 0 1313
0 1310 0 1313
a24 0 1315 140
:3 0 a27 1506 15
:3 0 e1 :3 0 1316
1317 0 15 :3 0
da :2 0 157 :3 0
1319 131b 0 a36
131a 131d :3 0 131e
:2 0 9a :3 0 1e
:3 0 90 :3 0 98
:3 0 1c :3 0 15d
:4 0 191 1 :8 0
132c 15 :3 0 e1
:3 0 1327 1328 0
e4 :3 0 1329 132a
0 132c a39 1376
e5 :3 0 15 :3 0
e1 :3 0 132f 1330
0 e4 :3 0 1331
1332 0 136c c3
:3 0 c4 :3 0 1334
1335 0 c3 :3 0
d3 :3 0 1337 1338
0 e6 :2 0 2
:4 0 192 :2 0 d5
:2 0 2a :2 0 a3c
133d 133f :3 0 a3f
1339 1341 1336 1343
1342 :2 0 c6 :3 0
d6 :3 0 1345 1346
0 c8 :4 0 193
:4 0 cb :2 0 cc
:3 0 a43 134a 134c
:3 0 cb :2 0 e9
:4 0 a46 134e 1350
:3 0 cb :2 0 ea
:4 0 a49 1352 1354
:3 0 cb :2 0 e4
:3 0 a4c 1356 1358
:3 0 cb :2 0 eb
:4 0 a4f 135a 135c
:3 0 cb :2 0 a0
:3 0 ec :3 0 2a
:2 0 ed :2 0 a52
135f 1363 a56 135e
1365 :3 0 a59 1347
1367 :2 0 1369 a5c
136a 1344 1369 0
136b a5e 0 136c
a60 136f :3 0 136f
0 136f 136e 136c
136d :6 0 1371 2f
:3 0 a63 1373 a65
1372 1371 :2 0 1374
a67 :2 0 1376 0
1376 1375 132c 1374
:6 0 1504 1 :3 0
84 :3 0 55 :3 0
3d :2 0 a69 1378
137b b0 :3 0 da
:2 0 194 :3 0 137d
137f 0 a6e 137e
1381 :3 0 71 :3 0
172 :3 0 3d :2 0
84 :3 0 41 :3 0
3d :2 0 a71 1386
1389 b0 :3 0 173
:3 0 138b 138c 0
6e :3 0 a74 1384
138f 1383 1390 0
1405 af :3 0 12f
:3 0 23 :3 0 16d
:3 0 b0 :3 0 174
:3 0 177 :3 0 6e
:3 0 98 :3 0 1c
:4 0 195 1 :8 0
13b2 e0 :4 0 139d
:3 0 f7 :3 0 da
:2 0 a7b 13a0 13a1
:3 0 15 :3 0 e1
:3 0 13a3 13a4 0
3d :2 0 13a5 13a6
0 13a8 a7e 13af
15 :3 0 e1 :3 0
13a9 13aa 0 e2
:2 0 13ab 13ac 0
13ae a80 13b0 13a2
13a8 0 13b1 0
13ae 0 13b1 a82
0 13b2 a85 13fc
e5 :3 0 15 :3 0
e1 :3 0 13b5 13b6
0 e4 :3 0 13b7
13b8 0 13f2 c3
:3 0 c4 :3 0 13ba
13bb 0 c3 :3 0
d3 :3 0 13bd 13be
0 e6 :2 0 2
:4 0 196 :2 0 d5
:2 0 2a :2 0 a88
13c3 13c5 :3 0 a8b
13bf 13c7 13bc 13c9
13c8 :2 0 c6 :3 0
d6 :3 0 13cb 13cc
0 c8 :4 0 197
:4 0 cb :2 0 cc
:3 0 a8f 13d0 13d2
:3 0 cb :2 0 e9
:4 0 a92 13d4 13d6
:3 0 cb :2 0 ea
:4 0 a95 13d8 13da
:3 0 cb :2 0 e4
:3 0 a98 13dc 13de
:3 0 cb :2 0 eb
:4 0 a9b 13e0 13e2
:3 0 cb :2 0 a0
:3 0 ec :3 0 2a
:2 0 ed :2 0 a9e
13e5 13e9 aa2 13e4
13eb :3 0 aa5 13cd
13ed :2 0 13ef aa8
13f0 13ca 13ef 0
13f1 aaa 0 13f2
aac 13f5 :3 0 13f5
0 13f5 13f4 13f2
13f3 :6 0 13f7 31
:3 0 aaf 13f9 ab1
13f8 13f7 :2 0 13fa
ab3 :2 0 13fc 0
13fc 13fb 13b2 13fa
:6 0 1405 1 :3 0
71 :3 0 198 :3 0
1c :3 0 ab5 13ff
1401 13fe 1402 0
1405 140 :3 0 ab7
1501 d8 :3 0 84
:3 0 55 :3 0 3d
:2 0 abb 1407 140a
b0 :3 0 174 :3 0
140c 140d 0 abe
1406 140f 1410 :2 0
b0 :3 0 13b :2 0
174 :3 0 1412 1414
0 ac3 1413 1416
:3 0 af :3 0 12f
:3 0 23 :3 0 16d
:3 0 199 :3 0 19a
:3 0 16d :3 0 b0
:3 0 174 :3 0 98
:3 0 1c :4 0 19b
1 :8 0 1439 e0
:4 0 1424 :3 0 f7
:3 0 da :2 0 ac8
1427 1428 :3 0 15
:3 0 e1 :3 0 142a
142b 0 3d :2 0
142c 142d 0 142f
acb 1436 15 :3 0
e1 :3 0 1430 1431
0 e2 :2 0 1432
1433 0 1435 acd
1437 1429 142f 0
1438 0 1435 0
1438 acf 0 1439
ad2 1483 e5 :3 0
15 :3 0 e1 :3 0
143c 143d 0 e4
:3 0 143e 143f 0
1479 c3 :3 0 c4
:3 0 1441 1442 0
c3 :3 0 d3 :3 0
1444 1445 0 e6
:2 0 2 :4 0 19c
:2 0 d5 :2 0 2a
:2 0 ad5 144a 144c
:3 0 ad8 1446 144e
1443 1450 144f :2 0
c6 :3 0 d6 :3 0
1452 1453 0 c8
:4 0 19d :4 0 cb
:2 0 cc :3 0 adc
1457 1459 :3 0 cb
:2 0 e9 :4 0 adf
145b 145d :3 0 cb
:2 0 ea :4 0 ae2
145f 1461 :3 0 cb
:2 0 e4 :3 0 ae5
1463 1465 :3 0 cb
:2 0 eb :4 0 ae8
1467 1469 :3 0 cb
:2 0 a0 :3 0 ec
:3 0 2a :2 0 ed
:2 0 aeb 146c 1470
aef 146b 1472 :3 0
af2 1454 1474 :2 0
1476 af5 1477 1451
1476 0 1478 af7
0 1479 af9 147c
:3 0 147c 0 147c
147b 1479 147a :6 0
147e 33 :3 0 afc
1480 afe 147f 147e
:2 0 1481 b00 :2 0
1483 0 1483 1482
1439 1481 :6 0 148b
1 :3 0 71 :3 0
198 :3 0 1c :3 0
b02 1486 1488 1485
1489 0 148b b04
148c 1417 148b 0
1503 af :3 0 12f
:3 0 23 :3 0 16d
:3 0 199 :3 0 19a
:3 0 16d :3 0 b0
:3 0 19e :3 0 98
:3 0 1c :4 0 19f
1 :8 0 14ae e0
:4 0 1499 :3 0 f7
:3 0 da :2 0 b09
149c 149d :3 0 15
:3 0 e1 :3 0 149f
14a0 0 3d :2 0
14a1 14a2 0 14a4
b0c 14ab 15 :3 0
e1 :3 0 14a5 14a6
0 e2 :2 0 14a7
14a8 0 14aa b0e
14ac 149e 14a4 0
14ad 0 14aa 0
14ad b10 0 14ae
b13 14f8 e5 :3 0
15 :3 0 e1 :3 0
14b1 14b2 0 e4
:3 0 14b3 14b4 0
14ee c3 :3 0 c4
:3 0 14b6 14b7 0
c3 :3 0 d3 :3 0
14b9 14ba 0 e6
:2 0 2 :4 0 1a0
:2 0 d5 :2 0 2a
:2 0 b16 14bf 14c1
:3 0 b19 14bb 14c3
14b8 14c5 14c4 :2 0
c6 :3 0 d6 :3 0
14c7 14c8 0 c8
:4 0 1a1 :4 0 cb
:2 0 cc :3 0 b1d
14cc 14ce :3 0 cb
:2 0 e9 :4 0 b20
14d0 14d2 :3 0 cb
:2 0 ea :4 0 b23
14d4 14d6 :3 0 cb
:2 0 e4 :3 0 b26
14d8 14da :3 0 cb
:2 0 eb :4 0 b29
14dc 14de :3 0 cb
:2 0 a0 :3 0 ec
:3 0 2a :2 0 ed
:2 0 b2c 14e1 14e5
b30 14e0 14e7 :3 0
b33 14c9 14e9 :2 0
14eb b36 14ec 14c6
14eb 0 14ed b38
0 14ee b3a 14f1
:3 0 14f1 0 14f1
14f0 14ee 14ef :6 0
14f3 35 :3 0 b3d
14f5 b3f 14f4 14f3
:2 0 14f6 b41 :2 0
14f8 0 14f8 14f7
14ae 14f6 :6 0 1500
1 :3 0 71 :3 0
198 :3 0 1c :3 0
b43 14fb 14fd 14fa
14fe 0 1500 b45
1502 1382 1405 0
1503 0 1500 0
1503 b48 0 1504
b4c 1505 131f 1504
0 1507 1037 1315
0 1507 b4f 0
1508 b52 150a fc9
fd0 0 150b 0
1508 0 150b b55
0 150c b58 1511
1e :3 0 1e :3 0
150d 150e 0 1510
b5c 1512 dde 150c
0 1513 0 1510
0 1513 b5e 0
4b22 67 :3 0 de
:4 0 1514 1515 0
4b22 69 :3 0 de
:4 0 1517 1518 0
4b22 26 :3 0 de
:4 0 151a 151b 0
4b22 71 :3 0 1a2
:4 0 151e 151f :3 0
151d 1520 0 4b22
84 :3 0 62 :3 0
3d :2 0 b61 1522
1525 da :2 0 3d
:2 0 b66 1527 1529
:3 0 152a :2 0 84
:3 0 61 :3 0 3d
:2 0 b69 152c 152f
da :2 0 3d :2 0
b6e 1531 1533 :3 0
1534 :2 0 152b 1536
1535 :2 0 71 :3 0
1a3 :3 0 22 :3 0
21 :3 0 2e :3 0
67 :3 0 69 :3 0
85 :3 0 58 :3 0
5c :3 0 5b :3 0
5d :3 0 b71 1539
1544 1538 1545 0
1547 b7c 1548 1537
1547 0 1549 b7e
0 4b22 5f :3 0
1a4 :3 0 115 :3 0
5e :3 0 116 :3 0
117 :3 0 118 :3 0
119 :3 0 5e :3 0
125 :3 0 1a4 :3 0
11a :3 0 11b :3 0
118 :3 0 1a4 :3 0
115 :3 0 118 :3 0
8b :3 0 1a4 :3 0
115 :3 0 92 :3 0
21 :4 0 1a5 1
:8 0 1566 15 :3 0
e1 :3 0 1561 1562
0 e4 :3 0 1563
1564 0 1566 b80
15b0 e5 :3 0 15
:3 0 e1 :3 0 1569
156a 0 e4 :3 0
156b 156c 0 15a6
c3 :3 0 c4 :3 0
156e 156f 0 c3
:3 0 d3 :3 0 1571
1572 0 e6 :2 0
2 :4 0 1a6 :2 0
d5 :2 0 2a :2 0
b83 1577 1579 :3 0
b86 1573 157b 1570
157d 157c :2 0 c6
:3 0 d6 :3 0 157f
1580 0 c8 :4 0
1a7 :4 0 cb :2 0
cc :3 0 b8a 1584
1586 :3 0 cb :2 0
e9 :4 0 b8d 1588
158a :3 0 cb :2 0
ea :4 0 b90 158c
158e :3 0 cb :2 0
e4 :3 0 b93 1590
1592 :3 0 cb :2 0
eb :4 0 b96 1594
1596 :3 0 cb :2 0
a0 :3 0 ec :3 0
2a :2 0 ed :2 0
b99 1599 159d b9d
1598 159f :3 0 ba0
1581 15a1 :2 0 15a3
ba3 15a4 157e 15a3
0 15a5 ba5 0
15a6 ba7 15a9 :3 0
15a9 0 15a9 15a8
15a6 15a7 :6 0 15ab
37 :3 0 baa 15ad
bac 15ac 15ab :2 0
15ae bae :2 0 15b0
0 15b0 15af 1566
15ae :6 0 4b22 1
:3 0 15 :3 0 e1
:3 0 15b2 15b3 0
15 :3 0 13b :2 0
157 :3 0 15b5 15b7
0 bb2 15b6 15b9
:3 0 15ba :2 0 5e
:3 0 1a8 :2 0 15bc
15bd 0 15bf bb5
15c0 15bb 15bf 0
15c1 bb7 0 4b22
4b :3 0 3d :2 0
15c2 15c3 0 4b22
43 :3 0 3d :2 0
15c5 15c6 0 4b22
81 :4 0 15c8 15c9
0 4b22 1a9 :3 0
1aa :3 0 78 :3 0
6f :3 0 106 :3 0
91 :3 0 22 :4 0
1ab 1 :8 0 15d8
15 :3 0 e1 :3 0
15d3 15d4 0 e4
:3 0 15d5 15d6 0
15d8 bb9 1622 e5
:3 0 15 :3 0 e1
:3 0 15db 15dc 0
e4 :3 0 15dd 15de
0 1618 c3 :3 0
c4 :3 0 15e0 15e1
0 c3 :3 0 d3
:3 0 15e3 15e4 0
e6 :2 0 2 :4 0
1ac :2 0 d5 :2 0
2a :2 0 bbc 15e9
15eb :3 0 bbf 15e5
15ed 15e2 15ef 15ee
:2 0 c6 :3 0 d6
:3 0 15f1 15f2 0
c8 :4 0 1ad :4 0
cb :2 0 cc :3 0
bc3 15f6 15f8 :3 0
cb :2 0 e9 :4 0
bc6 15fa 15fc :3 0
cb :2 0 ea :4 0
bc9 15fe 1600 :3 0
cb :2 0 e4 :3 0
bcc 1602 1604 :3 0
cb :2 0 eb :4 0
bcf 1606 1608 :3 0
cb :2 0 a0 :3 0
ec :3 0 2a :2 0
ed :2 0 bd2 160b
160f bd6 160a 1611
:3 0 bd9 15f3 1613
:2 0 1615 bdc 1616
15f0 1615 0 1617
bde 0 1618 be0
161b :3 0 161b 0
161b 161a 1618 1619
:6 0 161d 39 :3 0
be3 161f be5 161e
161d :2 0 1620 be7
:2 0 1622 0 1622
1621 15d8 1620 :6 0
4b22 1 :3 0 116
:3 0 133 :3 0 1624
1625 0 22 :3 0
20 :3 0 be9 1626
1629 13b :2 0 3d
:2 0 bee 162b 162d
:3 0 1ae :3 0 1af
:3 0 43 :3 0 1b0
:3 0 91 :3 0 22
:3 0 9b :3 0 22
:3 0 92 :3 0 23
:4 0 1b1 1 :8 0
163f 15 :3 0 e1
:3 0 163a 163b 0
e4 :3 0 163c 163d
0 163f bf1 1689
e5 :3 0 15 :3 0
e1 :3 0 1642 1643
0 e4 :3 0 1644
1645 0 167f c3
:3 0 c4 :3 0 1647
1648 0 c3 :3 0
d3 :3 0 164a 164b
0 e6 :2 0 2
:4 0 1b2 :2 0 d5
:2 0 2a :2 0 bf4
1650 1652 :3 0 bf7
164c 1654 1649 1656
1655 :2 0 c6 :3 0
d6 :3 0 1658 1659
0 c8 :4 0 1b3
:4 0 cb :2 0 cc
:3 0 bfb 165d 165f
:3 0 cb :2 0 e9
:4 0 bfe 1661 1663
:3 0 cb :2 0 ea
:4 0 c01 1665 1667
:3 0 cb :2 0 e4
:3 0 c04 1669 166b
:3 0 cb :2 0 eb
:4 0 c07 166d 166f
:3 0 cb :2 0 a0
:3 0 ec :3 0 2a
:2 0 ed :2 0 c0a
1672 1676 c0e 1671
1678 :3 0 c11 165a
167a :2 0 167c c14
167d 1657 167c 0
167e c16 0 167f
c18 1682 :3 0 1682
0 1682 1681 167f
1680 :6 0 1684 3b
:3 0 c1b 1686 c1d
1685 1684 :2 0 1687
c1f :2 0 1689 0
1689 1688 163f 1687
:6 0 169f 1 :3 0
84 :3 0 43 :3 0
3d :2 0 c21 168b
168e da :2 0 3d
:2 0 c26 1690 1692
:3 0 20 :3 0 22
:3 0 1694 1695 0
1697 c29 169c 43
:3 0 3d :2 0 1698
1699 0 169b c2b
169d 1693 1697 0
169e 0 169b 0
169e c2d 0 169f
c30 16a0 162e 169f
0 16a1 c33 0
4b22 84 :3 0 4c
:3 0 3d :2 0 c35
16a2 16a5 10a :2 0
3d :2 0 c3a 16a7
16a9 :3 0 116 :3 0
133 :3 0 16ab 16ac
0 22 :3 0 20
:3 0 c3d 16ad 16b0
da :2 0 3d :2 0
c42 16b2 16b4 :3 0
9a :3 0 98 :3 0
9d :3 0 9f :3 0
a0 :3 0 a1 :3 0
9f :3 0 a0 :3 0
a2 :3 0 a5 :3 0
a6 :3 0 a7 :3 0
a8 :3 0 9b :3 0
9e :3 0 a9 :3 0
aa :3 0 ab :3 0
ac :3 0 1e :3 0
17 :3 0 7c :3 0
2b :3 0 2d :3 0
78 :3 0 79 :3 0
74 :3 0 75 :3 0
20 :3 0 7e :3 0
44 :3 0 46 :3 0
47 :3 0 48 :3 0
90 :3 0 9b :3 0
22 :3 0 92 :3 0
23 :3 0 93 :4 0
1b4 1 :8 0 16e4
15 :3 0 e1 :3 0
16df 16e0 0 e4
:3 0 16e1 16e2 0
16e4 c45 172e e5
:3 0 15 :3 0 e1
:3 0 16e7 16e8 0
e4 :3 0 16e9 16ea
0 1724 c3 :3 0
c4 :3 0 16ec 16ed
0 c3 :3 0 d3
:3 0 16ef 16f0 0
e6 :2 0 2 :4 0
1b5 :2 0 d5 :2 0
2a :2 0 c48 16f5
16f7 :3 0 c4b 16f1
16f9 16ee 16fb 16fa
:2 0 c6 :3 0 d6
:3 0 16fd 16fe 0
c8 :4 0 1b6 :4 0
cb :2 0 cc :3 0
c4f 1702 1704 :3 0
cb :2 0 e9 :4 0
c52 1706 1708 :3 0
cb :2 0 ea :4 0
c55 170a 170c :3 0
cb :2 0 e4 :3 0
c58 170e 1710 :3 0
cb :2 0 eb :4 0
c5b 1712 1714 :3 0
cb :2 0 a0 :3 0
ec :3 0 2a :2 0
ed :2 0 c5e 1717
171b c62 1716 171d
:3 0 c65 16ff 171f
:2 0 1721 c68 1722
16fc 1721 0 1723
c6a 0 1724 c6c
1727 :3 0 1727 0
1727 1726 1724 1725
:6 0 1729 3d :3 0
c6f 172b c71 172a
1729 :2 0 172c c73
:2 0 172e 0 172e
172d 16e4 172c :6 0
21f3 1 :3 0 81
:3 0 1e :3 0 1730
1731 0 21f3 57
:3 0 3d :2 0 1733
1734 0 21f3 84
:3 0 76 :3 0 3d
:2 0 c75 1736 1739
da :2 0 2a :2 0
c7a 173b 173d :3 0
84 :3 0 48 :3 0
3d :2 0 c7d 173f
1742 84 :3 0 13b
:2 0 f :3 0 3d
:2 0 c80 1744 1748
c85 1745 174a :3 0
174b :2 0 84 :3 0
44 :3 0 3d :2 0
c88 174d 1750 84
:3 0 13b :2 0 b
:3 0 3d :2 0 c8b
1752 1756 c90 1753
1758 :3 0 1759 :2 0
174c 175b 175a :2 0
84 :3 0 4c :3 0
3d :2 0 c93 175d
1760 da :2 0 2a
:2 0 c98 1762 1764
:3 0 1765 :2 0 d8
:3 0 84 :3 0 c
:3 0 3d :2 0 c9b
1768 176b b0 :3 0
1b7 :3 0 176d 176e
0 c9e 1767 1770
1771 :2 0 13b :2 0
3d :2 0 ca3 1773
1775 :3 0 1776 :2 0
1766 1778 1777 :2 0
c3 :3 0 c4 :3 0
177a 177b 0 c3
:3 0 d3 :3 0 177d
177e 0 18 :2 0
2 :4 0 1b8 :2 0
d5 :2 0 2a :2 0
ca6 1783 1785 :3 0
ca9 177f 1787 177c
1789 1788 :2 0 c6
:3 0 d6 :3 0 178b
178c 0 c8 :4 0
1b9 :4 0 cb :2 0
cc :3 0 cad 1790
1792 :3 0 cb :2 0
e9 :4 0 cb0 1794
1796 :3 0 cb :2 0
f0 :4 0 cb3 1798
179a :3 0 cb :2 0
84 :3 0 d0 :3 0
b0 :3 0 1ba :3 0
179f 17a0 0 cb6
179e 17a2 d1 :4 0
cb8 179d 17a5 cbb
179c 17a7 :3 0 cb
:2 0 f2 :4 0 cbe
17a9 17ab :3 0 cb
:2 0 ce :4 0 cc1
17ad 17af :3 0 cb
:2 0 21 :3 0 cc4
17b1 17b3 :3 0 cb
:2 0 ce :4 0 cc7
17b5 17b7 :3 0 cca
178d 17b9 :2 0 17bb
ccd 17bc 178a 17bb
0 17bd ccf 0
17e7 c3 :3 0 c4
:3 0 17be 17bf 0
c3 :3 0 d3 :3 0
17c1 17c2 0 2a
:2 0 2 :4 0 1bb
:2 0 d5 :2 0 2a
:2 0 cd1 17c7 17c9
:3 0 cd4 17c3 17cb
17c0 17cd 17cc :2 0
c6 :3 0 d6 :3 0
17cf 17d0 0 c8
:4 0 1bc :4 0 cb
:2 0 cc :3 0 cd8
17d4 17d6 :3 0 cdb
17d1 17d8 :2 0 17da
cde 17db 17ce 17da
0 17dc ce0 0
17e7 f5 :3 0 f6
:3 0 17dd 17de 0
b0 :3 0 1ba :3 0
17e0 17e1 0 21
:3 0 f7 :3 0 ce2
17df 17e5 :2 0 17e7
ce6 17fb 57 :3 0
2a :2 0 17e8 17e9
0 17fa 84 :3 0
f :3 0 3d :2 0
cea 17eb 17ee da
:2 0 3d :2 0 cef
17f0 17f2 :3 0 7e
:3 0 3d :2 0 17f4
17f5 0 17f7 cf2
17f8 17f3 17f7 0
17f9 cf4 0 17fa
cf6 17fc 1779 17e7
0 17fd 0 17fa
0 17fd cf9 0
17fe cfc 17ff 175c
17fe 0 1800 cfe
0 181c 3f :3 0
9 :3 0 1801 1802
0 181c 24 :3 0
7 :3 0 1804 1805
0 181c 26 :3 0
8 :3 0 1807 1808
0 181c 44 :3 0
b :3 0 180a 180b
0 181c 45 :3 0
10 :3 0 180d 180e
0 181c 46 :3 0
d :3 0 1810 1811
0 181c 47 :3 0
e :3 0 1813 1814
0 181c 4e :3 0
c :3 0 1816 1817
0 181c 48 :3 0
f :3 0 1819 181a
0 181c d00 181d
173e 181c 0 181e
d0b 0 21f3 15
:3 0 e1 :3 0 181f
1820 0 15 :3 0
da :2 0 157 :3 0
1822 1824 0 d0f
1823 1826 :3 0 1827
:2 0 1e :3 0 165
:2 0 d12 182a 182b
:3 0 182c :2 0 182d
:2 0 1828 182f 182e
:2 0 a0 :3 0 6f
:3 0 2a :2 0 2a
:2 0 d14 1831 1835
da :2 0 1bd :4 0
d1a 1837 1839 :3 0
7a :3 0 1be :2 0
2a :2 0 d1d 183c
183e :3 0 183b 183f
0 1852 15 :3 0
e1 :3 0 1841 1842
0 1bf :3 0 22
:3 0 22 :3 0 1e
:3 0 2b :3 0 2d
:3 0 74 :3 0 75
:3 0 7a :3 0 79
:3 0 78 :3 0 d1f
1844 184f 1843 1850
0 1852 d2a 1853
183a 1852 0 1854
d2d 0 21ef 84
:3 0 4c :3 0 3d
:2 0 d2f 1855 1858
da :2 0 2a :2 0
d34 185a 185c :3 0
90 :3 0 9a :3 0
1e :4 0 1c0 1
:8 0 1877 e0 :4 0
1862 :3 0 f7 :3 0
da :2 0 d39 1865
1866 :3 0 15 :3 0
e1 :3 0 1868 1869
0 3d :2 0 186a
186b 0 186d d3c
1874 15 :3 0 e1
:3 0 186e 186f 0
e2 :2 0 1870 1871
0 1873 d3e 1875
1867 186d 0 1876
0 1873 0 1876
d40 0 1877 d43
18c1 e5 :3 0 15
:3 0 e1 :3 0 187a
187b 0 e4 :3 0
187c 187d 0 18b7
c3 :3 0 c4 :3 0
187f 1880 0 c3
:3 0 d3 :3 0 1882
1883 0 e6 :2 0
2 :4 0 1c1 :2 0
d5 :2 0 2a :2 0
d46 1888 188a :3 0
d49 1884 188c 1881
188e 188d :2 0 c6
:3 0 d6 :3 0 1890
1891 0 c8 :4 0
1c2 :4 0 cb :2 0
cc :3 0 d4d 1895
1897 :3 0 cb :2 0
e9 :4 0 d50 1899
189b :3 0 cb :2 0
ea :4 0 d53 189d
189f :3 0 cb :2 0
e4 :3 0 d56 18a1
18a3 :3 0 cb :2 0
eb :4 0 d59 18a5
18a7 :3 0 cb :2 0
a0 :3 0 ec :3 0
2a :2 0 ed :2 0
d5c 18aa 18ae d60
18a9 18b0 :3 0 d63
1892 18b2 :2 0 18b4
d66 18b5 188f 18b4
0 18b6 d68 0
18b7 d6a 18ba :3 0
18ba 0 18ba 18b9
18b7 18b8 :6 0 18bc
3f :3 0 d6d 18be
d6f 18bd 18bc :2 0
18bf d71 :2 0 18c1
0 18c1 18c0 1877
18bf :6 0 19f2 1
:3 0 1b0 :3 0 91
:3 0 22 :3 0 9a
:3 0 1e :4 0 1c3
1 :8 0 18de e0
:4 0 18c9 :3 0 f7
:3 0 da :2 0 d75
18cc 18cd :3 0 15
:3 0 e1 :3 0 18cf
18d0 0 3d :2 0
18d1 18d2 0 18d4
d78 18db 15 :3 0
e1 :3 0 18d5 18d6
0 e2 :2 0 18d7
18d8 0 18da d7a
18dc 18ce 18d4 0
18dd 0 18da 0
18dd d7c 0 18de
d7f 1928 e5 :3 0
15 :3 0 e1 :3 0
18e1 18e2 0 e4
:3 0 18e3 18e4 0
191e c3 :3 0 c4
:3 0 18e6 18e7 0
c3 :3 0 d3 :3 0
18e9 18ea 0 e6
:2 0 2 :4 0 1c4
:2 0 d5 :2 0 2a
:2 0 d82 18ef 18f1
:3 0 d85 18eb 18f3
18e8 18f5 18f4 :2 0
c6 :3 0 d6 :3 0
18f7 18f8 0 c8
:4 0 1c5 :4 0 cb
:2 0 cc :3 0 d89
18fc 18fe :3 0 cb
:2 0 e9 :4 0 d8c
1900 1902 :3 0 cb
:2 0 ea :4 0 d8f
1904 1906 :3 0 cb
:2 0 e4 :3 0 d92
1908 190a :3 0 cb
:2 0 eb :4 0 d95
190c 190e :3 0 cb
:2 0 a0 :3 0 ec
:3 0 2a :2 0 ed
:2 0 d98 1911 1915
d9c 1910 1917 :3 0
d9f 18f9 1919 :2 0
191b da2 191c 18f6
191b 0 191d da4
0 191e da6 1921
:3 0 1921 0 1921
1920 191e 191f :6 0
1923 41 :3 0 da9
1925 dab 1924 1923
:2 0 1926 dad :2 0
1928 0 1928 1927
18de 1926 :6 0 19f2
1 :3 0 1e :3 0
81 :3 0 192a 192b
0 19f2 1c6 :3 0
1c7 :3 0 2b :3 0
1b0 :3 0 91 :3 0
22 :3 0 9a :3 0
1e :4 0 1c8 1
:8 0 193b 15 :3 0
e1 :3 0 1936 1937
0 e4 :3 0 1938
1939 0 193b daf
1985 e5 :3 0 15
:3 0 e1 :3 0 193e
193f 0 e4 :3 0
1940 1941 0 197b
c3 :3 0 c4 :3 0
1943 1944 0 c3
:3 0 d3 :3 0 1946
1947 0 e6 :2 0
2 :4 0 1c9 :2 0
d5 :2 0 2a :2 0
db2 194c 194e :3 0
db5 1948 1950 1945
1952 1951 :2 0 c6
:3 0 d6 :3 0 1954
1955 0 c8 :4 0
1ca :4 0 cb :2 0
cc :3 0 db9 1959
195b :3 0 cb :2 0
e9 :4 0 dbc 195d
195f :3 0 cb :2 0
ea :4 0 dbf 1961
1963 :3 0 cb :2 0
e4 :3 0 dc2 1965
1967 :3 0 cb :2 0
eb :4 0 dc5 1969
196b :3 0 cb :2 0
a0 :3 0 ec :3 0
2a :2 0 ed :2 0
dc8 196e 1972 dcc
196d 1974 :3 0 dcf
1956 1976 :2 0 1978
dd2 1979 1953 1978
0 197a dd4 0
197b dd6 197e :3 0
197e 0 197e 197d
197b 197c :6 0 1980
43 :3 0 dd9 1982
ddb 1981 1980 :2 0
1983 ddd :2 0 1985
0 1985 1984 193b
1983 :6 0 19f2 1
:3 0 116 :3 0 166
:3 0 1987 1988 0
24 :3 0 2b :3 0
167 :2 0 ddf 1989
198d 1cb :2 0 3d
:2 0 de5 198f 1991
:3 0 116 :3 0 1cc
:3 0 9f :3 0 a0
:3 0 2b :3 0 116
:3 0 1cd :3 0 24
:3 0 24 :3 0 1ce
:4 0 1cf 1 :8 0
19a3 15 :3 0 e1
:3 0 199e 199f 0
e4 :3 0 19a0 19a1
0 19a3 de8 19ed
e5 :3 0 15 :3 0
e1 :3 0 19a6 19a7
0 e4 :3 0 19a8
19a9 0 19e3 c3
:3 0 c4 :3 0 19ab
19ac 0 c3 :3 0
d3 :3 0 19ae 19af
0 e6 :2 0 2
:4 0 1d0 :2 0 d5
:2 0 2a :2 0 deb
19b4 19b6 :3 0 dee
19b0 19b8 19ad 19ba
19b9 :2 0 c6 :3 0
d6 :3 0 19bc 19bd
0 c8 :4 0 1d1
:4 0 cb :2 0 cc
:3 0 df2 19c1 19c3
:3 0 cb :2 0 e9
:4 0 df5 19c5 19c7
:3 0 cb :2 0 ea
:4 0 df8 19c9 19cb
:3 0 cb :2 0 e4
:3 0 dfb 19cd 19cf
:3 0 cb :2 0 eb
:4 0 dfe 19d1 19d3
:3 0 cb :2 0 a0
:3 0 ec :3 0 2a
:2 0 ed :2 0 e01
19d6 19da e05 19d5
19dc :3 0 e08 19be
19de :2 0 19e0 e0b
19e1 19bb 19e0 0
19e2 e0d 0 19e3
e0f 19e6 :3 0 19e6
0 19e6 19e5 19e3
19e4 :6 0 19e8 45
:3 0 e12 19ea e14
19e9 19e8 :2 0 19eb
e16 :2 0 19ed 0
19ed 19ec 19a3 19eb
:6 0 19ef 1 :3 0
e18 19f0 1992 19ef
0 19f1 e1a 0
19f2 e1c 1e71 84
:3 0 62 :3 0 3d
:2 0 e22 19f3 19f6
da :2 0 3d :2 0
e27 19f8 19fa :3 0
19fb :2 0 84 :3 0
61 :3 0 3d :2 0
e2a 19fd 1a00 da
:2 0 3d :2 0 e2f
1a02 1a04 :3 0 1a05
:2 0 19fc 1a07 1a06
:2 0 58 :3 0 84
:3 0 58 :3 0 3d
:2 0 e32 1a0a 1a0d
1d2 :2 0 84 :3 0
5e :3 0 3d :2 0
e35 1a10 1a13 e38
1a0f 1a15 :3 0 1a09
1a16 0 1b58 5c
:3 0 84 :3 0 5c
:3 0 3d :2 0 e3b
1a19 1a1c 1d2 :2 0
84 :3 0 5e :3 0
3d :2 0 e3e 1a1f
1a22 e41 1a1e 1a24
:3 0 1a18 1a25 0
1b58 5b :3 0 84
:3 0 5b :3 0 3d
:2 0 e44 1a28 1a2b
1d2 :2 0 84 :3 0
5e :3 0 3d :2 0
e47 1a2e 1a31 e4a
1a2d 1a33 :3 0 1a27
1a34 0 1b58 5d
:3 0 84 :3 0 5d
:3 0 3d :2 0 e4d
1a37 1a3a 1d2 :2 0
84 :3 0 5e :3 0
3d :2 0 e50 1a3d
1a40 e53 1a3c 1a42
:3 0 1a36 1a43 0
1b58 84 :3 0 78
:3 0 3d :2 0 e56
1a45 1a48 da :2 0
3d :2 0 e5b 1a4a
1a4c :3 0 90 :3 0
98 :3 0 1c :3 0
92 :3 0 21 :3 0
93 :3 0 a7 :3 0
58 :3 0 1d3 :3 0
5c :3 0 a8 :3 0
5b :3 0 1d4 :3 0
5d :3 0 9e :3 0
57 :3 0 9e :3 0
7e :3 0 1d5 :3 0
9d :3 0 1d6 :3 0
58 :3 0 1d7 :3 0
199 :3 0 19a :3 0
1d7 :3 0 b0 :3 0
1d8 :3 0 9a :3 0
1e :4 0 1d9 1
:8 0 1a82 e0 :4 0
1a6d :3 0 f7 :3 0
da :2 0 e60 1a70
1a71 :3 0 15 :3 0
e1 :3 0 1a73 1a74
0 3d :2 0 1a75
1a76 0 1a78 e63
1a7f 15 :3 0 e1
:3 0 1a79 1a7a 0
e2 :2 0 1a7b 1a7c
0 1a7e e65 1a80
1a72 1a78 0 1a81
0 1a7e 0 1a81
e67 0 1a82 e6a
1acc e5 :3 0 15
:3 0 e1 :3 0 1a85
1a86 0 e4 :3 0
1a87 1a88 0 1ac2
c3 :3 0 c4 :3 0
1a8a 1a8b 0 c3
:3 0 d3 :3 0 1a8d
1a8e 0 e6 :2 0
2 :4 0 1da :2 0
d5 :2 0 2a :2 0
e6d 1a93 1a95 :3 0
e70 1a8f 1a97 1a8c
1a99 1a98 :2 0 c6
:3 0 d6 :3 0 1a9b
1a9c 0 c8 :4 0
1db :4 0 cb :2 0
cc :3 0 e74 1aa0
1aa2 :3 0 cb :2 0
e9 :4 0 e77 1aa4
1aa6 :3 0 cb :2 0
ea :4 0 e7a 1aa8
1aaa :3 0 cb :2 0
e4 :3 0 e7d 1aac
1aae :3 0 cb :2 0
eb :4 0 e80 1ab0
1ab2 :3 0 cb :2 0
a0 :3 0 ec :3 0
2a :2 0 ed :2 0
e83 1ab5 1ab9 e87
1ab4 1abb :3 0 e8a
1a9d 1abd :2 0 1abf
e8d 1ac0 1a9a 1abf
0 1ac1 e8f 0
1ac2 e91 1ac5 :3 0
1ac5 0 1ac5 1ac4
1ac2 1ac3 :6 0 1ac7
47 :3 0 e94 1ac9
e96 1ac8 1ac7 :2 0
1aca e98 :2 0 1acc
0 1acc 1acb 1a82
1aca :6 0 1ace 1
:3 0 e9a 1b54 90
:3 0 98 :3 0 1c
:3 0 92 :3 0 21
:3 0 93 :3 0 a7
:3 0 58 :3 0 1d3
:3 0 5c :3 0 a8
:3 0 5b :3 0 1d4
:3 0 5d :3 0 9e
:3 0 57 :3 0 9e
:3 0 7e :3 0 1d5
:3 0 9d :3 0 1d6
:3 0 58 :3 0 1dc
:3 0 9d :3 0 9d
:3 0 5b :3 0 1d7
:3 0 199 :3 0 19a
:3 0 1d7 :3 0 b0
:3 0 1d8 :3 0 9a
:3 0 1e :4 0 1dd
1 :8 0 1b07 e0
:4 0 1af2 :3 0 f7
:3 0 da :2 0 e9e
1af5 1af6 :3 0 15
:3 0 e1 :3 0 1af8
1af9 0 3d :2 0
1afa 1afb 0 1afd
ea1 1b04 15 :3 0
e1 :3 0 1afe 1aff
0 e2 :2 0 1b00
1b01 0 1b03 ea3
1b05 1af7 1afd 0
1b06 0 1b03 0
1b06 ea5 0 1b07
ea8 1b51 e5 :3 0
15 :3 0 e1 :3 0
1b0a 1b0b 0 e4
:3 0 1b0c 1b0d 0
1b47 c3 :3 0 c4
:3 0 1b0f 1b10 0
c3 :3 0 d3 :3 0
1b12 1b13 0 e6
:2 0 2 :4 0 1de
:2 0 d5 :2 0 2a
:2 0 eab 1b18 1b1a
:3 0 eae 1b14 1b1c
1b11 1b1e 1b1d :2 0
c6 :3 0 d6 :3 0
1b20 1b21 0 c8
:4 0 1df :4 0 cb
:2 0 cc :3 0 eb2
1b25 1b27 :3 0 cb
:2 0 e9 :4 0 eb5
1b29 1b2b :3 0 cb
:2 0 ea :4 0 eb8
1b2d 1b2f :3 0 cb
:2 0 e4 :3 0 ebb
1b31 1b33 :3 0 cb
:2 0 eb :4 0 ebe
1b35 1b37 :3 0 cb
:2 0 a0 :3 0 ec
:3 0 2a :2 0 ed
:2 0 ec1 1b3a 1b3e
ec5 1b39 1b40 :3 0
ec8 1b22 1b42 :2 0
1b44 ecb 1b45 1b1f
1b44 0 1b46 ecd
0 1b47 ecf 1b4a
:3 0 1b4a 0 1b4a
1b49 1b47 1b48 :6 0
1b4c 49 :3 0 ed2
1b4e ed4 1b4d 1b4c
:2 0 1b4f ed6 :2 0
1b51 0 1b51 1b50
1b07 1b4f :6 0 1b53
1 :3 0 ed8 1b55
1a4d 1ace 0 1b56
0 1b53 0 1b56
eda 0 1b58 140
:3 0 edd 1d99 84
:3 0 62 :3 0 3d
:2 0 ee3 1b59 1b5c
da :2 0 3d :2 0
ee8 1b5e 1b60 :3 0
58 :3 0 84 :3 0
58 :3 0 3d :2 0
eeb 1b63 1b66 1d2
:2 0 84 :3 0 5e
:3 0 3d :2 0 eee
1b69 1b6c ef1 1b68
1b6e :3 0 1b62 1b6f
0 1bfd 5c :3 0
84 :3 0 5c :3 0
3d :2 0 ef4 1b72
1b75 1d2 :2 0 84
:3 0 5e :3 0 3d
:2 0 ef7 1b78 1b7b
efa 1b77 1b7d :3 0
1b71 1b7e 0 1bfd
90 :3 0 98 :3 0
1c :3 0 92 :3 0
21 :3 0 93 :3 0
a7 :3 0 58 :3 0
1d3 :3 0 5c :3 0
9e :3 0 57 :3 0
9e :3 0 7e :3 0
1d5 :3 0 9d :3 0
1d6 :3 0 58 :3 0
1d7 :3 0 199 :3 0
19a :3 0 1d7 :3 0
b0 :3 0 1d8 :3 0
9a :3 0 1e :4 0
1e0 1 :8 0 1bb0
e0 :4 0 1b9b :3 0
f7 :3 0 da :2 0
eff 1b9e 1b9f :3 0
15 :3 0 e1 :3 0
1ba1 1ba2 0 3d
:2 0 1ba3 1ba4 0
1ba6 f02 1bad 15
:3 0 e1 :3 0 1ba7
1ba8 0 e2 :2 0
1ba9 1baa 0 1bac
f04 1bae 1ba0 1ba6
0 1baf 0 1bac
0 1baf f06 0
1bb0 f09 1bfa e5
:3 0 15 :3 0 e1
:3 0 1bb3 1bb4 0
e4 :3 0 1bb5 1bb6
0 1bf0 c3 :3 0
c4 :3 0 1bb8 1bb9
0 c3 :3 0 d3
:3 0 1bbb 1bbc 0
e6 :2 0 2 :4 0
1e1 :2 0 d5 :2 0
2a :2 0 f0c 1bc1
1bc3 :3 0 f0f 1bbd
1bc5 1bba 1bc7 1bc6
:2 0 c6 :3 0 d6
:3 0 1bc9 1bca 0
c8 :4 0 1e2 :4 0
cb :2 0 cc :3 0
f13 1bce 1bd0 :3 0
cb :2 0 e9 :4 0
f16 1bd2 1bd4 :3 0
cb :2 0 ea :4 0
f19 1bd6 1bd8 :3 0
cb :2 0 e4 :3 0
f1c 1bda 1bdc :3 0
cb :2 0 eb :4 0
f1f 1bde 1be0 :3 0
cb :2 0 a0 :3 0
ec :3 0 2a :2 0
ed :2 0 f22 1be3
1be7 f26 1be2 1be9
:3 0 f29 1bcb 1beb
:2 0 1bed f2c 1bee
1bc8 1bed 0 1bef
f2e 0 1bf0 f30
1bf3 :3 0 1bf3 0
1bf3 1bf2 1bf0 1bf1
:6 0 1bf5 4b :3 0
f33 1bf7 f35 1bf6
1bf5 :2 0 1bf8 f37
:2 0 1bfa 0 1bfa
1bf9 1bb0 1bf8 :6 0
1bfd 1 :3 0 140
:3 0 f39 1bfe 1b61
1bfd 0 1d9b 84
:3 0 61 :3 0 3d
:2 0 f3d 1bff 1c02
da :2 0 3d :2 0
f42 1c04 1c06 :3 0
5b :3 0 84 :3 0
5b :3 0 3d :2 0
f45 1c09 1c0c 1d2
:2 0 84 :3 0 5e
:3 0 3d :2 0 f48
1c0f 1c12 f4b 1c0e
1c14 :3 0 1c08 1c15
0 1d28 5d :3 0
84 :3 0 5d :3 0
3d :2 0 f4e 1c18
1c1b 1d2 :2 0 84
:3 0 5e :3 0 3d
:2 0 f51 1c1e 1c21
f54 1c1d 1c23 :3 0
1c17 1c24 0 1d28
84 :3 0 78 :3 0
3d :2 0 f57 1c26
1c29 da :2 0 3d
:2 0 f5c 1c2b 1c2d
:3 0 90 :3 0 98
:3 0 1c :3 0 92
:3 0 21 :3 0 93
:3 0 a8 :3 0 5b
:3 0 1d4 :3 0 5d
:3 0 9e :3 0 57
:3 0 9e :3 0 7e
:3 0 1d7 :3 0 199
:3 0 19a :3 0 1d7
:3 0 b0 :3 0 1d8
:3 0 9a :3 0 1e
:4 0 1e3 1 :8 0
1c5b e0 :4 0 1c46
:3 0 f7 :3 0 da
:2 0 f61 1c49 1c4a
:3 0 15 :3 0 e1
:3 0 1c4c 1c4d 0
3d :2 0 1c4e 1c4f
0 1c51 f64 1c58
15 :3 0 e1 :3 0
1c52 1c53 0 e2
:2 0 1c54 1c55 0
1c57 f66 1c59 1c4b
1c51 0 1c5a 0
1c57 0 1c5a f68
0 1c5b f6b 1ca5
e5 :3 0 15 :3 0
e1 :3 0 1c5e 1c5f
0 e4 :3 0 1c60
1c61 0 1c9b c3
:3 0 c4 :3 0 1c63
1c64 0 c3 :3 0
d3 :3 0 1c66 1c67
0 e6 :2 0 2
:4 0 1e4 :2 0 d5
:2 0 2a :2 0 f6e
1c6c 1c6e :3 0 f71
1c68 1c70 1c65 1c72
1c71 :2 0 c6 :3 0
d6 :3 0 1c74 1c75
0 c8 :4 0 1e5
:4 0 cb :2 0 cc
:3 0 f75 1c79 1c7b
:3 0 cb :2 0 e9
:4 0 f78 1c7d 1c7f
:3 0 cb :2 0 ea
:4 0 f7b 1c81 1c83
:3 0 cb :2 0 e4
:3 0 f7e 1c85 1c87
:3 0 cb :2 0 eb
:4 0 f81 1c89 1c8b
:3 0 cb :2 0 a0
:3 0 ec :3 0 2a
:2 0 ed :2 0 f84
1c8e 1c92 f88 1c8d
1c94 :3 0 f8b 1c76
1c96 :2 0 1c98 f8e
1c99 1c73 1c98 0
1c9a f90 0 1c9b
f92 1c9e :3 0 1c9e
0 1c9e 1c9d 1c9b
1c9c :6 0 1ca0 4d
:3 0 f95 1ca2 f97
1ca1 1ca0 :2 0 1ca3
f99 :2 0 1ca5 0
1ca5 1ca4 1c5b 1ca3
:6 0 1ca7 1 :3 0
f9b 1d25 90 :3 0
98 :3 0 1c :3 0
92 :3 0 21 :3 0
93 :3 0 a8 :3 0
5b :3 0 1d4 :3 0
5d :3 0 9e :3 0
57 :3 0 9e :3 0
7e :3 0 1dc :3 0
9d :3 0 9d :3 0
5b :3 0 1d7 :3 0
199 :3 0 19a :3 0
1d7 :3 0 b0 :3 0
1d8 :3 0 9a :3 0
1e :4 0 1e6 1
:8 0 1cd8 e0 :4 0
1cc3 :3 0 f7 :3 0
da :2 0 f9f 1cc6
1cc7 :3 0 15 :3 0
e1 :3 0 1cc9 1cca
0 3d :2 0 1ccb
1ccc 0 1cce fa2
1cd5 15 :3 0 e1
:3 0 1ccf 1cd0 0
e2 :2 0 1cd1 1cd2
0 1cd4 fa4 1cd6
1cc8 1cce 0 1cd7
0 1cd4 0 1cd7
fa6 0 1cd8 fa9
1d22 e5 :3 0 15
:3 0 e1 :3 0 1cdb
1cdc 0 e4 :3 0
1cdd 1cde 0 1d18
c3 :3 0 c4 :3 0
1ce0 1ce1 0 c3
:3 0 d3 :3 0 1ce3
1ce4 0 e6 :2 0
2 :4 0 1e7 :2 0
d5 :2 0 2a :2 0
fac 1ce9 1ceb :3 0
faf 1ce5 1ced 1ce2
1cef 1cee :2 0 c6
:3 0 d6 :3 0 1cf1
1cf2 0 c8 :4 0
1e8 :4 0 cb :2 0
cc :3 0 fb3 1cf6
1cf8 :3 0 cb :2 0
e9 :4 0 fb6 1cfa
1cfc :3 0 cb :2 0
ea :4 0 fb9 1cfe
1d00 :3 0 cb :2 0
e4 :3 0 fbc 1d02
1d04 :3 0 cb :2 0
eb :4 0 fbf 1d06
1d08 :3 0 cb :2 0
a0 :3 0 ec :3 0
2a :2 0 ed :2 0
fc2 1d0b 1d0f fc6
1d0a 1d11 :3 0 fc9
1cf3 1d13 :2 0 1d15
fcc 1d16 1cf0 1d15
0 1d17 fce 0
1d18 fd0 1d1b :3 0
1d1b 0 1d1b 1d1a
1d18 1d19 :6 0 1d1d
4f :3 0 fd3 1d1f
fd5 1d1e 1d1d :2 0
1d20 fd7 :2 0 1d22
0 1d22 1d21 1cd8
1d20 :6 0 1d24 1
:3 0 fd9 1d26 1c2e
1ca7 0 1d27 0
1d24 0 1d27 fdb
0 1d28 fde 1d29
1c07 1d28 0 1d9b
90 :3 0 98 :3 0
1c :3 0 9e :3 0
57 :3 0 9e :3 0
7e :3 0 92 :3 0
21 :3 0 93 :3 0
9a :3 0 1e :4 0
1e9 1 :8 0 1d4c
e0 :4 0 1d37 :3 0
f7 :3 0 da :2 0
fe4 1d3a 1d3b :3 0
15 :3 0 e1 :3 0
1d3d 1d3e 0 3d
:2 0 1d3f 1d40 0
1d42 fe7 1d49 15
:3 0 e1 :3 0 1d43
1d44 0 e2 :2 0
1d45 1d46 0 1d48
fe9 1d4a 1d3c 1d42
0 1d4b 0 1d48
0 1d4b feb 0
1d4c fee 1d96 e5
:3 0 15 :3 0 e1
:3 0 1d4f 1d50 0
e4 :3 0 1d51 1d52
0 1d8c c3 :3 0
c4 :3 0 1d54 1d55
0 c3 :3 0 d3
:3 0 1d57 1d58 0
e6 :2 0 2 :4 0
1ea :2 0 d5 :2 0
2a :2 0 ff1 1d5d
1d5f :3 0 ff4 1d59
1d61 1d56 1d63 1d62
:2 0 c6 :3 0 d6
:3 0 1d65 1d66 0
c8 :4 0 1eb :4 0
cb :2 0 cc :3 0
ff8 1d6a 1d6c :3 0
cb :2 0 e9 :4 0
ffb 1d6e 1d70 :3 0
cb :2 0 ea :4 0
ffe 1d72 1d74 :3 0
cb :2 0 e4 :3 0
1001 1d76 1d78 :3 0
cb :2 0 eb :4 0
1004 1d7a 1d7c :3 0
cb :2 0 a0 :3 0
ec :3 0 2a :2 0
ed :2 0 1007 1d7f
1d83 100b 1d7e 1d85
:3 0 100e 1d67 1d87
:2 0 1d89 1011 1d8a
1d64 1d89 0 1d8b
1013 0 1d8c 1015
1d8f :3 0 1d8f 0
1d8f 1d8e 1d8c 1d8d
:6 0 1d91 51 :3 0
1018 1d93 101a 1d92
1d91 :2 0 1d94 101c
:2 0 1d96 0 1d96
1d95 1d4c 1d94 :6 0
1d98 1 :3 0 101e
1d9a 1a08 1b58 0
1d9b 0 1d98 0
1d9b 1020 0 1e70
1b0 :3 0 91 :3 0
22 :3 0 9a :3 0
1e :4 0 1c3 1
:8 0 1db7 e0 :4 0
1da2 :3 0 f7 :3 0
da :2 0 1027 1da5
1da6 :3 0 15 :3 0
e1 :3 0 1da8 1da9
0 3d :2 0 1daa
1dab 0 1dad 102a
1db4 15 :3 0 e1
:3 0 1dae 1daf 0
e2 :2 0 1db0 1db1
0 1db3 102c 1db5
1da7 1dad 0 1db6
0 1db3 0 1db6
102e 0 1db7 1031
1e01 e5 :3 0 15
:3 0 e1 :3 0 1dba
1dbb 0 e4 :3 0
1dbc 1dbd 0 1df7
c3 :3 0 c4 :3 0
1dbf 1dc0 0 c3
:3 0 d3 :3 0 1dc2
1dc3 0 e6 :2 0
2 :4 0 1ec :2 0
d5 :2 0 2a :2 0
1034 1dc8 1dca :3 0
1037 1dc4 1dcc 1dc1
1dce 1dcd :2 0 c6
:3 0 d6 :3 0 1dd0
1dd1 0 c8 :4 0
1ed :4 0 cb :2 0
cc :3 0 103b 1dd5
1dd7 :3 0 cb :2 0
e9 :4 0 103e 1dd9
1ddb :3 0 cb :2 0
ea :4 0 1041 1ddd
1ddf :3 0 cb :2 0
e4 :3 0 1044 1de1
1de3 :3 0 cb :2 0
eb :4 0 1047 1de5
1de7 :3 0 cb :2 0
a0 :3 0 ec :3 0
2a :2 0 ed :2 0
104a 1dea 1dee 104e
1de9 1df0 :3 0 1051
1dd2 1df2 :2 0 1df4
1054 1df5 1dcf 1df4
0 1df6 1056 0
1df7 1058 1dfa :3 0
1dfa 0 1dfa 1df9
1df7 1df8 :6 0 1dfc
53 :3 0 105b 1dfe
105d 1dfd 1dfc :2 0
1dff 105f :2 0 1e01
0 1e01 1e00 1db7
1dff :6 0 1e70 1
:3 0 1ee :3 0 1e
:3 0 1ef :3 0 1f0
:3 0 1f1 :3 0 1f2
:3 0 1f3 :3 0 1f4
:3 0 1ee :3 0 98
:3 0 23 :4 0 1f5
1 :8 0 1e24 e0
:4 0 1e0f :3 0 f7
:3 0 da :2 0 1063
1e12 1e13 :3 0 15
:3 0 e1 :3 0 1e15
1e16 0 3d :2 0
1e17 1e18 0 1e1a
1066 1e21 15 :3 0
e1 :3 0 1e1b 1e1c
0 e2 :2 0 1e1d
1e1e 0 1e20 1068
1e22 1e14 1e1a 0
1e23 0 1e20 0
1e23 106a 0 1e24
106d 1e6e e5 :3 0
15 :3 0 e1 :3 0
1e27 1e28 0 e4
:3 0 1e29 1e2a 0
1e64 c3 :3 0 c4
:3 0 1e2c 1e2d 0
c3 :3 0 d3 :3 0
1e2f 1e30 0 e6
:2 0 2 :4 0 1f6
:2 0 d5 :2 0 2a
:2 0 1070 1e35 1e37
:3 0 1073 1e31 1e39
1e2e 1e3b 1e3a :2 0
c6 :3 0 d6 :3 0
1e3d 1e3e 0 c8
:4 0 1f7 :4 0 cb
:2 0 cc :3 0 1077
1e42 1e44 :3 0 cb
:2 0 e9 :4 0 107a
1e46 1e48 :3 0 cb
:2 0 ea :4 0 107d
1e4a 1e4c :3 0 cb
:2 0 e4 :3 0 1080
1e4e 1e50 :3 0 cb
:2 0 eb :4 0 1083
1e52 1e54 :3 0 cb
:2 0 a0 :3 0 ec
:3 0 2a :2 0 ed
:2 0 1086 1e57 1e5b
108a 1e56 1e5d :3 0
108d 1e3f 1e5f :2 0
1e61 1090 1e62 1e3c
1e61 0 1e63 1092
0 1e64 1094 1e67
:3 0 1e67 0 1e67
1e66 1e64 1e65 :6 0
1e69 55 :3 0 1097
1e6b 1099 1e6a 1e69
:2 0 1e6c 109b :2 0
1e6e 0 1e6e 1e6d
1e24 1e6c :6 0 1e70
1 :3 0 109d 1e72
185d 19f2 0 1e73
0 1e70 0 1e73
10a1 0 21ef 56
:3 0 2a :2 0 1e74
1e75 0 21ef af
:3 0 98 :3 0 17
:4 0 1f8 1 :8 0
1e90 e0 :4 0 1e7b
:3 0 f7 :3 0 da
:2 0 10a6 1e7e 1e7f
:3 0 15 :3 0 e1
:3 0 1e81 1e82 0
3d :2 0 1e83 1e84
0 1e86 10a9 1e8d
15 :3 0 e1 :3 0
1e87 1e88 0 e2
:2 0 1e89 1e8a 0
1e8c 10ab 1e8e 1e80
1e86 0 1e8f 0
1e8c 0 1e8f 10ad
0 1e90 10b0 1eda
e5 :3 0 15 :3 0
e1 :3 0 1e93 1e94
0 e4 :3 0 1e95
1e96 0 1ed0 c3
:3 0 c4 :3 0 1e98
1e99 0 c3 :3 0
d3 :3 0 1e9b 1e9c
0 e6 :2 0 2
:4 0 1f9 :2 0 d5
:2 0 2a :2 0 10b3
1ea1 1ea3 :3 0 10b6
1e9d 1ea5 1e9a 1ea7
1ea6 :2 0 c6 :3 0
d6 :3 0 1ea9 1eaa
0 c8 :4 0 1fa
:4 0 cb :2 0 cc
:3 0 10ba 1eae 1eb0
:3 0 cb :2 0 e9
:4 0 10bd 1eb2 1eb4
:3 0 cb :2 0 ea
:4 0 10c0 1eb6 1eb8
:3 0 cb :2 0 e4
:3 0 10c3 1eba 1ebc
:3 0 cb :2 0 eb
:4 0 10c6 1ebe 1ec0
:3 0 cb :2 0 a0
:3 0 ec :3 0 2a
:2 0 ed :2 0 10c9
1ec3 1ec7 10cd 1ec2
1ec9 :3 0 10d0 1eab
1ecb :2 0 1ecd 10d3
1ece 1ea8 1ecd 0
1ecf 10d5 0 1ed0
10d7 1ed3 :3 0 1ed3
0 1ed3 1ed2 1ed0
1ed1 :6 0 1ed5 57
:3 0 10da 1ed7 10dc
1ed6 1ed5 :2 0 1ed8
10de :2 0 1eda 0
1eda 1ed9 1e90 1ed8
:6 0 21ef 1 :3 0
1fb :3 0 91 :3 0
22 :3 0 92 :3 0
23 :4 0 1fc 1
:8 0 1ef7 e0 :4 0
1ee2 :3 0 f7 :3 0
da :2 0 10e2 1ee5
1ee6 :3 0 15 :3 0
e1 :3 0 1ee8 1ee9
0 3d :2 0 1eea
1eeb 0 1eed 10e5
1ef4 15 :3 0 e1
:3 0 1eee 1eef 0
e2 :2 0 1ef0 1ef1
0 1ef3 10e7 1ef5
1ee7 1eed 0 1ef6
0 1ef3 0 1ef6
10e9 0 1ef7 10ec
1f41 e5 :3 0 15
:3 0 e1 :3 0 1efa
1efb 0 e4 :3 0
1efc 1efd 0 1f37
c3 :3 0 c4 :3 0
1eff 1f00 0 c3
:3 0 d3 :3 0 1f02
1f03 0 e6 :2 0
2 :4 0 1fd :2 0
d5 :2 0 2a :2 0
10ef 1f08 1f0a :3 0
10f2 1f04 1f0c 1f01
1f0e 1f0d :2 0 c6
:3 0 d6 :3 0 1f10
1f11 0 c8 :4 0
1fe :4 0 cb :2 0
cc :3 0 10f6 1f15
1f17 :3 0 cb :2 0
e9 :4 0 10f9 1f19
1f1b :3 0 cb :2 0
ea :4 0 10fc 1f1d
1f1f :3 0 cb :2 0
e4 :3 0 10ff 1f21
1f23 :3 0 cb :2 0
eb :4 0 1102 1f25
1f27 :3 0 cb :2 0
a0 :3 0 ec :3 0
2a :2 0 ed :2 0
1105 1f2a 1f2e 1109
1f29 1f30 :3 0 110c
1f12 1f32 :2 0 1f34
110f 1f35 1f0f 1f34
0 1f36 1111 0
1f37 1113 1f3a :3 0
1f3a 0 1f3a 1f39
1f37 1f38 :6 0 1f3c
59 :3 0 1116 1f3e
1118 1f3d 1f3c :2 0
1f3f 111a :2 0 1f41
0 1f41 1f40 1ef7
1f3f :6 0 21ef 1
:3 0 84 :3 0 76
:3 0 3d :2 0 111c
1f43 1f46 da :2 0
2a :2 0 1121 1f48
1f4a :3 0 1f4b :2 0
84 :3 0 77 :3 0
3d :2 0 1124 1f4d
1f50 da :2 0 3d
:2 0 1129 1f52 1f54
:3 0 1f55 :2 0 1f4c
1f57 1f56 :2 0 4a
:3 0 3d :2 0 1f59
1f5a 0 21ec 40
:3 0 3d :2 0 1f5c
1f5d 0 21ec 1ff
:3 0 200 :3 0 1f5f
1f60 0 57 :3 0
2a :2 0 112c 1f61
1f64 13b :2 0 3d
:2 0 1131 1f66 1f68
:3 0 51 :3 0 13a
:2 0 1f6a 1f6b 0
1f6d 1134 1f72 51
:3 0 2a :2 0 1f6e
1f6f 0 1f71 1136
1f73 1f69 1f6d 0
1f74 0 1f71 0
1f74 1138 0 21ec
84 :3 0 f :3 0
3d :2 0 113b 1f75
1f78 da :2 0 3d
:2 0 1140 1f7a 1f7c
:3 0 44 :3 0 3d
:2 0 1f7e 1f7f 0
1f81 1143 1f82 1f7d
1f81 0 1f83 1145
0 21ec 6b :3 0
201 :3 0 31 :3 0
32 :3 0 84 :3 0
46 :3 0 3d :2 0
1147 1f88 1f8b 84
:3 0 47 :3 0 3d
:2 0 114a 1f8d 1f90
84 :3 0 52 :3 0
3d :2 0 114d 1f92
1f95 84 :3 0 4e
:3 0 3d :2 0 1150
1f97 1f9a 84 :3 0
48 :3 0 3d :2 0
1153 1f9c 1f9f 84
:3 0 45 :3 0 3d
:2 0 1156 1fa1 1fa4
84 :3 0 4f :3 0
3d :2 0 1159 1fa6
1fa9 84 :3 0 50
:3 0 3d :2 0 115c
1fab 1fae 44 :3 0
3f :3 0 49 :3 0
115f 1f85 1fb3 1f84
1fb4 0 21ec 84
:3 0 6b :3 0 3d
:2 0 116d 1fb6 1fb9
b0 :3 0 da :2 0
202 :3 0 1fbb 1fbd
0 1172 1fbc 1fbf
:3 0 c3 :3 0 c4
:3 0 1fc1 1fc2 0
c3 :3 0 d3 :3 0
1fc4 1fc5 0 203
:2 0 2 :4 0 204
:2 0 d5 :2 0 2a
:2 0 1175 1fca 1fcc
:3 0 1178 1fc6 1fce
1fc3 1fd0 1fcf :2 0
c6 :3 0 d6 :3 0
1fd2 1fd3 0 c8
:4 0 205 :4 0 cb
:2 0 cc :3 0 117c
1fd7 1fd9 :3 0 cb
:2 0 e9 :4 0 117f
1fdb 1fdd :3 0 cb
:2 0 f0 :4 0 1182
1fdf 1fe1 :3 0 cb
:2 0 84 :3 0 d0
:3 0 b0 :3 0 202
:3 0 1fe6 1fe7 0
1185 1fe5 1fe9 d1
:4 0 1187 1fe4 1fec
118a 1fe3 1fee :3 0
118d 1fd4 1ff0 :2 0
1ff2 1190 1ff3 1fd1
1ff2 0 1ff4 1192
0 201e c3 :3 0
c4 :3 0 1ff5 1ff6
0 c3 :3 0 d3
:3 0 1ff8 1ff9 0
2a :2 0 2 :4 0
206 :2 0 d5 :2 0
2a :2 0 1194 1ffe
2000 :3 0 1197 1ffa
2002 1ff7 2004 2003
:2 0 c6 :3 0 d6
:3 0 2006 2007 0
c8 :4 0 207 :4 0
cb :2 0 cc :3 0
119b 200b 200d :3 0
119e 2008 200f :2 0
2011 11a1 2012 2005
2011 0 2013 11a3
0 201e f5 :3 0
208 :3 0 2014 2015
0 b0 :3 0 202
:3 0 2017 2018 0
f7 :3 0 11a5 2016
201b :2 0 201e 140
:3 0 11a8 2097 84
:3 0 6b :3 0 3d
:2 0 11ac 201f 2022
13b :2 0 3d :2 0
11b1 2024 2026 :3 0
c3 :3 0 c4 :3 0
2028 2029 0 c3
:3 0 d3 :3 0 202b
202c 0 18 :2 0
2 :4 0 209 :2 0
d5 :2 0 2a :2 0
11b4 2031 2033 :3 0
11b7 202d 2035 202a
2037 2036 :2 0 c6
:3 0 d6 :3 0 2039
203a 0 c8 :4 0
20a :4 0 cb :2 0
cc :3 0 11bb 203e
2040 :3 0 cb :2 0
e9 :4 0 11be 2042
2044 :3 0 cb :2 0
f0 :4 0 11c1 2046
2048 :3 0 cb :2 0
84 :3 0 d0 :3 0
6b :3 0 11c4 204c
204e d1 :4 0 11c6
204b 2051 11c9 204a
2053 :3 0 cb :2 0
f2 :4 0 11cc 2055
2057 :3 0 cb :2 0
ce :4 0 11cf 2059
205b :3 0 cb :2 0
22 :3 0 11d2 205d
205f :3 0 cb :2 0
ce :4 0 11d5 2061
2063 :3 0 11d8 203b
2065 :2 0 2067 11db
2068 2038 2067 0
2069 11dd 0 2095
c3 :3 0 c4 :3 0
206a 206b 0 c3
:3 0 d3 :3 0 206d
206e 0 2a :2 0
2 :4 0 20b :2 0
d5 :2 0 2a :2 0
11df 2073 2075 :3 0
11e2 206f 2077 206c
2079 2078 :2 0 c6
:3 0 d6 :3 0 207b
207c 0 c8 :4 0
20c :4 0 cb :2 0
cc :3 0 11e6 2080
2082 :3 0 11e9 207d
2084 :2 0 2086 11ec
2087 207a 2086 0
2088 11ee 0 2095
f5 :3 0 f6 :3 0
2089 208a 0 84
:3 0 6b :3 0 3d
:2 0 11f0 208c 208f
22 :3 0 f7 :3 0
11f3 208b 2093 :2 0
2095 11f7 2096 2027
2095 0 2098 1fc0
201e 0 2098 11fb
0 21ec 84 :3 0
44 :3 0 3d :2 0
11fe 2099 209c da
:2 0 3d :2 0 1203
209e 20a0 :3 0 4e
:3 0 b0 :3 0 20d
:3 0 20a3 20a4 0
20a2 20a5 0 20a7
1206 20b8 4e :3 0
1ff :3 0 19a :3 0
20a9 20aa 0 84
:3 0 4e :3 0 3d
:2 0 1208 20ac 20af
b0 :3 0 20d :3 0
20b1 20b2 0 120b
20ab 20b4 20a8 20b5
0 20b7 120e 20b9
20a1 20a7 0 20ba
0 20b7 0 20ba
1210 0 21ec 6a
:3 0 5a :2 0 20bb
20bc 0 21ec 66
:3 0 20e :3 0 1e
:3 0 22 :3 0 22
:3 0 21 :3 0 6a
:3 0 41 :3 0 29
:3 0 29 :3 0 29
:3 0 29 :3 0 24
:3 0 26 :3 0 49
:3 0 3f :3 0 44
:3 0 46 :3 0 47
:3 0 40 :3 0 52
:3 0 2e :3 0 4a
:3 0 4e :3 0 48
:3 0 45 :3 0 51
:3 0 4f :3 0 53
:3 0 1a :3 0 3d
:2 0 3d :2 0 5a
:2 0 5a :2 0 1213
20bf 20e0 20be 20e1
0 21ec 84 :3 0
66 :3 0 3d :2 0
1234 20e3 20e6 da
:2 0 20f :2 0 1239
20e8 20ea :3 0 c3
:3 0 c4 :3 0 20ec
20ed 0 c3 :3 0
d3 :3 0 20ef 20f0
0 18 :2 0 2
:4 0 210 :2 0 d5
:2 0 2a :2 0 123c
20f5 20f7 :3 0 123f
20f1 20f9 20ee 20fb
20fa :2 0 c6 :3 0
d6 :3 0 20fd 20fe
0 c8 :4 0 211
:4 0 cb :2 0 cc
:3 0 1243 2102 2104
:3 0 cb :2 0 e9
:4 0 1246 2106 2108
:3 0 cb :2 0 f0
:4 0 1249 210a 210c
:3 0 cb :2 0 84
:3 0 d0 :3 0 b0
:3 0 212 :3 0 2111
2112 0 124c 2110
2114 d1 :4 0 124e
210f 2117 1251 210e
2119 :3 0 cb :2 0
f2 :4 0 1254 211b
211d :3 0 cb :2 0
ce :4 0 1257 211f
2121 :3 0 cb :2 0
21 :3 0 125a 2123
2125 :3 0 cb :2 0
ce :4 0 125d 2127
2129 :3 0 1260 20ff
212b :2 0 212d 1263
212e 20fc 212d 0
212f 1265 0 215a
c3 :3 0 c4 :3 0
2130 2131 0 c3
:3 0 d3 :3 0 2133
2134 0 2a :2 0
2 :4 0 213 :2 0
d5 :2 0 2a :2 0
1267 2139 213b :3 0
126a 2135 213d 2132
213f 213e :2 0 c6
:3 0 d6 :3 0 2141
2142 0 c8 :4 0
214 :4 0 cb :2 0
cc :3 0 126e 2146
2148 :3 0 1271 2143
214a :2 0 214c 1274
214d 2140 214c 0
214e 1276 0 215a
f5 :3 0 f6 :3 0
214f 2150 0 b0
:3 0 212 :3 0 2152
2153 0 21 :3 0
f7 :3 0 1278 2151
2157 :2 0 215a 140
:3 0 127c 21e9 84
:3 0 66 :3 0 3d
:2 0 1280 215b 215e
13b :2 0 3d :2 0
1285 2160 2162 :3 0
c3 :3 0 c4 :3 0
2164 2165 0 c3
:3 0 d3 :3 0 2167
2168 0 18 :2 0
2 :4 0 215 :2 0
d5 :2 0 2a :2 0
1288 216d 216f :3 0
128b 2169 2171 2166
2173 2172 :2 0 c6
:3 0 d6 :3 0 2175
2176 0 c8 :4 0
216 :4 0 cb :2 0
cc :3 0 128f 217a
217c :3 0 cb :2 0
e9 :4 0 1292 217e
2180 :3 0 cb :2 0
f0 :4 0 1295 2182
2184 :3 0 cb :2 0
84 :3 0 d0 :3 0
b0 :3 0 1ba :3 0
2189 218a 0 1298
2188 218c d1 :4 0
129a 2187 218f 129d
2186 2191 :3 0 cb
:2 0 f2 :4 0 12a0
2193 2195 :3 0 cb
:2 0 ce :4 0 12a3
2197 2199 :3 0 cb
:2 0 1c :3 0 12a6
219b 219d :3 0 cb
:2 0 ce :4 0 12a9
219f 21a1 :3 0 12ac
2177 21a3 :2 0 21a5
12af 21a6 2174 21a5
0 21a7 12b1 0
21d1 c3 :3 0 c4
:3 0 21a8 21a9 0
c3 :3 0 d3 :3 0
21ab 21ac 0 2a
:2 0 2 :4 0 217
:2 0 d5 :2 0 2a
:2 0 12b3 21b1 21b3
:3 0 12b6 21ad 21b5
21aa 21b7 21b6 :2 0
c6 :3 0 d6 :3 0
21b9 21ba 0 c8
:4 0 218 :4 0 cb
:2 0 cc :3 0 12ba
21be 21c0 :3 0 12bd
21bb 21c2 :2 0 21c4
12c0 21c5 21b8 21c4
0 21c6 12c2 0
21d1 f5 :3 0 f6
:3 0 21c7 21c8 0
b0 :3 0 1ba :3 0
21ca 21cb 0 1c
:3 0 f7 :3 0 12c4
21c9 21cf :2 0 21d1
12c8 21d2 2163 21d1
0 21eb 6b :3 0
139 :2 0 21d3 21d4
0 21e8 6b :3 0
219 :3 0 22 :3 0
1d :3 0 6b :3 0
84 :3 0 4f :3 0
3d :2 0 12cc 21db
21de 84 :3 0 3f
:3 0 3d :2 0 12cf
21e0 21e3 12d2 21d7
21e5 21d6 21e6 0
21e8 12d8 21ea 20eb
215a 0 21eb 0
21e8 0 21eb 12db
0 21ec 12df 21ed
1f58 21ec 0 21ee
12ea 0 21ef 12ec
21f0 1830 21ef 0
21f1 12f3 0 21f3
140 :3 0 12f5 22f7
a0 :3 0 6f :3 0
2a :2 0 2a :2 0
12fb 21f4 21f8 da
:2 0 1bd :4 0 1301
21fa 21fc :3 0 9a
:3 0 9f :3 0 a0
:3 0 a1 :3 0 9f
:3 0 a0 :3 0 a2
:3 0 a5 :3 0 a6
:3 0 a7 :3 0 a8
:3 0 81 :3 0 2b
:3 0 2d :3 0 78
:3 0 79 :3 0 74
:3 0 75 :3 0 90
:3 0 91 :3 0 22
:3 0 9b :3 0 22
:3 0 93 :3 0 92
:3 0 23 :4 0 21a
1 :8 0 221e 15
:3 0 e1 :3 0 2219
221a 0 e4 :3 0
221b 221c 0 221e
1304 2268 e5 :3 0
15 :3 0 e1 :3 0
2221 2222 0 e4
:3 0 2223 2224 0
225e c3 :3 0 c4
:3 0 2226 2227 0
c3 :3 0 d3 :3 0
2229 222a 0 e6
:2 0 2 :4 0 21b
:2 0 d5 :2 0 2a
:2 0 1307 222f 2231
:3 0 130a 222b 2233
2228 2235 2234 :2 0
c6 :3 0 d6 :3 0
2237 2238 0 c8
:4 0 21c :4 0 cb
:2 0 cc :3 0 130e
223c 223e :3 0 cb
:2 0 e9 :4 0 1311
2240 2242 :3 0 cb
:2 0 ea :4 0 1314
2244 2246 :3 0 cb
:2 0 e4 :3 0 1317
2248 224a :3 0 cb
:2 0 eb :4 0 131a
224c 224e :3 0 cb
:2 0 a0 :3 0 ec
:3 0 2a :2 0 ed
:2 0 131d 2251 2255
1321 2250 2257 :3 0
1324 2239 2259 :2 0
225b 1327 225c 2236
225b 0 225d 1329
0 225e 132b 2261
:3 0 2261 0 2261
2260 225e 225f :6 0
2263 5b :3 0 132e
2265 1330 2264 2263
:2 0 2266 1332 :2 0
2268 0 2268 2267
221e 2266 :6 0 2296
1 :3 0 15 :3 0
e1 :3 0 226a 226b
0 15 :3 0 da
:2 0 157 :3 0 226d
226f 0 1336 226e
2271 :3 0 2272 :2 0
81 :3 0 165 :2 0
1339 2275 2276 :3 0
2277 :2 0 2278 :2 0
2273 227a 2279 :2 0
7a :3 0 1be :2 0
2a :2 0 133b 227d
227f :3 0 227c 2280
0 2293 15 :3 0
e1 :3 0 2282 2283
0 1bf :3 0 22
:3 0 22 :3 0 81
:3 0 2b :3 0 2d
:3 0 74 :3 0 75
:3 0 7a :3 0 79
:3 0 78 :3 0 133d
2285 2290 2284 2291
0 2293 1348 2294
227b 2293 0 2295
134b 0 2296 134d
2297 21fd 2296 0
22f9 9a :3 0 a5
:3 0 81 :3 0 78
:3 0 90 :3 0 91
:3 0 22 :3 0 9b
:3 0 22 :3 0 92
:3 0 23 :3 0 93
:4 0 21d 1 :8 0
22aa 15 :3 0 e1
:3 0 22a5 22a6 0
e4 :3 0 22a7 22a8
0 22aa 1350 22f4
e5 :3 0 15 :3 0
e1 :3 0 22ad 22ae
0 e4 :3 0 22af
22b0 0 22ea c3
:3 0 c4 :3 0 22b2
22b3 0 c3 :3 0
d3 :3 0 22b5 22b6
0 e6 :2 0 2
:4 0 21e :2 0 d5
:2 0 2a :2 0 1353
22bb 22bd :3 0 1356
22b7 22bf 22b4 22c1
22c0 :2 0 c6 :3 0
d6 :3 0 22c3 22c4
0 c8 :4 0 21f
:4 0 cb :2 0 cc
:3 0 135a 22c8 22ca
:3 0 cb :2 0 e9
:4 0 135d 22cc 22ce
:3 0 cb :2 0 ea
:4 0 1360 22d0 22d2
:3 0 cb :2 0 e4
:3 0 1363 22d4 22d6
:3 0 cb :2 0 eb
:4 0 1366 22d8 22da
:3 0 cb :2 0 a0
:3 0 ec :3 0 2a
:2 0 ed :2 0 1369
22dd 22e1 136d 22dc
22e3 :3 0 1370 22c5
22e5 :2 0 22e7 1373
22e8 22c2 22e7 0
22e9 1375 0 22ea
1377 22ed :3 0 22ed
0 22ed 22ec 22ea
22eb :6 0 22ef 5d
:3 0 137a 22f1 137c
22f0 22ef :2 0 22f2
137e :2 0 22f4 0
22f4 22f3 22aa 22f2
:6 0 22f6 1 :3 0
1380 22f8 16b5 21f3
0 22f9 0 22f6
0 22f9 1382 0
22fb 140 :3 0 1386
23ff a0 :3 0 6f
:3 0 2a :2 0 2a
:2 0 1388 22fc 2300
da :2 0 1bd :4 0
138e 2302 2304 :3 0
9a :3 0 9f :3 0
a0 :3 0 a1 :3 0
9f :3 0 a0 :3 0
a2 :3 0 a5 :3 0
a6 :3 0 a7 :3 0
a8 :3 0 81 :3 0
2b :3 0 2d :3 0
78 :3 0 79 :3 0
74 :3 0 75 :3 0
90 :3 0 91 :3 0
22 :3 0 9b :3 0
22 :3 0 92 :3 0
23 :3 0 93 :4 0
220 1 :8 0 2326
15 :3 0 e1 :3 0
2321 2322 0 e4
:3 0 2323 2324 0
2326 1391 2370 e5
:3 0 15 :3 0 e1
:3 0 2329 232a 0
e4 :3 0 232b 232c
0 2366 c3 :3 0
c4 :3 0 232e 232f
0 c3 :3 0 d3
:3 0 2331 2332 0
e6 :2 0 2 :4 0
221 :2 0 d5 :2 0
2a :2 0 1394 2337
2339 :3 0 1397 2333
233b 2330 233d 233c
:2 0 c6 :3 0 d6
:3 0 233f 2340 0
c8 :4 0 222 :4 0
cb :2 0 cc :3 0
139b 2344 2346 :3 0
cb :2 0 e9 :4 0
139e 2348 234a :3 0
cb :2 0 ea :4 0
13a1 234c 234e :3 0
cb :2 0 e4 :3 0
13a4 2350 2352 :3 0
cb :2 0 eb :4 0
13a7 2354 2356 :3 0
cb :2 0 a0 :3 0
ec :3 0 2a :2 0
ed :2 0 13aa 2359
235d 13ae 2358 235f
:3 0 13b1 2341 2361
:2 0 2363 13b4 2364
233e 2363 0 2365
13b6 0 2366 13b8
2369 :3 0 2369 0
2369 2368 2366 2367
:6 0 236b 5f :3 0
13bb 236d 13bd 236c
236b :2 0 236e 13bf
:2 0 2370 0 2370
236f 2326 236e :6 0
239e 1 :3 0 15
:3 0 e1 :3 0 2372
2373 0 15 :3 0
da :2 0 157 :3 0
2375 2377 0 13c3
2376 2379 :3 0 237a
:2 0 81 :3 0 165
:2 0 13c6 237d 237e
:3 0 237f :2 0 2380
:2 0 237b 2382 2381
:2 0 7a :3 0 1be
:2 0 2a :2 0 13c8
2385 2387 :3 0 2384
2388 0 239b 15
:3 0 e1 :3 0 238a
238b 0 1bf :3 0
22 :3 0 22 :3 0
81 :3 0 2b :3 0
2d :3 0 74 :3 0
75 :3 0 7a :3 0
79 :3 0 78 :3 0
13ca 238d 2398 238c
2399 0 239b 13d5
239c 2383 239b 0
239d 13d8 0 239e
13da 239f 2305 239e
0 2401 9a :3 0
a5 :3 0 81 :3 0
78 :3 0 90 :3 0
91 :3 0 22 :3 0
9b :3 0 22 :3 0
92 :3 0 23 :3 0
93 :4 0 223 1
:8 0 23b2 15 :3 0
e1 :3 0 23ad 23ae
0 e4 :3 0 23af
23b0 0 23b2 13dd
23fc e5 :3 0 15
:3 0 e1 :3 0 23b5
23b6 0 e4 :3 0
23b7 23b8 0 23f2
c3 :3 0 c4 :3 0
23ba 23bb 0 c3
:3 0 d3 :3 0 23bd
23be 0 e6 :2 0
2 :4 0 224 :2 0
d5 :2 0 2a :2 0
13e0 23c3 23c5 :3 0
13e3 23bf 23c7 23bc
23c9 23c8 :2 0 c6
:3 0 d6 :3 0 23cb
23cc 0 c8 :4 0
225 :4 0 cb :2 0
cc :3 0 13e7 23d0
23d2 :3 0 cb :2 0
e9 :4 0 13ea 23d4
23d6 :3 0 cb :2 0
ea :4 0 13ed 23d8
23da :3 0 cb :2 0
e4 :3 0 13f0 23dc
23de :3 0 cb :2 0
eb :4 0 13f3 23e0
23e2 :3 0 cb :2 0
a0 :3 0 ec :3 0
2a :2 0 ed :2 0
13f6 23e5 23e9 13fa
23e4 23eb :3 0 13fd
23cd 23ed :2 0 23ef
1400 23f0 23ca 23ef
0 23f1 1402 0
23f2 1404 23f5 :3 0
23f5 0 23f5 23f4
23f2 23f3 :6 0 23f7
61 :3 0 1407 23f9
1409 23f8 23f7 :2 0
23fa 140b :2 0 23fc
0 23fc 23fb 23b2
23fa :6 0 23fe 1
:3 0 140d 2400 16aa
22fb 0 2401 0
23fe 0 2401 140f
0 4b22 1e :3 0
226 :2 0 1413 2403
2404 :3 0 2405 :2 0
2406 :2 0 84 :3 0
4c :3 0 3d :2 0
1415 2408 240b 10a
:2 0 3d :2 0 141a
240d 240f :3 0 2410
:2 0 2407 2412 2411
:2 0 84 :3 0 63
:3 0 3d :2 0 141d
2414 2417 da :2 0
3d :2 0 1422 2419
241b :3 0 241c :2 0
2413 241e 241d :2 0
1e :3 0 de :4 0
2420 2421 0 2750
1e :3 0 171 :4 0
2424 2425 :3 0 2423
2426 0 2750 84
:3 0 e :3 0 3d
:2 0 1425 2428 242b
da :2 0 e2 :2 0
142a 242d 242f :3 0
7e :3 0 84 :3 0
44 :3 0 3d :2 0
142d 2432 2435 2431
2436 0 2438 1430
2439 2430 2438 0
243a 1432 0 2750
84 :3 0 62 :3 0
3d :2 0 1434 243b
243e da :2 0 3d
:2 0 1439 2440 2442
:3 0 2443 :2 0 84
:3 0 61 :3 0 3d
:2 0 143c 2445 2448
da :2 0 3d :2 0
1441 244a 244c :3 0
244d :2 0 2444 244f
244e :2 0 84 :3 0
62 :3 0 3d :2 0
1444 2451 2454 da
:2 0 3d :2 0 1449
2456 2458 :3 0 2459
:2 0 84 :3 0 61
:3 0 3d :2 0 144c
245b 245e da :2 0
3d :2 0 1451 2460
2462 :3 0 2463 :2 0
245a 2465 2464 :2 0
58 :3 0 84 :3 0
58 :3 0 3d :2 0
1454 2468 246b 1d2
:2 0 84 :3 0 5e
:3 0 3d :2 0 1457
246e 2471 145a 246d
2473 :3 0 2467 2474
0 253a 5c :3 0
84 :3 0 5c :3 0
3d :2 0 145d 2477
247a 1d2 :2 0 84
:3 0 5e :3 0 3d
:2 0 1460 247d 2480
1463 247c 2482 :3 0
2476 2483 0 253a
5b :3 0 84 :3 0
5b :3 0 3d :2 0
1466 2486 2489 1d2
:2 0 84 :3 0 5e
:3 0 3d :2 0 1469
248c 248f 146c 248b
2491 :3 0 2485 2492
0 253a 5d :3 0
84 :3 0 5d :3 0
3d :2 0 146f 2495
2498 1d2 :2 0 84
:3 0 5e :3 0 3d
:2 0 1472 249b 249e
1475 249a 24a0 :3 0
2494 24a1 0 253a
90 :3 0 9a :3 0
98 :3 0 9b :3 0
91 :3 0 227 :3 0
228 :3 0 229 :3 0
22a :3 0 a1 :3 0
a2 :3 0 15d :3 0
22b :3 0 22c :3 0
92 :3 0 93 :3 0
94 :3 0 a5 :3 0
a6 :3 0 a7 :3 0
1d3 :3 0 a8 :3 0
1d4 :3 0 f9 :3 0
fa :3 0 178 :3 0
1e :3 0 1c :3 0
22 :3 0 22 :3 0
b0 :3 0 22d :3 0
b0 :3 0 22e :3 0
31 :3 0 32 :3 0
31 :3 0 32 :3 0
31 :3 0 32 :3 0
21 :3 0 2e :3 0
1e :3 0 78 :3 0
79 :3 0 58 :3 0
5c :3 0 5b :3 0
5d :3 0 7f :3 0
80 :3 0 7b :4 0
22f 1 :8 0 24ed
e0 :4 0 24d8 :3 0
f7 :3 0 da :2 0
147a 24db 24dc :3 0
15 :3 0 e1 :3 0
24de 24df 0 3d
:2 0 24e0 24e1 0
24e3 147d 24ea 15
:3 0 e1 :3 0 24e4
24e5 0 e2 :2 0
24e6 24e7 0 24e9
147f 24eb 24dd 24e3
0 24ec 0 24e9
0 24ec 1481 0
24ed 1484 2537 e5
:3 0 15 :3 0 e1
:3 0 24f0 24f1 0
e4 :3 0 24f2 24f3
0 252d c3 :3 0
c4 :3 0 24f5 24f6
0 c3 :3 0 d3
:3 0 24f8 24f9 0
e6 :2 0 2 :4 0
230 :2 0 d5 :2 0
2a :2 0 1487 24fe
2500 :3 0 148a 24fa
2502 24f7 2504 2503
:2 0 c6 :3 0 d6
:3 0 2506 2507 0
c8 :4 0 231 :4 0
cb :2 0 cc :3 0
148e 250b 250d :3 0
cb :2 0 e9 :4 0
1491 250f 2511 :3 0
cb :2 0 ea :4 0
1494 2513 2515 :3 0
cb :2 0 e4 :3 0
1497 2517 2519 :3 0
cb :2 0 eb :4 0
149a 251b 251d :3 0
cb :2 0 a0 :3 0
ec :3 0 2a :2 0
ed :2 0 149d 2520
2524 14a1 251f 2526
:3 0 14a4 2508 2528
:2 0 252a 14a7 252b
2505 252a 0 252c
14a9 0 252d 14ab
2530 :3 0 2530 0
2530 252f 252d 252e
:6 0 2532 63 :3 0
14ae 2534 14b0 2533
2532 :2 0 2535 14b2
:2 0 2537 0 2537
2536 24ed 2535 :6 0
253a 1 :3 0 140
:3 0 14b4 26af 84
:3 0 61 :3 0 3d
:2 0 14ba 253b 253e
da :2 0 3d :2 0
14bf 2540 2542 :3 0
5b :3 0 84 :3 0
5b :3 0 3d :2 0
14c2 2545 2548 1d2
:2 0 84 :3 0 5e
:3 0 3d :2 0 14c5
254b 254e 14c8 254a
2550 :3 0 2544 2551
0 25f8 5d :3 0
84 :3 0 5d :3 0
3d :2 0 14cb 2554
2557 1d2 :2 0 84
:3 0 5e :3 0 3d
:2 0 14ce 255a 255d
14d1 2559 255f :3 0
2553 2560 0 25f8
90 :3 0 9a :3 0
98 :3 0 9b :3 0
91 :3 0 227 :3 0
228 :3 0 229 :3 0
22a :3 0 a1 :3 0
a2 :3 0 15d :3 0
22b :3 0 22c :3 0
92 :3 0 93 :3 0
94 :3 0 a5 :3 0
a6 :3 0 a7 :3 0
1d3 :3 0 a8 :3 0
1d4 :3 0 f9 :3 0
fa :3 0 178 :3 0
1e :3 0 1c :3 0
22 :3 0 22 :3 0
b0 :3 0 22d :3 0
b0 :3 0 22e :3 0
31 :3 0 32 :3 0
31 :3 0 32 :3 0
31 :3 0 32 :3 0
21 :3 0 2e :3 0
1e :3 0 78 :3 0
79 :3 0 58 :3 0
5c :3 0 5b :3 0
5d :3 0 7f :3 0
80 :3 0 7b :4 0
232 1 :8 0 25ac
e0 :4 0 2597 :3 0
f7 :3 0 da :2 0
14d6 259a 259b :3 0
15 :3 0 e1 :3 0
259d 259e 0 3d
:2 0 259f 25a0 0
25a2 14d9 25a9 15
:3 0 e1 :3 0 25a3
25a4 0 e2 :2 0
25a5 25a6 0 25a8
14db 25aa 259c 25a2
0 25ab 0 25a8
0 25ab 14dd 0
25ac 14e0 25f6 e5
:3 0 15 :3 0 e1
:3 0 25af 25b0 0
e4 :3 0 25b1 25b2
0 25ec c3 :3 0
c4 :3 0 25b4 25b5
0 c3 :3 0 d3
:3 0 25b7 25b8 0
e6 :2 0 2 :4 0
233 :2 0 d5 :2 0
2a :2 0 14e3 25bd
25bf :3 0 14e6 25b9
25c1 25b6 25c3 25c2
:2 0 c6 :3 0 d6
:3 0 25c5 25c6 0
c8 :4 0 234 :4 0
cb :2 0 cc :3 0
14ea 25ca 25cc :3 0
cb :2 0 e9 :4 0
14ed 25ce 25d0 :3 0
cb :2 0 ea :4 0
14f0 25d2 25d4 :3 0
cb :2 0 e4 :3 0
14f3 25d6 25d8 :3 0
cb :2 0 eb :4 0
14f6 25da 25dc :3 0
cb :2 0 a0 :3 0
ec :3 0 2a :2 0
ed :2 0 14f9 25df
25e3 14fd 25de 25e5
:3 0 1500 25c7 25e7
:2 0 25e9 1503 25ea
25c4 25e9 0 25eb
1505 0 25ec 1507
25ef :3 0 25ef 0
25ef 25ee 25ec 25ed
:6 0 25f1 65 :3 0
150a 25f3 150c 25f2
25f1 :2 0 25f4 150e
:2 0 25f6 0 25f6
25f5 25ac 25f4 :6 0
25f8 1 :3 0 1510
25f9 2543 25f8 0
26b1 58 :3 0 84
:3 0 58 :3 0 3d
:2 0 1514 25fb 25fe
1d2 :2 0 84 :3 0
5e :3 0 3d :2 0
1517 2601 2604 151a
2600 2606 :3 0 25fa
2607 0 26ae 5c
:3 0 84 :3 0 5c
:3 0 3d :2 0 151d
260a 260d 1d2 :2 0
84 :3 0 5e :3 0
3d :2 0 1520 2610
2613 1523 260f 2615
:3 0 2609 2616 0
26ae 90 :3 0 9a
:3 0 98 :3 0 9b
:3 0 91 :3 0 227
:3 0 228 :3 0 229
:3 0 22a :3 0 a1
:3 0 a2 :3 0 15d
:3 0 22b :3 0 22c
:3 0 92 :3 0 93
:3 0 94 :3 0 a5
:3 0 a6 :3 0 a7
:3 0 1d3 :3 0 a8
:3 0 1d4 :3 0 f9
:3 0 fa :3 0 178
:3 0 1e :3 0 1c
:3 0 22 :3 0 22
:3 0 b0 :3 0 22d
:3 0 b0 :3 0 22e
:3 0 31 :3 0 32
:3 0 31 :3 0 32
:3 0 31 :3 0 32
:3 0 21 :3 0 2e
:3 0 1e :3 0 78
:3 0 79 :3 0 58
:3 0 5c :3 0 5b
:3 0 5d :3 0 7f
:3 0 80 :3 0 7b
:4 0 232 1 :8 0
2662 e0 :4 0 264d
:3 0 f7 :3 0 da
:2 0 1528 2650 2651
:3 0 15 :3 0 e1
:3 0 2653 2654 0
3d :2 0 2655 2656
0 2658 152b 265f
15 :3 0 e1 :3 0
2659 265a 0 e2
:2 0 265b 265c 0
265e 152d 2660 2652
2658 0 2661 0
265e 0 2661 152f
0 2662 1532 26ac
e5 :3 0 15 :3 0
e1 :3 0 2665 2666
0 e4 :3 0 2667
2668 0 26a2 c3
:3 0 c4 :3 0 266a
266b 0 c3 :3 0
d3 :3 0 266d 266e
0 e6 :2 0 2
:4 0 235 :2 0 d5
:2 0 2a :2 0 1535
2673 2675 :3 0 1538
266f 2677 266c 2679
2678 :2 0 c6 :3 0
d6 :3 0 267b 267c
0 c8 :4 0 236
:4 0 cb :2 0 cc
:3 0 153c 2680 2682
:3 0 cb :2 0 e9
:4 0 153f 2684 2686
:3 0 cb :2 0 ea
:4 0 1542 2688 268a
:3 0 cb :2 0 e4
:3 0 1545 268c 268e
:3 0 cb :2 0 eb
:4 0 1548 2690 2692
:3 0 cb :2 0 a0
:3 0 ec :3 0 2a
:2 0 ed :2 0 154b
2695 2699 154f 2694
269b :3 0 1552 267d
269d :2 0 269f 1555
26a0 267a 269f 0
26a1 1557 0 26a2
1559 26a5 :3 0 26a5
0 26a5 26a4 26a2
26a3 :6 0 26a7 67
:3 0 155c 26a9 155e
26a8 26a7 :2 0 26aa
1560 :2 0 26ac 0
26ac 26ab 2662 26aa
:6 0 26ae 1 :3 0
1562 26b0 2466 253a
0 26b1 0 26ae
0 26b1 1566 0
26b2 156a 274a 90
:3 0 9a :3 0 98
:3 0 9b :3 0 91
:3 0 227 :3 0 228
:3 0 229 :3 0 22a
:3 0 a1 :3 0 a2
:3 0 15d :3 0 22b
:3 0 22c :3 0 92
:3 0 93 :3 0 94
:3 0 a5 :3 0 a6
:3 0 a7 :3 0 1d3
:3 0 a8 :3 0 1d4
:3 0 f9 :3 0 fa
:3 0 178 :3 0 1e
:3 0 1c :3 0 22
:3 0 22 :3 0 b0
:3 0 22d :3 0 b0
:3 0 22e :3 0 31
:3 0 32 :3 0 31
:3 0 32 :3 0 31
:3 0 32 :3 0 21
:3 0 2e :3 0 1e
:3 0 78 :3 0 79
:3 0 58 :3 0 5c
:3 0 5b :3 0 5d
:3 0 7f :3 0 80
:3 0 7b :4 0 237
1 :8 0 26fd e0
:4 0 26e8 :3 0 f7
:3 0 da :2 0 156e
26eb 26ec :3 0 15
:3 0 e1 :3 0 26ee
26ef 0 3d :2 0
26f0 26f1 0 26f3
1571 26fa 15 :3 0
e1 :3 0 26f4 26f5
0 e2 :2 0 26f6
26f7 0 26f9 1573
26fb 26ed 26f3 0
26fc 0 26f9 0
26fc 1575 0 26fd
1578 2747 e5 :3 0
15 :3 0 e1 :3 0
2700 2701 0 e4
:3 0 2702 2703 0
273d c3 :3 0 c4
:3 0 2705 2706 0
c3 :3 0 d3 :3 0
2708 2709 0 e6
:2 0 2 :4 0 238
:2 0 d5 :2 0 2a
:2 0 157b 270e 2710
:3 0 157e 270a 2712
2707 2714 2713 :2 0
c6 :3 0 d6 :3 0
2716 2717 0 c8
:4 0 239 :4 0 cb
:2 0 cc :3 0 1582
271b 271d :3 0 cb
:2 0 e9 :4 0 1585
271f 2721 :3 0 cb
:2 0 ea :4 0 1588
2723 2725 :3 0 cb
:2 0 e4 :3 0 158b
2727 2729 :3 0 cb
:2 0 eb :4 0 158e
272b 272d :3 0 cb
:2 0 a0 :3 0 ec
:3 0 2a :2 0 ed
:2 0 1591 2730 2734
1595 272f 2736 :3 0
1598 2718 2738 :2 0
273a 159b 273b 2715
273a 0 273c 159d
0 273d 159f 2740
:3 0 2740 0 2740
273f 273d 273e :6 0
2742 69 :3 0 15a2
2744 15a4 2743 2742
:2 0 2745 15a6 :2 0
2747 0 2747 2746
26fd 2745 :6 0 2749
1 :3 0 15a8 274b
2450 26b2 0 274c
0 2749 0 274c
15aa 0 2750 56
:3 0 2a :2 0 274d
274e 0 2750 15ad
2751 241f 2750 0
2752 15b3 0 4b22
2f :3 0 a0 :3 0
2f :3 0 cb :2 0
23a :4 0 15b5 2756
2758 :3 0 2a :2 0
30 :2 0 15b8 2754
275c 2753 275d 0
4b22 1d :3 0 de
:4 0 275f 2760 0
4b22 3f :3 0 9
:3 0 2762 2763 0
4b22 17e :3 0 39
:3 0 12e :3 0 12f
:3 0 23 :4 0 17f
1 :8 0 2770 15
:3 0 e1 :3 0 276b
276c 0 e4 :3 0
276d 276e 0 2770
15bc 27ba e5 :3 0
15 :3 0 e1 :3 0
2773 2774 0 e4
:3 0 2775 2776 0
27b0 c3 :3 0 c4
:3 0 2778 2779 0
c3 :3 0 d3 :3 0
277b 277c 0 e6
:2 0 2 :4 0 23b
:2 0 d5 :2 0 2a
:2 0 15bf 2781 2783
:3 0 15c2 277d 2785
277a 2787 2786 :2 0
c6 :3 0 d6 :3 0
2789 278a 0 c8
:4 0 23c :4 0 cb
:2 0 cc :3 0 15c6
278e 2790 :3 0 cb
:2 0 e9 :4 0 15c9
2792 2794 :3 0 cb
:2 0 ea :4 0 15cc
2796 2798 :3 0 cb
:2 0 e4 :3 0 15cf
279a 279c :3 0 cb
:2 0 eb :4 0 15d2
279e 27a0 :3 0 cb
:2 0 a0 :3 0 ec
:3 0 2a :2 0 ed
:2 0 15d5 27a3 27a7
15d9 27a2 27a9 :3 0
15dc 278b 27ab :2 0
27ad 15df 27ae 2788
27ad 0 27af 15e1
0 27b0 15e3 27b3
:3 0 27b3 0 27b3
27b2 27b0 27b1 :6 0
27b5 6b :3 0 15e6
27b7 15e8 27b6 27b5
:2 0 27b8 15ea :2 0
27ba 0 27ba 27b9
2770 27b8 :6 0 4b22
1 :3 0 74 :3 0
5a :2 0 27bc 27bd
0 4b22 75 :3 0
5a :2 0 27bf 27c0
0 4b22 43 :3 0
3d :2 0 27c2 27c3
0 4b22 82 :3 0
da :2 0 3d :2 0
15ee 27c6 27c8 :3 0
27c9 :2 0 84 :3 0
77 :3 0 3d :2 0
15f1 27cb 27ce da
:2 0 2a :2 0 15f6
27d0 27d2 :3 0 27d3
:2 0 27ca 27d5 27d4
:2 0 23d :3 0 99
:3 0 a1 :3 0 24
:3 0 ae :3 0 a4
:3 0 90 :3 0 99
:3 0 99 :3 0 91
:3 0 22 :3 0 99
:3 0 92 :3 0 23
:3 0 99 :3 0 9b
:3 0 a4 :3 0 8b
:3 0 a4 :3 0 f8
:3 0 b0 :3 0 b1
:3 0 b0 :3 0 b2
:3 0 b0 :3 0 b3
:3 0 b0 :3 0 b4
:3 0 b0 :3 0 b5
:3 0 b0 :3 0 b6
:3 0 b0 :3 0 b7
:3 0 b0 :3 0 b8
:3 0 b0 :3 0 b9
:3 0 b0 :3 0 ba
:3 0 b0 :3 0 bb
:3 0 b0 :3 0 bc
:3 0 b0 :3 0 bd
:3 0 b0 :3 0 be
:3 0 b0 :3 0 bf
:3 0 a4 :3 0 c0
:3 0 2f :4 0 23e
1 :8 0 2812 15
:3 0 e1 :3 0 280d
280e 0 e4 :3 0
280f 2810 0 2812
15f9 285c e5 :3 0
15 :3 0 e1 :3 0
2815 2816 0 e4
:3 0 2817 2818 0
2852 c3 :3 0 c4
:3 0 281a 281b 0
c3 :3 0 d3 :3 0
281d 281e 0 e6
:2 0 2 :4 0 23f
:2 0 d5 :2 0 2a
:2 0 15fc 2823 2825
:3 0 15ff 281f 2827
281c 2829 2828 :2 0
c6 :3 0 d6 :3 0
282b 282c 0 c8
:4 0 240 :4 0 cb
:2 0 cc :3 0 1603
2830 2832 :3 0 cb
:2 0 e9 :4 0 1606
2834 2836 :3 0 cb
:2 0 ea :4 0 1609
2838 283a :3 0 cb
:2 0 e4 :3 0 160c
283c 283e :3 0 cb
:2 0 eb :4 0 160f
2840 2842 :3 0 cb
:2 0 a0 :3 0 ec
:3 0 2a :2 0 ed
:2 0 1612 2845 2849
1616 2844 284b :3 0
1619 282d 284d :2 0
284f 161c 2850 282a
284f 0 2851 161e
0 2852 1620 2855
:3 0 2855 0 2855
2854 2852 2853 :6 0
2857 6d :3 0 1623
2859 1625 2858 2857
:2 0 285a 1627 :2 0
285c 0 285c 285b
2812 285a :6 0 285e
1 :3 0 1629 285f
27d6 285e 0 2860
162b 0 4b22 24
:3 0 31 :3 0 2861
2862 0 4b22 df
:3 0 96 :4 0 2867
:2 0 4b22 2865 2868
:3 0 241 :3 0 96
:3 0 1b :3 0 1d
:3 0 20 :3 0 41
:3 0 3f :3 0 7e
:3 0 72 :3 0 73
:3 0 27 :3 0 28
:3 0 49 :3 0 1f
:3 0 78 :3 0 79
:3 0 74 :3 0 75
:3 0 44 :3 0 46
:3 0 47 :3 0 48
:3 0 4e :4 0 2881
:2 0 3eea 286a 2882
:3 0 162d :3 0 96
:3 0 e0 :3 0 2883
2884 :3 0 15 :3 0
e1 :3 0 2886 2887
0 3d :2 0 2888
2889 0 288b 1643
2892 15 :3 0 e1
:3 0 288c 288d 0
e2 :2 0 288e 288f
0 2891 1645 2893
2885 288b 0 2894
0 2891 0 2894
1647 0 3eea 15
:3 0 e1 :3 0 2895
2896 0 15 :3 0
13b :2 0 157 :3 0
2898 289a 0 164c
2899 289c :3 0 289d
:2 0 242 :8 0 28a1
164f 28a2 289e 28a1
0 28a3 1651 0
3eea 84 :3 0 3f
:3 0 3d :2 0 1653
28a4 28a7 da :2 0
3d :2 0 1658 28a9
28ab :3 0 71 :3 0
243 :3 0 1b :3 0
3d :2 0 165b 28ae
28b1 28ad 28b2 0
2b14 af :3 0 98
:3 0 1b :4 0 244
1 :8 0 28cd e0
:4 0 28b8 :3 0 f7
:3 0 da :2 0 1660
28bb 28bc :3 0 15
:3 0 e1 :3 0 28be
28bf 0 3d :2 0
28c0 28c1 0 28c3
1663 28ca 15 :3 0
e1 :3 0 28c4 28c5
0 e2 :2 0 28c6
28c7 0 28c9 1665
28cb 28bd 28c3 0
28cc 0 28c9 0
28cc 1667 0 28cd
166a 2917 e5 :3 0
15 :3 0 e1 :3 0
28d0 28d1 0 e4
:3 0 28d2 28d3 0
290d c3 :3 0 c4
:3 0 28d5 28d6 0
c3 :3 0 d3 :3 0
28d8 28d9 0 e6
:2 0 2 :4 0 245
:2 0 d5 :2 0 2a
:2 0 166d 28de 28e0
:3 0 1670 28da 28e2
28d7 28e4 28e3 :2 0
c6 :3 0 d6 :3 0
28e6 28e7 0 c8
:4 0 246 :4 0 cb
:2 0 cc :3 0 1674
28eb 28ed :3 0 cb
:2 0 e9 :4 0 1677
28ef 28f1 :3 0 cb
:2 0 ea :4 0 167a
28f3 28f5 :3 0 cb
:2 0 e4 :3 0 167d
28f7 28f9 :3 0 cb
:2 0 eb :4 0 1680
28fb 28fd :3 0 cb
:2 0 a0 :3 0 ec
:3 0 2a :2 0 ed
:2 0 1683 2900 2904
1687 28ff 2906 :3 0
168a 28e8 2908 :2 0
290a 168d 290b 28e5
290a 0 290c 168f
0 290d 1691 2910
:3 0 2910 0 2910
290f 290d 290e :6 0
2912 70 :3 0 1694
2914 1696 2913 2912
:2 0 2915 1698 :2 0
2917 0 2917 2916
28cd 2915 :6 0 2b14
6f :3 0 90 :3 0
9a :3 0 1d :4 0
247 1 :8 0 2932
e0 :4 0 291d :3 0
f7 :3 0 da :2 0
169c 2920 2921 :3 0
15 :3 0 e1 :3 0
2923 2924 0 3d
:2 0 2925 2926 0
2928 169f 292f 15
:3 0 e1 :3 0 2929
292a 0 e2 :2 0
292b 292c 0 292e
16a1 2930 2922 2928
0 2931 0 292e
0 2931 16a3 0
2932 16a6 297c e5
:3 0 15 :3 0 e1
:3 0 2935 2936 0
e4 :3 0 2937 2938
0 2972 c3 :3 0
c4 :3 0 293a 293b
0 c3 :3 0 d3
:3 0 293d 293e 0
e6 :2 0 2 :4 0
248 :2 0 d5 :2 0
2a :2 0 16a9 2943
2945 :3 0 16ac 293f
2947 293c 2949 2948
:2 0 c6 :3 0 d6
:3 0 294b 294c 0
c8 :4 0 249 :4 0
cb :2 0 cc :3 0
16b0 2950 2952 :3 0
cb :2 0 e9 :4 0
16b3 2954 2956 :3 0
cb :2 0 ea :4 0
16b6 2958 295a :3 0
cb :2 0 e4 :3 0
16b9 295c 295e :3 0
cb :2 0 eb :4 0
16bc 2960 2962 :3 0
cb :2 0 a0 :3 0
ec :3 0 2a :2 0
ed :2 0 16bf 2965
2969 16c3 2964 296b
:3 0 16c6 294d 296d
:2 0 296f 16c9 2970
294a 296f 0 2971
16cb 0 2972 16cd
2975 :3 0 2975 0
2975 2974 2972 2973
:6 0 2977 72 :3 0
16d0 2979 16d2 2978
2977 :2 0 297a 16d4
:2 0 297c 0 297c
297b 2932 297a :6 0
2b14 6f :3 0 24a
:3 0 9a :3 0 1d
:4 0 24b 1 :8 0
2997 e0 :4 0 2982
:3 0 f7 :3 0 da
:2 0 16d8 2985 2986
:3 0 15 :3 0 e1
:3 0 2988 2989 0
3d :2 0 298a 298b
0 298d 16db 2994
15 :3 0 e1 :3 0
298e 298f 0 e2
:2 0 2990 2991 0
2993 16dd 2995 2987
298d 0 2996 0
2993 0 2996 16df
0 2997 16e2 29e1
e5 :3 0 15 :3 0
e1 :3 0 299a 299b
0 e4 :3 0 299c
299d 0 29d7 c3
:3 0 c4 :3 0 299f
29a0 0 c3 :3 0
d3 :3 0 29a2 29a3
0 e6 :2 0 2
:4 0 24c :2 0 d5
:2 0 2a :2 0 16e5
29a8 29aa :3 0 16e8
29a4 29ac 29a1 29ae
29ad :2 0 c6 :3 0
d6 :3 0 29b0 29b1
0 c8 :4 0 24d
:4 0 cb :2 0 cc
:3 0 16ec 29b5 29b7
:3 0 cb :2 0 e9
:4 0 16ef 29b9 29bb
:3 0 cb :2 0 ea
:4 0 16f2 29bd 29bf
:3 0 cb :2 0 e4
:3 0 16f5 29c1 29c3
:3 0 cb :2 0 eb
:4 0 16f8 29c5 29c7
:3 0 cb :2 0 a0
:3 0 ec :3 0 2a
:2 0 ed :2 0 16fb
29ca 29ce 16ff 29c9
29d0 :3 0 1702 29b2
29d2 :2 0 29d4 1705
29d5 29af 29d4 0
29d6 1707 0 29d7
1709 29da :3 0 29da
0 29da 29d9 29d7
29d8 :6 0 29dc 74
:3 0 170c 29de 170e
29dd 29dc :2 0 29df
1710 :2 0 29e1 0
29e1 29e0 2997 29df
:6 0 2b14 6f :3 0
1b0 :3 0 91 :3 0
22 :3 0 9a :3 0
1d :4 0 24e 1
:8 0 29fe e0 :4 0
29e9 :3 0 f7 :3 0
da :2 0 1714 29ec
29ed :3 0 15 :3 0
e1 :3 0 29ef 29f0
0 3d :2 0 29f1
29f2 0 29f4 1717
29fb 15 :3 0 e1
:3 0 29f5 29f6 0
e2 :2 0 29f7 29f8
0 29fa 1719 29fc
29ee 29f4 0 29fd
0 29fa 0 29fd
171b 0 29fe 171e
2a48 e5 :3 0 15
:3 0 e1 :3 0 2a01
2a02 0 e4 :3 0
2a03 2a04 0 2a3e
c3 :3 0 c4 :3 0
2a06 2a07 0 c3
:3 0 d3 :3 0 2a09
2a0a 0 e6 :2 0
2 :4 0 24f :2 0
d5 :2 0 2a :2 0
1721 2a0f 2a11 :3 0
1724 2a0b 2a13 2a08
2a15 2a14 :2 0 c6
:3 0 d6 :3 0 2a17
2a18 0 c8 :4 0
250 :4 0 cb :2 0
cc :3 0 1728 2a1c
2a1e :3 0 cb :2 0
e9 :4 0 172b 2a20
2a22 :3 0 cb :2 0
ea :4 0 172e 2a24
2a26 :3 0 cb :2 0
e4 :3 0 1731 2a28
2a2a :3 0 cb :2 0
eb :4 0 1734 2a2c
2a2e :3 0 cb :2 0
a0 :3 0 ec :3 0
2a :2 0 ed :2 0
1737 2a31 2a35 173b
2a30 2a37 :3 0 173e
2a19 2a39 :2 0 2a3b
1741 2a3c 2a16 2a3b
0 2a3d 1743 0
2a3e 1745 2a41 :3 0
2a41 0 2a41 2a40
2a3e 2a3f :6 0 2a43
76 :3 0 1748 2a45
174a 2a44 2a43 :2 0
2a46 174c :2 0 2a48
0 2a48 2a47 29fe
2a46 :6 0 2b14 6f
:3 0 251 :3 0 98
:3 0 1d :4 0 252
1 :8 0 2a63 e0
:4 0 2a4e :3 0 f7
:3 0 da :2 0 1750
2a51 2a52 :3 0 15
:3 0 e1 :3 0 2a54
2a55 0 3d :2 0
2a56 2a57 0 2a59
1753 2a60 15 :3 0
e1 :3 0 2a5a 2a5b
0 e2 :2 0 2a5c
2a5d 0 2a5f 1755
2a61 2a53 2a59 0
2a62 0 2a5f 0
2a62 1757 0 2a63
175a 2aad e5 :3 0
15 :3 0 e1 :3 0
2a66 2a67 0 e4
:3 0 2a68 2a69 0
2aa3 c3 :3 0 c4
:3 0 2a6b 2a6c 0
c3 :3 0 d3 :3 0
2a6e 2a6f 0 e6
:2 0 2 :4 0 253
:2 0 d5 :2 0 2a
:2 0 175d 2a74 2a76
:3 0 1760 2a70 2a78
2a6d 2a7a 2a79 :2 0
c6 :3 0 d6 :3 0
2a7c 2a7d 0 c8
:4 0 254 :4 0 cb
:2 0 cc :3 0 1764
2a81 2a83 :3 0 cb
:2 0 e9 :4 0 1767
2a85 2a87 :3 0 cb
:2 0 ea :4 0 176a
2a89 2a8b :3 0 cb
:2 0 e4 :3 0 176d
2a8d 2a8f :3 0 cb
:2 0 eb :4 0 1770
2a91 2a93 :3 0 cb
:2 0 a0 :3 0 ec
:3 0 2a :2 0 ed
:2 0 1773 2a96 2a9a
1777 2a95 2a9c :3 0
177a 2a7e 2a9e :2 0
2aa0 177d 2aa1 2a7b
2aa0 0 2aa2 177f
0 2aa3 1781 2aa6
:3 0 2aa6 0 2aa6
2aa5 2aa3 2aa4 :6 0
2aa8 78 :3 0 1784
2aaa 1786 2aa9 2aa8
:2 0 2aab 1788 :2 0
2aad 0 2aad 2aac
2a63 2aab :6 0 2b14
6f :3 0 1ee :3 0
98 :3 0 1d :4 0
255 1 :8 0 2ac8
e0 :4 0 2ab3 :3 0
f7 :3 0 da :2 0
178c 2ab6 2ab7 :3 0
15 :3 0 e1 :3 0
2ab9 2aba 0 3d
:2 0 2abb 2abc 0
2abe 178f 2ac5 15
:3 0 e1 :3 0 2abf
2ac0 0 e2 :2 0
2ac1 2ac2 0 2ac4
1791 2ac6 2ab8 2abe
0 2ac7 0 2ac4
0 2ac7 1793 0
2ac8 1796 2b12 e5
:3 0 15 :3 0 e1
:3 0 2acb 2acc 0
e4 :3 0 2acd 2ace
0 2b08 c3 :3 0
c4 :3 0 2ad0 2ad1
0 c3 :3 0 d3
:3 0 2ad3 2ad4 0
e6 :2 0 2 :4 0
256 :2 0 d5 :2 0
2a :2 0 1799 2ad9
2adb :3 0 179c 2ad5
2add 2ad2 2adf 2ade
:2 0 c6 :3 0 d6
:3 0 2ae1 2ae2 0
c8 :4 0 257 :4 0
cb :2 0 cc :3 0
17a0 2ae6 2ae8 :3 0
cb :2 0 e9 :4 0
17a3 2aea 2aec :3 0
cb :2 0 ea :4 0
17a6 2aee 2af0 :3 0
cb :2 0 e4 :3 0
17a9 2af2 2af4 :3 0
cb :2 0 eb :4 0
17ac 2af6 2af8 :3 0
cb :2 0 a0 :3 0
ec :3 0 2a :2 0
ed :2 0 17af 2afb
2aff 17b3 2afa 2b01
:3 0 17b6 2ae3 2b03
:2 0 2b05 17b9 2b06
2ae0 2b05 0 2b07
17bb 0 2b08 17bd
2b0b :3 0 2b0b 0
2b0b 2b0a 2b08 2b09
:6 0 2b0d 7a :3 0
17c0 2b0f 17c2 2b0e
2b0d :2 0 2b10 17c4
:2 0 2b12 0 2b12
2b11 2ac8 2b10 :6 0
2b14 6f :3 0 17c6
3edd 258 :3 0 92
:3 0 21 :3 0 9a
:3 0 1d :3 0 91
:3 0 22 :3 0 92
:3 0 23 :4 0 259
1 :8 0 2b34 e0
:4 0 2b1f :3 0 f7
:3 0 da :2 0 17d0
2b22 2b23 :3 0 15
:3 0 e1 :3 0 2b25
2b26 0 3d :2 0
2b27 2b28 0 2b2a
17d3 2b31 15 :3 0
e1 :3 0 2b2b 2b2c
0 e2 :2 0 2b2d
2b2e 0 2b30 17d5
2b32 2b24 2b2a 0
2b33 0 2b30 0
2b33 17d7 0 2b34
17da 2b7e e5 :3 0
15 :3 0 e1 :3 0
2b37 2b38 0 e4
:3 0 2b39 2b3a 0
2b74 c3 :3 0 c4
:3 0 2b3c 2b3d 0
c3 :3 0 d3 :3 0
2b3f 2b40 0 e6
:2 0 2 :4 0 25a
:2 0 d5 :2 0 2a
:2 0 17dd 2b45 2b47
:3 0 17e0 2b41 2b49
2b3e 2b4b 2b4a :2 0
c6 :3 0 d6 :3 0
2b4d 2b4e 0 c8
:4 0 25b :4 0 cb
:2 0 cc :3 0 17e4
2b52 2b54 :3 0 cb
:2 0 e9 :4 0 17e7
2b56 2b58 :3 0 cb
:2 0 ea :4 0 17ea
2b5a 2b5c :3 0 cb
:2 0 e4 :3 0 17ed
2b5e 2b60 :3 0 cb
:2 0 eb :4 0 17f0
2b62 2b64 :3 0 cb
:2 0 a0 :3 0 ec
:3 0 2a :2 0 ed
:2 0 17f3 2b67 2b6b
17f7 2b66 2b6d :3 0
17fa 2b4f 2b6f :2 0
2b71 17fd 2b72 2b4c
2b71 0 2b73 17ff
0 2b74 1801 2b77
:3 0 2b77 0 2b77
2b76 2b74 2b75 :6 0
2b79 7c :3 0 1804
2b7b 1806 2b7a 2b79
:2 0 2b7c 1808 :2 0
2b7e 0 2b7e 2b7d
2b34 2b7c :6 0 3edc
6f :3 0 9a :3 0
17 :3 0 90 :3 0
91 :3 0 22 :3 0
9b :3 0 20 :3 0
92 :3 0 21 :3 0
93 :4 0 25c 1
:8 0 2b90 15 :3 0
e1 :3 0 2b8b 2b8c
0 e4 :3 0 2b8d
2b8e 0 2b90 180a
2bda e5 :3 0 15
:3 0 e1 :3 0 2b93
2b94 0 e4 :3 0
2b95 2b96 0 2bd0
c3 :3 0 c4 :3 0
2b98 2b99 0 c3
:3 0 d3 :3 0 2b9b
2b9c 0 e6 :2 0
2 :4 0 25d :2 0
d5 :2 0 2a :2 0
180d 2ba1 2ba3 :3 0
1810 2b9d 2ba5 2b9a
2ba7 2ba6 :2 0 c6
:3 0 d6 :3 0 2ba9
2baa 0 c8 :4 0
25e :4 0 cb :2 0
cc :3 0 1814 2bae
2bb0 :3 0 cb :2 0
e9 :4 0 1817 2bb2
2bb4 :3 0 cb :2 0
ea :4 0 181a 2bb6
2bb8 :3 0 cb :2 0
e4 :3 0 181d 2bba
2bbc :3 0 cb :2 0
eb :4 0 1820 2bbe
2bc0 :3 0 cb :2 0
a0 :3 0 ec :3 0
2a :2 0 ed :2 0
1823 2bc3 2bc7 1827
2bc2 2bc9 :3 0 182a
2bab 2bcb :2 0 2bcd
182d 2bce 2ba8 2bcd
0 2bcf 182f 0
2bd0 1831 2bd3 :3 0
2bd3 0 2bd3 2bd2
2bd0 2bd1 :6 0 2bd5
7e :3 0 1834 2bd7
1836 2bd6 2bd5 :2 0
2bd8 1838 :2 0 2bda
0 2bda 2bd9 2b90
2bd8 :6 0 3edc 6f
:3 0 15 :3 0 e1
:3 0 2bdc 2bdd 0
15 :3 0 da :2 0
100 :3 0 2bdf 2be1
0 183c 2be0 2be3
:3 0 2be4 :2 0 84
:3 0 4c :3 0 3d
:2 0 183f 2be6 2be9
da :2 0 3d :2 0
1844 2beb 2bed :3 0
1e :3 0 1d :3 0
2bef 2bf0 0 2bf2
1847 2bf3 2bee 2bf2
0 2bf4 1849 0
3ed9 98 :3 0 16d
:3 0 177 :3 0 17
:3 0 3c :3 0 19
:3 0 af :3 0 8b
:3 0 20 :3 0 92
:3 0 21 :3 0 93
:4 0 25f 1 :8 0
2c07 15 :3 0 e1
:3 0 2c02 2c03 0
e4 :3 0 2c04 2c05
0 2c07 184b 2c51
e5 :3 0 15 :3 0
e1 :3 0 2c0a 2c0b
0 e4 :3 0 2c0c
2c0d 0 2c47 c3
:3 0 c4 :3 0 2c0f
2c10 0 c3 :3 0
d3 :3 0 2c12 2c13
0 e6 :2 0 2
:4 0 260 :2 0 d5
:2 0 2a :2 0 184e
2c18 2c1a :3 0 1851
2c14 2c1c 2c11 2c1e
2c1d :2 0 c6 :3 0
d6 :3 0 2c20 2c21
0 c8 :4 0 261
:4 0 cb :2 0 cc
:3 0 1855 2c25 2c27
:3 0 cb :2 0 e9
:4 0 1858 2c29 2c2b
:3 0 cb :2 0 ea
:4 0 185b 2c2d 2c2f
:3 0 cb :2 0 e4
:3 0 185e 2c31 2c33
:3 0 cb :2 0 eb
:4 0 1861 2c35 2c37
:3 0 cb :2 0 a0
:3 0 ec :3 0 2a
:2 0 ed :2 0 1864
2c3a 2c3e 1868 2c39
2c40 :3 0 186b 2c22
2c42 :2 0 2c44 186e
2c45 2c1f 2c44 0
2c46 1870 0 2c47
1872 2c4a :3 0 2c4a
0 2c4a 2c49 2c47
2c48 :6 0 2c4c 80
:3 0 1875 2c4e 1877
2c4d 2c4c :2 0 2c4f
1879 :2 0 2c51 0
2c51 2c50 2c07 2c4f
:6 0 3ed9 6f :3 0
15 :3 0 e1 :3 0
2c53 2c54 0 15
:3 0 da :2 0 157
:3 0 2c56 2c58 0
187d 2c57 2c5a :3 0
2c5b :2 0 d8 :3 0
84 :3 0 3c :3 0
3d :2 0 1880 2c5e
2c61 b0 :3 0 19e
:3 0 2c63 2c64 0
1883 2c5d 2c66 2c67
:2 0 b0 :3 0 da
:2 0 19e :3 0 2c69
2c6b 0 1888 2c6a
2c6d :3 0 3f :3 0
3d :2 0 2c6f 2c70
0 2cdd af :3 0
12f :3 0 23 :3 0
92 :3 0 21 :3 0
93 :3 0 98 :3 0
1b :4 0 262 1
:8 0 2c90 e0 :4 0
2c7b :3 0 f7 :3 0
da :2 0 188d 2c7e
2c7f :3 0 15 :3 0
e1 :3 0 2c81 2c82
0 3d :2 0 2c83
2c84 0 2c86 1890
2c8d 15 :3 0 e1
:3 0 2c87 2c88 0
e2 :2 0 2c89 2c8a
0 2c8c 1892 2c8e
2c80 2c86 0 2c8f
0 2c8c 0 2c8f
1894 0 2c90 1897
2cda e5 :3 0 15
:3 0 e1 :3 0 2c93
2c94 0 e4 :3 0
2c95 2c96 0 2cd0
c3 :3 0 c4 :3 0
2c98 2c99 0 c3
:3 0 d3 :3 0 2c9b
2c9c 0 e6 :2 0
2 :4 0 263 :2 0
d5 :2 0 2a :2 0
189a 2ca1 2ca3 :3 0
189d 2c9d 2ca5 2c9a
2ca7 2ca6 :2 0 c6
:3 0 d6 :3 0 2ca9
2caa 0 c8 :4 0
264 :4 0 cb :2 0
cc :3 0 18a1 2cae
2cb0 :3 0 cb :2 0
e9 :4 0 18a4 2cb2
2cb4 :3 0 cb :2 0
ea :4 0 18a7 2cb6
2cb8 :3 0 cb :2 0
e4 :3 0 18aa 2cba
2cbc :3 0 cb :2 0
eb :4 0 18ad 2cbe
2cc0 :3 0 cb :2 0
a0 :3 0 ec :3 0
2a :2 0 ed :2 0
18b0 2cc3 2cc7 18b4
2cc2 2cc9 :3 0 18b7
2cab 2ccb :2 0 2ccd
18ba 2cce 2ca8 2ccd
0 2ccf 18bc 0
2cd0 18be 2cd3 :3 0
2cd3 0 2cd3 2cd2
2cd0 2cd1 :6 0 2cd5
82 :3 0 18c1 2cd7
18c3 2cd6 2cd5 :2 0
2cd8 18c5 :2 0 2cda
0 2cda 2cd9 2c90
2cd8 :6 0 2cdd 6f
:3 0 140 :3 0 18c7
2ddc 84 :3 0 3c
:3 0 3d :2 0 18ca
2cde 2ce1 b0 :3 0
da :2 0 194 :3 0
2ce3 2ce5 0 18cf
2ce4 2ce7 :3 0 71
:3 0 172 :3 0 3d
:2 0 84 :3 0 41
:3 0 3d :2 0 18d2
2cec 2cef b0 :3 0
173 :3 0 2cf1 2cf2
0 6e :3 0 18d5
2cea 2cf5 2ce9 2cf6
0 2d67 af :3 0
16d :3 0 b0 :3 0
19e :3 0 177 :3 0
6e :3 0 12f :3 0
23 :3 0 92 :3 0
21 :3 0 93 :3 0
98 :3 0 1b :4 0
265 1 :8 0 2d1b
e0 :4 0 2d06 :3 0
f7 :3 0 da :2 0
18dc 2d09 2d0a :3 0
15 :3 0 e1 :3 0
2d0c 2d0d 0 3d
:2 0 2d0e 2d0f 0
2d11 18df 2d18 15
:3 0 e1 :3 0 2d12
2d13 0 e2 :2 0
2d14 2d15 0 2d17
18e1 2d19 2d0b 2d11
0 2d1a 0 2d17
0 2d1a 18e3 0
2d1b 18e6 2d65 e5
:3 0 15 :3 0 e1
:3 0 2d1e 2d1f 0
e4 :3 0 2d20 2d21
0 2d5b c3 :3 0
c4 :3 0 2d23 2d24
0 c3 :3 0 d3
:3 0 2d26 2d27 0
e6 :2 0 2 :4 0
266 :2 0 d5 :2 0
2a :2 0 18e9 2d2c
2d2e :3 0 18ec 2d28
2d30 2d25 2d32 2d31
:2 0 c6 :3 0 d6
:3 0 2d34 2d35 0
c8 :4 0 267 :4 0
cb :2 0 cc :3 0
18f0 2d39 2d3b :3 0
cb :2 0 e9 :4 0
18f3 2d3d 2d3f :3 0
cb :2 0 ea :4 0
18f6 2d41 2d43 :3 0
cb :2 0 e4 :3 0
18f9 2d45 2d47 :3 0
cb :2 0 eb :4 0
18fc 2d49 2d4b :3 0
cb :2 0 a0 :3 0
ec :3 0 2a :2 0
ed :2 0 18ff 2d4e
2d52 1903 2d4d 2d54
:3 0 1906 2d36 2d56
:2 0 2d58 1909 2d59
2d33 2d58 0 2d5a
190b 0 2d5b 190d
2d5e :3 0 2d5e 0
2d5e 2d5d 2d5b 2d5c
:6 0 2d60 84 :3 0
1910 2d62 1912 2d61
2d60 :2 0 2d63 1914
:2 0 2d65 0 2d65
2d64 2d1b 2d63 :6 0
2d67 6f :3 0 1916
2d68 2ce8 2d67 0
2dde af :3 0 16d
:3 0 199 :3 0 19a
:3 0 3c :3 0 b0
:3 0 19e :3 0 177
:3 0 19 :3 0 12f
:3 0 23 :3 0 92
:3 0 21 :3 0 93
:3 0 98 :3 0 1b
:4 0 268 1 :8 0
2d8f e0 :4 0 2d7a
:3 0 f7 :3 0 da
:2 0 191b 2d7d 2d7e
:3 0 15 :3 0 e1
:3 0 2d80 2d81 0
3d :2 0 2d82 2d83
0 2d85 191e 2d8c
15 :3 0 e1 :3 0
2d86 2d87 0 e2
:2 0 2d88 2d89 0
2d8b 1920 2d8d 2d7f
2d85 0 2d8e 0
2d8b 0 2d8e 1922
0 2d8f 1925 2dd9
e5 :3 0 15 :3 0
e1 :3 0 2d92 2d93
0 e4 :3 0 2d94
2d95 0 2dcf c3
:3 0 c4 :3 0 2d97
2d98 0 c3 :3 0
d3 :3 0 2d9a 2d9b
0 e6 :2 0 2
:4 0 269 :2 0 d5
:2 0 2a :2 0 1928
2da0 2da2 :3 0 192b
2d9c 2da4 2d99 2da6
2da5 :2 0 c6 :3 0
d6 :3 0 2da8 2da9
0 c8 :4 0 26a
:4 0 cb :2 0 cc
:3 0 192f 2dad 2daf
:3 0 cb :2 0 e9
:4 0 1932 2db1 2db3
:3 0 cb :2 0 ea
:4 0 1935 2db5 2db7
:3 0 cb :2 0 e4
:3 0 1938 2db9 2dbb
:3 0 cb :2 0 eb
:4 0 193b 2dbd 2dbf
:3 0 cb :2 0 a0
:3 0 ec :3 0 2a
:2 0 ed :2 0 193e
2dc2 2dc6 1942 2dc1
2dc8 :3 0 1945 2daa
2dca :2 0 2dcc 1948
2dcd 2da7 2dcc 0
2dce 194a 0 2dcf
194c 2dd2 :3 0 2dd2
0 2dd2 2dd1 2dcf
2dd0 :6 0 2dd4 86
:3 0 194f 2dd6 1951
2dd5 2dd4 :2 0 2dd7
1953 :2 0 2dd9 0
2dd9 2dd8 2d8f 2dd7
:6 0 2ddb 6f :3 0
1955 2ddd 2c6e 2cdd
0 2dde 0 2ddb
0 2dde 1957 0
2e5d 15 :3 0 e1
:3 0 2ddf 2de0 0
15 :3 0 da :2 0
157 :3 0 2de2 2de4
0 195d 2de3 2de6
:3 0 2de7 :2 0 84
:3 0 3f :3 0 3d
:2 0 1960 2de9 2dec
10a :2 0 3d :2 0
1965 2dee 2df0 :3 0
2df1 :2 0 2de8 2df3
2df2 :2 0 af :3 0
98 :3 0 17 :4 0
1f8 1 :8 0 2e0e
e0 :4 0 2df9 :3 0
f7 :3 0 da :2 0
196a 2dfc 2dfd :3 0
15 :3 0 e1 :3 0
2dff 2e00 0 3d
:2 0 2e01 2e02 0
2e04 196d 2e0b 15
:3 0 e1 :3 0 2e05
2e06 0 e2 :2 0
2e07 2e08 0 2e0a
196f 2e0c 2dfe 2e04
0 2e0d 0 2e0a
0 2e0d 1971 0
2e0e 1974 2e58 e5
:3 0 15 :3 0 e1
:3 0 2e11 2e12 0
e4 :3 0 2e13 2e14
0 2e4e c3 :3 0
c4 :3 0 2e16 2e17
0 c3 :3 0 d3
:3 0 2e19 2e1a 0
e6 :2 0 2 :4 0
26b :2 0 d5 :2 0
2a :2 0 1977 2e1f
2e21 :3 0 197a 2e1b
2e23 2e18 2e25 2e24
:2 0 c6 :3 0 d6
:3 0 2e27 2e28 0
c8 :4 0 26c :4 0
cb :2 0 cc :3 0
197e 2e2c 2e2e :3 0
cb :2 0 e9 :4 0
1981 2e30 2e32 :3 0
cb :2 0 ea :4 0
1984 2e34 2e36 :3 0
cb :2 0 e4 :3 0
1987 2e38 2e3a :3 0
cb :2 0 eb :4 0
198a 2e3c 2e3e :3 0
cb :2 0 a0 :3 0
ec :3 0 2a :2 0
ed :2 0 198d 2e41
2e45 1991 2e40 2e47
:3 0 1994 2e29 2e49
:2 0 2e4b 1997 2e4c
2e26 2e4b 0 2e4d
1999 0 2e4e 199b
2e51 :3 0 2e51 0
2e51 2e50 2e4e 2e4f
:6 0 2e53 88 :3 0
199e 2e55 19a0 2e54
2e53 :2 0 2e56 19a2
:2 0 2e58 0 2e58
2e57 2e0e 2e56 :6 0
2e5a 6f :3 0 19a4
2e5b 2df4 2e5a 0
2e5c 19a6 0 2e5d
19a8 311b 26d :3 0
98 :3 0 a0 :3 0
110 :3 0 185 :3 0
18a :3 0 110 :3 0
185 :3 0 17 :3 0
38 :3 0 ae :3 0
110 :3 0 af :3 0
26d :3 0 110 :3 0
8b :3 0 20 :3 0
110 :3 0 8b :3 0
26d :3 0 8b :3 0
26d :3 0 16d :3 0
26d :3 0 92 :3 0
110 :3 0 26e :3 0
9a :3 0 90 :3 0
26f :3 0 26f :3 0
98 :3 0 26d :3 0
98 :4 0 270 1
:8 0 2e86 15 :3 0
e1 :3 0 2e81 2e82
0 e4 :3 0 2e83
2e84 0 2e86 19ab
2ed0 e5 :3 0 15
:3 0 e1 :3 0 2e89
2e8a 0 e4 :3 0
2e8b 2e8c 0 2ec6
c3 :3 0 c4 :3 0
2e8e 2e8f 0 c3
:3 0 d3 :3 0 2e91
2e92 0 e6 :2 0
2 :4 0 271 :2 0
d5 :2 0 2a :2 0
19ae 2e97 2e99 :3 0
19b1 2e93 2e9b 2e90
2e9d 2e9c :2 0 c6
:3 0 d6 :3 0 2e9f
2ea0 0 c8 :4 0
272 :4 0 cb :2 0
cc :3 0 19b5 2ea4
2ea6 :3 0 cb :2 0
e9 :4 0 19b8 2ea8
2eaa :3 0 cb :2 0
ea :4 0 19bb 2eac
2eae :3 0 cb :2 0
e4 :3 0 19be 2eb0
2eb2 :3 0 cb :2 0
eb :4 0 19c1 2eb4
2eb6 :3 0 cb :2 0
a0 :3 0 ec :3 0
2a :2 0 ed :2 0
19c4 2eb9 2ebd 19c8
2eb8 2ebf :3 0 19cb
2ea1 2ec1 :2 0 2ec3
19ce 2ec4 2e9e 2ec3
0 2ec5 19d0 0
2ec6 19d2 2ec9 :3 0
2ec9 0 2ec9 2ec8
2ec6 2ec7 :6 0 2ecb
8a :3 0 19d5 2ecd
19d7 2ecc 2ecb :2 0
2ece 19d9 :2 0 2ed0
0 2ed0 2ecf 2e86
2ece :6 0 311a 6f
:3 0 15 :3 0 e1
:3 0 2ed2 2ed3 0
15 :3 0 da :2 0
157 :3 0 2ed5 2ed7
0 19dd 2ed6 2ed9
:3 0 2eda :2 0 17
:3 0 165 :2 0 19e0
2edd 2ede :3 0 2edf
:2 0 2ee0 :2 0 2edb
2ee2 2ee1 :2 0 71
:3 0 172 :3 0 3d
:2 0 84 :3 0 41
:3 0 3d :2 0 19e2
2ee7 2eea b0 :3 0
273 :3 0 2eec 2eed
0 6e :3 0 19e5
2ee5 2ef0 2ee4 2ef1
0 302f af :3 0
98 :3 0 17 :4 0
1f8 1 :8 0 2f0c
e0 :4 0 2ef7 :3 0
f7 :3 0 da :2 0
19ec 2efa 2efb :3 0
15 :3 0 e1 :3 0
2efd 2efe 0 3d
:2 0 2eff 2f00 0
2f02 19ef 2f09 15
:3 0 e1 :3 0 2f03
2f04 0 e2 :2 0
2f05 2f06 0 2f08
19f1 2f0a 2efc 2f02
0 2f0b 0 2f08
0 2f0b 19f3 0
2f0c 19f6 2f56 e5
:3 0 15 :3 0 e1
:3 0 2f0f 2f10 0
e4 :3 0 2f11 2f12
0 2f4c c3 :3 0
c4 :3 0 2f14 2f15
0 c3 :3 0 d3
:3 0 2f17 2f18 0
e6 :2 0 2 :4 0
274 :2 0 d5 :2 0
2a :2 0 19f9 2f1d
2f1f :3 0 19fc 2f19
2f21 2f16 2f23 2f22
:2 0 c6 :3 0 d6
:3 0 2f25 2f26 0
c8 :4 0 275 :4 0
cb :2 0 cc :3 0
1a00 2f2a 2f2c :3 0
cb :2 0 e9 :4 0
1a03 2f2e 2f30 :3 0
cb :2 0 ea :4 0
1a06 2f32 2f34 :3 0
cb :2 0 e4 :3 0
1a09 2f36 2f38 :3 0
cb :2 0 eb :4 0
1a0c 2f3a 2f3c :3 0
cb :2 0 a0 :3 0
ec :3 0 2a :2 0
ed :2 0 1a0f 2f3f
2f43 1a13 2f3e 2f45
:3 0 1a16 2f27 2f47
:2 0 2f49 1a19 2f4a
2f24 2f49 0 2f4b
1a1b 0 2f4c 1a1d
2f4f :3 0 2f4f 0
2f4f 2f4e 2f4c 2f4d
:6 0 2f51 8c :3 0
1a20 2f53 1a22 2f52
2f51 :2 0 2f54 1a24
:2 0 2f56 0 2f56
2f55 2f0c 2f54 :6 0
302f 6f :3 0 af
:3 0 92 :3 0 21
:3 0 93 :3 0 12f
:3 0 23 :3 0 16d
:3 0 177 :3 0 6e
:3 0 98 :3 0 1b
:4 0 276 1 :8 0
2f79 e0 :4 0 2f64
:3 0 f7 :3 0 da
:2 0 1a28 2f67 2f68
:3 0 15 :3 0 e1
:3 0 2f6a 2f6b 0
3d :2 0 2f6c 2f6d
0 2f6f 1a2b 2f76
15 :3 0 e1 :3 0
2f70 2f71 0 e2
:2 0 2f72 2f73 0
2f75 1a2d 2f77 2f69
2f6f 0 2f78 0
2f75 0 2f78 1a2f
0 2f79 1a32 2fc3
e5 :3 0 15 :3 0
e1 :3 0 2f7c 2f7d
0 e4 :3 0 2f7e
2f7f 0 2fb9 c3
:3 0 c4 :3 0 2f81
2f82 0 c3 :3 0
d3 :3 0 2f84 2f85
0 e6 :2 0 2
:4 0 277 :2 0 d5
:2 0 2a :2 0 1a35
2f8a 2f8c :3 0 1a38
2f86 2f8e 2f83 2f90
2f8f :2 0 c6 :3 0
d6 :3 0 2f92 2f93
0 c8 :4 0 278
:4 0 cb :2 0 cc
:3 0 1a3c 2f97 2f99
:3 0 cb :2 0 e9
:4 0 1a3f 2f9b 2f9d
:3 0 cb :2 0 ea
:4 0 1a42 2f9f 2fa1
:3 0 cb :2 0 e4
:3 0 1a45 2fa3 2fa5
:3 0 cb :2 0 eb
:4 0 1a48 2fa7 2fa9
:3 0 cb :2 0 a0
:3 0 ec :3 0 2a
:2 0 ed :2 0 1a4b
2fac 2fb0 1a4f 2fab
2fb2 :3 0 1a52 2f94
2fb4 :2 0 2fb6 1a55
2fb7 2f91 2fb6 0
2fb8 1a57 0 2fb9
1a59 2fbc :3 0 2fbc
0 2fbc 2fbb 2fb9
2fba :6 0 2fbe 8e
:3 0 1a5c 2fc0 1a5e
2fbf 2fbe :2 0 2fc1
1a60 :2 0 2fc3 0
2fc3 2fc2 2f79 2fc1
:6 0 302f 6f :3 0
ae :3 0 185 :3 0
186 :3 0 185 :3 0
38 :3 0 36 :3 0
8b :3 0 20 :4 0
279 1 :8 0 2fe3
e0 :4 0 2fce :3 0
f7 :3 0 da :2 0
1a64 2fd1 2fd2 :3 0
15 :3 0 e1 :3 0
2fd4 2fd5 0 3d
:2 0 2fd6 2fd7 0
2fd9 1a67 2fe0 15
:3 0 e1 :3 0 2fda
2fdb 0 e2 :2 0
2fdc 2fdd 0 2fdf
1a69 2fe1 2fd3 2fd9
0 2fe2 0 2fdf
0 2fe2 1a6b 0
2fe3 1a6e 302d e5
:3 0 15 :3 0 e1
:3 0 2fe6 2fe7 0
e4 :3 0 2fe8 2fe9
0 3023 c3 :3 0
c4 :3 0 2feb 2fec
0 c3 :3 0 d3
:3 0 2fee 2fef 0
e6 :2 0 2 :4 0
27a :2 0 d5 :2 0
2a :2 0 1a71 2ff4
2ff6 :3 0 1a74 2ff0
2ff8 2fed 2ffa 2ff9
:2 0 c6 :3 0 d6
:3 0 2ffc 2ffd 0
c8 :4 0 27b :4 0
cb :2 0 cc :3 0
1a78 3001 3003 :3 0
cb :2 0 e9 :4 0
1a7b 3005 3007 :3 0
cb :2 0 ea :4 0
1a7e 3009 300b :3 0
cb :2 0 e4 :3 0
1a81 300d 300f :3 0
cb :2 0 eb :4 0
1a84 3011 3013 :3 0
cb :2 0 a0 :3 0
ec :3 0 2a :2 0
ed :2 0 1a87 3016
301a 1a8b 3015 301c
:3 0 1a8e 2ffe 301e
:2 0 3020 1a91 3021
2ffb 3020 0 3022
1a93 0 3023 1a95
3026 :3 0 3026 0
3026 3025 3023 3024
:6 0 3028 90 :3 0
1a98 302a 1a9a 3029
3028 :2 0 302b 1a9c
:2 0 302d 0 302d
302c 2fe3 302b :6 0
302f 6f :3 0 1a9e
3117 71 :3 0 172
:3 0 3d :2 0 84
:3 0 41 :3 0 3d
:2 0 1aa3 3033 3036
b0 :3 0 173 :3 0
3038 3039 0 6e
:3 0 1aa6 3031 303c
3030 303d 0 3116
ae :3 0 185 :3 0
186 :3 0 185 :3 0
39 :3 0 36 :3 0
8b :3 0 20 :4 0
27c 1 :8 0 305d
e0 :4 0 3048 :3 0
f7 :3 0 da :2 0
1aad 304b 304c :3 0
15 :3 0 e1 :3 0
304e 304f 0 3d
:2 0 3050 3051 0
3053 1ab0 305a 15
:3 0 e1 :3 0 3054
3055 0 e2 :2 0
3056 3057 0 3059
1ab2 305b 304d 3053
0 305c 0 3059
0 305c 1ab4 0
305d 1ab7 30a7 e5
:3 0 15 :3 0 e1
:3 0 3060 3061 0
e4 :3 0 3062 3063
0 309d c3 :3 0
c4 :3 0 3065 3066
0 c3 :3 0 d3
:3 0 3068 3069 0
e6 :2 0 2 :4 0
27d :2 0 d5 :2 0
2a :2 0 1aba 306e
3070 :3 0 1abd 306a
3072 3067 3074 3073
:2 0 c6 :3 0 d6
:3 0 3076 3077 0
c8 :4 0 27e :4 0
cb :2 0 cc :3 0
1ac1 307b 307d :3 0
cb :2 0 e9 :4 0
1ac4 307f 3081 :3 0
cb :2 0 ea :4 0
1ac7 3083 3085 :3 0
cb :2 0 e4 :3 0
1aca 3087 3089 :3 0
cb :2 0 eb :4 0
1acd 308b 308d :3 0
cb :2 0 a0 :3 0
ec :3 0 2a :2 0
ed :2 0 1ad0 3090
3094 1ad4 308f 3096
:3 0 1ad7 3078 3098
:2 0 309a 1ada 309b
3075 309a 0 309c
1adc 0 309d 1ade
30a0 :3 0 30a0 0
30a0 309f 309d 309e
:6 0 30a2 92 :3 0
1ae1 30a4 1ae3 30a3
30a2 :2 0 30a5 1ae5
:2 0 30a7 0 30a7
30a6 305d 30a5 :6 0
3116 6f :3 0 af
:3 0 92 :3 0 21
:3 0 93 :3 0 12f
:3 0 23 :3 0 16d
:3 0 177 :3 0 6e
:3 0 98 :3 0 1b
:4 0 27f 1 :8 0
30ca e0 :4 0 30b5
:3 0 f7 :3 0 da
:2 0 1ae9 30b8 30b9
:3 0 15 :3 0 e1
:3 0 30bb 30bc 0
3d :2 0 30bd 30be
0 30c0 1aec 30c7
15 :3 0 e1 :3 0
30c1 30c2 0 e2
:2 0 30c3 30c4 0
30c6 1aee 30c8 30ba
30c0 0 30c9 0
30c6 0 30c9 1af0
0 30ca 1af3 3114
e5 :3 0 15 :3 0
e1 :3 0 30cd 30ce
0 e4 :3 0 30cf
30d0 0 310a c3
:3 0 c4 :3 0 30d2
30d3 0 c3 :3 0
d3 :3 0 30d5 30d6
0 e6 :2 0 2
:4 0 280 :2 0 d5
:2 0 2a :2 0 1af6
30db 30dd :3 0 1af9
30d7 30df 30d4 30e1
30e0 :2 0 c6 :3 0
d6 :3 0 30e3 30e4
0 c8 :4 0 281
:4 0 cb :2 0 cc
:3 0 1afd 30e8 30ea
:3 0 cb :2 0 e9
:4 0 1b00 30ec 30ee
:3 0 cb :2 0 ea
:4 0 1b03 30f0 30f2
:3 0 cb :2 0 e4
:3 0 1b06 30f4 30f6
:3 0 cb :2 0 eb
:4 0 1b09 30f8 30fa
:3 0 cb :2 0 a0
:3 0 ec :3 0 2a
:2 0 ed :2 0 1b0c
30fd 3101 1b10 30fc
3103 :3 0 1b13 30e5
3105 :2 0 3107 1b16
3108 30e2 3107 0
3109 1b18 0 310a
1b1a 310d :3 0 310d
0 310d 310c 310a
310b :6 0 310f 94
:3 0 1b1d 3111 1b1f
3110 310f :2 0 3112
1b21 :2 0 3114 0
3114 3113 30ca 3112
:6 0 3116 6f :3 0
1b23 3118 2ee3 302f
0 3119 0 3116
0 3119 1b27 0
311a 1b2a 311c 2c5c
2e5d 0 311d 0
311a 0 311d 1b2d
0 3ed9 84 :3 0
3f :3 0 3d :2 0
1b30 311e 3121 10a
:2 0 3d :2 0 1b35
3123 3125 :3 0 84
:3 0 65 :3 0 3d
:2 0 1b38 3127 312a
da :2 0 2a :2 0
1b3d 312c 312e :3 0
312f :2 0 3a :3 0
165 :2 0 1b40 3132
3133 :3 0 3134 :2 0
3135 :2 0 3130 3137
3136 :2 0 124 :3 0
124 :3 0 3a :3 0
64 :3 0 ae :3 0
8b :3 0 20 :4 0
282 1 :8 0 3146
15 :3 0 e1 :3 0
3141 3142 0 e4
:3 0 3143 3144 0
3146 1b42 3190 e5
:3 0 15 :3 0 e1
:3 0 3149 314a 0
e4 :3 0 314b 314c
0 3186 c3 :3 0
c4 :3 0 314e 314f
0 c3 :3 0 d3
:3 0 3151 3152 0
e6 :2 0 2 :4 0
283 :2 0 d5 :2 0
2a :2 0 1b45 3157
3159 :3 0 1b48 3153
315b 3150 315d 315c
:2 0 c6 :3 0 d6
:3 0 315f 3160 0
c8 :4 0 284 :4 0
cb :2 0 cc :3 0
1b4c 3164 3166 :3 0
cb :2 0 e9 :4 0
1b4f 3168 316a :3 0
cb :2 0 ea :4 0
1b52 316c 316e :3 0
cb :2 0 e4 :3 0
1b55 3170 3172 :3 0
cb :2 0 eb :4 0
1b58 3174 3176 :3 0
cb :2 0 a0 :3 0
ec :3 0 2a :2 0
ed :2 0 1b5b 3179
317d 1b5f 3178 317f
:3 0 1b62 3161 3181
:2 0 3183 1b65 3184
315e 3183 0 3185
1b67 0 3186 1b69
3189 :3 0 3189 0
3189 3188 3186 3187
:6 0 318b 96 :3 0
1b6c 318d 1b6e 318c
318b :2 0 318e 1b70
:2 0 3190 0 3190
318f 3146 318e :6 0
32ed 6f :3 0 15
:3 0 e1 :3 0 3192
3193 0 15 :3 0
da :2 0 157 :3 0
3195 3197 0 1b74
3196 3199 :3 0 319a
:2 0 84 :3 0 64
:3 0 3d :2 0 1b77
319c 319f da :2 0
3d :2 0 1b7c 31a1
31a3 :3 0 31a4 :2 0
319b 31a6 31a5 :2 0
ae :3 0 124 :3 0
3a :3 0 8b :3 0
20 :4 0 285 1
:8 0 31c3 e0 :4 0
31ae :3 0 f7 :3 0
da :2 0 1b81 31b1
31b2 :3 0 15 :3 0
e1 :3 0 31b4 31b5
0 3d :2 0 31b6
31b7 0 31b9 1b84
31c0 15 :3 0 e1
:3 0 31ba 31bb 0
e2 :2 0 31bc 31bd
0 31bf 1b86 31c1
31b3 31b9 0 31c2
0 31bf 0 31c2
1b88 0 31c3 1b8b
320d e5 :3 0 15
:3 0 e1 :3 0 31c6
31c7 0 e4 :3 0
31c8 31c9 0 3203
c3 :3 0 c4 :3 0
31cb 31cc 0 c3
:3 0 d3 :3 0 31ce
31cf 0 e6 :2 0
2 :4 0 286 :2 0
d5 :2 0 2a :2 0
1b8e 31d4 31d6 :3 0
1b91 31d0 31d8 31cd
31da 31d9 :2 0 c6
:3 0 d6 :3 0 31dc
31dd 0 c8 :4 0
287 :4 0 cb :2 0
cc :3 0 1b95 31e1
31e3 :3 0 cb :2 0
e9 :4 0 1b98 31e5
31e7 :3 0 cb :2 0
ea :4 0 1b9b 31e9
31eb :3 0 cb :2 0
e4 :3 0 1b9e 31ed
31ef :3 0 cb :2 0
eb :4 0 1ba1 31f1
31f3 :3 0 cb :2 0
a0 :3 0 ec :3 0
2a :2 0 ed :2 0
1ba4 31f6 31fa 1ba8
31f5 31fc :3 0 1bab
31de 31fe :2 0 3200
1bae 3201 31db 3200
0 3202 1bb0 0
3203 1bb2 3206 :3 0
3206 0 3206 3205
3203 3204 :6 0 3208
98 :3 0 1bb5 320a
1bb7 3209 3208 :2 0
320b 1bb9 :2 0 320d
0 320d 320c 31c3
320b :6 0 3210 6f
:3 0 140 :3 0 1bbb
32eb 15 :3 0 e1
:3 0 3211 3212 0
15 :3 0 da :2 0
157 :3 0 3214 3216
0 1bbf 3215 3218
:3 0 3219 :2 0 84
:3 0 64 :3 0 3d
:2 0 1bc2 321b 321e
da :2 0 13a :2 0
1bc7 3220 3222 :3 0
3223 :2 0 321a 3225
3224 :2 0 e3 :3 0
96 :4 0 322a :2 0
3230 3228 0 15
:3 0 e1 :3 0 322b
322c 0 e4 :3 0
322d 322e 0 3230
1bca 327a e5 :3 0
15 :3 0 e1 :3 0
3233 3234 0 e4
:3 0 3235 3236 0
3270 c3 :3 0 c4
:3 0 3238 3239 0
c3 :3 0 d3 :3 0
323b 323c 0 e6
:2 0 2 :4 0 288
:2 0 d5 :2 0 2a
:2 0 1bcd 3241 3243
:3 0 1bd0 323d 3245
323a 3247 3246 :2 0
c6 :3 0 d6 :3 0
3249 324a 0 c8
:4 0 289 :4 0 cb
:2 0 cc :3 0 1bd4
324e 3250 :3 0 cb
:2 0 e9 :4 0 1bd7
3252 3254 :3 0 cb
:2 0 ea :4 0 1bda
3256 3258 :3 0 cb
:2 0 e4 :3 0 1bdd
325a 325c :3 0 cb
:2 0 eb :4 0 1be0
325e 3260 :3 0 cb
:2 0 a0 :3 0 ec
:3 0 2a :2 0 ed
:2 0 1be3 3263 3267
1be7 3262 3269 :3 0
1bea 324b 326b :2 0
326d 1bed 326e 3248
326d 0 326f 1bef
0 3270 1bf1 3273
:3 0 3273 0 3273
3272 3270 3271 :6 0
3275 9a :3 0 1bf4
3277 1bf6 3276 3275
:2 0 3278 1bf8 :2 0
327a 0 327a 3279
3230 3278 :6 0 32e9
6f :3 0 c3 :3 0
c4 :3 0 327c 327d
0 c3 :3 0 d3
:3 0 327f 3280 0
18 :2 0 2 :4 0
28a :2 0 d5 :2 0
2a :2 0 1bfa 3285
3287 :3 0 1bfd 3281
3289 327e 328b 328a
:2 0 c6 :3 0 d6
:3 0 328d 328e 0
c8 :4 0 28b :4 0
cb :2 0 cc :3 0
1c01 3292 3294 :3 0
cb :2 0 e9 :4 0
1c04 3296 3298 :3 0
cb :2 0 f0 :4 0
1c07 329a 329c :3 0
cb :2 0 84 :3 0
d0 :3 0 b0 :3 0
28c :3 0 32a1 32a2
0 1c0a 32a0 32a4
d1 :4 0 1c0c 329f
32a7 1c0f 329e 32a9
:3 0 cb :2 0 f2
:4 0 1c12 32ab 32ad
:3 0 cb :2 0 ce
:4 0 1c15 32af 32b1
:3 0 cb :2 0 20
:3 0 1c18 32b3 32b5
:3 0 cb :2 0 ce
:4 0 1c1b 32b7 32b9
:3 0 1c1e 328f 32bb
:2 0 32bd 1c21 32be
328c 32bd 0 32bf
1c23 0 32e9 c3
:3 0 c4 :3 0 32c0
32c1 0 c3 :3 0
d3 :3 0 32c3 32c4
0 2a :2 0 2
:4 0 28d :2 0 d5
:2 0 2a :2 0 1c25
32c9 32cb :3 0 1c28
32c5 32cd 32c2 32cf
32ce :2 0 c6 :3 0
d6 :3 0 32d1 32d2
0 c8 :4 0 28e
:4 0 cb :2 0 cc
:3 0 1c2c 32d6 32d8
:3 0 1c2f 32d3 32da
:2 0 32dc 1c32 32dd
32d0 32dc 0 32de
1c34 0 32e9 f5
:3 0 f6 :3 0 32df
32e0 0 b0 :3 0
28c :3 0 32e2 32e3
0 20 :3 0 f7
:3 0 1c36 32e1 32e7
:2 0 32e9 1c3a 32ea
3226 32e9 0 32ec
31a7 3210 0 32ec
1c3f 0 32ed 1c42
32ee 3138 32ed 0
32ef 1c45 0 3ed6
7a :3 0 1be :2 0
2a :2 0 1c47 32f1
32f3 :3 0 32f0 32f4
0 3ed6 15 :3 0
e1 :3 0 32f6 32f7
0 1bf :3 0 22
:3 0 20 :3 0 1d
:3 0 72 :3 0 73
:3 0 74 :3 0 75
:3 0 7a :3 0 79
:3 0 78 :3 0 1c49
32f9 3304 32f8 3305
0 3ed6 1b0 :3 0
91 :3 0 22 :3 0
9a :3 0 1d :4 0
24e 1 :8 0 3322
e0 :4 0 330d :3 0
f7 :3 0 da :2 0
1c56 3310 3311 :3 0
15 :3 0 e1 :3 0
3313 3314 0 3d
:2 0 3315 3316 0
3318 1c59 331f 15
:3 0 e1 :3 0 3319
331a 0 e2 :2 0
331b 331c 0 331e
1c5b 3320 3312 3318
0 3321 0 331e
0 3321 1c5d 0
3322 1c60 336c e5
:3 0 15 :3 0 e1
:3 0 3325 3326 0
e4 :3 0 3327 3328
0 3362 c3 :3 0
c4 :3 0 332a 332b
0 c3 :3 0 d3
:3 0 332d 332e 0
e6 :2 0 2 :4 0
28f :2 0 d5 :2 0
2a :2 0 1c63 3333
3335 :3 0 1c66 332f
3337 332c 3339 3338
:2 0 c6 :3 0 d6
:3 0 333b 333c 0
c8 :4 0 290 :4 0
cb :2 0 cc :3 0
1c6a 3340 3342 :3 0
cb :2 0 e9 :4 0
1c6d 3344 3346 :3 0
cb :2 0 ea :4 0
1c70 3348 334a :3 0
cb :2 0 e4 :3 0
1c73 334c 334e :3 0
cb :2 0 eb :4 0
1c76 3350 3352 :3 0
cb :2 0 a0 :3 0
ec :3 0 2a :2 0
ed :2 0 1c79 3355
3359 1c7d 3354 335b
:3 0 1c80 333d 335d
:2 0 335f 1c83 3360
333a 335f 0 3361
1c85 0 3362 1c87
3365 :3 0 3365 0
3365 3364 3362 3363
:6 0 3367 9c :3 0
1c8a 3369 1c8c 3368
3367 :2 0 336a 1c8e
:2 0 336c 0 336c
336b 3322 336a :6 0
3ed6 6f :3 0 26
:3 0 de :4 0 336e
336f 0 3ed6 82
:3 0 13b :2 0 3d
:2 0 1c92 3372 3374
:3 0 3f :3 0 9
:3 0 3376 3377 0
3758 24 :3 0 7
:3 0 3379 337a 0
3758 26 :3 0 8
:3 0 337c 337d 0
3758 44 :3 0 b
:3 0 337f 3380 0
3758 45 :3 0 10
:3 0 3382 3383 0
3758 46 :3 0 d
:3 0 3385 3386 0
3758 47 :3 0 e
:3 0 3388 3389 0
3758 4e :3 0 c
:3 0 338b 338c 0
3758 48 :3 0 f
:3 0 338e 338f 0
3758 d8 :3 0 84
:3 0 c :3 0 3d
:2 0 1c95 3392 3395
b0 :3 0 1b7 :3 0
3397 3398 0 1c98
3391 339a 339b :2 0
13b :2 0 3d :2 0
1c9d 339d 339f :3 0
33a0 :2 0 84 :3 0
48 :3 0 3d :2 0
1ca0 33a2 33a5 84
:3 0 13b :2 0 f
:3 0 3d :2 0 1ca3
33a7 33ab 1ca8 33a8
33ad :3 0 33ae :2 0
84 :3 0 44 :3 0
3d :2 0 1cab 33b0
33b3 84 :3 0 13b
:2 0 b :3 0 3d
:2 0 1cae 33b5 33b9
1cb3 33b6 33bb :3 0
33bc :2 0 33af 33be
33bd :2 0 33bf :2 0
33a1 33c1 33c0 :2 0
33c2 :2 0 84 :3 0
e :3 0 3d :2 0
1cb6 33c4 33c7 da
:2 0 e2 :2 0 1cbb
33c9 33cb :3 0 90
:3 0 92 :3 0 21
:3 0 93 :3 0 94
:3 0 4c :3 0 1e
:3 0 a7 :3 0 62
:3 0 58 :3 0 a7
:3 0 1d3 :3 0 62
:3 0 5c :3 0 1d3
:3 0 a8 :3 0 61
:3 0 5b :3 0 a8
:3 0 1d4 :3 0 61
:3 0 5d :3 0 1d4
:3 0 9e :3 0 b
:3 0 291 :3 0 3f
:3 0 ac :3 0 f
:3 0 1d7 :3 0 199
:3 0 19a :3 0 1d7
:3 0 b0 :3 0 1d8
:3 0 9a :3 0 1d
:4 0 292 1 :8 0
3408 e0 :4 0 33f3
:3 0 f7 :3 0 da
:2 0 1cc0 33f6 33f7
:3 0 15 :3 0 e1
:3 0 33f9 33fa 0
3d :2 0 33fb 33fc
0 33fe 1cc3 3405
15 :3 0 e1 :3 0
33ff 3400 0 e2
:2 0 3401 3402 0
3404 1cc5 3406 33f8
33fe 0 3407 0
3404 0 3407 1cc7
0 3408 1cca 3452
e5 :3 0 15 :3 0
e1 :3 0 340b 340c
0 e4 :3 0 340d
340e 0 3448 c3
:3 0 c4 :3 0 3410
3411 0 c3 :3 0
d3 :3 0 3413 3414
0 e6 :2 0 2
:4 0 293 :2 0 d5
:2 0 2a :2 0 1ccd
3419 341b :3 0 1cd0
3415 341d 3412 341f
341e :2 0 c6 :3 0
d6 :3 0 3421 3422
0 c8 :4 0 294
:4 0 cb :2 0 cc
:3 0 1cd4 3426 3428
:3 0 cb :2 0 e9
:4 0 1cd7 342a 342c
:3 0 cb :2 0 ea
:4 0 1cda 342e 3430
:3 0 cb :2 0 e4
:3 0 1cdd 3432 3434
:3 0 cb :2 0 eb
:4 0 1ce0 3436 3438
:3 0 cb :2 0 a0
:3 0 ec :3 0 2a
:2 0 ed :2 0 1ce3
343b 343f 1ce7 343a
3441 :3 0 1cea 3423
3443 :2 0 3445 1ced
3446 3420 3445 0
3447 1cef 0 3448
1cf1 344b :3 0 344b
0 344b 344a 3448
3449 :6 0 344d 9e
:3 0 1cf4 344f 1cf6
344e 344d :2 0 3450
1cf8 :2 0 3452 0
3452 3451 3408 3450
:6 0 3454 6f :3 0
1cfa 34df 90 :3 0
92 :3 0 21 :3 0
93 :3 0 94 :3 0
4c :3 0 1e :3 0
a7 :3 0 62 :3 0
58 :3 0 a7 :3 0
1d3 :3 0 62 :3 0
5c :3 0 1d3 :3 0
a8 :3 0 61 :3 0
5b :3 0 a8 :3 0
1d4 :3 0 61 :3 0
5d :3 0 1d4 :3 0
a9 :3 0 b :3 0
291 :3 0 3f :3 0
ab :3 0 e :3 0
ac :3 0 f :3 0
1d7 :3 0 199 :3 0
19a :3 0 1d7 :3 0
b0 :3 0 1d8 :3 0
9a :3 0 1d :4 0
295 1 :8 0 3492
e0 :4 0 347d :3 0
f7 :3 0 da :2 0
1cfe 3480 3481 :3 0
15 :3 0 e1 :3 0
3483 3484 0 3d
:2 0 3485 3486 0
3488 1d01 348f 15
:3 0 e1 :3 0 3489
348a 0 e2 :2 0
348b 348c 0 348e
1d03 3490 3482 3488
0 3491 0 348e
0 3491 1d05 0
3492 1d08 34dc e5
:3 0 15 :3 0 e1
:3 0 3495 3496 0
e4 :3 0 3497 3498
0 34d2 c3 :3 0
c4 :3 0 349a 349b
0 c3 :3 0 d3
:3 0 349d 349e 0
e6 :2 0 2 :4 0
296 :2 0 d5 :2 0
2a :2 0 1d0b 34a3
34a5 :3 0 1d0e 349f
34a7 349c 34a9 34a8
:2 0 c6 :3 0 d6
:3 0 34ab 34ac 0
c8 :4 0 297 :4 0
cb :2 0 cc :3 0
1d12 34b0 34b2 :3 0
cb :2 0 e9 :4 0
1d15 34b4 34b6 :3 0
cb :2 0 ea :4 0
1d18 34b8 34ba :3 0
cb :2 0 e4 :3 0
1d1b 34bc 34be :3 0
cb :2 0 eb :4 0
1d1e 34c0 34c2 :3 0
cb :2 0 a0 :3 0
ec :3 0 2a :2 0
ed :2 0 1d21 34c5
34c9 1d25 34c4 34cb
:3 0 1d28 34ad 34cd
:2 0 34cf 1d2b 34d0
34aa 34cf 0 34d1
1d2d 0 34d2 1d2f
34d5 :3 0 34d5 0
34d5 34d4 34d2 34d3
:6 0 34d7 a0 :3 0
1d32 34d9 1d34 34d8
34d7 :2 0 34da 1d36
:2 0 34dc 0 34dc
34db 3492 34da :6 0
34de 6f :3 0 1d38
34e0 33cc 3454 0
34e1 0 34de 0
34e1 1d3a 0 34e2
1d3d 3567 90 :3 0
92 :3 0 21 :3 0
93 :3 0 94 :3 0
4c :3 0 1e :3 0
a7 :3 0 62 :3 0
58 :3 0 a7 :3 0
1d3 :3 0 62 :3 0
5c :3 0 1d3 :3 0
a8 :3 0 61 :3 0
5b :3 0 a8 :3 0
1d4 :3 0 61 :3 0
5d :3 0 1d4 :3 0
1d7 :3 0 199 :3 0
19a :3 0 1d7 :3 0
b0 :3 0 1d8 :3 0
291 :3 0 3f :3 0
9a :3 0 1d :4 0
298 1 :8 0 351a
e0 :4 0 3505 :3 0
f7 :3 0 da :2 0
1d41 3508 3509 :3 0
15 :3 0 e1 :3 0
350b 350c 0 3d
:2 0 350d 350e 0
3510 1d44 3517 15
:3 0 e1 :3 0 3511
3512 0 e2 :2 0
3513 3514 0 3516
1d46 3518 350a 3510
0 3519 0 3516
0 3519 1d48 0
351a 1d4b 3564 e5
:3 0 15 :3 0 e1
:3 0 351d 351e 0
e4 :3 0 351f 3520
0 355a c3 :3 0
c4 :3 0 3522 3523
0 c3 :3 0 d3
:3 0 3525 3526 0
e6 :2 0 2 :4 0
299 :2 0 d5 :2 0
2a :2 0 1d4e 352b
352d :3 0 1d51 3527
352f 3524 3531 3530
:2 0 c6 :3 0 d6
:3 0 3533 3534 0
c8 :4 0 29a :4 0
cb :2 0 cc :3 0
1d55 3538 353a :3 0
cb :2 0 e9 :4 0
1d58 353c 353e :3 0
cb :2 0 ea :4 0
1d5b 3540 3542 :3 0
cb :2 0 e4 :3 0
1d5e 3544 3546 :3 0
cb :2 0 eb :4 0
1d61 3548 354a :3 0
cb :2 0 a0 :3 0
ec :3 0 2a :2 0
ed :2 0 1d64 354d
3551 1d68 354c 3553
:3 0 1d6b 3535 3555
:2 0 3557 1d6e 3558
3532 3557 0 3559
1d70 0 355a 1d72
355d :3 0 355d 0
355d 355c 355a 355b
:6 0 355f a2 :3 0
1d75 3561 1d77 3560
355f :2 0 3562 1d79
:2 0 3564 0 3564
3563 351a 3562 :6 0
3566 6f :3 0 1d7b
3568 33c3 34e2 0
3569 0 3566 0
3569 1d7d 0 3758
84 :3 0 48 :3 0
3d :2 0 1d80 356a
356d da :2 0 3d
:2 0 1d85 356f 3571
:3 0 3572 :2 0 84
:3 0 47 :3 0 3d
:2 0 1d88 3574 3577
13b :2 0 e2 :2 0
1d8d 3579 357b :3 0
357c :2 0 3573 357e
357d :2 0 44 :3 0
3d :2 0 3580 3581
0 3584 140 :3 0
1d90 3597 84 :3 0
47 :3 0 3d :2 0
1d92 3585 3588 da
:2 0 e2 :2 0 1d97
358a 358c :3 0 7e
:3 0 84 :3 0 44
:3 0 3d :2 0 1d9a
358f 3592 358e 3593
0 3595 1d9d 3596
358d 3595 0 3598
357f 3584 0 3598
1d9f 0 3758 6b
:3 0 201 :3 0 31
:3 0 32 :3 0 84
:3 0 46 :3 0 3d
:2 0 1da2 359d 35a0
84 :3 0 47 :3 0
3d :2 0 1da5 35a2
35a5 84 :3 0 52
:3 0 3d :2 0 1da8
35a7 35aa 84 :3 0
4e :3 0 3d :2 0
1dab 35ac 35af 84
:3 0 48 :3 0 3d
:2 0 1dae 35b1 35b4
84 :3 0 45 :3 0
3d :2 0 1db1 35b6
35b9 84 :3 0 4f
:3 0 3d :2 0 1db4
35bb 35be 84 :3 0
50 :3 0 3d :2 0
1db7 35c0 35c3 44
:3 0 3f :3 0 49
:3 0 1dba 359a 35c8
3599 35c9 0 3758
84 :3 0 6b :3 0
3d :2 0 1dc8 35cb
35ce b0 :3 0 da
:2 0 202 :3 0 35d0
35d2 0 1dcd 35d1
35d4 :3 0 e3 :3 0
96 :4 0 35d9 :2 0
35df 35d7 0 15
:3 0 e1 :3 0 35da
35db 0 e4 :3 0
35dc 35dd 0 35df
1dd0 3629 e5 :3 0
15 :3 0 e1 :3 0
35e2 35e3 0 e4
:3 0 35e4 35e5 0
361f c3 :3 0 c4
:3 0 35e7 35e8 0
c3 :3 0 d3 :3 0
35ea 35eb 0 e6
:2 0 2 :4 0 29b
:2 0 d5 :2 0 2a
:2 0 1dd3 35f0 35f2
:3 0 1dd6 35ec 35f4
35e9 35f6 35f5 :2 0
c6 :3 0 d6 :3 0
35f8 35f9 0 c8
:4 0 29c :4 0 cb
:2 0 cc :3 0 1dda
35fd 35ff :3 0 cb
:2 0 e9 :4 0 1ddd
3601 3603 :3 0 cb
:2 0 ea :4 0 1de0
3605 3607 :3 0 cb
:2 0 e4 :3 0 1de3
3609 360b :3 0 cb
:2 0 eb :4 0 1de6
360d 360f :3 0 cb
:2 0 a0 :3 0 ec
:3 0 2a :2 0 ed
:2 0 1de9 3612 3616
1ded 3611 3618 :3 0
1df0 35fa 361a :2 0
361c 1df3 361d 35f7
361c 0 361e 1df5
0 361f 1df7 3622
:3 0 3622 0 3622
3621 361f 3620 :6 0
3624 a4 :3 0 1dfa
3626 1dfc 3625 3624
:2 0 3627 1dfe :2 0
3629 0 3629 3628
35df 3627 :6 0 3688
6f :3 0 c3 :3 0
c4 :3 0 362b 362c
0 c3 :3 0 d3
:3 0 362e 362f 0
203 :2 0 2 :4 0
29d :2 0 d5 :2 0
2a :2 0 1e00 3634
3636 :3 0 1e03 3630
3638 362d 363a 3639
:2 0 c6 :3 0 d6
:3 0 363c 363d 0
c8 :4 0 29e :4 0
cb :2 0 cc :3 0
1e07 3641 3643 :3 0
cb :2 0 e9 :4 0
1e0a 3645 3647 :3 0
cb :2 0 f0 :4 0
1e0d 3649 364b :3 0
cb :2 0 84 :3 0
d0 :3 0 b0 :3 0
202 :3 0 3650 3651
0 1e10 364f 3653
d1 :4 0 1e12 364e
3656 1e15 364d 3658
:3 0 1e18 363e 365a
:2 0 365c 1e1b 365d
363b 365c 0 365e
1e1d 0 3688 c3
:3 0 c4 :3 0 365f
3660 0 c3 :3 0
d3 :3 0 3662 3663
0 2a :2 0 2
:4 0 29f :2 0 d5
:2 0 2a :2 0 1e1f
3668 366a :3 0 1e22
3664 366c 3661 366e
366d :2 0 c6 :3 0
d6 :3 0 3670 3671
0 c8 :4 0 2a0
:4 0 cb :2 0 cc
:3 0 1e26 3675 3677
:3 0 1e29 3672 3679
:2 0 367b 1e2c 367c
366f 367b 0 367d
1e2e 0 3688 f5
:3 0 208 :3 0 367e
367f 0 b0 :3 0
202 :3 0 3681 3682
0 f7 :3 0 1e30
3680 3685 :2 0 3688
140 :3 0 1e33 3756
84 :3 0 6b :3 0
3d :2 0 1e38 3689
368c 13b :2 0 3d
:2 0 1e3d 368e 3690
:3 0 e3 :3 0 96
:4 0 3695 :2 0 369b
3693 0 15 :3 0
e1 :3 0 3696 3697
0 e4 :3 0 3698
3699 0 369b 1e40
36e5 e5 :3 0 15
:3 0 e1 :3 0 369e
369f 0 e4 :3 0
36a0 36a1 0 36db
c3 :3 0 c4 :3 0
36a3 36a4 0 c3
:3 0 d3 :3 0 36a6
36a7 0 e6 :2 0
2 :4 0 2a1 :2 0
d5 :2 0 2a :2 0
1e43 36ac 36ae :3 0
1e46 36a8 36b0 36a5
36b2 36b1 :2 0 c6
:3 0 d6 :3 0 36b4
36b5 0 c8 :4 0
2a2 :4 0 cb :2 0
cc :3 0 1e4a 36b9
36bb :3 0 cb :2 0
e9 :4 0 1e4d 36bd
36bf :3 0 cb :2 0
ea :4 0 1e50 36c1
36c3 :3 0 cb :2 0
e4 :3 0 1e53 36c5
36c7 :3 0 cb :2 0
eb :4 0 1e56 36c9
36cb :3 0 cb :2 0
a0 :3 0 ec :3 0
2a :2 0 ed :2 0
1e59 36ce 36d2 1e5d
36cd 36d4 :3 0 1e60
36b6 36d6 :2 0 36d8
1e63 36d9 36b3 36d8
0 36da 1e65 0
36db 1e67 36de :3 0
36de 0 36de 36dd
36db 36dc :6 0 36e0
a6 :3 0 1e6a 36e2
1e6c 36e1 36e0 :2 0
36e3 1e6e :2 0 36e5
0 36e5 36e4 369b
36e3 :6 0 3754 6f
:3 0 c3 :3 0 c4
:3 0 36e7 36e8 0
c3 :3 0 d3 :3 0
36ea 36eb 0 18
:2 0 2 :4 0 2a3
:2 0 d5 :2 0 2a
:2 0 1e70 36f0 36f2
:3 0 1e73 36ec 36f4
36e9 36f6 36f5 :2 0
c6 :3 0 d6 :3 0
36f8 36f9 0 c8
:4 0 2a4 :4 0 cb
:2 0 cc :3 0 1e77
36fd 36ff :3 0 cb
:2 0 e9 :4 0 1e7a
3701 3703 :3 0 cb
:2 0 f0 :4 0 1e7d
3705 3707 :3 0 cb
:2 0 84 :3 0 d0
:3 0 6b :3 0 1e80
370b 370d d1 :4 0
1e82 370a 3710 1e85
3709 3712 :3 0 cb
:2 0 f2 :4 0 1e88
3714 3716 :3 0 cb
:2 0 ce :4 0 1e8b
3718 371a :3 0 cb
:2 0 22 :3 0 1e8e
371c 371e :3 0 cb
:2 0 ce :4 0 1e91
3720 3722 :3 0 1e94
36fa 3724 :2 0 3726
1e97 3727 36f7 3726
0 3728 1e99 0
3754 c3 :3 0 c4
:3 0 3729 372a 0
c3 :3 0 d3 :3 0
372c 372d 0 2a
:2 0 2 :4 0 2a5
:2 0 d5 :2 0 2a
:2 0 1e9b 3732 3734
:3 0 1e9e 372e 3736
372b 3738 3737 :2 0
c6 :3 0 d6 :3 0
373a 373b 0 c8
:4 0 2a6 :4 0 cb
:2 0 cc :3 0 1ea2
373f 3741 :3 0 1ea5
373c 3743 :2 0 3745
1ea8 3746 3739 3745
0 3747 1eaa 0
3754 f5 :3 0 f6
:3 0 3748 3749 0
84 :3 0 6b :3 0
3d :2 0 1eac 374b
374e 22 :3 0 f7
:3 0 1eaf 374a 3752
:2 0 3754 1eb3 3755
3691 3754 0 3757
35d5 3688 0 3757
1eb8 0 3758 1ebb
3869 84 :3 0 44
:3 0 3d :2 0 1ec9
3759 375c da :2 0
3d :2 0 1ece 375e
3760 :3 0 84 :3 0
7e :3 0 3d :2 0
1ed1 3762 3765 13b
:2 0 e2 :2 0 1ed6
3767 3769 :3 0 3761
376b 376a :2 0 84
:3 0 7e :3 0 3d
:2 0 1ed9 376d 3770
13b :2 0 3d :2 0
1ede 3772 3774 :3 0
376c 3776 3775 :2 0
47 :3 0 e2 :2 0
3778 3779 0 3782
44 :3 0 84 :3 0
7e :3 0 3d :2 0
1ee1 377c 377f 377b
3780 0 3782 1ee4
3783 3777 3782 0
3784 1ee7 0 3868
84 :3 0 49 :3 0
3d :2 0 1ee9 3785
3788 da :2 0 3d
:2 0 1eee 378a 378c
:3 0 378d :2 0 84
:3 0 49 :3 0 3d
:2 0 1ef1 378f 3792
84 :3 0 168 :2 0
4f :3 0 3d :2 0
1ef4 3794 3798 1ef9
3795 379a :3 0 379b
:2 0 378e 379d 379c
:2 0 49 :3 0 84
:3 0 4f :3 0 3d
:2 0 1efc 37a0 37a3
379f 37a4 0 37a6
1eff 37ba 49 :3 0
2a7 :3 0 84 :3 0
49 :3 0 3d :2 0
1f01 37a9 37ac 2a8
:2 0 84 :3 0 4f
:3 0 3d :2 0 1f04
37af 37b2 1f07 37ae
37b4 :3 0 1f0a 37a8
37b6 37a7 37b7 0
37b9 1f0c 37bb 379e
37a6 0 37bc 0
37b9 0 37bc 1f0e
0 3868 84 :3 0
49 :3 0 3d :2 0
1f11 37bd 37c0 168
:2 0 2a9 :2 0 1f16
37c2 37c4 :3 0 49
:3 0 84 :3 0 49
:3 0 3d :2 0 1f19
37c7 37ca 1d2 :2 0
3b :2 0 1f1c 37cc
37ce :3 0 37c6 37cf
0 37d1 1f1f 37e4
49 :3 0 2a7 :3 0
2aa :3 0 84 :3 0
49 :3 0 3d :2 0
1f21 37d5 37d8 1f24
37d4 37da 1d2 :2 0
2ab :2 0 1f26 37dc
37de :3 0 1f29 37d3
37e0 37d2 37e1 0
37e3 1f2b 37e5 37c5
37d1 0 37e6 0
37e3 0 37e6 1f2d
0 3868 90 :3 0
92 :3 0 21 :3 0
93 :3 0 94 :3 0
4c :3 0 1e :3 0
a7 :3 0 62 :3 0
58 :3 0 a7 :3 0
1d3 :3 0 62 :3 0
5c :3 0 1d3 :3 0
a8 :3 0 61 :3 0
5b :3 0 a8 :3 0
1d4 :3 0 61 :3 0
5d :3 0 1d4 :3 0
1d7 :3 0 199 :3 0
19a :3 0 1d7 :3 0
b0 :3 0 1d8 :3 0
9a :3 0 1d :4 0
2ac 1 :8 0 381c
e0 :4 0 3807 :3 0
f7 :3 0 da :2 0
1f32 380a 380b :3 0
15 :3 0 e1 :3 0
380d 380e 0 3d
:2 0 380f 3810 0
3812 1f35 3819 15
:3 0 e1 :3 0 3813
3814 0 e2 :2 0
3815 3816 0 3818
1f37 381a 380c 3812
0 381b 0 3818
0 381b 1f39 0
381c 1f3c 3866 e5
:3 0 15 :3 0 e1
:3 0 381f 3820 0
e4 :3 0 3821 3822
0 385c c3 :3 0
c4 :3 0 3824 3825
0 c3 :3 0 d3
:3 0 3827 3828 0
e6 :2 0 2 :4 0
2ad :2 0 d5 :2 0
2a :2 0 1f3f 382d
382f :3 0 1f42 3829
3831 3826 3833 3832
:2 0 c6 :3 0 d6
:3 0 3835 3836 0
c8 :4 0 2ae :4 0
cb :2 0 cc :3 0
1f46 383a 383c :3 0
cb :2 0 e9 :4 0
1f49 383e 3840 :3 0
cb :2 0 ea :4 0
1f4c 3842 3844 :3 0
cb :2 0 e4 :3 0
1f4f 3846 3848 :3 0
cb :2 0 eb :4 0
1f52 384a 384c :3 0
cb :2 0 a0 :3 0
ec :3 0 2a :2 0
ed :2 0 1f55 384f
3853 1f59 384e 3855
:3 0 1f5c 3837 3857
:2 0 3859 1f5f 385a
3834 3859 0 385b
1f61 0 385c 1f63
385f :3 0 385f 0
385f 385e 385c 385d
:6 0 3861 a8 :3 0
1f66 3863 1f68 3862
3861 :2 0 3864 1f6a
:2 0 3866 0 3866
3865 381c 3864 :6 0
3868 6f :3 0 1f6c
386a 3375 3758 0
386b 0 3868 0
386b 1f71 0 3ed6
4a :3 0 3d :2 0
386c 386d 0 3ed6
51 :3 0 2a :2 0
386f 3870 0 3ed6
40 :3 0 3d :2 0
3872 3873 0 3ed6
84 :3 0 44 :3 0
3d :2 0 1f74 3875
3878 da :2 0 3d
:2 0 1f79 387a 387c
:3 0 84 :3 0 7e
:3 0 3d :2 0 1f7c
387e 3881 da :2 0
e2 :2 0 1f81 3883
3885 :3 0 84 :3 0
7e :3 0 3d :2 0
1f84 3887 388a da
:2 0 3d :2 0 1f89
388c 388e :3 0 3886
3890 388f :2 0 3891
:2 0 387d 3893 3892
:2 0 4e :3 0 b0
:3 0 20d :3 0 3896
3897 0 3895 3898
0 389a 1f8c 38ab
4e :3 0 1ff :3 0
19a :3 0 389c 389d
0 84 :3 0 4e
:3 0 3d :2 0 1f8e
389f 38a2 b0 :3 0
20d :3 0 38a4 38a5
0 1f91 389e 38a7
389b 38a8 0 38aa
1f94 38ac 3894 389a
0 38ad 0 38aa
0 38ad 1f96 0
3ed6 45 :3 0 3d
:2 0 38ae 38af 0
3ed6 6a :3 0 5a
:2 0 38b1 38b2 0
3ed6 66 :3 0 20e
:3 0 1d :3 0 22
:3 0 20 :3 0 21
:3 0 6a :3 0 41
:3 0 29 :3 0 29
:3 0 29 :3 0 29
:3 0 24 :3 0 26
:3 0 49 :3 0 3f
:3 0 44 :3 0 46
:3 0 47 :3 0 40
:3 0 52 :3 0 2e
:3 0 4a :3 0 4e
:3 0 48 :3 0 45
:3 0 51 :3 0 4f
:3 0 53 :3 0 1a
:3 0 3d :2 0 3d
:2 0 5a :2 0 5a
:2 0 1f99 38b5 38d6
38b4 38d7 0 3ed6
84 :3 0 66 :3 0
3d :2 0 1fba 38d9
38dc da :2 0 20f
:2 0 1fbf 38de 38e0
:3 0 e3 :3 0 96
:4 0 38e5 :2 0 38eb
38e3 0 15 :3 0
e1 :3 0 38e6 38e7
0 e4 :3 0 38e8
38e9 0 38eb 1fc2
3935 e5 :3 0 15
:3 0 e1 :3 0 38ee
38ef 0 e4 :3 0
38f0 38f1 0 392b
c3 :3 0 c4 :3 0
38f3 38f4 0 c3
:3 0 d3 :3 0 38f6
38f7 0 e6 :2 0
2 :4 0 2af :2 0
d5 :2 0 2a :2 0
1fc5 38fc 38fe :3 0
1fc8 38f8 3900 38f5
3902 3901 :2 0 c6
:3 0 d6 :3 0 3904
3905 0 c8 :4 0
2b0 :4 0 cb :2 0
cc :3 0 1fcc 3909
390b :3 0 cb :2 0
e9 :4 0 1fcf 390d
390f :3 0 cb :2 0
ea :4 0 1fd2 3911
3913 :3 0 cb :2 0
e4 :3 0 1fd5 3915
3917 :3 0 cb :2 0
eb :4 0 1fd8 3919
391b :3 0 cb :2 0
a0 :3 0 ec :3 0
2a :2 0 ed :2 0
1fdb 391e 3922 1fdf
391d 3924 :3 0 1fe2
3906 3926 :2 0 3928
1fe5 3929 3903 3928
0 392a 1fe7 0
392b 1fe9 392e :3 0
392e 0 392e 392d
392b 392c :6 0 3930
aa :3 0 1fec 3932
1fee 3931 3930 :2 0
3933 1ff0 :2 0 3935
0 3935 3934 38eb
3933 :6 0 39a5 6f
:3 0 c3 :3 0 c4
:3 0 3937 3938 0
c3 :3 0 d3 :3 0
393a 393b 0 18
:2 0 2 :4 0 2b1
:2 0 d5 :2 0 2a
:2 0 1ff2 3940 3942
:3 0 1ff5 393c 3944
3939 3946 3945 :2 0
c6 :3 0 d6 :3 0
3948 3949 0 c8
:4 0 2b2 :4 0 cb
:2 0 cc :3 0 1ff9
394d 394f :3 0 cb
:2 0 e9 :4 0 1ffc
3951 3953 :3 0 cb
:2 0 f0 :4 0 1fff
3955 3957 :3 0 cb
:2 0 84 :3 0 d0
:3 0 b0 :3 0 212
:3 0 395c 395d 0
2002 395b 395f d1
:4 0 2004 395a 3962
2007 3959 3964 :3 0
cb :2 0 f2 :4 0
200a 3966 3968 :3 0
cb :2 0 ce :4 0
200d 396a 396c :3 0
cb :2 0 21 :3 0
2010 396e 3970 :3 0
cb :2 0 ce :4 0
2013 3972 3974 :3 0
2016 394a 3976 :2 0
3978 2019 3979 3947
3978 0 397a 201b
0 39a5 c3 :3 0
c4 :3 0 397b 397c
0 c3 :3 0 d3
:3 0 397e 397f 0
2a :2 0 2 :4 0
2b3 :2 0 d5 :2 0
2a :2 0 201d 3984
3986 :3 0 2020 3980
3988 397d 398a 3989
:2 0 c6 :3 0 d6
:3 0 398c 398d 0
c8 :4 0 2b4 :4 0
cb :2 0 cc :3 0
2024 3991 3993 :3 0
2027 398e 3995 :2 0
3997 202a 3998 398b
3997 0 3999 202c
0 39a5 f5 :3 0
f6 :3 0 399a 399b
0 b0 :3 0 212
:3 0 399d 399e 0
21 :3 0 f7 :3 0
202e 399c 39a2 :2 0
39a5 140 :3 0 2032
3a73 84 :3 0 66
:3 0 3d :2 0 2037
39a6 39a9 13b :2 0
3d :2 0 203c 39ab
39ad :3 0 e3 :3 0
96 :4 0 39b2 :2 0
39b8 39b0 0 15
:3 0 e1 :3 0 39b3
39b4 0 e4 :3 0
39b5 39b6 0 39b8
203f 3a02 e5 :3 0
15 :3 0 e1 :3 0
39bb 39bc 0 e4
:3 0 39bd 39be 0
39f8 c3 :3 0 c4
:3 0 39c0 39c1 0
c3 :3 0 d3 :3 0
39c3 39c4 0 e6
:2 0 2 :4 0 2b5
:2 0 d5 :2 0 2a
:2 0 2042 39c9 39cb
:3 0 2045 39c5 39cd
39c2 39cf 39ce :2 0
c6 :3 0 d6 :3 0
39d1 39d2 0 c8
:4 0 2b6 :4 0 cb
:2 0 cc :3 0 2049
39d6 39d8 :3 0 cb
:2 0 e9 :4 0 204c
39da 39dc :3 0 cb
:2 0 ea :4 0 204f
39de 39e0 :3 0 cb
:2 0 e4 :3 0 2052
39e2 39e4 :3 0 cb
:2 0 eb :4 0 2055
39e6 39e8 :3 0 cb
:2 0 a0 :3 0 ec
:3 0 2a :2 0 ed
:2 0 2058 39eb 39ef
205c 39ea 39f1 :3 0
205f 39d3 39f3 :2 0
39f5 2062 39f6 39d0
39f5 0 39f7 2064
0 39f8 2066 39fb
:3 0 39fb 0 39fb
39fa 39f8 39f9 :6 0
39fd ac :3 0 2069
39ff 206b 39fe 39fd
:2 0 3a00 206d :2 0
3a02 0 3a02 3a01
39b8 3a00 :6 0 3a71
6f :3 0 c3 :3 0
c4 :3 0 3a04 3a05
0 c3 :3 0 d3
:3 0 3a07 3a08 0
18 :2 0 2 :4 0
2b7 :2 0 d5 :2 0
2a :2 0 206f 3a0d
3a0f :3 0 2072 3a09
3a11 3a06 3a13 3a12
:2 0 c6 :3 0 d6
:3 0 3a15 3a16 0
c8 :4 0 2b8 :4 0
cb :2 0 cc :3 0
2076 3a1a 3a1c :3 0
cb :2 0 e9 :4 0
2079 3a1e 3a20 :3 0
cb :2 0 f0 :4 0
207c 3a22 3a24 :3 0
cb :2 0 84 :3 0
d0 :3 0 b0 :3 0
1ba :3 0 3a29 3a2a
0 207f 3a28 3a2c
d1 :4 0 2081 3a27
3a2f 2084 3a26 3a31
:3 0 cb :2 0 f2
:4 0 2087 3a33 3a35
:3 0 cb :2 0 ce
:4 0 208a 3a37 3a39
:3 0 cb :2 0 1c
:3 0 208d 3a3b 3a3d
:3 0 cb :2 0 ce
:4 0 2090 3a3f 3a41
:3 0 2093 3a17 3a43
:2 0 3a45 2096 3a46
3a14 3a45 0 3a47
2098 0 3a71 c3
:3 0 c4 :3 0 3a48
3a49 0 c3 :3 0
d3 :3 0 3a4b 3a4c
0 2a :2 0 2
:4 0 2b9 :2 0 d5
:2 0 2a :2 0 209a
3a51 3a53 :3 0 209d
3a4d 3a55 3a4a 3a57
3a56 :2 0 c6 :3 0
d6 :3 0 3a59 3a5a
0 c8 :4 0 2ba
:4 0 cb :2 0 cc
:3 0 20a1 3a5e 3a60
:3 0 20a4 3a5b 3a62
:2 0 3a64 20a7 3a65
3a58 3a64 0 3a66
20a9 0 3a71 f5
:3 0 f6 :3 0 3a67
3a68 0 b0 :3 0
1ba :3 0 3a6a 3a6b
0 1c :3 0 f7
:3 0 20ab 3a69 3a6f
:2 0 3a71 20af 3a72
39ae 3a71 0 3a74
38e1 39a5 0 3a74
20b4 0 3ed6 ae
:3 0 185 :3 0 186
:3 0 185 :3 0 39
:3 0 8b :3 0 20
:4 0 2bb 1 :8 0
3a92 e0 :4 0 3a7d
:3 0 f7 :3 0 da
:2 0 20b9 3a80 3a81
:3 0 15 :3 0 e1
:3 0 3a83 3a84 0
3d :2 0 3a85 3a86
0 3a88 20bc 3a8f
15 :3 0 e1 :3 0
3a89 3a8a 0 e2
:2 0 3a8b 3a8c 0
3a8e 20be 3a90 3a82
3a88 0 3a91 0
3a8e 0 3a91 20c0
0 3a92 20c3 3adc
e5 :3 0 15 :3 0
e1 :3 0 3a95 3a96
0 e4 :3 0 3a97
3a98 0 3ad2 c3
:3 0 c4 :3 0 3a9a
3a9b 0 c3 :3 0
d3 :3 0 3a9d 3a9e
0 e6 :2 0 2
:4 0 2bc :2 0 d5
:2 0 2a :2 0 20c6
3aa3 3aa5 :3 0 20c9
3a9f 3aa7 3a9c 3aa9
3aa8 :2 0 c6 :3 0
d6 :3 0 3aab 3aac
0 c8 :4 0 2bd
:4 0 cb :2 0 cc
:3 0 20cd 3ab0 3ab2
:3 0 cb :2 0 e9
:4 0 20d0 3ab4 3ab6
:3 0 cb :2 0 ea
:4 0 20d3 3ab8 3aba
:3 0 cb :2 0 e4
:3 0 20d6 3abc 3abe
:3 0 cb :2 0 eb
:4 0 20d9 3ac0 3ac2
:3 0 cb :2 0 a0
:3 0 ec :3 0 2a
:2 0 ed :2 0 20dc
3ac5 3ac9 20e0 3ac4
3acb :3 0 20e3 3aad
3acd :2 0 3acf 20e6
3ad0 3aaa 3acf 0
3ad1 20e8 0 3ad2
20ea 3ad5 :3 0 3ad5
0 3ad5 3ad4 3ad2
3ad3 :6 0 3ad7 ae
:3 0 20ed 3ad9 20ef
3ad8 3ad7 :2 0 3ada
20f1 :2 0 3adc 0
3adc 3adb 3a92 3ada
:6 0 3ed6 6f :3 0
251 :3 0 1d :3 0
2be :3 0 8b :3 0
2be :3 0 1f0 :3 0
2be :3 0 1f1 :3 0
2be :3 0 1f2 :3 0
2be :3 0 1f3 :3 0
2bf :3 0 2be :3 0
11a :3 0 12e :3 0
2c0 :3 0 2be :3 0
8b :3 0 2c0 :3 0
12d :3 0 2c0 :3 0
12f :3 0 23 :4 0
2c1 1 :8 0 3b0c
e0 :4 0 3af7 :3 0
f7 :3 0 da :2 0
20f5 3afa 3afb :3 0
15 :3 0 e1 :3 0
3afd 3afe 0 3d
:2 0 3aff 3b00 0
3b02 20f8 3b09 15
:3 0 e1 :3 0 3b03
3b04 0 e2 :2 0
3b05 3b06 0 3b08
20fa 3b0a 3afc 3b02
0 3b0b 0 3b08
0 3b0b 20fc 0
3b0c 20ff 3b56 e5
:3 0 15 :3 0 e1
:3 0 3b0f 3b10 0
e4 :3 0 3b11 3b12
0 3b4c c3 :3 0
c4 :3 0 3b14 3b15
0 c3 :3 0 d3
:3 0 3b17 3b18 0
e6 :2 0 2 :4 0
2c2 :2 0 d5 :2 0
2a :2 0 2102 3b1d
3b1f :3 0 2105 3b19
3b21 3b16 3b23 3b22
:2 0 c6 :3 0 d6
:3 0 3b25 3b26 0
c8 :4 0 2c3 :4 0
cb :2 0 cc :3 0
2109 3b2a 3b2c :3 0
cb :2 0 e9 :4 0
210c 3b2e 3b30 :3 0
cb :2 0 ea :4 0
210f 3b32 3b34 :3 0
cb :2 0 e4 :3 0
2112 3b36 3b38 :3 0
cb :2 0 eb :4 0
2115 3b3a 3b3c :3 0
cb :2 0 a0 :3 0
ec :3 0 2a :2 0
ed :2 0 2118 3b3f
3b43 211c 3b3e 3b45
:3 0 211f 3b27 3b47
:2 0 3b49 2122 3b4a
3b24 3b49 0 3b4b
2124 0 3b4c 2126
3b4f :3 0 3b4f 0
3b4f 3b4e 3b4c 3b4d
:6 0 3b51 b0 :3 0
2129 3b53 212b 3b52
3b51 :2 0 3b54 212d
:2 0 3b56 0 3b56
3b55 3b0c 3b54 :6 0
3ed6 6f :3 0 251
:3 0 1d :3 0 12d
:3 0 1f0 :3 0 1f1
:3 0 1f2 :3 0 1f3
:3 0 2c4 :3 0 251
:3 0 98 :3 0 23
:4 0 2c5 1 :8 0
3b79 e0 :4 0 3b64
:3 0 f7 :3 0 da
:2 0 2131 3b67 3b68
:3 0 15 :3 0 e1
:3 0 3b6a 3b6b 0
3d :2 0 3b6c 3b6d
0 3b6f 2134 3b76
15 :3 0 e1 :3 0
3b70 3b71 0 e2
:2 0 3b72 3b73 0
3b75 2136 3b77 3b69
3b6f 0 3b78 0
3b75 0 3b78 2138
0 3b79 213b 3bc3
e5 :3 0 15 :3 0
e1 :3 0 3b7c 3b7d
0 e4 :3 0 3b7e
3b7f 0 3bb9 c3
:3 0 c4 :3 0 3b81
3b82 0 c3 :3 0
d3 :3 0 3b84 3b85
0 e6 :2 0 2
:4 0 2c6 :2 0 d5
:2 0 2a :2 0 213e
3b8a 3b8c :3 0 2141
3b86 3b8e 3b83 3b90
3b8f :2 0 c6 :3 0
d6 :3 0 3b92 3b93
0 c8 :4 0 2c7
:4 0 cb :2 0 cc
:3 0 2145 3b97 3b99
:3 0 cb :2 0 e9
:4 0 2148 3b9b 3b9d
:3 0 cb :2 0 ea
:4 0 214b 3b9f 3ba1
:3 0 cb :2 0 e4
:3 0 214e 3ba3 3ba5
:3 0 cb :2 0 eb
:4 0 2151 3ba7 3ba9
:3 0 cb :2 0 a0
:3 0 ec :3 0 2a
:2 0 ed :2 0 2154
3bac 3bb0 2158 3bab
3bb2 :3 0 215b 3b94
3bb4 :2 0 3bb6 215e
3bb7 3b91 3bb6 0
3bb8 2160 0 3bb9
2162 3bbc :3 0 3bbc
0 3bbc 3bbb 3bb9
3bba :6 0 3bbe b2
:3 0 2165 3bc0 2167
3bbf 3bbe :2 0 3bc1
2169 :2 0 3bc3 0
3bc3 3bc2 3b79 3bc1
:6 0 3ed6 6f :3 0
1ee :3 0 1d :3 0
1ef :3 0 1f0 :3 0
1f1 :3 0 1f2 :3 0
1f3 :3 0 1f4 :3 0
1ee :3 0 98 :3 0
23 :4 0 2c8 1
:8 0 3be6 e0 :4 0
3bd1 :3 0 f7 :3 0
da :2 0 216d 3bd4
3bd5 :3 0 15 :3 0
e1 :3 0 3bd7 3bd8
0 3d :2 0 3bd9
3bda 0 3bdc 2170
3be3 15 :3 0 e1
:3 0 3bdd 3bde 0
e2 :2 0 3bdf 3be0
0 3be2 2172 3be4
3bd6 3bdc 0 3be5
0 3be2 0 3be5
2174 0 3be6 2177
3c30 e5 :3 0 15
:3 0 e1 :3 0 3be9
3bea 0 e4 :3 0
3beb 3bec 0 3c26
c3 :3 0 c4 :3 0
3bee 3bef 0 c3
:3 0 d3 :3 0 3bf1
3bf2 0 e6 :2 0
2 :4 0 2c9 :2 0
d5 :2 0 2a :2 0
217a 3bf7 3bf9 :3 0
217d 3bf3 3bfb 3bf0
3bfd 3bfc :2 0 c6
:3 0 d6 :3 0 3bff
3c00 0 c8 :4 0
2ca :4 0 cb :2 0
cc :3 0 2181 3c04
3c06 :3 0 cb :2 0
e9 :4 0 2184 3c08
3c0a :3 0 cb :2 0
ea :4 0 2187 3c0c
3c0e :3 0 cb :2 0
e4 :3 0 218a 3c10
3c12 :3 0 cb :2 0
eb :4 0 218d 3c14
3c16 :3 0 cb :2 0
a0 :3 0 ec :3 0
2a :2 0 ed :2 0
2190 3c19 3c1d 2194
3c18 3c1f :3 0 2197
3c01 3c21 :2 0 3c23
219a 3c24 3bfe 3c23
0 3c25 219c 0
3c26 219e 3c29 :3 0
3c29 0 3c29 3c28
3c26 3c27 :6 0 3c2b
b4 :3 0 21a1 3c2d
21a3 3c2c 3c2b :2 0
3c2e 21a5 :2 0 3c30
0 3c30 3c2f 3be6
3c2e :6 0 3ed6 6f
:3 0 4b :3 0 84
:3 0 4b :3 0 3d
:2 0 21a7 3c33 3c36
d5 :2 0 2a :2 0
21aa 3c38 3c3a :3 0
3c32 3c3b 0 3ed6
43 :3 0 84 :3 0
43 :3 0 3d :2 0
21ad 3c3e 3c41 d5
:2 0 84 :3 0 3f
:3 0 3d :2 0 21b0
3c44 3c47 21b3 3c43
3c49 :3 0 3c3d 3c4a
0 3ed6 6c :3 0
2a :4 0 3c4c 3c4d
0 3ed6 71 :3 0
2cb :3 0 22 :3 0
23 :3 0 6c :3 0
21b6 3c50 3c54 3c4f
3c55 0 3ed6 6c
:3 0 3d :4 0 3c57
3c58 0 3ed6 71
:3 0 2cb :3 0 22
:3 0 21 :3 0 6c
:3 0 21ba 3c5b 3c5f
3c5a 3c60 0 3ed6
24a :3 0 92 :3 0
21 :3 0 91 :3 0
22 :3 0 9a :3 0
1d :4 0 2cc 1
:8 0 3c7f e0 :4 0
3c6a :3 0 f7 :3 0
da :2 0 21c0 3c6d
3c6e :3 0 15 :3 0
e1 :3 0 3c70 3c71
0 3d :2 0 3c72
3c73 0 3c75 21c3
3c7c 15 :3 0 e1
:3 0 3c76 3c77 0
e2 :2 0 3c78 3c79
0 3c7b 21c5 3c7d
3c6f 3c75 0 3c7e
0 3c7b 0 3c7e
21c7 0 3c7f 21ca
3cc9 e5 :3 0 15
:3 0 e1 :3 0 3c82
3c83 0 e4 :3 0
3c84 3c85 0 3cbf
c3 :3 0 c4 :3 0
3c87 3c88 0 c3
:3 0 d3 :3 0 3c8a
3c8b 0 e6 :2 0
2 :4 0 2cd :2 0
d5 :2 0 2a :2 0
21cd 3c90 3c92 :3 0
21d0 3c8c 3c94 3c89
3c96 3c95 :2 0 c6
:3 0 d6 :3 0 3c98
3c99 0 c8 :4 0
2ce :4 0 cb :2 0
cc :3 0 21d4 3c9d
3c9f :3 0 cb :2 0
e9 :4 0 21d7 3ca1
3ca3 :3 0 cb :2 0
ea :4 0 21da 3ca5
3ca7 :3 0 cb :2 0
e4 :3 0 21dd 3ca9
3cab :3 0 cb :2 0
eb :4 0 21e0 3cad
3caf :3 0 cb :2 0
a0 :3 0 ec :3 0
2a :2 0 ed :2 0
21e3 3cb2 3cb6 21e7
3cb1 3cb8 :3 0 21ea
3c9a 3cba :2 0 3cbc
21ed 3cbd 3c97 3cbc
0 3cbe 21ef 0
3cbf 21f1 3cc2 :3 0
3cc2 0 3cc2 3cc1
3cbf 3cc0 :6 0 3cc4
b6 :3 0 21f4 3cc6
21f6 3cc5 3cc4 :2 0
3cc7 21f8 :2 0 3cc9
0 3cc9 3cc8 3c7f
3cc7 :6 0 3ed6 6f
:3 0 84 :3 0 62
:3 0 3d :2 0 21fa
3ccb 3cce da :2 0
3d :2 0 21ff 3cd0
3cd2 :3 0 3cd3 :2 0
84 :3 0 61 :3 0
3d :2 0 2202 3cd5
3cd8 da :2 0 3d
:2 0 2207 3cda 3cdc
:3 0 3cdd :2 0 3cd4
3cdf 3cde :2 0 258
:3 0 92 :3 0 21
:3 0 2cf :3 0 58
:3 0 2d0 :3 0 5c
:3 0 2d1 :3 0 5b
:3 0 2d2 :3 0 5d
:3 0 179 :3 0 1a
:3 0 17a :3 0 cc
:3 0 9a :3 0 17
:4 0 2d3 1 :8 0
3d08 e0 :4 0 3cf3
:3 0 f7 :3 0 da
:2 0 220c 3cf6 3cf7
:3 0 15 :3 0 e1
:3 0 3cf9 3cfa 0
3d :2 0 3cfb 3cfc
0 3cfe 220f 3d05
15 :3 0 e1 :3 0
3cff 3d00 0 e2
:2 0 3d01 3d02 0
3d04 2211 3d06 3cf8
3cfe 0 3d07 0
3d04 0 3d07 2213
0 3d08 2216 3d52
e5 :3 0 15 :3 0
e1 :3 0 3d0b 3d0c
0 e4 :3 0 3d0d
3d0e 0 3d48 c3
:3 0 c4 :3 0 3d10
3d11 0 c3 :3 0
d3 :3 0 3d13 3d14
0 e6 :2 0 2
:4 0 2d4 :2 0 d5
:2 0 2a :2 0 2219
3d19 3d1b :3 0 221c
3d15 3d1d 3d12 3d1f
3d1e :2 0 c6 :3 0
d6 :3 0 3d21 3d22
0 c8 :4 0 2d5
:4 0 cb :2 0 cc
:3 0 2220 3d26 3d28
:3 0 cb :2 0 e9
:4 0 2223 3d2a 3d2c
:3 0 cb :2 0 ea
:4 0 2226 3d2e 3d30
:3 0 cb :2 0 e4
:3 0 2229 3d32 3d34
:3 0 cb :2 0 eb
:4 0 222c 3d36 3d38
:3 0 cb :2 0 a0
:3 0 ec :3 0 2a
:2 0 ed :2 0 222f
3d3b 3d3f 2233 3d3a
3d41 :3 0 2236 3d23
3d43 :2 0 3d45 2239
3d46 3d20 3d45 0
3d47 223b 0 3d48
223d 3d4b :3 0 3d4b
0 3d4b 3d4a 3d48
3d49 :6 0 3d4d b8
:3 0 2240 3d4f 2242
3d4e 3d4d :2 0 3d50
2244 :2 0 3d52 0
3d52 3d51 3d08 3d50
:6 0 3d55 6f :3 0
140 :3 0 2246 3ed3
84 :3 0 62 :3 0
3d :2 0 2248 3d56
3d59 da :2 0 3d
:2 0 224d 3d5b 3d5d
:3 0 258 :3 0 92
:3 0 21 :3 0 2cf
:3 0 58 :3 0 2d0
:3 0 5c :3 0 179
:3 0 1a :3 0 17a
:3 0 cc :3 0 9a
:3 0 17 :4 0 2d6
1 :8 0 3d82 e0
:4 0 3d6d :3 0 f7
:3 0 da :2 0 2252
3d70 3d71 :3 0 15
:3 0 e1 :3 0 3d73
3d74 0 3d :2 0
3d75 3d76 0 3d78
2255 3d7f 15 :3 0
e1 :3 0 3d79 3d7a
0 e2 :2 0 3d7b
3d7c 0 3d7e 2257
3d80 3d72 3d78 0
3d81 0 3d7e 0
3d81 2259 0 3d82
225c 3dcc e5 :3 0
15 :3 0 e1 :3 0
3d85 3d86 0 e4
:3 0 3d87 3d88 0
3dc2 c3 :3 0 c4
:3 0 3d8a 3d8b 0
c3 :3 0 d3 :3 0
3d8d 3d8e 0 e6
:2 0 2 :4 0 2d7
:2 0 d5 :2 0 2a
:2 0 225f 3d93 3d95
:3 0 2262 3d8f 3d97
3d8c 3d99 3d98 :2 0
c6 :3 0 d6 :3 0
3d9b 3d9c 0 c8
:4 0 2d8 :4 0 cb
:2 0 cc :3 0 2266
3da0 3da2 :3 0 cb
:2 0 e9 :4 0 2269
3da4 3da6 :3 0 cb
:2 0 ea :4 0 226c
3da8 3daa :3 0 cb
:2 0 e4 :3 0 226f
3dac 3dae :3 0 cb
:2 0 eb :4 0 2272
3db0 3db2 :3 0 cb
:2 0 a0 :3 0 ec
:3 0 2a :2 0 ed
:2 0 2275 3db5 3db9
2279 3db4 3dbb :3 0
227c 3d9d 3dbd :2 0
3dbf 227f 3dc0 3d9a
3dbf 0 3dc1 2281
0 3dc2 2283 3dc5
:3 0 3dc5 0 3dc5
3dc4 3dc2 3dc3 :6 0
3dc7 ba :3 0 2286
3dc9 2288 3dc8 3dc7
:2 0 3dca 228a :2 0
3dcc 0 3dcc 3dcb
3d82 3dca :6 0 3dd6
6f :3 0 5b :3 0
84 :3 0 75 :3 0
3d :2 0 228c 3dcf
3dd2 3dce 3dd3 0
3dd6 140 :3 0 228f
3dd7 3d5e 3dd6 0
3ed5 84 :3 0 61
:3 0 3d :2 0 2292
3dd8 3ddb da :2 0
3d :2 0 2297 3ddd
3ddf :3 0 258 :3 0
92 :3 0 21 :3 0
2d1 :3 0 5b :3 0
2d2 :3 0 5d :3 0
179 :3 0 1a :3 0
17a :3 0 cc :3 0
9a :3 0 17 :4 0
2d9 1 :8 0 3e04
e0 :4 0 3def :3 0
f7 :3 0 da :2 0
229c 3df2 3df3 :3 0
15 :3 0 e1 :3 0
3df5 3df6 0 3d
:2 0 3df7 3df8 0
3dfa 229f 3e01 15
:3 0 e1 :3 0 3dfb
3dfc 0 e2 :2 0
3dfd 3dfe 0 3e00
22a1 3e02 3df4 3dfa
0 3e03 0 3e00
0 3e03 22a3 0
3e04 22a6 3e4e e5
:3 0 15 :3 0 e1
:3 0 3e07 3e08 0
e4 :3 0 3e09 3e0a
0 3e44 c3 :3 0
c4 :3 0 3e0c 3e0d
0 c3 :3 0 d3
:3 0 3e0f 3e10 0
e6 :2 0 2 :4 0
2da :2 0 d5 :2 0
2a :2 0 22a9 3e15
3e17 :3 0 22ac 3e11
3e19 3e0e 3e1b 3e1a
:2 0 c6 :3 0 d6
:3 0 3e1d 3e1e 0
c8 :4 0 2db :4 0
cb :2 0 cc :3 0
22b0 3e22 3e24 :3 0
cb :2 0 e9 :4 0
22b3 3e26 3e28 :3 0
cb :2 0 ea :4 0
22b6 3e2a 3e2c :3 0
cb :2 0 e4 :3 0
22b9 3e2e 3e30 :3 0
cb :2 0 eb :4 0
22bc 3e32 3e34 :3 0
cb :2 0 a0 :3 0
ec :3 0 2a :2 0
ed :2 0 22bf 3e37
3e3b 22c3 3e36 3e3d
:3 0 22c6 3e1f 3e3f
:2 0 3e41 22c9 3e42
3e1c 3e41 0 3e43
22cb 0 3e44 22cd
3e47 :3 0 3e47 0
3e47 3e46 3e44 3e45
:6 0 3e49 bc :3 0
22d0 3e4b 22d2 3e4a
3e49 :2 0 3e4c 22d4
:2 0 3e4e 0 3e4e
3e4d 3e04 3e4c :6 0
3e57 6f :3 0 58
:3 0 84 :3 0 74
:3 0 3d :2 0 22d6
3e51 3e54 3e50 3e55
0 3e57 22d9 3e58
3de0 3e57 0 3ed5
258 :3 0 92 :3 0
21 :3 0 179 :3 0
1a :3 0 17a :3 0
cc :3 0 9a :3 0
17 :4 0 2dc 1
:8 0 3e78 e0 :4 0
3e63 :3 0 f7 :3 0
da :2 0 22de 3e66
3e67 :3 0 15 :3 0
e1 :3 0 3e69 3e6a
0 3d :2 0 3e6b
3e6c 0 3e6e 22e1
3e75 15 :3 0 e1
:3 0 3e6f 3e70 0
e2 :2 0 3e71 3e72
0 3e74 22e3 3e76
3e68 3e6e 0 3e77
0 3e74 0 3e77
22e5 0 3e78 22e8
3ec2 e5 :3 0 15
:3 0 e1 :3 0 3e7b
3e7c 0 e4 :3 0
3e7d 3e7e 0 3eb8
c3 :3 0 c4 :3 0
3e80 3e81 0 c3
:3 0 d3 :3 0 3e83
3e84 0 e6 :2 0
2 :4 0 2dd :2 0
d5 :2 0 2a :2 0
22eb 3e89 3e8b :3 0
22ee 3e85 3e8d 3e82
3e8f 3e8e :2 0 c6
:3 0 d6 :3 0 3e91
3e92 0 c8 :4 0
2de :4 0 cb :2 0
cc :3 0 22f2 3e96
3e98 :3 0 cb :2 0
e9 :4 0 22f5 3e9a
3e9c :3 0 cb :2 0
ea :4 0 22f8 3e9e
3ea0 :3 0 cb :2 0
e4 :3 0 22fb 3ea2
3ea4 :3 0 cb :2 0
eb :4 0 22fe 3ea6
3ea8 :3 0 cb :2 0
a0 :3 0 ec :3 0
2a :2 0 ed :2 0
2301 3eab 3eaf 2305
3eaa 3eb1 :3 0 2308
3e93 3eb3 :2 0 3eb5
230b 3eb6 3e90 3eb5
0 3eb7 230d 0
3eb8 230f 3ebb :3 0
3ebb 0 3ebb 3eba
3eb8 3eb9 :6 0 3ebd
be :3 0 2312 3ebf
2314 3ebe 3ebd :2 0
3ec0 2316 :2 0 3ec2
0 3ec2 3ec1 3e78
3ec0 :6 0 3ed2 6f
:3 0 58 :3 0 84
:3 0 74 :3 0 3d
:2 0 2318 3ec5 3ec8
3ec4 3ec9 0 3ed2
5b :3 0 84 :3 0
75 :3 0 3d :2 0
231b 3ecc 3ecf 3ecb
3ed0 0 3ed2 231e
3ed4 3ce0 3d55 0
3ed5 0 3ed2 0
3ed5 2322 0 3ed6
2327 3ed7 3126 3ed6
0 3ed8 2342 0
3ed9 2344 3eda 2be5
3ed9 0 3edb 2349
0 3edc 234b 3ede
28ac 2b14 0 3edf
0 3edc 0 3edf
234f 0 3eea 15
:3 0 e1 :3 0 3ee0
3ee1 0 2df :3 0
22 :3 0 23 :3 0
1a :3 0 2352 3ee3
3ee7 3ee2 3ee8 0
3eea 2356 3eec 241
:4 0 3eea :4 0 4b22
e3 :3 0 96 :4 0
3ef0 :2 0 3ef6 3eee
0 15 :3 0 e1
:3 0 3ef1 3ef2 0
e4 :3 0 3ef3 3ef4
0 3ef6 235c 3f40
e5 :3 0 15 :3 0
e1 :3 0 3ef9 3efa
0 e4 :3 0 3efb
3efc 0 3f36 c3
:3 0 c4 :3 0 3efe
3eff 0 c3 :3 0
d3 :3 0 3f01 3f02
0 e6 :2 0 2
:4 0 2e0 :2 0 d5
:2 0 2a :2 0 235f
3f07 3f09 :3 0 2362
3f03 3f0b 3f00 3f0d
3f0c :2 0 c6 :3 0
d6 :3 0 3f0f 3f10
0 c8 :4 0 2e1
:4 0 cb :2 0 cc
:3 0 2366 3f14 3f16
:3 0 cb :2 0 e9
:4 0 2369 3f18 3f1a
:3 0 cb :2 0 ea
:4 0 236c 3f1c 3f1e
:3 0 cb :2 0 e4
:3 0 236f 3f20 3f22
:3 0 cb :2 0 eb
:4 0 2372 3f24 3f26
:3 0 cb :2 0 a0
:3 0 ec :3 0 2a
:2 0 ed :2 0 2375
3f29 3f2d 2379 3f28
3f2f :3 0 237c 3f11
3f31 :2 0 3f33 237f
3f34 3f0e 3f33 0
3f35 2381 0 3f36
2383 3f39 :3 0 3f39
0 3f39 3f38 3f36
3f37 :6 0 3f3b c0
:3 0 2386 3f3d 2388
3f3c 3f3b :2 0 3f3e
238a :2 0 3f40 0
3f40 3f3f 3ef6 3f3e
:6 0 4b22 1 :3 0
56 :3 0 3d :2 0
3f42 3f43 0 4b22
84 :3 0 4b :3 0
3d :2 0 238c 3f45
3f48 10a :2 0 3d
:2 0 2391 3f4a 3f4c
:3 0 3f :3 0 9
:3 0 3f4e 3f4f 0
4441 84 :3 0 3f
:3 0 3d :2 0 2394
3f51 3f54 84 :3 0
2e2 :2 0 43 :3 0
3d :2 0 2397 3f56
3f5a 239c 3f57 3f5c
:3 0 3f :3 0 84
:3 0 3f :3 0 3d
:2 0 239f 3f5f 3f62
1be :2 0 84 :3 0
43 :3 0 3d :2 0
23a2 3f65 3f68 23a5
3f64 3f6a :3 0 3f5e
3f6b 0 436d 84
:3 0 3f :3 0 3d
:2 0 23a8 3f6d 3f70
10a :2 0 3d :2 0
23ad 3f72 3f74 :3 0
3f75 :2 0 84 :3 0
4c :3 0 3d :2 0
23b0 3f77 3f7a 10a
:2 0 3d :2 0 23b5
3f7c 3f7e :3 0 3f7f
:2 0 3f76 3f81 3f80
:2 0 1e :3 0 165
:2 0 23b8 3f84 3f85
:3 0 3f86 :2 0 3f87
:2 0 3f82 3f89 3f88
:2 0 24 :3 0 7
:3 0 3f8b 3f8c 0
436a 26 :3 0 8
:3 0 3f8e 3f8f 0
436a 44 :3 0 b
:3 0 3f91 3f92 0
436a 45 :3 0 10
:3 0 3f94 3f95 0
436a 46 :3 0 d
:3 0 3f97 3f98 0
436a 47 :3 0 e
:3 0 3f9a 3f9b 0
436a 4e :3 0 c
:3 0 3f9d 3f9e 0
436a 48 :3 0 f
:3 0 3fa0 3fa1 0
436a 84 :3 0 48
:3 0 3d :2 0 23ba
3fa3 3fa6 da :2 0
3d :2 0 23bf 3fa8
3faa :3 0 84 :3 0
47 :3 0 3d :2 0
23c2 3fac 3faf 13b
:2 0 e2 :2 0 23c7
3fb1 3fb3 :3 0 3fab
3fb5 3fb4 :2 0 44
:3 0 3d :2 0 3fb7
3fb8 0 3fbb 140
:3 0 23ca 3fce 84
:3 0 47 :3 0 3d
:2 0 23cc 3fbc 3fbf
da :2 0 e2 :2 0
23d1 3fc1 3fc3 :3 0
7e :3 0 84 :3 0
44 :3 0 3d :2 0
23d4 3fc6 3fc9 3fc5
3fca 0 3fcc 23d7
3fcd 3fc4 3fcc 0
3fcf 3fb6 3fbb 0
3fcf 23d9 0 436a
6b :3 0 201 :3 0
31 :3 0 32 :3 0
84 :3 0 46 :3 0
3d :2 0 23dc 3fd4
3fd7 84 :3 0 47
:3 0 3d :2 0 23df
3fd9 3fdc 84 :3 0
52 :3 0 3d :2 0
23e2 3fde 3fe1 84
:3 0 4e :3 0 3d
:2 0 23e5 3fe3 3fe6
84 :3 0 48 :3 0
3d :2 0 23e8 3fe8
3feb 84 :3 0 45
:3 0 3d :2 0 23eb
3fed 3ff0 84 :3 0
4f :3 0 3d :2 0
23ee 3ff2 3ff5 84
:3 0 50 :3 0 3d
:2 0 23f1 3ff7 3ffa
44 :3 0 3f :3 0
49 :3 0 23f4 3fd1
3fff 3fd0 4000 0
436a 84 :3 0 6b
:3 0 3d :2 0 2402
4002 4005 b0 :3 0
da :2 0 202 :3 0
4007 4009 0 2407
4008 400b :3 0 c3
:3 0 c4 :3 0 400d
400e 0 c3 :3 0
d3 :3 0 4010 4011
0 203 :2 0 2
:4 0 2e3 :2 0 d5
:2 0 2a :2 0 240a
4016 4018 :3 0 240d
4012 401a 400f 401c
401b :2 0 c6 :3 0
d6 :3 0 401e 401f
0 c8 :4 0 2e4
:4 0 cb :2 0 cc
:3 0 2411 4023 4025
:3 0 cb :2 0 e9
:4 0 2414 4027 4029
:3 0 cb :2 0 f0
:4 0 2417 402b 402d
:3 0 cb :2 0 84
:3 0 d0 :3 0 b0
:3 0 202 :3 0 4032
4033 0 241a 4031
4035 d1 :4 0 241c
4030 4038 241f 402f
403a :3 0 2422 4020
403c :2 0 403e 2425
403f 401d 403e 0
4040 2427 0 406a
c3 :3 0 c4 :3 0
4041 4042 0 c3
:3 0 d3 :3 0 4044
4045 0 2a :2 0
2 :4 0 2e5 :2 0
d5 :2 0 2a :2 0
2429 404a 404c :3 0
242c 4046 404e 4043
4050 404f :2 0 c6
:3 0 d6 :3 0 4052
4053 0 c8 :4 0
2e6 :4 0 cb :2 0
cc :3 0 2430 4057
4059 :3 0 2433 4054
405b :2 0 405d 2436
405e 4051 405d 0
405f 2438 0 406a
f5 :3 0 208 :3 0
4060 4061 0 b0
:3 0 202 :3 0 4063
4064 0 f7 :3 0
243a 4062 4067 :2 0
406a 140 :3 0 243d
40e3 84 :3 0 6b
:3 0 3d :2 0 2441
406b 406e 13b :2 0
3d :2 0 2446 4070
4072 :3 0 c3 :3 0
c4 :3 0 4074 4075
0 c3 :3 0 d3
:3 0 4077 4078 0
18 :2 0 2 :4 0
2e7 :2 0 d5 :2 0
2a :2 0 2449 407d
407f :3 0 244c 4079
4081 4076 4083 4082
:2 0 c6 :3 0 d6
:3 0 4085 4086 0
c8 :4 0 2e8 :4 0
cb :2 0 cc :3 0
2450 408a 408c :3 0
cb :2 0 e9 :4 0
2453 408e 4090 :3 0
cb :2 0 f0 :4 0
2456 4092 4094 :3 0
cb :2 0 84 :3 0
d0 :3 0 6b :3 0
2459 4098 409a d1
:4 0 245b 4097 409d
245e 4096 409f :3 0
cb :2 0 f2 :4 0
2461 40a1 40a3 :3 0
cb :2 0 ce :4 0
2464 40a5 40a7 :3 0
cb :2 0 22 :3 0
2467 40a9 40ab :3 0
cb :2 0 ce :4 0
246a 40ad 40af :3 0
246d 4087 40b1 :2 0
40b3 2470 40b4 4084
40b3 0 40b5 2472
0 40e1 c3 :3 0
c4 :3 0 40b6 40b7
0 c3 :3 0 d3
:3 0 40b9 40ba 0
2a :2 0 2 :4 0
2e9 :2 0 d5 :2 0
2a :2 0 2474 40bf
40c1 :3 0 2477 40bb
40c3 40b8 40c5 40c4
:2 0 c6 :3 0 d6
:3 0 40c7 40c8 0
c8 :4 0 2ea :4 0
cb :2 0 cc :3 0
247b 40cc 40ce :3 0
247e 40c9 40d0 :2 0
40d2 2481 40d3 40c6
40d2 0 40d4 2483
0 40e1 f5 :3 0
f6 :3 0 40d5 40d6
0 84 :3 0 6b
:3 0 3d :2 0 2485
40d8 40db 22 :3 0
f7 :3 0 2488 40d7
40df :2 0 40e1 248c
40e2 4073 40e1 0
40e4 400c 406a 0
40e4 2490 0 436a
2eb :3 0 2ec :3 0
2ed :4 0 40e7 :4 0
40e8 :2 0 436a 15
:3 0 e1 :3 0 40ea
40eb 0 3d :2 0
40ec 40ed 0 436a
2ee :3 0 1c7 :3 0
1ae :3 0 1af :3 0
1b0 :3 0 91 :3 0
22 :3 0 2ef :3 0
1e :3 0 1c7 :4 0
2f0 1 :8 0 410f
e0 :4 0 40fa :3 0
f7 :3 0 da :2 0
2495 40fd 40fe :3 0
15 :3 0 e1 :3 0
4100 4101 0 3d
:2 0 4102 4103 0
4105 2498 410c 15
:3 0 e1 :3 0 4106
4107 0 e2 :2 0
4108 4109 0 410b
249a 410d 40ff 4105
0 410e 0 410b
0 410e 249c 0
410f 249f 4159 e5
:3 0 15 :3 0 e1
:3 0 4112 4113 0
e4 :3 0 4114 4115
0 414f c3 :3 0
c4 :3 0 4117 4118
0 c3 :3 0 d3
:3 0 411a 411b 0
e6 :2 0 2 :4 0
2f1 :2 0 d5 :2 0
2a :2 0 24a2 4120
4122 :3 0 24a5 411c
4124 4119 4126 4125
:2 0 c6 :3 0 d6
:3 0 4128 4129 0
c8 :4 0 2f2 :4 0
cb :2 0 cc :3 0
24a9 412d 412f :3 0
cb :2 0 e9 :4 0
24ac 4131 4133 :3 0
cb :2 0 ea :4 0
24af 4135 4137 :3 0
cb :2 0 e4 :3 0
24b2 4139 413b :3 0
cb :2 0 eb :4 0
24b5 413d 413f :3 0
cb :2 0 a0 :3 0
ec :3 0 2a :2 0
ed :2 0 24b8 4142
4146 24bc 4141 4148
:3 0 24bf 412a 414a
:2 0 414c 24c2 414d
4127 414c 0 414e
24c4 0 414f 24c6
4152 :3 0 4152 0
4152 4151 414f 4150
:6 0 4154 c2 :3 0
24c9 4156 24cb 4155
4154 :2 0 4157 24cd
:2 0 4159 0 4159
4158 410f 4157 :6 0
436a 1 :3 0 26
:3 0 de :4 0 415b
415c 0 436a 4a
:3 0 3d :2 0 415e
415f 0 436a 51
:3 0 3d :2 0 4161
4162 0 436a 40
:3 0 3d :2 0 4164
4165 0 436a 41
:3 0 2a :2 0 4167
4168 0 436a 84
:3 0 44 :3 0 3d
:2 0 24cf 416a 416d
10a :2 0 3d :2 0
24d4 416f 4171 :3 0
84 :3 0 7e :3 0
3d :2 0 24d7 4173
4176 13b :2 0 e2
:2 0 24dc 4178 417a
:3 0 84 :3 0 7e
:3 0 3d :2 0 24df
417c 417f 13b :2 0
3d :2 0 24e4 4181
4183 :3 0 417b 4185
4184 :2 0 4186 :2 0
4172 4188 4187 :2 0
84 :3 0 44 :3 0
3d :2 0 24e7 418a
418d da :2 0 3d
:2 0 24ec 418f 4191
:3 0 84 :3 0 7e
:3 0 3d :2 0 24ef
4193 4196 13b :2 0
e2 :2 0 24f4 4198
419a :3 0 4192 419c
419b :2 0 84 :3 0
7e :3 0 3d :2 0
24f7 419e 41a1 13b
:2 0 3d :2 0 24fc
41a3 41a5 :3 0 419d
41a7 41a6 :2 0 47
:3 0 e2 :2 0 41a9
41aa 0 41b3 44
:3 0 84 :3 0 7e
:3 0 3d :2 0 24ff
41ad 41b0 41ac 41b1
0 41b3 2502 41b4
41a8 41b3 0 41b5
2505 0 41c8 44
:3 0 1ff :3 0 19a
:3 0 41b7 41b8 0
84 :3 0 44 :3 0
3d :2 0 2507 41ba
41bd b0 :3 0 2f3
:3 0 41bf 41c0 0
250a 41b9 41c2 41b6
41c3 0 41c8 4e
:3 0 2a :2 0 41c5
41c6 0 41c8 250d
41cd 4e :3 0 3d
:2 0 41c9 41ca 0
41cc 2511 41ce 4189
41c8 0 41cf 0
41cc 0 41cf 2513
0 436a 6a :3 0
5a :2 0 41d0 41d1
0 436a 66 :3 0
20e :3 0 1c :3 0
22 :3 0 22 :3 0
21 :3 0 6a :3 0
41 :3 0 29 :3 0
29 :3 0 29 :3 0
29 :3 0 24 :3 0
26 :3 0 49 :3 0
3f :3 0 44 :3 0
46 :3 0 47 :3 0
40 :3 0 52 :3 0
2e :3 0 4a :3 0
4e :3 0 48 :3 0
45 :3 0 51 :3 0
4f :3 0 53 :3 0
1a :3 0 3d :2 0
3d :2 0 5a :2 0
5a :2 0 2516 41d4
41f5 41d3 41f6 0
436a 84 :3 0 66
:3 0 3d :2 0 2537
41f8 41fb da :2 0
20f :2 0 253c 41fd
41ff :3 0 c3 :3 0
c4 :3 0 4201 4202
0 c3 :3 0 d3
:3 0 4204 4205 0
18 :2 0 2 :4 0
2f4 :2 0 d5 :2 0
2a :2 0 253f 420a
420c :3 0 2542 4206
420e 4203 4210 420f
:2 0 c6 :3 0 d6
:3 0 4212 4213 0
c8 :4 0 2f5 :4 0
cb :2 0 cc :3 0
2546 4217 4219 :3 0
cb :2 0 e9 :4 0
2549 421b 421d :3 0
cb :2 0 f0 :4 0
254c 421f 4221 :3 0
cb :2 0 84 :3 0
d0 :3 0 b0 :3 0
212 :3 0 4226 4227
0 254f 4225 4229
d1 :4 0 2551 4224
422c 2554 4223 422e
:3 0 cb :2 0 f2
:4 0 2557 4230 4232
:3 0 cb :2 0 ce
:4 0 255a 4234 4236
:3 0 cb :2 0 21
:3 0 255d 4238 423a
:3 0 cb :2 0 ce
:4 0 2560 423c 423e
:3 0 2563 4214 4240
:2 0 4242 2566 4243
4211 4242 0 4244
2568 0 426f c3
:3 0 c4 :3 0 4245
4246 0 c3 :3 0
d3 :3 0 4248 4249
0 2a :2 0 2
:4 0 2f6 :2 0 d5
:2 0 2a :2 0 256a
424e 4250 :3 0 256d
424a 4252 4247 4254
4253 :2 0 c6 :3 0
d6 :3 0 4256 4257
0 c8 :4 0 2f7
:4 0 cb :2 0 cc
:3 0 2571 425b 425d
:3 0 2574 4258 425f
:2 0 4261 2577 4262
4255 4261 0 4263
2579 0 426f f5
:3 0 f6 :3 0 4264
4265 0 b0 :3 0
212 :3 0 4267 4268
0 21 :3 0 f7
:3 0 257b 4266 426c
:2 0 426f 140 :3 0
257f 4367 84 :3 0
66 :3 0 3d :2 0
2583 4270 4273 13b
:2 0 3d :2 0 2588
4275 4277 :3 0 c3
:3 0 c4 :3 0 4279
427a 0 c3 :3 0
d3 :3 0 427c 427d
0 18 :2 0 2
:4 0 2f8 :2 0 d5
:2 0 2a :2 0 258b
4282 4284 :3 0 258e
427e 4286 427b 4288
4287 :2 0 c6 :3 0
d6 :3 0 428a 428b
0 c8 :4 0 2f9
:4 0 cb :2 0 cc
:3 0 2592 428f 4291
:3 0 cb :2 0 e9
:4 0 2595 4293 4295
:3 0 cb :2 0 f0
:4 0 2598 4297 4299
:3 0 cb :2 0 84
:3 0 d0 :3 0 b0
:3 0 1ba :3 0 429e
429f 0 259b 429d
42a1 d1 :4 0 259d
429c 42a4 25a0 429b
42a6 :3 0 cb :2 0
f2 :4 0 25a3 42a8
42aa :3 0 cb :2 0
ce :4 0 25a6 42ac
42ae :3 0 cb :2 0
1c :3 0 25a9 42b0
42b2 :3 0 cb :2 0
ce :4 0 25ac 42b4
42b6 :3 0 25af 428c
42b8 :2 0 42ba 25b2
42bb 4289 42ba 0
42bc 25b4 0 42e6
c3 :3 0 c4 :3 0
42bd 42be 0 c3
:3 0 d3 :3 0 42c0
42c1 0 2a :2 0
2 :4 0 2fa :2 0
d5 :2 0 2a :2 0
25b6 42c6 42c8 :3 0
25b9 42c2 42ca 42bf
42cc 42cb :2 0 c6
:3 0 d6 :3 0 42ce
42cf 0 c8 :4 0
2fb :4 0 cb :2 0
cc :3 0 25bd 42d3
42d5 :3 0 25c0 42d0
42d7 :2 0 42d9 25c3
42da 42cd 42d9 0
42db 25c5 0 42e6
f5 :3 0 f6 :3 0
42dc 42dd 0 b0
:3 0 1ba :3 0 42df
42e0 0 1c :3 0
f7 :3 0 25c7 42de
42e4 :2 0 42e6 25cb
42e7 4278 42e6 0
4369 90 :3 0 98
:3 0 1c :3 0 92
:3 0 21 :3 0 93
:3 0 a7 :3 0 61
:3 0 58 :3 0 5e
:3 0 a7 :3 0 1d3
:3 0 61 :3 0 5c
:3 0 5e :3 0 1d3
:3 0 a8 :3 0 62
:3 0 5b :3 0 5e
:3 0 a8 :3 0 1d4
:3 0 62 :3 0 5d
:3 0 5e :3 0 1d4
:3 0 9a :3 0 1e
:4 0 2fc 1 :8 0
431a e0 :4 0 4305
:3 0 f7 :3 0 da
:2 0 25d1 4308 4309
:3 0 15 :3 0 e1
:3 0 430b 430c 0
3d :2 0 430d 430e
0 4310 25d4 4317
15 :3 0 e1 :3 0
4311 4312 0 e2
:2 0 4313 4314 0
4316 25d6 4318 430a
4310 0 4319 0
4316 0 4319 25d8
0 431a 25db 4364
e5 :3 0 15 :3 0
e1 :3 0 431d 431e
0 e4 :3 0 431f
4320 0 435a c3
:3 0 c4 :3 0 4322
4323 0 c3 :3 0
d3 :3 0 4325 4326
0 e6 :2 0 2
:4 0 2fd :2 0 d5
:2 0 2a :2 0 25de
432b 432d :3 0 25e1
4327 432f 4324 4331
4330 :2 0 c6 :3 0
d6 :3 0 4333 4334
0 c8 :4 0 2fe
:4 0 cb :2 0 cc
:3 0 25e5 4338 433a
:3 0 cb :2 0 e9
:4 0 25e8 433c 433e
:3 0 cb :2 0 ea
:4 0 25eb 4340 4342
:3 0 cb :2 0 e4
:3 0 25ee 4344 4346
:3 0 cb :2 0 eb
:4 0 25f1 4348 434a
:3 0 cb :2 0 a0
:3 0 ec :3 0 2a
:2 0 ed :2 0 25f4
434d 4351 25f8 434c
4353 :3 0 25fb 4335
4355 :2 0 4357 25fe
4358 4332 4357 0
4359 2600 0 435a
2602 435d :3 0 435d
0 435d 435c 435a
435b :6 0 435f c4
:3 0 2605 4361 2607
4360 435f :2 0 4362
2609 :2 0 4364 0
4364 4363 431a 4362
:6 0 4366 1 :3 0
260b 4368 4200 426f
0 4369 0 4366
0 4369 260d 0
436a 2611 436b 3f8a
436a 0 436c 2629
0 436d 262b 436e
3f5d 436d 0 436f
262e 0 4441 13c
:3 0 56 :3 0 af
:3 0 8b :3 0 22
:3 0 92 :3 0 23
:3 0 93 :4 0 2ff
1 :8 0 437e 15
:3 0 e1 :3 0 4379
437a 0 e4 :3 0
437b 437c 0 437e
2630 43c8 e5 :3 0
15 :3 0 e1 :3 0
4381 4382 0 e4
:3 0 4383 4384 0
43be c3 :3 0 c4
:3 0 4386 4387 0
c3 :3 0 d3 :3 0
4389 438a 0 e6
:2 0 2 :4 0 300
:2 0 d5 :2 0 2a
:2 0 2633 438f 4391
:3 0 2636 438b 4393
4388 4395 4394 :2 0
c6 :3 0 d6 :3 0
4397 4398 0 c8
:4 0 301 :4 0 cb
:2 0 cc :3 0 263a
439c 439e :3 0 cb
:2 0 e9 :4 0 263d
43a0 43a2 :3 0 cb
:2 0 ea :4 0 2640
43a4 43a6 :3 0 cb
:2 0 e4 :3 0 2643
43a8 43aa :3 0 cb
:2 0 eb :4 0 2646
43ac 43ae :3 0 cb
:2 0 a0 :3 0 ec
:3 0 2a :2 0 ed
:2 0 2649 43b1 43b5
264d 43b0 43b7 :3 0
2650 4399 43b9 :2 0
43bb 2653 43bc 4396
43bb 0 43bd 2655
0 43be 2657 43c1
:3 0 43c1 0 43c1
43c0 43be 43bf :6 0
43c3 c6 :3 0 265a
43c5 265c 43c4 43c3
:2 0 43c6 265e :2 0
43c8 0 43c8 43c7
437e 43c6 :6 0 4441
1 :3 0 84 :3 0
56 :3 0 3d :2 0
2660 43ca 43cd da
:2 0 3d :2 0 2665
43cf 43d1 :3 0 ae
:3 0 185 :3 0 186
:3 0 185 :3 0 39
:3 0 91 :3 0 22
:3 0 8b :3 0 22
:4 0 302 1 :8 0
43f2 e0 :4 0 43dd
:3 0 f7 :3 0 da
:2 0 266a 43e0 43e1
:3 0 15 :3 0 e1
:3 0 43e3 43e4 0
3d :2 0 43e5 43e6
0 43e8 266d 43ef
15 :3 0 e1 :3 0
43e9 43ea 0 e2
:2 0 43eb 43ec 0
43ee 266f 43f0 43e2
43e8 0 43f1 0
43ee 0 43f1 2671
0 43f2 2674 443c
e5 :3 0 15 :3 0
e1 :3 0 43f5 43f6
0 e4 :3 0 43f7
43f8 0 4432 c3
:3 0 c4 :3 0 43fa
43fb 0 c3 :3 0
d3 :3 0 43fd 43fe
0 e6 :2 0 2
:4 0 303 :2 0 d5
:2 0 2a :2 0 2677
4403 4405 :3 0 267a
43ff 4407 43fc 4409
4408 :2 0 c6 :3 0
d6 :3 0 440b 440c
0 c8 :4 0 304
:4 0 cb :2 0 cc
:3 0 267e 4410 4412
:3 0 cb :2 0 e9
:4 0 2681 4414 4416
:3 0 cb :2 0 ea
:4 0 2684 4418 441a
:3 0 cb :2 0 e4
:3 0 2687 441c 441e
:3 0 cb :2 0 eb
:4 0 268a 4420 4422
:3 0 cb :2 0 a0
:3 0 ec :3 0 2a
:2 0 ed :2 0 268d
4425 4429 2691 4424
442b :3 0 2694 440d
442d :2 0 442f 2697
4430 440a 442f 0
4431 2699 0 4432
269b 4435 :3 0 4435
0 4435 4434 4432
4433 :6 0 4437 c8
:3 0 269e 4439 26a0
4438 4437 :2 0 443a
26a2 :2 0 443c 0
443c 443b 43f2 443a
:6 0 443e 1 :3 0
26a4 443f 43d2 443e
0 4440 26a6 0
4441 26a8 4442 3f4d
4441 0 4443 26ad
0 4b22 63 :3 0
3d :2 0 4444 4445
0 4b22 81 :3 0
165 :2 0 26af 4448
4449 :3 0 444a :2 0
ae :3 0 1d7 :3 0
199 :3 0 19a :3 0
1d7 :3 0 b0 :3 0
305 :3 0 8b :3 0
22 :4 0 306 1
:8 0 446b e0 :4 0
4456 :3 0 f7 :3 0
da :2 0 26b3 4459
445a :3 0 15 :3 0
e1 :3 0 445c 445d
0 3d :2 0 445e
445f 0 4461 26b6
4468 15 :3 0 e1
:3 0 4462 4463 0
e2 :2 0 4464 4465
0 4467 26b8 4469
445b 4461 0 446a
0 4467 0 446a
26ba 0 446b 26bd
44b5 e5 :3 0 15
:3 0 e1 :3 0 446e
446f 0 e4 :3 0
4470 4471 0 44ab
c3 :3 0 c4 :3 0
4473 4474 0 c3
:3 0 d3 :3 0 4476
4477 0 e6 :2 0
2 :4 0 307 :2 0
d5 :2 0 2a :2 0
26c0 447c 447e :3 0
26c3 4478 4480 4475
4482 4481 :2 0 c6
:3 0 d6 :3 0 4484
4485 0 c8 :4 0
308 :4 0 cb :2 0
cc :3 0 26c7 4489
448b :3 0 cb :2 0
e9 :4 0 26ca 448d
448f :3 0 cb :2 0
ea :4 0 26cd 4491
4493 :3 0 cb :2 0
e4 :3 0 26d0 4495
4497 :3 0 cb :2 0
eb :4 0 26d3 4499
449b :3 0 cb :2 0
a0 :3 0 ec :3 0
2a :2 0 ed :2 0
26d6 449e 44a2 26da
449d 44a4 :3 0 26dd
4486 44a6 :2 0 44a8
26e0 44a9 4483 44a8
0 44aa 26e2 0
44ab 26e4 44ae :3 0
44ae 0 44ae 44ad
44ab 44ac :6 0 44b0
ca :3 0 26e7 44b2
26e9 44b1 44b0 :2 0
44b3 26eb :2 0 44b5
0 44b5 44b4 446b
44b3 :6 0 47b8 1
:3 0 84 :3 0 4c
:3 0 3d :2 0 26ed
44b7 44ba da :2 0
3d :2 0 26f2 44bc
44be :3 0 13c :3 0
56 :3 0 90 :3 0
91 :3 0 22 :3 0
94 :3 0 81 :4 0
309 1 :8 0 44cd
15 :3 0 e1 :3 0
44c8 44c9 0 e4
:3 0 44ca 44cb 0
44cd 26f5 4517 e5
:3 0 15 :3 0 e1
:3 0 44d0 44d1 0
e4 :3 0 44d2 44d3
0 450d c3 :3 0
c4 :3 0 44d5 44d6
0 c3 :3 0 d3
:3 0 44d8 44d9 0
e6 :2 0 2 :4 0
30a :2 0 d5 :2 0
2a :2 0 26f8 44de
44e0 :3 0 26fb 44da
44e2 44d7 44e4 44e3
:2 0 c6 :3 0 d6
:3 0 44e6 44e7 0
c8 :4 0 30b :4 0
cb :2 0 cc :3 0
26ff 44eb 44ed :3 0
cb :2 0 e9 :4 0
2702 44ef 44f1 :3 0
cb :2 0 ea :4 0
2705 44f3 44f5 :3 0
cb :2 0 e4 :3 0
2708 44f7 44f9 :3 0
cb :2 0 eb :4 0
270b 44fb 44fd :3 0
cb :2 0 a0 :3 0
ec :3 0 2a :2 0
ed :2 0 270e 4500
4504 2712 44ff 4506
:3 0 2715 44e8 4508
:2 0 450a 2718 450b
44e5 450a 0 450c
271a 0 450d 271c
4510 :3 0 4510 0
4510 450f 450d 450e
:6 0 4512 cc :3 0
271f 4514 2721 4513
4512 :2 0 4515 2723
:2 0 4517 0 4517
4516 44cd 4515 :6 0
45f6 1 :3 0 84
:3 0 56 :3 0 3d
:2 0 2725 4519 451c
da :2 0 3d :2 0
272a 451e 4520 :3 0
af :3 0 91 :3 0
22 :3 0 8b :3 0
22 :3 0 92 :3 0
23 :3 0 93 :4 0
30c 1 :8 0 4540
e0 :4 0 452b :3 0
f7 :3 0 da :2 0
272f 452e 452f :3 0
15 :3 0 e1 :3 0
4531 4532 0 3d
:2 0 4533 4534 0
4536 2732 453d 15
:3 0 e1 :3 0 4537
4538 0 e2 :2 0
4539 453a 0 453c
2734 453e 4530 4536
0 453f 0 453c
0 453f 2736 0
4540 2739 458a e5
:3 0 15 :3 0 e1
:3 0 4543 4544 0
e4 :3 0 4545 4546
0 4580 c3 :3 0
c4 :3 0 4548 4549
0 c3 :3 0 d3
:3 0 454b 454c 0
e6 :2 0 2 :4 0
30d :2 0 d5 :2 0
2a :2 0 273c 4551
4553 :3 0 273f 454d
4555 454a 4557 4556
:2 0 c6 :3 0 d6
:3 0 4559 455a 0
c8 :4 0 30e :4 0
cb :2 0 cc :3 0
2743 455e 4560 :3 0
cb :2 0 e9 :4 0
2746 4562 4564 :3 0
cb :2 0 ea :4 0
2749 4566 4568 :3 0
cb :2 0 e4 :3 0
274c 456a 456c :3 0
cb :2 0 eb :4 0
274f 456e 4570 :3 0
cb :2 0 a0 :3 0
ec :3 0 2a :2 0
ed :2 0 2752 4573
4577 2756 4572 4579
:3 0 2759 455b 457b
:2 0 457d 275c 457e
4558 457d 0 457f
275e 0 4580 2760
4583 :3 0 4583 0
4583 4582 4580 4581
:6 0 4585 ce :3 0
2763 4587 2765 4586
4585 :2 0 4588 2767
:2 0 458a 0 458a
4589 4540 4588 :6 0
45f3 1 :3 0 1fb
:3 0 91 :3 0 22
:3 0 92 :3 0 23
:4 0 1fc 1 :8 0
45a7 e0 :4 0 4592
:3 0 f7 :3 0 da
:2 0 276b 4595 4596
:3 0 15 :3 0 e1
:3 0 4598 4599 0
3d :2 0 459a 459b
0 459d 276e 45a4
15 :3 0 e1 :3 0
459e 459f 0 e2
:2 0 45a0 45a1 0
45a3 2770 45a5 4597
459d 0 45a6 0
45a3 0 45a6 2772
0 45a7 2775 45f1
e5 :3 0 15 :3 0
e1 :3 0 45aa 45ab
0 e4 :3 0 45ac
45ad 0 45e7 c3
:3 0 c4 :3 0 45af
45b0 0 c3 :3 0
d3 :3 0 45b2 45b3
0 e6 :2 0 2
:4 0 30f :2 0 d5
:2 0 2a :2 0 2778
45b8 45ba :3 0 277b
45b4 45bc 45b1 45be
45bd :2 0 c6 :3 0
d6 :3 0 45c0 45c1
0 c8 :4 0 310
:4 0 cb :2 0 cc
:3 0 277f 45c5 45c7
:3 0 cb :2 0 e9
:4 0 2782 45c9 45cb
:3 0 cb :2 0 ea
:4 0 2785 45cd 45cf
:3 0 cb :2 0 e4
:3 0 2788 45d1 45d3
:3 0 cb :2 0 eb
:4 0 278b 45d5 45d7
:3 0 cb :2 0 a0
:3 0 ec :3 0 2a
:2 0 ed :2 0 278e
45da 45de 2792 45d9
45e0 :3 0 2795 45c2
45e2 :2 0 45e4 2798
45e5 45bf 45e4 0
45e6 279a 0 45e7
279c 45ea :3 0 45ea
0 45ea 45e9 45e7
45e8 :6 0 45ec d0
:3 0 279f 45ee 27a1
45ed 45ec :2 0 45ef
27a3 :2 0 45f1 0
45f1 45f0 45a7 45ef
:6 0 45f3 1 :3 0
27a5 45f4 4521 45f3
0 45f5 27a8 0
45f6 27aa 45f7 44bf
45f6 0 45f8 27ad
0 47b8 84 :3 0
56 :3 0 3d :2 0
27af 45f9 45fc 10a
:2 0 3d :2 0 27b4
45fe 4600 :3 0 6b
:3 0 311 :2 0 4602
4603 0 47b5 71
:3 0 219 :3 0 22
:3 0 81 :3 0 6b
:3 0 3d :2 0 3d
:2 0 27b7 4606 460c
4605 460d 0 47b5
a1 :3 0 a2 :3 0
312 :3 0 9f :3 0
a0 :3 0 22b :3 0
9f :3 0 a0 :3 0
22c :3 0 a5 :3 0
a6 :3 0 a7 :3 0
a8 :3 0 31 :3 0
32 :3 0 3f :3 0
2b :3 0 2d :3 0
78 :3 0 79 :3 0
74 :3 0 75 :3 0
90 :3 0 9a :3 0
81 :4 0 313 1
:8 0 462e 15 :3 0
e1 :3 0 4629 462a
0 e4 :3 0 462b
462c 0 462e 27bd
4678 e5 :3 0 15
:3 0 e1 :3 0 4631
4632 0 e4 :3 0
4633 4634 0 466e
c3 :3 0 c4 :3 0
4636 4637 0 c3
:3 0 d3 :3 0 4639
463a 0 e6 :2 0
2 :4 0 314 :2 0
d5 :2 0 2a :2 0
27c0 463f 4641 :3 0
27c3 463b 4643 4638
4645 4644 :2 0 c6
:3 0 d6 :3 0 4647
4648 0 c8 :4 0
315 :4 0 cb :2 0
cc :3 0 27c7 464c
464e :3 0 cb :2 0
e9 :4 0 27ca 4650
4652 :3 0 cb :2 0
ea :4 0 27cd 4654
4656 :3 0 cb :2 0
e4 :3 0 27d0 4658
465a :3 0 cb :2 0
eb :4 0 27d3 465c
465e :3 0 cb :2 0
a0 :3 0 ec :3 0
2a :2 0 ed :2 0
27d6 4661 4665 27da
4660 4667 :3 0 27dd
4649 4669 :2 0 466b
27e0 466c 4646 466b
0 466d 27e2 0
466e 27e4 4671 :3 0
4671 0 4671 4670
466e 466f :6 0 4673
d2 :3 0 27e7 4675
27e9 4674 4673 :2 0
4676 27eb :2 0 4678
0 4678 4677 462e
4676 :6 0 47b5 1
:3 0 15 :3 0 e1
:3 0 467a 467b 0
15 :3 0 da :2 0
157 :3 0 467d 467f
0 27ef 467e 4681
:3 0 4682 :2 0 84
:3 0 78 :3 0 3d
:2 0 27f2 4684 4687
da :2 0 3d :2 0
27f7 4689 468b :3 0
1fb :3 0 316 :3 0
31 :3 0 317 :3 0
32 :3 0 318 :3 0
3f :3 0 319 :3 0
3f :3 0 74 :3 0
31a :3 0 91 :3 0
22 :3 0 92 :3 0
23 :4 0 31b 1
:8 0 46b2 e0 :4 0
469d :3 0 f7 :3 0
da :2 0 27fc 46a0
46a1 :3 0 15 :3 0
e1 :3 0 46a3 46a4
0 3d :2 0 46a5
46a6 0 46a8 27ff
46af 15 :3 0 e1
:3 0 46a9 46aa 0
e2 :2 0 46ab 46ac
0 46ae 2801 46b0
46a2 46a8 0 46b1
0 46ae 0 46b1
2803 0 46b2 2806
46fc e5 :3 0 15
:3 0 e1 :3 0 46b5
46b6 0 e4 :3 0
46b7 46b8 0 46f2
c3 :3 0 c4 :3 0
46ba 46bb 0 c3
:3 0 d3 :3 0 46bd
46be 0 e6 :2 0
2 :4 0 31c :2 0
d5 :2 0 2a :2 0
2809 46c3 46c5 :3 0
280c 46bf 46c7 46bc
46c9 46c8 :2 0 c6
:3 0 d6 :3 0 46cb
46cc 0 c8 :4 0
31d :4 0 cb :2 0
cc :3 0 2810 46d0
46d2 :3 0 cb :2 0
e9 :4 0 2813 46d4
46d6 :3 0 cb :2 0
ea :4 0 2816 46d8
46da :3 0 cb :2 0
e4 :3 0 2819 46dc
46de :3 0 cb :2 0
eb :4 0 281c 46e0
46e2 :3 0 cb :2 0
a0 :3 0 ec :3 0
2a :2 0 ed :2 0
281f 46e5 46e9 2823
46e4 46eb :3 0 2826
46cd 46ed :2 0 46ef
2829 46f0 46ca 46ef
0 46f1 282b 0
46f2 282d 46f5 :3 0
46f5 0 46f5 46f4
46f2 46f3 :6 0 46f7
d4 :3 0 2830 46f9
2832 46f8 46f7 :2 0
46fa 2834 :2 0 46fc
0 46fc 46fb 46b2
46fa :6 0 46fe 1
:3 0 2836 4773 1fb
:3 0 316 :3 0 31
:3 0 317 :3 0 32
:3 0 318 :3 0 3f
:3 0 319 :3 0 3f
:3 0 74 :3 0 31a
:3 0 3f :3 0 75
:3 0 91 :3 0 22
:3 0 92 :3 0 23
:4 0 31e 1 :8 0
4726 e0 :4 0 4711
:3 0 f7 :3 0 da
:2 0 283a 4714 4715
:3 0 15 :3 0 e1
:3 0 4717 4718 0
3d :2 0 4719 471a
0 471c 283d 4723
15 :3 0 e1 :3 0
471d 471e 0 e2
:2 0 471f 4720 0
4722 283f 4724 4716
471c 0 4725 0
4722 0 4725 2841
0 4726 2844 4770
e5 :3 0 15 :3 0
e1 :3 0 4729 472a
0 e4 :3 0 472b
472c 0 4766 c3
:3 0 c4 :3 0 472e
472f 0 c3 :3 0
d3 :3 0 4731 4732
0 e6 :2 0 2
:4 0 31f :2 0 d5
:2 0 2a :2 0 2847
4737 4739 :3 0 284a
4733 473b 4730 473d
473c :2 0 c6 :3 0
d6 :3 0 473f 4740
0 c8 :4 0 320
:4 0 cb :2 0 cc
:3 0 284e 4744 4746
:3 0 cb :2 0 e9
:4 0 2851 4748 474a
:3 0 cb :2 0 ea
:4 0 2854 474c 474e
:3 0 cb :2 0 e4
:3 0 2857 4750 4752
:3 0 cb :2 0 eb
:4 0 285a 4754 4756
:3 0 cb :2 0 a0
:3 0 ec :3 0 2a
:2 0 ed :2 0 285d
4759 475d 2861 4758
475f :3 0 2864 4741
4761 :2 0 4763 2867
4764 473e 4763 0
4765 2869 0 4766
286b 4769 :3 0 4769
0 4769 4768 4766
4767 :6 0 476b d6
:3 0 286e 476d 2870
476c 476b :2 0 476e
2872 :2 0 4770 0
4770 476f 4726 476e
:6 0 4772 1 :3 0
2874 4774 468c 46fe
0 4775 0 4772
0 4775 2876 0
4798 a0 :3 0 6f
:3 0 2a :2 0 2a
:2 0 2879 4776 477a
da :2 0 1bd :4 0
287f 477c 477e :3 0
477f :2 0 7a :3 0
3d :2 0 4781 4782
0 4795 15 :3 0
e1 :3 0 4784 4785
0 1bf :3 0 22
:3 0 22 :3 0 81
:3 0 2b :3 0 2d
:3 0 74 :3 0 75
:3 0 7a :3 0 79
:3 0 78 :3 0 2882
4787 4792 4786 4793
0 4795 288d 4796
4780 4795 0 4797
2890 0 4798 2892
4799 4683 4798 0
479a 2895 0 47b5
1e :3 0 165 :2 0
2897 479c 479d :3 0
479e :2 0 479f :2 0
116 :3 0 133 :3 0
47a1 47a2 0 81
:3 0 1e :3 0 2899
47a3 47a6 da :2 0
3d :2 0 289e 47a8
47aa :3 0 47ab :2 0
47a0 47ad 47ac :2 0
63 :3 0 2a :2 0
47af 47b0 0 47b2
28a1 47b3 47ae 47b2
0 47b4 28a3 0
47b5 28a5 47b6 4601
47b5 0 47b7 28ab
0 47b8 28ad 47b9
444b 47b8 0 47ba
28b1 0 4b22 84
:3 0 4c :3 0 3d
:2 0 28b3 47bb 47be
10a :2 0 3d :2 0
28b8 47c0 47c2 :3 0
47c3 :2 0 1e :3 0
165 :2 0 28bb 47c6
47c7 :3 0 47c8 :2 0
47c9 :2 0 47c4 47cb
47ca :2 0 84 :3 0
60 :3 0 3d :2 0
28bd 47cd 47d0 da
:2 0 2a :2 0 28c2
47d2 47d4 :3 0 13c
:3 0 56 :3 0 90
:3 0 91 :3 0 22
:3 0 94 :3 0 1e
:3 0 92 :3 0 23
:3 0 93 :4 0 321
1 :8 0 47e6 15
:3 0 e1 :3 0 47e1
47e2 0 e4 :3 0
47e3 47e4 0 47e6
28c5 4830 e5 :3 0
15 :3 0 e1 :3 0
47e9 47ea 0 e4
:3 0 47eb 47ec 0
4826 c3 :3 0 c4
:3 0 47ee 47ef 0
c3 :3 0 d3 :3 0
47f1 47f2 0 e6
:2 0 2 :4 0 322
:2 0 d5 :2 0 2a
:2 0 28c8 47f7 47f9
:3 0 28cb 47f3 47fb
47f0 47fd 47fc :2 0
c6 :3 0 d6 :3 0
47ff 4800 0 c8
:4 0 323 :4 0 cb
:2 0 cc :3 0 28cf
4804 4806 :3 0 cb
:2 0 e9 :4 0 28d2
4808 480a :3 0 cb
:2 0 ea :4 0 28d5
480c 480e :3 0 cb
:2 0 e4 :3 0 28d8
4810 4812 :3 0 cb
:2 0 eb :4 0 28db
4814 4816 :3 0 cb
:2 0 a0 :3 0 ec
:3 0 2a :2 0 ed
:2 0 28de 4819 481d
28e2 4818 481f :3 0
28e5 4801 4821 :2 0
4823 28e8 4824 47fe
4823 0 4825 28ea
0 4826 28ec 4829
:3 0 4829 0 4829
4828 4826 4827 :6 0
482b d8 :3 0 28ef
482d 28f1 482c 482b
:2 0 482e 28f3 :2 0
4830 0 4830 482f
47e6 482e :6 0 4914
1 :3 0 84 :3 0
56 :3 0 3d :2 0
28f5 4832 4835 10a
:2 0 3d :2 0 28fa
4837 4839 :3 0 90
:3 0 94 :3 0 91
:3 0 22 :3 0 94
:3 0 1e :3 0 92
:3 0 23 :3 0 93
:4 0 324 1 :8 0
485a e0 :4 0 4845
:3 0 f7 :3 0 da
:2 0 28ff 4848 4849
:3 0 15 :3 0 e1
:3 0 484b 484c 0
3d :2 0 484d 484e
0 4850 2902 4857
15 :3 0 e1 :3 0
4851 4852 0 e2
:2 0 4853 4854 0
4856 2904 4858 484a
4850 0 4859 0
4856 0 4859 2906
0 485a 2909 48a4
e5 :3 0 15 :3 0
e1 :3 0 485d 485e
0 e4 :3 0 485f
4860 0 489a c3
:3 0 c4 :3 0 4862
4863 0 c3 :3 0
d3 :3 0 4865 4866
0 e6 :2 0 2
:4 0 325 :2 0 d5
:2 0 2a :2 0 290c
486b 486d :3 0 290f
4867 486f 4864 4871
4870 :2 0 c6 :3 0
d6 :3 0 4873 4874
0 c8 :4 0 326
:4 0 cb :2 0 cc
:3 0 2913 4878 487a
:3 0 cb :2 0 e9
:4 0 2916 487c 487e
:3 0 cb :2 0 ea
:4 0 2919 4880 4882
:3 0 cb :2 0 e4
:3 0 291c 4884 4886
:3 0 cb :2 0 eb
:4 0 291f 4888 488a
:3 0 cb :2 0 a0
:3 0 ec :3 0 2a
:2 0 ed :2 0 2922
488d 4891 2926 488c
4893 :3 0 2929 4875
4895 :2 0 4897 292c
4898 4872 4897 0
4899 292e 0 489a
2930 489d :3 0 489d
0 489d 489c 489a
489b :6 0 489f da
:3 0 2933 48a1 2935
48a0 489f :2 0 48a2
2937 :2 0 48a4 0
48a4 48a3 485a 48a2
:6 0 4911 1 :3 0
1b0 :3 0 2ef :3 0
9a :3 0 91 :3 0
22 :3 0 2ef :3 0
1e :3 0 92 :3 0
23 :4 0 327 1
:8 0 48c5 e0 :4 0
48b0 :3 0 f7 :3 0
da :2 0 293b 48b3
48b4 :3 0 15 :3 0
e1 :3 0 48b6 48b7
0 3d :2 0 48b8
48b9 0 48bb 293e
48c2 15 :3 0 e1
:3 0 48bc 48bd 0
e2 :2 0 48be 48bf
0 48c1 2940 48c3
48b5 48bb 0 48c4
0 48c1 0 48c4
2942 0 48c5 2945
490f e5 :3 0 15
:3 0 e1 :3 0 48c8
48c9 0 e4 :3 0
48ca 48cb 0 4905
c3 :3 0 c4 :3 0
48cd 48ce 0 c3
:3 0 d3 :3 0 48d0
48d1 0 e6 :2 0
2 :4 0 328 :2 0
d5 :2 0 2a :2 0
2948 48d6 48d8 :3 0
294b 48d2 48da 48cf
48dc 48db :2 0 c6
:3 0 d6 :3 0 48de
48df 0 c8 :4 0
329 :4 0 cb :2 0
cc :3 0 294f 48e3
48e5 :3 0 cb :2 0
e9 :4 0 2952 48e7
48e9 :3 0 cb :2 0
ea :4 0 2955 48eb
48ed :3 0 cb :2 0
e4 :3 0 2958 48ef
48f1 :3 0 cb :2 0
eb :4 0 295b 48f3
48f5 :3 0 cb :2 0
a0 :3 0 ec :3 0
2a :2 0 ed :2 0
295e 48f8 48fc 2962
48f7 48fe :3 0 2965
48e0 4900 :2 0 4902
2968 4903 48dd 4902
0 4904 296a 0
4905 296c 4908 :3 0
4908 0 4908 4907
4905 4906 :6 0 490a
dc :3 0 296f 490c
2971 490b 490a :2 0
490d 2973 :2 0 490f
0 490f 490e 48c5
490d :6 0 4911 1
:3 0 2975 4912 483a
4911 0 4913 2978
0 4914 297a 4915
47d5 4914 0 4916
297d 0 4abc 6b
:3 0 311 :2 0 4917
4918 0 4abc 71
:3 0 219 :3 0 22
:3 0 1e :3 0 6b
:3 0 3d :2 0 3d
:2 0 297f 491b 4921
491a 4922 0 4abc
a1 :3 0 a2 :3 0
312 :3 0 9f :3 0
a0 :3 0 22b :3 0
9f :3 0 a0 :3 0
22c :3 0 a5 :3 0
a6 :3 0 a7 :3 0
a8 :3 0 31 :3 0
32 :3 0 3f :3 0
2b :3 0 2d :3 0
78 :3 0 79 :3 0
58 :3 0 5b :3 0
90 :3 0 9a :3 0
1e :4 0 32a 1
:8 0 4943 15 :3 0
e1 :3 0 493e 493f
0 e4 :3 0 4940
4941 0 4943 2985
498d e5 :3 0 15
:3 0 e1 :3 0 4946
4947 0 e4 :3 0
4948 4949 0 4983
c3 :3 0 c4 :3 0
494b 494c 0 c3
:3 0 d3 :3 0 494e
494f 0 e6 :2 0
2 :4 0 32b :2 0
d5 :2 0 2a :2 0
2988 4954 4956 :3 0
298b 4950 4958 494d
495a 4959 :2 0 c6
:3 0 d6 :3 0 495c
495d 0 c8 :4 0
32c :4 0 cb :2 0
cc :3 0 298f 4961
4963 :3 0 cb :2 0
e9 :4 0 2992 4965
4967 :3 0 cb :2 0
ea :4 0 2995 4969
496b :3 0 cb :2 0
e4 :3 0 2998 496d
496f :3 0 cb :2 0
eb :4 0 299b 4971
4973 :3 0 cb :2 0
a0 :3 0 ec :3 0
2a :2 0 ed :2 0
299e 4976 497a 29a2
4975 497c :3 0 29a5
495e 497e :2 0 4980
29a8 4981 495b 4980
0 4982 29aa 0
4983 29ac 4986 :3 0
4986 0 4986 4985
4983 4984 :6 0 4988
de :3 0 29af 498a
29b1 4989 4988 :2 0
498b 29b3 :2 0 498d
0 498d 498c 4943
498b :6 0 4abc 1
:3 0 15 :3 0 e1
:3 0 498f 4990 0
15 :3 0 da :2 0
157 :3 0 4992 4994
0 29b7 4993 4996
:3 0 4997 :2 0 84
:3 0 78 :3 0 3d
:2 0 29ba 4999 499c
da :2 0 3d :2 0
29bf 499e 49a0 :3 0
1fb :3 0 316 :3 0
31 :3 0 317 :3 0
32 :3 0 318 :3 0
3f :3 0 319 :3 0
3f :3 0 58 :3 0
31a :3 0 91 :3 0
22 :3 0 92 :3 0
21 :4 0 32d 1
:8 0 49c7 e0 :4 0
49b2 :3 0 f7 :3 0
da :2 0 29c4 49b5
49b6 :3 0 15 :3 0
e1 :3 0 49b8 49b9
0 3d :2 0 49ba
49bb 0 49bd 29c7
49c4 15 :3 0 e1
:3 0 49be 49bf 0
e2 :2 0 49c0 49c1
0 49c3 29c9 49c5
49b7 49bd 0 49c6
0 49c3 0 49c6
29cb 0 49c7 29ce
4a11 e5 :3 0 15
:3 0 e1 :3 0 49ca
49cb 0 e4 :3 0
49cc 49cd 0 4a07
c3 :3 0 c4 :3 0
49cf 49d0 0 c3
:3 0 d3 :3 0 49d2
49d3 0 e6 :2 0
2 :4 0 32e :2 0
d5 :2 0 2a :2 0
29d1 49d8 49da :3 0
29d4 49d4 49dc 49d1
49de 49dd :2 0 c6
:3 0 d6 :3 0 49e0
49e1 0 c8 :4 0
32f :4 0 cb :2 0
cc :3 0 29d8 49e5
49e7 :3 0 cb :2 0
e9 :4 0 29db 49e9
49eb :3 0 cb :2 0
ea :4 0 29de 49ed
49ef :3 0 cb :2 0
e4 :3 0 29e1 49f1
49f3 :3 0 cb :2 0
eb :4 0 29e4 49f5
49f7 :3 0 cb :2 0
a0 :3 0 ec :3 0
2a :2 0 ed :2 0
29e7 49fa 49fe 29eb
49f9 4a00 :3 0 29ee
49e2 4a02 :2 0 4a04
29f1 4a05 49df 4a04
0 4a06 29f3 0
4a07 29f5 4a0a :3 0
4a0a 0 4a0a 4a09
4a07 4a08 :6 0 4a0c
e0 :3 0 29f8 4a0e
29fa 4a0d 4a0c :2 0
4a0f 29fc :2 0 4a11
0 4a11 4a10 49c7
4a0f :6 0 4a13 1
:3 0 29fe 4a88 1fb
:3 0 316 :3 0 31
:3 0 317 :3 0 32
:3 0 318 :3 0 3f
:3 0 319 :3 0 3f
:3 0 58 :3 0 31a
:3 0 3f :3 0 5b
:3 0 91 :3 0 22
:3 0 92 :3 0 21
:4 0 330 1 :8 0
4a3b e0 :4 0 4a26
:3 0 f7 :3 0 da
:2 0 2a02 4a29 4a2a
:3 0 15 :3 0 e1
:3 0 4a2c 4a2d 0
3d :2 0 4a2e 4a2f
0 4a31 2a05 4a38
15 :3 0 e1 :3 0
4a32 4a33 0 e2
:2 0 4a34 4a35 0
4a37 2a07 4a39 4a2b
4a31 0 4a3a 0
4a37 0 4a3a 2a09
0 4a3b 2a0c 4a85
e5 :3 0 15 :3 0
e1 :3 0 4a3e 4a3f
0 e4 :3 0 4a40
4a41 0 4a7b c3
:3 0 c4 :3 0 4a43
4a44 0 c3 :3 0
d3 :3 0 4a46 4a47
0 e6 :2 0 2
:4 0 331 :2 0 d5
:2 0 2a :2 0 2a0f
4a4c 4a4e :3 0 2a12
4a48 4a50 4a45 4a52
4a51 :2 0 c6 :3 0
d6 :3 0 4a54 4a55
0 c8 :4 0 332
:4 0 cb :2 0 cc
:3 0 2a16 4a59 4a5b
:3 0 cb :2 0 e9
:4 0 2a19 4a5d 4a5f
:3 0 cb :2 0 ea
:4 0 2a1c 4a61 4a63
:3 0 cb :2 0 e4
:3 0 2a1f 4a65 4a67
:3 0 cb :2 0 eb
:4 0 2a22 4a69 4a6b
:3 0 cb :2 0 a0
:3 0 ec :3 0 2a
:2 0 ed :2 0 2a25
4a6e 4a72 2a29 4a6d
4a74 :3 0 2a2c 4a56
4a76 :2 0 4a78 2a2f
4a79 4a53 4a78 0
4a7a 2a31 0 4a7b
2a33 4a7e :3 0 4a7e
0 4a7e 4a7d 4a7b
4a7c :6 0 4a80 e2
:3 0 2a36 4a82 2a38
4a81 4a80 :2 0 4a83
2a3a :2 0 4a85 0
4a85 4a84 4a3b 4a83
:6 0 4a87 1 :3 0
2a3c 4a89 49a1 4a13
0 4a8a 0 4a87
0 4a8a 2a3e 0
4ab9 a0 :3 0 6f
:3 0 2a :2 0 2a
:2 0 2a41 4a8b 4a8f
da :2 0 1bd :4 0
2a47 4a91 4a93 :3 0
4a94 :2 0 84 :3 0
63 :3 0 3d :2 0
2a4a 4a96 4a99 da
:2 0 3d :2 0 2a4f
4a9b 4a9d :3 0 4a9e
:2 0 4a95 4aa0 4a9f
:2 0 7a :3 0 3d
:2 0 4aa2 4aa3 0
4ab6 15 :3 0 e1
:3 0 4aa5 4aa6 0
1bf :3 0 22 :3 0
22 :3 0 1e :3 0
2b :3 0 2d :3 0
58 :3 0 5b :3 0
7a :3 0 79 :3 0
78 :3 0 2a52 4aa8
4ab3 4aa7 4ab4 0
4ab6 2a5d 4ab7 4aa1
4ab6 0 4ab8 2a60
0 4ab9 2a62 4aba
4998 4ab9 0 4abb
2a65 0 4abc 2a67
4abd 47cc 4abc 0
4abe 2a6d 0 4b22
71 :3 0 333 :3 0
22 :3 0 2a6f 4ac0
4ac2 4abf 4ac3 0
4b22 15 :3 0 e1
:3 0 4ac5 4ac6 0
da :2 0 e2 :2 0
2a73 4ac8 4aca :3 0
15 :3 0 e1 :3 0
4acc 4acd 0 3d
:2 0 4ace 4acf 0
4ad1 2a76 4ad2 4acb
4ad1 0 4ad3 2a78
0 4b22 c3 :3 0
c4 :3 0 4ad4 4ad5
0 c3 :3 0 d3
:3 0 4ad7 4ad8 0
139 :2 0 2 :4 0
334 :2 0 d5 :2 0
2a :2 0 2a7a 4add
4adf :3 0 2a7d 4ad9
4ae1 4ad6 4ae3 4ae2
:2 0 c6 :3 0 d6
:3 0 4ae5 4ae6 0
c8 :4 0 335 :4 0
cb :2 0 cc :3 0
2a81 4aea 4aec :3 0
cb :2 0 e9 :4 0
2a84 4aee 4af0 :3 0
cb :2 0 f0 :4 0
2a87 4af2 4af4 :3 0
cb :2 0 84 :3 0
d0 :3 0 15 :3 0
e1 :3 0 4af9 4afa
0 2a8a 4af8 4afc
d1 :4 0 2a8c 4af7
4aff 2a8f 4af6 4b01
:3 0 cb :2 0 f2
:4 0 2a92 4b03 4b05
:3 0 cb :2 0 ce
:4 0 2a95 4b07 4b09
:3 0 cb :2 0 1e
:3 0 2a98 4b0b 4b0d
:3 0 cb :2 0 ce
:4 0 2a9b 4b0f 4b11
:3 0 2a9e 4ae7 4b13
:2 0 4b15 2aa1 4b16
4ae4 4b15 0 4b17
2aa3 0 4b22 f5
:3 0 336 :3 0 4b18
4b19 0 15 :3 0
e1 :3 0 4b1b 4b1c
0 1e :3 0 f7
:3 0 2aa5 4b1a 4b20
:2 0 4b22 2aa9 4bc3
15 :3 0 337 :2 0
4 4b23 4b24 0
c3 :3 0 c4 :3 0
4b26 4b27 0 c3
:3 0 d3 :3 0 4b29
4b2a 0 e6 :2 0
2 :4 0 338 :2 0
d5 :2 0 2a :2 0
2b00 4b2f 4b31 :3 0
2b03 4b2b 4b33 4b28
4b35 4b34 :2 0 c6
:3 0 d6 :3 0 4b37
4b38 0 c8 :4 0
339 :4 0 cb :2 0
cc :3 0 2b07 4b3c
4b3e :3 0 2b0a 4b39
4b40 :2 0 4b59 c6
:3 0 d6 :3 0 4b42
4b43 0 c8 :4 0
33a :4 0 cb :2 0
15 :3 0 33b :3 0
4b48 4b49 0 2b0d
4b47 4b4b :3 0 cb
:2 0 f2 :4 0 2b10
4b4d 4b4f :3 0 cb
:2 0 15 :3 0 33c
:3 0 4b52 4b53 0
2b13 4b51 4b55 :3 0
2b16 4b44 4b57 :2 0
4b59 2b19 4b5a 4b36
4b59 0 4b5b 2b1c
0 4b6b df :3 0
c2 :3 0 15 :3 0
33b :3 0 33d :3 0
15 :3 0 33c :3 0
33e :3 0 1ce :4 0
33f 1 :a 0 4b67
:2 0 4b6b 4b5d 4b65
:2 0 14 :3 0 c2
:3 0 4b69 :2 0 4b6b
2b1e 4b6d 2b22 4b6c
4b6b :2 0 4bc1 e5
:3 0 15 :3 0 e1
:3 0 4b70 4b71 0
e4 :3 0 4b72 4b73
0 4bb9 c3 :3 0
c4 :3 0 4b75 4b76
0 c3 :3 0 d3
:3 0 4b78 4b79 0
e6 :2 0 2 :4 0
340 :2 0 d5 :2 0
2a :2 0 2b24 4b7e
4b80 :3 0 2b27 4b7a
4b82 4b77 4b84 4b83
:2 0 c6 :3 0 d6
:3 0 4b86 4b87 0
c8 :4 0 341 :4 0
cb :2 0 cc :3 0
2b2b 4b8b 4b8d :3 0
2b2e 4b88 4b8f :2 0
4ba9 c6 :3 0 d6
:3 0 4b91 4b92 0
c8 :4 0 ea :4 0
cb :2 0 e4 :3 0
2b31 4b96 4b98 :3 0
cb :2 0 eb :4 0
2b34 4b9a 4b9c :3 0
cb :2 0 a0 :3 0
ec :3 0 2a :2 0
ed :2 0 2b37 4b9f
4ba3 2b3b 4b9e 4ba5
:3 0 2b3e 4b93 4ba7
:2 0 4ba9 2b41 4baa
4b85 4ba9 0 4bab
2b44 0 4bb9 df
:3 0 c2 :3 0 33d
:3 0 15 :3 0 33c
:3 0 33e :3 0 1ce
:4 0 342 1 :a 0
4bb5 :2 0 4bb9 4bad
4bb3 :2 0 14 :3 0
c2 :3 0 4bb7 :2 0
4bb9 2b46 4bbc :3 0
4bbc 0 4bbc 4bbb
4bb9 4bba :6 0 4bbe
1 :3 0 2b4b 4bc0
2b4d 4bbf 4bbe :2 0
4bc1 2b4f :2 0 4bc3
2b52 4bc3 4bc2 4b22
4bc1 :6 0 4bc4 :2 0
2 44 4bc3 4bc7
:3 0 4bc6 4bc4 4bc8
:8 0 
2bba
4
:3 0 1 3 1
7 1 b 1
f 1 13 1
17 1 1b 1
1f 1 23 1
27 1 2b 1
2f 1 33 1
37 1 3b f
6 a e 12
16 1a 1e 22
26 2a 2e 32
36 3a 3e 1
48 1 46 1
4f 1 4d 1
56 1 54 1
5d 1 5b 1
64 1 62 1
6b 1 69 1
72 1 70 1
79 1 77 1
80 1 7e 1
87 1 85 1
8e 1 8c 1
95 1 93 1
9a 1 9f 1
a4 1 a9 1
b0 1 ae 1
b5 1 ba 1
c1 1 bf 1
c8 1 c6 1
cd 1 d2 1
d7 1 dc 1
e3 1 e1 1
ea 1 e8 1
f1 1 ef 1
f8 1 f6 1
ff 1 fd 1
104 1 10a 1
110 1 116 1
11c 1 122 1
128 1 12e 1
134 1 13a 1
140 1 146 1
14c 1 152 1
158 1 15e 1
164 1 16a 1
170 1 176 1
17c 1 182 1
188 1 18e 1
194 1 19a 1
1a0 1 1a6 1
1ac 1 1b2 1
1b8 1 1be 1
1c4 1 1ca 1
1d0 1 1d6 1
1dc 1 1e2 1
1e8 1 1ee 1
1f6 1 1f4 1
1fd 1 1fb 1
202 1 208 1
210 1 20e 1
215 1 21d 1
21b 1 224 1
222 1 229 1
22f 1 235 1
23a 1 23f 1
245 1 24b 1
251 1 257 1
25d 1 263 1
269 1 26f 1
275 1 27b 1
283 1 281 1
28a 1 288 1
291 1 28f 2
29b 29c 1 29e
1 296 1 2a4
1 2aa 1 2ba
1 2ce 1 346
1 34c 1 359
1 365 2 368
36a 2 36d 36f
2 371 373 2
375 377 2 379
37b 2 37d 37f
2 381 383 2
385 387 2 389
38b 2 38d 38f
2 391 393 2
395 397 2 399
39b 2 39d 39f
2 3a1 3a3 2
3a5 3a7 2 3a9
3ab 2 3ad 3af
2 3b1 3b3 2
3b5 3b7 2 3b9
3bb 1 3c1 2
3c3 3c4 2 3bd
3c6 2 3c8 3ca
1 3d0 2 3d2
3d3 2 3cc 3d5
2 3d7 3d9 1
3df 2 3e1 3e2
2 3db 3e4 2
3e6 3e8 1 3ee
2 3f0 3f1 2
3ea 3f3 2 3f5
3f7 1 3fd 2
3ff 400 2 3f9
402 2 404 406
1 40c 2 40e
40f 2 408 411
2 413 415 1
41b 2 41d 41e
2 417 420 2
422 424 1 42a
2 42c 42d 2
426 42f 2 431
433 1 439 2
43b 43c 2 435
43e 2 440 442
2 444 446 2
448 44a 2 44c
44e 2 450 452
4 361 367 36c
454 1 456 1
458 2 462 464
3 460 461 466
2 46f 471 2
46e 473 1 475
1 477 2 48e
48f 2 491 494
2 499 49a 1
4a0 2 49c 4a0
2 4a5 4a6 1
4ac 2 4a8 4ac
1 4b4 1 4b6
1 4dd 1 4e3
2 4e5 4e6 2
4ef 4f5 2 506
508 3 504 505
50a 2 513 515
2 517 519 2
51b 51d 2 51f
521 2 523 525
3 52a 52b 52c
2 527 52e 2
512 530 1 532
1 534 2 4fd
535 1 539 1
4f8 1 53d 2
543 544 1 548
2 546 548 2
553 555 3 551
552 557 2 560
562 2 564 566
2 568 56a 1
572 2 574 575
2 56c 577 2
579 57b 2 57d
57f 2 581 583
2 585 587 2
55f 589 1 58b
1 58d 2 597
599 3 595 596
59b 2 5a4 5a6
2 5a3 5a8 1
5aa 1 5ac 3
5b3 5b4 5b5 3
58e 5ad 5b7 1
5b9 2 5cc 5d1
2 5e2 5e4 3
5e0 5e1 5e6 2
5ef 5f1 2 5f3
5f5 2 5f7 5f9
2 5fb 5fd 2
5ff 601 3 606
607 608 2 603
60a 2 5ee 60c
1 60e 1 610
2 5d9 611 1
615 1 5d4 1
619 1 624 2
620 624 2 630
632 3 62e 62f
634 2 63d 63f
2 641 643 2
645 647 1 64f
2 651 652 2
649 654 2 656
658 2 65a 65c
2 65e 660 2
662 664 2 63c
666 1 668 1
66a 2 674 676
3 672 673 678
2 681 683 2
680 685 1 687
1 689 3 690
691 692 3 66b
68a 694 1 696
2 6a0 6a5 2
6b6 6b8 3 6b4
6b5 6ba 2 6c3
6c5 2 6c7 6c9
2 6cb 6cd 2
6cf 6d1 2 6d3
6d5 3 6da 6db
6dc 2 6d7 6de
2 6c2 6e0 1
6e2 1 6e4 2
6ad 6e5 1 6e9
1 6a8 1 6ed
2 6f3 6f4 1
6f8 2 6f6 6f8
2 703 705 3
701 702 707 2
710 712 2 714
716 2 718 71a
1 722 2 724
725 2 71c 727
2 729 72b 2
72d 72f 2 731
733 2 735 737
2 70f 739 1
73b 1 73d 2
747 749 3 745
746 74b 2 754
756 2 753 758
1 75a 1 75c
3 763 764 765
3 73e 75d 767
1 769 2 790
795 2 7a6 7a8
3 7a4 7a5 7aa
2 7b3 7b5 2
7b7 7b9 2 7bb
7bd 2 7bf 7c1
2 7c3 7c5 3
7ca 7cb 7cc 2
7c7 7ce 2 7b2
7d0 1 7d2 1
7d4 2 79d 7d5
1 7d9 1 798
1 7dd 1 7e8
2 7e4 7e8 2
7f4 7f6 3 7f2
7f3 7f8 2 801
803 2 805 807
2 809 80b 1
813 2 815 816
2 80d 818 2
81a 81c 2 81e
820 2 822 824
2 826 828 2
800 82a 1 82c
1 82e 2 838
83a 3 836 837
83c 2 845 847
2 844 849 1
84b 1 84d 3
854 855 856 3
82f 84e 858 1
85a 2 863 868
2 879 87b 3
877 878 87d 2
886 888 2 88a
88c 2 88e 890
2 892 894 2
896 898 3 89d
89e 89f 2 89a
8a1 2 885 8a3
1 8a5 1 8a7
2 870 8a8 1
8ac 1 86b 1
8b0 1 8bb 2
8b7 8bb 2 8c7
8c9 3 8c5 8c6
8cb 2 8d4 8d6
2 8d8 8da 2
8dc 8de 1 8e6
2 8e8 8e9 2
8e0 8eb 2 8ed
8ef 2 8f1 8f3
2 8f5 8f7 2
8f9 8fb 2 8d3
8fd 1 8ff 1
901 2 90b 90d
3 909 90a 90f
2 918 91a 2
917 91c 1 91e
1 920 3 927
928 929 3 902
921 92b 1 92d
2 934 939 2
94a 94c 3 948
949 94e 2 957
959 2 95b 95d
2 95f 961 2
963 965 2 967
969 3 96e 96f
970 2 96b 972
2 956 974 1
976 1 978 2
941 979 1 97d
1 93c 1 981
2 989 98a 1
98e 2 98c 98e
1 993 1 995
1 99d 2 999
99d 2 9a9 9ab
3 9a7 9a8 9ad
2 9b6 9b8 2
9ba 9bc 2 9be
9c0 1 9c8 2
9ca 9cb 2 9c2
9cd 2 9cf 9d1
2 9d3 9d5 2
9d7 9d9 2 9db
9dd 2 9b5 9df
1 9e1 1 9e3
2 9ed 9ef 3
9eb 9ec 9f1 2
9fa 9fc 2 9f9
9fe 1 a00 1
a02 3 a09 a0a
a0b 3 9e4 a03
a0d 1 a0f 2
a17 a18 2 a1a
a1b 2 a22 a23
2 a25 a26 2
a2d a2e 2 a30
a31 1 a37 2
a35 a37 2 a3b
a3c 1 a40 2
a3e a40 2 a4e
a53 2 a64 a66
3 a62 a63 a68
2 a71 a73 2
a75 a77 2 a79
a7b 2 a7d a7f
2 a81 a83 3
a88 a89 a8a 2
a85 a8c 2 a70
a8e 1 a90 1
a92 2 a5b a93
1 a97 1 a56
1 a9b 1 a9e
2 aa3 aa4 1
aa8 2 aa6 aa8
2 ab6 abb 2
acc ace 3 aca
acb ad0 2 ad9
adb 2 add adf
2 ae1 ae3 2
ae5 ae7 2 ae9
aeb 3 af0 af1
af2 2 aed af4
2 ad8 af6 1
af8 1 afa 2
ac3 afb 1 aff
1 abe 1 b03
1 b06 2 b0a
b09 2 b0d b0e
1 b12 2 b10
b12 2 b1d b1f
3 b1b b1c b21
2 b2a b2c 2
b2e b30 2 b32
b34 1 b3c 2
b3e b3f 2 b36
b41 2 b43 b45
2 b47 b49 2
b4b b4d 2 b4f
b51 2 b29 b53
1 b55 1 b57
2 b61 b63 3
b5f b60 b65 2
b6e b70 2 b6d
b72 1 b74 1
b76 3 b7d b7e
b7f 3 b58 b77
b81 1 b83 2
b0b b84 2 b91
b96 2 ba7 ba9
3 ba5 ba6 bab
2 bb4 bb6 2
bb8 bba 2 bbc
bbe 2 bc0 bc2
2 bc4 bc6 3
bcb bcc bcd 2
bc8 bcf 2 bb3
bd1 1 bd3 1
bd5 2 b9e bd6
1 bda 1 b99
1 bde 2 bee
bf3 2 c04 c06
3 c02 c03 c08
2 c11 c13 2
c15 c17 2 c19
c1b 2 c1d c1f
2 c21 c23 3
c28 c29 c2a 2
c25 c2c 2 c10
c2e 1 c30 1
c32 2 bfb c33
1 c37 1 bf6
1 c3b 2 c42
c43 1 c45 1
c4a 2 c48 c4a
2 c4e c4f 1
c53 2 c51 c53
2 c58 c59 1
c5d 2 c5b c5d
2 c70 c75 2
c86 c88 3 c84
c85 c8a 2 c93
c95 2 c97 c99
2 c9b c9d 2
c9f ca1 2 ca3
ca5 3 caa cab
cac 2 ca7 cae
2 c92 cb0 1
cb2 1 cb4 2
c7d cb5 1 cb9
1 c78 1 cbd
2 cc3 cc4 1
cc8 2 cc6 cc8
2 cd3 cd5 3
cd1 cd2 cd7 2
ce0 ce2 2 ce4
ce6 2 ce8 cea
1 cf2 2 cf4
cf5 2 cec cf7
2 cf9 cfb 2
cfd cff 2 d01
d03 2 d05 d07
2 cdf d09 1
d0b 1 d0d 2
d17 d19 3 d15
d16 d1b 2 d24
d26 2 d23 d28
1 d2a 1 d2c
3 d33 d34 d35
3 d0e d2d d37
1 d39 2 cc0
d3a 1 d3c 3
be1 c3e d3d 2
d3f d40 1 d61
1 d67 2 d69
d6a 1 d72 2
d6e d72 1 d78
1 d7c 2 d7e
d7f 2 d83 d89
2 d9a d9c 3
d98 d99 d9e 2
da7 da9 2 dab
dad 2 daf db1
2 db3 db5 2
db7 db9 3 dbe
dbf dc0 2 dbb
dc2 2 da6 dc4
1 dc6 1 dc8
2 d91 dc9 1
dcd 1 d8c 1
dd1 2 dd7 dd8
1 ddc 2 dda
ddc 2 dea def
2 e00 e02 3
dfe dff e04 2
e0d e0f 2 e11
e13 2 e15 e17
2 e19 e1b 2
e1d e1f 3 e24
e25 e26 2 e21
e28 2 e0c e2a
1 e2c 1 e2e
2 df7 e2f 1
e33 1 df2 1
e37 2 e3d e3e
1 e42 2 e40
e42 2 e55 e5a
2 e6b e6d 3
e69 e6a e6f 2
e78 e7a 2 e7c
e7e 2 e80 e82
2 e84 e86 2
e88 e8a 3 e8f
e90 e91 2 e8c
e93 2 e77 e95
1 e97 1 e99
2 e62 e9a 1
e9e 1 e5d 1
ea2 1 ead 2
ea9 ead 2 eb9
ebb 3 eb7 eb8
ebd 2 ec6 ec8
2 eca ecc 2
ece ed0 1 ed8
2 eda edb 2
ed2 edd 2 edf
ee1 2 ee3 ee5
2 ee7 ee9 2
eeb eed 2 ec5
eef 1 ef1 1
ef3 2 efd eff
3 efb efc f01
2 f0a f0c 2
f09 f0e 1 f10
1 f12 3 f19
f1a f1b 3 ef4
f13 f1d 1 f20
1 f26 3 f31
f32 f33 1 f37
2 f35 f37 3
f3e f3f f40 1
f44 2 f42 f44
2 f52 f54 3
f50 f51 f56 2
f5f f61 2 f63
f65 2 f67 f69
1 f71 2 f73
f74 2 f6b f76
2 f78 f7a 2
f7c f7e 2 f80
f82 2 f84 f86
2 f5e f88 1
f8a 1 f8c 2
f96 f98 3 f94
f95 f9a 2 fa3
fa5 2 fa2 fa7
1 fa9 1 fab
3 fb2 fb3 fb4
3 f8d fac fb6
1 fb8 1 fb9
2 fbc fbb 3
e47 ea5 fbd 1
fbf 2 fc2 fc3
1 fc7 2 fc5
fc7 2 fcc fcf
2 fdc fe1 2
ff2 ff4 3 ff0
ff1 ff6 2 fff
1001 2 1003 1005
2 1007 1009 2
100b 100d 2 100f
1011 3 1016 1017
1018 2 1013 101a
2 ffe 101c 1
101e 1 1020 2
fe9 1021 1 1025
1 fe4 1 1029
1 1034 2 1030
1034 2 1044 1045
4 1042 1047 104a
104b 7 105c 105d
105e 105f 1060 1061
1062 2 1069 106a
1 106c 1 108d
2 108c 108d 1
1095 1 109b 2
109d 109e 2 108a
109f 2 10b0 10b2
3 10ae 10af 10b4
2 10bd 10bf 2
10c1 10c3 2 10c5
10c7 2 10c9 10cb
2 10cd 10cf 3
10d4 10d5 10d6 2
10d1 10d8 2 10bc
10da 1 10dc 1
10de 2 10a7 10df
1 10e3 1 10a2
1 10e7 2 10f1
10f6 2 1107 1109
3 1105 1106 110b
2 1114 1116 2
1118 111a 2 111c
111e 2 1120 1122
2 1124 1126 3
112b 112c 112d 2
1128 112f 2 1113
1131 1 1133 1
1135 2 10fe 1136
1 113a 1 10f9
1 113e 2 1146
1147 1 114b 2
1149 114b 1 1150
2 115e 1163 2
1174 1176 3 1172
1173 1178 2 1181
1183 2 1185 1187
2 1189 118b 2
118d 118f 2 1191
1193 3 1198 1199
119a 2 1195 119c
2 1180 119e 1
11a0 1 11a2 2
116b 11a3 1 11a7
1 1166 1 11ab
1 11ae 2 11b1
11b2 2 11b5 11b6
1 11ba 2 11b8
11ba 1 11ca 2
11c9 11ca 1 11d2
1 11d8 2 11da
11db 2 11c7 11dc
2 11ed 11ef 3
11eb 11ec 11f1 2
11fa 11fc 2 11fe
1200 2 1202 1204
2 1206 1208 2
120a 120c 3 1211
1212 1213 2 120e
1215 2 11f9 1217
1 1219 1 121b
2 11e4 121c 1
1220 1 11df 1
1224 1 123d 2
123c 123d 1 1245
1 124b 2 124d
124e 2 123a 124f
2 1260 1262 3
125e 125f 1264 2
126d 126f 2 1271
1273 2 1275 1277
2 1279 127b 2
127d 127f 3 1284
1285 1286 2 1281
1288 2 126c 128a
1 128c 1 128e
2 1257 128f 1
1293 1 1252 1
1297 2 1227 129a
1 12b1 2 12b0
12b1 1 12b9 1
12bf 2 12c1 12c2
2 12ae 12c3 2
12d4 12d6 3 12d2
12d3 12d8 2 12e1
12e3 2 12e5 12e7
2 12e9 12eb 2
12ed 12ef 2 12f1
12f3 3 12f8 12f9
12fa 2 12f5 12fc
2 12e0 12fe 1
1300 1 1302 2
12cb 1303 1 1307
1 12c6 1 130b
1 130e 2 1311
1312 c 103a 103f
104e 1053 1056 1059
1065 106f 10ea 1141
11b3 1313 1 131c
2 1318 131c 2
1326 132b 2 133c
133e 3 133a 133b
1340 2 1349 134b
2 134d 134f 2
1351 1353 2 1355
1357 2 1359 135b
3 1360 1361 1362
2 135d 1364 2
1348 1366 1 1368
1 136a 2 1333
136b 1 136f 1
132e 1 1373 2
1379 137a 1 1380
2 137c 1380 2
1387 1388 4 1385
138a 138d 138e 1
139f 2 139e 139f
1 13a7 1 13ad
2 13af 13b0 2
139c 13b1 2 13c2
13c4 3 13c0 13c1
13c6 2 13cf 13d1
2 13d3 13d5 2
13d7 13d9 2 13db
13dd 2 13df 13e1
3 13e6 13e7 13e8
2 13e3 13ea 2
13ce 13ec 1 13ee
1 13f0 2 13b9
13f1 1 13f5 1
13b4 1 13f9 1
1400 3 1391 13fc
1403 2 1408 1409
2 140b 140e 1
1415 2 1411 1415
1 1426 2 1425
1426 1 142e 1
1434 2 1436 1437
2 1423 1438 2
1449 144b 3 1447
1448 144d 2 1456
1458 2 145a 145c
2 145e 1460 2
1462 1464 2 1466
1468 3 146d 146e
146f 2 146a 1471
2 1455 1473 1
1475 1 1477 2
1440 1478 1 147c
1 143b 1 1480
1 1487 2 1483
148a 1 149b 2
149a 149b 1 14a3
1 14a9 2 14ab
14ac 2 1498 14ad
2 14be 14c0 3
14bc 14bd 14c2 2
14cb 14cd 2 14cf
14d1 2 14d3 14d5
2 14d7 14d9 2
14db 14dd 3 14e2
14e3 14e4 2 14df
14e6 2 14ca 14e8
1 14ea 1 14ec
2 14b5 14ed 1
14f1 1 14b0 1
14f5 1 14fc 2
14f8 14ff 3 1501
148c 1502 2 1376
1503 2 1506 1505
2 102c 1507 2
1509 150a 3 e3a
fc0 150b 1 150f
2 1511 1512 2
1523 1524 1 1528
2 1526 1528 2
152d 152e 1 1532
2 1530 1532 a
153a 153b 153c 153d
153e 153f 1540 1541
1542 1543 1 1546
1 1548 2 1560
1565 2 1576 1578
3 1574 1575 157a
2 1583 1585 2
1587 1589 2 158b
158d 2 158f 1591
2 1593 1595 3
159a 159b 159c 2
1597 159e 2 1582
15a0 1 15a2 1
15a4 2 156d 15a5
1 15a9 1 1568
1 15ad 1 15b8
2 15b4 15b8 1
15be 1 15c0 2
15d2 15d7 2 15e8
15ea 3 15e6 15e7
15ec 2 15f5 15f7
2 15f9 15fb 2
15fd 15ff 2 1601
1603 2 1605 1607
3 160c 160d 160e
2 1609 1610 2
15f4 1612 1 1614
1 1616 2 15df
1617 1 161b 1
15da 1 161f 2
1627 1628 1 162c
2 162a 162c 2
1639 163e 2 164f
1651 3 164d 164e
1653 2 165c 165e
2 1660 1662 2
1664 1666 2 1668
166a 2 166c 166e
3 1673 1674 1675
2 1670 1677 2
165b 1679 1 167b
1 167d 2 1646
167e 1 1682 1
1641 1 1686 2
168c 168d 1 1691
2 168f 1691 1
1696 1 169a 2
169c 169d 2 1689
169e 1 16a0 2
16a3 16a4 1 16a8
2 16a6 16a8 2
16ae 16af 1 16b3
2 16b1 16b3 2
16de 16e3 2 16f4
16f6 3 16f2 16f3
16f8 2 1701 1703
2 1705 1707 2
1709 170b 2 170d
170f 2 1711 1713
3 1718 1719 171a
2 1715 171c 2
1700 171e 1 1720
1 1722 2 16eb
1723 1 1727 1
16e6 1 172b 2
1737 1738 1 173c
2 173a 173c 2
1740 1741 2 1746
1747 1 1749 2
1743 1749 2 174e
174f 2 1754 1755
1 1757 2 1751
1757 2 175e 175f
1 1763 2 1761
1763 2 1769 176a
2 176c 176f 1
1774 2 1772 1774
2 1782 1784 3
1780 1781 1786 2
178f 1791 2 1793
1795 2 1797 1799
1 17a1 2 17a3
17a4 2 179b 17a6
2 17a8 17aa 2
17ac 17ae 2 17b0
17b2 2 17b4 17b6
2 178e 17b8 1
17ba 1 17bc 2
17c6 17c8 3 17c4
17c5 17ca 2 17d3
17d5 2 17d2 17d7
1 17d9 1 17db
3 17e2 17e3 17e4
3 17bd 17dc 17e6
2 17ec 17ed 1
17f1 2 17ef 17f1
1 17f6 1 17f8
2 17ea 17f9 2
17fb 17fc 1 17fd
1 17ff a 1800
1803 1806 1809 180c
180f 1812 1815 1818
181b 1 181d 1
1825 2 1821 1825
1 1829 3 1832
1833 1834 1 1838
2 1836 1838 1
183d a 1845 1846
1847 1848 1849 184a
184b 184c 184d 184e
2 1840 1851 1
1853 2 1856 1857
1 185b 2 1859
185b 1 1864 2
1863 1864 1 186c
1 1872 2 1874
1875 2 1861 1876
2 1887 1889 3
1885 1886 188b 2
1894 1896 2 1898
189a 2 189c 189e
2 18a0 18a2 2
18a4 18a6 3 18ab
18ac 18ad 2 18a8
18af 2 1893 18b1
1 18b3 1 18b5
2 187e 18b6 1
18ba 1 1879 1
18be 1 18cb 2
18ca 18cb 1 18d3
1 18d9 2 18db
18dc 2 18c8 18dd
2 18ee 18f0 3
18ec 18ed 18f2 2
18fb 18fd 2 18ff
1901 2 1903 1905
2 1907 1909 2
190b 190d 3 1912
1913 1914 2 190f
1916 2 18fa 1918
1 191a 1 191c
2 18e5 191d 1
1921 1 18e0 1
1925 2 1935 193a
2 194b 194d 3
1949 194a 194f 2
1958 195a 2 195c
195e 2 1960 1962
2 1964 1966 2
1968 196a 3 196f
1970 1971 2 196c
1973 2 1957 1975
1 1977 1 1979
2 1942 197a 1
197e 1 193d 1
1982 3 198a 198b
198c 1 1990 2
198e 1990 2 199d
19a2 2 19b3 19b5
3 19b1 19b2 19b7
2 19c0 19c2 2
19c4 19c6 2 19c8
19ca 2 19cc 19ce
2 19d0 19d2 3
19d7 19d8 19d9 2
19d4 19db 2 19bf
19dd 1 19df 1
19e1 2 19aa 19e2
1 19e6 1 19a5
1 19ea 1 19ed
1 19f0 5 18c1
1928 192c 1985 19f1
2 19f4 19f5 1
19f9 2 19f7 19f9
2 19fe 19ff 1
1a03 2 1a01 1a03
2 1a0b 1a0c 2
1a11 1a12 2 1a0e
1a14 2 1a1a 1a1b
2 1a20 1a21 2
1a1d 1a23 2 1a29
1a2a 2 1a2f 1a30
2 1a2c 1a32 2
1a38 1a39 2 1a3e
1a3f 2 1a3b 1a41
2 1a46 1a47 1
1a4b 2 1a49 1a4b
1 1a6f 2 1a6e
1a6f 1 1a77 1
1a7d 2 1a7f 1a80
2 1a6c 1a81 2
1a92 1a94 3 1a90
1a91 1a96 2 1a9f
1aa1 2 1aa3 1aa5
2 1aa7 1aa9 2
1aab 1aad 2 1aaf
1ab1 3 1ab6 1ab7
1ab8 2 1ab3 1aba
2 1a9e 1abc 1
1abe 1 1ac0 2
1a89 1ac1 1 1ac5
1 1a84 1 1ac9
1 1acc 1 1af4
2 1af3 1af4 1
1afc 1 1b02 2
1b04 1b05 2 1af1
1b06 2 1b17 1b19
3 1b15 1b16 1b1b
2 1b24 1b26 2
1b28 1b2a 2 1b2c
1b2e 2 1b30 1b32
2 1b34 1b36 3
1b3b 1b3c 1b3d 2
1b38 1b3f 2 1b23
1b41 1 1b43 1
1b45 2 1b0e 1b46
1 1b4a 1 1b09
1 1b4e 1 1b51
2 1b54 1b55 5
1a17 1a26 1a35 1a44
1b56 2 1b5a 1b5b
1 1b5f 2 1b5d
1b5f 2 1b64 1b65
2 1b6a 1b6b 2
1b67 1b6d 2 1b73
1b74 2 1b79 1b7a
2 1b76 1b7c 1
1b9d 2 1b9c 1b9d
1 1ba5 1 1bab
2 1bad 1bae 2
1b9a 1baf 2 1bc0
1bc2 3 1bbe 1bbf
1bc4 2 1bcd 1bcf
2 1bd1 1bd3 2
1bd5 1bd7 2 1bd9
1bdb 2 1bdd 1bdf
3 1be4 1be5 1be6
2 1be1 1be8 2
1bcc 1bea 1 1bec
1 1bee 2 1bb7
1bef 1 1bf3 1
1bb2 1 1bf7 3
1b70 1b7f 1bfa 2
1c00 1c01 1 1c05
2 1c03 1c05 2
1c0a 1c0b 2 1c10
1c11 2 1c0d 1c13
2 1c19 1c1a 2
1c1f 1c20 2 1c1c
1c22 2 1c27 1c28
1 1c2c 2 1c2a
1c2c 1 1c48 2
1c47 1c48 1 1c50
1 1c56 2 1c58
1c59 2 1c45 1c5a
2 1c6b 1c6d 3
1c69 1c6a 1c6f 2
1c78 1c7a 2 1c7c
1c7e 2 1c80 1c82
2 1c84 1c86 2
1c88 1c8a 3 1c8f
1c90 1c91 2 1c8c
1c93 2 1c77 1c95
1 1c97 1 1c99
2 1c62 1c9a 1
1c9e 1 1c5d 1
1ca2 1 1ca5 1
1cc5 2 1cc4 1cc5
1 1ccd 1 1cd3
2 1cd5 1cd6 2
1cc2 1cd7 2 1ce8
1cea 3 1ce6 1ce7
1cec 2 1cf5 1cf7
2 1cf9 1cfb 2
1cfd 1cff 2 1d01
1d03 2 1d05 1d07
3 1d0c 1d0d 1d0e
2 1d09 1d10 2
1cf4 1d12 1 1d14
1 1d16 2 1cdf
1d17 1 1d1b 1
1cda 1 1d1f 1
1d22 2 1d25 1d26
3 1c16 1c25 1d27
1 1d39 2 1d38
1d39 1 1d41 1
1d47 2 1d49 1d4a
2 1d36 1d4b 2
1d5c 1d5e 3 1d5a
1d5b 1d60 2 1d69
1d6b 2 1d6d 1d6f
2 1d71 1d73 2
1d75 1d77 2 1d79
1d7b 3 1d80 1d81
1d82 2 1d7d 1d84
2 1d68 1d86 1
1d88 1 1d8a 2
1d53 1d8b 1 1d8f
1 1d4e 1 1d93
1 1d96 4 1d99
1bfe 1d29 1d9a 1
1da4 2 1da3 1da4
1 1dac 1 1db2
2 1db4 1db5 2
1da1 1db6 2 1dc7
1dc9 3 1dc5 1dc6
1dcb 2 1dd4 1dd6
2 1dd8 1dda 2
1ddc 1dde 2 1de0
1de2 2 1de4 1de6
3 1deb 1dec 1ded
2 1de8 1def 2
1dd3 1df1 1 1df3
1 1df5 2 1dbe
1df6 1 1dfa 1
1db9 1 1dfe 1
1e11 2 1e10 1e11
1 1e19 1 1e1f
2 1e21 1e22 2
1e0e 1e23 2 1e34
1e36 3 1e32 1e33
1e38 2 1e41 1e43
2 1e45 1e47 2
1e49 1e4b 2 1e4d
1e4f 2 1e51 1e53
3 1e58 1e59 1e5a
2 1e55 1e5c 2
1e40 1e5e 1 1e60
1 1e62 2 1e2b
1e63 1 1e67 1
1e26 1 1e6b 3
1d9b 1e01 1e6e 2
1e71 1e72 1 1e7d
2 1e7c 1e7d 1
1e85 1 1e8b 2
1e8d 1e8e 2 1e7a
1e8f 2 1ea0 1ea2
3 1e9e 1e9f 1ea4
2 1ead 1eaf 2
1eb1 1eb3 2 1eb5
1eb7 2 1eb9 1ebb
2 1ebd 1ebf 3
1ec4 1ec5 1ec6 2
1ec1 1ec8 2 1eac
1eca 1 1ecc 1
1ece 2 1e97 1ecf
1 1ed3 1 1e92
1 1ed7 1 1ee4
2 1ee3 1ee4 1
1eec 1 1ef2 2
1ef4 1ef5 2 1ee1
1ef6 2 1f07 1f09
3 1f05 1f06 1f0b
2 1f14 1f16 2
1f18 1f1a 2 1f1c
1f1e 2 1f20 1f22
2 1f24 1f26 3
1f2b 1f2c 1f2d 2
1f28 1f2f 2 1f13
1f31 1 1f33 1
1f35 2 1efe 1f36
1 1f3a 1 1ef9
1 1f3e 2 1f44
1f45 1 1f49 2
1f47 1f49 2 1f4e
1f4f 1 1f53 2
1f51 1f53 2 1f62
1f63 1 1f67 2
1f65 1f67 1 1f6c
1 1f70 2 1f72
1f73 2 1f76 1f77
1 1f7b 2 1f79
1f7b 1 1f80 1
1f82 2 1f89 1f8a
2 1f8e 1f8f 2
1f93 1f94 2 1f98
1f99 2 1f9d 1f9e
2 1fa2 1fa3 2
1fa7 1fa8 2 1fac
1fad d 1f86 1f87
1f8c 1f91 1f96 1f9b
1fa0 1fa5 1faa 1faf
1fb0 1fb1 1fb2 2
1fb7 1fb8 1 1fbe
2 1fba 1fbe 2
1fc9 1fcb 3 1fc7
1fc8 1fcd 2 1fd6
1fd8 2 1fda 1fdc
2 1fde 1fe0 1
1fe8 2 1fea 1feb
2 1fe2 1fed 2
1fd5 1fef 1 1ff1
1 1ff3 2 1ffd
1fff 3 1ffb 1ffc
2001 2 200a 200c
2 2009 200e 1
2010 1 2012 2
2019 201a 3 1ff4
2013 201c 2 2020
2021 1 2025 2
2023 2025 2 2030
2032 3 202e 202f
2034 2 203d 203f
2 2041 2043 2
2045 2047 1 204d
2 204f 2050 2
2049 2052 2 2054
2056 2 2058 205a
2 205c 205e 2
2060 2062 2 203c
2064 1 2066 1
2068 2 2072 2074
3 2070 2071 2076
2 207f 2081 2
207e 2083 1 2085
1 2087 2 208d
208e 3 2090 2091
2092 3 2069 2088
2094 2 2097 2096
2 209a 209b 1
209f 2 209d 209f
1 20a6 2 20ad
20ae 2 20b0 20b3
1 20b6 2 20b8
20b9 20 20c0 20c1
20c2 20c3 20c4 20c5
20c6 20c7 20c8 20c9
20ca 20cb 20cc 20cd
20ce 20cf 20d0 20d1
20d2 20d3 20d4 20d5
20d6 20d7 20d8 20d9
20da 20db 20dc 20dd
20de 20df 2 20e4
20e5 1 20e9 2
20e7 20e9 2 20f4
20f6 3 20f2 20f3
20f8 2 2101 2103
2 2105 2107 2
2109 210b 1 2113
2 2115 2116 2
210d 2118 2 211a
211c 2 211e 2120
2 2122 2124 2
2126 2128 2 2100
212a 1 212c 1
212e 2 2138 213a
3 2136 2137 213c
2 2145 2147 2
2144 2149 1 214b
1 214d 3 2154
2155 2156 3 212f
214e 2158 2 215c
215d 1 2161 2
215f 2161 2 216c
216e 3 216a 216b
2170 2 2179 217b
2 217d 217f 2
2181 2183 1 218b
2 218d 218e 2
2185 2190 2 2192
2194 2 2196 2198
2 219a 219c 2
219e 21a0 2 2178
21a2 1 21a4 1
21a6 2 21b0 21b2
3 21ae 21af 21b4
2 21bd 21bf 2
21bc 21c1 1 21c3
1 21c5 3 21cc
21cd 21ce 3 21a7
21c6 21d0 2 21dc
21dd 2 21e1 21e2
5 21d8 21d9 21da
21df 21e4 2 21d5
21e7 3 21e9 21d2
21ea a 1f5b 1f5e
1f74 1f83 1fb5 2098
20ba 20bd 20e2 21eb
1 21ed 6 1854
1e73 1e76 1eda 1f41
21ee 1 21f0 5
172e 1732 1735 181e
21f1 3 21f5 21f6
21f7 1 21fb 2
21f9 21fb 2 2218
221d 2 222e 2230
3 222c 222d 2232
2 223b 223d 2
223f 2241 2 2243
2245 2 2247 2249
2 224b 224d 3
2252 2253 2254 2
224f 2256 2 223a
2258 1 225a 1
225c 2 2225 225d
1 2261 1 2220
1 2265 1 2270
2 226c 2270 1
2274 1 227e a
2286 2287 2288 2289
228a 228b 228c 228d
228e 228f 2 2281
2292 1 2294 2
2268 2295 2 22a4
22a9 2 22ba 22bc
3 22b8 22b9 22be
2 22c7 22c9 2
22cb 22cd 2 22cf
22d1 2 22d3 22d5
2 22d7 22d9 3
22de 22df 22e0 2
22db 22e2 2 22c6
22e4 1 22e6 1
22e8 2 22b1 22e9
1 22ed 1 22ac
1 22f1 1 22f4
3 22f7 2297 22f8
1 22f9 3 22fd
22fe 22ff 1 2303
2 2301 2303 2
2320 2325 2 2336
2338 3 2334 2335
233a 2 2343 2345
2 2347 2349 2
234b 234d 2 234f
2351 2 2353 2355
3 235a 235b 235c
2 2357 235e 2
2342 2360 1 2362
1 2364 2 232d
2365 1 2369 1
2328 1 236d 1
2378 2 2374 2378
1 237c 1 2386
a 238e 238f 2390
2391 2392 2393 2394
2395 2396 2397 2
2389 239a 1 239c
2 2370 239d 2
23ac 23b1 2 23c2
23c4 3 23c0 23c1
23c6 2 23cf 23d1
2 23d3 23d5 2
23d7 23d9 2 23db
23dd 2 23df 23e1
3 23e6 23e7 23e8
2 23e3 23ea 2
23ce 23ec 1 23ee
1 23f0 2 23b9
23f1 1 23f5 1
23b4 1 23f9 1
23fc 3 23ff 239f
2400 1 2402 2
2409 240a 1 240e
2 240c 240e 2
2415 2416 1 241a
2 2418 241a 2
2429 242a 1 242e
2 242c 242e 2
2433 2434 1 2437
1 2439 2 243c
243d 1 2441 2
243f 2441 2 2446
2447 1 244b 2
2449 244b 2 2452
2453 1 2457 2
2455 2457 2 245c
245d 1 2461 2
245f 2461 2 2469
246a 2 246f 2470
2 246c 2472 2
2478 2479 2 247e
247f 2 247b 2481
2 2487 2488 2
248d 248e 2 248a
2490 2 2496 2497
2 249c 249d 2
2499 249f 1 24da
2 24d9 24da 1
24e2 1 24e8 2
24ea 24eb 2 24d7
24ec 2 24fd 24ff
3 24fb 24fc 2501
2 250a 250c 2
250e 2510 2 2512
2514 2 2516 2518
2 251a 251c 3
2521 2522 2523 2
251e 2525 2 2509
2527 1 2529 1
252b 2 24f4 252c
1 2530 1 24ef
1 2534 5 2475
2484 2493 24a2 2537
2 253c 253d 1
2541 2 253f 2541
2 2546 2547 2
254c 254d 2 2549
254f 2 2555 2556
2 255b 255c 2
2558 255e 1 2599
2 2598 2599 1
25a1 1 25a7 2
25a9 25aa 2 2596
25ab 2 25bc 25be
3 25ba 25bb 25c0
2 25c9 25cb 2
25cd 25cf 2 25d1
25d3 2 25d5 25d7
2 25d9 25db 3
25e0 25e1 25e2 2
25dd 25e4 2 25c8
25e6 1 25e8 1
25ea 2 25b3 25eb
1 25ef 1 25ae
1 25f3 3 2552
2561 25f6 2 25fc
25fd 2 2602 2603
2 25ff 2605 2
260b 260c 2 2611
2612 2 260e 2614
1 264f 2 264e
264f 1 2657 1
265d 2 265f 2660
2 264c 2661 2
2672 2674 3 2670
2671 2676 2 267f
2681 2 2683 2685
2 2687 2689 2
268b 268d 2 268f
2691 3 2696 2697
2698 2 2693 269a
2 267e 269c 1
269e 1 26a0 2
2669 26a1 1 26a5
1 2664 1 26a9
3 2608 2617 26ac
3 26af 25f9 26b0
1 26b1 1 26ea
2 26e9 26ea 1
26f2 1 26f8 2
26fa 26fb 2 26e7
26fc 2 270d 270f
3 270b 270c 2711
2 271a 271c 2
271e 2720 2 2722
2724 2 2726 2728
2 272a 272c 3
2731 2732 2733 2
272e 2735 2 2719
2737 1 2739 1
273b 2 2704 273c
1 2740 1 26ff
1 2744 1 2747
2 274a 274b 5
2422 2427 243a 274c
274f 1 2751 2
2755 2757 3 2759
275a 275b 2 276a
276f 2 2780 2782
3 277e 277f 2784
2 278d 278f 2
2791 2793 2 2795
2797 2 2799 279b
2 279d 279f 3
27a4 27a5 27a6 2
27a1 27a8 2 278c
27aa 1 27ac 1
27ae 2 2777 27af
1 27b3 1 2772
1 27b7 1 27c7
2 27c5 27c7 2
27cc 27cd 1 27d1
2 27cf 27d1 2
280c 2811 2 2822
2824 3 2820 2821
2826 2 282f 2831
2 2833 2835 2
2837 2839 2 283b
283d 2 283f 2841
3 2846 2847 2848
2 2843 284a 2
282e 284c 1 284e
1 2850 2 2819
2851 1 2855 1
2814 1 2859 1
285c 1 285f 15
286b 286c 286d 286e
286f 2870 2871 2872
2873 2874 2875 2876
2877 2878 2879 287a
287b 287c 287d 287e
287f 1 288a 1
2890 2 2892 2893
1 289b 2 2897
289b 1 28a0 1
28a2 2 28a5 28a6
1 28aa 2 28a8
28aa 2 28af 28b0
1 28ba 2 28b9
28ba 1 28c2 1
28c8 2 28ca 28cb
2 28b7 28cc 2
28dd 28df 3 28db
28dc 28e1 2 28ea
28ec 2 28ee 28f0
2 28f2 28f4 2
28f6 28f8 2 28fa
28fc 3 2901 2902
2903 2 28fe 2905
2 28e9 2907 1
2909 1 290b 2
28d4 290c 1 2910
1 28cf 1 2914
1 291f 2 291e
291f 1 2927 1
292d 2 292f 2930
2 291c 2931 2
2942 2944 3 2940
2941 2946 2 294f
2951 2 2953 2955
2 2957 2959 2
295b 295d 2 295f
2961 3 2966 2967
2968 2 2963 296a
2 294e 296c 1
296e 1 2970 2
2939 2971 1 2975
1 2934 1 2979
1 2984 2 2983
2984 1 298c 1
2992 2 2994 2995
2 2981 2996 2
29a7 29a9 3 29a5
29a6 29ab 2 29b4
29b6 2 29b8 29ba
2 29bc 29be 2
29c0 29c2 2 29c4
29c6 3 29cb 29cc
29cd 2 29c8 29cf
2 29b3 29d1 1
29d3 1 29d5 2
299e 29d6 1 29da
1 2999 1 29de
1 29eb 2 29ea
29eb 1 29f3 1
29f9 2 29fb 29fc
2 29e8 29fd 2
2a0e 2a10 3 2a0c
2a0d 2a12 2 2a1b
2a1d 2 2a1f 2a21
2 2a23 2a25 2
2a27 2a29 2 2a2b
2a2d 3 2a32 2a33
2a34 2 2a2f 2a36
2 2a1a 2a38 1
2a3a 1 2a3c 2
2a05 2a3d 1 2a41
1 2a00 1 2a45
1 2a50 2 2a4f
2a50 1 2a58 1
2a5e 2 2a60 2a61
2 2a4d 2a62 2
2a73 2a75 3 2a71
2a72 2a77 2 2a80
2a82 2 2a84 2a86
2 2a88 2a8a 2
2a8c 2a8e 2 2a90
2a92 3 2a97 2a98
2a99 2 2a94 2a9b
2 2a7f 2a9d 1
2a9f 1 2aa1 2
2a6a 2aa2 1 2aa6
1 2a65 1 2aaa
1 2ab5 2 2ab4
2ab5 1 2abd 1
2ac3 2 2ac5 2ac6
2 2ab2 2ac7 2
2ad8 2ada 3 2ad6
2ad7 2adc 2 2ae5
2ae7 2 2ae9 2aeb
2 2aed 2aef 2
2af1 2af3 2 2af5
2af7 3 2afc 2afd
2afe 2 2af9 2b00
2 2ae4 2b02 1
2b04 1 2b06 2
2acf 2b07 1 2b0b
1 2aca 1 2b0f
7 28b3 2917 297c
29e1 2a48 2aad 2b12
1 2b21 2 2b20
2b21 1 2b29 1
2b2f 2 2b31 2b32
2 2b1e 2b33 2
2b44 2b46 3 2b42
2b43 2b48 2 2b51
2b53 2 2b55 2b57
2 2b59 2b5b 2
2b5d 2b5f 2 2b61
2b63 3 2b68 2b69
2b6a 2 2b65 2b6c
2 2b50 2b6e 1
2b70 1 2b72 2
2b3b 2b73 1 2b77
1 2b36 1 2b7b
2 2b8a 2b8f 2
2ba0 2ba2 3 2b9e
2b9f 2ba4 2 2bad
2baf 2 2bb1 2bb3
2 2bb5 2bb7 2
2bb9 2bbb 2 2bbd
2bbf 3 2bc4 2bc5
2bc6 2 2bc1 2bc8
2 2bac 2bca 1
2bcc 1 2bce 2
2b97 2bcf 1 2bd3
1 2b92 1 2bd7
1 2be2 2 2bde
2be2 2 2be7 2be8
1 2bec 2 2bea
2bec 1 2bf1 1
2bf3 2 2c01 2c06
2 2c17 2c19 3
2c15 2c16 2c1b 2
2c24 2c26 2 2c28
2c2a 2 2c2c 2c2e
2 2c30 2c32 2
2c34 2c36 3 2c3b
2c3c 2c3d 2 2c38
2c3f 2 2c23 2c41
1 2c43 1 2c45
2 2c0e 2c46 1
2c4a 1 2c09 1
2c4e 1 2c59 2
2c55 2c59 2 2c5f
2c60 2 2c62 2c65
1 2c6c 2 2c68
2c6c 1 2c7d 2
2c7c 2c7d 1 2c85
1 2c8b 2 2c8d
2c8e 2 2c7a 2c8f
2 2ca0 2ca2 3
2c9e 2c9f 2ca4 2
2cad 2caf 2 2cb1
2cb3 2 2cb5 2cb7
2 2cb9 2cbb 2
2cbd 2cbf 3 2cc4
2cc5 2cc6 2 2cc1
2cc8 2 2cac 2cca
1 2ccc 1 2cce
2 2c97 2ccf 1
2cd3 1 2c92 1
2cd7 2 2c71 2cda
2 2cdf 2ce0 1
2ce6 2 2ce2 2ce6
2 2ced 2cee 4
2ceb 2cf0 2cf3 2cf4
1 2d08 2 2d07
2d08 1 2d10 1
2d16 2 2d18 2d19
2 2d05 2d1a 2
2d2b 2d2d 3 2d29
2d2a 2d2f 2 2d38
2d3a 2 2d3c 2d3e
2 2d40 2d42 2
2d44 2d46 2 2d48
2d4a 3 2d4f 2d50
2d51 2 2d4c 2d53
2 2d37 2d55 1
2d57 1 2d59 2
2d22 2d5a 1 2d5e
1 2d1d 1 2d62
2 2cf7 2d65 1
2d7c 2 2d7b 2d7c
1 2d84 1 2d8a
2 2d8c 2d8d 2
2d79 2d8e 2 2d9f
2da1 3 2d9d 2d9e
2da3 2 2dac 2dae
2 2db0 2db2 2
2db4 2db6 2 2db8
2dba 2 2dbc 2dbe
3 2dc3 2dc4 2dc5
2 2dc0 2dc7 2
2dab 2dc9 1 2dcb
1 2dcd 2 2d96
2dce 1 2dd2 1
2d91 1 2dd6 1
2dd9 3 2ddc 2d68
2ddd 1 2de5 2
2de1 2de5 2 2dea
2deb 1 2def 2
2ded 2def 1 2dfb
2 2dfa 2dfb 1
2e03 1 2e09 2
2e0b 2e0c 2 2df8
2e0d 2 2e1e 2e20
3 2e1c 2e1d 2e22
2 2e2b 2e2d 2
2e2f 2e31 2 2e33
2e35 2 2e37 2e39
2 2e3b 2e3d 3
2e42 2e43 2e44 2
2e3f 2e46 2 2e2a
2e48 1 2e4a 1
2e4c 2 2e15 2e4d
1 2e51 1 2e10
1 2e55 1 2e58
1 2e5b 2 2dde
2e5c 2 2e80 2e85
2 2e96 2e98 3
2e94 2e95 2e9a 2
2ea3 2ea5 2 2ea7
2ea9 2 2eab 2ead
2 2eaf 2eb1 2
2eb3 2eb5 3 2eba
2ebb 2ebc 2 2eb7
2ebe 2 2ea2 2ec0
1 2ec2 1 2ec4
2 2e8d 2ec5 1
2ec9 1 2e88 1
2ecd 1 2ed8 2
2ed4 2ed8 1 2edc
2 2ee8 2ee9 4
2ee6 2eeb 2eee 2eef
1 2ef9 2 2ef8
2ef9 1 2f01 1
2f07 2 2f09 2f0a
2 2ef6 2f0b 2
2f1c 2f1e 3 2f1a
2f1b 2f20 2 2f29
2f2b 2 2f2d 2f2f
2 2f31 2f33 2
2f35 2f37 2 2f39
2f3b 3 2f40 2f41
2f42 2 2f3d 2f44
2 2f28 2f46 1
2f48 1 2f4a 2
2f13 2f4b 1 2f4f
1 2f0e 1 2f53
1 2f66 2 2f65
2f66 1 2f6e 1
2f74 2 2f76 2f77
2 2f63 2f78 2
2f89 2f8b 3 2f87
2f88 2f8d 2 2f96
2f98 2 2f9a 2f9c
2 2f9e 2fa0 2
2fa2 2fa4 2 2fa6
2fa8 3 2fad 2fae
2faf 2 2faa 2fb1
2 2f95 2fb3 1
2fb5 1 2fb7 2
2f80 2fb8 1 2fbc
1 2f7b 1 2fc0
1 2fd0 2 2fcf
2fd0 1 2fd8 1
2fde 2 2fe0 2fe1
2 2fcd 2fe2 2
2ff3 2ff5 3 2ff1
2ff2 2ff7 2 3000
3002 2 3004 3006
2 3008 300a 2
300c 300e 2 3010
3012 3 3017 3018
3019 2 3014 301b
2 2fff 301d 1
301f 1 3021 2
2fea 3022 1 3026
1 2fe5 1 302a
4 2ef2 2f56 2fc3
302d 2 3034 3035
4 3032 3037 303a
303b 1 304a 2
3049 304a 1 3052
1 3058 2 305a
305b 2 3047 305c
2 306d 306f 3
306b 306c 3071 2
307a 307c 2 307e
3080 2 3082 3084
2 3086 3088 2
308a 308c 3 3091
3092 3093 2 308e
3095 2 3079 3097
1 3099 1 309b
2 3064 309c 1
30a0 1 305f 1
30a4 1 30b7 2
30b6 30b7 1 30bf
1 30c5 2 30c7
30c8 2 30b4 30c9
2 30da 30dc 3
30d8 30d9 30de 2
30e7 30e9 2 30eb
30ed 2 30ef 30f1
2 30f3 30f5 2
30f7 30f9 3 30fe
30ff 3100 2 30fb
3102 2 30e6 3104
1 3106 1 3108
2 30d1 3109 1
310d 1 30cc 1
3111 3 303e 30a7
3114 2 3117 3118
2 2ed0 3119 2
311b 311c 2 311f
3120 1 3124 2
3122 3124 2 3128
3129 1 312d 2
312b 312d 1 3131
2 3140 3145 2
3156 3158 3 3154
3155 315a 2 3163
3165 2 3167 3169
2 316b 316d 2
316f 3171 2 3173
3175 3 317a 317b
317c 2 3177 317e
2 3162 3180 1
3182 1 3184 2
314d 3185 1 3189
1 3148 1 318d
1 3198 2 3194
3198 2 319d 319e
1 31a2 2 31a0
31a2 1 31b0 2
31af 31b0 1 31b8
1 31be 2 31c0
31c1 2 31ad 31c2
2 31d3 31d5 3
31d1 31d2 31d7 2
31e0 31e2 2 31e4
31e6 2 31e8 31ea
2 31ec 31ee 2
31f0 31f2 3 31f7
31f8 31f9 2 31f4
31fb 2 31df 31fd
1 31ff 1 3201
2 31ca 3202 1
3206 1 31c5 1
320a 1 320d 1
3217 2 3213 3217
2 321c 321d 1
3221 2 321f 3221
2 3229 322f 2
3240 3242 3 323e
323f 3244 2 324d
324f 2 3251 3253
2 3255 3257 2
3259 325b 2 325d
325f 3 3264 3265
3266 2 3261 3268
2 324c 326a 1
326c 1 326e 2
3237 326f 1 3273
1 3232 1 3277
2 3284 3286 3
3282 3283 3288 2
3291 3293 2 3295
3297 2 3299 329b
1 32a3 2 32a5
32a6 2 329d 32a8
2 32aa 32ac 2
32ae 32b0 2 32b2
32b4 2 32b6 32b8
2 3290 32ba 1
32bc 1 32be 2
32c8 32ca 3 32c6
32c7 32cc 2 32d5
32d7 2 32d4 32d9
1 32db 1 32dd
3 32e4 32e5 32e6
4 327a 32bf 32de
32e8 2 32eb 32ea
2 3190 32ec 1
32ee 1 32f2 a
32fa 32fb 32fc 32fd
32fe 32ff 3300 3301
3302 3303 1 330f
2 330e 330f 1
3317 1 331d 2
331f 3320 2 330c
3321 2 3332 3334
3 3330 3331 3336
2 333f 3341 2
3343 3345 2 3347
3349 2 334b 334d
2 334f 3351 3
3356 3357 3358 2
3353 335a 2 333e
335c 1 335e 1
3360 2 3329 3361
1 3365 1 3324
1 3369 1 3373
2 3371 3373 2
3393 3394 2 3396
3399 1 339e 2
339c 339e 2 33a3
33a4 2 33a9 33aa
1 33ac 2 33a6
33ac 2 33b1 33b2
2 33b7 33b8 1
33ba 2 33b4 33ba
2 33c5 33c6 1
33ca 2 33c8 33ca
1 33f5 2 33f4
33f5 1 33fd 1
3403 2 3405 3406
2 33f2 3407 2
3418 341a 3 3416
3417 341c 2 3425
3427 2 3429 342b
2 342d 342f 2
3431 3433 2 3435
3437 3 343c 343d
343e 2 3439 3440
2 3424 3442 1
3444 1 3446 2
340f 3447 1 344b
1 340a 1 344f
1 3452 1 347f
2 347e 347f 1
3487 1 348d 2
348f 3490 2 347c
3491 2 34a2 34a4
3 34a0 34a1 34a6
2 34af 34b1 2
34b3 34b5 2 34b7
34b9 2 34bb 34bd
2 34bf 34c1 3
34c6 34c7 34c8 2
34c3 34ca 2 34ae
34cc 1 34ce 1
34d0 2 3499 34d1
1 34d5 1 3494
1 34d9 1 34dc
2 34df 34e0 1
34e1 1 3507 2
3506 3507 1 350f
1 3515 2 3517
3518 2 3504 3519
2 352a 352c 3
3528 3529 352e 2
3537 3539 2 353b
353d 2 353f 3541
2 3543 3545 2
3547 3549 3 354e
354f 3550 2 354b
3552 2 3536 3554
1 3556 1 3558
2 3521 3559 1
355d 1 351c 1
3561 1 3564 2
3567 3568 2 356b
356c 1 3570 2
356e 3570 2 3575
3576 1 357a 2
3578 357a 1 3582
2 3586 3587 1
358b 2 3589 358b
2 3590 3591 1
3594 2 3597 3596
2 359e 359f 2
35a3 35a4 2 35a8
35a9 2 35ad 35ae
2 35b2 35b3 2
35b7 35b8 2 35bc
35bd 2 35c1 35c2
d 359b 359c 35a1
35a6 35ab 35b0 35b5
35ba 35bf 35c4 35c5
35c6 35c7 2 35cc
35cd 1 35d3 2
35cf 35d3 2 35d8
35de 2 35ef 35f1
3 35ed 35ee 35f3
2 35fc 35fe 2
3600 3602 2 3604
3606 2 3608 360a
2 360c 360e 3
3613 3614 3615 2
3610 3617 2 35fb
3619 1 361b 1
361d 2 35e6 361e
1 3622 1 35e1
1 3626 2 3633
3635 3 3631 3632
3637 2 3640 3642
2 3644 3646 2
3648 364a 1 3652
2 3654 3655 2
364c 3657 2 363f
3659 1 365b 1
365d 2 3667 3669
3 3665 3666 366b
2 3674 3676 2
3673 3678 1 367a
1 367c 2 3683
3684 4 3629 365e
367d 3686 2 368a
368b 1 368f 2
368d 368f 2 3694
369a 2 36ab 36ad
3 36a9 36aa 36af
2 36b8 36ba 2
36bc 36be 2 36c0
36c2 2 36c4 36c6
2 36c8 36ca 3
36cf 36d0 36d1 2
36cc 36d3 2 36b7
36d5 1 36d7 1
36d9 2 36a2 36da
1 36de 1 369d
1 36e2 2 36ef
36f1 3 36ed 36ee
36f3 2 36fc 36fe
2 3700 3702 2
3704 3706 1 370c
2 370e 370f 2
3708 3711 2 3713
3715 2 3717 3719
2 371b 371d 2
371f 3721 2 36fb
3723 1 3725 1
3727 2 3731 3733
3 372f 3730 3735
2 373e 3740 2
373d 3742 1 3744
1 3746 2 374c
374d 3 374f 3750
3751 4 36e5 3728
3747 3753 2 3756
3755 d 3378 337b
337e 3381 3384 3387
338a 338d 3390 3569
3598 35ca 3757 2
375a 375b 1 375f
2 375d 375f 2
3763 3764 1 3768
2 3766 3768 2
376e 376f 1 3773
2 3771 3773 2
377d 377e 2 377a
3781 1 3783 2
3786 3787 1 378b
2 3789 378b 2
3790 3791 2 3796
3797 1 3799 2
3793 3799 2 37a1
37a2 1 37a5 2
37aa 37ab 2 37b0
37b1 2 37ad 37b3
1 37b5 1 37b8
2 37ba 37bb 2
37be 37bf 1 37c3
2 37c1 37c3 2
37c8 37c9 2 37cb
37cd 1 37d0 2
37d6 37d7 1 37d9
2 37db 37dd 1
37df 1 37e2 2
37e4 37e5 1 3809
2 3808 3809 1
3811 1 3817 2
3819 381a 2 3806
381b 2 382c 382e
3 382a 382b 3830
2 3839 383b 2
383d 383f 2 3841
3843 2 3845 3847
2 3849 384b 3
3850 3851 3852 2
384d 3854 2 3838
3856 1 3858 1
385a 2 3823 385b
1 385f 1 381e
1 3863 4 3784
37bc 37e6 3866 2
3869 386a 2 3876
3877 1 387b 2
3879 387b 2 387f
3880 1 3884 2
3882 3884 2 3888
3889 1 388d 2
388b 388d 1 3899
2 38a0 38a1 2
38a3 38a6 1 38a9
2 38ab 38ac 20
38b6 38b7 38b8 38b9
38ba 38bb 38bc 38bd
38be 38bf 38c0 38c1
38c2 38c3 38c4 38c5
38c6 38c7 38c8 38c9
38ca 38cb 38cc 38cd
38ce 38cf 38d0 38d1
38d2 38d3 38d4 38d5
2 38da 38db 1
38df 2 38dd 38df
2 38e4 38ea 2
38fb 38fd 3 38f9
38fa 38ff 2 3908
390a 2 390c 390e
2 3910 3912 2
3914 3916 2 3918
391a 3 391f 3920
3921 2 391c 3923
2 3907 3925 1
3927 1 3929 2
38f2 392a 1 392e
1 38ed 1 3932
2 393f 3941 3
393d 393e 3943 2
394c 394e 2 3950
3952 2 3954 3956
1 395e 2 3960
3961 2 3958 3963
2 3965 3967 2
3969 396b 2 396d
396f 2 3971 3973
2 394b 3975 1
3977 1 3979 2
3983 3985 3 3981
3982 3987 2 3990
3992 2 398f 3994
1 3996 1 3998
3 399f 39a0 39a1
4 3935 397a 3999
39a3 2 39a7 39a8
1 39ac 2 39aa
39ac 2 39b1 39b7
2 39c8 39ca 3
39c6 39c7 39cc 2
39d5 39d7 2 39d9
39db 2 39dd 39df
2 39e1 39e3 2
39e5 39e7 3 39ec
39ed 39ee 2 39e9
39f0 2 39d4 39f2
1 39f4 1 39f6
2 39bf 39f7 1
39fb 1 39ba 1
39ff 2 3a0c 3a0e
3 3a0a 3a0b 3a10
2 3a19 3a1b 2
3a1d 3a1f 2 3a21
3a23 1 3a2b 2
3a2d 3a2e 2 3a25
3a30 2 3a32 3a34
2 3a36 3a38 2
3a3a 3a3c 2 3a3e
3a40 2 3a18 3a42
1 3a44 1 3a46
2 3a50 3a52 3
3a4e 3a4f 3a54 2
3a5d 3a5f 2 3a5c
3a61 1 3a63 1
3a65 3 3a6c 3a6d
3a6e 4 3a02 3a47
3a66 3a70 2 3a73
3a72 1 3a7f 2
3a7e 3a7f 1 3a87
1 3a8d 2 3a8f
3a90 2 3a7c 3a91
2 3aa2 3aa4 3
3aa0 3aa1 3aa6 2
3aaf 3ab1 2 3ab3
3ab5 2 3ab7 3ab9
2 3abb 3abd 2
3abf 3ac1 3 3ac6
3ac7 3ac8 2 3ac3
3aca 2 3aae 3acc
1 3ace 1 3ad0
2 3a99 3ad1 1
3ad5 1 3a94 1
3ad9 1 3af9 2
3af8 3af9 1 3b01
1 3b07 2 3b09
3b0a 2 3af6 3b0b
2 3b1c 3b1e 3
3b1a 3b1b 3b20 2
3b29 3b2b 2 3b2d
3b2f 2 3b31 3b33
2 3b35 3b37 2
3b39 3b3b 3 3b40
3b41 3b42 2 3b3d
3b44 2 3b28 3b46
1 3b48 1 3b4a
2 3b13 3b4b 1
3b4f 1 3b0e 1
3b53 1 3b66 2
3b65 3b66 1 3b6e
1 3b74 2 3b76
3b77 2 3b63 3b78
2 3b89 3b8b 3
3b87 3b88 3b8d 2
3b96 3b98 2 3b9a
3b9c 2 3b9e 3ba0
2 3ba2 3ba4 2
3ba6 3ba8 3 3bad
3bae 3baf 2 3baa
3bb1 2 3b95 3bb3
1 3bb5 1 3bb7
2 3b80 3bb8 1
3bbc 1 3b7b 1
3bc0 1 3bd3 2
3bd2 3bd3 1 3bdb
1 3be1 2 3be3
3be4 2 3bd0 3be5
2 3bf6 3bf8 3
3bf4 3bf5 3bfa 2
3c03 3c05 2 3c07
3c09 2 3c0b 3c0d
2 3c0f 3c11 2
3c13 3c15 3 3c1a
3c1b 3c1c 2 3c17
3c1e 2 3c02 3c20
1 3c22 1 3c24
2 3bed 3c25 1
3c29 1 3be8 1
3c2d 2 3c34 3c35
2 3c37 3c39 2
3c3f 3c40 2 3c45
3c46 2 3c42 3c48
3 3c51 3c52 3c53
3 3c5c 3c5d 3c5e
1 3c6c 2 3c6b
3c6c 1 3c74 1
3c7a 2 3c7c 3c7d
2 3c69 3c7e 2
3c8f 3c91 3 3c8d
3c8e 3c93 2 3c9c
3c9e 2 3ca0 3ca2
2 3ca4 3ca6 2
3ca8 3caa 2 3cac
3cae 3 3cb3 3cb4
3cb5 2 3cb0 3cb7
2 3c9b 3cb9 1
3cbb 1 3cbd 2
3c86 3cbe 1 3cc2
1 3c81 1 3cc6
2 3ccc 3ccd 1
3cd1 2 3ccf 3cd1
2 3cd6 3cd7 1
3cdb 2 3cd9 3cdb
1 3cf5 2 3cf4
3cf5 1 3cfd 1
3d03 2 3d05 3d06
2 3cf2 3d07 2
3d18 3d1a 3 3d16
3d17 3d1c 2 3d25
3d27 2 3d29 3d2b
2 3d2d 3d2f 2
3d31 3d33 2 3d35
3d37 3 3d3c 3d3d
3d3e 2 3d39 3d40
2 3d24 3d42 1
3d44 1 3d46 2
3d0f 3d47 1 3d4b
1 3d0a 1 3d4f
1 3d52 2 3d57
3d58 1 3d5c 2
3d5a 3d5c 1 3d6f
2 3d6e 3d6f 1
3d77 1 3d7d 2
3d7f 3d80 2 3d6c
3d81 2 3d92 3d94
3 3d90 3d91 3d96
2 3d9f 3da1 2
3da3 3da5 2 3da7
3da9 2 3dab 3dad
2 3daf 3db1 3
3db6 3db7 3db8 2
3db3 3dba 2 3d9e
3dbc 1 3dbe 1
3dc0 2 3d89 3dc1
1 3dc5 1 3d84
1 3dc9 2 3dd0
3dd1 2 3dcc 3dd4
2 3dd9 3dda 1
3dde 2 3ddc 3dde
1 3df1 2 3df0
3df1 1 3df9 1
3dff 2 3e01 3e02
2 3dee 3e03 2
3e14 3e16 3 3e12
3e13 3e18 2 3e21
3e23 2 3e25 3e27
2 3e29 3e2b 2
3e2d 3e2f 2 3e31
3e33 3 3e38 3e39
3e3a 2 3e35 3e3c
2 3e20 3e3e 1
3e40 1 3e42 2
3e0b 3e43 1 3e47
1 3e06 1 3e4b
2 3e52 3e53 2
3e4e 3e56 1 3e65
2 3e64 3e65 1
3e6d 1 3e73 2
3e75 3e76 2 3e62
3e77 2 3e88 3e8a
3 3e86 3e87 3e8c
2 3e95 3e97 2
3e99 3e9b 2 3e9d
3e9f 2 3ea1 3ea3
2 3ea5 3ea7 3
3eac 3ead 3eae 2
3ea9 3eb0 2 3e94
3eb2 1 3eb4 1
3eb6 2 3e7f 3eb7
1 3ebb 1 3e7a
1 3ebf 2 3ec6
3ec7 2 3ecd 3ece
3 3ec2 3eca 3ed1
4 3ed3 3dd7 3e58
3ed4 1a 32ef 32f5
3306 336c 3370 386b
386e 3871 3874 38ad
38b0 38b3 38d8 3a74
3adc 3b56 3bc3 3c30
3c3c 3c4b 3c4e 3c56
3c59 3c61 3cc9 3ed5
1 3ed7 4 2bf4
2c51 311d 3ed8 1
3eda 3 2b7e 2bda
3edb 2 3edd 3ede
3 3ee4 3ee5 3ee6
5 2880 2894 28a3
3edf 3ee9 2 3eef
3ef5 2 3f06 3f08
3 3f04 3f05 3f0a
2 3f13 3f15 2
3f17 3f19 2 3f1b
3f1d 2 3f1f 3f21
2 3f23 3f25 3
3f2a 3f2b 3f2c 2
3f27 3f2e 2 3f12
3f30 1 3f32 1
3f34 2 3efd 3f35
1 3f39 1 3ef8
1 3f3d 2 3f46
3f47 1 3f4b 2
3f49 3f4b 2 3f52
3f53 2 3f58 3f59
1 3f5b 2 3f55
3f5b 2 3f60 3f61
2 3f66 3f67 2
3f63 3f69 2 3f6e
3f6f 1 3f73 2
3f71 3f73 2 3f78
3f79 1 3f7d 2
3f7b 3f7d 1 3f83
2 3fa4 3fa5 1
3fa9 2 3fa7 3fa9
2 3fad 3fae 1
3fb2 2 3fb0 3fb2
1 3fb9 2 3fbd
3fbe 1 3fc2 2
3fc0 3fc2 2 3fc7
3fc8 1 3fcb 2
3fce 3fcd 2 3fd5
3fd6 2 3fda 3fdb
2 3fdf 3fe0 2
3fe4 3fe5 2 3fe9
3fea 2 3fee 3fef
2 3ff3 3ff4 2
3ff8 3ff9 d 3fd2
3fd3 3fd8 3fdd 3fe2
3fe7 3fec 3ff1 3ff6
3ffb 3ffc 3ffd 3ffe
2 4003 4004 1
400a 2 4006 400a
2 4015 4017 3
4013 4014 4019 2
4022 4024 2 4026
4028 2 402a 402c
1 4034 2 4036
4037 2 402e 4039
2 4021 403b 1
403d 1 403f 2
4049 404b 3 4047
4048 404d 2 4056
4058 2 4055 405a
1 405c 1 405e
2 4065 4066 3
4040 405f 4068 2
406c 406d 1 4071
2 406f 4071 2
407c 407e 3 407a
407b 4080 2 4089
408b 2 408d 408f
2 4091 4093 1
4099 2 409b 409c
2 4095 409e 2
40a0 40a2 2 40a4
40a6 2 40a8 40aa
2 40ac 40ae 2
4088 40b0 1 40b2
1 40b4 2 40be
40c0 3 40bc 40bd
40c2 2 40cb 40cd
2 40ca 40cf 1
40d1 1 40d3 2
40d9 40da 3 40dc
40dd 40de 3 40b5
40d4 40e0 2 40e3
40e2 1 40fc 2
40fb 40fc 1 4104
1 410a 2 410c
410d 2 40f9 410e
2 411f 4121 3
411d 411e 4123 2
412c 412e 2 4130
4132 2 4134 4136
2 4138 413a 2
413c 413e 3 4143
4144 4145 2 4140
4147 2 412b 4149
1 414b 1 414d
2 4116 414e 1
4152 1 4111 1
4156 2 416b 416c
1 4170 2 416e
4170 2 4174 4175
1 4179 2 4177
4179 2 417d 417e
1 4182 2 4180
4182 2 418b 418c
1 4190 2 418e
4190 2 4194 4195
1 4199 2 4197
4199 2 419f 41a0
1 41a4 2 41a2
41a4 2 41ae 41af
2 41ab 41b2 1
41b4 2 41bb 41bc
2 41be 41c1 3
41b5 41c4 41c7 1
41cb 2 41cd 41ce
20 41d5 41d6 41d7
41d8 41d9 41da 41db
41dc 41dd 41de 41df
41e0 41e1 41e2 41e3
41e4 41e5 41e6 41e7
41e8 41e9 41ea 41eb
41ec 41ed 41ee 41ef
41f0 41f1 41f2 41f3
41f4 2 41f9 41fa
1 41fe 2 41fc
41fe 2 4209 420b
3 4207 4208 420d
2 4216 4218 2
421a 421c 2 421e
4220 1 4228 2
422a 422b 2 4222
422d 2 422f 4231
2 4233 4235 2
4237 4239 2 423b
423d 2 4215 423f
1 4241 1 4243
2 424d 424f 3
424b 424c 4251 2
425a 425c 2 4259
425e 1 4260 1
4262 3 4269 426a
426b 3 4244 4263
426d 2 4271 4272
1 4276 2 4274
4276 2 4281 4283
3 427f 4280 4285
2 428e 4290 2
4292 4294 2 4296
4298 1 42a0 2
42a2 42a3 2 429a
42a5 2 42a7 42a9
2 42ab 42ad 2
42af 42b1 2 42b3
42b5 2 428d 42b7
1 42b9 1 42bb
2 42c5 42c7 3
42c3 42c4 42c9 2
42d2 42d4 2 42d1
42d6 1 42d8 1
42da 3 42e1 42e2
42e3 3 42bc 42db
42e5 1 4307 2
4306 4307 1 430f
1 4315 2 4317
4318 2 4304 4319
2 432a 432c 3
4328 4329 432e 2
4337 4339 2 433b
433d 2 433f 4341
2 4343 4345 2
4347 4349 3 434e
434f 4350 2 434b
4352 2 4336 4354
1 4356 1 4358
2 4321 4359 1
435d 1 431c 1
4361 1 4364 3
4367 42e7 4368 17
3f8d 3f90 3f93 3f96
3f99 3f9c 3f9f 3fa2
3fcf 4001 40e4 40e9
40ee 4159 415d 4160
4163 4166 4169 41cf
41d2 41f7 4369 1
436b 2 3f6c 436c
1 436e 2 4378
437d 2 438e 4390
3 438c 438d 4392
2 439b 439d 2
439f 43a1 2 43a3
43a5 2 43a7 43a9
2 43ab 43ad 3
43b2 43b3 43b4 2
43af 43b6 2 439a
43b8 1 43ba 1
43bc 2 4385 43bd
1 43c1 1 4380
1 43c5 2 43cb
43cc 1 43d0 2
43ce 43d0 1 43df
2 43de 43df 1
43e7 1 43ed 2
43ef 43f0 2 43dc
43f1 2 4402 4404
3 4400 4401 4406
2 440f 4411 2
4413 4415 2 4417
4419 2 441b 441d
2 441f 4421 3
4426 4427 4428 2
4423 442a 2 440e
442c 1 442e 1
4430 2 43f9 4431
1 4435 1 43f4
1 4439 1 443c
1 443f 4 3f50
436f 43c8 4440 1
4442 1 4447 1
4458 2 4457 4458
1 4460 1 4466
2 4468 4469 2
4455 446a 2 447b
447d 3 4479 447a
447f 2 4488 448a
2 448c 448e 2
4490 4492 2 4494
4496 2 4498 449a
3 449f 44a0 44a1
2 449c 44a3 2
4487 44a5 1 44a7
1 44a9 2 4472
44aa 1 44ae 1
446d 1 44b2 2
44b8 44b9 1 44bd
2 44bb 44bd 2
44c7 44cc 2 44dd
44df 3 44db 44dc
44e1 2 44ea 44ec
2 44ee 44f0 2
44f2 44f4 2 44f6
44f8 2 44fa 44fc
3 4501 4502 4503
2 44fe 4505 2
44e9 4507 1 4509
1 450b 2 44d4
450c 1 4510 1
44cf 1 4514 2
451a 451b 1 451f
2 451d 451f 1
452d 2 452c 452d
1 4535 1 453b
2 453d 453e 2
452a 453f 2 4550
4552 3 454e 454f
4554 2 455d 455f
2 4561 4563 2
4565 4567 2 4569
456b 2 456d 456f
3 4574 4575 4576
2 4571 4578 2
455c 457a 1 457c
1 457e 2 4547
457f 1 4583 1
4542 1 4587 1
4594 2 4593 4594
1 459c 1 45a2
2 45a4 45a5 2
4591 45a6 2 45b7
45b9 3 45b5 45b6
45bb 2 45c4 45c6
2 45c8 45ca 2
45cc 45ce 2 45d0
45d2 2 45d4 45d6
3 45db 45dc 45dd
2 45d8 45df 2
45c3 45e1 1 45e3
1 45e5 2 45ae
45e6 1 45ea 1
45a9 1 45ee 2
458a 45f1 1 45f4
2 4517 45f5 1
45f7 2 45fa 45fb
1 45ff 2 45fd
45ff 5 4607 4608
4609 460a 460b 2
4628 462d 2 463e
4640 3 463c 463d
4642 2 464b 464d
2 464f 4651 2
4653 4655 2 4657
4659 2 465b 465d
3 4662 4663 4664
2 465f 4666 2
464a 4668 1 466a
1 466c 2 4635
466d 1 4671 1
4630 1 4675 1
4680 2 467c 4680
2 4685 4686 1
468a 2 4688 468a
1 469f 2 469e
469f 1 46a7 1
46ad 2 46af 46b0
2 469c 46b1 2
46c2 46c4 3 46c0
46c1 46c6 2 46cf
46d1 2 46d3 46d5
2 46d7 46d9 2
46db 46dd 2 46df
46e1 3 46e6 46e7
46e8 2 46e3 46ea
2 46ce 46ec 1
46ee 1 46f0 2
46b9 46f1 1 46f5
1 46b4 1 46f9
1 46fc 1 4713
2 4712 4713 1
471b 1 4721 2
4723 4724 2 4710
4725 2 4736 4738
3 4734 4735 473a
2 4743 4745 2
4747 4749 2 474b
474d 2 474f 4751
2 4753 4755 3
475a 475b 475c 2
4757 475e 2 4742
4760 1 4762 1
4764 2 472d 4765
1 4769 1 4728
1 476d 1 4770
2 4773 4774 3
4777 4778 4779 1
477d 2 477b 477d
a 4788 4789 478a
478b 478c 478d 478e
478f 4790 4791 2
4783 4794 1 4796
2 4775 4797 1
4799 1 479b 2
47a4 47a5 1 47a9
2 47a7 47a9 1
47b1 1 47b3 5
4604 460e 4678 479a
47b4 1 47b6 3
44b5 45f8 47b7 1
47b9 2 47bc 47bd
1 47c1 2 47bf
47c1 1 47c5 2
47ce 47cf 1 47d3
2 47d1 47d3 2
47e0 47e5 2 47f6
47f8 3 47f4 47f5
47fa 2 4803 4805
2 4807 4809 2
480b 480d 2 480f
4811 2 4813 4815
3 481a 481b 481c
2 4817 481e 2
4802 4820 1 4822
1 4824 2 47ed
4825 1 4829 1
47e8 1 482d 2
4833 4834 1 4838
2 4836 4838 1
4847 2 4846 4847
1 484f 1 4855
2 4857 4858 2
4844 4859 2 486a
486c 3 4868 4869
486e 2 4877 4879
2 487b 487d 2
487f 4881 2 4883
4885 2 4887 4889
3 488e 488f 4890
2 488b 4892 2
4876 4894 1 4896
1 4898 2 4861
4899 1 489d 1
485c 1 48a1 1
48b2 2 48b1 48b2
1 48ba 1 48c0
2 48c2 48c3 2
48af 48c4 2 48d5
48d7 3 48d3 48d4
48d9 2 48e2 48e4
2 48e6 48e8 2
48ea 48ec 2 48ee
48f0 2 48f2 48f4
3 48f9 48fa 48fb
2 48f6 48fd 2
48e1 48ff 1 4901
1 4903 2 48cc
4904 1 4908 1
48c7 1 490c 2
48a4 490f 1 4912
2 4830 4913 1
4915 5 491c 491d
491e 491f 4920 2
493d 4942 2 4953
4955 3 4951 4952
4957 2 4960 4962
2 4964 4966 2
4968 496a 2 496c
496e 2 4970 4972
3 4977 4978 4979
2 4974 497b 2
495f 497d 1 497f
1 4981 2 494a
4982 1 4986 1
4945 1 498a 1
4995 2 4991 4995
2 499a 499b 1
499f 2 499d 499f
1 49b4 2 49b3
49b4 1 49bc 1
49c2 2 49c4 49c5
2 49b1 49c6 2
49d7 49d9 3 49d5
49d6 49db 2 49e4
49e6 2 49e8 49ea
2 49ec 49ee 2
49f0 49f2 2 49f4
49f6 3 49fb 49fc
49fd 2 49f8 49ff
2 49e3 4a01 1
4a03 1 4a05 2
49ce 4a06 1 4a0a
1 49c9 1 4a0e
1 4a11 1 4a28
2 4a27 4a28 1
4a30 1 4a36 2
4a38 4a39 2 4a25
4a3a 2 4a4b 4a4d
3 4a49 4a4a 4a4f
2 4a58 4a5a 2
4a5c 4a5e 2 4a60
4a62 2 4a64 4a66
2 4a68 4a6a 3
4a6f 4a70 4a71 2
4a6c 4a73 2 4a57
4a75 1 4a77 1
4a79 2 4a42 4a7a
1 4a7e 1 4a3d
1 4a82 1 4a85
2 4a88 4a89 3
4a8c 4a8d 4a8e 1
4a92 2 4a90 4a92
2 4a97 4a98 1
4a9c 2 4a9a 4a9c
a 4aa9 4aaa 4aab
4aac 4aad 4aae 4aaf
4ab0 4ab1 4ab2 2
4aa4 4ab5 1 4ab7
2 4a8a 4ab8 1
4aba 5 4916 4919
4923 498d 4abb 1
4abd 1 4ac1 1
4ac9 2 4ac7 4ac9
1 4ad0 1 4ad2
2 4adc 4ade 3
4ada 4adb 4ae0 2
4ae9 4aeb 2 4aed
4aef 2 4af1 4af3
1 4afb 2 4afd
4afe 2 4af5 4b00
2 4b02 4b04 2
4b06 4b08 2 4b0a
4b0c 2 4b0e 4b10
2 4ae8 4b12 1
4b14 1 4b16 3
4b1d 4b1e 4b1f 56
459 478 47b 47e
481 484 487 48a
497 4b7 4ba 4bd
4c0 4c3 4c6 4c9
4cc 4cf 4d4 4e7
4ec 540 5ba 61c
697 69a 6f0 76a
7e0 85b 8b3 92e
984 996 a10 a13
a1e a29 a34 d41
d44 d47 d4a d4d
d50 d53 d58 d6b
d80 dd4 1513 1516
1519 151c 1521 1549
15b0 15c1 15c4 15c7
15ca 1622 16a1 2401
2752 275e 2761 2764
27ba 27be 27c1 27c4
2860 2863 2866 3eec
3f40 3f44 4443 4446
47ba 4abe 4ac4 4ad3
4b17 4b21 2 4b2e
4b30 3 4b2c 4b2d
4b32 2 4b3b 4b3d
2 4b3a 4b3f 2
4b46 4b4a 2 4b4c
4b4e 2 4b50 4b54
2 4b45 4b56 2
4b41 4b58 1 4b5a
3 4b5b 4b66 4b6a
1 4b25 2 4b7d
4b7f 3 4b7b 4b7c
4b81 2 4b8a 4b8c
2 4b89 4b8e 2
4b95 4b97 2 4b99
4b9b 3 4ba0 4ba1
4ba2 2 4b9d 4ba4
2 4b94 4ba6 2
4b90 4ba8 1 4baa
4 4b74 4bab 4bb4
4bb8 1 4bbc 1
4b6f 2 4b6d 4bc0
67 4b 52 59
60 67 6e 75
7c 83 8a 91
98 9d a2 a7
ac b3 b8 bd
c4 cb d0 d5
da df e6 ed
f4 fb 102 108
10e 114 11a 120
126 12c 132 138
13e 144 14a 150
156 15c 162 168
16e 174 17a 180
186 18c 192 198
19e 1a4 1aa 1b0
1b6 1bc 1c2 1c8
1ce 1d4 1da 1e0
1e6 1ec 1f2 1f9
200 206 20c 213
219 220 227 22d
233 238 23d 243
249 24f 255 25b
261 267 26d 273
279 27f 286 28d
294 2a2 2a8 2ae
2bb 2cf 347 351

1
4
0 
4bc7
0
1
140
e4
77
0 1 1 1 1 5 1 7
1 9 1 b 1 d 1 f
1 11 1 13 1 15 1 17
1 19 1 1b 1 1d 1 1f
1 21 1 23 1 25 1 27
1 29 1 2b 1 2d 1 2f
1 31 1 33 1 35 1 37
1 39 1 3b 1 3d 1 3f
1 41 1 43 1 45 1 47
1 49 1 4b 1 4d 1 4f
1 51 1 53 1 55 1 57
1 59 1 5b 1 5d 1 5f
1 61 1 63 1 65 1 67
1 69 1 6b 1 6d 1 6f
70 6f 72 6f 74 6f 76 6f
78 6f 7a 6f 7c 6f 7e 6f
80 6f 82 6f 84 6f 86 6f
88 6f 8a 6f 8c 6f 8e 6f
90 6f 92 6f 94 6f 96 6f
98 6f 9a 6f 9c 6f 9e 6f
a0 6f a2 6f a4 6f a6 6f
a8 6f aa 6f ac 6f ae 6f
b0 6f b2 6f b4 6f b6 6f
b8 6f ba 6f bc 6f be 1
c0 1 c2 1 c4 1 c6 1
c8 1 ca 1 cc 1 ce 1
d0 1 d2 1 d4 1 d6 1
d8 1 da 1 dc 1 de 1
e0 1 e2 1 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0

245 1 0
3b 1 0
33 1 0
215 1 0
1ee 1 0
24b 1 0
37 1 0
dc 1 0
164 1 0
208 1 0
182 1 0
116 1 0
9f 1 0
69 1 0
222 1 0
2f 1 0
251 1 0
263 1 0
21b 1 0
70 1 0
27 1 0
1e2 1 0
b 1 0
15e 1 0
77 1 0
23 1 0
1be 1 0
bf 1 0
e1 1 0
19a 1 0
d7 1 0
2a4 1 0
1ac 1 0
5b 1 0
20e 1 0
17c 1 0
1b2 1 0
194 1 0
104 1 0
2d5 1 4
22f 1 0
1d0 1 0
122 1 0
27b 1 0
1b 1 0
140 1 0
2c1 1 3
1fb 1 0
110 1 0
cd 1 0
a4 1 0
2b1 1 2
1f4 1 0
9a 1 0
17 1 0
134 1 0
257 1 0
23f 1 0
4d 1 0
3 1 0
1ca 1 0
26f 1 0
2 0 1
296 1 0
16a 1 0
281 1 0
f6 1 0
23a 1 0
d2 1 0
a9 1 0
229 1 0
128 1 0
25d 1 0
176 1 0
10a 1 0
2b 1 0
28f 1 0
288 1 0
1dc 1 0
7e 1 0
46 1 0
c6 1 0
f 1 0
7 1 0
13a 1 0
12e 1 0
2aa 1 0
188 1 0
152 1 0
1e8 1 0
1c4 1 0
93 1 0
ef 1 0
275 1 0
269 1 0
1b8 1 0
11c 1 0
202 1 0
1a0 1 0
b5 1 0
8c 1 0
85 1 0
170 1 0
62 1 0
18e 1 0
1f 1 0
235 1 0
1d6 1 0
1a6 1 0
ba 1 0
e8 1 0
14c 1 0
54 1 0
fd 1 0
146 1 0
13 1 0
34c 1 0
158 1 0
ae 1 0
0

/
SHOW ERRORS FUNCTION SP_A_RESTOPROF;
ALTER FUNCTION SP_A_RESTOPROF COMPILE DEBUG;
/*
#Stored Procedure  :SP_U_RATES
#Short Description :
#Description       :
#Table Name        :
#Parameters        :
#Returns           :
#Errors            :
*/
Prompt == FUNCTION SP_U_RATES ==
CREATE OR REPLACE FUNCTION SP_U_RATES wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
5c
2 :e:
1FUNCTION:
1SP_U_RATES:
1ID001:
1VARCHAR2:
1REG_COST:
1NUMBER:
1SPEC_COST:
1REG_RATE:
1SPEC_RATE:
1RATE_ADJUSTMENT001:
1PLS_INTEGER:
1RES_ID001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_ID:
132:
1H_RES_ID:
1H_REG_COST:
10:
1H_REG_RATE:
1H_SPEC_COST:
1H_SPEC_RATE:
1H_RATE_ADJUSTMENT:
1H_FLAG:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_U_RATES(:
1':
1, :
1COALESCE:
1TO_CHAR:
1NULL:
1);:
1CHECK_TRACE:
11:
134:
1+:
1FPUT:
1               ENTER:: SP_U_RATES(35) :: cplan.sql(11925) :: :
1IS NULL:
139:
1        RETURN_ERROR:: SP_U_RATES(40) :: cplan.sql(11930) :: :
1 :
1STATE:: :
1PMO_CNST:
1INVALID_PARAMS:
1 ID:: :
142:
1                EXIT:: SP_U_RATES(43) :: cplan.sql(11933) :: :
1PMODEFINES:
1PMO_RETURN_ERROR_SP:
1TRUE:
1SC_STATE:
1FC_U_RATES:
1=:
1100:
14:
166:
1       RETURN_STATUS:: SP_U_RATES(67) :: cplan.sql(11957) :: :
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
116:
173:
1           EXCEPTION:: SP_U_RATES(74) :: cplan.sql(11964) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1ID:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
1OTHERS:
1SQLCODE:
185:
1           EXCEPTION:: SP_U_RATES(86) :: cplan.sql(11976) :: :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
2a9
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 :2 a0
6b 1c 81 b0 :2 a0 6b :2 a0 6b
6e a5 b a 10 :2 a0 6b 6e
:2 a0 6b 6e a5 b 6e 7e a0
b4 2e 6e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :3 a0 a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e :3 a0 a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e :3 a0 a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
:3 a0 a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c a0 7e b4 2e
5a :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b :2 a0 a5 57
b7 19 3c a0 51 d :2 a0 d
:2 a0 d :2 a0 d :2 a0 d :2 a0 d
:2 a0 d :2 a0 d :2 a0 6b :9 a0 a5
b d :2 a0 6b 7e 51 b4 2e
:2 a0 6b 51 d b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
:2 a0 a5 57 b7 :2 a0 6b :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 :2 a0 6b
:2 6e 7e :2 a0 6b b4 2e 7e 6e
b4 2e 7e :2 a0 6b b4 2e a5
57 b7 19 3c :9 a0 12a e9 dd
:2 a0 65 b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c :7 a0 12a e9 dd :2 a0 65
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 68 4f 1d 17 b5 
2a9
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 5e
5a 30 66 6f 6b 59 77 84
80 56 8c 95 91 7f 9d 7c
a2 a6 aa ae b1 b5 d2 bd
c1 c4 c5 cd bc ef dd b9
e1 e2 ea dc 10b fa fe d9
106 f9 127 116 11a f6 122 115
143 132 136 112 13e 131 15f 14e
152 12e 15a 14d 17b 16a 16e 14a
176 169 197 186 18a 166 192 185
1b7 1a2 1a6 182 1aa 1b2 1a1 1be
1c2 19e 1c6 1ca 1ce 1d1 1d6 1d7
1 1d9 1de 1e2 1e6 1e9 1ee 1f2
1f6 1f9 1fe 1ff 201 206 209 20d
20e 213 218 21b 220 221 226 229
22d 22e 233 236 23b 23c 241 244
249 24a 24f 252 256 25a 25e 25f
261 266 267 269 26a 26f 272 277
278 27d 280 284 288 28c 28d 28f
294 295 297 298 29d 2a0 2a5 2a6
2ab 2ae 2b2 2b6 2ba 2bb 2bd 2c2
2c3 2c5 2c6 2cb 2ce 2d3 2d4 2d9
2dc 2e0 2e4 2e8 2e9 2eb 2f0 2f1
2f3 2f4 2f9 2fc 301 302 307 30a
30e 312 316 317 319 31e 31f 321
322 327 32a 32f 330 335 338 33d
33e 343 346 34a 34b 350 353 358
359 35e 361 366 367 36c 36d 372
374 378 37b 37f 383 386 38a 38e
391 394 399 39c 39f 3a2 3a3 3a8
3a9 1 3ab 3b0 3b4 3b8 3bb 3c0
3c5 3c8 3cc 3cd 3d2 3d3 3d8 3da
3de 3e1 3e5 3e8 3e9 3ee 3f1 3f5
3f9 3fc 400 404 407 40a 40f 412
415 418 419 41e 41f 1 421 426
42a 42e 431 436 43b 43e 442 443
448 44b 450 451 456 459 45e 45f
464 467 46b 46f 473 477 47a 47b
47d 482 483 485 486 48b 48e 493
494 499 49c 4a1 4a2 4a7 4aa 4ae
4af 4b4 4b7 4bc 4bd 4c2 4c3 4c8
4ca 4ce 4d1 4d5 4d9 4dc 4e0 4e4
4e7 4ea 4ef 4f2 4f5 4f8 4f9 4fe
4ff 1 501 506 50a 50e 511 516
51b 51e 522 523 528 529 52e 530
534 537 53b 53f 542 546 54a 54d
551 555 556 55b 55d 561 564 568
56b 56f 573 577 57b 57f 583 587
58b 58f 593 597 59b 59f 5a3 5a7
5ab 5af 5b3 5b7 5bb 5bf 5c3 5c7
5cb 5ce 5d2 5d6 5da 5de 5e2 5e6
5ea 5ee 5f2 5f3 5f5 5f9 5fd 601
604 607 60a 60b 610 614 618 61b
61e 622 624 628 62b 62f 633 636
63a 63e 641 644 649 64c 64f 652
653 658 659 1 65b 660 664 668
66b 670 675 678 67c 67d 682 685
68a 68b 690 693 698 699 69e 6a1
6a5 6a9 6ad 6b1 6b4 6b5 6b7 6bc
6bd 6bf 6c0 6c5 6c8 6cd 6ce 6d3
6d6 6db 6dc 6e1 6e4 6e8 6e9 6ee
6f1 6f6 6f7 6fc 6fd 702 704 708
70b 70f 713 716 71a 71e 721 725
729 72a 72f 731 735 739 73c 740
744 747 74b 74f 752 755 75a 75d
760 763 764 769 76a 1 76c 771
775 779 77c 781 786 789 78d 78e
793 794 799 79d 7a1 7a4 7a9 7ae
7b1 7b5 7b9 7bc 7bd 7c2 7c5 7ca
7cb 7d0 7d3 7d7 7db 7de 7df 7e4
7e5 7ea 7ec 7f0 7f3 7f7 7fb 7ff
803 807 80b 80f 813 817 823 828
82c 830 834 838 83a 83b 840 1
844 848 84c 84f 853 857 85b 85f
862 866 86a 86d 870 875 878 87b
87e 87f 884 885 1 887 88c 890
894 897 89c 8a1 8a4 8a8 8a9 8ae
8af 8b4 8b8 8bc 8bf 8c4 8c9 8cc
8d0 8d1 8d6 8d9 8de 8df 8e4 8e7
8eb 8ef 8f2 8f5 8f6 8f8 8f9 8fe
8ff 904 906 90a 90d 911 915 919
91d 921 925 929 935 93a 93e 942
946 94a 94c 950 952 95e 960 962
963 968 96c 96e 97a 97e 980 981
98a 
2a9
2
0 1 a 6 c :3 6 f :3 6
10 :3 6 f :3 6 10 :3 6 19 :3 6
10 :2 6 1 3 a 13 a :2 1
4 9 12 11 :2 9 :2 4 d 16
15 :2 d :2 4 :2 f 19 f :2 4 :2 f
19 f :2 4 :2 10 1a 10 :2 4 :2 10
1a 10 :2 4 :2 16 25 16 :2 4 :2 b
1a b :2 4 e 17 :3 e 4 7
:2 11 23 :2 2d 3a :2 23 :3 7 :2 d 19
25 :2 2f 43 :2 25 52 58 5b :2 52
69 7d 8 :2 69 d 10 :2 69 16
19 :2 69 b e :2 69 13 16 1f
27 :2 1f 32 :2 16 :2 69 b e :2 69
13 16 1f 27 :2 1f 33 :2 16 :2 69
b e :2 69 13 16 1f 27 :2 1f
32 :2 16 :2 69 b e :2 69 13 16
1f 27 :2 1f 33 :2 16 :2 69 b e
:2 69 13 16 1f 27 :2 1f 3c :2 16
:2 69 b e :2 69 13 16 :2 69 1b
1e :2 69 28 2b :2 69 30 33 :2 69
:2 7 48 :2 4 7 :2 11 23 :2 2d 39
3c 4a 4c 4d :2 4a :2 23 :3 7 :2 d
12 1e 5b 5e :2 1e :2 7 50 :2 4
:4 8 7 a :2 14 26 :2 30 3c 40
4e 50 51 :2 4e :2 26 :3 a :2 10 15
21 5e 61 :2 21 6e 71 :2 21 75
78 :2 21 82 85 8e 96 :2 9f :2 8e
b0 :2 85 :2 21 b8 bb :2 21 c3 c6
:2 21 cb ce :2 21 d4 d7 :2 21 :2 a
54 :2 7 a :2 14 26 :2 30 3c 3f
4d 4f 50 :2 4d :2 26 :3 a :2 10 15
21 5e 61 :2 21 :2 a 53 :3 7 :2 12
26 :2 2f 3f 46 :2 7 17 :3 4 e
:2 4 c :2 4 10 :2 4 12 :2 4 13
:2 4 12 :2 4 13 :2 4 19 :2 4 :2 d
19 24 2a 36 43 4f 23 36
40 :2 19 4 7 :2 10 19 1b :2 19
7 :2 10 1c 7 1f :2 4 7 :2 11
23 :2 2d 39 3c 4a 4c 4d :2 4a
:2 23 :3 7 :2 d 12 1e 5b 5e :2 1e
6b 6e :2 1e 72 75 :2 1e 7f 82
8b 93 :2 9c :2 8b a7 :2 82 :2 1e af
b2 :2 1e ba bd :2 1e c2 c5 :2 1e
cb ce :2 1e :2 7 50 :3 4 :2 f 21
:2 2a 34 3b :2 4 1 9 12 9
a :2 14 26 :2 30 3c 40 4e 50
51 :2 4e :2 26 :3 a :2 10 15 21 5e
61 :2 21 :3 a :2 10 15 39 5c 5f
:2 68 :2 39 76 79 :2 39 81 84 :2 8d
:2 39 :2 a 54 :3 7 c 15 1e 2c
a 13 1e f e 7 e 7
e 7 29 :2 4 :2 9 7 :2 10 1c
:2 7 :2 11 23 :2 2d 39 3d 4b 4d
4e :2 4b :2 23 :3 7 :2 d 12 1e 5b
5e :2 1e :3 7 :2 d 12 36 42 45
:2 36 4d 50 :2 36 5c 5f 66 6f
72 :2 5f :2 36 :2 7 51 :2 4 7 c
1b a 13 1e f e 7 e
7 e 7 :2 4 :4 10 :2 4 :8 1 
2a9
4
0 :2 1 :4 3 :4 4
:4 5 :4 6 :4 7 :4 8
:4 9 2 :4 a :2 1
:7 c :7 d :6 e :6 f
:6 10 :6 11 :6 12 :6 13
:7 15 :b 17 :11 18 19
:2 18 :2 19 :2 18 :2 19
:2 18 :2 1a :2 18 :9 1a
:2 18 :2 1b :2 18 :9 1b
:2 18 :2 1c :2 18 :9 1c
:2 18 :2 1d :2 18 :9 1d
:2 18 :2 1e :2 18 :9 1e
:2 18 :2 1f :2 18 :2 1f
:2 18 :2 1f :2 18 :2 1f
:2 18 :2 1f :4 18 :3 17
:11 22 :b 23 :3 22 :5 26
:11 27 :30 28 :3 27 :11 2a
:b 2b :3 2a :a 2d :3 26
:3 30 :3 33 :3 34 :3 35
:3 36 :3 37 :3 38 :3 39
:9 3b :3 3c :3 3b :7 3e
:5 3f :3 3e :11 42 :30 43
:3 42 :a 45 16 :3 48
:11 49 :b 4a :17 4b :3 49
:2 4d :3 4e :3 4f 50
4e 4d 4e :3 51
:3 48 :2 52 :5 54 :11 55
:b 56 :18 57 :3 55 :2 59
5a :3 5b 5c 5a
59 5a :3 5d :2 53
:6 52 47 :7 1 
98c
4
:3 0 1 :3 0 2
:a 0 2a4 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
56 0 7 6
:3 0 5 :7 0 9
8 :3 0 6 :3 0
7 :7 0 d c
:3 0 d 7c 0
b 6 :3 0 8
:7 0 11 10 :3 0
6 :3 0 9 :7 0
15 14 :3 0 11
:2 0 f b :3 0
a :7 0 19 18
:3 0 4 :3 0 c
:7 0 1d 1c :3 0
d :3 0 e :3 0
f :2 0 4 21
22 0 1f 23
0 2a4 2 24
:2 0 11 :2 0 1b
4 :3 0 11 :2 0
19 27 29 :6 0
2c 2a 0 2a2
0 10 :6 0 14
:2 0 1f 4 :3 0
1d 2e 30 :6 0
33 31 0 2a2
0 12 :6 0 14
:2 0 21 6 :3 0
35 :7 0 39 36
37 2a2 0 13
:6 0 14 :2 0 23
6 :3 0 3b :7 0
3f 3c 3d 2a2
0 15 :6 0 14
:2 0 25 6 :3 0
41 :7 0 45 42
43 2a2 0 16
:6 0 14 :2 0 27
6 :3 0 47 :7 0
4b 48 49 2a2
0 17 :6 0 14
:2 0 29 b :3 0
4d :7 0 51 4e
4f 2a2 0 18
:6 0 59 5a 0
2b b :3 0 53
:7 0 57 54 55
2a2 0 19 :6 0
5f 60 0 2d
e :3 0 f :2 0
4 5b :7 0 5e
5c 0 2a2 0
1a :6 0 1b :3 0
1c :3 0 1b :3 0
1d :3 0 62 63
0 2 :4 0 2f
64 66 61 68
67 :2 0 1e :3 0
1f :3 0 6a 6b
0 20 :4 0 1b
:3 0 21 :3 0 6e
6f 0 2 :4 0
31 70 72 22
:4 0 23 :2 0 24
:3 0 33 75 77
:3 0 25 :4 0 23
:2 0 26 :4 0 36
7a 7c :3 0 23
:2 0 3 :3 0 39
7e 80 :3 0 23
:2 0 26 :4 0 3c
82 84 :3 0 23
:2 0 27 :4 0 3f
86 88 :3 0 23
:2 0 28 :3 0 29
:3 0 5 :3 0 42
8c 8e 2a :4 0
44 8b 91 47
8a 93 :3 0 23
:2 0 27 :4 0 4a
95 97 :3 0 23
:2 0 28 :3 0 29
:3 0 7 :3 0 4d
9b 9d 2a :4 0
4f 9a a0 52
99 a2 :3 0 23
:2 0 27 :4 0 55
a4 a6 :3 0 23
:2 0 28 :3 0 29
:3 0 8 :3 0 58
aa ac 2a :4 0
5a a9 af 5d
a8 b1 :3 0 23
:2 0 27 :4 0 60
b3 b5 :3 0 23
:2 0 28 :3 0 29
:3 0 9 :3 0 63
b9 bb 2a :4 0
65 b8 be 68
b7 c0 :3 0 23
:2 0 27 :4 0 6b
c2 c4 :3 0 23
:2 0 28 :3 0 29
:3 0 a :3 0 6e
c8 ca 2a :4 0
70 c7 cd 73
c6 cf :3 0 23
:2 0 27 :4 0 76
d1 d3 :3 0 23
:2 0 26 :4 0 79
d5 d7 :3 0 23
:2 0 c :3 0 7c
d9 db :3 0 23
:2 0 26 :4 0 7f
dd df :3 0 23
:2 0 2b :4 0 82
e1 e3 :3 0 85
6c e5 :2 0 e7
8a e8 69 e7
0 e9 8c 0
202 1b :3 0 1c
:3 0 ea eb 0
1b :3 0 2c :3 0
ed ee 0 2d
:2 0 2 :4 0 2e
:2 0 2f :2 0 2d
:2 0 8e f3 f5
:3 0 91 ef f7
ec f9 f8 :2 0
1e :3 0 30 :3 0
fb fc 0 20
:4 0 31 :4 0 23
:2 0 24 :3 0 95
100 102 :3 0 98
fd 104 :2 0 106
9b 107 fa 106
0 108 9d 0
202 3 :3 0 32
:2 0 9f 10a 10b
:3 0 10c :2 0 1b
:3 0 1c :3 0 10e
10f 0 1b :3 0
2c :3 0 111 112
0 11 :2 0 2
:4 0 33 :2 0 2f
:2 0 2d :2 0 a1
117 119 :3 0 a4
113 11b 110 11d
11c :2 0 1e :3 0
30 :3 0 11f 120
0 20 :4 0 34
:4 0 23 :2 0 24
:3 0 a8 124 126
:3 0 23 :2 0 35
:4 0 ab 128 12a
:3 0 23 :2 0 36
:4 0 ae 12c 12e
:3 0 23 :2 0 28
:3 0 29 :3 0 37
:3 0 38 :3 0 133
134 0 b1 132
136 2a :4 0 b3
131 139 b6 130
13b :3 0 23 :2 0
39 :4 0 b9 13d
13f :3 0 23 :2 0
26 :4 0 bc 141
143 :3 0 23 :2 0
3 :3 0 bf 145
147 :3 0 23 :2 0
26 :4 0 c2 149
14b :3 0 c5 121
14d :2 0 14f c8
150 11e 14f 0
151 ca 0 17b
1b :3 0 1c :3 0
152 153 0 1b
:3 0 2c :3 0 155
156 0 2d :2 0
2 :4 0 3a :2 0
2f :2 0 2d :2 0
cc 15b 15d :3 0
cf 157 15f 154
161 160 :2 0 1e
:3 0 30 :3 0 163
164 0 20 :4 0
3b :4 0 23 :2 0
24 :3 0 d3 168
16a :3 0 d6 165
16c :2 0 16e d9
16f 162 16e 0
170 db 0 17b
3c :3 0 3d :3 0
171 172 0 37
:3 0 38 :3 0 174
175 0 3 :3 0
3e :3 0 dd 173
179 :2 0 17b e1
17c 10d 17b 0
17d e5 0 202
19 :3 0 2d :2 0
17e 17f 0 202
10 :3 0 3 :3 0
181 182 0 202
12 :3 0 c :3 0
184 185 0 202
13 :3 0 5 :3 0
187 188 0 202
16 :3 0 7 :3 0
18a 18b 0 202
15 :3 0 8 :3 0
18d 18e 0 202
17 :3 0 9 :3 0
190 191 0 202
18 :3 0 a :3 0
193 194 0 202
e :3 0 3f :3 0
196 197 0 40
:3 0 10 :3 0 13
:3 0 16 :3 0 15
:3 0 17 :3 0 18
:3 0 12 :3 0 19
:3 0 e7 199 1a2
198 1a3 0 202
e :3 0 3f :3 0
1a5 1a6 0 41
:2 0 42 :2 0 f2
1a8 1aa :3 0 e
:3 0 3f :3 0 1ac
1ad 0 14 :2 0
1ae 1af 0 1b1
f5 1b2 1ab 1b1
0 1b3 f7 0
202 1b :3 0 1c
:3 0 1b4 1b5 0
1b :3 0 2c :3 0
1b7 1b8 0 43
:2 0 2 :4 0 44
:2 0 2f :2 0 2d
:2 0 f9 1bd 1bf
:3 0 fc 1b9 1c1
1b6 1c3 1c2 :2 0
1e :3 0 30 :3 0
1c5 1c6 0 20
:4 0 45 :4 0 23
:2 0 24 :3 0 100
1ca 1cc :3 0 23
:2 0 35 :4 0 103
1ce 1d0 :3 0 23
:2 0 36 :4 0 106
1d2 1d4 :3 0 23
:2 0 28 :3 0 29
:3 0 e :3 0 3f
:3 0 1d9 1da 0
109 1d8 1dc 2a
:4 0 10b 1d7 1df
10e 1d6 1e1 :3 0
23 :2 0 39 :4 0
111 1e3 1e5 :3 0
23 :2 0 26 :4 0
114 1e7 1e9 :3 0
23 :2 0 3 :3 0
117 1eb 1ed :3 0
23 :2 0 26 :4 0
11a 1ef 1f1 :3 0
11d 1c7 1f3 :2 0
1f5 120 1f6 1c4
1f5 0 1f7 122
0 202 3c :3 0
46 :3 0 1f8 1f9
0 e :3 0 3f
:3 0 1fb 1fc 0
3 :3 0 3e :3 0
124 1fa 200 :2 0
202 128 2a3 e
:3 0 47 :2 0 4
203 204 0 1b
:3 0 1c :3 0 206
207 0 1b :3 0
2c :3 0 209 20a
0 48 :2 0 2
:4 0 49 :2 0 2f
:2 0 2d :2 0 138
20f 211 :3 0 13b
20b 213 208 215
214 :2 0 1e :3 0
30 :3 0 217 218
0 20 :4 0 4a
:4 0 23 :2 0 24
:3 0 13f 21c 21e
:3 0 142 219 220
:2 0 239 1e :3 0
30 :3 0 222 223
0 20 :4 0 4b
:4 0 23 :2 0 e
:3 0 4c :3 0 228
229 0 145 227
22b :3 0 23 :2 0
39 :4 0 148 22d
22f :3 0 23 :2 0
e :3 0 4d :3 0
232 233 0 14b
231 235 :3 0 14e
224 237 :2 0 239
151 23a 216 239
0 23b 154 0
24b 4e :3 0 1a
:3 0 e :3 0 4c
:3 0 4f :3 0 e
:3 0 4d :3 0 50
:3 0 51 :4 0 52
1 :a 0 247 :2 0
24b 23d 245 :2 0
d :3 0 1a :3 0
249 :2 0 24b 156
24d 15a 24c 24b
:2 0 2a1 53 :3 0
e :3 0 3f :3 0
250 251 0 54
:3 0 252 253 0
299 1b :3 0 1c
:3 0 255 256 0
1b :3 0 2c :3 0
258 259 0 48
:2 0 2 :4 0 55
:2 0 2f :2 0 2d
:2 0 15c 25e 260
:3 0 15f 25a 262
257 264 263 :2 0
1e :3 0 30 :3 0
266 267 0 20
:4 0 56 :4 0 23
:2 0 24 :3 0 163
26b 26d :3 0 166
268 26f :2 0 289
1e :3 0 30 :3 0
271 272 0 20
:4 0 57 :4 0 23
:2 0 54 :3 0 169
276 278 :3 0 23
:2 0 58 :4 0 16c
27a 27c :3 0 23
:2 0 59 :3 0 5a
:3 0 2d :2 0 5b
:2 0 16f 27f 283
173 27e 285 :3 0
176 273 287 :2 0
289 179 28a 265
289 0 28b 17c
0 299 4e :3 0
1a :3 0 4f :3 0
e :3 0 4d :3 0
50 :3 0 51 :4 0
5c 1 :a 0 295
:2 0 299 28d 293
:2 0 d :3 0 1a
:3 0 297 :2 0 299
17e 29c :3 0 29c
0 29c 29b 299
29a :6 0 29e 1
:3 0 183 2a0 185
29f 29e :2 0 2a1
187 :2 0 2a3 18a
2a3 2a2 202 2a1
:6 0 2a4 :2 0 2
24 2a3 2a7 :3 0
2a6 2a4 2a8 :8 0

194
4
:3 0 1 3 1
7 1 b 1
f 1 13 1
17 1 1b 7
6 a e 12
16 1a 1e 1
28 1 26 1
2f 1 2d 1
34 1 3a 1
40 1 46 1
4c 1 52 1
58 1 65 1
71 2 74 76
2 79 7b 2
7d 7f 2 81
83 2 85 87
1 8d 2 8f
90 2 89 92
2 94 96 1
9c 2 9e 9f
2 98 a1 2
a3 a5 1 ab
2 ad ae 2
a7 b0 2 b2
b4 1 ba 2
bc bd 2 b6
bf 2 c1 c3
1 c9 2 cb
cc 2 c5 ce
2 d0 d2 2
d4 d6 2 d8
da 2 dc de
2 e0 e2 4
6d 73 78 e4
1 e6 1 e8
2 f2 f4 3
f0 f1 f6 2
ff 101 2 fe
103 1 105 1
107 1 109 2
116 118 3 114
115 11a 2 123
125 2 127 129
2 12b 12d 1
135 2 137 138
2 12f 13a 2
13c 13e 2 140
142 2 144 146
2 148 14a 2
122 14c 1 14e
1 150 2 15a
15c 3 158 159
15e 2 167 169
2 166 16b 1
16d 1 16f 3
176 177 178 3
151 170 17a 1
17c 8 19a 19b
19c 19d 19e 19f
1a0 1a1 1 1a9
2 1a7 1a9 1
1b0 1 1b2 2
1bc 1be 3 1ba
1bb 1c0 2 1c9
1cb 2 1cd 1cf
2 1d1 1d3 1
1db 2 1dd 1de
2 1d5 1e0 2
1e2 1e4 2 1e6
1e8 2 1ea 1ec
2 1ee 1f0 2
1c8 1f2 1 1f4
1 1f6 3 1fd
1fe 1ff f e9
108 17d 180 183
186 189 18c 18f
192 195 1a4 1b3
1f7 201 2 20e
210 3 20c 20d
212 2 21b 21d
2 21a 21f 2
226 22a 2 22c
22e 2 230 234
2 225 236 2
221 238 1 23a
3 23b 246 24a
1 205 2 25d
25f 3 25b 25c
261 2 26a 26c
2 269 26e 2
275 277 2 279
27b 3 280 281
282 2 27d 284
2 274 286 2
270 288 1 28a
4 254 28b 294
298 1 29c 1
24f 2 24d 2a0
9 2b 32 38
3e 44 4a 50
56 5d 
1
4
0 
2a7
0
1
14
2
11
0 1 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 
2 0 1
7 1 0
4c 1 0
13 1 0
1b 1 0
40 1 0
3a 1 0
3 1 0
f 1 0
26 1 0
b 1 0
2d 1 0
17 1 0
52 1 0
46 1 0
34 1 0
58 1 0
0

/
SHOW ERRORS FUNCTION SP_U_RATES;
ALTER FUNCTION SP_U_RATES COMPILE DEBUG;
/*
#Stored Procedure  :SP_U_RATES_EDITED
#Short Description :
#Description       :
#Table Name        :
#Parameters        :
#Returns           :
#Errors            :
*/
Prompt == FUNCTION SP_U_RATES_EDITED ==
CREATE OR REPLACE FUNCTION SP_U_RATES_EDITED wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
73
2 :e:
1FUNCTION:
1SP_U_RATES_EDITED:
1ID001:
1VARCHAR2:
1RATES_EDITED001:
1PLS_INTEGER:
1RES_ID001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_ID:
132:
1H_RESOURCE_ID:
1H_REG_COST:
1NUMBER:
10:
1H_SPEC_COST:
1H_REG_RATE:
1H_SPEC_RATE:
1H_FLAG:
1H_OLD_REG_COST:
1H_OLD_REG_SALE:
1H_OLD_SPEC_COST:
1H_OLD_SPEC_RATE:
1H_RATE_ID:
1H_RATE_ADJUSTMENT:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_U_RATES_EDITED(:
1':
1, :
1COALESCE:
1TO_CHAR:
1NULL:
1);:
1CHECK_TRACE:
11:
131:
1+:
1FPUT:
1               ENTER:: SP_U_RATES_EDITED(32) :: cplan.sql(12032) :: :
1REGULAR_COST:
1REGULAR_RATE:
1SPECIAL_COST:
1SPECIAL_RATE:
1RATE_ADJUSTMENT:
1TASK_ASSIGNMENTS:
1TSK_ASSIGNMENT_ID:
1SELECT REGULAR_COST, REGULAR_RATE,:n      SPECIAL_COST, SPECIAL_RATE, RATE_AD+
1JUSTMENT:n      INTO   h_old_reg_cost, h_old_reg_sale ,:n      h_old_spec_cos+
1t,h_old_spec_rate, h_rate_adjustment:n      FROM TASK_ASSIGNMENTS:n      WHER+
1E TSK_ASSIGNMENT_ID = id001:
1SC_STATE:
1SQLCODE:
1OTHERS:
116:
151:
1           EXCEPTION:: SP_U_RATES_EDITED(52) :: cplan.sql(12052) :: :
1 :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1RATE_ID:
1RESOURCES:
1RESOURCE_ID:
1SELECT RATE_ID INTO h_rate_id:n      FROM RESOURCES:n      WHERE RESOURCE_ID +
1= res_id001:
166:
1           EXCEPTION:: SP_U_RATES_EDITED(67) :: cplan.sql(12067) :: :
1REGULAR_SALE:
1SPECIAL_SALE:
1RATES:
1SELECT REGULAR_COST, REGULAR_SALE,:n      SPECIAL_COST, SPECIAL_SALE:n      I+
1NTO   h_reg_cost, h_reg_rate ,:n      h_spec_cost,h_spec_rate:n      FROM RAT+
1ES:n      WHERE RATE_ID = h_rate_id:
184:
1           EXCEPTION:: SP_U_RATES_EDITED(85) :: cplan.sql(12085) :: :
1RATES_EDITED:
1BITAND:
1UPDATE TASK_ASSIGNMENTS:n      SET RATES_EDITED = BITAND(RATES_EDITED,rates_e+
1dited001):n      WHERE TSK_ASSIGNMENT_ID = id001:
1FOUND:
1TRUE:
1=:
1100:
1103:
1           EXCEPTION:: SP_U_RATES_EDITED(104) :: cplan.sql(12104) :: :
1>:
12:
1FC_U_RATES:
14:
1121:
1       RETURN_STATUS:: SP_U_RATES_EDITED(122) :: cplan.sql(12122) :: :
1STATE:: :
1 ID:: :
1PMODEFINES:
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
1128:
1           EXCEPTION:: SP_U_RATES_EDITED(129) :: cplan.sql(12129) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1ID:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
1140:
1           EXCEPTION:: SP_U_RATES_EDITED(141) :: cplan.sql(12141) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
390
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 1c 51 81 b0 a3 :2 a0 6b
1c 81 b0 :2 a0 6b :2 a0 6b 6e
a5 b a 10 :2 a0 6b 6e :2 a0
6b 6e a5 b 6e 7e a0 b4
2e 6e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
d a0 51 d :d a0 12a :2 a0 6b
a0 d b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :5 a0
12a :2 a0 6b a0 d b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :b a0 12a :2 a0 6b a0 d
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :7 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :3 a0 51
a5 b 51 a5 b 5a 7e 51
b4 2e :2 a0 d :2 a0 d b7 19
3c :3 a0 51 a5 b 51 a5 b
5a 7e 51 b4 2e :2 a0 d :2 a0
d b7 19 3c :2 a0 6b :9 a0 a5
b d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b :2 a0 a5 57 b7 :2 a0
6b :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 :2 a0 6b :2 6e 7e :2 a0 6b b4
2e 7e 6e b4 2e 7e :2 a0 6b
b4 2e a5 57 b7 19 3c :9 a0
12a e9 dd :2 a0 65 b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c :7 a0 12a e9
dd :2 a0 65 b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 68 4f
1d 17 b5 
390
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 30
56 5a 5e 62 65 69 86 71
75 78 79 81 70 a3 91 6d
95 96 9e 90 bf ae b2 8d
ba ad db ca ce aa d6 c9
f7 e6 ea c6 f2 e5 113 102
106 e2 10e 101 12f 11e 122 fe
12a 11d 14b 13a 13e 11a 146 139
167 156 15a 136 162 155 183 172
176 152 17e 171 19f 18e 192 16e
19a 18d 1bc 1aa 18a 1ae 1af 1b7
1a9 1d8 1c7 1cb 1a6 1d3 1c6 1f8
1e3 1e7 1c3 1eb 1f3 1e2 1ff 203
1df 207 20b 20f 212 217 218 1
21a 21f 223 227 22a 22f 233 237
23a 23f 240 242 247 24a 24e 24f
254 259 25c 261 262 267 26a 26e
26f 274 277 27c 27d 282 285 28a
28b 290 293 297 29b 29f 2a0 2a2
2a7 2a8 2aa 2ab 2b0 2b3 2b8 2b9
2be 2c1 2c6 2c7 2cc 2cf 2d3 2d4
2d9 2dc 2e1 2e2 2e7 2ea 2ef 2f0
2f5 2f6 2fb 2fd 301 304 308 30c
30f 313 317 31a 31d 322 325 328
32b 32c 331 332 1 334 339 33d
341 344 349 34e 351 355 356 35b
35c 361 363 367 36a 36e 372 376
37a 37d 381 385 389 38d 391 395
399 39d 3a1 3a5 3a9 3ad 3b1 3b5
3c1 3c5 3c9 3cc 3d0 3d4 3d6 1
3da 3de 3e2 3e5 3e9 3ed 3f1 3f5
3f8 3fc 400 403 406 40b 40e 411
414 415 41a 41b 1 41d 422 426
42a 42d 432 437 43a 43e 43f 444
447 44c 44d 452 455 45a 45b 460
463 467 468 46d 470 475 476 47b
47e 482 486 489 48c 48d 48f 490
495 496 49b 49d 4a1 4a4 4a6 4aa
4ac 4b8 4ba 4bc 4bd 4c2 4c6 4c8
4d4 4d6 4da 4de 4e2 4e6 4ea 4f6
4fa 4fe 501 505 509 50b 1 50f
513 517 51a 51e 522 526 52a 52d
531 535 538 53b 540 543 546 549
54a 54f 550 1 552 557 55b 55f
562 567 56c 56f 573 574 579 57c
581 582 587 58a 58f 590 595 598
59c 59d 5a2 5a5 5aa 5ab 5b0 5b3
5b7 5bb 5be 5c1 5c2 5c4 5c5 5ca
5cb 5d0 5d2 5d6 5d9 5db 5df 5e1
5ed 5ef 5f1 5f2 5f7 5fb 5fd 609
60b 60f 613 617 61b 61f 623 627
62b 62f 633 637 643 647 64b 64e
652 656 658 1 65c 660 664 667
66b 66f 673 677 67a 67e 682 685
688 68d 690 693 696 697 69c 69d
1 69f 6a4 6a8 6ac 6af 6b4 6b9
6bc 6c0 6c1 6c6 6c9 6ce 6cf 6d4
6d7 6dc 6dd 6e2 6e5 6e9 6ea 6ef
6f2 6f7 6f8 6fd 700 704 708 70b
70e 70f 711 712 717 718 71d 71f
723 726 728 72c 72e 73a 73c 73e
73f 744 748 74a 756 758 75c 760
764 768 76c 770 774 780 784 789
78d 790 791 796 79a 79e 7a1 7a4
7a8 7aa 7ae 7b2 7b5 7b8 7bc 7be
7c2 7c6 7c9 7cb 1 7cf 7d3 7d7
7da 7de 7e2 7e6 7ea 7ed 7f1 7f5
7f8 7fb 800 803 806 809 80a 80f
810 1 812 817 81b 81f 822 827
82c 82f 833 834 839 83c 841 842
847 84a 84f 850 855 858 85c 85d
862 865 86a 86b 870 873 877 87b
87e 881 882 884 885 88a 88b 890
892 896 899 89b 89f 8a1 8ad 8af
8b1 8b2 8b7 8bb 8bd 8c9 8cb 8cf
8d3 8d7 8da 8db 8dd 8e0 8e1 8e3
8e6 8e9 8ec 8ed 8f2 8f6 8fa 8fe
902 906 90a 90c 910 913 917 91b
91f 922 923 925 928 929 92b 92e
931 934 935 93a 93e 942 946 94a
94e 952 954 958 95b 95f 963 966
96a 96e 972 976 97a 97e 982 986
98a 98b 98d 991 995 999 99c 9a0
9a4 9a7 9aa 9af 9b2 9b5 9b8 9b9
9be 9bf 1 9c1 9c6 9ca 9ce 9d1
9d6 9db 9de 9e2 9e3 9e8 9eb 9f0
9f1 9f6 9f9 9fe 9ff a04 a07 a0b
a0f a13 a17 a1a a1b a1d a22 a23
a25 a26 a2b a2e a33 a34 a39 a3c
a41 a42 a47 a4a a4e a4f a54 a57
a5c a5d a62 a63 a68 a6a a6e a71
a75 a79 a7c a80 a84 a87 a8b a8f
a90 a95 a97 a9b a9f aa2 aa6 aaa
aad ab1 ab5 ab8 abb ac0 ac3 ac6
ac9 aca acf ad0 1 ad2 ad7 adb
adf ae2 ae7 aec aef af3 af4 af9
afa aff b03 b07 b0a b0f b14 b17
b1b b1f b22 b23 b28 b2b b30 b31
b36 b39 b3d b41 b44 b45 b4a b4b
b50 b52 b56 b59 b5d b61 b65 b69
b6d b71 b75 b79 b7d b89 b8e b92
b96 b9a b9e ba0 ba1 ba6 1 baa
bae bb2 bb5 bb9 bbd bc1 bc5 bc8
bcc bd0 bd3 bd6 bdb bde be1 be4
be5 bea beb 1 bed bf2 bf6 bfa
bfd c02 c07 c0a c0e c0f c14 c15
c1a c1e c22 c25 c2a c2f c32 c36
c37 c3c c3f c44 c45 c4a c4d c51
c55 c58 c5b c5c c5e c5f c64 c65
c6a c6c c70 c73 c77 c7b c7f c83
c87 c8b c8f c9b ca0 ca4 ca8 cac
cb0 cb2 cb6 cb8 cc4 cc6 cc8 cc9
cce cd2 cd4 ce0 ce4 ce6 ce7 cf0 
390
2
0 1 a 6 c :3 6 16 :3 6
10 :2 6 1 3 a 13 a :2 1
4 9 12 11 :2 9 :2 4 12 1b
1a :2 12 :2 4 :2 f 19 f :2 4 :2 10
1a 10 :2 4 :2 f 19 f :2 4 :2 10
1a 10 :2 4 :2 b 1a b :2 4 :2 13
1d 13 :2 4 :2 13 1d 13 :2 4 :2 14
1e 14 :2 4 :2 14 1e 14 :2 4 e
17 16 :2 e :2 4 :2 16 25 16 :2 4
e 17 :3 e 4 7 :2 11 23 :2 2d
3a :2 23 :3 7 :2 d 19 25 :2 2f 43
:2 25 59 5f 62 :2 59 70 8b 8
:2 70 d 10 :2 70 16 19 :2 70 b
e :2 70 13 16 1f 27 :2 1f 39
:2 16 :2 70 b e :2 70 13 16 :2 70
1b 1e :2 70 28 2b :2 70 30 33
:2 70 :2 7 4f :2 4 7 :2 11 23 :2 2d
39 3c 51 53 54 :2 51 :2 23 :3 7
:2 d 12 1e 62 65 :2 1e :2 7 57
:3 4 15 :2 4 e 4 e 1c 7
15 23 e 1e 7 17 28 c
d 21 :2 7 :2 10 1c 7 4 :2 c
a :2 13 1f a d :2 17 29 :2 33
3f 43 58 5a 5b :2 58 :2 29 :3 d
:2 13 18 24 68 6b :2 24 78 7b
:2 24 7f 82 :2 24 8e 91 :2 24 99
9c :2 24 a8 ab b2 bb be :2 ab
:2 24 :2 d 5e :2 a :2 7 :4 13 :2 7 4
:3 1 e 1b c d 1b :2 7 :2 10
1c 7 4 :2 c a :2 13 1f a
d :2 17 29 :2 33 3f 43 58 5a
5b :2 58 :2 29 :3 d :2 13 18 24 68
6b :2 24 78 7b :2 24 7f 82 :2 24
8e 91 :2 24 99 9c :2 24 a8 ab
b2 bb be :2 ab :2 24 :2 d 5e :2 a
:2 7 :4 13 :2 7 4 :3 1 e 1c 7
15 e 1a 7 13 c d 17
:2 7 :2 10 1c 7 4 :2 c a :2 13
1f a d :2 17 29 :2 33 3f 43
58 5a 5b :2 58 :2 29 :3 d :2 13 18
24 68 6b :2 24 78 7b :2 24 7f
82 :2 24 8e 91 :2 24 99 9c :2 24
a8 ab b2 bb be :2 ab :2 24 :2 d
5e :2 a :2 7 :4 13 :2 7 4 :3 1 e
b 1a 21 2e d 21 7 e
a 16 :3 14 a :2 13 1f a 1b
a :2 13 1f a :4 7 4 :2 c a
:2 13 1f a d :2 17 29 :2 33 3f
43 58 5b 5c :2 58 :2 29 :3 d :2 13
18 24 69 6c :2 24 79 7c :2 24
80 83 :2 24 8f 92 :2 24 9a 9d
:2 24 a9 ac b3 bc bf :2 ac :2 24
:2 d 5f :2 a :2 7 :4 13 :2 7 4 :3 1
8 f 18 29 :2 f 2d :2 8 7
31 33 :2 31 7 19 :2 7 1a 7
35 :2 4 8 f 18 29 :2 f 2d
:2 8 7 31 33 :2 31 7 19 :2 7
1a 7 35 :3 4 :2 d 19 24 2a
3a 4b 23 34 47 56 :2 19 4
7 :2 11 23 :2 2d 39 3c 51 54
55 :2 51 :2 23 :3 7 :2 d 12 1e 63
66 :2 1e 73 76 :2 1e 7a 7d :2 1e
87 8a 93 9b :2 a4 :2 93 af :2 8a
:2 1e b7 ba :2 1e c2 c5 :2 1e ca
cd :2 1e d3 d6 :2 1e :2 7 58 :3 4
:2 f 21 :2 2a 34 3b :2 4 1 9
12 9 a :2 14 26 :2 30 3c 40
55 58 59 :2 55 :2 26 :3 a :2 10 15
21 66 69 :2 21 :3 a :2 10 15 39
5c 5f :2 68 :2 39 76 79 :2 39 81
84 :2 8d :2 39 :2 a 5c :3 7 c 15
1e 2c a 13 1e f e 7
e 7 e 7 29 :2 4 :2 9 7
:2 10 1c :2 7 :2 11 23 :2 2d 39 3d
52 55 56 :2 52 :2 23 :3 7 :2 d 12
1e 63 66 :2 1e :3 7 :2 d 12 36
42 45 :2 36 4d 50 :2 36 5c 5f
66 6f 72 :2 5f :2 36 :2 7 59 :2 4
7 c 1b a 13 1e f e
7 e 7 e 7 :2 4 :4 10 :2 4
:8 1 
390
4
0 :2 1 :4 3 :4 4
:4 5 2 :4 6 :2 1
:7 8 :7 9 :6 a :6 b
:6 c :6 d :6 e :6 f
:6 10 :6 11 :6 12 :7 13
:6 14 :7 16 :b 18 :11 19
1a :2 19 :2 1a :2 19
:2 1a :2 19 :2 1b :2 19
:9 1b :2 19 :2 1c :2 19
:2 1c :2 19 :2 1c :2 19
:2 1c :2 19 :2 1c :4 19
:3 18 :11 1f :b 20 :3 1f
:3 23 :3 25 :2 28 :3 29
:2 2a :3 2b 2c :2 2d
28 :5 2e 27 :2 30
:5 32 :11 33 :24 34 :3 33
:2 31 :6 30 2f :3 17
:2 3a 3b :2 3c 3a
:5 3d 39 :2 3f :5 41
:11 42 :24 43 :3 42 :2 40
:6 3f 3e :3 17 :2 49
:2 4a :2 4b :2 4c 4d
:2 4e 49 :5 4f 48
:2 51 :5 53 :11 54 :24 55
:3 54 :2 52 :6 51 50
:3 17 5b :4 5c :2 5d
5b :6 5e :5 5f 5e
:5 61 60 :3 5e 5a
:2 64 :5 66 :11 67 :24 68
:3 67 :2 65 :6 64 63
:3 17 :e 6d :3 6e :3 6f
:3 6d :e 71 :3 72 :3 73
:3 71 :8 76 :4 77 :3 76
:11 79 :30 7a :3 79 :a 7c
17 :3 7f :11 80 :b 81
:17 82 :3 80 :2 84 :3 85
:3 86 87 85 84
85 :3 88 :3 7f :2 89
:5 8b :11 8c :b 8d :18 8e
:3 8c :2 90 91 :3 92
93 91 90 91
:3 94 :2 8a :6 89 7e
:7 1 
cf2
4
:3 0 1 :3 0 2
:a 0 38b 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
:2 0 7 6 :3 0
5 :7 0 9 8
:3 0 4 :3 0 7
:7 0 d c :3 0
8 :3 0 9 :3 0
a :2 0 4 11
12 0 f 13
0 38b 2 14
:2 0 c :2 0 f
4 :3 0 c :2 0
d 17 19 :6 0
1c 1a 0 389
0 b :6 0 10
:2 0 13 4 :3 0
11 1e 20 :6 0
23 21 0 389
0 d :6 0 10
:2 0 15 f :3 0
25 :7 0 29 26
27 389 0 e
:6 0 10 :2 0 17
f :3 0 2b :7 0
2f 2c 2d 389
0 11 :6 0 10
:2 0 19 f :3 0
31 :7 0 35 32
33 389 0 12
:6 0 10 :2 0 1b
f :3 0 37 :7 0
3b 38 39 389
0 13 :6 0 10
:2 0 1d 6 :3 0
3d :7 0 41 3e
3f 389 0 14
:6 0 10 :2 0 1f
f :3 0 43 :7 0
47 44 45 389
0 15 :6 0 10
:2 0 21 f :3 0
49 :7 0 4d 4a
4b 389 0 16
:6 0 10 :2 0 23
f :3 0 4f :7 0
53 50 51 389
0 17 :6 0 c
:2 0 25 f :3 0
55 :7 0 59 56
57 389 0 18
:6 0 10 :2 0 29
4 :3 0 27 5b
5d :6 0 60 5e
0 389 0 19
:6 0 68 69 0
2b 6 :3 0 62
:7 0 66 63 64
389 0 1a :6 0
6e 6f 0 2d
9 :3 0 a :2 0
4 6a :7 0 6d
6b 0 389 0
1b :6 0 1c :3 0
1d :3 0 1c :3 0
1e :3 0 71 72
0 2 :4 0 2f
73 75 70 77
76 :2 0 1f :3 0
20 :3 0 79 7a
0 21 :4 0 1c
:3 0 22 :3 0 7d
7e 0 2 :4 0
31 7f 81 23
:4 0 24 :2 0 25
:3 0 33 84 86
:3 0 26 :4 0 24
:2 0 27 :4 0 36
89 8b :3 0 24
:2 0 3 :3 0 39
8d 8f :3 0 24
:2 0 27 :4 0 3c
91 93 :3 0 24
:2 0 28 :4 0 3f
95 97 :3 0 24
:2 0 29 :3 0 2a
:3 0 5 :3 0 42
9b 9d 2b :4 0
44 9a a0 47
99 a2 :3 0 24
:2 0 28 :4 0 4a
a4 a6 :3 0 24
:2 0 27 :4 0 4d
a8 aa :3 0 24
:2 0 7 :3 0 50
ac ae :3 0 24
:2 0 27 :4 0 53
b0 b2 :3 0 24
:2 0 2c :4 0 56
b4 b6 :3 0 59
7b b8 :2 0 ba
5e bb 78 ba
0 bc 60 0
2e9 1c :3 0 1d
:3 0 bd be 0
1c :3 0 2d :3 0
c0 c1 0 2e
:2 0 2 :4 0 2f
:2 0 30 :2 0 2e
:2 0 62 c6 c8
:3 0 65 c2 ca
bf cc cb :2 0
1f :3 0 31 :3 0
ce cf 0 21
:4 0 32 :4 0 24
:2 0 25 :3 0 69
d3 d5 :3 0 6c
d0 d7 :2 0 d9
6f da cd d9
0 db 71 0
2e9 d :3 0 7
:3 0 dc dd 0
2e9 14 :3 0 10
:2 0 df e0 0
2e9 33 :3 0 34
:3 0 35 :3 0 36
:3 0 37 :3 0 15
:3 0 16 :3 0 17
:3 0 18 :3 0 1a
:3 0 38 :3 0 39
:3 0 3 :4 0 3a
1 :8 0 f5 9
:3 0 3b :3 0 f0
f1 0 3c :3 0
f2 f3 0 f5
73 13f 3d :3 0
9 :3 0 3b :3 0
f8 f9 0 3c
:3 0 fa fb 0
135 1c :3 0 1d
:3 0 fd fe 0
1c :3 0 2d :3 0
100 101 0 3e
:2 0 2 :4 0 3f
:2 0 30 :2 0 2e
:2 0 76 106 108
:3 0 79 102 10a
ff 10c 10b :2 0
1f :3 0 31 :3 0
10e 10f 0 21
:4 0 40 :4 0 24
:2 0 25 :3 0 7d
113 115 :3 0 24
:2 0 41 :4 0 80
117 119 :3 0 24
:2 0 42 :4 0 83
11b 11d :3 0 24
:2 0 3c :3 0 86
11f 121 :3 0 24
:2 0 43 :4 0 89
123 125 :3 0 24
:2 0 44 :3 0 45
:3 0 2e :2 0 46
:2 0 8c 128 12c
90 127 12e :3 0
93 110 130 :2 0
132 96 133 10d
132 0 134 98
0 135 9a 138
:3 0 138 0 138
137 135 136 :6 0
13a 2 :3 0 9d
13c 9f 13b 13a
:2 0 13d a1 :2 0
13f 0 13f 13e
f5 13d :6 0 2e9
1 :3 0 47 :3 0
19 :3 0 48 :3 0
49 :3 0 7 :4 0
4a 1 :8 0 14c
9 :3 0 3b :3 0
147 148 0 3c
:3 0 149 14a 0
14c a3 196 3d
:3 0 9 :3 0 3b
:3 0 14f 150 0
3c :3 0 151 152
0 18c 1c :3 0
1d :3 0 154 155
0 1c :3 0 2d
:3 0 157 158 0
3e :2 0 2 :4 0
4b :2 0 30 :2 0
2e :2 0 a6 15d
15f :3 0 a9 159
161 156 163 162
:2 0 1f :3 0 31
:3 0 165 166 0
21 :4 0 4c :4 0
24 :2 0 25 :3 0
ad 16a 16c :3 0
24 :2 0 41 :4 0
b0 16e 170 :3 0
24 :2 0 42 :4 0
b3 172 174 :3 0
24 :2 0 3c :3 0
b6 176 178 :3 0
24 :2 0 43 :4 0
b9 17a 17c :3 0
24 :2 0 44 :3 0
45 :3 0 2e :2 0
46 :2 0 bc 17f
183 c0 17e 185
:3 0 c3 167 187
:2 0 189 c6 18a
164 189 0 18b
c8 0 18c ca
18f :3 0 18f 0
18f 18e 18c 18d
:6 0 191 4 :3 0
cd 193 cf 192
191 :2 0 194 d1
:2 0 196 0 196
195 14c 194 :6 0
2e9 1 :3 0 33
:3 0 4d :3 0 35
:3 0 4e :3 0 e
:3 0 12 :3 0 11
:3 0 13 :3 0 4f
:3 0 47 :3 0 19
:4 0 50 1 :8 0
1a9 9 :3 0 3b
:3 0 1a4 1a5 0
3c :3 0 1a6 1a7
0 1a9 d3 1f3
3d :3 0 9 :3 0
3b :3 0 1ac 1ad
0 3c :3 0 1ae
1af 0 1e9 1c
:3 0 1d :3 0 1b1
1b2 0 1c :3 0
2d :3 0 1b4 1b5
0 3e :2 0 2
:4 0 51 :2 0 30
:2 0 2e :2 0 d6
1ba 1bc :3 0 d9
1b6 1be 1b3 1c0
1bf :2 0 1f :3 0
31 :3 0 1c2 1c3
0 21 :4 0 52
:4 0 24 :2 0 25
:3 0 dd 1c7 1c9
:3 0 24 :2 0 41
:4 0 e0 1cb 1cd
:3 0 24 :2 0 42
:4 0 e3 1cf 1d1
:3 0 24 :2 0 3c
:3 0 e6 1d3 1d5
:3 0 24 :2 0 43
:4 0 e9 1d7 1d9
:3 0 24 :2 0 44
:3 0 45 :3 0 2e
:2 0 46 :2 0 ec
1dc 1e0 f0 1db
1e2 :3 0 f3 1c4
1e4 :2 0 1e6 f6
1e7 1c1 1e6 0
1e8 f8 0 1e9
fa 1ec :3 0 1ec
0 1ec 1eb 1e9
1ea :6 0 1ee 6
:3 0 fd 1f0 ff
1ef 1ee :2 0 1f1
101 :2 0 1f3 0
1f3 1f2 1a9 1f1
:6 0 2e9 1 :3 0
38 :3 0 53 :3 0
54 :3 0 53 :3 0
5 :3 0 39 :3 0
3 :4 0 55 1
:8 0 212 56 :4 0
1fd :3 0 57 :3 0
58 :2 0 105 200
201 :3 0 9 :3 0
3b :3 0 203 204
0 10 :2 0 205
206 0 208 108
20f 9 :3 0 3b
:3 0 209 20a 0
59 :2 0 20b 20c
0 20e 10a 210
202 208 0 211
0 20e 0 211
10c 0 212 10f
25c 3d :3 0 9
:3 0 3b :3 0 215
216 0 3c :3 0
217 218 0 252
1c :3 0 1d :3 0
21a 21b 0 1c
:3 0 2d :3 0 21d
21e 0 3e :2 0
2 :4 0 5a :2 0
30 :2 0 2e :2 0
112 223 225 :3 0
115 21f 227 21c
229 228 :2 0 1f
:3 0 31 :3 0 22b
22c 0 21 :4 0
5b :4 0 24 :2 0
25 :3 0 119 230
232 :3 0 24 :2 0
41 :4 0 11c 234
236 :3 0 24 :2 0
42 :4 0 11f 238
23a :3 0 24 :2 0
3c :3 0 122 23c
23e :3 0 24 :2 0
43 :4 0 125 240
242 :3 0 24 :2 0
44 :3 0 45 :3 0
2e :2 0 46 :2 0
128 245 249 12c
244 24b :3 0 12f
22d 24d :2 0 24f
132 250 22a 24f
0 251 134 0
252 136 255 :3 0
255 0 255 254
252 253 :6 0 257
8 :3 0 139 259
13b 258 257 :2 0
25a 13d :2 0 25c
0 25c 25b 212
25a :6 0 2e9 1
:3 0 54 :3 0 29
:3 0 5 :3 0 10
:2 0 13f 25f 262
2e :2 0 142 25e
265 266 :2 0 5c
:2 0 10 :2 0 147
268 26a :3 0 15
:3 0 e :3 0 26c
26d 0 272 17
:3 0 11 :3 0 26f
270 0 272 14a
273 26b 272 0
274 14d 0 2e9
54 :3 0 29 :3 0
5 :3 0 10 :2 0
14f 276 279 5d
:2 0 152 275 27c
27d :2 0 5c :2 0
10 :2 0 157 27f
281 :3 0 16 :3 0
12 :3 0 283 284
0 289 18 :3 0
13 :3 0 286 287
0 289 15a 28a
282 289 0 28b
15d 0 2e9 9
:3 0 3b :3 0 28c
28d 0 5e :3 0
b :3 0 15 :3 0
17 :3 0 16 :3 0
18 :3 0 1a :3 0
d :3 0 14 :3 0
15f 28f 298 28e
299 0 2e9 1c
:3 0 1d :3 0 29b
29c 0 1c :3 0
2d :3 0 29e 29f
0 5f :2 0 2
:4 0 60 :2 0 30
:2 0 2e :2 0 168
2a4 2a6 :3 0 16b
2a0 2a8 29d 2aa
2a9 :2 0 1f :3 0
31 :3 0 2ac 2ad
0 21 :4 0 61
:4 0 24 :2 0 25
:3 0 16f 2b1 2b3
:3 0 24 :2 0 41
:4 0 172 2b5 2b7
:3 0 24 :2 0 62
:4 0 175 2b9 2bb
:3 0 24 :2 0 29
:3 0 2a :3 0 9
:3 0 3b :3 0 2c0
2c1 0 178 2bf
2c3 2b :4 0 17a
2be 2c6 17d 2bd
2c8 :3 0 24 :2 0
63 :4 0 180 2ca
2cc :3 0 24 :2 0
27 :4 0 183 2ce
2d0 :3 0 24 :2 0
3 :3 0 186 2d2
2d4 :3 0 24 :2 0
27 :4 0 189 2d6
2d8 :3 0 18c 2ae
2da :2 0 2dc 18f
2dd 2ab 2dc 0
2de 191 0 2e9
64 :3 0 65 :3 0
2df 2e0 0 9
:3 0 3b :3 0 2e2
2e3 0 3 :3 0
57 :3 0 193 2e1
2e7 :2 0 2e9 197
38a 9 :3 0 66
:2 0 4 2ea 2eb
0 1c :3 0 1d
:3 0 2ed 2ee 0
1c :3 0 2d :3 0
2f0 2f1 0 3e
:2 0 2 :4 0 67
:2 0 30 :2 0 2e
:2 0 1a5 2f6 2f8
:3 0 1a8 2f2 2fa
2ef 2fc 2fb :2 0
1f :3 0 31 :3 0
2fe 2ff 0 21
:4 0 68 :4 0 24
:2 0 25 :3 0 1ac
303 305 :3 0 1af
300 307 :2 0 320
1f :3 0 31 :3 0
309 30a 0 21
:4 0 69 :4 0 24
:2 0 9 :3 0 6a
:3 0 30f 310 0
1b2 30e 312 :3 0
24 :2 0 63 :4 0
1b5 314 316 :3 0
24 :2 0 9 :3 0
6b :3 0 319 31a
0 1b8 318 31c
:3 0 1bb 30b 31e
:2 0 320 1be 321
2fd 320 0 322
1c1 0 332 6c
:3 0 1b :3 0 9
:3 0 6a :3 0 6d
:3 0 9 :3 0 6b
:3 0 6e :3 0 6f
:4 0 70 1 :a 0
32e :2 0 332 324
32c :2 0 8 :3 0
1b :3 0 330 :2 0
332 1c3 334 1c7
333 332 :2 0 388
3d :3 0 9 :3 0
3b :3 0 337 338
0 3c :3 0 339
33a 0 380 1c
:3 0 1d :3 0 33c
33d 0 1c :3 0
2d :3 0 33f 340
0 3e :2 0 2
:4 0 71 :2 0 30
:2 0 2e :2 0 1c9
345 347 :3 0 1cc
341 349 33e 34b
34a :2 0 1f :3 0
31 :3 0 34d 34e
0 21 :4 0 72
:4 0 24 :2 0 25
:3 0 1d0 352 354
:3 0 1d3 34f 356
:2 0 370 1f :3 0
31 :3 0 358 359
0 21 :4 0 42
:4 0 24 :2 0 3c
:3 0 1d6 35d 35f
:3 0 24 :2 0 43
:4 0 1d9 361 363
:3 0 24 :2 0 44
:3 0 45 :3 0 2e
:2 0 46 :2 0 1dc
366 36a 1e0 365
36c :3 0 1e3 35a
36e :2 0 370 1e6
371 34c 370 0
372 1e9 0 380
6c :3 0 1b :3 0
6d :3 0 9 :3 0
6b :3 0 6e :3 0
6f :4 0 73 1
:a 0 37c :2 0 380
374 37a :2 0 8
:3 0 1b :3 0 37e
:2 0 380 1eb 383
:3 0 383 0 383
382 380 381 :6 0
385 1 :3 0 1f0
387 1f2 386 385
:2 0 388 1f4 :2 0
38a 1f7 38a 389
2e9 388 :6 0 38b
:2 0 2 14 38a
38e :3 0 38d 38b
38f :8 0 
206
4
:3 0 1 3 1
7 1 b 3
6 a e 1
18 1 16 1
1f 1 1d 1
24 1 2a 1
30 1 36 1
3c 1 42 1
48 1 4e 1
54 1 5c 1
5a 1 61 1
67 1 74 1
80 2 83 85
2 88 8a 2
8c 8e 2 90
92 2 94 96
1 9c 2 9e
9f 2 98 a1
2 a3 a5 2
a7 a9 2 ab
ad 2 af b1
2 b3 b5 4
7c 82 87 b7
1 b9 1 bb
2 c5 c7 3
c3 c4 c9 2
d2 d4 2 d1
d6 1 d8 1
da 2 ef f4
2 105 107 3
103 104 109 2
112 114 2 116
118 2 11a 11c
2 11e 120 2
122 124 3 129
12a 12b 2 126
12d 2 111 12f
1 131 1 133
2 fc 134 1
138 1 f7 1
13c 2 146 14b
2 15c 15e 3
15a 15b 160 2
169 16b 2 16d
16f 2 171 173
2 175 177 2
179 17b 3 180
181 182 2 17d
184 2 168 186
1 188 1 18a
2 153 18b 1
18f 1 14e 1
193 2 1a3 1a8
2 1b9 1bb 3
1b7 1b8 1bd 2
1c6 1c8 2 1ca
1cc 2 1ce 1d0
2 1d2 1d4 2
1d6 1d8 3 1dd
1de 1df 2 1da
1e1 2 1c5 1e3
1 1e5 1 1e7
2 1b0 1e8 1
1ec 1 1ab 1
1f0 1 1ff 2
1fe 1ff 1 207
1 20d 2 20f
210 2 1fc 211
2 222 224 3
220 221 226 2
22f 231 2 233
235 2 237 239
2 23b 23d 2
23f 241 3 246
247 248 2 243
24a 2 22e 24c
1 24e 1 250
2 219 251 1
255 1 214 1
259 2 260 261
2 263 264 1
269 2 267 269
2 26e 271 1
273 2 277 278
2 27a 27b 1
280 2 27e 280
2 285 288 1
28a 8 290 291
292 293 294 295
296 297 2 2a3
2a5 3 2a1 2a2
2a7 2 2b0 2b2
2 2b4 2b6 2
2b8 2ba 1 2c2
2 2c4 2c5 2
2bc 2c7 2 2c9
2cb 2 2cd 2cf
2 2d1 2d3 2
2d5 2d7 2 2af
2d9 1 2db 1
2dd 3 2e4 2e5
2e6 d bc db
de e1 13f 196
1f3 25c 274 28b
29a 2de 2e8 2
2f5 2f7 3 2f3
2f4 2f9 2 302
304 2 301 306
2 30d 311 2
313 315 2 317
31b 2 30c 31d
2 308 31f 1
321 3 322 32d
331 1 2ec 2
344 346 3 342
343 348 2 351
353 2 350 355
2 35c 35e 2
360 362 3 367
368 369 2 364
36b 2 35b 36d
2 357 36f 1
371 4 33b 372
37b 37f 1 383
1 336 2 334
387 e 1b 22
28 2e 34 3a
40 46 4c 52
58 5f 65 6c

1
4
0 
38e
0
1
14
a
12
0 1 2 1 4 1 6 1
8 1 0 0 0 0 0 0
0 0 0 0 
42 1 0
61 1 0
5a 1 0
1d 1 0
54 1 0
b 1 0
2a 1 0
30 1 0
2 0 1
48 1 0
3 1 0
4e 1 0
16 1 0
3c 1 0
36 1 0
7 1 0
24 1 0
67 1 0
0

/
SHOW ERRORS FUNCTION SP_U_RATES_EDITED;
ALTER FUNCTION SP_U_RATES_EDITED COMPILE DEBUG;
/*
#Stored Procedure  :SP_U_TIMECODE2
#Short Description :
#Description       :
#Table Name        :
#Parameters        :
#Returns           :
#Errors            :
*/
Prompt == FUNCTION SP_U_TIMECODE2 ==
CREATE OR REPLACE FUNCTION SP_U_TIMECODE2 wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
55
2 :e:
1FUNCTION:
1SP_U_TIMECODE2:
1ASSIGN_ID:
1VARCHAR2:
1ID001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_TEMP_SC_STATE:
1PLS_INTEGER:
10:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_U_TIMECODE2(:
1':
1, :
1);:
1CHECK_TRACE:
11:
117:
1+:
1FPUT:
1               ENTER:: SP_U_TIMECODE2(18) :: cplan.sql(12183) :: :
1IS NULL:
18:
122:
1      RETURN_INVALID:: SP_U_TIMECODE2(23) :: cplan.sql(12188) :: :
1 :
1STATE:: :
1COALESCE:
1TO_CHAR:
1PMO_CNST:
1INVALID_PARAMS:
1NULL:
125:
1                EXIT:: SP_U_TIMECODE2(26) :: cplan.sql(12191) :: :
1PMODEFINES:
1PMO_RETURN_INVALID_SP:
1TRUE:
1TASK_ASSIGNMENTS:
1TIMECODE2_ID:
1TSK_ASSIGNMENT_ID:
1UPDATE TASK_ASSIGNMENTS SET TIMECODE2_ID = id001 WHERE TSK_ASSIGNMENT_ID = as+
1sign_id:
1FOUND:
1=:
1SC_STATE:
1100:
1OTHERS:
1SQLCODE:
116:
143:
1           EXCEPTION:: SP_U_TIMECODE2(44) :: cplan.sql(12209) :: :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
14:
149:
1       RETURN_STATUS:: SP_U_TIMECODE2(50) :: cplan.sql(12215) :: :
1 ID:: :
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
156:
1           EXCEPTION:: SP_U_TIMECODE2(57) :: cplan.sql(12222) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1ID:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
168:
1           EXCEPTION:: SP_U_TIMECODE2(69) :: cplan.sql(12234) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
247
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d b4 :3 a0 6b 2c 6a
a3 a0 1c 51 81 b0 a3 :2 a0
6b 1c 81 b0 :2 a0 6b :2 a0 6b
6e a5 b a 10 :2 a0 6b 6e
:2 a0 6b 6e a5 b 6e 7e a0
b4 2e 6e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c a0 7e b4 2e :2 5a
a0 7e b4 2e :2 5a 52 10 :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b a0 a5 57 b7 19
3c :5 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b :2 a0 a5 57 b7 :2 a0
6b :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 :2 a0 6b :2 6e 7e :2 a0 6b b4
2e 7e 6e b4 2e 7e :2 a0 6b
b4 2e a5 57 b7 19 3c :9 a0
12a e9 dd :2 a0 65 b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c :7 a0 12a e9
dd :2 a0 65 b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 68 4f
1d 17 b5 
247
2
0 3 7 23 1f 1e 2b 38
34 1b 40 33 45 49 4d 30
51 55 71 5d 61 69 6c 5c
91 7c 80 59 84 8c 7b 98
9c 78 a0 a4 a8 ab b0 b1
1 b3 b8 bc c0 c3 c8 cc
d0 d3 d8 d9 db e0 e3 e7
e8 ed f2 f5 fa fb 100 103
107 108 10d 110 115 116 11b 11e
123 124 129 12c 131 132 137 13a
13e 13f 144 147 14c 14d 152 155
15a 15b 160 161 166 168 16c 16f
173 177 17a 17e 182 185 188 18d
190 193 196 197 19c 19d 1 19f
1a4 1a8 1ac 1af 1b4 1b9 1bc 1c0
1c1 1c6 1c7 1cc 1ce 1d2 1d5 1d9
1dc 1dd 1e2 1e5 1e8 1ec 1ef 1f0
1f5 1f8 1 1fb 200 204 208 20b
20f 213 216 219 21e 221 224 227
228 22d 22e 1 230 235 239 23d
240 245 24a 24d 251 252 257 25a
25f 260 265 268 26d 26e 273 276
27a 27e 282 286 289 28a 28c 291
292 294 295 29a 29b 2a0 2a2 2a6
2a9 2ad 2b1 2b4 2b8 2bc 2bf 2c2
2c7 2ca 2cd 2d0 2d1 2d6 2d7 1
2d9 2de 2e2 2e6 2e9 2ee 2f3 2f6
2fa 2fb 300 301 306 308 30c 30f
313 317 31a 31e 322 325 329 32a
32f 331 335 338 33c 340 344 348
34c 358 35c 361 365 368 369 36e
372 376 379 37c 380 382 386 38a
38d 390 394 396 39a 39e 3a1 3a3
1 3a7 3ab 3af 3b2 3b6 3ba 3be
3c2 3c5 3c9 3cd 3d0 3d3 3d8 3db
3de 3e1 3e2 3e7 3e8 1 3ea 3ef
3f3 3f7 3fa 3ff 404 407 40b 40c
411 414 419 41a 41f 422 427 428
42d 430 434 435 43a 43d 442 443
448 44b 44f 453 456 459 45a 45c
45d 462 463 468 46a 46e 471 473
477 479 485 487 489 48a 48f 493
495 4a1 4a3 4a7 4ab 4ae 4b2 4b6
4b9 4bc 4c1 4c4 4c7 4ca 4cb 4d0
4d1 1 4d3 4d8 4dc 4e0 4e3 4e8
4ed 4f0 4f4 4f5 4fa 4fd 502 503
508 50b 510 511 516 519 51d 521
525 529 52c 52d 52f 534 535 537
538 53d 540 545 546 54b 54e 553
554 559 55c 560 561 566 569 56e
56f 574 575 57a 57c 580 583 587
58b 58e 592 596 599 59d 5a1 5a2
5a7 5a9 5ad 5b1 5b4 5b8 5bc 5bf
5c3 5c7 5ca 5cd 5d2 5d5 5d8 5db
5dc 5e1 5e2 1 5e4 5e9 5ed 5f1
5f4 5f9 5fe 601 605 606 60b 60c
611 615 619 61c 621 626 629 62d
631 634 635 63a 63d 642 643 648
64b 64f 653 656 657 65c 65d 662
664 668 66b 66f 673 677 67b 67f
683 687 68b 68f 69b 6a0 6a4 6a8
6ac 6b0 6b2 6b3 6b8 1 6bc 6c0
6c4 6c7 6cb 6cf 6d3 6d7 6da 6de
6e2 6e5 6e8 6ed 6f0 6f3 6f6 6f7
6fc 6fd 1 6ff 704 708 70c 70f
714 719 71c 720 721 726 727 72c
730 734 737 73c 741 744 748 749
74e 751 756 757 75c 75f 763 767
76a 76d 76e 770 771 776 777 77c
77e 782 785 789 78d 791 795 799
79d 7a1 7ad 7b2 7b6 7ba 7be 7c2
7c4 7c8 7ca 7d6 7d8 7da 7db 7e0
7e4 7e6 7f2 7f6 7f8 7f9 802 
247
2
0 1 a 6 10 :3 6 c :2 6
1 3 a 13 a :2 1 4 :2 14
23 14 :2 4 e 17 :3 e 4 7
:2 11 23 :2 2d 3a :2 23 :3 7 :2 d 19
25 :2 2f 43 :2 25 56 5c 5f :2 56
6d 85 8 :2 6d d 10 :2 6d 1a
1d :2 6d b e :2 6d 13 16 :2 6d
1b 1e :2 6d 24 27 :2 6d 2c 2f
:2 6d :2 7 4c :2 4 7 :2 11 23 :2 2d
39 3c 4e 50 51 :2 4e :2 23 :3 7
:2 d 12 1e 5f 62 :2 1e :2 7 54
:2 4 :4 9 8 7 :4 22 21 20 :2 7
a :2 14 26 :2 30 3c 3f 51 53
54 :2 51 :2 26 :3 a :2 10 15 21 62
65 :2 21 72 75 :2 21 79 7c :2 21
86 89 92 9a :2 a3 :2 92 b4 :2 89
:2 21 :2 a 57 :2 7 a :2 14 26 :2 30
3c 3f 51 53 54 :2 51 :2 26 :3 a
:2 10 15 21 62 65 :2 21 :2 a 57
:3 7 :2 12 28 :2 31 41 :2 7 32 :2 4
e 23 32 3e 52 7 e a
16 :3 14 a :2 13 1f a 1b a
:2 13 1f a :4 7 4 :2 c a :2 13
1f a d :2 17 29 :2 33 3f 43
55 57 58 :2 55 :2 29 :3 d :2 13 18
24 65 68 :2 24 75 78 :2 24 7c
7f :2 24 8b 8e :2 24 96 99 :2 24
a5 a8 af b8 bb :2 a8 :2 24 :2 d
5b :2 a :2 7 :4 13 :2 7 4 :3 1 7
:2 11 23 :2 2d 39 3c 4e 50 51
:2 4e :2 23 :3 7 :2 d 12 1e 5f 62
:2 1e 6f 72 :2 1e 76 79 :2 1e 83
86 8f 97 :2 a0 :2 8f ab :2 86 :2 1e
b3 b6 :2 1e be c1 :2 1e c6 c9
:2 1e d3 d6 :2 1e :2 7 54 :3 4 :2 f
21 :2 2a 34 3f :2 4 1 9 12
9 a :2 14 26 :2 30 3c 40 52
54 55 :2 52 :2 26 :3 a :2 10 15 21
62 65 :2 21 :3 a :2 10 15 39 5c
5f :2 68 :2 39 76 79 :2 39 81 84
:2 8d :2 39 :2 a 58 :3 7 c 15 1e
2c a 13 1e f e 7 e
7 e 7 29 :2 4 :2 9 7 :2 10
1c :2 7 :2 11 23 :2 2d 39 3d 4f
51 52 :2 4f :2 23 :3 7 :2 d 12 1e
5f 62 :2 1e :3 7 :2 d 12 36 42
45 :2 36 4d 50 :2 36 5c 5f 66
6f 72 :2 5f :2 36 :2 7 55 :2 4 7
c 1b a 13 1e f e 7
e 7 e 7 :2 4 :4 10 :2 4 :8 1

247
4
0 :2 1 :4 3 :4 4
2 :4 5 :2 1 :6 7
:7 9 :b b :11 c d
:2 c :2 d :2 c :2 d
:2 c :2 e :2 c :2 e
:2 c :2 e :2 c :2 e
:2 c :2 e :4 c :3 b
:11 11 :b 12 :3 11 :e 15
:11 16 :20 17 :3 16 :11 19
:b 1a :3 19 :9 1c :3 15
:6 21 :6 22 :5 23 22
:5 25 24 :3 22 20
:2 28 :5 2a :11 2b :24 2c
:3 2b :2 29 :6 28 27
:3 a :11 31 :30 32 :3 31
:a 34 a :3 37 :11 38
:b 39 :17 3a :3 38 :2 3c
:3 3d :3 3e 3f 3d
3c 3d :3 40 :3 37
:2 41 :5 43 :11 44 :b 45
:18 46 :3 44 :2 48 49
:3 4a 4b 49 48
49 :3 4c :2 42 :6 41
36 :7 1 
804
4
:3 0 1 :3 0 2
:a 0 242 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 d
e 0 7 4
:3 0 5 :7 0 9
8 :3 0 6 :3 0
7 :3 0 8 :2 0
4 b f 0
242 2 10 :2 0
19 1a 0 :2 a
:3 0 13 :7 0 b
:2 0 17 14 15
240 0 9 :6 0
1f 20 0 c
7 :3 0 8 :2 0
4 1b :7 0 1e
1c 0 240 0
c :6 0 d :3 0
e :3 0 d :3 0
f :3 0 22 23
0 2 :4 0 e
24 26 21 28
27 :2 0 10 :3 0
11 :3 0 2a 2b
0 12 :4 0 d
:3 0 13 :3 0 2e
2f 0 2 :4 0
10 30 32 14
:4 0 15 :2 0 16
:3 0 12 35 37
:3 0 17 :4 0 15
:2 0 18 :4 0 15
3a 3c :3 0 15
:2 0 3 :3 0 18
3e 40 :3 0 15
:2 0 18 :4 0 1b
42 44 :3 0 15
:2 0 19 :4 0 1e
46 48 :3 0 15
:2 0 18 :4 0 21
4a 4c :3 0 15
:2 0 5 :3 0 24
4e 50 :3 0 15
:2 0 18 :4 0 27
52 54 :3 0 15
:2 0 1a :4 0 2a
56 58 :3 0 2d
2c 5a :2 0 5c
32 5d 29 5c
0 5e 34 0
1a0 d :3 0 e
:3 0 5f 60 0
d :3 0 1b :3 0
62 63 0 1c
:2 0 2 :4 0 1d
:2 0 1e :2 0 1c
:2 0 36 68 6a
:3 0 39 64 6c
61 6e 6d :2 0
10 :3 0 1f :3 0
70 71 0 12
:4 0 20 :4 0 15
:2 0 16 :3 0 3d
75 77 :3 0 40
72 79 :2 0 7b
43 7c 6f 7b
0 7d 45 0
1a0 3 :3 0 21
:2 0 47 7f 80
:3 0 81 :2 0 82
:2 0 5 :3 0 21
:2 0 49 85 86
:3 0 87 :2 0 88
:2 0 83 8a 89
:2 0 d :3 0 e
:3 0 8c 8d 0
d :3 0 1b :3 0
8f 90 0 22
:2 0 2 :4 0 23
:2 0 1e :2 0 1c
:2 0 4b 95 97
:3 0 4e 91 99
8e 9b 9a :2 0
10 :3 0 1f :3 0
9d 9e 0 12
:4 0 24 :4 0 15
:2 0 16 :3 0 52
a2 a4 :3 0 15
:2 0 25 :4 0 55
a6 a8 :3 0 15
:2 0 26 :4 0 58
aa ac :3 0 15
:2 0 27 :3 0 28
:3 0 29 :3 0 2a
:3 0 b1 b2 0
5b b0 b4 2b
:4 0 5d af b7
60 ae b9 :3 0
63 9f bb :2 0
bd 66 be 9c
bd 0 bf 68
0 e8 d :3 0
e :3 0 c0 c1
0 d :3 0 1b
:3 0 c3 c4 0
1c :2 0 2 :4 0
2c :2 0 1e :2 0
1c :2 0 6a c9
cb :3 0 6d c5
cd c2 cf ce
:2 0 10 :3 0 1f
:3 0 d1 d2 0
12 :4 0 2d :4 0
15 :2 0 16 :3 0
71 d6 d8 :3 0
74 d3 da :2 0
dc 77 dd d0
dc 0 de 79
0 e8 2e :3 0
2f :3 0 df e0
0 29 :3 0 2a
:3 0 e2 e3 0
30 :3 0 7b e1
e6 :2 0 e8 7e
e9 8b e8 0
ea 82 0 1a0
31 :3 0 32 :3 0
5 :3 0 33 :3 0
3 :4 0 34 1
:8 0 106 35 :4 0
f1 :3 0 30 :3 0
36 :2 0 86 f4
f5 :3 0 7 :3 0
37 :3 0 f7 f8
0 b :2 0 f9
fa 0 fc 89
103 7 :3 0 37
:3 0 fd fe 0
38 :2 0 ff 100
0 102 8b 104
f6 fc 0 105
0 102 0 105
8d 0 106 90
150 39 :3 0 7
:3 0 37 :3 0 109
10a 0 3a :3 0
10b 10c 0 146
d :3 0 e :3 0
10e 10f 0 d
:3 0 1b :3 0 111
112 0 3b :2 0
2 :4 0 3c :2 0
1e :2 0 1c :2 0
93 117 119 :3 0
96 113 11b 110
11d 11c :2 0 10
:3 0 1f :3 0 11f
120 0 12 :4 0
3d :4 0 15 :2 0
16 :3 0 9a 124
126 :3 0 15 :2 0
25 :4 0 9d 128
12a :3 0 15 :2 0
3e :4 0 a0 12c
12e :3 0 15 :2 0
3a :3 0 a3 130
132 :3 0 15 :2 0
3f :4 0 a6 134
136 :3 0 15 :2 0
40 :3 0 41 :3 0
1c :2 0 42 :2 0
a9 139 13d ad
138 13f :3 0 b0
121 141 :2 0 143
b3 144 11e 143
0 145 b5 0
146 b7 149 :3 0
149 0 149 148
146 147 :6 0 14b
2 :3 0 ba 14d
bc 14c 14b :2 0
14e be :2 0 150
0 150 14f 106
14e :6 0 1a0 1
:3 0 d :3 0 e
:3 0 152 153 0
d :3 0 1b :3 0
155 156 0 43
:2 0 2 :4 0 44
:2 0 1e :2 0 1c
:2 0 c0 15b 15d
:3 0 c3 157 15f
154 161 160 :2 0
10 :3 0 1f :3 0
163 164 0 12
:4 0 45 :4 0 15
:2 0 16 :3 0 c7
168 16a :3 0 15
:2 0 25 :4 0 ca
16c 16e :3 0 15
:2 0 26 :4 0 cd
170 172 :3 0 15
:2 0 27 :3 0 28
:3 0 7 :3 0 37
:3 0 177 178 0
d0 176 17a 2b
:4 0 d2 175 17d
d5 174 17f :3 0
15 :2 0 46 :4 0
d8 181 183 :3 0
15 :2 0 18 :4 0
db 185 187 :3 0
15 :2 0 3 :3 0
de 189 18b :3 0
15 :2 0 18 :4 0
e1 18d 18f :3 0
e4 165 191 :2 0
193 e7 194 162
193 0 195 e9
0 1a0 2e :3 0
47 :3 0 196 197
0 7 :3 0 37
:3 0 199 19a 0
3 :3 0 30 :3 0
eb 198 19e :2 0
1a0 ef 241 7
:3 0 48 :2 0 4
1a1 1a2 0 d
:3 0 e :3 0 1a4
1a5 0 d :3 0
1b :3 0 1a7 1a8
0 3b :2 0 2
:4 0 49 :2 0 1e
:2 0 1c :2 0 f6
1ad 1af :3 0 f9
1a9 1b1 1a6 1b3
1b2 :2 0 10 :3 0
1f :3 0 1b5 1b6
0 12 :4 0 4a
:4 0 15 :2 0 16
:3 0 fd 1ba 1bc
:3 0 100 1b7 1be
:2 0 1d7 10 :3 0
1f :3 0 1c0 1c1
0 12 :4 0 4b
:4 0 15 :2 0 7
:3 0 4c :3 0 1c6
1c7 0 103 1c5
1c9 :3 0 15 :2 0
46 :4 0 106 1cb
1cd :3 0 15 :2 0
7 :3 0 4d :3 0
1d0 1d1 0 109
1cf 1d3 :3 0 10c
1c2 1d5 :2 0 1d7
10f 1d8 1b4 1d7
0 1d9 112 0
1e9 4e :3 0 c
:3 0 7 :3 0 4c
:3 0 4f :3 0 7
:3 0 4d :3 0 50
:3 0 51 :4 0 52
1 :a 0 1e5 :2 0
1e9 1db 1e3 :2 0
6 :3 0 c :3 0
1e7 :2 0 1e9 114
1eb 118 1ea 1e9
:2 0 23f 39 :3 0
7 :3 0 37 :3 0
1ee 1ef 0 3a
:3 0 1f0 1f1 0
237 d :3 0 e
:3 0 1f3 1f4 0
d :3 0 1b :3 0
1f6 1f7 0 3b
:2 0 2 :4 0 53
:2 0 1e :2 0 1c
:2 0 11a 1fc 1fe
:3 0 11d 1f8 200
1f5 202 201 :2 0
10 :3 0 1f :3 0
204 205 0 12
:4 0 54 :4 0 15
:2 0 16 :3 0 121
209 20b :3 0 124
206 20d :2 0 227
10 :3 0 1f :3 0
20f 210 0 12
:4 0 3e :4 0 15
:2 0 3a :3 0 127
214 216 :3 0 15
:2 0 3f :4 0 12a
218 21a :3 0 15
:2 0 40 :3 0 41
:3 0 1c :2 0 42
:2 0 12d 21d 221
131 21c 223 :3 0
134 211 225 :2 0
227 137 228 203
227 0 229 13a
0 237 4e :3 0
c :3 0 4f :3 0
7 :3 0 4d :3 0
50 :3 0 51 :4 0
55 1 :a 0 233
:2 0 237 22b 231
:2 0 6 :3 0 c
:3 0 235 :2 0 237
13c 23a :3 0 23a
0 23a 239 237
238 :6 0 23c 1
:3 0 141 23e 143
23d 23c :2 0 23f
145 :2 0 241 148
241 240 1a0 23f
:6 0 242 :2 0 2
10 241 245 :3 0
244 242 246 :8 0

14b
4
:3 0 1 3 1
7 2 6 a
1 12 1 18
1 25 1 31
2 34 36 2
39 3b 2 3d
3f 2 41 43
2 45 47 2
49 4b 2 4d
4f 2 51 53
2 55 57 4
2d 33 38 59
1 5b 1 5d
2 67 69 3
65 66 6b 2
74 76 2 73
78 1 7a 1
7c 1 7e 1
84 2 94 96
3 92 93 98
2 a1 a3 2
a5 a7 2 a9
ab 1 b3 2
b5 b6 2 ad
b8 2 a0 ba
1 bc 1 be
2 c8 ca 3
c6 c7 cc 2
d5 d7 2 d4
d9 1 db 1
dd 2 e4 e5
3 bf de e7
1 e9 1 f3
2 f2 f3 1
fb 1 101 2
103 104 2 f0
105 2 116 118
3 114 115 11a
2 123 125 2
127 129 2 12b
12d 2 12f 131
2 133 135 3
13a 13b 13c 2
137 13e 2 122
140 1 142 1
144 2 10d 145
1 149 1 108
1 14d 2 15a
15c 3 158 159
15e 2 167 169
2 16b 16d 2
16f 171 1 179
2 17b 17c 2
173 17e 2 180
182 2 184 186
2 188 18a 2
18c 18e 2 166
190 1 192 1
194 3 19b 19c
19d 6 5e 7d
ea 150 195 19f
2 1ac 1ae 3
1aa 1ab 1b0 2
1b9 1bb 2 1b8
1bd 2 1c4 1c8
2 1ca 1cc 2
1ce 1d2 2 1c3
1d4 2 1bf 1d6
1 1d8 3 1d9
1e4 1e8 1 1a3
2 1fb 1fd 3
1f9 1fa 1ff 2
208 20a 2 207
20c 2 213 215
2 217 219 3
21e 21f 220 2
21b 222 2 212
224 2 20e 226
1 228 4 1f2
229 232 236 1
23a 1 1ed 2
1eb 23e 2 16
1d 
1
4
0 
245
0
1
14
4
5
0 1 2 1 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 
2 0 1
12 1 0
7 1 0
3 1 0
18 1 0
0

/
SHOW ERRORS FUNCTION SP_U_TIMECODE2;
ALTER FUNCTION SP_U_TIMECODE2 COMPILE DEBUG;
/*
#Stored Procedure  :SP_S_PROFILE
#Short Description :
#Description       :
#Table Name        :
#Parameters        :
 $$bitflag       Description
   0	-  WBS Project global view: Resources  Profile with Competencies  Skills
   1	-  WBS Project global view: Resources  Profiles
   6	-  CRI Project global view: Resources  Profiles
   2,3	-  WBS  CRI - Assignments View
   4	-  WBS  CRI - All assignments with effort (no participants, no project assignments) in the current project
   5	-  WBS  CRI - All participants (no effort) in the current project
   8	-  WBS  CRI - All assignments (effort, participants, project assignments) in the current project
   9	-  WBS  CRI - All assignments for a Resource / Profile under a element (project, deliverable, task)
   7	-  WBS Project Assignments
   11	-  DOC Assignments View (SC_TABLE_DOC, SC_TABLE_POL_DOC, SC_TABLE_RES_DOC, SC_TABLE_AST_DOC,SC_TABLE_CLN_DOC,SC_TABLE_VDR_DOC)
   12	-  WBS  CRI - display nickname for All assignments (effort, participants, project assignments) in the current project
   13	-  Returns nickname for All assignments (effort, participants, project assignments) in the current pool
#Returns           :
#Errors            :
*/
Prompt == FUNCTION SP_S_PROFILE ==
CREATE OR REPLACE FUNCTION SP_S_PROFILE wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
1fb
2 :e:
1FUNCTION:
1SP_S_PROFILE:
1ID001:
1VARCHAR2:
1BITFLAG001:
1PLS_INTEGER:
1RES_ID001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_RANK:
1200:
1H_ID:
132:
1H_REC_USER:
1H_PROJECT_ID:
1H_IN:
1255:
1H_BIT_FLAG:
11:
1H_BITFLAG:
10:
1H_PER_DAY:
1H_TYPE_ID:
1H_COUNT:
1H_TEMP_SC_STATE:
1H_LEVEL_STATE:
1C7751A:
1C7751B:
1C7751C:
1C7751T:
1C7751D:
1C7751E:
1C7751F:
1C7751G:
1C7751H:
1C7751J:
1C7751L:
1C7751M:
1C7751N:
1C77513N:
1CLN_AST_RES:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_S_PROFILE(:
1':
1, :
1COALESCE:
1TO_CHAR:
1NULL:
1);:
1CHECK_TRACE:
175:
1+:
1FPUT:
1               ENTER:: SP_S_PROFILE(76) :: cplan.sql(12349) :: :
1IS NULL:
182:
1        RETURN_ERROR:: SP_S_PROFILE(83) :: cplan.sql(12356) :: :
1 :
1STATE:: :
1PMO_CNST:
1INVALID_PARAMS:
1 ID:: :
185:
1                EXIT:: SP_S_PROFILE(86) :: cplan.sql(12359) :: :
1PMODEFINES:
1PMO_RETURN_ERROR_SP:
1TRUE:
1=:
12:
13:
1B:
1PROJECT_ID:
1TYPE_ID:
1A:
1MINUTE_PER_DAY:
1LEVEL_STATE:
1TMT_WBS:
1ELEMENT_ID:
1SELECT B.PROJECT_ID, B.TYPE_ID, COALESCE(A.MINUTE_PER_DAY, 480), B.LEVEL_STAT+
1E:n         INTO h_project_id, h_type_id, h_per_day, h_level_state:n         +
1FROM TMT_WBS A, TMT_WBS B WHERE B.ELEMENT_ID = h_id AND A.ELEMENT_ID = B.PROJ+
1ECT_ID:
1SC_STATE:
1SQLCODE:
1OTHERS:
116:
1108:
1           EXCEPTION:: SP_S_PROFILE(109) :: cplan.sql(12382) :: :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1SC_SQL_NO_DATA:
1TMT_CRI:
1SELECT B.PROJECT_ID, B.TYPE_ID, COALESCE(A.MINUTE_PER_DAY, 480):n            +
1INTO h_project_id, h_type_id, h_per_day:n            FROM TMT_WBS A, TMT_CRI +
1B WHERE B.ELEMENT_ID = h_id AND A.ELEMENT_ID = B.PROJECT_ID:
1125:
1           EXCEPTION:: SP_S_PROFILE(126) :: cplan.sql(12399) :: :
1TMT_POOLS:
1SELECT 480 INTO h_per_day FROM TMT_POOLS WHERE ELEMENT_ID = h_id:
1140:
1           EXCEPTION:: SP_S_PROFILE(141) :: cplan.sql(12414) :: :
1147:
1        RETURN_ERROR:: SP_S_PROFILE(148) :: cplan.sql(12421) :: :
1150:
1                EXIT:: SP_S_PROFILE(151) :: cplan.sql(12424) :: :
1ELSIF:
110:
1TASK_ASSIGNMENTS:
1TSK_ASSIGNMENT_ID:
1SELECT PROJECT_ID INTO h_project_id:n         FROM TASK_ASSIGNMENTS WHERE TSK+
1_ASSIGNMENT_ID = h_id:
1166:
1           EXCEPTION:: SP_S_PROFILE(167) :: cplan.sql(12440) :: :
1173:
1        RETURN_ERROR:: SP_S_PROFILE(174) :: cplan.sql(12447) :: :
1176:
1                EXIT:: SP_S_PROFILE(177) :: cplan.sql(12450) :: :
1SELECT COALESCE(MINUTE_PER_DAY, 480), LEVEL_STATE INTO h_per_day, h_level_sta+
1te:n         FROM TMT_WBS WHERE ELEMENT_ID = h_id:
1190:
1           EXCEPTION:: SP_S_PROFILE(191) :: cplan.sql(12464) :: :
113:
1RANK:
1SELECT RANK INTO h_rank FROM TMT_POOLS WHERE ELEMENT_ID = h_id:
1203:
1           EXCEPTION:: SP_S_PROFILE(204) :: cplan.sql(12477) :: :
1210:
1        RETURN_ERROR:: SP_S_PROFILE(211) :: cplan.sql(12484) :: :
1213:
1                EXIT:: SP_S_PROFILE(214) :: cplan.sql(12487) :: :
1480:
1!=:
1SC_SRCH_PARTICIPANT:
111:
1SC_ASSET_ASSIGNED_RESOURCES:
1SC_CLIENT_ASSIGNED_RESOURCES:
1SELECT COALESCE(MINUTE_PER_DAY, 480), LEVEL_STATE INTO h_per_day, h_level_sta+
1te:n         FROM TMT_WBS WHERE ELEMENT_ID = id001:
1231:
1           EXCEPTION:: SP_S_PROFILE(232) :: cplan.sql(12505) :: :
1238:
1        RETURN_ERROR:: SP_S_PROFILE(239) :: cplan.sql(12512) :: :
1241:
1                EXIT:: SP_S_PROFILE(242) :: cplan.sql(12515) :: :
1EXECUTE:
1IMMEDIATE:
1DELETE FROM PMO_TMP_ASGNDRES_INFO:
1PMO_TMP_ASGNDRES_INFO:
1RESOURCE_ID:
1PARENT_ID:
1RATE_ID:
1PROFICIENCY_LEVEL_ID:
1PREFERENCE_LEVEL_ID:
1EXPERIENCE_ID:
1LAST_USED_DATETIME:
1R:
1RESOURCE_ASSIGNMENTS:
1JOIN:
1TMT_COMPETENCIES:
1RESOURCE_TYPE:
1INSERT INTO PMO_TMP_ASGNDRES_INFO:n         (:n         RESOURCE_ID,:n       +
1  PARENT_ID,:n         RATE_ID,:n         PROFICIENCY_LEVEL_ID,:n         PRE+
1FERENCE_LEVEL_ID,:n         EXPERIENCE_ID,:n         LAST_USED_DATETIME:n    +
1     ):n         SELECT DISTINCT:n         a.RESOURCE_ID,:n         r.PARENT_+
1ID,:n         r.RATE_ID,:n         r.PROFICIENCY_LEVEL_ID,:n         r.PREFER+
1ENCE_LEVEL_ID,:n         r.EXPERIENCE_ID,:n         r.LAST_USED_DATETIME:n   +
1      FROM RESOURCE_ASSIGNMENTS a JOIN TMT_COMPETENCIES r ON a.RESOURCE_ID=r.+
1RESOURCE_ID:n         WHERE PROJECT_ID = h_id AND RESOURCE_TYPE = '0':
1FOUND:
1100:
1285:
1           EXCEPTION:: SP_S_PROFILE(286) :: cplan.sql(12559) :: :
1DELETE FROM PMO_TMP_PROF_INFO:
1PMO_TMP_PROF_INFO:
1PROFILE_ID:
1INSERT INTO PMO_TMP_PROF_INFO (PROFILE_ID):n         SELECT DISTINCT RESOURCE+
1_ID:n         FROM RESOURCE_ASSIGNMENTS:n         WHERE PROJECT_ID = h_id AND+
1 RESOURCE_TYPE = '1':
1309:
1           EXCEPTION:: SP_S_PROFILE(310) :: cplan.sql(12583) :: :
1OPEN:
1TA:
1RES:
1RES_TYPE:
1P:
1FULL_NAME:
1ELEMENT_NAME:
1STATUS1_ID:
1E_MAIL_ADDRESS:
1D:
1ROLE_NAME:
1LAST_USED:
1RC:
1REGULAR_COST:
1REGULAR_SALE:
1SPECIAL_COST:
1SPECIAL_SALE:
1OBJECTIVES:
1RESOURCES:
1C:
1LEFT:
1OUTER:
1RATES:
1PRF:
1PROFILE_NAME:
1PROFILES:
1ROLE_ID:
1RESOURCE_ASSIGN_SKILLS:
1S:
1RES_ASSIGNMENT_ID:
1SKILL_ID:
1RESOURCE_ASSIGN_ROLES:
1SELECT CASE WHEN EXISTS(SELECT * FROM TASK_ASSIGNMENTS ta WHERE ta.PROJECT_ID+
1=h_id AND ta.RESOURCE_ID = RES.RESOURCE_ID) THEN 13 ELSE 185 END AS RES_TYPE,+
1:n      RES.RESOURCE_ID, p.FULL_NAME AS ELEMENT_NAME, p.STATUS1_ID, p.E_MAIL_+
1ADDRESS, d.TYPE_ID, d.ELEMENT_NAME AS ROLE_NAME,:n      RES.PROFICIENCY_LEVEL+
1_ID, RES.PREFERENCE_LEVEL_ID, RES.EXPERIENCE_ID, RES.LAST_USED_DATETIME AS LA+
1ST_USED,rc.REGULAR_COST,rc.REGULAR_SALE,rc.SPECIAL_COST,rc.SPECIAL_SALE, '' A+
1S OBJECTIVES,'' AS RANK:n      FROM PMO_TMP_ASGNDRES_INFO RES JOIN RESOURCES +
1p ON RES.RESOURCE_ID=p.RESOURCE_ID:n      JOIN TMT_COMPETENCIES c ON c.ELEMEN+
1T_ID=RES.PARENT_ID:n      JOIN TMT_COMPETENCIES d ON d.ELEMENT_ID=c.PARENT_ID+
1:n      LEFT OUTER JOIN RATES rc ON rc.RATE_ID=RES.RATE_ID:n      :n      UNI+
1ON ALL:n      :n      SELECT 41 AS RES_TYPE,PRF.PROFILE_ID AS RESOURCE_ID, p.+
1PROFILE_NAME AS ELEMENT_NAME, 0 AS STATUS1_ID, '' AS E_MAIL_ADDRESS,:n      c+
1.TYPE_ID, c.ELEMENT_NAME AS ROLE_NAME,:n      r.PROFICIENCY_LEVEL_ID, r.PREFE+
1RENCE_LEVEL_ID,r.EXPERIENCE_ID,r.LAST_USED_DATETIME AS LAST_USED,:n      rc.R+
1EGULAR_COST,rc.REGULAR_SALE,rc.SPECIAL_COST,rc.SPECIAL_SALE,'' AS OBJECTIVES,+
1'' AS RANK:n      FROM PMO_TMP_PROF_INFO PRF  JOIN PROFILES p ON PRF.PROFILE_+
1ID=p.PROFILE_ID:n      LEFT OUTER JOIN TMT_COMPETENCIES r ON p.ROLE_ID=r.ELEM+
1ENT_ID:n      LEFT OUTER JOIN TMT_COMPETENCIES c ON c.ELEMENT_ID=r.PARENT_ID+
1:n      LEFT OUTER JOIN RATES rc ON rc.RATE_ID=r.RATE_ID:n      :n      UNION+
1 ALL:n      :n      SELECT 41 AS RES_TYPE,PRF.PROFILE_ID AS RESOURCE_ID,p.PRO+
1FILE_NAME AS ELEMENT_NAME,0 AS STATUS1_ID,'' AS E_MAIL_ADDRESS,:n      c.TYPE+
1_ID, c.ELEMENT_NAME AS ROLE_NAME,:n      r.PROFICIENCY_LEVEL_ID, r.PREFERENCE+
1_LEVEL_ID, r.EXPERIENCE_ID, r.LAST_USED_DATETIME AS LAST_USED,:n      rc.REGU+
1LAR_COST,rc.REGULAR_SALE,rc.SPECIAL_COST,rc.SPECIAL_SALE, '' AS OBJECTIVES,''+
1 AS RANK:n      FROM PMO_TMP_PROF_INFO PRF JOIN PROFILES p ON PRF.PROFILE_ID=+
1p.PROFILE_ID:n      JOIN RESOURCE_ASSIGN_SKILLS s ON p.PROFILE_ID=s.RES_ASSIG+
1NMENT_ID:n      LEFT OUTER JOIN TMT_COMPETENCIES r ON s.SKILL_ID=r.ELEMENT_ID+
1:n      LEFT OUTER JOIN TMT_COMPETENCIES c ON c.ELEMENT_ID=r.PARENT_ID:n     +
1 LEFT OUTER JOIN RATES rc ON rc.RATE_ID=r.RATE_ID:n      :n      UNION ALL:n +
1     :n      SELECT 41 AS RES_TYPE,PRF.PROFILE_ID AS RESOURCE_ID,p.PROFILE_NA+
1ME AS ELEMENT_NAME,0 AS STATUS1_ID,'' AS E_MAIL_ADDRESS,:n      c.TYPE_ID, c.+
1ELEMENT_NAME AS ROLE_NAME,:n      r.PROFICIENCY_LEVEL_ID, r.PREFERENCE_LEVEL_+
1ID, r.EXPERIENCE_ID, r.LAST_USED_DATETIME AS LAST_USED,:n      rc.REGULAR_COS+
1T,rc.REGULAR_SALE,rc.SPECIAL_COST,rc.SPECIAL_SALE, '' AS OBJECTIVES,'' AS RAN+
1K:n      FROM PMO_TMP_PROF_INFO PRF JOIN PROFILES p ON PRF.PROFILE_ID=p.PROFI+
1LE_ID:n      JOIN RESOURCE_ASSIGN_ROLES s ON p.PROFILE_ID=s.RES_ASSIGNMENT_ID+
1:n      LEFT OUTER JOIN TMT_COMPETENCIES r ON s.ROLE_ID=r.ELEMENT_ID:n      L+
1EFT OUTER JOIN TMT_COMPETENCIES c ON c.ELEMENT_ID=r.PARENT_ID:n      LEFT OUT+
1ER JOIN RATES rc ON rc.RATE_ID=r.RATE_ID:n      ORDER BY RES_TYPE, RESOURCE_I+
1D, TYPE_ID:
1358:
1                EXIT:: SP_S_PROFILE(359) :: cplan.sql(12632) :: :
16:
1DELETE FROM PMO_TMP_RES_DATA:
1PMO_TMP_RES_DATA:
1RA:
1PROJECT_ASSIGNMENT_ID:
1T:
1TASK_ID:
1INSERT INTO PMO_TMP_RES_DATA (RESOURCE_ID, TYPE_ID):n         SELECT DISTINCT+
1:n         ra.RESOURCE_ID,:n         CASE WHEN ta.TSK_ASSIGNMENT_ID IS NuLL T+
1HEN 185 ELSE 13 END AS TYPE_ID:n         FROM RESOURCE_ASSIGNMENTS ra LEFT OU+
1TER JOIN TASK_ASSIGNMENTS ta ON ta.PROJECT_ID=h_id AND ra.RESOURCE_ID = ta.RE+
1SOURCE_ID:n         WHERE ra.PROJECT_ID=h_id AND ra.RESOURCE_TYPE='0' AND ta.+
1PROJECT_ASSIGNMENT_ID IS NuLL AND:n         NOT EXISTS(SELECT * FROM TASK_ASS+
1IGNMENTS t WHERE ra.RESOURCE_ID = t.RESOURCE_ID AND t.TASK_ID=h_id):
1384:
1           EXCEPTION:: SP_S_PROFILE(385) :: cplan.sql(12658) :: :
1FC_U_CREATETMPTABLE:
1PMO_TMP_CPLN01_TEMP:
1ELEMENT_TYPE:
1INSERT INTO PMO_TMP_CPLN01_TEMP(ELEMENT_ID,ELEMENT_NAME):n         SELECT DIS+
1TINCT r.PROFILE_ID ,r.PROFILE_NAME:n         FROM RESOURCE_ASSIGNMENTS a JOIN+
1 PROFILES r ON a.RESOURCE_TYPE='1' AND r.PROFILE_ID=a.RESOURCE_ID :n         +
1JOIN TMT_COMPETENCIES c ON c.ELEMENT_ID=r.ROLE_ID:n         JOIN TMT_COMPETEN+
1CIES d ON d.ELEMENT_ID=c.PARENT_ID :n         JOIN TASK_ASSIGNMENTS t ON t.RE+
1S_ASSIGNMENT_ID=a.RES_ASSIGNMENT_ID AND t.PROJECT_ASSIGNMENT_ID IS NuLL:n    +
1     WHERE a.PROJECT_ID=h_id AND a.ELEMENT_TYPE>1:
1409:
1           EXCEPTION:: SP_S_PROFILE(410) :: cplan.sql(12683) :: :
1TO_TIMESTAMP:
1PLANNED_START:
1PLANNED_FINISH:
1PLANNED_EFFORT:
1START_DATE:
1FINISH_DATE:
1WORK:
1REMAINING:
1T_UNIT:
1BEST_START:
1BEST_FINISH:
1CALENDAR:
1PLANNED_WORK:
1PERIOD_AVAILABILITY:
1ASSIGN_STRING:
1SELECT a.RESOURCE_ID AS ELEMENT_ID,'' AS RES_ASSIGNMENT_ID, p.FULL_NAME AS EL+
1EMENT_NAME,a.TYPE_ID,p.E_MAIL_ADDRESS,:n      TO_TIMESTAMP('1899-12-31 00::00+
1::00') AS PLANNED_START, TO_TIMESTAMP('1899-12-31 00::00::00') AS PLANNED_FIN+
1ISH,0 AS PLANNED_EFFORT,:n      TO_TIMESTAMP('1899-12-31 00::00::00') AS STAR+
1T_DATE, TO_TIMESTAMP('1899-12-31 00::00::00') AS FINISH_DATE, 0 AS WORK, 0 AS+
1 REMAINING,0 AS T_UNIT,h_per_day AS MINUTE_PER_DAY,'' AS BEST_START,'' AS BES+
1T_FINISH,:n      0 AS CALENDAR, 0 AS PLANNED_WORK, 0 AS PERIOD_AVAILABILITY, +
1'' AS ASSIGN_STRING, '' AS OBJECTIVES,'' AS RANK:n      FROM PMO_TMP_RES_DATA+
1 a JOIN RESOURCES p ON a.RESOURCE_ID=p.RESOURCE_ID:n      :n      UNION ALL:n+
1      :n      SELECT ELEMENT_ID,'' AS RES_ASSIGNMENT_ID, ELEMENT_NAME,41 AS T+
1YPE_ID,'' AS E_MAIL_ADDRESS,:n      TO_TIMESTAMP('1899-12-31 00::00::00') AS +
1PLANNED_START, TO_TIMESTAMP('1899-12-31 00::00::00') AS PLANNED_FINISH,0 AS P+
1LANNED_EFFORT,:n      TO_TIMESTAMP('1899-12-31 00::00::00') AS START_DATE, TO+
1_TIMESTAMP('1899-12-31 00::00::00') AS FINISH_DATE, 0 AS WORK, 0 AS REMAINING+
1,0 AS T_UNIT,h_per_day AS MINUTE_PER_DAY,:n      '' AS BEST_START,''  AS BEST+
1_FINISH,0 AS CALENDAR, 0 AS PLANNED_WORK, 0 AS PERIOD_AVAILABILITY, '' AS ASS+
1IGN_STRING, '' AS OBJECTIVES,'' AS RANK:n      FROM PMO_TMP_CPLN01_TEMP:n    +
1  ORDER BY TYPE_ID:
1429:
1                EXIT:: SP_S_PROFILE(430) :: cplan.sql(12703) :: :
1PARTICIPANT:
1START_DT:
1FINISH_DT:
1WORK_LOCATION:
1SECURITY_ID:
1G:
1SECURITY_NAME:
1CRI_SECURITY_ID:
1G2:
1CRI_SECURITY_NAME:
1REGULAR_RATE:
1SPECIAL_RATE:
1FS_LABOR_CODE:
1REC_STATUS:
1TIMECODE2_ID:
1TC:
1TIMECODE2:
1C_EFFORT:
1C_UNIT:
1C_CONTOUR:
1CONTOUR_TYPE:
1C_OCCURRENCE:
1BILLABLE:
1ASSIGNMENT_DELAY:
1TMT_GLOBAL_SECURITY:
1TMT_TIMECODES:
1SELECT CASE WHEN t.TSK_ASSIGNMENT_ID IS NOT NuLL THEN t.TSK_ASSIGNMENT_ID ELS+
1E a.RES_ASSIGNMENT_ID END AS ELEMENT_ID,:n      a.PROFILE_ID, p.PROFILE_NAME +
1AS ELEMENT_NAME,41 AS TYPE_ID,a.RES_ASSIGNMENT_ID, a.PARTICIPANT, t.PLANNED_S+
1TART,t.PLANNED_FINISH,:n      t.PLANNED_WORK,t.START_DT,t.FINISH_DT,h_per_day+
1 AS MINUTE_PER_DAY, a.WORK_LOCATION, a.SECURITY_ID, g.ELEMENT_NAME AS SECURIT+
1Y_NAME,:n      COALESCE(a.CRI_SECURITY_ID,a.SECURITY_ID) AS CRI_SECURITY_ID, +
1g2.ELEMENT_NAME AS CRI_SECURITY_NAME, t.REGULAR_COST,t.REGULAR_RATE,t.SPECIAL+
1_COST,t.SPECIAL_RATE,'' AS FS_LABOR_CODE,a.REC_STATUS,t.ASSIGN_STRING,:n     +
1 t.PROJECT_ASSIGNMENT_ID,t.TIMECODE2_ID,TC.ELEMENT_NAME AS TIMECODE2, t.T_UNI+
1T, t.C_EFFORT, t.C_UNIT, t.C_CONTOUR, t.CONTOUR_TYPE, t.C_OCCURRENCE, BILLABL+
1E,:n      t.ASSIGNMENT_DELAY:n      FROM RESOURCE_ASSIGNMENTS a LEFT OUTER JO+
1IN TASK_ASSIGNMENTS t ON t.TASK_ID = h_id AND a.RES_ASSIGNMENT_ID = t.RES_ASS+
1IGNMENT_ID:n      LEFT OUTER JOIN PROFILES p ON a.RESOURCE_ID = p.PROFILE_ID +
1LEFT OUTER JOIN TMT_GLOBAL_SECURITY g ON a.SECURITY_ID=g.ELEMENT_ID:n      LE+
1FT OUTER JOIN TMT_GLOBAL_SECURITY g2 ON COALESCE(a.CRI_SECURITY_ID,a.SECURITY+
1_ID)=g2.ELEMENT_ID:n      LEFT OUTER JOIN TMT_TIMECODES TC ON TC.ELEMENT_ID= +
1t.TIMECODE2_ID:n      WHERE a.ELEMENT_ID = h_id AND a.RESOURCE_TYPE='1' ORDER+
1 BY ELEMENT_NAME:
1445:
1                EXIT:: SP_S_PROFILE(446) :: cplan.sql(12719) :: :
1ISTASK:
1COUNT:
1SELECT COUNT(*) INTO h_count FROM TASK_ASSIGNMENTS WHERE PROJECT_ID = h_proje+
1ct_id AND TASK_ID = h_id:
1459:
1           EXCEPTION:: SP_S_PROFILE(460) :: cplan.sql(12733) :: :
1DUAL:
1BIT_FLAG:
1SELECT COUNT('X') INTO h_count FROM DUAL WHERE EXISTS (:n               SELEC+
1T 'X' FROM TASK_ASSIGNMENTS WHERE PROJECT_ID = h_project_id AND TASK_ID = h_i+
1d AND BIT_FLAG = '0'):
1476:
1           EXCEPTION:: SP_S_PROFILE(477) :: cplan.sql(12750) :: :
1TIMESHEET_APPROVAL_STATUS:
1APV:
1TO_DATE:
1ACTUAL_START:
1WEEK_OF:
1SELECT COUNT('X') INTO h_count FROM DUAL WHERE EXISTS (:n                  SE+
1LECT 'X' FROM TASK_ASSIGNMENTS ta JOIN TIMESHEET_APPROVAL_STATUS apv:n       +
1           ON apv.ELEMENT_ID = ta.PROJECT_ID AND apv.RESOURCE_ID = ta.RESOURC+
1E_ID:n                  WHERE ta.PROJECT_ID = h_project_id AND ta.TASK_ID = h+
1_id AND:n                  (TO_DATE(SubStr(ta.ACTUAL_START, 1, 10)) - 7     )+
1 <= apv.WEEK_OF):
1494:
1           EXCEPTION:: SP_S_PROFILE(495) :: cplan.sql(12768) :: :
1SD:
1FD:
1SCHED_EFFORT:
1WORK_TODATE:
1UNITS_PERCENT:
1MILESTONE_PERCENT:
1TRUNC:
1TO_NUMBER:
1WORK_PERCENT:
1BAK_START_DT:
1BAK_FINISH_DT:
1BAK_WORK:
1FORECAST_START:
1FORECAST_FINISH:
1ETC:
1ACTUAL_FINISH:
1ACTUAL:
1PROPOSED_START:
1PROPOSED_FINISH:
1PROPOSED_EFFORT:
1PROPOSED_WORK:
1BASELINE1_START:
1BASELINE1_FINISH:
1BASELINE1_EFFORT:
1BASELINE1_WORK:
1TIMECODE2_NAME:
1CAPITAL_EXPENSE:
1RATE_ADJUSTMENT:
1ASSIGN_COUNT:
1UNRESOLVED_DURATION:
1DURATION:
1LEVEL_START:
1LEVEL_FINISH:
1LEVEL_DURATION:
1LEVEL_EFFORT:
1PERCENT_DISCRETE:
1TOP_ID:
1LEVEL_AFFECTED_FLAG:
1LABOR_COST_CC_ID:
1LABOR_COST_CC_NAME:
1LABOR_REVENUE_CC_ID:
1LABOR_REVENUE_CC_NAME:
1DEFAULT_LABOR_FLAG:
1CONTRACT_ID:
1CONTRACT_NAME:
1UNRESOLVED_FINISH:
1SC_UFS:
1SC_FS:
1SC_SS:
1SC_FF:
1SC_SF:
1UNRESOLVED_START:
1SCHED_WORK:
1ASSIGN_UNITS:
1UNITS_MSP:
1EC:
1CC:
1CTR:
1TMT_CHARGECODES:
1TMT_CONTRACTS:
1SELECT t.ELEMENT_ID, a.RESOURCE_ID, t.ELEMENT_NAME, t.TYPE_ID, '' AS RES_ASSI+
1GNMENT_ID, a.PARTICIPANT, t.START_DT,t.FINISH_DT,:n         t.SD, t.FD, t.STA+
1RT_DT AS PLANNED_START, t.FINISH_DT AS PLANNED_FINISH,:n         t.SCHED_EFFO+
1RT + t.PLANNED_EFFORT AS PLANNED_WORK, t.SCHED_EFFORT + t.PLANNED_EFFORT - t.+
1WORK_TODATE AS REMAINING,:n         0 UNITS_PERCENT, t.MILESTONE_PERCENT,:n  +
1       CASE WHEN t.WORK_TODATE = 0 THEN 0 ELSE Trunc((TO_NUMBER(t.WORK_TODATE+
1)/TO_NUMBER(t.SCHED_EFFORT + t.PLANNED_EFFORT))*10000) END AS WORK_PERCENT,:n+
1         TO_TIMESTAMP('1899-12-31 00::00::00') AS BAK_START_DT,TO_TIMESTAMP('+
11899-12-31 00::00::00') AS BAK_FINISH_DT,0 AS BAK_WORK,:n         t.FORECAST_+
1START,t.FORECAST_FINISH,t.ETC, t.ACTUAL_START,t.ACTUAL_FINISH,:n         t.WO+
1RK_TODATE AS ACTUAL,t.PROPOSED_START, t.PROPOSED_FINISH, t.PROPOSED_EFFORT AS+
1 PROPOSED_WORK,:n         h_per_day AS MINUTE_PER_DAY, 0 AS WORK_LOCATION, ''+
1 AS SECURITY_ID, '' AS SECURITY_NAME,:n         '' AS CRI_SECURITY_ID, '' AS +
1CRI_SECURITY_NAME, 0.00 AS REGULAR_COST,0.00 AS REGULAR_RATE,0.00 AS SPECIAL_+
1COST,0.00 AS SPECIAL_RATE,:n         '' AS FS_LABOR_CODE,t.REC_STATUS,'' AS A+
1SSIGN_STRING,t.BASELINE1_START,t.BASELINE1_FINISH,t.BASELINE1_EFFORT AS BASEL+
1INE1_WORK,:n         '' AS PROJECT_ASSIGNMENT_ID,'' AS TIMECODE2_ID, '' AS TI+
1MECODE2_NAME, 0 AS T_UNIT, 0 AS C_EFFORT, 0 AS C_UNIT, 0 AS C_CONTOUR, 0 AS C+
1ONTOUR_TYPE, 0 AS C_OCCURRENCE, 0 AS BILLABLE, 0 AS CAPITAL_EXPENSE,:n       +
1  0 AS ASSIGNMENT_DELAY, h_bit_flag AS BIT_FLAG, 0 AS RATE_ADJUSTMENT, t.ASSI+
1GN_COUNT, t.UNRESOLVED_DURATION AS DURATION,:n         CASE WHEN h_level_stat+
1e = 1 THEN t.LEVEL_START ELSE TO_TIMESTAMP('1899-12-31 00::00::00') END AS LE+
1VEL_START,:n         CASE WHEN h_level_state = 1 THEN t.LEVEL_FINISH ELSE TO_+
1TIMESTAMP('1899-12-31 00::00::00') END AS LEVEL_FINISH,:n         CASE WHEN h+
1_level_state = 1 THEN t.LEVEL_DURATION ELSE 0 END AS LEVEL_EFFORT, t.WORK_PER+
1CENT AS PERCENT_DISCRETE, 0 as TOP_ID, '0' AS LEVEL_AFFECTED_FLAG,:n         +
1'' AS LABOR_COST_CC_ID, '' AS LABOR_COST_CC_NAME, '' AS LABOR_REVENUE_CC_ID, +
1'' AS LABOR_REVENUE_CC_NAME, 'N' AS DEFAULT_LABOR_FLAG,:n         '' AS CONTR+
1ACT_ID, '' AS CONTRACT_NAME:n         FROM TMT_WBS t LEFT JOIN RESOURCE_ASSIG+
1NMENTS a ON a.ELEMENT_ID = t.ELEMENT_ID AND a.RESOURCE_ID = h_rec_user:n     +
1    LEFT OUTER JOIN TMT_GLOBAL_SECURITY g ON a.SECURITY_ID=g.ELEMENT_ID:n    +
1     WHERE t.PROJECT_ID = h_project_id AND t.ELEMENT_ID = h_id:n         UNIO+
1N ALL:n         SELECT CASE WHEN t.TSK_ASSIGNMENT_ID IS NOT NuLL THEN t.TSK_A+
1SSIGNMENT_ID ELSE a.RES_ASSIGNMENT_ID END AS ELEMENT_ID, a.RESOURCE_ID,:n    +
1     CASE WHEN a.RESOURCE_TYPE='1' THEN (SELECT p.PROFILE_NAME FROM PROFILES +
1p WHERE a.RESOURCE_ID = p.PROFILE_ID):n         ELSE (SELECT r.FULL_NAME FROM+
1 RESOURCES r WHERE a.RESOURCE_ID = r.RESOURCE_ID) END AS ELEMENT_NAME,:n     +
1    CASE WHEN t.TSK_ASSIGNMENT_ID IS NuLL THEN 185 WHEN a.RESOURCE_TYPE='1' T+
1HEN 41 ELSE 13 END AS TYPE_ID,:n         a.RES_ASSIGNMENT_ID, a.PARTICIPANT, +
1t.START_DT, t.UNRESOLVED_FINISH AS FINISH_DT,:n         CASE WHEN t.SD = PMO_+
1CNST.SC_UFS OR t.SD = PMO_CNST.SC_FS THEN PMO_CNST.SC_SS ELSE t.SD END AS SD,+
1 CASE WHEN t.FD = PMO_CNST.SC_FF THEN PMO_CNST.SC_SF ELSE t.FD END AS FD, t.U+
1NRESOLVED_START AS PLANNED_START, t.UNRESOLVED_FINISH AS PLANNED_FINISH,:n   +
1      CASE WHEN BIT_FLAG = '2' THEN SCHED_WORK ELSE PLANNED_WORK END AS PLANN+
1ED_WORK,:n         CASE WHEN BIT_FLAG = '2' THEN SCHED_WORK - WORK_TODATE ELS+
1E PLANNED_WORK END AS REMAINING,:n         CASE WHEN t.ASSIGN_UNITS > t.UNITS+
1_MSP THEN t.ASSIGN_UNITS ELSE t.UNITS_MSP END AS UNITS_PERCENT,:n         0 A+
1S MILESTONE_PERCENT,:n         CASE WHEN t.WORK_TODATE = 0 THEN 0 ELSE Trunc(+
1(TO_NUMBER(t.WORK_TODATE)/TO_NUMBER(PLANNED_WORK+SCHED_WORK))*10000) END AS W+
1ORK_PERCENT,:n         t.BAK_START_DT,t.BAK_FINISH_DT,t.BAK_WORK,:n         t+
1.FORECAST_START,t.FORECAST_FINISH,t.ETC, t.ACTUAL_START,t.ACTUAL_FINISH,:n   +
1      t.WORK_TODATE AS ACTUAL,PROPOSED_START, PROPOSED_FINISH, PROPOSED_WORK,+
1:n         h_per_day AS MINUTE_PER_DAY, a.WORK_LOCATION, a.SECURITY_ID, g.ELE+
1MENT_NAME AS SECURITY_NAME,:n         COALESCE(a.CRI_SECURITY_ID,a.SECURITY_I+
1D) AS CRI_SECURITY_ID, g2.ELEMENT_NAME AS CRI_SECURITY_NAME, t.REGULAR_COST,t+
1.REGULAR_RATE,t.SPECIAL_COST,t.SPECIAL_RATE,:n         CASE WHEN a.RESOURCE_T+
1YPE='0' THEN (SELECT r.FS_LABOR_CODE FROM RESOURCES r WHERE a.RESOURCE_ID = r+
1.RESOURCE_ID):n         ELSE '' END AS FS_LABOR_CODE,a.REC_STATUS,t.ASSIGN_ST+
1RING,t.BASELINE1_START,t.BASELINE1_FINISH,t.BASELINE1_WORK,:n         t.PROJE+
1CT_ASSIGNMENT_ID,t.TIMECODE2_ID, TC.ELEMENT_NAME AS TIMECODE2_NAME, t.T_UNIT,+
1 t.C_EFFORT, t.C_UNIT, t.C_CONTOUR, t.CONTOUR_TYPE, t.C_OCCURRENCE, t.BILLABL+
1E, t.CAPITAL_EXPENSE,:n         t.ASSIGNMENT_DELAY, CASE WHEN t.BIT_FLAG IS N+
1uLL THEN '' WHEN t.BIT_FLAG = '0' THEN '1' ELSE '2' END AS BIT_FLAG, t.RATE_A+
1DJUSTMENT, 0 AS ASSIGN_COUNT, t.UNRESOLVED_DURATION AS DURATION,:n         CA+
1SE WHEN h_level_state = 1 THEN COALESCE(t.LEVEL_START,t.UNRESOLVED_START) ELS+
1E TO_TIMESTAMP('1899-12-31 00::00::00') END AS LEVEL_START,:n         CASE WH+
1EN h_level_state = 1 THEN COALESCE(t.LEVEL_FINISH,t.UNRESOLVED_FINISH) ELSE T+
1O_TIMESTAMP('1899-12-31 00::00::00') END AS LEVEL_FINISH,:n         CASE WHEN+
1 h_level_state = 1 THEN CASE WHEN t.LEVEL_EFFORT = 0 THEN t.ETC ELSE t.LEVEL_+
1EFFORT END ELSE 0 END AS LEVEL_EFFORT, t.MILESTONE_PERCENT AS PERCENT_DISCRET+
1E, 1 as TOP_ID, '0' AS LEVEL_AFFECTED_FLAG,:n         T.LABOR_COST_CC_ID,:n  +
1       EC.ELEMENT_NAME AS LABOR_COST_CC_NAME,:n         T.LABOR_REVENUE_CC_ID+
1,:n         CC.ELEMENT_NAME AS LABOR_REVENUE_CC_NAME, T.DEFAULT_LABOR_FLAG,:n+
1         T.CONTRACT_ID, CTR.ELEMENT_NAME AS CONTRACT_NAME:n         FROM RESO+
1URCE_ASSIGNMENTS a LEFT OUTER JOIN TASK_ASSIGNMENTS t ON a.RES_ASSIGNMENT_ID +
1= t.RES_ASSIGNMENT_ID:n         LEFT OUTER JOIN TMT_GLOBAL_SECURITY g ON a.SE+
1CURITY_ID=g.ELEMENT_ID:n         LEFT OUTER JOIN TMT_GLOBAL_SECURITY g2 ON CO+
1ALESCE(a.CRI_SECURITY_ID,a.SECURITY_ID)=g2.ELEMENT_ID:n         LEFT OUTER JO+
1IN TMT_TIMECODES TC ON TC.ELEMENT_ID= t.TIMECODE2_ID:n         LEFT OUTER JOI+
1N TMT_CHARGECODES EC ON EC.ELEMENT_ID = T.LABOR_COST_CC_ID:n         LEFT OUT+
1ER JOIN TMT_CHARGECODES CC ON CC.ELEMENT_ID = T.LABOR_REVENUE_CC_ID:n        +
1 LEFT OUTER JOIN TMT_CONTRACTS CTR ON CTR.ELEMENT_ID = T.CONTRACT_ID:n       +
1  WHERE a.PROJECT_ID = h_project_id AND a.ELEMENT_ID = h_id AND a.REC_STATUS +
1NOT IN ('L','D'):n         ORDER BY TOP_ID, ELEMENT_NAME:
1573:
1                EXIT:: SP_S_PROFILE(574) :: cplan.sql(12847) :: :
1BEST:
1SELECT CASE WHEN t.TSK_ASSIGNMENT_ID IS NOT NuLL THEN t.TSK_ASSIGNMENT_ID ELS+
1E a.RES_ASSIGNMENT_ID END AS ELEMENT_ID,a.RESOURCE_ID,:n         CASE WHEN a.+
1RESOURCE_TYPE='1' THEN (SELECT p.PROFILE_NAME FROM PROFILES p WHERE a.RESOURC+
1E_ID = p.PROFILE_ID):n         ELSE (SELECT r.FULL_NAME FROM RESOURCES r WHER+
1E a.RESOURCE_ID = r.RESOURCE_ID) END AS ELEMENT_NAME,:n         CASE WHEN t.T+
1SK_ASSIGNMENT_ID IS NuLL THEN 185 WHEN a.RESOURCE_TYPE='1' THEN 41 ELSE 13 EN+
1D AS TYPE_ID,:n         a.RES_ASSIGNMENT_ID, a.PARTICIPANT, t.START_DT,t.FINI+
1SH_DT,:n         t.SD, t.FD, t.UNRESOLVED_START AS PLANNED_START, t.UNRESOLVE+
1D_FINISH AS PLANNED_FINISH,:n         BEST AS PLANNED_WORK, CASE WHEN BIT_FLA+
1G = '2' THEN SCHED_WORK ELSE PLANNED_WORK END AS REMAINING,:n         t.UNITS+
1_MSP AS UNITS_PERCENT, t.MILESTONE_PERCENT, 0 AS WORK_PERCENT,:n         t.BA+
1K_START_DT,t.BAK_FINISH_DT,t.BAK_WORK,:n         t.FORECAST_START,t.FORECAST_+
1FINISH,t.ETC, t.ACTUAL_START,t.ACTUAL_FINISH,:n         t.WORK_TODATE AS ACTU+
1AL,PROPOSED_START, PROPOSED_FINISH, PROPOSED_WORK,:n         h_per_day AS MIN+
1UTE_PER_DAY, a.WORK_LOCATION, a.SECURITY_ID, g.ELEMENT_NAME AS SECURITY_NAME,+
1:n         COALESCE(a.CRI_SECURITY_ID,a.SECURITY_ID) AS CRI_SECURITY_ID, g2.E+
1LEMENT_NAME AS CRI_SECURITY_NAME, t.REGULAR_COST,t.REGULAR_RATE,t.SPECIAL_COS+
1T,t.SPECIAL_RATE,:n         CASE WHEN a.RESOURCE_TYPE='0' THEN (SELECT r.FS_L+
1ABOR_CODE FROM RESOURCES r WHERE a.RESOURCE_ID = r.RESOURCE_ID):n         ELS+
1E '' END AS FS_LABOR_CODE,a.REC_STATUS,t.ASSIGN_STRING,t.BASELINE1_START,t.BA+
1SELINE1_FINISH,t.BASELINE1_WORK,:n         t.PROJECT_ASSIGNMENT_ID,t.TIMECODE+
12_ID, TC.ELEMENT_NAME AS TIMECODE2_NAME, t.T_UNIT, t.C_EFFORT, t.C_UNIT, t.C_+
1CONTOUR, t.CONTOUR_TYPE, t.C_OCCURRENCE, t.BILLABLE, t.CAPITAL_EXPENSE,:n    +
1     t.ASSIGNMENT_DELAY, CASE WHEN t.BIT_FLAG IS NuLL THEN '' WHEN t.BIT_FLAG+
1 = '0' THEN '1' ELSE '2' END AS BIT_FLAG, t.RATE_ADJUSTMENT, 0 AS ASSIGN_COUN+
1T, 0 AS DURATION,:n         t.LEVEL_START, t.LEVEL_FINISH, t.LEVEL_EFFORT, t.+
1MILESTONE_PERCENT AS PERCENT_DISCRETE, 0 as TOP_ID,:n         CASE WHEN t.TSK+
1_ASSIGNMENT_ID IS NOT NuLL AND t.PROJECT_ASSIGNMENT_ID = t.TSK_ASSIGNMENT_ID +
1AND (t.LEVEL_START <> t.UNRESOLVED_START OR t.LEVEL_FINISH <> t.UNRESOLVED_FI+
1NISH) THEN '1' ELSE '0' END AS LEVEL_AFFECTED_FLAG,:n         T.LABOR_COST_CC+
1_ID,:n         EC.ELEMENT_NAME AS LABOR_COST_CC_NAME,:n         T.LABOR_REVEN+
1UE_CC_ID,:n         CC.ELEMENT_NAME AS LABOR_REVENUE_CC_NAME, T.DEFAULT_LABOR+
1_FLAG,:n         T.CONTRACT_ID, CTR.ELEMENT_NAME AS CONTRACT_NAME:n         F+
1ROM RESOURCE_ASSIGNMENTS a LEFT OUTER JOIN TASK_ASSIGNMENTS t ON a.RES_ASSIGN+
1MENT_ID = t.RES_ASSIGNMENT_ID:n         LEFT OUTER JOIN TMT_GLOBAL_SECURITY g+
1 ON a.SECURITY_ID=g.ELEMENT_ID:n         LEFT OUTER JOIN TMT_GLOBAL_SECURITY +
1g2 ON COALESCE(a.CRI_SECURITY_ID,a.SECURITY_ID)=g2.ELEMENT_ID:n         LEFT +
1OUTER JOIN TMT_TIMECODES TC ON TC.ELEMENT_ID= t.TIMECODE2_ID:n         LEFT O+
1UTER JOIN TMT_CHARGECODES EC ON EC.ELEMENT_ID = T.LABOR_COST_CC_ID:n         +
1LEFT OUTER JOIN TMT_CHARGECODES CC ON CC.ELEMENT_ID = T.LABOR_REVENUE_CC_ID:n+
1         LEFT OUTER JOIN TMT_CONTRACTS CTR ON CTR.ELEMENT_ID = T.CONTRACT_ID+
1:n         WHERE a.REC_STATUS NOT IN ('L','D') AND a.ELEMENT_ID = h_id:n     +
1    ORDER BY TYPE_ID, ELEMENT_NAME:
1613:
1                EXIT:: SP_S_PROFILE(614) :: cplan.sql(12887) :: :
14:
1DELETE FROM PMO_TMP_RES_SET:
1PMO_TMP_RES_SET:
1MIN:
1MAX:
1SUM:
1SCHED_START:
1SCHED_FINISH:
1INSERT INTO PMO_TMP_RES_SET:n         (:n         RESOURCE_ID,:n         RESO+
1URCE_TYPE ,:n         PLANNED_START ,:n         PLANNED_FINISH ,:n         PL+
1ANNED_EFFORT ,:n         START_DATE ,:n         FINISH_DATE ,:n         WORK +
1,:n         REMAINING:n         ):n         SELECT:n         RESOURCE_ID,:n  +
1       RESOURCE_TYPE,:n         MIN(PLANNED_START) AS PLANNED_START,:n       +
1  MAX(PLANNED_FINISH) AS PLANNED_FINISH,:n         SUM(PLANNED_WORK) AS PLANN+
1ED_EFFORT,:n         MIN(SCHED_START) AS START_DATE,:n         MAX(SCHED_FINI+
1SH) AS FINISH_DATE,:n         SUM(SCHED_WORK) AS WORK,:n         SUM(ETC) AS +
1REMAINING:n         FROM TASK_ASSIGNMENTS WHERE PROJECT_ID=h_id AND PROJECT_A+
1SSIGNMENT_ID IS NuLL GROUP BY RESOURCE_ID, RESOURCE_TYPE:
1656:
1           EXCEPTION:: SP_S_PROFILE(657) :: cplan.sql(12930) :: :
1INSERT INTO PMO_TMP_CPLN01_TEMP(ELEMENT_ID,ELEMENT_NAME, PLANNED_START, PLANN+
1ED_FINISH, PLANNED_EFFORT,START_DATE, FINISH_DATE,:n         WORK, REMAINING)+
1:n         SELECT DISTINCT r.PROFILE_ID,r.PROFILE_NAME,:n         a.PLANNED_S+
1TART, a.PLANNED_FINISH,a.PLANNED_EFFORT, a.START_DATE, a.FINISH_DATE, a.WORK,+
1 a.REMAINING:n         FROM PMO_TMP_RES_SET a JOIN PROFILES r ON a.RESOURCE_T+
1YPE='1' AND r.PROFILE_ID=a.RESOURCE_ID JOIN TMT_COMPETENCIES c ON c.ELEMENT_I+
1D=r.ROLE_ID:n         JOIN TMT_COMPETENCIES d ON d.ELEMENT_ID=c.PARENT_ID:
1680:
1           EXCEPTION:: SP_S_PROFILE(681) :: cplan.sql(12954) :: :
1SELECT a.RESOURCE_ID AS ELEMENT_ID,'' AS RES_ASSIGNMENT_ID, p.FULL_NAME AS EL+
1EMENT_NAME,13 AS TYPE_ID,p.E_MAIL_ADDRESS,:n      a.PLANNED_START, a.PLANNED_+
1FINISH,a.PLANNED_EFFORT, a.START_DATE, a.FINISH_DATE, a.WORK, a.REMAINING,0 A+
1S T_UNIT,h_per_day AS MINUTE_PER_DAY,:n      '' AS BEST_START,'' AS BEST_FINI+
1SH, 0 AS CALENDAR, 0 AS PLANNED_WORK, 0 AS PERIOD_AVAILABILITY, '' AS ASSIGN_+
1STRING,p.FS_LABOR_CODE, '' AS OBJECTIVES,'' AS RANK:n      FROM PMO_TMP_RES_S+
1ET a JOIN RESOURCES p ON a.RESOURCE_TYPE = '0' AND a.RESOURCE_ID=p.RESOURCE_I+
1D:n      :n      UNION ALL:n      :n      SELECT ELEMENT_ID,'' AS RES_ASSIGNM+
1ENT_ID, ELEMENT_NAME,41 AS TYPE_ID,'' AS E_MAIL_ADDRESS,:n      PLANNED_START+
1, PLANNED_FINISH,PLANNED_EFFORT,   START_DATE, FINISH_DATE, WORK, REMAINING,0+
1 AS T_UNIT,h_per_day AS MINUTE_PER_DAY,:n      '' AS BEST_START,''  AS BEST_F+
1INISH,0 AS CALENDAR, 0 AS PLANNED_WORK, 0 AS PERIOD_AVAILABILITY, '' AS ASSIG+
1N_STRING,'' AS FS_LABOR_CODE, '' AS OBJECTIVES,'' AS RANK:n      FROM PMO_TMP+
1_CPLN01_TEMP ORDER BY TYPE_ID:
1697:
1                EXIT:: SP_S_PROFILE(698) :: cplan.sql(12971) :: :
15:
1739:
1           EXCEPTION:: SP_S_PROFILE(740) :: cplan.sql(13013) :: :
1INSERT INTO PMO_TMP_CPLN01_TEMP(ELEMENT_ID,ELEMENT_NAME, RESOURCE_TYPE, TYPE_+
1ID, E_MAIL_ADDRESS, PLANNED_START, PLANNED_FINISH, PLANNED_EFFORT,START_DATE,+
1 FINISH_DATE,:n         WORK, REMAINING, FS_LABOR_CODE):n         SELECT DIST+
1INCT r.PROFILE_ID ,r.PROFILE_NAME ,'1',41 ,'',:n         a.PLANNED_START, a.P+
1LANNED_FINISH,a.PLANNED_EFFORT, a.START_DATE, a.FINISH_DATE, a.WORK, a.REMAIN+
1ING,:n         '':n         FROM PMO_TMP_RES_SET a JOIN PROFILES r ON a.RESOU+
1RCE_TYPE='1' AND r.PROFILE_ID=a.RESOURCE_ID JOIN TMT_COMPETENCIES c ON c.ELEM+
1ENT_ID=r.ROLE_ID:n         JOIN TMT_COMPETENCIES d ON d.ELEMENT_ID=c.PARENT_I+
1D:n         UNION ALL:n         SELECT DISTINCT ra.RESOURCE_ID ,p.FULL_NAME ,+
1'0',185 ,p.E_MAIL_ADDRESS,:n         TO_TIMESTAMP('1899-12-31 00::00::00') , +
1TO_TIMESTAMP('1899-12-31 00::00::00') ,0 ,:n         TO_TIMESTAMP('1899-12-31+
1 00::00::00') , TO_TIMESTAMP('1899-12-31 00::00::00') , 0 , 0 ,p.FS_LABOR_COD+
1E:n         FROM RESOURCE_ASSIGNMENTS ra, RESOURCES p:n         WHERE ra.PROJ+
1ECT_ID=h_id AND ra.RESOURCE_ID = p.RESOURCE_ID:n         AND NOT EXISTS(SELEC+
1T ta.TSK_ASSIGNMENT_ID FROM TASK_ASSIGNMENTS ta:n         WHERE ta.RES_ASSIGN+
1MENT_ID IN (SELECT a.RES_ASSIGNMENT_ID:n         FROM RESOURCE_ASSIGNMENTS a +
1WHERE a.PROJECT_ID = ra.PROJECT_ID AND a.RESOURCE_ID = ra.RESOURCE_ID)):
1773:
1           EXCEPTION:: SP_S_PROFILE(774) :: cplan.sql(13047) :: :
1SELECT a.RESOURCE_ID AS ELEMENT_ID,'' AS RES_ASSIGNMENT_ID, p.FULL_NAME AS EL+
1EMENT_NAME,13 AS TYPE_ID,p.E_MAIL_ADDRESS,:n      a.PLANNED_START, a.PLANNED_+
1FINISH,a.PLANNED_EFFORT, a.START_DATE, a.FINISH_DATE, a.WORK, a.REMAINING,0 A+
1S T_UNIT,h_per_day AS MINUTE_PER_DAY,:n      '' AS BEST_START,'' AS BEST_FINI+
1SH, 0 AS CALENDAR, 0 AS PLANNED_WORK, 0 AS PERIOD_AVAILABILITY, '' AS ASSIGN_+
1STRING,p.FS_LABOR_CODE, '' AS OBJECTIVES,'' AS RANK:n      FROM PMO_TMP_RES_S+
1ET a JOIN RESOURCES p ON a.RESOURCE_TYPE = '0' AND a.RESOURCE_ID=p.RESOURCE_I+
1D:n      UNION ALL:n      SELECT ELEMENT_ID,'' AS RES_ASSIGNMENT_ID, ELEMENT_+
1NAME,TYPE_ID,E_MAIL_ADDRESS,:n      PLANNED_START, PLANNED_FINISH,PLANNED_EFF+
1ORT,   START_DATE, FINISH_DATE, WORK, REMAINING,0 AS T_UNIT,h_per_day AS MINU+
1TE_PER_DAY,:n      '' AS BEST_START,''  AS BEST_FINISH,0 AS CALENDAR, 0 AS PL+
1ANNED_WORK, 0 AS PERIOD_AVAILABILITY, '' AS ASSIGN_STRING, FS_LABOR_CODE, '' +
1AS OBJECTIVES,'' AS RANK:n      FROM PMO_TMP_CPLN01_TEMP WHERE RESOURCE_TYPE=+
1'1' AND TYPE_ID = 41:n      UNION ALL:n      SELECT ELEMENT_ID,'' AS RES_ASSI+
1GNMENT_ID, ELEMENT_NAME,TYPE_ID,E_MAIL_ADDRESS,:n      PLANNED_START, PLANNED+
1_FINISH,PLANNED_EFFORT,:n      START_DATE, FINISH_DATE, WORK, REMAINING,0 AS +
1T_UNIT,h_per_day AS MINUTE_PER_DAY,'' AS BEST_START,'' AS BEST_FINISH,:n     +
1 0 AS CALENDAR, 0 AS PLANNED_WORK, 0 AS PERIOD_AVAILABILITY, '' AS ASSIGN_STR+
1ING,FS_LABOR_CODE, '' AS OBJECTIVES,'' AS RANK:n      FROM PMO_TMP_CPLN01_TEM+
1P:n      WHERE RESOURCE_TYPE = '0' AND TYPE_ID = 185:n      ORDER BY TYPE_ID +
1DESC, ELEMENT_NAME:
1796:
1                EXIT:: SP_S_PROFILE(797) :: cplan.sql(13070) :: :
17:
1PLANNED_REMAINING:
1PA:
1DESCRIPTION:
1LEVEL_PLANNED_START:
1LEVEL_PLANNED_FINISH:
1LEVEL_SCHED_START:
1LEVEL_SCHED_FINISH:
1ESTIMATED_BASELINE1_START:
1ESTIMATED_BASELINE1_FINISH:
1ESTIMATED_BASELINE1_EFFORT:
1ESTIMATED_BASELINE3_START:
1ESTIMATED_BASELINE3_FINISH:
1ESTIMATED_BASELINE3_EFFORT:
1PROJECT_ASSIGNMENTS:
1SELECT t.RESOURCE_ID AS ELEMENT_ID, t.RES_ASSIGNMENT_ID, p.FULL_NAME AS ELEME+
1NT_NAME, 13 AS TYPE_ID,p.E_MAIL_ADDRESS,:n      b.PLANNED_START, b.PLANNED_FI+
1NISH, b.BEST AS PLANNED_EFFORT, b.PLANNED_WORK AS PLANNED_REMAINING, a.BAK_ST+
1ART_DT AS START_DATE, a.BAK_FINISH_DT AS FINISH_DATE,:n      a.BEST AS WORK, +
1a.SCHED_WORK AS REMAINING, h_per_day AS MINUTE_PER_DAY,'' AS BEST_START, '' A+
1S BEST_FINISH,:n      0 AS CALENDAR,0 AS PLANNED_WORK, 0 AS PERIOD_AVAILABILI+
1TY, '' AS ASSIGN_STRING,p.FS_LABOR_CODE, '' AS OBJECTIVES,'' AS RANK,:n      +
1pa.REGULAR_COST, pa.REGULAR_RATE, pa.SPECIAL_COST, pa.SPECIAL_RATE, pa.DESCRI+
1PTION,:n      pa.LEVEL_PLANNED_START, pa.LEVEL_PLANNED_FINISH, pa.LEVEL_SCHED+
1_START, pa.LEVEL_SCHED_FINISH,:n      pa.ESTIMATED_BASELINE1_START, pa.ESTIMA+
1TED_BASELINE1_FINISH, pa.ESTIMATED_BASELINE1_EFFORT,:n      pa.ESTIMATED_BASE+
1LINE3_START, pa.ESTIMATED_BASELINE3_FINISH, pa.ESTIMATED_BASELINE3_EFFORT:n  +
1    FROM RESOURCE_ASSIGNMENTS t JOIN PROJECT_ASSIGNMENTS pa ON pa.PROJECT_ID +
1= h_id AND pa.RESOURCE_ID = t.RESOURCE_ID:n      LEFT JOIN TASK_ASSIGNMENTS a+
1 ON a.RES_ASSIGNMENT_ID=t.RES_ASSIGNMENT_ID AND a.BIT_FLAG='2':n      LEFT JO+
1IN TASK_ASSIGNMENTS b ON b.RES_ASSIGNMENT_ID=t.RES_ASSIGNMENT_ID AND b.BIT_FL+
1AG='0':n      JOIN RESOURCES p ON t.RESOURCE_ID=p.RESOURCE_ID:n      WHERE t.+
1ELEMENT_ID=h_id AND t.RESOURCE_TYPE='0' AND (a.TSK_ASSIGNMENT_ID IS NOT NuLL +
1OR b.TSK_ASSIGNMENT_ID IS NOT NuLL):n      UNION ALL:n      SELECT t.RESOURCE+
1_ID AS ELEMENT_ID, a.RES_ASSIGNMENT_ID, p.PROFILE_NAME AS ELEMENT_NAME, 41 AS+
1 TYPE_ID,'' AS E_MAIL_ADDRESS,:n      t.PLANNED_START, t.PLANNED_FINISH,t.BES+
1T AS PLANNED_EFFORT,t.PLANNED_WORK AS PLANNED_REMAINING,TO_TIMESTAMP('1899-12+
1-31 00::00::00') AS START_DATE, TO_TIMESTAMP('1899-12-31 00::00::00') AS FINI+
1SH_DATE,:n      0 AS WORK,0 AS REMAINING,h_per_day AS MINUTE_PER_DAY,'' AS BE+
1ST_START, '' AS BEST_FINISH,:n      0 AS CALENDAR, 0 AS PLANNED_WORK, 0 AS PE+
1RIOD_AVAILABILITY, t.ASSIGN_STRING,'' AS FS_LABOR_CODE, '' AS OBJECTIVES,'' A+
1S RANK,:n      pa.REGULAR_COST, pa.REGULAR_RATE, pa.SPECIAL_COST, pa.SPECIAL_+
1RATE, pa.DESCRIPTION,:n      pa.LEVEL_PLANNED_START, pa.LEVEL_PLANNED_FINISH,+
1 pa.LEVEL_SCHED_START, pa.LEVEL_SCHED_FINISH,:n      pa.ESTIMATED_BASELINE1_S+
1TART, pa.ESTIMATED_BASELINE1_FINISH, pa.ESTIMATED_BASELINE1_EFFORT,:n      pa+
1.ESTIMATED_BASELINE3_START, pa.ESTIMATED_BASELINE3_FINISH, pa.ESTIMATED_BASEL+
1INE3_EFFORT:n      FROM RESOURCE_ASSIGNMENTS a JOIN PROFILES p ON a.RESOURCE_+
1ID=p.PROFILE_ID:n      JOIN TASK_ASSIGNMENTS t ON t.RES_ASSIGNMENT_ID=a.RES_A+
1SSIGNMENT_ID:n      JOIN PROJECT_ASSIGNMENTS pa ON pa.PROJECT_ID = h_id AND p+
1a.RESOURCE_ID = a.RESOURCE_ID:n      WHERE a.ELEMENT_ID=h_id AND a.RESOURCE_T+
1YPE='1':n      ORDER BY TYPE_ID DESC, ELEMENT_NAME:
1894:
1                EXIT:: SP_S_PROFILE(895) :: cplan.sql(13168) :: :
18:
1DELETE FROM PMO_TMP_PRJ_INFO:
1PMO_TMP_PRJ_INFO:
1PRJ_PLANNED_START:
1PRJ_PLANNED_FINISH:
1PRJ_SCHED_START:
1PRJ_SCHED_FINISH:
1SCHED_REMAINING:
1INSERT INTO PMO_TMP_PRJ_INFO:n         (RESOURCE_ID,:n         RESOURCE_TYPE,+
1:n         PRJ_PLANNED_START,:n         PRJ_PLANNED_FINISH,:n         PLANNED+
1_REMAINING,:n         PLANNED_EFFORT,:n         PRJ_SCHED_START ,:n         P+
1RJ_SCHED_FINISH,:n         SCHED_REMAINING,:n         WORK,:n         TYPE_ID+
1:n         ):n         SELECT:n         RESOURCE_ID,:n         RESOURCE_TYPE,+
1:n         MIN(PLANNED_START)  AS PRJ_PLANNED_START,:n         MAX(PLANNED_FI+
1NISH) AS PRJ_PLANNED_FINISH,:n         SUM(PLANNED_WORK)   AS PLANNED_REMAINI+
1NG,:n         SUM(CASE WHEN BIT_FLAG='0' THEN BEST ELSE 0 END) AS PLANNED_EFF+
1ORT,:n         MIN(SCHED_START)    AS PRJ_SCHED_START,:n         MAX(SCHED_FI+
1NISH)   AS PRJ_SCHED_FINISH,:n         SUM(SCHED_WORK)     AS SCHED_REMAINING+
1,:n         SUM(CASE WHEN BIT_FLAG='2' THEN BEST ELSE 0 END) AS WORK, 13:n   +
1      FROM TASK_ASSIGNMENTS:n         WHERE PROJECT_ID=h_id AND TASK_ID=h_id+
1:n         GROUP BY RESOURCE_ID, RESOURCE_TYPE:
1940:
1           EXCEPTION:: SP_S_PROFILE(941) :: cplan.sql(13214) :: :
1DELETE FROM PMO_TMP_RES_INFO:
1PMO_TMP_RES_INFO:
1INSERT INTO PMO_TMP_RES_INFO:n         (:n         RESOURCE_ID,:n         RES+
1OURCE_TYPE,:n         PLANNED_START,:n         PLANNED_FINISH,:n         PLAN+
1NED_EFFORT,:n         START_DATE,:n         FINISH_DATE,:n         WORK,:n   +
1      REMAINING,:n         PRJ_PLANNED_START,:n         PRJ_PLANNED_FINISH,:n+
1         PLANNED_REMAINING,:n         PRJ_SCHED_START,:n         PRJ_SCHED_FI+
1NISH,:n         SCHED_REMAINING,:n         LEVEL_PLANNED_START,:n         LEV+
1EL_PLANNED_FINISH,:n         LEVEL_SCHED_START,:n         LEVEL_SCHED_FINISH,+
1:n         ESTIMATED_BASELINE1_START,:n         ESTIMATED_BASELINE1_FINISH,:n+
1         ESTIMATED_BASELINE1_EFFORT,:n         ESTIMATED_BASELINE3_START,:n  +
1       ESTIMATED_BASELINE3_FINISH,:n         ESTIMATED_BASELINE3_EFFORT,:n   +
1      REGULAR_COST,:n         REGULAR_RATE,:n         SPECIAL_COST,:n        +
1 SPECIAL_RATE,:n         TYPE_ID,:n         DESCRIPTION:n         ):n        +
1 SELECT:n         a.RESOURCE_ID,      a.RESOURCE_TYPE,        a.PLANNED_START+
1,        a.PLANNED_FINISH,:n         a.PLANNED_WORK,     a.SCHED_START,      +
1    a.SCHED_FINISH,         a.SCHED_WORK,:n         a.ETC,              b.PRJ+
1_PLANNED_START,    b.PRJ_PLANNED_FINISH,   b.PLANNED_REMAINING,:n         b.P+
1RJ_SCHED_START,  b.PRJ_SCHED_FINISH,     b.SCHED_REMAINING,:n         a.LEVEL+
1_PLANNED_START, a.LEVEL_PLANNED_FINISH, a.LEVEL_SCHED_START, a.LEVEL_SCHED_FI+
1NISH,:n         a.ESTIMATED_BASELINE1_START, a.ESTIMATED_BASELINE1_FINISH, a.+
1ESTIMATED_BASELINE1_EFFORT,:n         a.ESTIMATED_BASELINE3_START, a.ESTIMATE+
1D_BASELINE3_FINISH, a.ESTIMATED_BASELINE3_EFFORT,:n         a.REGULAR_COST,  +
1   a.REGULAR_RATE,         a.SPECIAL_COST,         a.SPECIAL_RATE,:n         +
1COALESCE(b.TYPE_ID,CASE WHEN (a.PLANNED_WORK+a.SCHED_WORK) = 0 THEN 185 ELSE +
113 END), a.DESCRIPTION:n         FROM PROJECT_ASSIGNMENTS a LEFT OUTER JOIN P+
1MO_TMP_PRJ_INFO b ON a.RESOURCE_ID = b.RESOURCE_ID:n         WHERE a.PROJECT_+
1ID=h_id:
11007:
1           EXCEPTION:: SP_S_PROFILE(1008) :: cplan.sql(13281) :: :
1RI:
1UPDATE PMO_TMP_RES_INFO RI SET TYPE_ID = 13 WHERE TYPE_ID = 185 AND EXISTS(:n+
1         SELECT TASK_ID FROM TASK_ASSIGNMENTS T WHERE T.PROJECT_ID=h_id AND T+
1.RESOURCE_ID = RI.RESOURCE_ID AND T.RESOURCE_TYPE = '0'):
11026:
1           EXCEPTION:: SP_S_PROFILE(1027) :: cplan.sql(13300) :: :
1SELECT a.RESOURCE_ID AS ELEMENT_ID,'' AS RES_ASSIGNMENT_ID, p.FULL_NAME AS EL+
1EMENT_NAME, a.TYPE_ID,p.E_MAIL_ADDRESS,:n      a.PLANNED_START, a.PLANNED_FIN+
1ISH,a.PLANNED_EFFORT, a.START_DATE, a.FINISH_DATE, a.WORK, a.REMAINING,0 AS T+
1_UNIT,h_per_day AS MINUTE_PER_DAY,:n      '' AS BEST_START,'' AS BEST_FINISH,+
1 0 AS CALENDAR, 0 AS PLANNED_WORK, 0 AS PERIOD_AVAILABILITY, '' AS ASSIGN_STR+
1ING,p.FS_LABOR_CODE, '' AS OBJECTIVES,'' AS RANK,:n      CASE WHEN a.PRJ_PLAN+
1NED_START IS NOT NuLL OR a.PRJ_SCHED_START IS NOT NuLL THEN a.RESOURCE_ID ELS+
1E '' END AS PROJECT_ASSIGNMENT_ID, a.PRJ_PLANNED_START, a.PRJ_PLANNED_FINISH,+
1 a.PLANNED_REMAINING, a.PRJ_SCHED_START, a.PRJ_SCHED_FINISH, a.SCHED_REMAININ+
1G,:n      h_id AS PROJECT_ID,:n      a.LEVEL_PLANNED_START, a.LEVEL_PLANNED_F+
1INISH, a.LEVEL_SCHED_START, a.LEVEL_SCHED_FINISH,:n      a.ESTIMATED_BASELINE+
11_START, a.ESTIMATED_BASELINE1_FINISH, a.ESTIMATED_BASELINE1_EFFORT,:n      a+
1.ESTIMATED_BASELINE3_START, a.ESTIMATED_BASELINE3_FINISH, a.ESTIMATED_BASELIN+
1E3_EFFORT,:n      a.REGULAR_COST, a.REGULAR_RATE, a.SPECIAL_COST, a.SPECIAL_R+
1ATE, a.DESCRIPTION:n      FROM PMO_TMP_RES_INFO a JOIN RESOURCES p ON a.RESOU+
1RCE_TYPE = '0' AND a.RESOURCE_ID=p.RESOURCE_ID:n      UNION ALL:n      SELECT+
1  r.PROFILE_ID AS ELEMENT_ID,'' AS RES_ASSIGNMENT_ID, r.PROFILE_NAME AS ELEME+
1NT_NAME,41 AS TYPE_ID,'' AS E_MAIL_ADDRESS,:n      a.PLANNED_START, a.PLANNED+
1_FINISH,a.PLANNED_EFFORT, a.START_DATE, a.FINISH_DATE, a.WORK, a.REMAINING,0 +
1AS T_UNIT,h_per_day AS MINUTE_PER_DAY,:n      '' AS BEST_START,''  AS BEST_FI+
1NISH,0 AS CALENDAR, 0 AS PLANNED_WORK, 0 AS PERIOD_AVAILABILITY, '' AS ASSIGN+
1_STRING,'' AS FS_LABOR_CODE, '' AS OBJECTIVES,'' AS RANK,:n      CASE WHEN a.+
1PRJ_PLANNED_START IS NOT NuLL OR a.PRJ_SCHED_START IS NOT NuLL THEN a.RESOURC+
1E_ID ELSE '' END AS PROJECT_ASSIGNMENT_ID, a.PRJ_PLANNED_START, a.PRJ_PLANNED+
1_FINISH, a.PLANNED_REMAINING, a.PRJ_SCHED_START, a.PRJ_SCHED_FINISH, a.SCHED_+
1REMAINING,:n      h_id AS PROJECT_ID,:n      a.LEVEL_PLANNED_START, a.LEVEL_P+
1LANNED_FINISH, a.LEVEL_SCHED_START, a.LEVEL_SCHED_FINISH,:n      a.ESTIMATED_+
1BASELINE1_START, a.ESTIMATED_BASELINE1_FINISH, a.ESTIMATED_BASELINE1_EFFORT,+
1:n      a.ESTIMATED_BASELINE3_START, a.ESTIMATED_BASELINE3_FINISH, a.ESTIMATE+
1D_BASELINE3_EFFORT,:n      a.REGULAR_COST, a.REGULAR_RATE, a.SPECIAL_COST, a.+
1SPECIAL_RATE, a.DESCRIPTION:n      FROM PMO_TMP_RES_INFO a JOIN PROFILES r ON+
1 a.RESOURCE_TYPE='1' AND r.PROFILE_ID=a.RESOURCE_ID:n      JOIN TMT_COMPETENC+
1IES c ON c.ELEMENT_ID=r.ROLE_ID:n      JOIN TMT_COMPETENCIES d ON d.ELEMENT_I+
1D=c.PARENT_ID:
11055:
1                EXIT:: SP_S_PROFILE(1056) :: cplan.sql(13329) :: :
1SELECT PROFILE_NAME INTO h_in FROM PROFILES WHERE PROFILE_ID = h_id:
11067:
1           EXCEPTION:: SP_S_PROFILE(1068) :: cplan.sql(13341) :: :
1SC_SQL_SUCCESS:
1ROLE_TYPE:
1ORG_ID:
1ORG:
1ORG_NAME:
1GEO_ID:
1GEO:
1GEO_NAME:
1POOL_ID:
1POOL:
1POOL_NAME:
1TMT_ORGANIZATIONS:
1TMT_GEOGRAPHIES:
1DS:
1CS:
1PMO_ORASTD:
1STRINGCONCAT:
1RTRIM:
1SELECT h_id AS ELEMENT_ID, h_in AS ELEMENT_NAME,41 AS TYPE_ID,30 AS ROLE_TYPE+
1, p.ROLE_ID, h_in AS ROLE_NAME,:n         ORG_ID, org.ELEMENT_NAME AS ORG_NAM+
1E, GEO_ID, geo.ELEMENT_NAME AS GEO_NAME, POOL_ID, pool.ELEMENT_NAME AS POOL_N+
1AME:n         FROM PROFILES p:n         LEFT JOIN TMT_ORGANIZATIONS org ON or+
1g.ELEMENT_ID  = ORG_ID:n         LEFT JOIN TMT_GEOGRAPHIES geo   ON geo.ELEME+
1NT_ID  = GEO_ID:n         LEFT JOIN TMT_POOLS pool        ON pool.ELEMENT_ID +
1= POOL_ID:n         WHERE p.PROFILE_ID = h_id:n         UNION ALL:n         S+
1ELECT h_id AS ELEMENT_ID, h_in AS ELEMENT_NAME,41 AS TYPE_ID,ds.TYPE_ID AS RO+
1LE_TYPE,:n         cs.ELEMENT_ID AS ROLE_ID, PMO_ORASTD.StringConcat(PMO_ORAS+
1TD.StringConcat(RTRIM(ds.ELEMENT_NAME), ', '), RTRIM(cs.ELEMENT_NAME)) AS ROL+
1E_NAME,:n         '' ORG_ID, '' AS ORG_NAME, '' GEO_ID, '' AS GEO_NAME, '' PO+
1OL_ID, '' AS POOL_NAME:n         FROM RESOURCE_ASSIGN_ROLES r LEFT OUTER JOIN+
1 TMT_COMPETENCIES cs ON r.ROLE_ID=cs.ELEMENT_ID:n         LEFT OUTER JOIN TMT+
1_COMPETENCIES ds ON ds.ELEMENT_ID=cs.PARENT_ID WHERE r.RES_ASSIGNMENT_ID=h_id+
1:n         UNION ALL:n         SELECT h_id AS ELEMENT_ID, h_in AS ELEMENT_NAM+
1E,41 AS TYPE_ID,ds.TYPE_ID AS ROLE_TYPE,:n         cs.ELEMENT_ID AS ROLE_ID, +
1PMO_ORASTD.StringConcat(PMO_ORASTD.StringConcat(RTRIM(ds.ELEMENT_NAME), ', ')+
1, RTRIM(cs.ELEMENT_NAME)) AS ROLE_NAME,:n         '' ORG_ID, '' AS ORG_NAME, +
1'' GEO_ID, '' AS GEO_NAME, '' POOL_ID, '' AS POOL_NAME:n         FROM RESOURC+
1E_ASSIGN_SKILLS s LEFT OUTER JOIN TMT_COMPETENCIES cs ON s.SKILL_ID=cs.ELEMEN+
1T_ID:n         LEFT OUTER JOIN TMT_COMPETENCIES ds ON ds.ELEMENT_ID=cs.PARENT+
1_ID WHERE s.RES_ASSIGNMENT_ID=h_id:n         ORDER BY ELEMENT_ID,TYPE_ID:
11094:
1                EXIT:: SP_S_PROFILE(1095) :: cplan.sql(13368) :: :
1SELECT CASE WHEN t.TSK_ASSIGNMENT_ID IS NOT NuLL THEN t.TSK_ASSIGNMENT_ID ELS+
1E a.RES_ASSIGNMENT_ID END AS ELEMENT_ID, a.RESOURCE_ID,:n      CASE WHEN a.RE+
1SOURCE_TYPE='1' THEN (SELECT p.PROFILE_NAME FROM PROFILES p WHERE a.RESOURCE_+
1ID = p.PROFILE_ID):n      ELSE (SELECT r.FULL_NAME FROM RESOURCES r WHERE a.R+
1ESOURCE_ID = r.RESOURCE_ID) END AS ELEMENT_NAME,:n      CASE WHEN t.TSK_ASSIG+
1NMENT_ID IS NuLL THEN 185 WHEN a.RESOURCE_TYPE='1' THEN 41 ELSE 13 END AS TYP+
1E_ID,:n      a.RES_ASSIGNMENT_ID, a.PARTICIPANT, t.START_DT,t.FINISH_DT,:n   +
1   t.SD, t.FD, t.UNRESOLVED_START AS PLANNED_START, t.UNRESOLVED_FINISH AS PL+
1ANNED_FINISH,:n      CASE WHEN BIT_FLAG = '2' THEN SCHED_WORK ELSE PLANNED_WO+
1RK END AS PLANNED_WORK,:n      CASE WHEN BIT_FLAG = '2' THEN SCHED_WORK - WOR+
1K_TODATE ELSE PLANNED_WORK END AS REMAINING,:n      CASE WHEN t.ASSIGN_UNITS +
1> t.UNITS_MSP THEN t.ASSIGN_UNITS ELSE t.UNITS_MSP END AS UNITS_PERCENT,:n   +
1   0 AS MILESTONE_PERCENT,:n      CASE WHEN t.WORK_TODATE = 0 THEN 0 ELSE Tru+
1nc((TO_NUMBER(t.WORK_TODATE)/TO_NUMBER(PLANNED_WORK+SCHED_WORK))*10000) END A+
1S WORK_PERCENT,:n      t.BAK_START_DT,t.BAK_FINISH_DT,t.BAK_WORK,:n      t.FO+
1RECAST_START,t.FORECAST_FINISH,t.ETC, t.ACTUAL_START,t.ACTUAL_FINISH,:n      +
1t.WORK_TODATE AS ACTUAL,PROPOSED_START, PROPOSED_FINISH, PROPOSED_WORK,:n    +
1  h_per_day AS MINUTE_PER_DAY, a.WORK_LOCATION, a.SECURITY_ID, g.ELEMENT_NAME+
1 AS SECURITY_NAME,:n      COALESCE(a.CRI_SECURITY_ID,a.SECURITY_ID) AS CRI_SE+
1CURITY_ID, g2.ELEMENT_NAME AS CRI_SECURITY_NAME, t.REGULAR_COST,t.REGULAR_RAT+
1E,t.SPECIAL_COST,t.SPECIAL_RATE,:n      CASE WHEN a.RESOURCE_TYPE='0' THEN (S+
1ELECT r.FS_LABOR_CODE FROM RESOURCES r WHERE a.RESOURCE_ID = r.RESOURCE_ID):n+
1      ELSE '' END AS FS_LABOR_CODE,a.REC_STATUS,t.ASSIGN_STRING,t.BASELINE1_S+
1TART,t.BASELINE1_FINISH,t.BASELINE1_WORK,:n      t.PROJECT_ASSIGNMENT_ID,t.TI+
1MECODE2_ID, TC.ELEMENT_NAME AS TIMECODE2_NAME, t.T_UNIT, t.C_EFFORT, t.C_UNIT+
1, t.C_CONTOUR, t.CONTOUR_TYPE, t.C_OCCURRENCE, t.BILLABLE, t.CAPITAL_EXPENSE,+
1:n      t.ASSIGNMENT_DELAY, CASE WHEN t.BIT_FLAG IS NuLL THEN '' WHEN t.BIT_F+
1LAG = '0' THEN '1' ELSE '2' END AS BIT_FLAG, t.RATE_ADJUSTMENT, 0 AS ASSIGN_C+
1OUNT, t.UNRESOLVED_DURATION AS DURATION,:n      CASE WHEN h_level_state = 1 T+
1HEN COALESCE(t.LEVEL_START,t.UNRESOLVED_START) ELSE TO_TIMESTAMP('1899-12-31 +
100::00::00') END AS LEVEL_START,:n      CASE WHEN h_level_state = 1 THEN COAL+
1ESCE(t.LEVEL_FINISH,t.UNRESOLVED_FINISH) ELSE TO_TIMESTAMP('1899-12-31 00::00+
1::00') END AS LEVEL_FINISH,:n      CASE WHEN h_level_state = 1 THEN CASE WHEN+
1 t.LEVEL_EFFORT = 0 THEN t.ETC ELSE t.LEVEL_EFFORT END ELSE 0 END AS LEVEL_EF+
1FORT, t.MILESTONE_PERCENT AS PERCENT_DISCRETE, 0 as TOP_ID,:n      CASE WHEN +
1t.TSK_ASSIGNMENT_ID IS NOT NuLL AND t.PROJECT_ASSIGNMENT_ID = t.TSK_ASSIGNMEN+
1T_ID AND (t.LEVEL_START <> t.UNRESOLVED_START OR t.LEVEL_FINISH <> t.UNRESOLV+
1ED_FINISH) THEN '1' ELSE '0' END AS LEVEL_AFFECTED_FLAG,:n      T.LABOR_COST_+
1CC_ID,:n      EC.ELEMENT_NAME AS LABOR_COST_CC_NAME,:n      T.LABOR_REVENUE_C+
1C_ID,:n      CC.ELEMENT_NAME AS LABOR_REVENUE_CC_NAME, T.DEFAULT_LABOR_FLAG,+
1:n      T.CONTRACT_ID, CTR.ELEMENT_NAME AS CONTRACT_NAME:n      FROM RESOURCE+
1_ASSIGNMENTS a JOIN TASK_ASSIGNMENTS t ON t.TSK_ASSIGNMENT_ID = h_id AND a.RE+
1S_ASSIGNMENT_ID = t.RES_ASSIGNMENT_ID:n      LEFT OUTER JOIN TMT_GLOBAL_SECUR+
1ITY g ON a.SECURITY_ID=g.ELEMENT_ID:n      LEFT OUTER JOIN TMT_GLOBAL_SECURIT+
1Y g2 ON COALESCE(a.CRI_SECURITY_ID,a.SECURITY_ID)=g2.ELEMENT_ID:n      LEFT O+
1UTER JOIN TMT_TIMECODES TC ON TC.ELEMENT_ID= t.TIMECODE2_ID:n      LEFT OUTER+
1 JOIN TMT_CHARGECODES EC ON EC.ELEMENT_ID = T.LABOR_COST_CC_ID:n      LEFT OU+
1TER JOIN TMT_CHARGECODES CC ON CC.ELEMENT_ID = T.LABOR_REVENUE_CC_ID:n      L+
1EFT OUTER JOIN TMT_CONTRACTS CTR ON CTR.ELEMENT_ID = T.CONTRACT_ID:n      ORD+
1ER BY TYPE_ID DESC, ELEMENT_NAME:
11137:
1                EXIT:: SP_S_PROFILE(1138) :: cplan.sql(13411) :: :
1SC_PROFILE:
1ACCEPTED_DATE:
1DELAY:
1SELECT a.RES_ASSIGNMENT_ID AS ELEMENT_ID, a.RESOURCE_ID,:n      CASE WHEN a.R+
1ESOURCE_TYPE='1' THEN (SELECT p.PROFILE_NAME FROM PROFILES p WHERE a.RESOURCE+
1_ID = p.PROFILE_ID):n      ELSE (SELECT r.FULL_NAME FROM RESOURCES r WHERE a.+
1RESOURCE_ID = r.RESOURCE_ID) END AS ELEMENT_NAME,:n      CASE WHEN a.RESOURCE+
1_TYPE='1' THEN PMO_CNST.SC_PROFILE ELSE 185 END AS TYPE_ID,  a.RES_ASSIGNMENT+
1_ID, a.PARTICIPANT, TO_TIMESTAMP('1899-12-31 00::00::00') AS PLANNED_START, T+
1O_TIMESTAMP('1899-12-31 00::00::00') AS PLANNED_FINISH,:n      0 AS PLANNED_W+
1ORK,TO_TIMESTAMP('1899-12-31 00::00::00') AS START_DT,TO_TIMESTAMP('1899-12-3+
11 00::00::00') AS FINISH_DT,:n      TO_TIMESTAMP('1899-12-31 00::00::00') AS +
1SCHED_START,TO_TIMESTAMP('1899-12-31 00::00::00') AS SCHED_FINISH, 0 AS SCHED+
1_WORK,:n      TO_TIMESTAMP('1899-12-31 00::00::00') AS BAK_START_DT,TO_TIMEST+
1AMP('1899-12-31 00::00::00') AS BAK_FINISH_DT, 0 AS BAK_WORK,:n      TO_TIMES+
1TAMP('1899-12-31 00::00::00') AS FORECAST_START,TO_TIMESTAMP('1899-12-31 00::+
100::00') AS FORECAST_FINISH,0 AS ETC,:n      TO_TIMESTAMP('1899-12-31 00::00+
1::00') AS ACTUAL_START,TO_TIMESTAMP('1899-12-31 00::00::00') AS ACTUAL_FINISH+
1,:n      0 AS ACTUAL,h_per_day AS MINUTE_PER_DAY, a.WORK_LOCATION, TO_TIMESTA+
1MP('1899-12-31 00::00::00') AS ACCEPTED_DATE,:n      a.SECURITY_ID, g.ELEMENT+
1_NAME AS SECURITY_NAME, COALESCE(a.CRI_SECURITY_ID,a.SECURITY_ID) AS CRI_SECU+
1RITY_ID, g2.ELEMENT_NAME AS CRI_SECURITY_NAME,:n      0 AS REGULAR_COST,0 AS +
1REGULAR_RATE,0 AS SPECIAL_COST, 0 AS SPECIAL_RATE,:n      CASE WHEN a.RESOURC+
1E_TYPE='0' THEN (SELECT r.FS_LABOR_CODE FROM RESOURCES r WHERE a.RESOURCE_ID +
1= r.RESOURCE_ID):n      ELSE '' END AS FS_LABOR_CODE,:n      a.REC_STATUS,'' +
1AS ASSIGN_STRING,:n      TO_TIMESTAMP('1899-12-31 00::00::00') AS BASELINE1_S+
1TART,TO_TIMESTAMP('1899-12-31 00::00::00') AS BASELINE1_FINISH,0 AS BASELINE1+
1_WORK,:n      '' AS PROJECT_ASSIGNMENT_ID, '' AS TIMECODE2_ID, '' AS TIMECODE+
12_NAME, 0 AS T_UNIT,:n      0 AS C_EFFORT, 0 AS C_UNIT, 0 AS C_CONTOUR, 0 AS +
1CONTOUR_TYPE, 0 AS C_OCCURRENCE, 0 AS BILLABLE,:n      0 AS DELAY:n      FROM+
1 RESOURCE_ASSIGNMENTS a:n      LEFT OUTER JOIN TMT_GLOBAL_SECURITY g ON a.SEC+
1URITY_ID=g.ELEMENT_ID:n      LEFT OUTER JOIN TMT_GLOBAL_SECURITY g2 ON COALES+
1CE(a.CRI_SECURITY_ID,a.SECURITY_ID)=g2.ELEMENT_ID:n      WHERE a.REC_STATUS N+
1OT IN ('L','D') AND a.ELEMENT_ID = h_id:n      ORDER BY TYPE_ID DESC, ELEMENT+
1_NAME:
11166:
1                EXIT:: SP_S_PROFILE(1167) :: cplan.sql(13440) :: :
112:
1DELETE FROM PMO_TMP_RTA:
1PMO_TMP_RTA:
1PA_FLAG:
1TABLE_TYPE:
1SC_TABLE_WBS:
1INSERT INTO PMO_TMP_RTA (RESOURCE_ID, RESOURCE_TYPE, PA_FLAG):n         SELEC+
1T RESOURCE_ID, RESOURCE_TYPE, 'N' AS PA_FLAG:n         FROM TASK_ASSIGNMENTS+
1:n         WHERE PROJECT_ID = h_id AND:n         PROJECT_ASSIGNMENT_ID IS NuL+
1L AND:n         TABLE_TYPE = PMO_CNST.SC_TABLE_WBS:n         GROUP BY RESOURC+
1E_ID, RESOURCE_TYPE:
11194:
1           EXCEPTION:: SP_S_PROFILE(1195) :: cplan.sql(13468) :: :
1DELETE FROM PMO_TMP_CP_PRJ:
1PMO_TMP_CP_PRJ:
1INSERT INTO PMO_TMP_CP_PRJ (RESOURCE_ID, RESOURCE_TYPE, PA_FLAG):n         SE+
1LECT  RESOURCE_ID, RESOURCE_TYPE, 'Y' AS PA_FLAG:n         FROM TASK_ASSIGNME+
1NTS:n         WHERE PROJECT_ID = h_id AND:n         TASK_ID = h_id:n         +
1GROUP BY RESOURCE_ID, RESOURCE_TYPE:
11220:
1           EXCEPTION:: SP_S_PROFILE(1221) :: cplan.sql(13494) :: :
1DELETE FROM PMO_TMP_RESOURCE_DATA:
1PMO_TMP_RESOURCE_DATA:
1INSERT INTO PMO_TMP_RESOURCE_DATA (RESOURCE_ID, RESOURCE_TYPE, PA_FLAG):n    +
1     SELECT a.RESOURCE_ID, a.RESOURCE_TYPE, a.PA_FLAG:n         FROM PMO_TMP_+
1RTA a LEFT OUTER JOIN PMO_TMP_CP_PRJ b ON a.RESOURCE_ID=b.RESOURCE_ID:n      +
1   UNION:n         SELECT b.RESOURCE_ID, b.RESOURCE_TYPE, b.PA_FLAG:n        +
1 FROM PMO_TMP_CP_PRJ b LEFT OUTER JOIN PMO_TMP_RTA a ON a.RESOURCE_ID=b.RESOU+
1RCE_ID:
11246:
1           EXCEPTION:: SP_S_PROFILE(1247) :: cplan.sql(13520) :: :
1NICK_NAME:
1PRJ:
1RD:
1SELECT a.RESOURCE_ID AS ELEMENT_ID, p.FULL_NAME AS ELEMENT_NAME,13 AS TYPE_ID+
1, p.NICK_NAME, a.PA_FLAG:n      FROM PMO_TMP_RESOURCE_DATA a JOIN RESOURCES p+
1 ON a.RESOURCE_TYPE = '0' AND a.RESOURCE_ID=p.RESOURCE_ID:n      LEFT OUTER J+
1OIN PMO_TMP_CP_PRJ PRJ ON a.RESOURCE_ID=PRJ.RESOURCE_ID:n      :n      UNION +
1ALL:n      :n      SELECT DISTINCT r.PROFILE_ID AS ELEMENT_ID, r.PROFILE_NAME+
1 AS ELEMENT_NAME,41 AS TYPE_ID, ' ' AS NICK_NAME, a.PA_FLAG:n      FROM PMO_T+
1MP_RESOURCE_DATA a JOIN PROFILES r ON a.RESOURCE_TYPE = '1' AND r.PROFILE_ID +
1= a.RESOURCE_ID:n      JOIN TMT_COMPETENCIES c ON c.ELEMENT_ID=r.ROLE_ID:n   +
1   JOIN TMT_COMPETENCIES d ON d.ELEMENT_ID=c.PARENT_ID:n      LEFT OUTER JOIN+
1 PMO_TMP_CP_PRJ PRJ ON a.RESOURCE_ID=PRJ.RESOURCE_ID:n      :n      UNION ALL+
1:n      :n      SELECT DISTINCT ra.RESOURCE_ID AS ELEMENT_ID, p.FULL_NAME AS +
1ELEMENT_NAME, 185 AS TYPE_ID, p.NICK_NAME, 'N' AS PA_FLAG:n      FROM RESOURC+
1E_ASSIGNMENTS ra, RESOURCES p:n      WHERE ra.PROJECT_ID=h_id AND:n      ra.R+
1ESOURCE_ID = p.RESOURCE_ID AND:n      NOT EXISTS(SELECT rd.RESOURCE_ID FROM P+
1MO_TMP_RESOURCE_DATA rd WHERE ra.RESOURCE_ID = rd.RESOURCE_ID):n      ORDER B+
1Y TYPE_ID DESC, ELEMENT_NAME:
11272:
1                EXIT:: SP_S_PROFILE(1273) :: cplan.sql(13546) :: :
1SELECT t.ELEMENT_ID, p.FULL_NAME AS ELEMENT_NAME,13 AS TYPE_ID, p.NICK_NAME, +
1'N' AS PA_FLAG:n      FROM TMT_POOLS t JOIN RESOURCES p:n      ON t.ELEMENT_I+
1D = p.RESOURCE_ID:n      WHERE t.TYPE_ID = 13:n      AND t.RANK LIKE h_rank |+
1| '%':n      ORDER BY ELEMENT_NAME:
11286:
1                EXIT:: SP_S_PROFILE(1287) :: cplan.sql(13560) :: :
1SC_RESOURCE:
1SELECT R.RESOURCE_ID AS ELEMENT_ID, R.FULL_NAME AS ELEMENT_NAME,PMO_CNST.SC_R+
1ESOURCE AS TYPE_ID, R.NICK_NAME, 'N' AS PA_FLAG:n      FROM PROJECT_ASSIGNMEN+
1TS RA, RESOURCES R:n      WHERE RA.PROJECT_ID = h_id:n      AND RA.RESOURCE_I+
1D = R.RESOURCE_ID:n      ORDER BY ELEMENT_NAME:
11300:
1                EXIT:: SP_S_PROFILE(1301) :: cplan.sql(13574) :: :
11305:
1       RETURN_STATUS:: SP_S_PROFILE(1306) :: cplan.sql(13579) :: :
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
11314:
1           EXCEPTION:: SP_S_PROFILE(1315) :: cplan.sql(13588) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1ERROR:
1ID:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
11326:
1           EXCEPTION:: SP_S_PROFILE(1327) :: cplan.sql(13600) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
1f2b
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 :2 a0 6b 1c 81 b0
a3 :2 a0 6b 1c 81 b0 a3 :2 a0
6b 1c 81 b0 a3 :2 a0 6b 1c
81 b0 a3 :2 a0 6b 1c 81 b0
a3 :2 a0 6b 1c 81 b0 a3 :2 a0
6b 1c 81 b0 a3 :2 a0 6b 1c
81 b0 a3 :2 a0 6b 1c 81 b0
a3 :2 a0 6b 1c 81 b0 a3 :2 a0
6b 1c 81 b0 a3 :2 a0 6b 1c
81 b0 a3 :2 a0 6b 1c 81 b0
a3 :2 a0 6b 1c 81 b0 a3 :2 a0
6b 1c 81 b0 a3 :2 a0 6b 1c
81 b0 :2 a0 6b :2 a0 6b 6e a5
b a 10 :2 a0 6b 6e :2 a0 6b
6e a5 b 6e 7e a0 b4 2e
6e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :3 a0 a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c a0 7e
b4 2e 5a :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b :2 a0
a5 57 b7 19 3c :2 a0 d :2 a0
d :2 a0 d :2 a0 51 a5 b 7e
51 b4 2e 5a :2 a0 51 a5 b
7e 51 b4 2e 5a 52 10 :18 a0
12a :2 a0 6b a0 d b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 6b a0 7e a0 6b
b4 2e 5a :15 a0 12a :2 a0 6b a0
d b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
a0 7e a0 6b b4 2e 5a :4 a0
12a :2 a0 6b a0 d b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 6b a0 7e a0 6b
b4 2e 5a :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b :2 a0
a5 57 b7 19 3c b7 19 3c
b7 19 3c a0 b7 :2 a0 51 a5
b 7e 51 b4 2e :5 a0 12a :2 a0
6b a0 d b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 6b a0 7e a0 6b b4 2e
5a :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b :2 a0 a5 57
b7 19 3c :8 a0 12a :2 a0 6b a0
d b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f a0 b7
19 :2 a0 51 a5 b 7e 51 b4
2e :5 a0 12a :2 a0 6b a0 d b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 6b a0 7e
a0 6b b4 2e 5a :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b :2 a0 a5 57 b7 19 3c a0
51 d a0 b7 19 :2 a0 51 a5
b a0 7e a0 6b b4 2e 5a
:2 a0 51 a5 b 7e 51 b4 2e
5a a 10 :2 a0 51 a5 b a0
7e a0 6b b4 2e 5a a 10
:2 a0 51 a5 b a0 7e a0 6b
b4 2e 5a a 10 :8 a0 12a :2 a0
6b a0 d b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 6b a0 7e a0 6b b4 2e
5a :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b :2 a0 a5 57
b7 19 3c b7 :2 19 3c :2 a0 51
a5 b 7e 51 b4 2e :2 a0 6e
11e 11d :2 a0 6b 51 d :22 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
6e 11e 11d :2 a0 6b 51 d :7 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:12d a0 12a e9 dd :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
65 a0 b7 :2 a0 51 a5 b 7e
51 b4 2e 5a :2 a0 51 a5 b
7e 51 b4 2e 5a 52 10 :2 a0
6e 11e 11d :2 a0 6b 51 d :26 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 6b a0 b4 2e d :2e a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :49 a0
12a e9 dd :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 65
a0 b7 19 :2 a0 51 a5 b 7e
51 b4 2e :8d a0 12a e9 dd :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 65 a0 b7 19 :2 a0
51 a5 b 7e 51 b4 2e :3 a0
51 a5 b a5 b 7e 51 b4
2e a0 51 d :7 a0 12a :2 a0 6b
a0 d b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
51 a5 b 7e 51 b4 2e a0
6e d b7 :9 a0 12a :2 a0 6b a0
d b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 51
a5 b 7e 51 b4 2e :1c a0 12a
:2 a0 6b a0 d b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 51 a5 b 7e 51 b4
2e a0 6e d b7 a0 6e d
b7 :2 19 3c b7 a0 6e d b7
:2 19 3c b7 :2 19 3c :1f7 a0 12a e9
dd :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :2 a0 65 b7 :11d a0
12a e9 dd :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 65
b7 :2 19 3c a0 b7 19 :2 a0 51
a5 b 7e 51 b4 2e :2 a0 6e
11e 11d :2 a0 6b 51 d :27 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
6b a0 b4 2e d :35 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :4c a0 12a
e9 dd :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 65 a0
b7 19 :2 a0 51 a5 b 7e 51
b4 2e :2 a0 6e 11e 11d :2 a0 6b
51 d :27 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 6b a0 b4 2e
d :62 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :6a a0 12a e9 dd :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 65 a0 b7 19 :2 a0 51
a5 b 7e 51 b4 2e :e2 a0 12a
e9 dd :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 65 a0
b7 19 :2 a0 51 a5 b 7e 51
b4 2e :2 a0 6e 11e 11d :2 a0 6b
51 d :2f a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 6e 11e 11d :2 a0
6b 51 d :71 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :10 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :d5 a0 12a e9
dd :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :2 a0 65 a0 b7
19 :2 a0 51 a5 b a0 7e a0
6b b4 2e :5 a0 12a :2 a0 6b a0
d b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
a0 7e a0 6b b4 2e 5a :9a a0
12a e9 dd :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 65
b7 19 3c a0 b7 19 :2 a0 51
a5 b 7e 51 b4 2e :13e a0 12a
e9 dd :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 65 a0
b7 19 :2 a0 51 a5 b 7e 51
b4 2e :94 a0 12a e9 dd :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 65 a0 b7 19 :2 a0 51
a5 b 7e 51 b4 2e :2 a0 6e
11e 11d :2 a0 6b 51 d :10 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
6e 11e 11d :2 a0 6b 51 d :e a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 6e 11e 11d :2 a0 6b 51 d
:26 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :6c a0 12a e9 dd :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 65 a0 b7 19 :2 a0 51 a5
b 7e 51 b4 2e :1a a0 12a e9
dd :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :2 a0 65 a0 b7
19 :2 a0 51 a5 b a0 7e a0
6b b4 2e 5a :2 a0 51 a5 b
a0 7e a0 6b b4 2e 5a 52
10 :1a a0 12a e9 dd :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 65 b7 19 :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :4 a0 6b a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b :2 a0 a5 57
b7 :2 19 3c b7 :2 a0 6b :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 :2 a0 6b
:2 6e 7e :2 a0 6b b4 2e 7e 6e
b4 2e 7e :2 a0 6b b4 2e a5
57 b7 19 3c :9 a0 12a e9 dd
:2 a0 65 b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c :7 a0 12a e9 dd :2 a0 65
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 68 4f 1d 17 b5 
1f2b
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 30
56 5a 5e 62 65 69 86 71
75 78 79 81 70 a3 91 6d
95 96 9e 90 c0 ae 8d b2
b3 bb ad dd cb aa cf d0
d8 ca fa e8 c7 ec ed f5
e7 117 105 e4 109 10a 112 104
133 122 126 101 12e 121 14f 13e
142 11e 14a 13d 16b 15a 15e 13a
166 159 187 176 17a 156 182 175
1a3 192 196 172 19e 191 1bf 1ae
1b2 18e 1ba 1ad 1df 1ca 1ce 1aa
1d2 1da 1c9 1ff 1ea 1ee 1c6 1f2
1fa 1e9 21f 20a 20e 1e6 212 21a
209 23f 22a 22e 206 232 23a 229
25f 24a 24e 226 252 25a 249 27f
26a 26e 246 272 27a 269 29f 28a
28e 266 292 29a 289 2bf 2aa 2ae
286 2b2 2ba 2a9 2df 2ca 2ce 2a6
2d2 2da 2c9 2ff 2ea 2ee 2c6 2f2
2fa 2e9 31f 30a 30e 2e6 312 31a
309 33f 32a 32e 306 332 33a 329
35f 34a 34e 326 352 35a 349 37f
36a 36e 346 372 37a 369 39f 38a
38e 366 392 39a 389 3bf 3aa 3ae
386 3b2 3ba 3a9 3c6 3ca 3a6 3ce
3d2 3d6 3d9 3de 3df 1 3e1 3e6
3ea 3ee 3f1 3f6 3fa 3fe 401 406
407 409 40e 411 415 416 41b 420
423 428 429 42e 431 435 436 43b
43e 443 444 449 44c 451 452 457
45a 45e 462 466 467 469 46e 46f
471 472 477 47a 47f 480 485 488
48d 48e 493 496 49a 49b 4a0 4a3
4a8 4a9 4ae 4b1 4b6 4b7 4bc 4bd
4c2 4c4 4c8 4cb 4cf 4d3 4d6 4da
4de 4e1 4e4 4e9 4ec 4ef 4f2 4f3
4f8 4f9 1 4fb 500 504 508 50b
510 515 518 51c 51d 522 523 528
52a 52e 531 535 538 539 53e 541
545 549 54c 550 554 557 55a 55f
562 565 568 569 56e 56f 1 571
576 57a 57e 581 586 58b 58e 592
593 598 59b 5a0 5a1 5a6 5a9 5ae
5af 5b4 5b7 5bb 5bf 5c3 5c7 5ca
5cb 5cd 5d2 5d3 5d5 5d6 5db 5de
5e3 5e4 5e9 5ec 5f1 5f2 5f7 5fa
5fe 5ff 604 607 60c 60d 612 613
618 61a 61e 621 625 629 62c 630
634 637 63a 63f 642 645 648 649
64e 64f 1 651 656 65a 65e 661
666 66b 66e 672 673 678 679 67e
680 684 687 68b 68f 692 696 69a
69d 6a1 6a5 6a6 6ab 6ad 6b1 6b4
6b8 6bc 6c0 6c4 6c8 6cc 6d0 6d4
6d8 6dc 6e0 6e3 6e4 6e6 6e9 6ec
6ed 6f2 6f5 6f9 6fd 700 701 703
706 709 70a 70f 1 712 717 71b
71f 723 727 72b 72f 733 737 73b
73f 743 747 74b 74f 753 757 75b
75f 763 767 76b 76f 773 777 783
787 78b 78e 792 796 798 1 79c
7a0 7a4 7a7 7ab 7af 7b3 7b7 7ba
7be 7c2 7c5 7c8 7cd 7d0 7d3 7d6
7d7 7dc 7dd 1 7df 7e4 7e8 7ec
7ef 7f4 7f9 7fc 800 801 806 809
80e 80f 814 817 81c 81d 822 825
829 82a 82f 832 837 838 83d 840
844 848 84b 84e 84f 851 852 857
858 85d 85f 863 866 868 86c 86e
87a 87c 87e 87f 884 888 88a 896
898 89c 8a0 8a3 8a7 8aa 8ae 8b1
8b2 8b7 8ba 8be 8c2 8c6 8ca 8ce
8d2 8d6 8da 8de 8e2 8e6 8ea 8ee
8f2 8f6 8fa 8fe 902 906 90a 90e
91a 91e 922 925 929 92d 92f 1
933 937 93b 93e 942 946 94a 94e
951 955 959 95c 95f 964 967 96a
96d 96e 973 974 1 976 97b 97f
983 986 98b 990 993 997 998 99d
9a0 9a5 9a6 9ab 9ae 9b3 9b4 9b9
9bc 9c0 9c1 9c6 9c9 9ce 9cf 9d4
9d7 9db 9df 9e2 9e5 9e6 9e8 9e9
9ee 9ef 9f4 9f6 9fa 9fd 9ff a03
a05 a11 a13 a15 a16 a1b a1f a21
a2d a2f a33 a37 a3a a3e a41 a45
a48 a49 a4e a51 a55 a59 a5d a61
a6d a71 a75 a78 a7c a80 a82 1
a86 a8a a8e a91 a95 a99 a9d aa1
aa4 aa8 aac aaf ab2 ab7 aba abd
ac0 ac1 ac6 ac7 1 ac9 ace ad2
ad6 ad9 ade ae3 ae6 aea aeb af0
af3 af8 af9 afe b01 b06 b07 b0c
b0f b13 b14 b19 b1c b21 b22 b27
b2a b2e b32 b35 b38 b39 b3b b3c
b41 b42 b47 b49 b4d b50 b52 b56
b58 b64 b66 b68 b69 b6e b72 b74
b80 b82 b86 b8a b8d b91 b94 b98
b9b b9c ba1 ba4 ba8 bac baf bb3
bb7 bba bbd bc2 bc5 bc8 bcb bcc
bd1 bd2 1 bd4 bd9 bdd be1 be4
be9 bee bf1 bf5 bf6 bfb bfe c03
c04 c09 c0c c11 c12 c17 c1a c1e
c22 c26 c2a c2d c2e c30 c35 c36
c38 c39 c3e c41 c46 c47 c4c c4f
c54 c55 c5a c5d c61 c62 c67 c6a
c6f c70 c75 c76 c7b c7d c81 c84
c88 c8c c8f c93 c97 c9a c9d ca2
ca5 ca8 cab cac cb1 cb2 1 cb4
cb9 cbd cc1 cc4 cc9 cce cd1 cd5
cd6 cdb cdc ce1 ce3 ce7 cea cee
cf2 cf5 cf9 cfd d00 d04 d08 d09
d0e d10 d14 d17 d19 d1d d20 d22
d26 d29 d2d d2f d33 d37 d3a d3b
d3d d40 d43 d44 d49 d4d d51 d55
d59 d5d d69 d6d d71 d74 d78 d7c
d7e 1 d82 d86 d8a d8d d91 d95
d99 d9d da0 da4 da8 dab dae db3
db6 db9 dbc dbd dc2 dc3 1 dc5
dca dce dd2 dd5 dda ddf de2 de6
de7 dec def df4 df5 dfa dfd e02
e03 e08 e0b e0f e10 e15 e18 e1d
e1e e23 e26 e2a e2e e31 e34 e35
e37 e38 e3d e3e e43 e45 e49 e4c
e4e e52 e54 e60 e62 e64 e65 e6a
e6e e70 e7c e7e e82 e86 e89 e8d
e90 e94 e97 e98 e9d ea0 ea4 ea8
eab eaf eb3 eb6 eb9 ebe ec1 ec4
ec7 ec8 ecd ece 1 ed0 ed5 ed9
edd ee0 ee5 eea eed ef1 ef2 ef7
efa eff f00 f05 f08 f0d f0e f13
f16 f1a f1e f22 f26 f29 f2a f2c
f31 f32 f34 f35 f3a f3d f42 f43
f48 f4b f50 f51 f56 f59 f5d f5e
f63 f66 f6b f6c f71 f72 f77 f79
f7d f80 f84 f88 f8b f8f f93 f96
f99 f9e fa1 fa4 fa7 fa8 fad fae
1 fb0 fb5 fb9 fbd fc0 fc5 fca
fcd fd1 fd2 fd7 fd8 fdd fdf fe3
fe6 fea fee ff1 ff5 ff9 ffc 1000
1004 1005 100a 100c 1010 1013 1017 101b
101f 1023 1027 102b 102f 1033 103f 1043
1047 104a 104e 1052 1054 1 1058 105c
1060 1063 1067 106b 106f 1073 1076 107a
107e 1081 1084 1089 108c 108f 1092 1093
1098 1099 1 109b 10a0 10a4 10a8 10ab
10b0 10b5 10b8 10bc 10bd 10c2 10c5 10ca
10cb 10d0 10d3 10d8 10d9 10de 10e1 10e5
10e6 10eb 10ee 10f3 10f4 10f9 10fc 1100
1104 1107 110a 110b 110d 110e 1113 1114
1119 111b 111f 1122 1124 1128 112a 1136
1138 113a 113b 1140 1144 1146 1152 1154
1158 115a 115e 1162 1166 1169 116a 116c
116f 1172 1173 1178 117c 1180 1184 1188
118c 1198 119c 11a0 11a3 11a7 11ab 11ad
1 11b1 11b5 11b9 11bc 11c0 11c4 11c8
11cc 11cf 11d3 11d7 11da 11dd 11e2 11e5
11e8 11eb 11ec 11f1 11f2 1 11f4 11f9
11fd 1201 1204 1209 120e 1211 1215 1216
121b 121e 1223 1224 1229 122c 1231 1232
1237 123a 123e 123f 1244 1247 124c 124d
1252 1255 1259 125d 1260 1263 1264 1266
1267 126c 126d 1272 1274 1278 127b 127d
1281 1283 128f 1291 1293 1294 1299 129d
129f 12ab 12ad 12b1 12b5 12b8 12bc 12bf
12c3 12c6 12c7 12cc 12cf 12d3 12d7 12da
12de 12e2 12e5 12e8 12ed 12f0 12f3 12f6
12f7 12fc 12fd 1 12ff 1304 1308 130c
130f 1314 1319 131c 1320 1321 1326 1329
132e 132f 1334 1337 133c 133d 1342 1345
1349 134d 1351 1355 1358 1359 135b 1360
1361 1363 1364 1369 136c 1371 1372 1377
137a 137f 1380 1385 1388 138c 138d 1392
1395 139a 139b 13a0 13a1 13a6 13a8 13ac
13af 13b3 13b7 13ba 13be 13c2 13c5 13c8
13cd 13d0 13d3 13d6 13d7 13dc 13dd 1
13df 13e4 13e8 13ec 13ef 13f4 13f9 13fc
1400 1401 1406 1407 140c 140e 1412 1415
1419 141d 1420 1424 1428 142b 142f 1433
1434 1439 143b 143f 1442 1446 1449 144d
1451 1453 1457 145b 145f 1462 1463 1465
1469 146c 1470 1473 1474 1479 147c 1480
1484 1487 1488 148a 148d 1490 1491 1496
1 1499 149e 14a2 14a6 14a9 14aa 14ac
14b0 14b3 14b7 14ba 14bb 14c0 1 14c3
14c8 14cc 14d0 14d3 14d4 14d6 14da 14dd
14e1 14e4 14e5 14ea 1 14ed 14f2 14f6
14fa 14fe 1502 1506 150a 150e 1512 151e
1522 1526 1529 152d 1531 1533 1 1537
153b 153f 1542 1546 154a 154e 1552 1555
1559 155d 1560 1563 1568 156b 156e 1571
1572 1577 1578 1 157a 157f 1583 1587
158a 158f 1594 1597 159b 159c 15a1 15a4
15a9 15aa 15af 15b2 15b7 15b8 15bd 15c0
15c4 15c5 15ca 15cd 15d2 15d3 15d8 15db
15df 15e3 15e6 15e9 15ea 15ec 15ed 15f2
15f3 15f8 15fa 15fe 1601 1603 1607 1609
1615 1617 1619 161a 161f 1623 1625 1631
1633 1637 163b 163e 1642 1645 1649 164c
164d 1652 1655 1659 165d 1660 1664 1668
166b 166e 1673 1676 1679 167c 167d 1682
1683 1 1685 168a 168e 1692 1695 169a
169f 16a2 16a6 16a7 16ac 16af 16b4 16b5
16ba 16bd 16c2 16c3 16c8 16cb 16cf 16d3
16d7 16db 16de 16df 16e1 16e6 16e7 16e9
16ea 16ef 16f2 16f7 16f8 16fd 1700 1705
1706 170b 170e 1712 1713 1718 171b 1720
1721 1726 1727 172c 172e 1732 1735 1739
173d 1740 1744 1748 174b 174e 1753 1756
1759 175c 175d 1762 1763 1 1765 176a
176e 1772 1775 177a 177f 1782 1786 1787
178c 178d 1792 1794 1798 179b 179f 17a3
17a6 17aa 17ae 17b1 17b5 17b9 17ba 17bf
17c1 17c5 17c8 17ca 17ce 17d2 17d5 17d9
17dd 17e0 17e1 17e3 17e6 17e9 17ea 17ef
17f3 17f7 17fc 1801 1805 1809 180d 1810
1813 1817 181b 181f 1823 1827 182b 182f
1833 1837 183b 183f 1843 1847 184b 184f
1853 1857 185b 185f 1863 1867 186b 186f
1873 1877 187b 187f 1883 1887 188b 188f
1893 1897 189b 189f 18ab 18af 18b4 18b8
18bb 18bc 18c1 18c5 18c9 18cc 18cf 18d3
18d5 18d9 18dd 18e0 18e3 18e7 18e9 18ed
18f1 18f4 18f6 1 18fa 18fe 1902 1905
1909 190d 1911 1915 1918 191c 1920 1923
1926 192b 192e 1931 1934 1935 193a 193b
1 193d 1942 1946 194a 194d 1952 1957
195a 195e 195f 1964 1967 196c 196d 1972
1975 197a 197b 1980 1983 1987 1988 198d
1990 1995 1996 199b 199e 19a2 19a6 19a9
19ac 19ad 19af 19b0 19b5 19b6 19bb 19bd
19c1 19c4 19c6 19ca 19cc 19d8 19da 19dc
19dd 19e2 19e6 19e8 19f4 19f6 19fa 19fe
1a03 1a08 1a0c 1a10 1a14 1a17 1a1a 1a1e
1a22 1a26 1a2a 1a2e 1a32 1a36 1a3a 1a46
1a4a 1a4f 1a53 1a56 1a57 1a5c 1a60 1a64
1a67 1a6a 1a6e 1a70 1a74 1a78 1a7b 1a7e
1a82 1a84 1a88 1a8c 1a8f 1a91 1 1a95
1a99 1a9d 1aa0 1aa4 1aa8 1aac 1ab0 1ab3
1ab7 1abb 1abe 1ac1 1ac6 1ac9 1acc 1acf
1ad0 1ad5 1ad6 1 1ad8 1add 1ae1 1ae5
1ae8 1aed 1af2 1af5 1af9 1afa 1aff 1b02
1b07 1b08 1b0d 1b10 1b15 1b16 1b1b 1b1e
1b22 1b23 1b28 1b2b 1b30 1b31 1b36 1b39
1b3d 1b41 1b44 1b47 1b48 1b4a 1b4b 1b50
1b51 1b56 1b58 1b5c 1b5f 1b61 1b65 1b67
1b73 1b75 1b77 1b78 1b7d 1b81 1b83 1b8f
1b91 1b95 1b99 1b9d 1ba1 1ba5 1ba9 1bad
1bb1 1bb5 1bb9 1bbd 1bc1 1bc5 1bc9 1bcd
1bd1 1bd5 1bd9 1bdd 1be1 1be5 1be9 1bed
1bf1 1bf5 1bf9 1bfd 1c01 1c05 1c09 1c0d
1c11 1c15 1c19 1c1d 1c21 1c25 1c29 1c2d
1c31 1c35 1c39 1c3d 1c41 1c45 1c49 1c4d
1c51 1c55 1c59 1c5d 1c61 1c65 1c69 1c6d
1c71 1c75 1c79 1c7d 1c81 1c85 1c89 1c8d
1c91 1c95 1c99 1c9d 1ca1 1ca5 1ca9 1cad
1cb1 1cb5 1cb9 1cbd 1cc1 1cc5 1cc9 1ccd
1cd1 1cd5 1cd9 1cdd 1ce1 1ce5 1ce9 1ced
1cf1 1cf5 1cf9 1cfd 1d01 1d05 1d09 1d0d
1d11 1d15 1d19 1d1d 1d21 1d25 1d29 1d2d
1d31 1d35 1d39 1d3d 1d41 1d45 1d49 1d4d
1d51 1d55 1d59 1d5d 1d61 1d65 1d69 1d6d
1d71 1d75 1d79 1d7d 1d81 1d85 1d89 1d8d
1d91 1d95 1d99 1d9d 1da1 1da5 1da9 1dad
1db1 1db5 1db9 1dbd 1dc1 1dc5 1dc9 1dcd
1dd1 1dd5 1dd9 1ddd 1de1 1de5 1de9 1ded
1df1 1df5 1df9 1dfd 1e01 1e05 1e09 1e0d
1e11 1e15 1e19 1e1d 1e21 1e25 1e29 1e2d
1e31 1e35 1e39 1e3d 1e41 1e45 1e49 1e4d
1e51 1e55 1e59 1e5d 1e61 1e65 1e69 1e6d
1e71 1e75 1e79 1e7d 1e81 1e85 1e89 1e8d
1e91 1e95 1e99 1e9d 1ea1 1ea5 1ea9 1ead
1eb1 1eb5 1eb9 1ebd 1ec1 1ec5 1ec9 1ecd
1ed1 1ed5 1ed9 1edd 1ee1 1ee5 1ee9 1eed
1ef1 1ef5 1ef9 1efd 1f01 1f05 1f09 1f0d
1f11 1f15 1f19 1f1d 1f21 1f25 1f29 1f2d
1f31 1f35 1f39 1f3d 1f41 1f45 1f49 1f4d
1f51 1f55 1f59 1f5d 1f61 1f65 1f69 1f6d
1f71 1f75 1f79 1f7d 1f81 1f85 1f89 1f8d
1f91 1f95 1f99 1f9d 1fa1 1fa5 1fa9 1fad
1fb1 1fb5 1fb9 1fbd 1fc1 1fc5 1fc9 1fcd
1fd1 1fd5 1fd9 1fdd 1fe1 1fe5 1fe9 1fed
1ff1 1ff5 1ff9 1ffd 2001 2005 2009 200d
2011 2015 2019 201d 2021 2025 2029 202d
2031 2035 2039 203d 2041 2045 2051 2056
205a 205e 2062 2065 2069 206d 2070 2073
2078 207b 207e 2081 2082 2087 2088 1
208a 208f 2093 2097 209a 209f 20a4 20a7
20ab 20ac 20b1 20b2 20b7 20b9 20bd 20c0
20c4 20c8 20cc 20d0 20d2 20d6 20da 20dd
20de 20e0 20e3 20e6 20e7 20ec 20ef 20f3
20f7 20fa 20fb 20fd 2100 2103 2104 2109
1 210c 2111 2115 2119 211e 2123 2127
212b 212f 2132 2135 2139 213d 2141 2145
2149 214d 2151 2155 2159 215d 2161 2165
2169 216d 2171 2175 2179 217d 2181 2185
2189 218d 2191 2195 2199 219d 21a1 21a5
21a9 21ad 21b1 21b5 21b9 21bd 21c1 21c5
21c9 21cd 21d1 21dd 21e1 21e6 21ea 21ed
21ee 21f3 21f7 21fb 21fe 2201 2205 2207
220b 220f 2212 2215 2219 221b 221f 2223
2226 2228 1 222c 2230 2234 2237 223b
223f 2243 2247 224a 224e 2252 2255 2258
225d 2260 2263 2266 2267 226c 226d 1
226f 2274 2278 227c 227f 2284 2289 228c
2290 2291 2296 2299 229e 229f 22a4 22a7
22ac 22ad 22b2 22b5 22b9 22ba 22bf 22c2
22c7 22c8 22cd 22d0 22d4 22d8 22db 22de
22df 22e1 22e2 22e7 22e8 22ed 22ef 22f3
22f6 22f8 22fc 22fe 230a 230c 230e 230f
2314 2318 231a 2326 2328 232c 2330 2333
2337 2338 233d 2341 2345 2349 234d 2351
2355 2359 235d 2361 2365 2369 236d 2371
2375 2379 237d 2381 2385 2389 238d 2391
2395 2399 239d 23a1 23a5 23a9 23ad 23b1
23b5 23b9 23bd 23c1 23c5 23c9 23cd 23d1
23d5 23d9 23dd 23e1 23e5 23e9 23ed 23f1
23f5 23f9 2405 2409 240e 2412 2415 2416
241b 241f 2423 2426 2429 242d 242f 2433
2437 243a 243d 2441 2443 2447 244b 244e
2450 1 2454 2458 245c 245f 2463 2467
246b 246f 2472 2476 247a 247d 2480 2485
2488 248b 248e 248f 2494 2495 1 2497
249c 24a0 24a4 24a7 24ac 24b1 24b4 24b8
24b9 24be 24c1 24c6 24c7 24cc 24cf 24d4
24d5 24da 24dd 24e1 24e2 24e7 24ea 24ef
24f0 24f5 24f8 24fc 2500 2503 2506 2507
2509 250a 250f 2510 2515 2517 251b 251e
2520 2524 2526 2532 2534 2536 2537 253c
2540 2542 254e 2550 2554 2558 255c 2560
2564 2568 256c 2570 2574 2578 257c 2580
2584 2588 258c 2590 2594 2598 259c 25a0
25a4 25a8 25ac 25b0 25b4 25b8 25bc 25c0
25c4 25c8 25cc 25d0 25d4 25d8 25dc 25e0
25e4 25e8 25ec 25f0 25f4 25f8 25fc 2600
2604 2608 260c 2610 2614 2618 261c 2620
2624 2628 262c 2630 2634 2638 263c 2640
2644 2648 264c 2650 2654 2658 265c 2660
2664 2668 266c 2670 2674 2680 2685 2689
268d 2691 2694 2698 269c 269f 26a2 26a7
26aa 26ad 26b0 26b1 26b6 26b7 1 26b9
26be 26c2 26c6 26c9 26ce 26d3 26d6 26da
26db 26e0 26e1 26e6 26e8 26ec 26ef 26f3
26f7 26fb 26ff 2701 2705 2709 270d 2710
2711 2713 2716 2719 271a 271f 2723 2727
272b 272f 2733 2737 273b 273f 2743 2747
274b 274f 2753 2757 275b 275f 2763 2767
276b 276f 2773 2777 277b 277f 2783 2787
278b 278f 2793 2797 279b 279f 27a3 27a7
27ab 27af 27b3 27b7 27bb 27bf 27c3 27c7
27cb 27cf 27d3 27d7 27db 27df 27e3 27e7
27eb 27ef 27f3 27f7 27fb 27ff 2803 2807
280b 280f 2813 2817 281b 281f 2823 2827
282b 282f 2833 2837 283b 283f 2843 2847
284b 284f 2853 2857 285b 285f 2863 2867
286b 286f 2873 2877 287b 287f 2883 2887
288b 288f 2893 2897 289b 289f 28a3 28a7
28ab 28af 28b3 28b7 28bb 28bf 28c3 28c7
28cb 28cf 28d3 28d7 28db 28df 28e3 28e7
28eb 28ef 28f3 28f7 28fb 28ff 2903 2907
290b 290f 2913 2917 291b 291f 2923 2927
292b 292f 2933 2937 293b 293f 2943 2947
294b 294f 2953 295f 2964 2968 296c 2970
2973 2977 297b 297e 2981 2986 2989 298c
298f 2990 2995 2996 1 2998 299d 29a1
29a5 29a8 29ad 29b2 29b5 29b9 29ba 29bf
29c0 29c5 29c7 29cb 29ce 29d2 29d6 29da
29de 29e0 29e4 29e8 29ec 29ef 29f0 29f2
29f5 29f8 29f9 29fe 2a02 2a06 2a0a 2a0d
2a0e 2a10 2a11 2a13 2a16 2a19 2a1a 2a1f
2a23 2a26 2a2a 2a2e 2a32 2a36 2a3a 2a3e
2a42 2a46 2a52 2a56 2a5a 2a5d 2a61 2a65
2a67 1 2a6b 2a6f 2a73 2a76 2a7a 2a7e
2a82 2a86 2a89 2a8d 2a91 2a94 2a97 2a9c
2a9f 2aa2 2aa5 2aa6 2aab 2aac 1 2aae
2ab3 2ab7 2abb 2abe 2ac3 2ac8 2acb 2acf
2ad0 2ad5 2ad8 2add 2ade 2ae3 2ae6 2aeb
2aec 2af1 2af4 2af8 2af9 2afe 2b01 2b06
2b07 2b0c 2b0f 2b13 2b17 2b1a 2b1d 2b1e
2b20 2b21 2b26 2b27 2b2c 2b2e 2b32 2b35
2b37 2b3b 2b3d 2b49 2b4b 2b4d 2b4e 2b53
2b57 2b59 2b65 2b67 2b6b 2b6f 2b72 2b73
2b75 2b78 2b7b 2b7c 2b81 2b85 2b8a 2b8e
2b90 2b94 2b98 2b9c 2ba0 2ba4 2ba8 2bac
2bb0 2bb4 2bc0 2bc4 2bc8 2bcb 2bcf 2bd3
2bd5 1 2bd9 2bdd 2be1 2be4 2be8 2bec
2bf0 2bf4 2bf7 2bfb 2bff 2c02 2c05 2c0a
2c0d 2c10 2c13 2c14 2c19 2c1a 1 2c1c
2c21 2c25 2c29 2c2c 2c31 2c36 2c39 2c3d
2c3e 2c43 2c46 2c4b 2c4c 2c51 2c54 2c59
2c5a 2c5f 2c62 2c66 2c67 2c6c 2c6f 2c74
2c75 2c7a 2c7d 2c81 2c85 2c88 2c8b 2c8c
2c8e 2c8f 2c94 2c95 2c9a 2c9c 2ca0 2ca3
2ca5 2ca9 2cab 2cb7 2cb9 2cbb 2cbc 2cc1
2cc5 2cc7 2cd3 2cd5 2cd9 2cdd 2ce0 2ce1
2ce3 2ce6 2ce9 2cea 2cef 2cf3 2cf7 2cfb
2cff 2d03 2d07 2d0b 2d0f 2d13 2d17 2d1b
2d1f 2d23 2d27 2d2b 2d2f 2d33 2d37 2d3b
2d3f 2d43 2d47 2d4b 2d4f 2d53 2d57 2d5b
2d5f 2d6b 2d6f 2d73 2d76 2d7a 2d7e 2d80
1 2d84 2d88 2d8c 2d8f 2d93 2d97 2d9b
2d9f 2da2 2da6 2daa 2dad 2db0 2db5 2db8
2dbb 2dbe 2dbf 2dc4 2dc5 1 2dc7 2dcc
2dd0 2dd4 2dd7 2ddc 2de1 2de4 2de8 2de9
2dee 2df1 2df6 2df7 2dfc 2dff 2e04 2e05
2e0a 2e0d 2e11 2e12 2e17 2e1a 2e1f 2e20
2e25 2e28 2e2c 2e30 2e33 2e36 2e37 2e39
2e3a 2e3f 2e40 2e45 2e47 2e4b 2e4e 2e50
2e54 2e56 2e62 2e64 2e66 2e67 2e6c 2e70
2e72 2e7e 2e80 2e84 2e88 2e8b 2e8c 2e8e
2e91 2e94 2e95 2e9a 2e9e 2ea3 2ea7 2ea9
2ead 2eb2 2eb6 2eb8 2ebc 2ec0 2ec3 2ec5
2ec9 2ece 2ed2 2ed4 2ed8 2edc 2edf 2ee1
2ee5 2ee9 2eec 2ef0 2ef4 2ef8 2efc 2f00
2f04 2f08 2f0c 2f10 2f14 2f18 2f1c 2f20
2f24 2f28 2f2c 2f30 2f34 2f38 2f3c 2f40
2f44 2f48 2f4c 2f50 2f54 2f58 2f5c 2f60
2f64 2f68 2f6c 2f70 2f74 2f78 2f7c 2f80
2f84 2f88 2f8c 2f90 2f94 2f98 2f9c 2fa0
2fa4 2fa8 2fac 2fb0 2fb4 2fb8 2fbc 2fc0
2fc4 2fc8 2fcc 2fd0 2fd4 2fd8 2fdc 2fe0
2fe4 2fe8 2fec 2ff0 2ff4 2ff8 2ffc 3000
3004 3008 300c 3010 3014 3018 301c 3020
3024 3028 302c 3030 3034 3038 303c 3040
3044 3048 304c 3050 3054 3058 305c 3060
3064 3068 306c 3070 3074 3078 307c 3080
3084 3088 308c 3090 3094 3098 309c 30a0
30a4 30a8 30ac 30b0 30b4 30b8 30bc 30c0
30c4 30c8 30cc 30d0 30d4 30d8 30dc 30e0
30e4 30e8 30ec 30f0 30f4 30f8 30fc 3100
3104 3108 310c 3110 3114 3118 311c 3120
3124 3128 312c 3130 3134 3138 313c 3140
3144 3148 314c 3150 3154 3158 315c 3160
3164 3168 316c 3170 3174 3178 317c 3180
3184 3188 318c 3190 3194 3198 319c 31a0
31a4 31a8 31ac 31b0 31b4 31b8 31bc 31c0
31c4 31c8 31cc 31d0 31d4 31d8 31dc 31e0
31e4 31e8 31ec 31f0 31f4 31f8 31fc 3200
3204 3208 320c 3210 3214 3218 321c 3220
3224 3228 322c 3230 3234 3238 323c 3240
3244 3248 324c 3250 3254 3258 325c 3260
3264 3268 326c 3270 3274 3278 327c 3280
3284 3288 328c 3290 3294 3298 329c 32a0
32a4 32a8 32ac 32b0 32b4 32b8 32bc 32c0
32c4 32c8 32cc 32d0 32d4 32d8 32dc 32e0
32e4 32e8 32ec 32f0 32f4 32f8 32fc 3300
3304 3308 330c 3310 3314 3318 331c 3320
3324 3328 332c 3330 3334 3338 333c 3340
3344 3348 334c 3350 3354 3358 335c 3360
3364 3368 336c 3370 3374 3378 337c 3380
3384 3388 338c 3390 3394 3398 339c 33a0
33a4 33a8 33ac 33b0 33b4 33b8 33bc 33c0
33c4 33c8 33cc 33d0 33d4 33d8 33dc 33e0
33e4 33e8 33ec 33f0 33f4 33f8 33fc 3400
3404 3408 340c 3410 3414 3418 341c 3420
3424 3428 342c 3430 3434 3438 343c 3440
3444 3448 344c 3450 3454 3458 345c 3460
3464 3468 346c 3470 3474 3478 347c 3480
3484 3488 348c 3490 3494 3498 349c 34a0
34a4 34a8 34ac 34b0 34b4 34b8 34bc 34c0
34c4 34c8 34cc 34d0 34d4 34d8 34dc 34e0
34e4 34e8 34ec 34f0 34f4 34f8 34fc 3500
3504 3508 350c 3510 3514 3518 351c 3520
3524 3528 352c 3530 3534 3538 353c 3540
3544 3548 354c 3550 3554 3558 355c 3560
3564 3568 356c 3570 3574 3578 357c 3580
3584 3588 358c 3590 3594 3598 359c 35a0
35a4 35a8 35ac 35b0 35b4 35b8 35bc 35c0
35c4 35c8 35cc 35d0 35d4 35d8 35dc 35e0
35e4 35e8 35ec 35f0 35f4 35f8 35fc 3600
3604 3608 360c 3610 3614 3618 361c 3620
3624 3628 362c 3630 3634 3638 363c 3640
3644 3648 364c 3650 3654 3658 365c 3660
3664 3668 366c 3670 3674 3678 367c 3680
3684 3688 368c 3690 3694 3698 369c 36a0
36a4 36a8 36ac 36b0 36b4 36b8 36bc 36c0
36c4 36c8 36d4 36d9 36dd 36e1 36e5 36e8
36ec 36f0 36f3 36f6 36fb 36fe 3701 3704
3705 370a 370b 1 370d 3712 3716 371a
371d 3722 3727 372a 372e 372f 3734 3735
373a 373c 3740 3743 3747 374b 374f 3751
3755 3759 375d 3761 3765 3769 376d 3771
3775 3779 377d 3781 3785 3789 378d 3791
3795 3799 379d 37a1 37a5 37a9 37ad 37b1
37b5 37b9 37bd 37c1 37c5 37c9 37cd 37d1
37d5 37d9 37dd 37e1 37e5 37e9 37ed 37f1
37f5 37f9 37fd 3801 3805 3809 380d 3811
3815 3819 381d 3821 3825 3829 382d 3831
3835 3839 383d 3841 3845 3849 384d 3851
3855 3859 385d 3861 3865 3869 386d 3871
3875 3879 387d 3881 3885 3889 388d 3891
3895 3899 389d 38a1 38a5 38a9 38ad 38b1
38b5 38b9 38bd 38c1 38c5 38c9 38cd 38d1
38d5 38d9 38dd 38e1 38e5 38e9 38ed 38f1
38f5 38f9 38fd 3901 3905 3909 390d 3911
3915 3919 391d 3921 3925 3929 392d 3931
3935 3939 393d 3941 3945 3949 394d 3951
3955 3959 395d 3961 3965 3969 396d 3971
3975 3979 397d 3981 3985 3989 398d 3991
3995 3999 399d 39a1 39a5 39a9 39ad 39b1
39b5 39b9 39bd 39c1 39c5 39c9 39cd 39d1
39d5 39d9 39dd 39e1 39e5 39e9 39ed 39f1
39f5 39f9 39fd 3a01 3a05 3a09 3a0d 3a11
3a15 3a19 3a1d 3a21 3a25 3a29 3a2d 3a31
3a35 3a39 3a3d 3a41 3a45 3a49 3a4d 3a51
3a55 3a59 3a5d 3a61 3a65 3a69 3a6d 3a71
3a75 3a79 3a7d 3a81 3a85 3a89 3a8d 3a91
3a95 3a99 3a9d 3aa1 3aa5 3aa9 3aad 3ab1
3ab5 3ab9 3abd 3ac1 3ac5 3ac9 3acd 3ad1
3ad5 3ad9 3add 3ae1 3ae5 3ae9 3aed 3af1
3af5 3af9 3afd 3b01 3b05 3b09 3b0d 3b11
3b15 3b19 3b1d 3b21 3b25 3b29 3b2d 3b31
3b35 3b39 3b3d 3b41 3b45 3b49 3b4d 3b51
3b55 3b59 3b5d 3b61 3b65 3b69 3b6d 3b71
3b75 3b79 3b7d 3b81 3b85 3b89 3b8d 3b91
3b95 3b99 3b9d 3ba1 3ba5 3ba9 3bad 3bb1
3bb5 3bb9 3bbd 3bc1 3bc5 3bd1 3bd6 3bda
3bde 3be2 3be5 3be9 3bed 3bf0 3bf3 3bf8
3bfb 3bfe 3c01 3c02 3c07 3c08 1 3c0a
3c0f 3c13 3c17 3c1a 3c1f 3c24 3c27 3c2b
3c2c 3c31 3c32 3c37 3c39 3c3d 3c40 3c44
3c48 3c4c 3c4e 3c52 3c56 3c59 3c5d 3c5f
3c63 3c67 3c6b 3c6e 3c6f 3c71 3c74 3c77
3c78 3c7d 3c81 3c85 3c8a 3c8f 3c93 3c97
3c9b 3c9e 3ca1 3ca5 3ca9 3cad 3cb1 3cb5
3cb9 3cbd 3cc1 3cc5 3cc9 3ccd 3cd1 3cd5
3cd9 3cdd 3ce1 3ce5 3ce9 3ced 3cf1 3cf5
3cf9 3cfd 3d01 3d05 3d09 3d0d 3d11 3d15
3d19 3d1d 3d21 3d25 3d29 3d2d 3d31 3d35
3d39 3d3d 3d41 3d4d 3d51 3d56 3d5a 3d5d
3d5e 3d63 3d67 3d6b 3d6e 3d71 3d75 3d77
3d7b 3d7f 3d82 3d85 3d89 3d8b 3d8f 3d93
3d96 3d98 1 3d9c 3da0 3da4 3da7 3dab
3daf 3db3 3db7 3dba 3dbe 3dc2 3dc5 3dc8
3dcd 3dd0 3dd3 3dd6 3dd7 3ddc 3ddd 1
3ddf 3de4 3de8 3dec 3def 3df4 3df9 3dfc
3e00 3e01 3e06 3e09 3e0e 3e0f 3e14 3e17
3e1c 3e1d 3e22 3e25 3e29 3e2a 3e2f 3e32
3e37 3e38 3e3d 3e40 3e44 3e48 3e4b 3e4e
3e4f 3e51 3e52 3e57 3e58 3e5d 3e5f 3e63
3e66 3e68 3e6c 3e6e 3e7a 3e7c 3e7e 3e7f
3e84 3e88 3e8a 3e96 3e98 3e9c 3ea0 3ea3
3ea7 3ea8 3ead 3eb1 3eb5 3eb9 3ebd 3ec1
3ec5 3ec9 3ecd 3ed1 3ed5 3ed9 3edd 3ee1
3ee5 3ee9 3eed 3ef1 3ef5 3ef9 3efd 3f01
3f05 3f09 3f0d 3f11 3f15 3f19 3f1d 3f21
3f25 3f29 3f2d 3f31 3f35 3f39 3f3d 3f41
3f45 3f49 3f4d 3f51 3f55 3f59 3f5d 3f61
3f65 3f69 3f6d 3f71 3f75 3f79 3f7d 3f81
3f85 3f91 3f95 3f9a 3f9e 3fa1 3fa2 3fa7
3fab 3faf 3fb2 3fb5 3fb9 3fbb 3fbf 3fc3
3fc6 3fc9 3fcd 3fcf 3fd3 3fd7 3fda 3fdc
1 3fe0 3fe4 3fe8 3feb 3fef 3ff3 3ff7
3ffb 3ffe 4002 4006 4009 400c 4011 4014
4017 401a 401b 4020 4021 1 4023 4028
402c 4030 4033 4038 403d 4040 4044 4045
404a 404d 4052 4053 4058 405b 4060 4061
4066 4069 406d 406e 4073 4076 407b 407c
4081 4084 4088 408c 408f 4092 4093 4095
4096 409b 409c 40a1 40a3 40a7 40aa 40ac
40b0 40b2 40be 40c0 40c2 40c3 40c8 40cc
40ce 40da 40dc 40e0 40e4 40e8 40ec 40f0
40f4 40f8 40fc 4100 4104 4108 410c 4110
4114 4118 411c 4120 4124 4128 412c 4130
4134 4138 413c 4140 4144 4148 414c 4150
4154 4158 415c 4160 4164 4168 416c 4170
4174 4178 417c 4180 4184 4188 418c 4190
4194 4198 419c 41a0 41a4 41a8 41ac 41b0
41b4 41b8 41bc 41c0 41c4 41c8 41cc 41d0
41d4 41d8 41dc 41e0 41e4 41e8 41ec 41f0
41f4 41f8 41fc 4200 4204 4208 420c 4218
421d 4221 4225 4229 422c 4230 4234 4237
423a 423f 4242 4245 4248 4249 424e 424f
1 4251 4256 425a 425e 4261 4266 426b
426e 4272 4273 4278 4279 427e 4280 4284
4287 428b 428f 4293 4297 4299 429d 42a1
42a5 42a8 42a9 42ab 42ae 42b1 42b2 42b7
42bb 42bf 42c4 42c9 42cd 42d1 42d5 42d8
42db 42df 42e3 42e7 42eb 42ef 42f3 42f7
42fb 42ff 4303 4307 430b 430f 4313 4317
431b 431f 4323 4327 432b 432f 4333 4337
433b 433f 4343 4347 434b 434f 4353 4357
435b 435f 4363 4367 436b 436f 4373 4377
437b 4387 438b 4390 4394 4397 4398 439d
43a1 43a5 43a8 43ab 43af 43b1 43b5 43b9
43bc 43bf 43c3 43c5 43c9 43cd 43d0 43d2
1 43d6 43da 43de 43e1 43e5 43e9 43ed
43f1 43f4 43f8 43fc 43ff 4402 4407 440a
440d 4410 4411 4416 4417 1 4419 441e
4422 4426 4429 442e 4433 4436 443a 443b
4440 4443 4448 4449 444e 4451 4456 4457
445c 445f 4463 4464 4469 446c 4471 4472
4477 447a 447e 4482 4485 4488 4489 448b
448c 4491 4492 4497 4499 449d 44a0 44a2
44a6 44a8 44b4 44b6 44b8 44b9 44be 44c2
44c4 44d0 44d2 44d6 44da 44dd 44e1 44e2
44e7 44eb 44ef 44f3 44f7 44fb 44ff 4503
4507 450b 450f 4513 4517 451b 451f 4523
4527 452b 452f 4533 4537 453b 453f 4543
4547 454b 454f 4553 4557 455b 455f 4563
4567 456b 456f 4573 4577 457b 457f 4583
4587 458b 458f 4593 4597 459b 459f 45a3
45a7 45ab 45af 45b3 45b7 45bb 45bf 45c3
45c7 45cb 45cf 45d3 45d7 45db 45df 45e3
45e7 45eb 45ef 45f3 45f7 45fb 45ff 4603
4607 460b 460f 4613 4617 461b 461f 4623
4627 462b 462f 4633 4637 463b 463f 4643
4647 464b 464f 4653 4657 465b 465f 4663
4667 466b 466f 4673 467f 4683 4688 468c
468f 4690 4695 4699 469d 46a0 46a3 46a7
46a9 46ad 46b1 46b4 46b7 46bb 46bd 46c1
46c5 46c8 46ca 1 46ce 46d2 46d6 46d9
46dd 46e1 46e5 46e9 46ec 46f0 46f4 46f7
46fa 46ff 4702 4705 4708 4709 470e 470f
1 4711 4716 471a 471e 4721 4726 472b
472e 4732 4733 4738 473b 4740 4741 4746
4749 474e 474f 4754 4757 475b 475c 4761
4764 4769 476a 476f 4772 4776 477a 477d
4780 4781 4783 4784 4789 478a 478f 4791
4795 4798 479a 479e 47a0 47ac 47ae 47b0
47b1 47b6 47ba 47bc 47c8 47ca 47ce 47d2
47d6 47da 47de 47e2 47e6 47ea 47ee 47f2
47f6 47fa 47fe 4802 4806 480a 480e 4812
4816 481a 481e 4822 4826 482a 482e 4832
4836 483a 483e 4842 4846 484a 484e 4852
4856 485a 485e 4862 4866 486a 486e 4872
4876 487a 487e 4882 4886 488a 488e 4892
4896 489a 489e 48a2 48a6 48aa 48ae 48b2
48b6 48ba 48be 48c2 48c6 48ca 48ce 48d2
48d6 48da 48de 48e2 48e6 48ea 48ee 48f2
48f6 48fa 48fe 4902 4906 490a 490e 4912
4916 491a 491e 4922 4926 492a 492e 4932
4936 493a 493e 4942 4946 494a 494e 4952
4956 495a 495e 4962 4966 496a 496e 4972
497e 4983 4987 498b 498f 4992 4996 499a
499d 49a0 49a5 49a8 49ab 49ae 49af 49b4
49b5 1 49b7 49bc 49c0 49c4 49c7 49cc
49d1 49d4 49d8 49d9 49de 49df 49e4 49e6
49ea 49ed 49f1 49f5 49f9 49fd 49ff 4a03
4a07 4a0b 4a0e 4a0f 4a11 4a14 4a17 4a18
4a1d 4a21 4a25 4a29 4a2d 4a31 4a35 4a39
4a3d 4a41 4a45 4a49 4a4d 4a51 4a55 4a59
4a5d 4a61 4a65 4a69 4a6d 4a71 4a75 4a79
4a7d 4a81 4a85 4a89 4a8d 4a91 4a95 4a99
4a9d 4aa1 4aa5 4aa9 4aad 4ab1 4ab5 4ab9
4abd 4ac1 4ac5 4ac9 4acd 4ad1 4ad5 4ad9
4add 4ae1 4ae5 4ae9 4aed 4af1 4af5 4af9
4afd 4b01 4b05 4b09 4b0d 4b11 4b15 4b19
4b1d 4b21 4b25 4b29 4b2d 4b31 4b35 4b39
4b3d 4b41 4b45 4b49 4b4d 4b51 4b55 4b59
4b5d 4b61 4b65 4b69 4b6d 4b71 4b75 4b79
4b7d 4b81 4b85 4b89 4b8d 4b91 4b95 4b99
4b9d 4ba1 4ba5 4ba9 4bad 4bb1 4bb5 4bb9
4bbd 4bc1 4bc5 4bc9 4bcd 4bd1 4bd5 4bd9
4bdd 4be1 4be5 4be9 4bed 4bf1 4bf5 4bf9
4bfd 4c01 4c05 4c09 4c0d 4c11 4c15 4c19
4c1d 4c21 4c25 4c29 4c2d 4c31 4c35 4c39
4c3d 4c41 4c45 4c49 4c4d 4c51 4c55 4c59
4c5d 4c61 4c65 4c69 4c6d 4c71 4c75 4c79
4c7d 4c81 4c85 4c89 4c8d 4c91 4c95 4c99
4c9d 4ca1 4ca5 4ca9 4cad 4cb1 4cb5 4cb9
4cbd 4cc1 4cc5 4cc9 4ccd 4cd1 4cd5 4cd9
4cdd 4ce1 4ce5 4ce9 4ced 4cf1 4cf5 4cf9
4cfd 4d01 4d05 4d09 4d0d 4d11 4d15 4d19
4d1d 4d21 4d25 4d29 4d2d 4d31 4d35 4d39
4d3d 4d41 4d45 4d49 4d4d 4d51 4d55 4d59
4d5d 4d61 4d65 4d69 4d6d 4d71 4d75 4d79
4d7d 4d81 4d85 4d89 4d8d 4d91 4d95 4d99
4d9d 4da1 4da5 4db1 4db6 4dba 4dbe 4dc2
4dc5 4dc9 4dcd 4dd0 4dd3 4dd8 4ddb 4dde
4de1 4de2 4de7 4de8 1 4dea 4def 4df3
4df7 4dfa 4dff 4e04 4e07 4e0b 4e0c 4e11
4e12 4e17 4e19 4e1d 4e20 4e24 4e28 4e2c
4e30 4e32 4e36 4e3a 4e3e 4e41 4e42 4e44
4e47 4e4a 4e4b 4e50 4e54 4e58 4e5d 4e62
4e66 4e6a 4e6e 4e71 4e74 4e78 4e7c 4e80
4e84 4e88 4e8c 4e90 4e94 4e98 4e9c 4ea0
4ea4 4ea8 4eac 4eb0 4eb4 4eb8 4ebc 4ec0
4ec4 4ec8 4ecc 4ed0 4ed4 4ed8 4edc 4ee0
4ee4 4ee8 4eec 4ef0 4ef4 4ef8 4efc 4f00
4f04 4f08 4f0c 4f10 4f14 4f18 4f1c 4f20
4f24 4f28 4f2c 4f30 4f34 4f40 4f44 4f49
4f4d 4f50 4f51 4f56 4f5a 4f5e 4f61 4f64
4f68 4f6a 4f6e 4f72 4f75 4f78 4f7c 4f7e
4f82 4f86 4f89 4f8b 1 4f8f 4f93 4f97
4f9a 4f9e 4fa2 4fa6 4faa 4fad 4fb1 4fb5
4fb8 4fbb 4fc0 4fc3 4fc6 4fc9 4fca 4fcf
4fd0 1 4fd2 4fd7 4fdb 4fdf 4fe2 4fe7
4fec 4fef 4ff3 4ff4 4ff9 4ffc 5001 5002
5007 500a 500f 5010 5015 5018 501c 501d
5022 5025 502a 502b 5030 5033 5037 503b
503e 5041 5042 5044 5045 504a 504b 5050
5052 5056 5059 505b 505f 5061 506d 506f
5071 5072 5077 507b 507d 5089 508b 508f
5093 5098 509d 50a1 50a5 50a9 50ac 50af
50b3 50b7 50bb 50bf 50c3 50c7 50cb 50cf
50d3 50d7 50db 50df 50e3 50e7 50eb 50ef
50f3 50f7 50fb 50ff 5103 5107 510b 510f
5113 5117 511b 511f 5123 5127 512b 512f
5133 5137 513b 513f 5143 5147 514b 514f
5153 5157 515b 515f 5163 5167 516b 516f
5173 5177 517b 517f 5183 5187 518b 518f
5193 5197 519b 519f 51a3 51a7 51ab 51af
51b3 51b7 51bb 51bf 51c3 51c7 51cb 51cf
51d3 51d7 51db 51df 51e3 51e7 51eb 51ef
51f3 51f7 51fb 51ff 5203 5207 520b 520f
5213 5217 521b 521f 5223 5227 522b 522f
5233 5237 523b 523f 5243 5247 524b 524f
5253 5257 525b 525f 5263 5267 526b 526f
5273 5277 5283 5287 528c 5290 5293 5294
5299 529d 52a1 52a4 52a7 52ab 52ad 52b1
52b5 52b8 52bb 52bf 52c1 52c5 52c9 52cc
52ce 1 52d2 52d6 52da 52dd 52e1 52e5
52e9 52ed 52f0 52f4 52f8 52fb 52fe 5303
5306 5309 530c 530d 5312 5313 1 5315
531a 531e 5322 5325 532a 532f 5332 5336
5337 533c 533f 5344 5345 534a 534d 5352
5353 5358 535b 535f 5360 5365 5368 536d
536e 5373 5376 537a 537e 5381 5384 5385
5387 5388 538d 538e 5393 5395 5399 539c
539e 53a2 53a4 53b0 53b2 53b4 53b5 53ba
53be 53c0 53cc 53ce 53d2 53d6 53da 53de
53e2 53e6 53ea 53ee 53f2 53f6 53fa 53fe
5402 5406 540a 540e 541a 541e 5423 5427
542a 542b 5430 5434 5438 543b 543e 5442
5444 5448 544c 544f 5452 5456 5458 545c
5460 5463 5465 1 5469 546d 5471 5474
5478 547c 5480 5484 5487 548b 548f 5492
5495 549a 549d 54a0 54a3 54a4 54a9 54aa
1 54ac 54b1 54b5 54b9 54bc 54c1 54c6
54c9 54cd 54ce 54d3 54d6 54db 54dc 54e1
54e4 54e9 54ea 54ef 54f2 54f6 54f7 54fc
54ff 5504 5505 550a 550d 5511 5515 5518
551b 551c 551e 551f 5524 5525 552a 552c
5530 5533 5535 5539 553b 5547 5549 554b
554c 5551 5555 5557 5563 5565 5569 556d
5571 5575 5579 557d 5581 5585 5589 558d
5591 5595 5599 559d 55a1 55a5 55a9 55ad
55b1 55b5 55b9 55bd 55c1 55c5 55c9 55cd
55d1 55d5 55d9 55dd 55e1 55e5 55e9 55ed
55f1 55f5 55f9 55fd 5601 5605 5609 560d
5611 5615 5619 561d 5621 5625 5629 562d
5631 5635 5639 563d 5641 5645 5649 564d
5651 5655 5659 565d 5661 5665 5669 566d
5671 5675 5679 567d 5681 5685 5689 568d
5691 5695 5699 569d 56a1 56a5 56a9 56ad
56b1 56b5 56b9 56bd 56c1 56c5 56c9 56cd
56d1 56d5 56d9 56dd 56e1 56e5 56e9 56ed
56f1 56f5 56f9 56fd 5701 5705 5709 570d
5711 5715 5719 571d 5721 5725 5729 572d
5731 5735 5739 573d 5741 5745 5749 574d
5751 5755 5759 575d 5761 5765 5769 576d
5771 5775 5779 577d 5781 5785 5789 578d
5791 5795 5799 579d 57a1 57a5 57a9 57ad
57b1 57b5 57b9 57bd 57c1 57c5 57c9 57cd
57d1 57d5 57d9 57dd 57e1 57e5 57e9 57ed
57f1 57f5 57f9 57fd 5801 5805 5809 580d
5811 5815 5819 581d 5821 5825 5829 582d
5831 5835 5839 583d 5841 5845 5849 584d
5851 5855 5859 585d 5861 5865 5869 586d
5871 5875 5879 587d 5881 5885 5889 588d
5891 5895 5899 589d 58a1 58a5 58a9 58ad
58b1 58b5 58b9 58c5 58ca 58ce 58d2 58d6
58d9 58dd 58e1 58e4 58e7 58ec 58ef 58f2
58f5 58f6 58fb 58fc 1 58fe 5903 5907
590b 590e 5913 5918 591b 591f 5920 5925
5926 592b 592d 5931 5934 5938 593c 5940
5944 5946 594a 594e 5952 5955 5956 5958
595c 595f 5963 5966 5967 596c 5970 5974
5978 597c 5980 598c 5990 5994 5997 599b
599f 59a1 1 59a5 59a9 59ad 59b0 59b4
59b8 59bc 59c0 59c3 59c7 59cb 59ce 59d1
59d6 59d9 59dc 59df 59e0 59e5 59e6 1
59e8 59ed 59f1 59f5 59f8 59fd 5a02 5a05
5a09 5a0a 5a0f 5a12 5a17 5a18 5a1d 5a20
5a25 5a26 5a2b 5a2e 5a32 5a33 5a38 5a3b
5a40 5a41 5a46 5a49 5a4d 5a51 5a54 5a57
5a58 5a5a 5a5b 5a60 5a61 5a66 5a68 5a6c
5a6f 5a71 5a75 5a77 5a83 5a85 5a87 5a88
5a8d 5a91 5a93 5a9f 5aa1 5aa5 5aa9 5aac
5ab0 5ab3 5ab7 5aba 5abb 5ac0 5ac3 5ac7
5acb 5acf 5ad3 5ad7 5adb 5adf 5ae3 5ae7
5aeb 5aef 5af3 5af7 5afb 5aff 5b03 5b07
5b0b 5b0f 5b13 5b17 5b1b 5b1f 5b23 5b27
5b2b 5b2f 5b33 5b37 5b3b 5b3f 5b43 5b47
5b4b 5b4f 5b53 5b57 5b5b 5b5f 5b63 5b67
5b6b 5b6f 5b73 5b77 5b7b 5b7f 5b83 5b87
5b8b 5b8f 5b93 5b97 5b9b 5b9f 5ba3 5ba7
5bab 5baf 5bb3 5bb7 5bbb 5bbf 5bc3 5bc7
5bcb 5bcf 5bd3 5bd7 5bdb 5bdf 5be3 5be7
5beb 5bef 5bf3 5bf7 5bfb 5bff 5c03 5c07
5c0b 5c0f 5c13 5c17 5c1b 5c1f 5c23 5c27
5c2b 5c2f 5c33 5c37 5c3b 5c3f 5c43 5c47
5c4b 5c4f 5c53 5c57 5c5b 5c5f 5c63 5c67
5c6b 5c6f 5c73 5c77 5c7b 5c7f 5c83 5c87
5c8b 5c8f 5c93 5c97 5c9b 5c9f 5ca3 5ca7
5cab 5caf 5cb3 5cb7 5cbb 5cbf 5cc3 5cc7
5ccb 5ccf 5cd3 5cd7 5cdb 5cdf 5ce3 5ce7
5ceb 5cef 5cf3 5cf7 5cfb 5cff 5d03 5d07
5d0b 5d0f 5d13 5d17 5d1b 5d1f 5d23 5d27
5d2b 5d37 5d3c 5d40 5d44 5d48 5d4b 5d4f
5d53 5d56 5d59 5d5e 5d61 5d64 5d67 5d68
5d6d 5d6e 1 5d70 5d75 5d79 5d7d 5d80
5d85 5d8a 5d8d 5d91 5d92 5d97 5d98 5d9d
5d9f 5da3 5da6 5daa 5dae 5db2 5db4 5db8
5dbb 5dbf 5dc1 5dc5 5dc9 5dcd 5dd0 5dd1
5dd3 5dd6 5dd9 5dda 5ddf 5de3 5de7 5deb
5def 5df3 5df7 5dfb 5dff 5e03 5e07 5e0b
5e0f 5e13 5e17 5e1b 5e1f 5e23 5e27 5e2b
5e2f 5e33 5e37 5e3b 5e3f 5e43 5e47 5e4b
5e4f 5e53 5e57 5e5b 5e5f 5e63 5e67 5e6b
5e6f 5e73 5e77 5e7b 5e7f 5e83 5e87 5e8b
5e8f 5e93 5e97 5e9b 5e9f 5ea3 5ea7 5eab
5eaf 5eb3 5eb7 5ebb 5ebf 5ec3 5ec7 5ecb
5ecf 5ed3 5ed7 5edb 5edf 5ee3 5ee7 5eeb
5eef 5ef3 5ef7 5efb 5eff 5f03 5f07 5f0b
5f0f 5f13 5f17 5f1b 5f1f 5f23 5f27 5f2b
5f2f 5f33 5f37 5f3b 5f3f 5f43 5f47 5f4b
5f4f 5f53 5f57 5f5b 5f5f 5f63 5f67 5f6b
5f6f 5f73 5f77 5f7b 5f7f 5f83 5f87 5f8b
5f8f 5f93 5f97 5f9b 5f9f 5fa3 5fa7 5fab
5faf 5fb3 5fb7 5fbb 5fbf 5fc3 5fc7 5fcb
5fcf 5fd3 5fd7 5fdb 5fdf 5fe3 5fe7 5feb
5fef 5ff3 5ff7 5ffb 5fff 6003 6007 600b
600f 6013 6017 601b 601f 6023 6027 602b
602f 6033 6037 603b 603f 6043 6047 604b
604f 6053 6057 605b 605f 6063 6067 606b
606f 6073 6077 607b 607f 6083 6087 608b
608f 6093 6097 609b 609f 60a3 60a7 60ab
60af 60b3 60b7 60bb 60bf 60c3 60c7 60cb
60cf 60d3 60d7 60db 60df 60e3 60e7 60eb
60ef 60f3 60f7 60fb 60ff 6103 6107 610b
610f 6113 6117 611b 611f 6123 6127 612b
612f 6133 6137 613b 613f 6143 6147 614b
614f 6153 6157 615b 615f 6163 6167 616b
616f 6173 6177 617b 617f 6183 6187 618b
618f 6193 6197 619b 619f 61a3 61a7 61ab
61af 61b3 61b7 61bb 61bf 61c3 61c7 61cb
61cf 61d3 61d7 61db 61df 61e3 61e7 61eb
61ef 61f3 61f7 61fb 61ff 6203 6207 620b
620f 6213 6217 621b 621f 6223 6227 622b
622f 6233 6237 623b 623f 6243 6247 624b
624f 6253 6257 625b 625f 6263 6267 626b
626f 6273 6277 627b 627f 6283 6287 628b
628f 6293 6297 629b 629f 62a3 62a7 62ab
62af 62b3 62b7 62bb 62bf 62c3 62c7 62cb
62cf 62d3 62d7 62e3 62e8 62ec 62f0 62f4
62f7 62fb 62ff 6302 6305 630a 630d 6310
6313 6314 6319 631a 1 631c 6321 6325
6329 632c 6331 6336 6339 633d 633e 6343
6344 6349 634b 634f 6352 6356 635a 635e
6362 6364 6368 636c 6370 6373 6374 6376
6379 637c 637d 6382 6386 638a 638e 6392
6396 639a 639e 63a2 63a6 63aa 63ae 63b2
63b6 63ba 63be 63c2 63c6 63ca 63ce 63d2
63d6 63da 63de 63e2 63e6 63ea 63ee 63f2
63f6 63fa 63fe 6402 6406 640a 640e 6412
6416 641a 641e 6422 6426 642a 642e 6432
6436 643a 643e 6442 6446 644a 644e 6452
6456 645a 645e 6462 6466 646a 646e 6472
6476 647a 647e 6482 6486 648a 648e 6492
6496 649a 649e 64a2 64a6 64aa 64ae 64b2
64b6 64ba 64be 64c2 64c6 64ca 64ce 64d2
64d6 64da 64de 64e2 64e6 64ea 64ee 64f2
64f6 64fa 64fe 6502 6506 650a 650e 6512
6516 651a 651e 6522 6526 652a 652e 6532
6536 653a 653e 6542 6546 654a 654e 6552
6556 655a 655e 6562 6566 656a 656e 6572
6576 657a 657e 6582 6586 658a 658e 6592
6596 659a 659e 65a2 65a6 65aa 65ae 65b2
65b6 65ba 65be 65c2 65c6 65ca 65ce 65d2
65de 65e3 65e7 65eb 65ef 65f2 65f6 65fa
65fd 6600 6605 6608 660b 660e 660f 6614
6615 1 6617 661c 6620 6624 6627 662c
6631 6634 6638 6639 663e 663f 6644 6646
664a 664d 6651 6655 6659 665d 665f 6663
6667 666b 666e 666f 6671 6674 6677 6678
667d 6681 6685 668a 668f 6693 6697 669b
669e 66a1 66a5 66a9 66ad 66b1 66b5 66b9
66bd 66c1 66c5 66c9 66cd 66d1 66d5 66d9
66dd 66e1 66e5 66f1 66f5 66fa 66fe 6701
6702 6707 670b 670f 6712 6715 6719 671b
671f 6723 6726 6729 672d 672f 6733 6737
673a 673c 1 6740 6744 6748 674b 674f
6753 6757 675b 675e 6762 6766 6769 676c
6771 6774 6777 677a 677b 6780 6781 1
6783 6788 678c 6790 6793 6798 679d 67a0
67a4 67a5 67aa 67ad 67b2 67b3 67b8 67bb
67c0 67c1 67c6 67c9 67cd 67ce 67d3 67d6
67db 67dc 67e1 67e4 67e8 67ec 67ef 67f2
67f3 67f5 67f6 67fb 67fc 6801 6803 6807
680a 680c 6810 6812 681e 6820 6822 6823
6828 682c 682e 683a 683c 6840 6844 6849
684e 6852 6856 685a 685d 6860 6864 6868
686c 6870 6874 6878 687c 6880 6884 6888
688c 6890 6894 6898 689c 68a8 68ac 68b1
68b5 68b8 68b9 68be 68c2 68c6 68c9 68cc
68d0 68d2 68d6 68da 68dd 68e0 68e4 68e6
68ea 68ee 68f1 68f3 1 68f7 68fb 68ff
6902 6906 690a 690e 6912 6915 6919 691d
6920 6923 6928 692b 692e 6931 6932 6937
6938 1 693a 693f 6943 6947 694a 694f
6954 6957 695b 695c 6961 6964 6969 696a
696f 6972 6977 6978 697d 6980 6984 6985
698a 698d 6992 6993 6998 699b 699f 69a3
69a6 69a9 69aa 69ac 69ad 69b2 69b3 69b8
69ba 69be 69c1 69c3 69c7 69c9 69d5 69d7
69d9 69da 69df 69e3 69e5 69f1 69f3 69f7
69fb 6a00 6a05 6a09 6a0d 6a11 6a14 6a17
6a1b 6a1f 6a23 6a27 6a2b 6a2f 6a33 6a37
6a3b 6a3f 6a43 6a47 6a4b 6a4f 6a53 6a57
6a5b 6a5f 6a63 6a67 6a6b 6a6f 6a73 6a77
6a7b 6a7f 6a83 6a87 6a8b 6a8f 6a93 6a97
6a9b 6a9f 6aa3 6aa7 6aab 6aaf 6ab3 6abf
6ac3 6ac8 6acc 6acf 6ad0 6ad5 6ad9 6add
6ae0 6ae3 6ae7 6ae9 6aed 6af1 6af4 6af7
6afb 6afd 6b01 6b05 6b08 6b0a 1 6b0e
6b12 6b16 6b19 6b1d 6b21 6b25 6b29 6b2c
6b30 6b34 6b37 6b3a 6b3f 6b42 6b45 6b48
6b49 6b4e 6b4f 1 6b51 6b56 6b5a 6b5e
6b61 6b66 6b6b 6b6e 6b72 6b73 6b78 6b7b
6b80 6b81 6b86 6b89 6b8e 6b8f 6b94 6b97
6b9b 6b9c 6ba1 6ba4 6ba9 6baa 6baf 6bb2
6bb6 6bba 6bbd 6bc0 6bc1 6bc3 6bc4 6bc9
6bca 6bcf 6bd1 6bd5 6bd8 6bda 6bde 6be0
6bec 6bee 6bf0 6bf1 6bf6 6bfa 6bfc 6c08
6c0a 6c0e 6c12 6c16 6c1a 6c1e 6c22 6c26
6c2a 6c2e 6c32 6c36 6c3a 6c3e 6c42 6c46
6c4a 6c4e 6c52 6c56 6c5a 6c5e 6c62 6c66
6c6a 6c6e 6c72 6c76 6c7a 6c7e 6c82 6c86
6c8a 6c8e 6c92 6c96 6c9a 6c9e 6ca2 6ca6
6caa 6cae 6cb2 6cb6 6cba 6cbe 6cc2 6cc6
6cca 6cce 6cd2 6cd6 6cda 6cde 6ce2 6ce6
6cea 6cee 6cf2 6cf6 6cfa 6cfe 6d02 6d06
6d0a 6d0e 6d12 6d16 6d1a 6d1e 6d22 6d26
6d2a 6d2e 6d32 6d36 6d3a 6d3e 6d42 6d46
6d4a 6d4e 6d52 6d56 6d5a 6d5e 6d62 6d66
6d6a 6d6e 6d72 6d76 6d7a 6d7e 6d82 6d86
6d8a 6d8e 6d92 6d96 6d9a 6d9e 6da2 6da6
6daa 6dae 6db2 6db6 6dba 6dc6 6dcb 6dcf
6dd3 6dd7 6dda 6dde 6de2 6de5 6de8 6ded
6df0 6df3 6df6 6df7 6dfc 6dfd 1 6dff
6e04 6e08 6e0c 6e0f 6e14 6e19 6e1c 6e20
6e21 6e26 6e27 6e2c 6e2e 6e32 6e35 6e39
6e3d 6e41 6e45 6e47 6e4b 6e4f 6e53 6e56
6e57 6e59 6e5c 6e5f 6e60 6e65 6e69 6e6d
6e71 6e75 6e79 6e7d 6e81 6e85 6e89 6e8d
6e91 6e95 6e99 6e9d 6ea1 6ea5 6ea9 6ead
6eb1 6eb5 6eb9 6ebd 6ec1 6ec5 6ec9 6ecd
6ed9 6ede 6ee2 6ee6 6eea 6eed 6ef1 6ef5
6ef8 6efb 6f00 6f03 6f06 6f09 6f0a 6f0f
6f10 1 6f12 6f17 6f1b 6f1f 6f22 6f27
6f2c 6f2f 6f33 6f34 6f39 6f3a 6f3f 6f41
6f45 6f48 6f4c 6f50 6f54 6f58 6f5a 6f5e
6f62 6f66 6f69 6f6a 6f6c 6f70 6f73 6f77
6f7a 6f7b 6f80 6f83 6f87 6f8b 6f8e 6f8f
6f91 6f95 6f98 6f9c 6f9f 6fa0 6fa5 1
6fa8 6fad 6fb1 6fb5 6fb9 6fbd 6fc1 6fc5
6fc9 6fcd 6fd1 6fd5 6fd9 6fdd 6fe1 6fe5
6fe9 6fed 6ff1 6ff5 6ff9 6ffd 7001 7005
7009 700d 7011 7015 7021 7026 702a 702e
7032 7035 7039 703d 7040 7043 7048 704b
704e 7051 7052 7057 7058 1 705a 705f
7063 7067 706a 706f 7074 7077 707b 707c
7081 7082 7087 7089 708d 7090 7094 7098
709c 709e 70a2 70a6 70aa 70ad 70b1 70b5
70b8 70bb 70c0 70c3 70c6 70c9 70ca 70cf
70d0 1 70d2 70d7 70db 70df 70e2 70e7
70ec 70ef 70f3 70f4 70f9 70fc 7101 7102
7107 710a 710f 7110 7115 7118 711c 7120
7124 7128 712b 712c 712e 7133 7134 7136
7137 713c 713f 7144 7145 714a 714d 7152
7153 7158 715b 715f 7160 7165 7168 716d
716e 7173 7174 7179 717b 717f 7182 7186
718a 718d 7191 7195 7198 719c 71a0 71a1
71a6 71a8 71ac 71b0 71b3 71b5 71b9 71bd
71c0 71c4 71c8 71cb 71cf 71d3 71d6 71d9
71de 71e1 71e4 71e7 71e8 71ed 71ee 1
71f0 71f5 71f9 71fd 7200 7205 720a 720d
7211 7212 7217 7218 721d 7221 7225 7228
722d 7232 7235 7239 723d 7240 7241 7246
7249 724e 724f 7254 7257 725b 725f 7262
7263 7268 7269 726e 7270 7274 7277 727b
727f 7283 7287 728b 728f 7293 7297 729b
72a7 72ac 72b0 72b4 72b8 72bc 72be 72bf
72c4 1 72c8 72cc 72d0 72d3 72d7 72db
72df 72e3 72e6 72ea 72ee 72f1 72f4 72f9
72fc 72ff 7302 7303 7308 7309 1 730b
7310 7314 7318 731b 7320 7325 7328 732c
732d 7332 7333 7338 733c 7340 7343 7348
734d 7350 7354 7355 735a 735d 7362 7363
7368 736b 736f 7373 7376 7379 737a 737c
737d 7382 7383 7388 738a 738e 7391 7395
7399 739d 73a1 73a5 73a9 73ad 73b9 73be
73c2 73c6 73ca 73ce 73d0 73d4 73d6 73e2
73e4 73e6 73e7 73ec 73f0 73f2 73fe 7402
7404 7405 740e 
1f2b
2
0 1 a 6 c :3 6 11 :3 6
10 :2 6 1 3 a 13 a :2 1
4 b 14 13 :2 b :2 4 9 12
11 :2 9 :2 4 f 18 17 :2 f :2 4
11 1a 19 :2 11 :2 4 9 12 11
:2 9 :2 4 f 18 17 :2 f :2 4 :2 e
1d e :2 4 :2 e 1d e :2 4 :2 e
1d e :2 4 :2 c 1b c :2 4 :2 14
23 14 :2 4 :2 12 21 12 4 7
e 17 :3 e :2 7 e 17 :3 e :2 7
e 17 :3 e :2 7 e 17 :3 e :2 7
e 17 :3 e :2 7 e 17 :3 e :2 7
e 17 :3 e :2 7 e 17 :3 e :2 7
e 17 :3 e :2 7 e 17 :3 e :2 7
e 17 :3 e :2 7 e 17 :3 e :2 7
e 17 :3 e :2 7 f 18 :3 f :2 7
13 1c :3 13 7 4 e 17 :3 e
4 7 :2 11 23 :2 2d 3a :2 23 :3 7
:2 d 19 25 :2 2f 43 :2 25 54 5a
5d :2 54 6b 81 8 :2 6b d 10
:2 6b 16 19 :2 6b b e :2 6b 13
16 1f 27 :2 1f 34 :2 16 :2 6b b
e :2 6b 13 16 :2 6b 1b 1e :2 6b
28 2b :2 6b 30 33 :2 6b :2 7 4a
:2 4 7 :2 11 23 :2 2d 39 3c 4c
4e 4f :2 4c :2 23 :3 7 :2 d 12 1e
5d 60 :2 1e :2 7 52 :2 4 :4 8 7
a :2 14 26 :2 30 3c 40 50 52
53 :2 50 :2 26 :3 a :2 10 15 21 60
63 :2 21 70 73 :2 21 77 7a :2 21
84 87 90 98 :2 a1 :2 90 b2 :2 87
:2 21 ba bd :2 21 c5 c8 :2 21 cd
d0 :2 21 d6 d9 :2 21 :2 a 56 :2 7
a :2 14 26 :2 30 3c 3f 4f 51
52 :2 4f :2 26 :3 a :2 10 15 21 60
63 :2 21 :2 a 55 :3 7 :2 12 26 :2 2f
3f 46 :2 7 17 :3 4 c :2 4 11
:2 4 12 4 8 11 1c :2 8 1f
21 :2 1f 7 28 31 3c :2 28 3f
41 :2 3f 27 :2 7 11 13 1f 21
2a 33 35 4b 4d f 1d 28
33 f 17 1a 22 2a 2c 39
42 44 51 53 :2 a :2 13 1f a
7 :2 f d :2 16 22 d 10 :2 1a
2c :2 36 42 46 56 59 5a :2 56
:2 2c :3 10 :2 16 1b 27 67 6a :2 27
77 7a :2 27 7e 81 :2 27 8d 90
:2 27 98 9b :2 27 a7 aa b1 ba
bd :2 aa :2 27 :2 10 5d :2 d :2 a :4 16
:2 a 7 :3 44 b :2 14 1f 1d :2 28
:2 1d a 14 16 22 24 2d 36
38 12 20 2b 12 1a 1d 25
2d 2f 3c 45 47 54 56 :2 d
:2 16 22 d a :2 12 10 :2 19 25
10 13 :2 1d 2f :2 39 45 49 59
5c 5d :2 59 :2 2f :3 13 :2 19 1e 2a
6a 6d :2 2a 7a 7d :2 2a 81 84
:2 2a 90 93 :2 2a 9b 9e :2 2a aa
ad b4 bd c0 :2 ad :2 2a :2 13 60
:2 10 :2 d :4 19 :2 d a :3 38 e :2 17
22 20 :2 2b :2 20 d 20 2f 3f
4c :2 10 :2 19 25 10 d :2 15 13
:2 1c 28 13 16 :2 20 32 :2 3c 48
4c 5c 5f 60 :2 5c :2 32 :3 16 :2 1c
21 2d 6d 70 :2 2d 7d 80 :2 2d
84 87 :2 2d 93 96 :2 2d 9e a1
:2 2d ad b0 b7 c0 c3 :2 b0 :2 2d
:2 16 63 :2 13 :2 10 :4 1c :2 10 d :3 3b
11 :2 1a 25 23 :2 2e :2 23 10 13
:2 1d 2f :2 39 45 49 59 5c 5d
:2 59 :2 2f :3 13 :2 19 1e 2a 6a 6d
:2 2a 7a 7d :2 2a 81 84 :2 2a 8e
91 9a a2 :2 ab :2 9a bc :2 91 :2 2a
c4 c7 :2 2a cf d2 :2 2a d7 da
:2 2a df e2 :2 2a :2 13 60 :2 10 13
:2 1d 2f :2 39 45 48 58 5b 5c
:2 58 :2 2f :3 13 :2 19 1e 2a 6a 6d
:2 2a :2 13 5f :3 10 :2 1b 2f :2 38 48
4e :2 10 3e :2 d 3b :2 a 38 :2 7
4 44 a 13 1e :2 a 21 23
:2 21 11 21 f 26 3a :2 a :2 13
1f a 7 :2 f d :2 16 22 d
10 :2 1a 2c :2 36 42 46 56 59
5a :2 56 :2 2c :3 10 :2 16 1b 27 67
6a :2 27 77 7a :2 27 7e 81 :2 27
8d 90 :2 27 98 9b :2 27 a7 aa
b1 ba bd :2 aa :2 27 :2 10 5d :2 d
:2 a :4 16 :2 a 7 :3 26 b :2 14 1f
1d :2 28 :2 1d a d :2 17 29 :2 33
3f 43 53 56 57 :2 53 :2 29 :3 d
:2 13 18 24 64 67 :2 24 74 77
:2 24 7b 7e :2 24 88 8b 94 9c
:2 a5 :2 94 b6 :2 8b :2 24 be c1 :2 24
c9 cc :2 24 d1 d4 :2 24 da dd
:2 24 :2 d 5a :2 a d :2 17 29 :2 33
3f 42 52 55 56 :2 52 :2 29 :3 d
:2 13 18 24 64 67 :2 24 :2 d 59
:3 a :2 15 29 :2 32 42 49 :2 a 38
:2 7 11 1a 30 41 4c f 1d
2a :2 a :2 13 1f a 7 :2 f d
:2 16 22 d 10 :2 1a 2c :2 36 42
46 56 59 5a :2 56 :2 2c :3 10 :2 16
1b 27 67 6a :2 27 77 7a :2 27
7e 81 :2 27 8d 90 :2 27 98 9b
:2 27 a7 aa b1 ba bd :2 aa :2 27
:2 10 5d :2 d :2 a :4 16 :2 a 7 :3 26
4 26 44 a 13 1e :2 a 21
23 :2 21 11 1b 27 37 44 :2 a
:2 13 1f a 7 :2 f d :2 16 22
d 10 :2 1a 2c :2 36 42 46 56
59 5a :2 56 :2 2c :3 10 :2 16 1b 27
67 6a :2 27 77 7a :2 27 7e 81
:2 27 8d 90 :2 27 98 9b :2 27 a7
aa b1 ba bd :2 aa :2 27 :2 10 5d
:2 d :2 a :4 16 :2 a 7 :3 26 b :2 14
1f 1d :2 28 :2 1d a d :2 17 29
:2 33 3f 43 53 56 57 :2 53 :2 29
:3 d :2 13 18 24 64 67 :2 24 74
77 :2 24 7b 7e :2 24 88 8b 94
9c :2 a5 :2 94 b6 :2 8b :2 24 be c1
:2 24 c9 cc :2 24 d1 d4 :2 24 da
dd :2 24 :2 d 5a :2 a d :2 17 29
:2 33 3f 42 52 55 56 :2 52 :2 29
:3 d :2 13 18 24 64 67 :2 24 :2 d
59 :3 a :2 15 29 :2 32 42 49 :2 a
38 :3 7 14 7 4 26 44 b
14 1f :2 b 25 22 :2 2e :2 22 a
48 51 5c :2 48 5f 62 :2 5f 47
:2 a 16 1f 2a :2 16 30 2d :2 39
:2 2d 15 :2 a 5b 11 1c :2 5b 22
1f :2 2b :2 1f 5a :2 a 11 1a 30
41 4c f 1d 2a :2 a :2 13 1f
a 7 :2 f d :2 16 22 d 10
:2 1a 2c :2 36 42 46 56 59 5a
:2 56 :2 2c :3 10 :2 16 1b 27 67 6a
:2 27 77 7a :2 27 7e 81 :2 27 8d
90 :2 27 98 9b :2 27 a7 aa b1
ba bd :2 aa :2 27 :2 10 5d :2 d :2 a
:4 16 :2 a 7 :3 49 b :2 14 1f 1d
:2 28 :2 1d a d :2 17 29 :2 33 3f
43 53 56 57 :2 53 :2 29 :3 d :2 13
18 24 64 67 :2 24 74 77 :2 24
7b 7e :2 24 88 8b 94 9c :2 a5
:2 94 b6 :2 8b :2 24 be c1 :2 24 c9
cc :2 24 d1 d4 :2 24 da dd :2 24
:2 d 5a :2 a d :2 17 29 :2 33 3f
42 52 55 56 :2 52 :2 29 :3 d :2 13
18 24 64 67 :2 24 :2 d 59 :3 a
:2 15 29 :2 32 42 49 :2 a 38 :2 7
49 44 :2 4 7 10 1b :2 7 1e
20 :2 1e 7 f 19 :3 7 :2 10 1c
7 16 :8 a c a c a c
a c a c a c a c
f 24 26 2b 3c 41 43 4f
51 10 1d 26 a 11 d 19
:3 17 d :2 16 22 d 1e d :2 16
22 d :4 a 7 :2 f d :2 16 22
d 10 :2 1a 2c :2 36 42 46 56
59 5a :2 56 :2 2c :3 10 :2 16 1b 27
67 6a :2 27 77 7a :2 27 7e 81
:2 27 8d 90 :2 27 98 9b :2 27 a7
aa b1 ba bd :2 aa :2 27 :2 10 5d
:2 d :2 a :4 16 :2 a 7 :3 22 7 f
19 :3 7 :2 10 1c 7 16 29 1a
f 10 1d 26 a 11 d 19
:3 17 d :2 16 22 d 1e d :2 16
22 d :4 a 7 :2 f d :2 16 22
d 10 :2 1a 2c :2 36 42 46 56
59 5a :2 56 :2 2c :3 10 :2 16 1b 27
67 6a :2 27 77 7a :2 27 7e 81
:2 27 8d 90 :2 27 98 9b :2 27 a7
aa b1 ba bd :2 aa :2 27 :2 10 5d
:2 d :2 a :4 16 :2 a 7 :3 22 7 c
3d 4e 57 5a 65 6e 71 7f
83 a8 7 b 18 1a 27 35
37 43 45 55 57 60 62 72
7 b 21 25 3a 3e 4d 51
67 71 74 81 84 91 94 a1
a4 b8 c9 c 22 26 2b 35
3a 3e 4a 4c 7 c 1d 22
24 2f 33 7 c 1d 22 24
2f 31 7 c 12 17 1d 23
26 2e 32 14 1d 21 2f 3c
3e 4e 61 73 7 9 12 14
24 7 9 1f 21 35 37 45
47 5d 7 a 17 1a 27 2a
37 3a 4d 5e c 1e 23 28
31 36 3a 45 47 7 c 12
17 28 2d 2f 37 39 7 c
12 17 28 2d 2f 3a 3c 7
c 12 17 1d 23 26 2e 30
14 1d 21 2f 3b 3d 4d 5f
70 7 9 12 14 24 7 9
1f 21 36 38 47 49 5f 7
a 17 1a 27 2a 37 3a 4e
5f c 1e 22 27 30 35 39
44 46 7 c 23 28 2a 35
37 7 c 12 17 28 2d 2f
38 3a 7 c 12 17 28 2d
2f 3a 3c 7 c 12 17 1d
23 26 2e 30 14 1d 21 2f
3b 3d 4d 5f 70 7 9 12
14 24 7 9 1f 21 36 38
47 49 5f 7 a 17 1a 27
2a 37 3a 4e 5f c 1e 22
27 30 35 39 44 46 7 c
22 27 29 34 36 7 c 12
17 28 2d 2f 37 39 7 c
12 17 28 2d 2f 3a 3c 7
c 12 17 1d 23 26 2e 30
10 1a 27 17 7 17 a :2 14
26 :2 30 3c 3f 4f 52 53 :2 4f
:2 26 :3 a :2 10 15 21 61 64 :2 21
:2 a 56 :3 7 e 7 4 22 b
14 1f :2 b 22 24 :2 22 a 2b
34 3f :2 2b 42 44 :2 42 2a :2 a
7 f 19 :3 7 :2 10 1c 7 16
28 35 a d 14 17 49 f
24 27 2c 32 37 48 4e 51
5c 65 68 76 79 10 13 1e
27 2a 40 43 23 34 3c 3f
4d 4f 5f 61 69 a 11 d
19 :3 17 d :2 16 22 d 1e d
:2 16 22 d :4 a 7 :2 f d :2 16
22 d 10 :2 1a 2c :2 36 42 46
56 59 5a :2 56 :2 2c :3 10 :2 16 1b
27 67 6a :2 27 77 7a :2 27 7e
81 :2 27 8d 90 :2 27 98 9b :2 27
a7 aa b1 ba bd :2 aa :2 27 :2 10
5d :2 d :2 a :4 16 :2 a 7 :3 47 7
:2 10 :3 1c 7 16 2a 35 1a 1c
28 2a f 24 26 2b 34 39
3b 51 53 5e 60 a f 20
25 27 32 34 a f 20 25
27 32 34 a f 20 25 27
39 3b 51 53 10 12 1d 26
28 a 11 d 19 :3 17 d :2 16
22 d 1e d :2 16 22 d :4 a
7 :2 f d :2 16 22 d 10 :2 1a
2c :2 36 42 46 56 59 5a :2 56
:2 2c :3 10 :2 16 1b 27 67 6a :2 27
77 7a :2 27 7e 81 :2 27 8d 90
:2 27 98 9b :2 27 a7 aa b1 ba
bd :2 aa :2 27 :2 10 5d :2 d :2 a :4 16
:2 a 7 :3 47 7 c 1e 20 2f
40 53 55 62 6f 71 79 7b
7 2e 3d 64 78 7 2e 3a
61 73 7e 8d 94 a1 b6 c7
c 1b 2e 49 5e 6f c 1d
1f 24 2e 33 35 41 43 e
1f 32 45 53 7 2e 3d 64
78 7 2e 3a 61 73 7e 8d
94 a1 d 1f 30 3f 52 6d
82 93 c 10 17 7 17 a
:2 14 26 :2 30 3c 3f 4f 52 53
:2 4f :2 26 :3 a :2 10 15 21 61 64
:2 21 :2 a 56 :3 7 e 7 4 47
22 a 13 1e :2 a 21 23 :2 21
7 c 28 2a 4d 4f 66 68
81 7 9 15 17 27 3a 42
44 57 59 66 68 76 78 7
9 16 18 21 23 2d 3a 4a
4c 5b 5d 6a 6c 7c 7 10
12 22 24 34 45 48 58 6b
6d 7a 7c 89 8b 98 9a ad
bb bd c8 ca 7 9 1f 21
2e 31 41 4c 4e 56 58 62
64 6c 6e 79 7b 89 8b 99
7 9 c 21 23 28 2e 33
44 49 4b 55 5e 60 74 76
7 c 12 17 20 25 27 35
37 42 47 4d 52 66 6b 6d
79 7b 7 c 12 17 2b 31
3a 3c 4c 4e 5b 5e 7 c
12 17 25 2b 2e 3a 3c d
f 1c 25 27 42 17 7 17
a :2 14 26 :2 30 3c 3f 4f 52
53 :2 4f :2 26 :3 a :2 10 15 21 61
64 :2 21 :2 a 56 :3 7 e 7 4
25 22 a 13 1e :2 a 21 23
:2 21 a 11 1a 25 :2 11 :2 a 29
2c :2 29 a 15 a 14 22 2f
46 53 64 6e :2 d :2 16 22 d
a :2 12 10 :2 19 25 10 13 :2 1d
2f :2 39 45 49 59 5c 5d :2 59
:2 2f :3 13 :2 19 1e 2a 6a 6d :2 2a
7a 7d :2 2a 81 84 :2 2a 90 93
:2 2a 9b 9e :2 2a aa ad b4 bd
c0 :2 ad :2 2a :2 13 60 :2 10 :2 d :4 19
:2 d a :3 2e d 16 1f :2 d 22
24 :2 22 d 1b d 26 17 27
34 20 37 44 55 5f 68 :2 10
:2 19 25 10 d :2 15 13 :2 1c 28
13 16 :2 20 32 :2 3c 48 4c 5c
5f 60 :2 5c :2 32 :3 16 :2 1c 21 2d
6d 70 :2 2d 7d 80 :2 2d 84 87
:2 2d 93 96 :2 2d 9e a1 :2 2d ad
b0 b7 c0 c3 :2 b0 :2 2d :2 16 63
:2 13 :2 10 :4 1c :2 10 d :3 a 10 19
22 :2 10 25 27 :2 25 1a 2a 37
23 34 37 3c 56 16 1a 27
2a 39 3d 4b 4e 19 1c 29
3a 3d 47 14 1c 23 26 49
4d :2 13 :2 1c 28 13 10 :2 18 16
:2 1f 2b 16 19 :2 23 35 :2 3f 4b
4f 5f 62 63 :2 5f :2 35 :3 19 :2 1f
24 30 70 73 :2 30 80 83 :2 30
87 8a :2 30 96 99 :2 30 a1 a4
:2 30 b0 b3 ba c3 c6 :2 b3 :2 30
:2 19 66 :2 16 :2 13 :4 1f :2 13 10 :3 29
13 1c 25 :2 13 28 2a :2 28 13
21 13 2c 13 21 13 :4 10 29
10 1e 10 :4 d :5 a f 21 23
2f 31 3e 40 4e 50 5f 72
74 81 83 8c 8e a c 10
12 16 18 24 33 35 42 a
c 1b 1d 2f 3d 3f 4e 50
61 63 72 c 1b 1d 14 16
32 39 43 45 52 5c 5e 6d
6f 8e a 31 3e 65 78 a
c 1b 1d 2d 2f 34 36 43
45 a c 1b 22 24 34 36
47 49 5c a 17 2c 41 54
10 27 42 57 6c 81 10 1e
20 31 3f 41 51 53 64 66
7a 10 2c 40 55 62 71 7e
8e a1 b4 c3 f 21 2f 3e
4f 51 5f 61 78 14 2b 2d
3e 69 14 2b 2d 3f 6a 14
2b 2d 4a 58 5a 6a 81 90
10 28 42 5d 7b 10 23 f
17 19 1e 23 38 3d 3f 4c
4e 5d 5f 6d a f 15 1a
2e 33 35 41 43 10 12 1f
30 32 3f 1b 1d 40 42 59
5b 74 80 82 14 16 35 37
49 52 5a 5c 6a 6c 17 19
28 32 3a 3c 4a 4c 60 14
16 3e 40 69 a c 1f 21
2e 30 3a 3c 51 14 16 1b
24 2e 30 35 3e 49 52 5d
5f 69 77 79 7e 87 92 9b
a6 a8 b2 b6 b8 cc db dd
f2 14 28 38 4c 14 28 35
46 5a 14 16 25 27 36 38
4a 4c 5d f 14 16 32 39
43 45 52 5c 69 84 a c
19 1b 29 2b a c 1b 1d
2d 2f 34 36 43 45 a c
1b 22 32 43 a 17 27 29
38 3a 47 49 59 a 13 15
25 27 37 48 4b 5b 6e 70
7d 7f 8c 8e 9b 9d 14 16
35 37 4a 54 5c 5e 6c 6e
19 27 29 34 36 44 46 56
58 69 6b a c 22 24 32
35 45 55 57 5f 61 6b 6d
75 77 82 84 92 94 a2 a4
ae b0 a c 28 2a 48 4a
72 7c 7e 94 a2 a4 bb 14
2b 34 36 42 44 5b 86 14
2b 34 36 43 45 5d 88 14
35 37 4d 4f 58 5a 79 87
89 9e b5 c4 a c a d
1d a c a d 1d 34 36
a c 19 1d 2d f 24 26
2b 31 36 47 4c 4e 62 64
a f 15 1a 2e 33 35 41
43 a f 15 1a 2e 34 3d
3f 4f 51 5e 61 a f 15
1a 28 2e 31 3d 3f a f
15 1a 2a 30 33 40 42 a
f 15 1a 2a 30 33 40 42
a f 15 1a 28 2f 33 40
42 10 12 1f 30 32 3f 48
4a 13 1b 1a a 1a d :2 17
29 :2 33 3f 42 52 55 56 :2 52
:2 29 :3 d :2 13 18 24 64 67 :2 24
:2 d 59 :3 a 11 a 2e a f
2b 2d 50 52 69 6b 84 8f
91 14 16 35 37 49 52 5a
5c 6a 6c 17 19 28 32 3a
3c 4a 4c 60 14 16 3e 40
69 a c 1f 21 2e 30 39
3b a c 10 12 16 18 2c
3b 3d 52 a 12 2a 3e 4e
62 a c 19 28 2a 42 a
c 19 1b 29 2b a c 1b
1d 2d 2f 34 36 43 45 a
c 1b 22 32 43 a 17 27
29 38 3a 47 49 59 a 13
15 25 27 37 48 4b 5b 6e
70 7d 7f 8c 8e 9b 9d 14
16 35 37 4a 54 5c 5e 6c
6e 19 27 29 34 36 44 46
56 58 69 6b a c 22 24
32 35 45 55 57 5f 61 6b
6d 75 77 82 84 92 94 a2
a4 ae b0 a c 28 2a 48
4a 72 7c 7e 94 a7 a c
19 1b 29 2b 39 3b 50 67
14 16 38 3a 52 54 6b 6d
7c 7e 92 94 a4 a6 d2 a
c a d 1d a c a d
1d 34 36 a c 19 1d 2d
f 24 26 2b 31 36 47 4c
4e 62 64 a f 15 1a 2e
33 35 41 43 a f 15 1a
2e 34 3d 3f 4f 51 5e 61
a f 15 1a 28 2e 31 3d
3f a f 15 1a 2a 30 33
40 42 a f 15 1a 2a 30
33 40 42 a f 15 1a 28
2f 33 40 42 10 12 32 34
41 13 1c 1a a 1a d :2 17
29 :2 33 3f 42 52 55 56 :2 52
:2 29 :3 d :2 13 18 24 64 67 :2 24
:2 d 59 :3 a 11 a :4 7 4 25
22 a 13 1e :2 a 21 23 :2 21
7 f 19 :3 7 :2 10 1c 7 16
:c a e 20 a e 21 a e
1f a e 1e a e 1f a
e 1d a e 16 f 26 31
3a 61 6e a 11 d 19 :3 17
d :2 16 22 d 1e d :2 16 22
d :4 a 7 :2 f d :2 16 22 d
10 :2 1a 2c :2 36 42 46 56 59
5a :2 56 :2 2c :3 10 :2 16 1b 27 67
6a :2 27 77 7a :2 27 7e 81 :2 27
8d 90 :2 27 98 9b :2 27 a7 aa
b1 ba bd :2 aa :2 27 :2 10 5d :2 d
:2 a :4 16 :2 a 7 :3 25 7 :2 10 :3 1c
7 16 2a 35 43 52 62 71
7d a 10 1a 1c 27 29 a
c 1b 1d 2c 2e 3e 40 4c
4e 5b 5d 63 65 f 1f 21
26 2f 34 36 4c 4e 59 5b
67 6c 7d 82 84 8f 91 a
f 20 25 27 32 34 a 11
d 19 :3 17 d :2 16 22 d 1e
d :2 16 22 d :4 a 7 :2 f d
:2 16 22 d 10 :2 1a 2c :2 36 42
46 56 59 5a :2 56 :2 2c :3 10 :2 16
1b 27 67 6a :2 27 77 7a :2 27
7e 81 :2 27 8d 90 :2 27 98 9b
:2 27 a7 aa b1 ba bd :2 aa :2 27
:2 10 5d :2 d :2 a :4 16 :2 a 7 :3 25
7 c 1e 20 2f 40 53 55
62 75 7d 7f 7 9 18 1a
29 2b 3b 3d 49 4b 58 5a
60 62 71 78 85 d 1e 30
3f 52 6d 7b 7d 92 a3 c
1c 1e 23 2d 32 34 4c 4e
5a 5c e 1f 32 45 53 7
16 25 37 43 50 56 65 6c
79 d 1f 30 3f 52 6d 81
96 a7 c 29 17 7 17 a
:2 14 26 :2 30 3c 3f 4f 52 53
:2 4f :2 26 :3 a :2 10 15 21 61 64
:2 21 :2 a 56 :3 7 e 7 4 25
22 a 13 1e :2 a 21 23 :2 21
7 f 19 :3 7 :2 10 1c 7 16
:c a e 20 a e 21 a e
1f a e 1e a e 1f a
e 1d a e 16 f 26 31
3a 61 6e a 11 d 19 :3 17
d :2 16 22 d 1e d :2 16 22
d :4 a 7 :2 f d :2 16 22 d
10 :2 1a 2c :2 36 42 46 56 59
5a :2 56 :2 2c :3 10 :2 16 1b 27 67
6a :2 27 77 7a :2 27 7e 81 :2 27
8d 90 :2 27 98 9b :2 27 a7 aa
b1 ba bd :2 aa :2 27 :2 10 5d :2 d
:2 a :4 16 :2 a 7 :3 25 7 :2 10 :3 1c
7 16 2a 35 43 52 5b 6b
7a 8a 99 a5 a 10 1b 1a
1c 28 2a a c 1b 1d 2c
2e 3e 40 4c 4e 5b 5d 63
65 f 1f 21 26 2f 34 36
4c 4e 59 5b 67 6c 7d 82
84 8f 91 a f 20 25 27
32 34 1a 1d 2a 2c 40 42
a 30 a 30 5d 5f f 24
28 32 10 13 1e 27 2a 38
3a 20 23 3a 4b 10 13 30
32 f 24 2c 2e 3b 3e 4d
4f 5d 60 a 11 d 19 :3 17
d :2 16 22 d 1e d :2 16 22
d :4 a 7 :2 f d :2 16 22 d
10 :2 1a 2c :2 36 42 46 56 59
5a :2 56 :2 2c :3 10 :2 16 1b 27 67
6a :2 27 77 7a :2 27 7e 81 :2 27
8d 90 :2 27 98 9b :2 27 a7 aa
b1 ba bd :2 aa :2 27 :2 10 5d :2 d
:2 a :4 16 :2 a 7 :3 25 7 c 1e
20 2f 40 53 55 62 75 7d
7f 7 9 18 1a 29 2b 3b
3d 49 4b 58 5a 60 62 71
78 85 d 1e 30 3f 52 6d
7b 7d 92 a3 c 1c 1e 23
2d 32 34 4c 4e 5a 5c e
1f 32 3f 47 7 16 25 37
43 50 56 65 6c 79 d 1f
30 3f 52 6d 7c 91 a2 c
26 3c e 1f 32 3f 47 7
16 25 7 13 20 26 35 3c
49 5e 6f c 1b 2e 49 57
6c 7d c d 25 10 1e 17
7 17 a :2 14 26 :2 30 3c 3f
4f 52 53 :2 4f :2 26 :3 a :2 10 15
21 61 64 :2 21 :2 a 56 :3 7 e
7 4 25 22 a 13 1e :2 a
21 23 :2 21 7 c 1e 20 2f
3b 3d 50 52 5f 73 7b 7d
7 9 18 1a 2a 2c 34 44
46 56 69 6b 7b 87 89 9a
7 9 11 17 19 27 32 3f
54 66 c 1a 2d 48 56 58
6d 7e 7 a 18 1b 29 2c
3a 3d 4b 4e 7 a 1f 22
38 3b 4e 51 7 a 25 28
44 47 7 a 25 28 44 47
c 21 23 28 3c 42 45 52
5b 5e 6c 6e 7 c 11 22
27 29 3b 3d 53 55 7 c
11 22 27 29 3b 3d 53 55
7 c 16 1b 1d 29 2b d
f 1a 23 25 3c 3e 5f 61
e 10 1f 2b 2d 40 42 52
66 74 7 9 18 1a 29 2b
33 42 44 54 66 8d 99 c0
c 16 20 2d 42 54 c 1b
2e 43 45 59 6e 7f 7 a
18 1b 29 2c 3a 3d 4b 4e
7 a 1f 22 38 3b 4e 51
7 a 25 28 44 47 7 a
25 28 44 47 c 21 23 28
31 36 38 44 46 7 c 1d
22 24 36 38 7 c 20 26
29 36 3f 42 50 52 d f
1a 23 25 10 1e 17 7 17
a :2 14 26 :2 30 3c 3f 4f 52
53 :2 4f :2 26 :3 a :2 10 15 21 61
64 :2 21 :2 a 56 :3 7 e 7 4
25 22 a 13 1e :2 a 21 23
:2 21 7 f 19 :3 7 :2 10 1c 7
16 b :d a e 21 a e 21
a e 21 a 18 2a 3e a
e 21 a e 21 a e 21
a 18 2a 3e f 10 1b 24
2c 13 20 a 11 d 19 :3 17
d :2 16 22 d 1e d :2 16 22
d :4 a 7 :2 f d :2 16 22 d
10 :2 1a 2c :2 36 42 46 56 59
5a :2 56 :2 2c :3 10 :2 16 1b 27 67
6a :2 27 77 7a :2 27 7e 81 :2 27
8d 90 :2 27 98 9b :2 27 a7 aa
b1 ba bd :2 aa :2 27 :2 10 5d :2 d
:2 a :4 16 :2 a 7 :3 25 7 f 19
:3 7 :2 10 1c 7 16 :20 a c 1e
20 36 38 4e 50 a c 1e
20 36 38 4e 50 a c 1e
20 36 38 4e 50 a c 1e
20 36 38 a c 21 23 39
3b 4e 50 a c 27 29 45
47 a c 27 29 45 47 a
c 1e 20 36 38 4e 50 a
13 15 28 2a 37 39 60 62
f 23 25 2a 30 35 46 4b
4d 5b 5d 10 12 1d a 11
d 19 :3 17 d :2 16 22 d 1e
d :2 16 22 d :4 a 7 :2 f d
:2 16 22 d 10 :2 1a 2c :2 36 42
46 56 5a 5b :2 56 :2 2c :3 10 :2 16
1b 27 68 6b :2 27 78 7b :2 27
7f 82 :2 27 8e 91 :2 27 99 9c
:2 27 a8 ab b2 bb be :2 ab :2 27
:2 10 5e :2 d :2 a :4 16 :2 a 7 :3 25
11 22 29 3c 11 1e 2f 37
39 44 4d 4f 5d 60 70 72
a 11 d 19 :3 17 d :2 16 22
d 1e d :2 16 22 d :4 a 7
:2 f d :2 16 22 d 10 :2 1a 2c
:2 36 42 46 56 5a 5b :2 56 :2 2c
:3 10 :2 16 1b 27 68 6b :2 27 78
7b :2 27 7f 82 :2 27 8e 91 :2 27
99 9c :2 27 a8 ab b2 bb be
:2 ab :2 27 :2 10 5e :2 d :2 a :4 16 :2 a
7 :3 25 7 c 1e 20 2f 40
53 55 62 70 72 7a 7c 7
9 18 1a 29 2b 3b 3d 49
4b 58 5a 60 62 71 78 85
d 1e 30 3f 52 6d 7b 7d
92 a3 11 13 34 36 57 59
74 8b 8d a0 a2 b6 b8 cb
cd de e0 f2 f4 7 f 7
9 1e 20 36 38 4b 4d 7
9 24 26 42 44 7 9 24
26 42 44 7 9 17 19 27
29 37 39 47 49 c 1d 1f
24 2e 33 35 4d 4f 5b 5d
f 11 1f 30 43 45 55 68
76 7 9 18 1a 29 2b 3b
3d 49 4b 58 5a 60 62 71
78 85 d 1f 30 3f 52 6d
81 96 a7 11 13 34 36 57
59 74 8b 8d a0 a2 b6 b8
cb cd de e0 f2 f4 7 f
7 9 1e 20 36 38 4b 4d
7 9 24 26 42 44 7 9
24 26 42 44 7 9 17 19
27 29 37 39 47 49 c 1d
1f 24 2d 32 34 4a 4c 57
59 7 c 1d 22 24 2f 31
7 c 1d 22 24 2f 31 17
7 17 a :2 14 26 :2 30 3c 3f
4f 53 54 :2 4f :2 26 :3 a :2 10 15
21 62 65 :2 21 :2 a 57 :3 7 e
7 4 25 22 a 13 1e :2 a
23 21 :2 2c :2 21 11 23 2d 3c
49 :2 a :2 13 1f a 7 :2 f d
:2 16 22 d 10 :2 1a 2c :2 36 42
46 56 5a 5b :2 56 :2 2c :3 10 :2 16
1b 27 68 6b :2 27 78 7b :2 27
7f 82 :2 27 8e 91 :2 27 99 9c
:2 27 a8 ab b2 bb be :2 ab :2 27
:2 10 5e :2 d :2 a :4 16 :2 a 7 :3 40
b :2 14 1f 1d :2 28 :2 1d :2 a f
21 29 35 3d 50 5e 69 6b
74 7c a 12 16 26 30 38
3c 4c 56 5f 64 74 f 18
a f 14 26 2d 31 3f a
f 14 24 2d 31 3f a f
14 1e 2d 32 3f 10 12 1f
11 19 25 2d 40 48 4b 56
a d 1b 24 2f 3c 47 54
5a 5d 73 79 7c 8e d 1b
28 36 43 52 f 25 27 2c
32 37 48 4e 50 58 5b a
f 15 1a 2b 31 34 3f 42
52 54 66 11 19 25 2d 40
48 4b 56 a d 1b 24 2f
3c 47 54 5a 5d 73 79 7c
8e d 1b 28 36 43 52 f
26 28 2d 33 38 49 4f 51
5a 5d a f 15 1a 2b 31
34 3f 42 52 54 66 13 1e
1a a 1a d :2 17 29 :2 33 3f
42 52 56 57 :2 52 :2 29 :3 d :2 13
18 24 65 68 :2 24 :2 d 5a :3 a
11 a 38 :2 7 4 40 22 a
13 1e :2 a 21 23 :2 21 7 c
28 2a 4d 4f 66 68 81 8d
8f 11 13 32 34 46 4f 57
59 67 69 14 16 25 2f 37
39 47 49 5d 11 13 3b 3d
66 7 9 1c 1e 2b 2d 36
38 7 9 d f 13 15 29
38 3a 4f 11 25 35 49 11
25 32 43 57 11 13 22 24
33 35 47 49 5a c 11 13
2f 36 40 42 4f 59 66 81
7 9 16 18 26 28 7 9
18 1a 2a 2c 31 33 40 42
7 9 18 1f 2f 40 7 14
24 26 35 37 44 46 56 7
10 12 22 24 34 45 48 58
6b 6d 7a 7c 89 8b 98 9a
11 13 32 34 47 51 59 5b
69 6b 16 24 26 31 33 41
43 53 55 66 68 7 9 1f
21 2f 32 42 52 54 5c 5e
68 6a 72 74 7f 81 8f 91
9f a1 ab ad 7 9 25 27
45 47 6f 79 7b 91 9f a1
b8 11 28 31 33 3f 41 58
83 11 28 31 33 40 42 5a
85 11 32 34 4a 4c 55 57
76 84 86 9b b2 11 13 35
37 4f 51 68 6a 79 7b 8f
91 a1 a3 cf 7 9 7 a
1a 7 9 7 a 1a 31 33
7 9 16 1a 2a c 21 23
28 39 3e 40 54 5d 5f 73
75 7 c 12 17 2b 30 32
3e 40 7 c 12 17 2b 31
3a 3c 4c 4e 5b 5e 7 c
12 17 25 2b 2e 3a 3c 7
c 12 17 27 2d 30 3d 3f
7 c 12 17 27 2d 30 3d
3f 7 c 12 17 25 2c 30
3d 3f 10 1e 17 7 17 a
:2 14 26 :2 30 3c 3f 4f 53 54
:2 4f :2 26 :3 a :2 10 15 21 62 65
:2 21 :2 a 57 :3 7 e 7 4 26
22 a 13 1e :2 a 21 23 :2 21
7 c 1e 20 35 41 43 11
13 32 34 46 4f 57 59 67
69 14 16 25 2f 37 39 47
49 5d 11 13 2a 33 4e 58
5a 6d 6f 7c a3 b2 d9 c
19 40 49 70 7 2e 3a 61
74 7 2e 3b 62 76 7 2e
3d 64 79 7 2e 3b 62 c
13 20 30 32 41 68 7 9
16 18 28 37 40 42 52 54
64 75 78 88 c 1e 30 43
11 13 32 34 47 51 59 5b
69 6b 16 7 9 1a 7 2e
3e 65 7b d 2a 3e 53 c
1b 28 38 4b 5e :2 c 21 7
c 12 17 2b 30 32 3e 40
7 c 12 17 2b 31 3a 3c
4c 4e 5b 5e d f 2f 31
3e 10 1e 17 7 17 a :2 14
26 :2 30 3c 3f 4f 53 54 :2 4f
:2 26 :3 a :2 10 15 21 62 65 :2 21
:2 a 57 :3 7 e 7 4 26 22
a 13 1e :2 a 21 23 :2 21 7
f 19 :3 7 :2 10 1c 7 16 23
30 3f 11 1e 34 f 10 1d
:2 a 17 20 13 20 a 11 d
19 :3 17 d :2 16 22 d 1e d
:2 16 22 d :4 a 7 :2 f d :2 16
22 d 10 :2 1a 2c :2 36 42 46
56 5a 5b :2 56 :2 2c :3 10 :2 16 1b
27 68 6b :2 27 78 7b :2 27 7f
82 :2 27 8e 91 :2 27 99 9c :2 27
a8 ab b2 bb be :2 ab :2 27 :2 10
5e :2 d :2 a :4 16 :2 a 7 :3 26 7
f 19 :3 7 :2 10 1c 7 16 26
33 42 12 1f 35 f 10 1d
a 14 13 20 a 11 d 19
:3 17 d :2 16 22 d 1e d :2 16
22 d :4 a 7 :2 f d :2 16 22
d 10 :2 1a 2c :2 36 42 46 56
5a 5b :2 56 :2 2c :3 10 :2 16 1b 27
68 6b :2 27 78 7b :2 27 7f 82
:2 27 8e 91 :2 27 99 9c :2 27 a8
ab b2 bb be :2 ab :2 27 :2 10 5e
:2 d :2 a :4 16 :2 a 7 :3 26 7 f
19 :3 7 :2 10 1c 7 16 2d 3a
49 11 13 20 22 31 33 f
1b 1d 22 28 2d 3c 41 43
4f 51 11 13 20 22 31 33
f 1e 20 25 2b 30 3c 41
43 4f 51 a 11 d 19 :3 17
d :2 16 22 d 1e d :2 16 22
d :4 a 7 :2 f d :2 16 22 d
10 :2 1a 2c :2 36 42 46 56 5a
5b :2 56 :2 2c :3 10 :2 16 1b 27 68
6b :2 27 78 7b :2 27 7f 82 :2 27
8e 91 :2 27 99 9c :2 27 a8 ab
b2 bb be :2 ab :2 27 :2 10 5e :2 d
:2 a :4 16 :2 a 7 :3 26 7 c 1e
20 2f 3b 3d 4a 5d 66 68
73 75 c 22 24 29 33 38
3a 52 54 60 62 7 c 12
17 26 2d 2f 3b 3f 17 19
27 33 35 45 58 68 73 75
c 22 24 29 32 37 39 51
53 60 62 7 c 1d 22 24
2f 31 7 c 1d 22 24 2f
31 7 c 12 17 26 2d 2f
3b 3f 17 1a 29 35 37 44
59 62 64 76 c 21 25 2f
d 10 1b 7 a 18 1a 19
1c 2d 43 4c 4f 5d 60 10
1e 17 7 17 a :2 14 26 :2 30
3c 3f 4f 53 54 :2 4f :2 26 :3 a
:2 10 15 21 62 65 :2 21 :2 a 57
:3 7 e 7 4 26 22 a 13
1e :2 a 21 23 :2 21 7 c 1f
21 2d 2f 3c 4f 58 5a 6c
c 16 18 1d 27 a c 19
1b d f b d 17 10 18
7 18 a :2 14 26 :2 30 3c 3f
4f 53 54 :2 4f :2 26 :3 a :2 10 15
21 62 65 :2 21 :2 a 57 :3 7 e
7 4 26 22 b 14 1f :2 b
24 22 :2 2d :2 22 a 4e 11 1c
:2 4e 21 1f :2 2a :2 1f 4d :2 a 7
c 23 25 34 40 42 4f 5c
65 74 7d 7f 91 c 20 24
2e d 10 1d b e 1c 1e
10 1c 7 1c a :2 14 26 :2 30
3c 3f 4f 53 54 :2 4f :2 26 :3 a
:2 10 15 21 62 65 :2 21 :2 a 57
:3 7 e 7 48 22 a :2 14 26
:2 30 3c 3f 4f 53 54 :2 4f :2 26
:3 a :2 10 15 21 62 65 :2 21 72
75 :2 21 79 7c :2 21 86 89 92
9a :2 a3 :2 92 b4 :2 89 :2 21 bc bf
:2 21 c7 ca :2 21 cf d2 :2 21 d8
db :2 21 :2 a 57 :3 7 :2 12 24 :2 2d
3d 44 :2 7 :4 4 1 9 12 9
a :2 14 26 :2 30 3c 40 50 54
55 :2 50 :2 26 :3 a :2 10 15 21 62
65 :2 21 :3 a :2 10 15 39 5c 5f
:2 68 :2 39 76 79 :2 39 81 84 :2 8d
:2 39 :2 a 58 :3 7 c 15 1e 2c
a 13 1e f e 7 e 7
e 7 29 :2 4 :2 9 7 :2 10 1c
:2 7 :2 11 23 :2 2d 39 3d 4d 51
52 :2 4d :2 23 :3 7 :2 d 12 1e 5f
62 :2 1e :3 7 :2 d 12 36 42 45
:2 36 4d 50 :2 36 5c 5f 66 6f
72 :2 5f :2 36 :2 7 55 :2 4 7 c
1b a 13 1e f e 7 e
7 e 7 :2 4 :4 10 :2 4 :8 1 
1f2b
4
0 :2 1 :4 3 :4 4
:4 5 2 :4 6 :2 1
:7 8 :7 9 :7 a :7 b
:7 c :7 d :6 e :6 f
:6 10 :6 11 :6 12 :6 13
:7 16 :7 19 :7 1c :7 1f
:7 22 :7 25 :7 28 :7 2b
:7 2e :7 31 :7 34 :7 37
:7 3a :7 3d :7 40 :7 42
:b 44 :11 45 46 :2 45
:2 46 :2 45 :2 46 :2 45
:2 47 :2 45 :9 47 :2 45
:2 48 :2 45 :2 48 :2 45
:2 48 :2 45 :2 48 :2 45
:2 48 :4 45 :3 44 :11 4b
:b 4c :3 4b :5 51 :11 52
:30 53 :3 52 :11 55 :b 56
:3 55 :a 58 :3 51 :3 5d
:3 5e :3 5f :16 62 :9 64
:4 65 :b 66 64 :5 67
63 :2 69 :5 6b :11 6c
:24 6d :3 6c :2 6a :6 69
68 :3 62 :a 73 :7 75
:3 76 :b 77 75 :5 78
74 :2 7a :5 7c :11 7d
:24 7e :3 7d :2 7b :6 7a
79 :3 73 :a 84 :5 86
:5 87 85 :2 89 :5 8b
:11 8c :24 8d :3 8c :2 8a
:6 89 88 :3 84 :a 92
:11 93 :30 94 :3 93 :11 96
:b 97 :3 96 :a 99 :3 92
:3 84 :3 73 9d 62
:9 9d :2 9f :3 a0 9f
:5 a1 9e :2 a3 :5 a5
:11 a6 :24 a7 :3 a6 :2 a4
:6 a3 a2 :3 9d :a ac
:11 ad :30 ae :3 ad :11 b0
:b b1 :3 b0 :a b3 :3 ac
:5 b7 :3 b8 b7 :5 b9
b6 :2 bb :5 bd :11 be
:24 bf :3 be :2 bc :6 bb
ba :3 9d c3 9d
62 :9 c3 :6 c5 :5 c6
c4 :2 c8 :5 ca :11 cb
:24 cc :3 cb :2 c9 :6 c8
c7 :3 c3 :a d1 :11 d2
:30 d3 :3 d2 :11 d5 :b d6
:3 d5 :a d8 :3 d1 :3 db
dc c3 62 :18 dc
:c dd :2 dc dd :2 de
:2 dd :6 de dd :2 dc
:5 e0 :3 e1 e0 :5 e2
df :2 e4 :5 e6 :11 e7
:24 e8 :3 e7 :2 e5 :6 e4
e3 :3 de :a ed :11 ee
:30 ef :3 ee :11 f1 :b f2
:3 f1 :a f4 :3 ed de
:3 62 :9 fa :5 fc :5 fd
100 102 103 104
105 106 107 108
:2 10b :2 10c :2 10d :2 10e
:2 10f :2 110 :2 111 :9 112
:3 113 100 :6 114 :5 115
114 :5 117 116 :3 114
ff :2 11a :5 11c :11 11d
:24 11e :3 11d :2 11b :6 11a
119 :3 fa :5 124 :5 125
:2 128 129 12a :3 12b
128 :6 12c :5 12d 12c
:5 12f 12e :3 12c 127
:2 132 :5 134 :11 135 :24 136
:3 135 :2 133 :6 132 131
:3 fa :c 13b :e 13c :13 13d
:9 13e :7 13f :7 140 :9 141
:9 145 :5 146 :9 147 :a 148
:9 149 :9 14a :9 14b :9 14c
:9 150 :5 151 :9 152 :a 153
:9 154 :7 155 :9 156 :9 157
:9 158 :9 15c :5 15d :9 15e
:a 15f :9 160 :7 161 :9 162
:9 163 :9 164 :3 165 :3 13b
:11 166 :b 167 :3 166 :3 169
16a fa :16 16a :5 16c
:5 16d :3 170 :2 172 :3 173
:e 174 :7 175 :9 176 170
:6 177 :5 178 177 :5 17a
179 :3 177 16f :2 17d
:5 17f :11 180 :24 181 :3 180
:2 17e :6 17d 17c :3 16a
:7 186 :3 189 :4 18a :b 18b
:7 18c :7 18d :9 18e :5 18f
189 :6 190 :5 191 190
:5 193 192 :3 190 188
:2 196 :5 198 :11 199 :24 19a
:3 199 :2 197 :6 196 195
:3 16a :d 19f :5 1a0 :b 1a1
:6 1a2 :9 1a3 :5 1a7 :5 1a8
:9 1a9 :8 1aa 1ab 1ac
:3 19f :11 1ad :b 1ae :3 1ad
:3 1b0 1b1 16a fa
:9 1b1 :9 1b2 :e 1b3 :f 1b4
:16 1b5 :14 1b6 :2 1b7 :e 1b8
:12 1b9 :c 1ba :9 1bb :6 1bc
:3 1b2 :11 1bd :b 1be :3 1bd
:3 1c0 1c1 1b1 fa
:9 1c1 :c 1c2 :3 1c3 :8 1c5
:5 1c6 1c4 :2 1c8 :5 1ca
:11 1cb :24 1cc :3 1cb :2 1c9
:6 1c8 1c7 :3 1c2 :9 1d1
:3 1d2 1d1 :3 1d5 :6 1d6
1d5 :5 1d7 1d4 :2 1d9
:5 1db :11 1dc :24 1dd :3 1dc
:2 1da :6 1d9 1d8 :3 1d3
:9 1e2 :3 1e4 :5 1e5 :8 1e6
:6 1e7 :6 1e8 1e4 :5 1e9
1e3 :2 1eb :5 1ed :11 1ee
:24 1ef :3 1ee :2 1ec :6 1eb
1ea :3 1e2 :9 1f4 :3 1f5
1f4 :3 1f7 1f6 :3 1f4
1e2 :3 1fa 1f9 :3 1e2
1d3 :3 1d1 :11 202 :a 203
:c 204 :3 205 :c 206 :5 207
:a 208 :a 209 :5 20a :6 20b
:b 20c :b 20d :9 20e :5 20f
:5 210 :9 211 :5 212 :2 213
:d 214 :9 215 :6 216 :9 218
:a 219 :9 21a :5 21b :9 21c
:1c 21d :4 21e :5 21f :9 220
221 :a 222 :6 223 :a 224
:6 225 :9 226 :11 227 :a 228
:b 229 :17 22a :d 22b :8 22c
:8 22d :d 22e :2 22f :3 230
:2 231 :5 232 :5 233 :b 234
:9 235 :c 236 :9 237 :9 238
:9 239 :9 23a :8 23b :2 23c
:3 202 :11 23d :b 23e :3 23d
:3 240 1c2 :b 244 :a 245
:9 246 :5 247 :8 248 :a 249
:6 24a :6 24b :6 24c :a 24d
:6 24e :9 24f :11 250 :a 251
:b 252 :17 253 :b 254 :a 255
:f 256 :2 257 :3 258 :2 259
:5 25a :5 25b :b 25c :9 25d
:c 25e :9 25f :9 260 :9 261
:9 262 :5 263 :2 264 :3 244
:11 265 :b 266 :3 265 :3 268
241 :3 1c2 26a 1c1
fa :9 26a :5 26c :5 26d
270 272 273 274
275 276 277 278
279 27a 27d 27e
:3 27f :3 280 :3 281 :3 282
:3 283 :3 284 :3 285 :6 286
270 :6 287 :5 288 287
:5 28a 289 :3 287 26f
:2 28d :5 28f :11 290 :24 291
:3 290 :2 28e :6 28d 28c
:3 26a :7 296 :8 299 :2 29a
:4 29b :e 29c :12 29d :7 29e
299 :6 29f :5 2a0 29f
:5 2a2 2a1 :3 29f 298
:2 2a5 :5 2a7 :11 2a8 :24 2a9
:3 2a8 :2 2a6 :6 2a5 2a4
:3 26a :c 2ae :11 2af :a 2b0
:b 2b1 :5 2b5 :a 2b6 :9 2b7
:2 2b8 :3 2ae :11 2b9 :b 2ba
:3 2b9 :3 2bc 2bd 26a
fa :9 2bd :5 2bf :5 2c0
2c3 2c5 2c6 2c7
2c8 2c9 2ca 2cb
2cc 2cd 2d0 2d1
:3 2d2 :3 2d3 :3 2d4 :3 2d5
:3 2d6 :3 2d7 :3 2d8 :6 2d9
2c3 :6 2da :5 2db 2da
:5 2dd 2dc :3 2da 2c2
:2 2e0 :5 2e2 :11 2e3 :24 2e4
:3 2e3 :2 2e1 :6 2e0 2df
:3 2bd :7 2e9 :b 2ec :3 2ed
:4 2ee :e 2ef :12 2f1 :7 2f2
:6 2f4 :2 2f5 :4 2f6 :4 2f7
:7 2f8 :4 2f9 :4 2fa :a 2fb
2ec :6 2fc :5 2fd 2fc
:5 2ff 2fe :3 2fc 2eb
:2 302 :5 304 :11 305 :24 306
:3 305 :2 303 :6 302 301
:3 2bd :c 30b :11 30c :a 30d
:b 30e :5 310 :a 311 :9 312
:3 313 :5 315 :3 316 :9 317
:7 318 319 :2 31a :2 31b
:3 30b :11 31c :b 31d :3 31c
:3 31f 362 2bd fa
:9 362 :d 363 :10 364 :a 365
:8 366 :a 367 :8 368 :6 369
:6 36a :c 36b :a 36c :a 36d
:7 36e :9 36f :a 371 :e 372
:6 373 :8 374 :a 375 :8 376
:6 377 :6 378 :9 379 :7 37a
:a 37b :5 37c :2 37d :3 363
:11 37e :b 37f :3 37e :3 381
382 362 fa :9 382
:5 384 :5 385 388 389
38a 38b 38c 38d
38e 38f 390 391
392 393 396 397
:3 398 :3 399 :3 39a :4 39b
:3 39c :3 39d :3 39e :4 39f
3a0 :4 3a1 :2 3a2 388
:6 3a3 :5 3a4 3a3 :5 3a6
3a5 :3 3a3 387 :2 3a9
:5 3ab :11 3ac :24 3ad :3 3ac
:2 3aa :6 3a9 3a8 :3 382
:5 3b4 :5 3b5 3b8 3ba
3bb 3bc 3bd 3be
3bf 3c0 3c1 3c2
3c3 3c4 3c5 3c6
3c7 3c8 3c9 3ca
3cb 3cc 3cd 3ce
3cf 3d0 3d1 3d2
3d3 3d4 3d5 3d6
3d7 3d8 :8 3db :8 3dc
:8 3dd :6 3de :8 3df :6 3e0
:6 3e1 :8 3e2 :9 3e3 :b 3e4
:3 3e5 3b8 :6 3e6 :5 3e7
3e6 :5 3e9 3e8 :3 3e6
3b7 :2 3ec :5 3ee :11 3ef
:24 3f0 :3 3ef :2 3ed :6 3ec
3eb :3 382 :4 3f7 :c 3f8
3f7 :6 3f9 :5 3fa 3f9
:5 3fc 3fb :3 3f9 3f6
:2 3ff :5 401 :11 402 :24 403
:3 402 :2 400 :6 3ff 3fe
:3 382 :d 408 :11 409 :a 40a
:13 40b :2 40c :8 40d :6 40e
:6 40f :a 410 :b 411 :9 413
:11 414 :9 415 :13 416 :2 417
:8 418 :6 419 :6 41a :a 41b
:b 41c :7 41d :7 41e :3 408
:11 41f :b 420 :3 41f :3 422
423 382 fa :b 423
:6 425 :5 426 424 :2 428
:5 42a :11 42b :24 42c :3 42b
:2 429 :6 428 427 :3 423
:a 431 :c 432 :c 433 :2 434
:7 435 :7 436 :7 437 :3 438
:8 43a :e 43b :6 43c :b 43d
:c 43e :8 440 :e 441 :6 442
:b 443 :c 444 :2 445 :3 432
:11 446 :b 447 :3 446 :3 449
:3 431 44b 423 fa
:9 44b :b 44c :a 44d :9 44e
:5 44f :8 450 :a 451 :4 452
:5 453 :9 454 455 :a 456
:6 457 :a 458 :6 459 :9 45a
:11 45b :a 45c :b 45d :17 45e
:d 45f :8 460 :8 461 :c 462
:f 463 :2 464 :3 465 :2 466
:5 467 :5 468 :c 469 :9 46a
:c 46b :9 46c :9 46d :9 46e
:9 46f :2 470 :3 44c :11 471
:b 472 :3 471 :3 474 475
44b fa :9 475 :7 476
:a 477 :9 478 :d 479 :5 47a
:5 47b :5 47c :5 47d :4 47e
:7 47f :e 480 :4 481 :a 482
483 :3 484 :5 485 :4 486
:6 487 488 :2 489 :9 48a
:c 48b :5 48c :2 48d :3 476
:11 48e :b 48f :3 48e :3 491
492 475 fa :9 492
:5 496 :5 497 :4 49a :3 49b
49c :2 49d 49e :3 49f
:2 4a0 49a :6 4a1 :5 4a2
4a1 :5 4a4 4a3 :3 4a1
499 :2 4a7 :5 4a9 :11 4aa
:24 4ab :3 4aa :2 4a8 :6 4a7
4a6 :3 492 :5 4b1 :5 4b2
:4 4b5 :3 4b6 4b7 :2 4b8
:2 4b9 :2 4ba 4b5 :6 4bb
:5 4bc 4bb :5 4be 4bd
:3 4bb 4b4 :2 4c1 :5 4c3
:11 4c4 :24 4c5 :3 4c4 :2 4c2
:6 4c1 4c0 :3 492 :5 4cb
:5 4cc :4 4cf :6 4d0 :b 4d1
:6 4d3 :b 4d4 4cf :6 4d5
:5 4d6 4d5 :5 4d8 4d7
:3 4d5 4ce :2 4db :5 4dd
:11 4de :24 4df :3 4de :2 4dc
:6 4db 4da :3 492 :d 4e4
:b 4e5 :9 4e6 :a 4ea :b 4eb
:7 4ec :7 4ed :9 4ee :a 4f2
:4 4f3 :3 4f4 :4 4f5 :8 4f6
:2 4f7 :3 4e4 :11 4f8 :b 4f9
:3 4f8 :3 4fb 4fc 492
fa :9 4fc :b 500 :5 501
:4 502 :2 503 :3 504 505
:3 500 :11 506 :b 507 :3 506
:3 509 50a 4fc fa
:d 50a :2 50b :2 50a :6 50b
:3 50a :e 50f :4 510 :3 511
:4 512 513 :3 50f :11 514
:b 515 :3 514 :3 517 50b
fa :11 519 :30 51a :3 519
:a 51c 518 :3 fa 43
:3 521 :11 522 :b 523 :17 524
:3 522 :2 526 :3 527 :3 528
529 527 526 527
:3 52a :3 521 :2 52b :5 52d
:11 52e :b 52f :18 530 :3 52e
:2 532 533 :3 534 535
533 532 533 :3 536
:2 52c :6 52b 520 :7 1

7410
4
:3 0 1 :3 0 2
:a 0 1f26 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
:2 0 7 6 :3 0
5 :7 0 9 8
:3 0 4 :3 0 7
:7 0 d c :3 0
8 :3 0 9 :3 0
a :2 0 4 11
12 0 f 13
0 1f26 2 14
:2 0 e :2 0 f
4 :3 0 c :2 0
d 17 19 :6 0
1c 1a 0 1f24
0 b :6 0 e
:2 0 13 4 :3 0
11 1e 20 :6 0
23 21 0 1f24
0 d :6 0 e
:2 0 17 4 :3 0
15 25 27 :6 0
2a 28 0 1f24
0 f :6 0 12
:2 0 1b 4 :3 0
19 2c 2e :6 0
31 2f 0 1f24
0 10 :6 0 14
:2 0 1f 4 :3 0
1d 33 35 :6 0
38 36 0 1f24
0 11 :6 0 16
:2 0 23 4 :3 0
21 3a 3c :6 0
3f 3d 0 1f24
0 13 :6 0 16
:2 0 25 6 :3 0
41 :7 0 45 42
43 1f24 0 15
:6 0 16 :2 0 27
6 :3 0 47 :7 0
4b 48 49 1f24
0 17 :6 0 16
:2 0 29 6 :3 0
4d :7 0 51 4e
4f 1f24 0 18
:6 0 16 :2 0 2b
6 :3 0 53 :7 0
57 54 55 1f24
0 19 :6 0 16
:2 0 2d 6 :3 0
59 :7 0 5d 5a
5b 1f24 0 1a
:6 0 65 66 0
2f 6 :3 0 5f
:7 0 63 60 61
1f24 0 1b :6 0
6c 6d 0 31
9 :3 0 a :2 0
4 67 :7 0 6a
68 0 1f24 0
1c :6 0 73 74
0 33 9 :3 0
a :2 0 4 6e
:7 0 71 6f 0
1f24 0 1d :6 0
7a 7b 0 35
9 :3 0 a :2 0
4 75 :7 0 78
76 0 1f24 0
1e :6 0 81 82
0 37 9 :3 0
a :2 0 4 7c
:7 0 7f 7d 0
1f24 0 1f :6 0
88 89 0 39
9 :3 0 a :2 0
4 83 :7 0 86
84 0 1f24 0
20 :6 0 8f 90
0 3b 9 :3 0
a :2 0 4 8a
:7 0 8d 8b 0
1f24 0 21 :6 0
96 97 0 3d
9 :3 0 a :2 0
4 91 :7 0 94
92 0 1f24 0
22 :6 0 9d 9e
0 3f 9 :3 0
a :2 0 4 98
:7 0 9b 99 0
1f24 0 23 :6 0
a4 a5 0 41
9 :3 0 a :2 0
4 9f :7 0 a2
a0 0 1f24 0
24 :6 0 ab ac
0 43 9 :3 0
a :2 0 4 a6
:7 0 a9 a7 0
1f24 0 25 :6 0
b2 b3 0 45
9 :3 0 a :2 0
4 ad :7 0 b0
ae 0 1f24 0
26 :6 0 b9 ba
0 47 9 :3 0
a :2 0 4 b4
:7 0 b7 b5 0
1f24 0 27 :6 0
c0 c1 0 49
9 :3 0 a :2 0
4 bb :7 0 be
bc 0 1f24 0
28 :6 0 c7 c8
0 4b 9 :3 0
a :2 0 4 c2
:7 0 c5 c3 0
1f24 0 29 :6 0
ce cf 0 4d
9 :3 0 a :2 0
4 c9 :7 0 cc
ca 0 1f24 0
2a :6 0 d4 d5
0 4f 9 :3 0
a :2 0 4 d0
:7 0 d3 d1 0
1f24 0 2b :6 0
2c :3 0 2d :3 0
2c :3 0 2e :3 0
d7 d8 0 2
:4 0 51 d9 db
d6 dd dc :2 0
2f :3 0 30 :3 0
df e0 0 31
:4 0 2c :3 0 32
:3 0 e3 e4 0
2 :4 0 53 e5
e7 33 :4 0 34
:2 0 35 :3 0 55
ea ec :3 0 36
:4 0 34 :2 0 37
:4 0 58 ef f1
:3 0 34 :2 0 3
:3 0 5b f3 f5
:3 0 34 :2 0 37
:4 0 5e f7 f9
:3 0 34 :2 0 38
:4 0 61 fb fd
:3 0 34 :2 0 39
:3 0 3a :3 0 5
:3 0 64 101 103
3b :4 0 66 100
106 69 ff 108
:3 0 34 :2 0 38
:4 0 6c 10a 10c
:3 0 34 :2 0 37
:4 0 6f 10e 110
:3 0 34 :2 0 7
:3 0 72 112 114
:3 0 34 :2 0 37
:4 0 75 116 118
:3 0 34 :2 0 3c
:4 0 78 11a 11c
:3 0 7b e1 11e
:2 0 120 80 121
de 120 0 122
82 0 1e84 2c
:3 0 2d :3 0 123
124 0 2c :3 0
3d :3 0 126 127
0 14 :2 0 2
:4 0 3e :2 0 3f
:2 0 14 :2 0 84
12c 12e :3 0 87
128 130 125 132
131 :2 0 2f :3 0
40 :3 0 134 135
0 31 :4 0 41
:4 0 34 :2 0 35
:3 0 8b 139 13b
:3 0 8e 136 13d
:2 0 13f 91 140
133 13f 0 141
93 0 1e84 3
:3 0 42 :2 0 95
143 144 :3 0 145
:2 0 2c :3 0 2d
:3 0 147 148 0
2c :3 0 3d :3 0
14a 14b 0 e
:2 0 2 :4 0 43
:2 0 3f :2 0 14
:2 0 97 150 152
:3 0 9a 14c 154
149 156 155 :2 0
2f :3 0 40 :3 0
158 159 0 31
:4 0 44 :4 0 34
:2 0 35 :3 0 9e
15d 15f :3 0 34
:2 0 45 :4 0 a1
161 163 :3 0 34
:2 0 46 :4 0 a4
165 167 :3 0 34
:2 0 39 :3 0 3a
:3 0 47 :3 0 48
:3 0 16c 16d 0
a7 16b 16f 3b
:4 0 a9 16a 172
ac 169 174 :3 0
34 :2 0 49 :4 0
af 176 178 :3 0
34 :2 0 37 :4 0
b2 17a 17c :3 0
34 :2 0 3 :3 0
b5 17e 180 :3 0
34 :2 0 37 :4 0
b8 182 184 :3 0
bb 15a 186 :2 0
188 be 189 157
188 0 18a c0
0 1b4 2c :3 0
2d :3 0 18b 18c
0 2c :3 0 3d
:3 0 18e 18f 0
14 :2 0 2 :4 0
4a :2 0 3f :2 0
14 :2 0 c2 194
196 :3 0 c5 190
198 18d 19a 199
:2 0 2f :3 0 40
:3 0 19c 19d 0
31 :4 0 4b :4 0
34 :2 0 35 :3 0
c9 1a1 1a3 :3 0
cc 19e 1a5 :2 0
1a7 cf 1a8 19b
1a7 0 1a9 d1
0 1b4 4c :3 0
4d :3 0 1aa 1ab
0 47 :3 0 48
:3 0 1ad 1ae 0
3 :3 0 4e :3 0
d3 1ac 1b2 :2 0
1b4 d7 1b5 146
1b4 0 1b6 db
0 1e84 d :3 0
3 :3 0 1b7 1b8
0 1e84 15 :3 0
5 :3 0 1ba 1bb
0 1e84 f :3 0
7 :3 0 1bd 1be
0 1e84 39 :3 0
15 :3 0 16 :2 0
dd 1c0 1c3 4f
:2 0 50 :2 0 e2
1c5 1c7 :3 0 1c8
:2 0 39 :3 0 15
:3 0 16 :2 0 e5
1ca 1cd 4f :2 0
51 :2 0 ea 1cf
1d1 :3 0 1d2 :2 0
1c9 1d4 1d3 :2 0
52 :3 0 53 :3 0
52 :3 0 54 :3 0
39 :3 0 55 :3 0
56 :3 0 52 :3 0
57 :3 0 10 :3 0
18 :3 0 17 :3 0
1b :3 0 58 :3 0
55 :3 0 58 :3 0
52 :3 0 52 :3 0
59 :3 0 d :3 0
55 :3 0 59 :3 0
52 :3 0 53 :4 0
5a 1 :8 0 1f4
9 :3 0 5b :3 0
1ef 1f0 0 5c
:3 0 1f1 1f2 0
1f4 ed 23e 5d
:3 0 9 :3 0 5b
:3 0 1f7 1f8 0
5c :3 0 1f9 1fa
0 234 2c :3 0
2d :3 0 1fc 1fd
0 2c :3 0 3d
:3 0 1ff 200 0
5e :2 0 2 :4 0
5f :2 0 3f :2 0
14 :2 0 f0 205
207 :3 0 f3 201
209 1fe 20b 20a
:2 0 2f :3 0 40
:3 0 20d 20e 0
31 :4 0 60 :4 0
34 :2 0 35 :3 0
f7 212 214 :3 0
34 :2 0 45 :4 0
fa 216 218 :3 0
34 :2 0 61 :4 0
fd 21a 21c :3 0
34 :2 0 5c :3 0
100 21e 220 :3 0
34 :2 0 62 :4 0
103 222 224 :3 0
34 :2 0 63 :3 0
64 :3 0 14 :2 0
65 :2 0 106 227
22b 10a 226 22d
:3 0 10d 20f 22f
:2 0 231 110 232
20c 231 0 233
112 0 234 114
237 :3 0 237 0
237 236 234 235
:6 0 239 2 :3 0
117 23b 119 23a
239 :2 0 23c 11b
:2 0 23e 0 23e
23d 1f4 23c :6 0
392 1 :3 0 9
:3 0 5b :3 0 240
241 0 9 :3 0
4f :2 0 66 :3 0
243 245 0 11f
244 247 :3 0 248
:2 0 52 :3 0 53
:3 0 52 :3 0 54
:3 0 39 :3 0 55
:3 0 56 :3 0 10
:3 0 18 :3 0 17
:3 0 58 :3 0 55
:3 0 67 :3 0 52
:3 0 52 :3 0 59
:3 0 d :3 0 55
:3 0 59 :3 0 52
:3 0 53 :4 0 68
1 :8 0 265 9
:3 0 5b :3 0 260
261 0 5c :3 0
262 263 0 265
122 2af 5d :3 0
9 :3 0 5b :3 0
268 269 0 5c
:3 0 26a 26b 0
2a5 2c :3 0 2d
:3 0 26d 26e 0
2c :3 0 3d :3 0
270 271 0 5e
:2 0 2 :4 0 69
:2 0 3f :2 0 14
:2 0 125 276 278
:3 0 128 272 27a
26f 27c 27b :2 0
2f :3 0 40 :3 0
27e 27f 0 31
:4 0 6a :4 0 34
:2 0 35 :3 0 12c
283 285 :3 0 34
:2 0 45 :4 0 12f
287 289 :3 0 34
:2 0 61 :4 0 132
28b 28d :3 0 34
:2 0 5c :3 0 135
28f 291 :3 0 34
:2 0 62 :4 0 138
293 295 :3 0 34
:2 0 63 :3 0 64
:3 0 14 :2 0 65
:2 0 13b 298 29c
13f 297 29e :3 0
142 280 2a0 :2 0
2a2 145 2a3 27d
2a2 0 2a4 147
0 2a5 149 2a8
:3 0 2a8 0 2a8
2a7 2a5 2a6 :6 0
2aa 4 :3 0 14c
2ac 14e 2ab 2aa
:2 0 2ad 150 :2 0
2af 0 2af 2ae
265 2ad :6 0 38e
1 :3 0 9 :3 0
5b :3 0 2b1 2b2
0 9 :3 0 4f
:2 0 66 :3 0 2b4
2b6 0 154 2b5
2b8 :3 0 2b9 :2 0
17 :3 0 6b :3 0
59 :3 0 d :4 0
6c 1 :8 0 2c5
9 :3 0 5b :3 0
2c0 2c1 0 5c
:3 0 2c2 2c3 0
2c5 157 30f 5d
:3 0 9 :3 0 5b
:3 0 2c8 2c9 0
5c :3 0 2ca 2cb
0 305 2c :3 0
2d :3 0 2cd 2ce
0 2c :3 0 3d
:3 0 2d0 2d1 0
5e :2 0 2 :4 0
6d :2 0 3f :2 0
14 :2 0 15a 2d6
2d8 :3 0 15d 2d2
2da 2cf 2dc 2db
:2 0 2f :3 0 40
:3 0 2de 2df 0
31 :4 0 6e :4 0
34 :2 0 35 :3 0
161 2e3 2e5 :3 0
34 :2 0 45 :4 0
164 2e7 2e9 :3 0
34 :2 0 61 :4 0
167 2eb 2ed :3 0
34 :2 0 5c :3 0
16a 2ef 2f1 :3 0
34 :2 0 62 :4 0
16d 2f3 2f5 :3 0
34 :2 0 63 :3 0
64 :3 0 14 :2 0
65 :2 0 170 2f8
2fc 174 2f7 2fe
:3 0 177 2e0 300
:2 0 302 17a 303
2dd 302 0 304
17c 0 305 17e
308 :3 0 308 0
308 307 305 306
:6 0 30a 6 :3 0
181 30c 183 30b
30a :2 0 30d 185
:2 0 30f 0 30f
30e 2c5 30d :6 0
38b 1 :3 0 9
:3 0 5b :3 0 311
312 0 9 :3 0
4f :2 0 66 :3 0
314 316 0 189
315 318 :3 0 319
:2 0 2c :3 0 2d
:3 0 31b 31c 0
2c :3 0 3d :3 0
31e 31f 0 e
:2 0 2 :4 0 6f
:2 0 3f :2 0 14
:2 0 18c 324 326
:3 0 18f 320 328
31d 32a 329 :2 0
2f :3 0 40 :3 0
32c 32d 0 31
:4 0 70 :4 0 34
:2 0 35 :3 0 193
331 333 :3 0 34
:2 0 45 :4 0 196
335 337 :3 0 34
:2 0 46 :4 0 199
339 33b :3 0 34
:2 0 39 :3 0 3a
:3 0 47 :3 0 48
:3 0 340 341 0
19c 33f 343 3b
:4 0 19e 33e 346
1a1 33d 348 :3 0
34 :2 0 49 :4 0
1a4 34a 34c :3 0
34 :2 0 37 :4 0
1a7 34e 350 :3 0
34 :2 0 d :3 0
1aa 352 354 :3 0
34 :2 0 37 :4 0
1ad 356 358 :3 0
1b0 32e 35a :2 0
35c 1b3 35d 32b
35c 0 35e 1b5
0 388 2c :3 0
2d :3 0 35f 360
0 2c :3 0 3d
:3 0 362 363 0
14 :2 0 2 :4 0
71 :2 0 3f :2 0
14 :2 0 1b7 368
36a :3 0 1ba 364
36c 361 36e 36d
:2 0 2f :3 0 40
:3 0 370 371 0
31 :4 0 72 :4 0
34 :2 0 35 :3 0
1be 375 377 :3 0
1c1 372 379 :2 0
37b 1c4 37c 36f
37b 0 37d 1c6
0 388 4c :3 0
4d :3 0 37e 37f
0 47 :3 0 48
:3 0 381 382 0
d :3 0 4e :3 0
1c8 380 386 :2 0
388 1cc 389 31a
388 0 38a 1d0
0 38b 1d2 38c
2ba 38b 0 38d
1d5 0 38e 1d7
38f 249 38e 0
390 1da 0 392
73 :3 0 1dc 6b4
39 :3 0 15 :3 0
16 :2 0 1df 393
396 4f :2 0 74
:2 0 1e4 398 39a
:3 0 53 :3 0 10
:3 0 75 :3 0 76
:3 0 d :4 0 77
1 :8 0 3a7 9
:3 0 5b :3 0 3a2
3a3 0 5c :3 0
3a4 3a5 0 3a7
1e7 3f1 5d :3 0
9 :3 0 5b :3 0
3aa 3ab 0 5c
:3 0 3ac 3ad 0
3e7 2c :3 0 2d
:3 0 3af 3b0 0
2c :3 0 3d :3 0
3b2 3b3 0 5e
:2 0 2 :4 0 78
:2 0 3f :2 0 14
:2 0 1ea 3b8 3ba
:3 0 1ed 3b4 3bc
3b1 3be 3bd :2 0
2f :3 0 40 :3 0
3c0 3c1 0 31
:4 0 79 :4 0 34
:2 0 35 :3 0 1f1
3c5 3c7 :3 0 34
:2 0 45 :4 0 1f4
3c9 3cb :3 0 34
:2 0 61 :4 0 1f7
3cd 3cf :3 0 34
:2 0 5c :3 0 1fa
3d1 3d3 :3 0 34
:2 0 62 :4 0 1fd
3d5 3d7 :3 0 34
:2 0 63 :3 0 64
:3 0 14 :2 0 65
:2 0 200 3da 3de
204 3d9 3e0 :3 0
207 3c2 3e2 :2 0
3e4 20a 3e5 3bf
3e4 0 3e6 20c
0 3e7 20e 3ea
:3 0 3ea 0 3ea
3e9 3e7 3e8 :6 0
3ec 8 :3 0 211
3ee 213 3ed 3ec
:2 0 3ef 215 :2 0
3f1 0 3f1 3f0
3a7 3ef :6 0 4c8
1 :3 0 9 :3 0
5b :3 0 3f3 3f4
0 9 :3 0 4f
:2 0 66 :3 0 3f6
3f8 0 219 3f7
3fa :3 0 3fb :2 0
2c :3 0 2d :3 0
3fd 3fe 0 2c
:3 0 3d :3 0 400
401 0 e :2 0
2 :4 0 7a :2 0
3f :2 0 14 :2 0
21c 406 408 :3 0
21f 402 40a 3ff
40c 40b :2 0 2f
:3 0 40 :3 0 40e
40f 0 31 :4 0
7b :4 0 34 :2 0
35 :3 0 223 413
415 :3 0 34 :2 0
45 :4 0 226 417
419 :3 0 34 :2 0
46 :4 0 229 41b
41d :3 0 34 :2 0
39 :3 0 3a :3 0
47 :3 0 48 :3 0
422 423 0 22c
421 425 3b :4 0
22e 420 428 231
41f 42a :3 0 34
:2 0 49 :4 0 234
42c 42e :3 0 34
:2 0 37 :4 0 237
430 432 :3 0 34
:2 0 3 :3 0 23a
434 436 :3 0 34
:2 0 37 :4 0 23d
438 43a :3 0 240
410 43c :2 0 43e
243 43f 40d 43e
0 440 245 0
46a 2c :3 0 2d
:3 0 441 442 0
2c :3 0 3d :3 0
444 445 0 14
:2 0 2 :4 0 7c
:2 0 3f :2 0 14
:2 0 247 44a 44c
:3 0 24a 446 44e
443 450 44f :2 0
2f :3 0 40 :3 0
452 453 0 31
:4 0 7d :4 0 34
:2 0 35 :3 0 24e
457 459 :3 0 251
454 45b :2 0 45d
254 45e 451 45d
0 45f 256 0
46a 4c :3 0 4d
:3 0 460 461 0
47 :3 0 48 :3 0
463 464 0 3
:3 0 4e :3 0 258
462 468 :2 0 46a
25c 46b 3fc 46a
0 46c 260 0
4c8 39 :3 0 56
:3 0 57 :3 0 17
:3 0 1b :3 0 58
:3 0 59 :3 0 d
:4 0 7e 1 :8 0
47b 9 :3 0 5b
:3 0 476 477 0
5c :3 0 478 479
0 47b 262 4c5
5d :3 0 9 :3 0
5b :3 0 47e 47f
0 5c :3 0 480
481 0 4bb 2c
:3 0 2d :3 0 483
484 0 2c :3 0
3d :3 0 486 487
0 5e :2 0 2
:4 0 7f :2 0 3f
:2 0 14 :2 0 265
48c 48e :3 0 268
488 490 485 492
491 :2 0 2f :3 0
40 :3 0 494 495
0 31 :4 0 80
:4 0 34 :2 0 35
:3 0 26c 499 49b
:3 0 34 :2 0 45
:4 0 26f 49d 49f
:3 0 34 :2 0 61
:4 0 272 4a1 4a3
:3 0 34 :2 0 5c
:3 0 275 4a5 4a7
:3 0 34 :2 0 62
:4 0 278 4a9 4ab
:3 0 34 :2 0 63
:3 0 64 :3 0 14
:2 0 65 :2 0 27b
4ae 4b2 27f 4ad
4b4 :3 0 282 496
4b6 :2 0 4b8 285
4b9 493 4b8 0
4ba 287 0 4bb
289 4be :3 0 4be
0 4be 4bd 4bb
4bc :6 0 4c0 a
:3 0 28c 4c2 28e
4c1 4c0 :2 0 4c3
290 :2 0 4c5 0
4c5 4c4 47b 4c3
:6 0 4c8 1 :3 0
73 :3 0 292 4c9
39b 4c8 0 6b5
39 :3 0 15 :3 0
16 :2 0 296 4ca
4cd 4f :2 0 81
:2 0 29b 4cf 4d1
:3 0 82 :3 0 b
:3 0 6b :3 0 59
:3 0 d :4 0 83
1 :8 0 4de 9
:3 0 5b :3 0 4d9
4da 0 5c :3 0
4db 4dc 0 4de
29e 528 5d :3 0
9 :3 0 5b :3 0
4e1 4e2 0 5c
:3 0 4e3 4e4 0
51e 2c :3 0 2d
:3 0 4e6 4e7 0
2c :3 0 3d :3 0
4e9 4ea 0 5e
:2 0 2 :4 0 84
:2 0 3f :2 0 14
:2 0 2a1 4ef 4f1
:3 0 2a4 4eb 4f3
4e8 4f5 4f4 :2 0
2f :3 0 40 :3 0
4f7 4f8 0 31
:4 0 85 :4 0 34
:2 0 35 :3 0 2a8
4fc 4fe :3 0 34
:2 0 45 :4 0 2ab
500 502 :3 0 34
:2 0 61 :4 0 2ae
504 506 :3 0 34
:2 0 5c :3 0 2b1
508 50a :3 0 34
:2 0 62 :4 0 2b4
50c 50e :3 0 34
:2 0 63 :3 0 64
:3 0 14 :2 0 65
:2 0 2b7 511 515
2bb 510 517 :3 0
2be 4f9 519 :2 0
51b 2c1 51c 4f6
51b 0 51d 2c3
0 51e 2c5 521
:3 0 521 0 521
520 51e 51f :6 0
523 c :3 0 2c8
525 2ca 524 523
:2 0 526 2cc :2 0
528 0 528 527
4de 526 :6 0 5a8
1 :3 0 9 :3 0
5b :3 0 52a 52b
0 9 :3 0 4f
:2 0 66 :3 0 52d
52f 0 2d0 52e
531 :3 0 532 :2 0
2c :3 0 2d :3 0
534 535 0 2c
:3 0 3d :3 0 537
538 0 e :2 0
2 :4 0 86 :2 0
3f :2 0 14 :2 0
2d3 53d 53f :3 0
2d6 539 541 536
543 542 :2 0 2f
:3 0 40 :3 0 545
546 0 31 :4 0
87 :4 0 34 :2 0
35 :3 0 2da 54a
54c :3 0 34 :2 0
45 :4 0 2dd 54e
550 :3 0 34 :2 0
46 :4 0 2e0 552
554 :3 0 34 :2 0
39 :3 0 3a :3 0
47 :3 0 48 :3 0
559 55a 0 2e3
558 55c 3b :4 0
2e5 557 55f 2e8
556 561 :3 0 34
:2 0 49 :4 0 2eb
563 565 :3 0 34
:2 0 37 :4 0 2ee
567 569 :3 0 34
:2 0 3 :3 0 2f1
56b 56d :3 0 34
:2 0 37 :4 0 2f4
56f 571 :3 0 2f7
547 573 :2 0 575
2fa 576 544 575
0 577 2fc 0
5a1 2c :3 0 2d
:3 0 578 579 0
2c :3 0 3d :3 0
57b 57c 0 14
:2 0 2 :4 0 88
:2 0 3f :2 0 14
:2 0 2fe 581 583
:3 0 301 57d 585
57a 587 586 :2 0
2f :3 0 40 :3 0
589 58a 0 31
:4 0 89 :4 0 34
:2 0 35 :3 0 305
58e 590 :3 0 308
58b 592 :2 0 594
30b 595 588 594
0 596 30d 0
5a1 4c :3 0 4d
:3 0 597 598 0
47 :3 0 48 :3 0
59a 59b 0 3
:3 0 4e :3 0 30f
599 59f :2 0 5a1
313 5a2 533 5a1
0 5a3 317 0
5a8 17 :3 0 8a
:2 0 5a4 5a5 0
5a8 73 :3 0 319
5a9 4d2 5a8 0
6b5 39 :3 0 15
:3 0 16 :2 0 31d
5aa 5ad 47 :3 0
8b :2 0 8c :3 0
5af 5b1 0 322
5b0 5b3 :3 0 5b4
:2 0 39 :3 0 15
:3 0 16 :2 0 325
5b6 5b9 8b :2 0
8d :2 0 32a 5bb
5bd :3 0 5be :2 0
5b5 5c0 5bf :2 0
39 :3 0 15 :3 0
16 :2 0 32d 5c2
5c5 47 :3 0 8b
:2 0 8e :3 0 5c7
5c9 0 332 5c8
5cb :3 0 5cc :2 0
5c1 5ce 5cd :2 0
39 :3 0 15 :3 0
16 :2 0 335 5d0
5d3 47 :3 0 8b
:2 0 8f :3 0 5d5
5d7 0 33a 5d6
5d9 :3 0 5da :2 0
5cf 5dc 5db :2 0
39 :3 0 56 :3 0
57 :3 0 17 :3 0
1b :3 0 58 :3 0
59 :3 0 3 :4 0
90 1 :8 0 5ec
9 :3 0 5b :3 0
5e7 5e8 0 5c
:3 0 5e9 5ea 0
5ec 33d 636 5d
:3 0 9 :3 0 5b
:3 0 5ef 5f0 0
5c :3 0 5f1 5f2
0 62c 2c :3 0
2d :3 0 5f4 5f5
0 2c :3 0 3d
:3 0 5f7 5f8 0
5e :2 0 2 :4 0
91 :2 0 3f :2 0
14 :2 0 340 5fd
5ff :3 0 343 5f9
601 5f6 603 602
:2 0 2f :3 0 40
:3 0 605 606 0
31 :4 0 92 :4 0
34 :2 0 35 :3 0
347 60a 60c :3 0
34 :2 0 45 :4 0
34a 60e 610 :3 0
34 :2 0 61 :4 0
34d 612 614 :3 0
34 :2 0 5c :3 0
350 616 618 :3 0
34 :2 0 62 :4 0
353 61a 61c :3 0
34 :2 0 63 :3 0
64 :3 0 14 :2 0
65 :2 0 356 61f
623 35a 61e 625
:3 0 35d 607 627
:2 0 629 360 62a
604 629 0 62b
362 0 62c 364
62f :3 0 62f 0
62f 62e 62c 62d
:6 0 631 e :3 0
367 633 369 632
631 :2 0 634 36b
:2 0 636 0 636
635 5ec 634 :6 0
6b2 1 :3 0 9
:3 0 5b :3 0 638
639 0 9 :3 0
4f :2 0 66 :3 0
63b 63d 0 36f
63c 63f :3 0 640
:2 0 2c :3 0 2d
:3 0 642 643 0
2c :3 0 3d :3 0
645 646 0 e
:2 0 2 :4 0 93
:2 0 3f :2 0 14
:2 0 372 64b 64d
:3 0 375 647 64f
644 651 650 :2 0
2f :3 0 40 :3 0
653 654 0 31
:4 0 94 :4 0 34
:2 0 35 :3 0 379
658 65a :3 0 34
:2 0 45 :4 0 37c
65c 65e :3 0 34
:2 0 46 :4 0 37f
660 662 :3 0 34
:2 0 39 :3 0 3a
:3 0 47 :3 0 48
:3 0 667 668 0
382 666 66a 3b
:4 0 384 665 66d
387 664 66f :3 0
34 :2 0 49 :4 0
38a 671 673 :3 0
34 :2 0 37 :4 0
38d 675 677 :3 0
34 :2 0 3 :3 0
390 679 67b :3 0
34 :2 0 37 :4 0
393 67d 67f :3 0
396 655 681 :2 0
683 399 684 652
683 0 685 39b
0 6af 2c :3 0
2d :3 0 686 687
0 2c :3 0 3d
:3 0 689 68a 0
14 :2 0 2 :4 0
95 :2 0 3f :2 0
14 :2 0 39d 68f
691 :3 0 3a0 68b
693 688 695 694
:2 0 2f :3 0 40
:3 0 697 698 0
31 :4 0 96 :4 0
34 :2 0 35 :3 0
3a4 69c 69e :3 0
3a7 699 6a0 :2 0
6a2 3aa 6a3 696
6a2 0 6a4 3ac
0 6af 4c :3 0
4d :3 0 6a5 6a6
0 47 :3 0 48
:3 0 6a8 6a9 0
3 :3 0 4e :3 0
3ae 6a7 6ad :2 0
6af 3b2 6b0 641
6af 0 6b1 3b6
0 6b2 3b8 6b3
5dd 6b2 0 6b5
1d5 392 0 6b5
3bb 0 1e84 39
:3 0 15 :3 0 16
:2 0 3c0 6b6 6b9
4f :2 0 16 :2 0
3c5 6bb 6bd :3 0
97 :3 0 98 :3 0
99 :4 0 6c1 :4 0
6c2 :2 0 913 9
:3 0 5b :3 0 6c4
6c5 0 16 :2 0
6c6 6c7 0 913
9a :3 0 9b :3 0
9c :3 0 9d :3 0
9e :3 0 9f :3 0
a0 :3 0 a1 :3 0
55 :3 0 9b :3 0
a2 :3 0 9c :3 0
a2 :3 0 9d :3 0
a2 :3 0 9e :3 0
a2 :3 0 9f :3 0
a2 :3 0 a0 :3 0
a2 :3 0 a1 :3 0
a3 :3 0 55 :3 0
a4 :3 0 a5 :3 0
a2 :3 0 55 :3 0
9b :3 0 a2 :3 0
9b :3 0 53 :3 0
d :3 0 a6 :4 0
a7 1 :8 0 701
a8 :4 0 6ec :3 0
4e :3 0 4f :2 0
3ca 6ef 6f0 :3 0
9 :3 0 5b :3 0
6f2 6f3 0 16
:2 0 6f4 6f5 0
6f7 3cd 6fe 9
:3 0 5b :3 0 6f8
6f9 0 a9 :2 0
6fa 6fb 0 6fd
3cf 6ff 6f1 6f7
0 700 0 6fd
0 700 3d1 0
701 3d4 74b 5d
:3 0 9 :3 0 5b
:3 0 704 705 0
5c :3 0 706 707
0 741 2c :3 0
2d :3 0 709 70a
0 2c :3 0 3d
:3 0 70c 70d 0
5e :2 0 2 :4 0
aa :2 0 3f :2 0
14 :2 0 3d7 712
714 :3 0 3da 70e
716 70b 718 717
:2 0 2f :3 0 40
:3 0 71a 71b 0
31 :4 0 ab :4 0
34 :2 0 35 :3 0
3de 71f 721 :3 0
34 :2 0 45 :4 0
3e1 723 725 :3 0
34 :2 0 61 :4 0
3e4 727 729 :3 0
34 :2 0 5c :3 0
3e7 72b 72d :3 0
34 :2 0 62 :4 0
3ea 72f 731 :3 0
34 :2 0 63 :3 0
64 :3 0 14 :2 0
65 :2 0 3ed 734
738 3f1 733 73a
:3 0 3f4 71c 73c
:2 0 73e 3f7 73f
719 73e 0 740
3f9 0 741 3fb
744 :3 0 744 0
744 743 741 742
:6 0 746 10 :3 0
3fe 748 400 747
746 :2 0 749 402
:2 0 74b 0 74b
74a 701 749 :6 0
913 1 :3 0 97
:3 0 98 :3 0 ac
:4 0 74f :4 0 750
:2 0 913 9 :3 0
5b :3 0 752 753
0 16 :2 0 754
755 0 913 ad
:3 0 ae :3 0 9b
:3 0 a3 :3 0 53
:3 0 d :3 0 a6
:4 0 af 1 :8 0
774 a8 :4 0 75f
:3 0 4e :3 0 4f
:2 0 406 762 763
:3 0 9 :3 0 5b
:3 0 765 766 0
16 :2 0 767 768
0 76a 409 771
9 :3 0 5b :3 0
76b 76c 0 a9
:2 0 76d 76e 0
770 40b 772 764
76a 0 773 0
770 0 773 40d
0 774 410 7be
5d :3 0 9 :3 0
5b :3 0 777 778
0 5c :3 0 779
77a 0 7b4 2c
:3 0 2d :3 0 77c
77d 0 2c :3 0
3d :3 0 77f 780
0 5e :2 0 2
:4 0 b0 :2 0 3f
:2 0 14 :2 0 413
785 787 :3 0 416
781 789 77e 78b
78a :2 0 2f :3 0
40 :3 0 78d 78e
0 31 :4 0 b1
:4 0 34 :2 0 35
:3 0 41a 792 794
:3 0 34 :2 0 45
:4 0 41d 796 798
:3 0 34 :2 0 61
:4 0 420 79a 79c
:3 0 34 :2 0 5c
:3 0 423 79e 7a0
:3 0 34 :2 0 62
:4 0 426 7a2 7a4
:3 0 34 :2 0 63
:3 0 64 :3 0 14
:2 0 65 :2 0 429
7a7 7ab 42d 7a6
7ad :3 0 430 78f
7af :2 0 7b1 433
7b2 78c 7b1 0
7b3 435 0 7b4
437 7b7 :3 0 7b7
0 7b7 7b6 7b4
7b5 :6 0 7b9 12
:3 0 43a 7bb 43c
7ba 7b9 :2 0 7bc
43e :2 0 7be 0
7be 7bd 774 7bc
:6 0 913 1 :3 0
b2 :3 0 1c :3 0
75 :3 0 b3 :3 0
b3 :3 0 53 :3 0
d :3 0 b3 :3 0
9b :3 0 b4 :3 0
9b :3 0 b5 :3 0
b4 :3 0 9b :3 0
b6 :3 0 b7 :3 0
b8 :3 0 b6 :3 0
b9 :3 0 b6 :3 0
ba :3 0 bb :3 0
54 :3 0 bb :3 0
b8 :3 0 bc :3 0
b4 :3 0 9e :3 0
b4 :3 0 9f :3 0
b4 :3 0 a0 :3 0
b4 :3 0 a1 :3 0
bd :3 0 be :3 0
bf :3 0 be :3 0
c0 :3 0 be :3 0
c1 :3 0 be :3 0
c2 :3 0 c3 :3 0
82 :3 0 9a :3 0
b4 :3 0 a4 :3 0
c4 :3 0 b6 :3 0
b4 :3 0 9b :3 0
b6 :3 0 9b :3 0
a4 :3 0 a5 :3 0
c5 :3 0 c5 :3 0
59 :3 0 b4 :3 0
9c :3 0 a4 :3 0
a5 :3 0 bb :3 0
bb :3 0 59 :3 0
c5 :3 0 9c :3 0
c6 :3 0 c7 :3 0
a4 :3 0 c8 :3 0
be :3 0 be :3 0
9d :3 0 b4 :3 0
9d :3 0 b5 :3 0
c9 :3 0 ae :3 0
9b :3 0 b6 :3 0
ca :3 0 b8 :3 0
b9 :3 0 ba :3 0
c5 :3 0 54 :3 0
c5 :3 0 b8 :3 0
bc :3 0 a2 :3 0
9e :3 0 a2 :3 0
9f :3 0 a2 :3 0
a0 :3 0 a2 :3 0
a1 :3 0 bd :3 0
be :3 0 bf :3 0
be :3 0 c0 :3 0
be :3 0 c1 :3 0
be :3 0 c2 :3 0
c3 :3 0 82 :3 0
ad :3 0 c9 :3 0
a4 :3 0 cb :3 0
b6 :3 0 c9 :3 0
ae :3 0 b6 :3 0
ae :3 0 c6 :3 0
c7 :3 0 a4 :3 0
a5 :3 0 a2 :3 0
b6 :3 0 cc :3 0
a2 :3 0 59 :3 0
c6 :3 0 c7 :3 0
a4 :3 0 a5 :3 0
c5 :3 0 c5 :3 0
59 :3 0 a2 :3 0
9c :3 0 c6 :3 0
c7 :3 0 a4 :3 0
c8 :3 0 be :3 0
be :3 0 9d :3 0
a2 :3 0 9d :3 0
b5 :3 0 c9 :3 0
ae :3 0 9b :3 0
b6 :3 0 ca :3 0
b8 :3 0 b9 :3 0
ba :3 0 c5 :3 0
54 :3 0 c5 :3 0
b8 :3 0 bc :3 0
a2 :3 0 9e :3 0
a2 :3 0 9f :3 0
a2 :3 0 a0 :3 0
a2 :3 0 a1 :3 0
bd :3 0 be :3 0
bf :3 0 be :3 0
c0 :3 0 be :3 0
c1 :3 0 be :3 0
c2 :3 0 c3 :3 0
82 :3 0 ad :3 0
c9 :3 0 a4 :3 0
cb :3 0 b6 :3 0
c9 :3 0 ae :3 0
b6 :3 0 ae :3 0
a4 :3 0 cd :3 0
ce :3 0 b6 :3 0
ae :3 0 ce :3 0
cf :3 0 c6 :3 0
c7 :3 0 a4 :3 0
a5 :3 0 a2 :3 0
ce :3 0 d0 :3 0
a2 :3 0 59 :3 0
c6 :3 0 c7 :3 0
a4 :3 0 a5 :3 0
c5 :3 0 c5 :3 0
59 :3 0 a2 :3 0
9c :3 0 c6 :3 0
c7 :3 0 a4 :3 0
c8 :3 0 be :3 0
be :3 0 9d :3 0
a2 :3 0 9d :3 0
b5 :3 0 c9 :3 0
ae :3 0 9b :3 0
b6 :3 0 ca :3 0
b8 :3 0 b9 :3 0
ba :3 0 c5 :3 0
54 :3 0 c5 :3 0
b8 :3 0 bc :3 0
a2 :3 0 9e :3 0
a2 :3 0 9f :3 0
a2 :3 0 a0 :3 0
a2 :3 0 a1 :3 0
bd :3 0 be :3 0
bf :3 0 be :3 0
c0 :3 0 be :3 0
c1 :3 0 be :3 0
c2 :3 0 c3 :3 0
82 :3 0 ad :3 0
c9 :3 0 a4 :3 0
cb :3 0 b6 :3 0
c9 :3 0 ae :3 0
b6 :3 0 ae :3 0
a4 :3 0 d1 :3 0
ce :3 0 b6 :3 0
ae :3 0 ce :3 0
cf :3 0 c6 :3 0
c7 :3 0 a4 :3 0
a5 :3 0 a2 :3 0
ce :3 0 cc :3 0
a2 :3 0 59 :3 0
c6 :3 0 c7 :3 0
a4 :3 0 a5 :3 0
c5 :3 0 c5 :3 0
59 :3 0 a2 :3 0
9c :3 0 c6 :3 0
c7 :3 0 a4 :3 0
c8 :3 0 be :3 0
be :3 0 9d :3 0
a2 :3 0 9d :3 0
b5 :3 0 9b :3 0
54 :4 0 d2 1
:a 0 8ef :2 0 913
7c1 8ed :2 0 2c
:3 0 2d :3 0 8f0
8f1 0 2c :3 0
3d :3 0 8f3 8f4
0 14 :2 0 2
:4 0 d3 :2 0 3f
:2 0 14 :2 0 440
8f9 8fb :3 0 443
8f5 8fd 8f2 8ff
8fe :2 0 2f :3 0
40 :3 0 901 902
0 31 :4 0 d4
:4 0 34 :2 0 35
:3 0 447 906 908
:3 0 44a 903 90a
:2 0 90c 44d 90d
900 90c 0 90e
44f 0 913 8
:3 0 1c :3 0 910
:2 0 913 73 :3 0
451 1e81 39 :3 0
15 :3 0 16 :2 0
45b 914 917 4f
:2 0 14 :2 0 460
919 91b :3 0 91c
:2 0 39 :3 0 15
:3 0 16 :2 0 463
91e 921 4f :2 0
d5 :2 0 468 923
925 :3 0 926 :2 0
91d 928 927 :2 0
97 :3 0 98 :3 0
d6 :4 0 92c :4 0
92d :2 0 ac2 9
:3 0 5b :3 0 92f
930 0 16 :2 0
931 932 0 ac2
d7 :3 0 9b :3 0
54 :3 0 d8 :3 0
9b :3 0 b3 :3 0
76 :3 0 54 :3 0
a3 :3 0 d8 :3 0
c6 :3 0 c7 :3 0
a4 :3 0 75 :3 0
b3 :3 0 b3 :3 0
53 :3 0 d :3 0
d8 :3 0 9b :3 0
b3 :3 0 9b :3 0
d8 :3 0 53 :3 0
d :3 0 d8 :3 0
a6 :3 0 b3 :3 0
d9 :3 0 75 :3 0
da :3 0 d8 :3 0
9b :3 0 da :3 0
9b :3 0 da :3 0
db :3 0 d :4 0
dc 1 :8 0 970
a8 :4 0 95b :3 0
4e :3 0 4f :2 0
46d 95e 95f :3 0
9 :3 0 5b :3 0
961 962 0 16
:2 0 963 964 0
966 470 96d 9
:3 0 5b :3 0 967
968 0 a9 :2 0
969 96a 0 96c
472 96e 960 966
0 96f 0 96c
0 96f 474 0
970 477 9ba 5d
:3 0 9 :3 0 5b
:3 0 973 974 0
5c :3 0 975 976
0 9b0 2c :3 0
2d :3 0 978 979
0 2c :3 0 3d
:3 0 97b 97c 0
5e :2 0 2 :4 0
dd :2 0 3f :2 0
14 :2 0 47a 981
983 :3 0 47d 97d
985 97a 987 986
:2 0 2f :3 0 40
:3 0 989 98a 0
31 :4 0 de :4 0
34 :2 0 35 :3 0
481 98e 990 :3 0
34 :2 0 45 :4 0
484 992 994 :3 0
34 :2 0 61 :4 0
487 996 998 :3 0
34 :2 0 5c :3 0
48a 99a 99c :3 0
34 :2 0 62 :4 0
48d 99e 9a0 :3 0
34 :2 0 63 :3 0
64 :3 0 14 :2 0
65 :2 0 490 9a3
9a7 494 9a2 9a9
:3 0 497 98b 9ab
:2 0 9ad 49a 9ae
988 9ad 0 9af
49c 0 9b0 49e
9b3 :3 0 9b3 0
9b3 9b2 9b0 9b1
:6 0 9b5 14 :3 0
4a1 9b7 4a3 9b6
9b5 :2 0 9b8 4a5
:2 0 9ba 0 9ba
9b9 970 9b8 :6 0
ac2 1 :3 0 9
:3 0 5b :3 0 9bc
9bd 0 df :4 0
9bf 9c0 :3 0 9be
9c1 0 ac2 e0
:3 0 59 :3 0 b8
:3 0 a2 :3 0 ae
:3 0 a2 :3 0 ca
:3 0 a3 :3 0 55
:3 0 a4 :3 0 cb
:3 0 a2 :3 0 55
:3 0 a6 :3 0 a2
:3 0 ae :3 0 55
:3 0 9b :3 0 a4
:3 0 a5 :3 0 c5
:3 0 c5 :3 0 59
:3 0 a2 :3 0 cc
:3 0 a4 :3 0 a5
:3 0 bb :3 0 bb
:3 0 59 :3 0 c5
:3 0 9c :3 0 a4
:3 0 75 :3 0 da
:3 0 da :3 0 cf
:3 0 55 :3 0 cf
:3 0 da :3 0 d9
:3 0 55 :3 0 53
:3 0 d :3 0 55
:3 0 e1 :4 0 e2
1 :8 0 a07 a8
:4 0 9f2 :3 0 4e
:3 0 4f :2 0 4a9
9f5 9f6 :3 0 9
:3 0 5b :3 0 9f8
9f9 0 16 :2 0
9fa 9fb 0 9fd
4ac a04 9 :3 0
5b :3 0 9fe 9ff
0 a9 :2 0 a00
a01 0 a03 4ae
a05 9f7 9fd 0
a06 0 a03 0
a06 4b0 0 a07
4b3 a51 5d :3 0
9 :3 0 5b :3 0
a0a a0b 0 5c
:3 0 a0c a0d 0
a47 2c :3 0 2d
:3 0 a0f a10 0
2c :3 0 3d :3 0
a12 a13 0 5e
:2 0 2 :4 0 e3
:2 0 3f :2 0 14
:2 0 4b6 a18 a1a
:3 0 4b9 a14 a1c
a11 a1e a1d :2 0
2f :3 0 40 :3 0
a20 a21 0 31
:4 0 e4 :4 0 34
:2 0 35 :3 0 4bd
a25 a27 :3 0 34
:2 0 45 :4 0 4c0
a29 a2b :3 0 34
:2 0 61 :4 0 4c3
a2d a2f :3 0 34
:2 0 5c :3 0 4c6
a31 a33 :3 0 34
:2 0 62 :4 0 4c9
a35 a37 :3 0 34
:2 0 63 :3 0 64
:3 0 14 :2 0 65
:2 0 4cc a3a a3e
4d0 a39 a40 :3 0
4d3 a22 a42 :2 0
a44 4d6 a45 a1f
a44 0 a46 4d8
0 a47 4da a4a
:3 0 a4a 0 a4a
a49 a47 a48 :6 0
a4c 16 :3 0 4dd
a4e 4df a4d a4c
:2 0 a4f 4e1 :2 0
a51 0 a51 a50
a07 a4f :6 0 ac2
1 :3 0 b2 :3 0
1d :3 0 55 :3 0
9b :3 0 59 :3 0
cf :3 0 b6 :3 0
b7 :3 0 b8 :3 0
55 :3 0 54 :3 0
b6 :3 0 ba :3 0
e5 :3 0 e6 :3 0
e5 :3 0 e7 :3 0
e8 :3 0 e5 :3 0
e9 :3 0 e5 :3 0
ea :3 0 eb :3 0
ec :3 0 ed :3 0
17 :3 0 56 :3 0
ee :3 0 ef :3 0
f0 :3 0 f1 :3 0
f2 :3 0 f3 :3 0
c3 :3 0 82 :3 0
d7 :3 0 55 :3 0
a4 :3 0 c4 :3 0
b6 :3 0 55 :3 0
9b :3 0 b6 :3 0
9b :3 0 59 :3 0
cf :3 0 b8 :3 0
54 :3 0 ba :3 0
e5 :3 0 e6 :3 0
e5 :3 0 e7 :3 0
e8 :3 0 e5 :3 0
e9 :3 0 e5 :3 0
ea :3 0 eb :3 0
ec :3 0 ed :3 0
17 :3 0 56 :3 0
ee :3 0 ef :3 0
f0 :3 0 f1 :3 0
f2 :3 0 f3 :3 0
c3 :3 0 82 :3 0
e0 :3 0 54 :4 0
f4 1 :a 0 a9e
:2 0 ac2 a54 a9c
:2 0 2c :3 0 2d
:3 0 a9f aa0 0
2c :3 0 3d :3 0
aa2 aa3 0 14
:2 0 2 :4 0 f5
:2 0 3f :2 0 14
:2 0 4e3 aa8 aaa
:3 0 4e6 aa4 aac
aa1 aae aad :2 0
2f :3 0 40 :3 0
ab0 ab1 0 31
:4 0 f6 :4 0 34
:2 0 35 :3 0 4ea
ab5 ab7 :3 0 4ed
ab2 ab9 :2 0 abb
4f0 abc aaf abb
0 abd 4f2 0
ac2 8 :3 0 1d
:3 0 abf :2 0 ac2
73 :3 0 4f4 ac3
929 ac2 0 1e83
39 :3 0 15 :3 0
16 :2 0 4fd ac4
ac7 4f :2 0 50
:2 0 502 ac9 acb
:3 0 b2 :3 0 1e
:3 0 da :3 0 76
:3 0 da :3 0 76
:3 0 55 :3 0 cf
:3 0 59 :3 0 55
:3 0 ae :3 0 b6
:3 0 ca :3 0 b8
:3 0 54 :3 0 55
:3 0 cf :3 0 55
:3 0 f7 :3 0 da
:3 0 e6 :3 0 da
:3 0 e7 :3 0 da
:3 0 f1 :3 0 da
:3 0 f8 :3 0 da
:3 0 f9 :3 0 17
:3 0 56 :3 0 55
:3 0 fa :3 0 55
:3 0 fb :3 0 fc
:3 0 b8 :3 0 fd
:3 0 39 :3 0 55
:3 0 fe :3 0 55
:3 0 fb :3 0 fe
:3 0 ff :3 0 b8
:3 0 100 :3 0 da
:3 0 bf :3 0 da
:3 0 101 :3 0 da
:3 0 c1 :3 0 da
:3 0 102 :3 0 103
:3 0 55 :3 0 104
:3 0 da :3 0 f3
:3 0 da :3 0 d9
:3 0 da :3 0 105
:3 0 106 :3 0 b8
:3 0 107 :3 0 da
:3 0 ed :3 0 da
:3 0 108 :3 0 da
:3 0 109 :3 0 da
:3 0 10a :3 0 da
:3 0 10b :3 0 da
:3 0 10c :3 0 10d
:3 0 da :3 0 10e
:3 0 a3 :3 0 55
:3 0 c6 :3 0 c7
:3 0 a4 :3 0 75
:3 0 da :3 0 da
:3 0 db :3 0 d
:3 0 55 :3 0 cf
:3 0 da :3 0 cf
:3 0 c6 :3 0 c7
:3 0 a4 :3 0 cb
:3 0 b6 :3 0 55
:3 0 9b :3 0 b6
:3 0 ae :3 0 c6
:3 0 c7 :3 0 a4
:3 0 10f :3 0 fc
:3 0 55 :3 0 fb
:3 0 fc :3 0 59
:3 0 c6 :3 0 c7
:3 0 a4 :3 0 10f
:3 0 ff :3 0 39
:3 0 55 :3 0 fe
:3 0 55 :3 0 fb
:3 0 ff :3 0 59
:3 0 c6 :3 0 c7
:3 0 a4 :3 0 110
:3 0 106 :3 0 106
:3 0 59 :3 0 da
:3 0 105 :3 0 55
:3 0 59 :3 0 d
:3 0 55 :3 0 a6
:3 0 b8 :4 0 111
1 :a 0 b5c :2 0
b80 ace b5a :2 0
2c :3 0 2d :3 0
b5d b5e 0 2c
:3 0 3d :3 0 b60
b61 0 14 :2 0
2 :4 0 112 :2 0
3f :2 0 14 :2 0
505 b66 b68 :3 0
508 b62 b6a b5f
b6c b6b :2 0 2f
:3 0 40 :3 0 b6e
b6f 0 31 :4 0
113 :4 0 34 :2 0
35 :3 0 50c b73
b75 :3 0 50f b70
b77 :2 0 b79 512
b7a b6d b79 0
b7b 514 0 b80
8 :3 0 1e :3 0
b7d :2 0 b80 73
:3 0 516 b81 acc
b80 0 1e83 39
:3 0 15 :3 0 16
:2 0 51a b82 b85
4f :2 0 51 :2 0
51f b87 b89 :3 0
114 :3 0 39 :3 0
18 :3 0 16 :2 0
522 b8c b8f 525
b8b b91 8b :2 0
16 :2 0 529 b93
b95 :3 0 19 :3 0
16 :2 0 b97 b98
0 f0e 115 :3 0
19 :3 0 75 :3 0
53 :3 0 10 :3 0
db :3 0 d :4 0
116 1 :8 0 ba7
9 :3 0 5b :3 0
ba2 ba3 0 5c
:3 0 ba4 ba5 0
ba7 52c bf1 5d
:3 0 9 :3 0 5b
:3 0 baa bab 0
5c :3 0 bac bad
0 be7 2c :3 0
2d :3 0 baf bb0
0 2c :3 0 3d
:3 0 bb2 bb3 0
5e :2 0 2 :4 0
117 :2 0 3f :2 0
14 :2 0 52f bb8
bba :3 0 532 bb4
bbc bb1 bbe bbd
:2 0 2f :3 0 40
:3 0 bc0 bc1 0
31 :4 0 118 :4 0
34 :2 0 35 :3 0
536 bc5 bc7 :3 0
34 :2 0 45 :4 0
539 bc9 bcb :3 0
34 :2 0 61 :4 0
53c bcd bcf :3 0
34 :2 0 5c :3 0
53f bd1 bd3 :3 0
34 :2 0 62 :4 0
542 bd5 bd7 :3 0
34 :2 0 63 :3 0
64 :3 0 14 :2 0
65 :2 0 545 bda
bde 549 bd9 be0
:3 0 54c bc2 be2
:2 0 be4 54f be5
bbf be4 0 be6
551 0 be7 553
bea :3 0 bea 0
bea be9 be7 be8
:6 0 bec 18 :3 0
556 bee 558 bed
bec :2 0 bef 55a
:2 0 bf1 0 bf1
bf0 ba7 bef :6 0
f0e 1 :3 0 39
:3 0 19 :3 0 16
:2 0 55c bf3 bf6
4f :2 0 16 :2 0
561 bf8 bfa :3 0
13 :3 0 14 :4 0
bfc bfd 0 bff
564 cef 115 :3 0
19 :3 0 119 :3 0
75 :3 0 53 :3 0
10 :3 0 db :3 0
d :3 0 11a :4 0
11b 1 :8 0 c0f
9 :3 0 5b :3 0
c0a c0b 0 5c
:3 0 c0c c0d 0
c0f 566 c59 5d
:3 0 9 :3 0 5b
:3 0 c12 c13 0
5c :3 0 c14 c15
0 c4f 2c :3 0
2d :3 0 c17 c18
0 2c :3 0 3d
:3 0 c1a c1b 0
5e :2 0 2 :4 0
11c :2 0 3f :2 0
14 :2 0 569 c20
c22 :3 0 56c c1c
c24 c19 c26 c25
:2 0 2f :3 0 40
:3 0 c28 c29 0
31 :4 0 11d :4 0
34 :2 0 35 :3 0
570 c2d c2f :3 0
34 :2 0 45 :4 0
573 c31 c33 :3 0
34 :2 0 61 :4 0
576 c35 c37 :3 0
34 :2 0 5c :3 0
579 c39 c3b :3 0
34 :2 0 62 :4 0
57c c3d c3f :3 0
34 :2 0 63 :3 0
64 :3 0 14 :2 0
65 :2 0 57f c42
c46 583 c41 c48
:3 0 586 c2a c4a
:2 0 c4c 589 c4d
c27 c4c 0 c4e
58b 0 c4f 58d
c52 :3 0 c52 0
c52 c51 c4f c50
:6 0 c54 1a :3 0
590 c56 592 c55
c54 :2 0 c57 594
:2 0 c59 0 c59
c58 c0f c57 :6 0
cee 1 :3 0 39
:3 0 19 :3 0 16
:2 0 596 c5b c5e
4f :2 0 16 :2 0
59b c60 c62 :3 0
115 :3 0 19 :3 0
119 :3 0 75 :3 0
b3 :3 0 a4 :3 0
11e :3 0 11f :3 0
11f :3 0 59 :3 0
b3 :3 0 53 :3 0
11f :3 0 9b :3 0
b3 :3 0 9b :3 0
b3 :3 0 53 :3 0
10 :3 0 b3 :3 0
db :3 0 d :3 0
120 :3 0 63 :3 0
b3 :3 0 121 :3 0
11f :3 0 122 :4 0
123 1 :8 0 c86
9 :3 0 5b :3 0
c81 c82 0 5c
:3 0 c83 c84 0
c86 59e cd0 5d
:3 0 9 :3 0 5b
:3 0 c89 c8a 0
5c :3 0 c8b c8c
0 cc6 2c :3 0
2d :3 0 c8e c8f
0 2c :3 0 3d
:3 0 c91 c92 0
5e :2 0 2 :4 0
124 :2 0 3f :2 0
14 :2 0 5a1 c97
c99 :3 0 5a4 c93
c9b c90 c9d c9c
:2 0 2f :3 0 40
:3 0 c9f ca0 0
31 :4 0 125 :4 0
34 :2 0 35 :3 0
5a8 ca4 ca6 :3 0
34 :2 0 45 :4 0
5ab ca8 caa :3 0
34 :2 0 61 :4 0
5ae cac cae :3 0
34 :2 0 5c :3 0
5b1 cb0 cb2 :3 0
34 :2 0 62 :4 0
5b4 cb4 cb6 :3 0
34 :2 0 63 :3 0
64 :3 0 14 :2 0
65 :2 0 5b7 cb9
cbd 5bb cb8 cbf
:3 0 5be ca1 cc1
:2 0 cc3 5c1 cc4
c9e cc3 0 cc5
5c3 0 cc6 5c5
cc9 :3 0 cc9 0
cc9 cc8 cc6 cc7
:6 0 ccb 1c :3 0
5c8 ccd 5ca ccc
ccb :2 0 cce 5cc
:2 0 cd0 0 cd0
ccf c86 cce :6 0
ce6 1 :3 0 39
:3 0 19 :3 0 16
:2 0 5ce cd2 cd5
4f :2 0 16 :2 0
5d3 cd7 cd9 :3 0
13 :3 0 50 :4 0
cdb cdc 0 cde
5d6 ce3 13 :3 0
14 :4 0 cdf ce0
0 ce2 5d8 ce4
cda cde 0 ce5
0 ce2 0 ce5
5da 0 ce6 5dd
ceb 13 :3 0 14
:4 0 ce7 ce8 0
cea 5e0 cec c63
ce6 0 ced 0
cea 0 ced 5e2
0 cee 5e5 cf0
bfb bff 0 cf1
0 cee 0 cf1
5e8 0 f0e b2
:3 0 1f :3 0 da
:3 0 59 :3 0 55
:3 0 9b :3 0 da
:3 0 b8 :3 0 da
:3 0 54 :3 0 cf
:3 0 55 :3 0 f7
:3 0 da :3 0 f8
:3 0 da :3 0 f9
:3 0 da :3 0 126
:3 0 da :3 0 127
:3 0 da :3 0 f8
:3 0 e6 :3 0 da
:3 0 f9 :3 0 e7
:3 0 da :3 0 128
:3 0 da :3 0 e8
:3 0 f1 :3 0 da
:3 0 128 :3 0 da
:3 0 e8 :3 0 da
:3 0 129 :3 0 ec
:3 0 12a :3 0 da
:3 0 12b :3 0 da
:3 0 129 :3 0 12c
:3 0 12d :3 0 da
:3 0 129 :3 0 12d
:3 0 da :3 0 128
:3 0 da :3 0 e8
:3 0 12e :3 0 e5
:3 0 12f :3 0 e5
:3 0 130 :3 0 131
:3 0 da :3 0 132
:3 0 da :3 0 133
:3 0 da :3 0 134
:3 0 da :3 0 121
:3 0 da :3 0 135
:3 0 da :3 0 129
:3 0 136 :3 0 da
:3 0 137 :3 0 da
:3 0 138 :3 0 da
:3 0 139 :3 0 13a
:3 0 17 :3 0 56
:3 0 fa :3 0 fb
:3 0 fd :3 0 fe
:3 0 100 :3 0 bf
:3 0 101 :3 0 c1
:3 0 102 :3 0 103
:3 0 da :3 0 104
:3 0 f3 :3 0 da
:3 0 13b :3 0 da
:3 0 13c :3 0 da
:3 0 13d :3 0 13e
:3 0 d9 :3 0 105
:3 0 13f :3 0 ed
:3 0 108 :3 0 109
:3 0 10a :3 0 10b
:3 0 10c :3 0 10d
:3 0 140 :3 0 10e
:3 0 13 :3 0 11a
:3 0 141 :3 0 da
:3 0 142 :3 0 da
:3 0 143 :3 0 144
:3 0 1b :3 0 da
:3 0 145 :3 0 e5
:3 0 145 :3 0 1b
:3 0 da :3 0 146
:3 0 e5 :3 0 146
:3 0 1b :3 0 da
:3 0 147 :3 0 148
:3 0 da :3 0 12e
:3 0 149 :3 0 14a
:3 0 14b :3 0 14c
:3 0 14d :3 0 14e
:3 0 14f :3 0 150
:3 0 151 :3 0 152
:3 0 58 :3 0 da
:3 0 c6 :3 0 a4
:3 0 a3 :3 0 55
:3 0 55 :3 0 59
:3 0 da :3 0 59
:3 0 55 :3 0 9b
:3 0 f :3 0 c6
:3 0 c7 :3 0 a4
:3 0 10f :3 0 fc
:3 0 55 :3 0 fb
:3 0 fc :3 0 59
:3 0 da :3 0 53
:3 0 10 :3 0 da
:3 0 59 :3 0 d
:3 0 da :3 0 76
:3 0 da :3 0 76
:3 0 55 :3 0 cf
:3 0 59 :3 0 55
:3 0 9b :3 0 55
:3 0 a6 :3 0 b6
:3 0 ca :3 0 cb
:3 0 b6 :3 0 55
:3 0 9b :3 0 b6
:3 0 ae :3 0 a2
:3 0 b7 :3 0 c4
:3 0 a2 :3 0 55
:3 0 9b :3 0 a2
:3 0 9b :3 0 b8
:3 0 da :3 0 76
:3 0 55 :3 0 a6
:3 0 54 :3 0 55
:3 0 cf :3 0 55
:3 0 f7 :3 0 da
:3 0 f8 :3 0 da
:3 0 153 :3 0 f9
:3 0 da :3 0 126
:3 0 47 :3 0 154
:3 0 da :3 0 126
:3 0 47 :3 0 155
:3 0 47 :3 0 156
:3 0 da :3 0 126
:3 0 126 :3 0 da
:3 0 127 :3 0 47
:3 0 157 :3 0 47
:3 0 158 :3 0 da
:3 0 127 :3 0 127
:3 0 da :3 0 159
:3 0 e6 :3 0 da
:3 0 153 :3 0 e7
:3 0 11a :3 0 15a
:3 0 f1 :3 0 f1
:3 0 11a :3 0 15a
:3 0 129 :3 0 f1
:3 0 ec :3 0 da
:3 0 15b :3 0 da
:3 0 15c :3 0 da
:3 0 15b :3 0 da
:3 0 15c :3 0 12a
:3 0 12b :3 0 da
:3 0 129 :3 0 12c
:3 0 12d :3 0 da
:3 0 129 :3 0 12d
:3 0 f1 :3 0 15a
:3 0 12e :3 0 da
:3 0 12f :3 0 da
:3 0 130 :3 0 da
:3 0 131 :3 0 da
:3 0 132 :3 0 da
:3 0 133 :3 0 da
:3 0 134 :3 0 da
:3 0 121 :3 0 da
:3 0 135 :3 0 da
:3 0 129 :3 0 136
:3 0 137 :3 0 138
:3 0 13a :3 0 17
:3 0 56 :3 0 55
:3 0 fa :3 0 55
:3 0 fb :3 0 fc
:3 0 b8 :3 0 fd
:3 0 39 :3 0 55
:3 0 fe :3 0 55
:3 0 fb :3 0 fe
:3 0 ff :3 0 b8
:3 0 100 :3 0 da
:3 0 bf :3 0 da
:3 0 101 :3 0 da
:3 0 c1 :3 0 da
:3 0 102 :3 0 55
:3 0 a6 :3 0 a2
:3 0 103 :3 0 c4
:3 0 a2 :3 0 55
:3 0 9b :3 0 a2
:3 0 9b :3 0 103
:3 0 55 :3 0 104
:3 0 da :3 0 f3
:3 0 da :3 0 13b
:3 0 da :3 0 13c
:3 0 da :3 0 13e
:3 0 da :3 0 d9
:3 0 da :3 0 105
:3 0 106 :3 0 b8
:3 0 13f :3 0 da
:3 0 ed :3 0 da
:3 0 108 :3 0 da
:3 0 109 :3 0 da
:3 0 10a :3 0 da
:3 0 10b :3 0 da
:3 0 10c :3 0 da
:3 0 10d :3 0 da
:3 0 140 :3 0 da
:3 0 10e :3 0 da
:3 0 11a :3 0 da
:3 0 11a :3 0 11a
:3 0 da :3 0 141
:3 0 142 :3 0 da
:3 0 143 :3 0 144
:3 0 1b :3 0 39
:3 0 da :3 0 145
:3 0 da :3 0 159
:3 0 e5 :3 0 145
:3 0 1b :3 0 39
:3 0 da :3 0 146
:3 0 da :3 0 153
:3 0 e5 :3 0 146
:3 0 1b :3 0 da
:3 0 148 :3 0 da
:3 0 134 :3 0 da
:3 0 148 :3 0 148
:3 0 da :3 0 12b
:3 0 149 :3 0 14a
:3 0 14b :3 0 da
:3 0 14c :3 0 15d
:3 0 b8 :3 0 14d
:3 0 da :3 0 14e
:3 0 15e :3 0 b8
:3 0 14f :3 0 da
:3 0 150 :3 0 da
:3 0 151 :3 0 15f
:3 0 b8 :3 0 152
:3 0 a3 :3 0 55
:3 0 c6 :3 0 c7
:3 0 a4 :3 0 75
:3 0 da :3 0 55
:3 0 cf :3 0 da
:3 0 cf :3 0 c6
:3 0 c7 :3 0 a4
:3 0 10f :3 0 fc
:3 0 55 :3 0 fb
:3 0 fc :3 0 59
:3 0 c6 :3 0 c7
:3 0 a4 :3 0 10f
:3 0 ff :3 0 39
:3 0 55 :3 0 fe
:3 0 55 :3 0 fb
:3 0 ff :3 0 59
:3 0 c6 :3 0 c7
:3 0 a4 :3 0 110
:3 0 106 :3 0 106
:3 0 59 :3 0 da
:3 0 105 :3 0 c6
:3 0 c7 :3 0 a4
:3 0 160 :3 0 15d
:3 0 15d :3 0 59
:3 0 da :3 0 14c
:3 0 c6 :3 0 c7
:3 0 a4 :3 0 160
:3 0 15e :3 0 15e
:3 0 59 :3 0 da
:3 0 14e :3 0 c6
:3 0 c7 :3 0 a4
:3 0 161 :3 0 15f
:3 0 15f :3 0 59
:3 0 da :3 0 151
:3 0 55 :3 0 53
:3 0 10 :3 0 55
:3 0 59 :3 0 d
:3 0 55 :3 0 104
:3 0 14a :3 0 b8
:4 0 162 1 :a 0
eeb :2 0 f0e cf3
ee9 :2 0 2c :3 0
2d :3 0 eec eed
0 2c :3 0 3d
:3 0 eef ef0 0
14 :2 0 2 :4 0
163 :2 0 3f :2 0
14 :2 0 5eb ef5
ef7 :3 0 5ee ef1
ef9 eee efb efa
:2 0 2f :3 0 40
:3 0 efd efe 0
31 :4 0 164 :4 0
34 :2 0 35 :3 0
5f2 f02 f04 :3 0
5f5 eff f06 :2 0
f08 5f8 f09 efc
f08 0 f0a 5fa
0 f0e 8 :3 0
1f :3 0 f0c :2 0
f0e 5fc 1052 b2
:3 0 20 :3 0 da
:3 0 76 :3 0 da
:3 0 76 :3 0 55
:3 0 cf :3 0 59
:3 0 55 :3 0 9b
:3 0 55 :3 0 a6
:3 0 b6 :3 0 ca
:3 0 cb :3 0 b6
:3 0 55 :3 0 9b
:3 0 b6 :3 0 ae
:3 0 a2 :3 0 b7
:3 0 c4 :3 0 a2
:3 0 55 :3 0 9b
:3 0 a2 :3 0 9b
:3 0 b8 :3 0 da
:3 0 76 :3 0 55
:3 0 a6 :3 0 54
:3 0 55 :3 0 cf
:3 0 55 :3 0 f7
:3 0 da :3 0 f8
:3 0 da :3 0 f9
:3 0 da :3 0 126
:3 0 da :3 0 127
:3 0 da :3 0 159
:3 0 e6 :3 0 da
:3 0 153 :3 0 e7
:3 0 165 :3 0 f1
:3 0 11a :3 0 15a
:3 0 f1 :3 0 ec
:3 0 da :3 0 15c
:3 0 12a :3 0 da
:3 0 12b :3 0 12e
:3 0 da :3 0 12f
:3 0 da :3 0 130
:3 0 da :3 0 131
:3 0 da :3 0 132
:3 0 da :3 0 133
:3 0 da :3 0 134
:3 0 da :3 0 121
:3 0 da :3 0 135
:3 0 da :3 0 129
:3 0 136 :3 0 137
:3 0 138 :3 0 13a
:3 0 17 :3 0 56
:3 0 55 :3 0 fa
:3 0 55 :3 0 fb
:3 0 fc :3 0 b8
:3 0 fd :3 0 39
:3 0 55 :3 0 fe
:3 0 55 :3 0 fb
:3 0 fe :3 0 ff
:3 0 b8 :3 0 100
:3 0 da :3 0 bf
:3 0 da :3 0 101
:3 0 da :3 0 c1
:3 0 da :3 0 102
:3 0 55 :3 0 a6
:3 0 a2 :3 0 103
:3 0 c4 :3 0 a2
:3 0 55 :3 0 9b
:3 0 a2 :3 0 9b
:3 0 103 :3 0 55
:3 0 104 :3 0 da
:3 0 f3 :3 0 da
:3 0 13b :3 0 da
:3 0 13c :3 0 da
:3 0 13e :3 0 da
:3 0 d9 :3 0 da
:3 0 105 :3 0 106
:3 0 b8 :3 0 13f
:3 0 da :3 0 ed
:3 0 da :3 0 108
:3 0 da :3 0 109
:3 0 da :3 0 10a
:3 0 da :3 0 10b
:3 0 da :3 0 10c
:3 0 da :3 0 10d
:3 0 da :3 0 140
:3 0 da :3 0 10e
:3 0 da :3 0 11a
:3 0 da :3 0 11a
:3 0 11a :3 0 da
:3 0 141 :3 0 142
:3 0 144 :3 0 da
:3 0 145 :3 0 da
:3 0 146 :3 0 da
:3 0 148 :3 0 da
:3 0 12b :3 0 149
:3 0 14a :3 0 da
:3 0 76 :3 0 da
:3 0 d9 :3 0 da
:3 0 76 :3 0 da
:3 0 145 :3 0 da
:3 0 159 :3 0 da
:3 0 146 :3 0 da
:3 0 153 :3 0 14b
:3 0 da :3 0 14c
:3 0 15d :3 0 b8
:3 0 14d :3 0 da
:3 0 14e :3 0 15e
:3 0 b8 :3 0 14f
:3 0 da :3 0 150
:3 0 da :3 0 151
:3 0 15f :3 0 b8
:3 0 152 :3 0 a3
:3 0 55 :3 0 c6
:3 0 c7 :3 0 a4
:3 0 75 :3 0 da
:3 0 55 :3 0 cf
:3 0 da :3 0 cf
:3 0 c6 :3 0 c7
:3 0 a4 :3 0 10f
:3 0 fc :3 0 55
:3 0 fb :3 0 fc
:3 0 59 :3 0 c6
:3 0 c7 :3 0 a4
:3 0 10f :3 0 ff
:3 0 39 :3 0 55
:3 0 fe :3 0 55
:3 0 fb :3 0 ff
:3 0 59 :3 0 c6
:3 0 c7 :3 0 a4
:3 0 110 :3 0 106
:3 0 106 :3 0 59
:3 0 da :3 0 105
:3 0 c6 :3 0 c7
:3 0 a4 :3 0 160
:3 0 15d :3 0 15d
:3 0 59 :3 0 da
:3 0 14c :3 0 c6
:3 0 c7 :3 0 a4
:3 0 160 :3 0 15e
:3 0 15e :3 0 59
:3 0 da :3 0 14e
:3 0 c6 :3 0 c7
:3 0 a4 :3 0 161
:3 0 15f :3 0 15f
:3 0 59 :3 0 da
:3 0 151 :3 0 55
:3 0 104 :3 0 55
:3 0 59 :3 0 d
:3 0 54 :3 0 b8
:4 0 166 1 :a 0
102e :2 0 1051 f10
102c :2 0 2c :3 0
2d :3 0 102f 1030
0 2c :3 0 3d
:3 0 1032 1033 0
14 :2 0 2 :4 0
167 :2 0 3f :2 0
14 :2 0 603 1038
103a :3 0 606 1034
103c 1031 103e 103d
:2 0 2f :3 0 40
:3 0 1040 1041 0
31 :4 0 168 :4 0
34 :2 0 35 :3 0
60a 1045 1047 :3 0
60d 1042 1049 :2 0
104b 610 104c 103f
104b 0 104d 612
0 1051 8 :3 0
20 :3 0 104f :2 0
1051 614 1053 b96
f0e 0 1054 0
1051 0 1054 618
0 1056 73 :3 0
61b 1057 b8a 1056
0 1e83 39 :3 0
15 :3 0 16 :2 0
61d 1058 105b 4f
:2 0 169 :2 0 622
105d 105f :3 0 97
:3 0 98 :3 0 16a
:4 0 1063 :4 0 1064
:2 0 1204 9 :3 0
5b :3 0 1066 1067
0 16 :2 0 1068
1069 0 1204 16b
:3 0 9b :3 0 a6
:3 0 e6 :3 0 e7
:3 0 e8 :3 0 e9
:3 0 ea :3 0 eb
:3 0 ec :3 0 9b
:3 0 a6 :3 0 16c
:3 0 e6 :3 0 e6
:3 0 16d :3 0 e7
:3 0 e7 :3 0 16e
:3 0 f1 :3 0 e8
:3 0 16c :3 0 16f
:3 0 e9 :3 0 16d
:3 0 170 :3 0 ea
:3 0 16e :3 0 15a
:3 0 eb :3 0 16e
:3 0 134 :3 0 ec
:3 0 75 :3 0 53
:3 0 d :3 0 d9
:3 0 9b :3 0 a6
:4 0 171 1 :8 0
10a8 a8 :4 0 1093
:3 0 4e :3 0 4f
:2 0 627 1096 1097
:3 0 9 :3 0 5b
:3 0 1099 109a 0
16 :2 0 109b 109c
0 109e 62a 10a5
9 :3 0 5b :3 0
109f 10a0 0 a9
:2 0 10a1 10a2 0
10a4 62c 10a6 1098
109e 0 10a7 0
10a4 0 10a7 62e
0 10a8 631 10f2
5d :3 0 9 :3 0
5b :3 0 10ab 10ac
0 5c :3 0 10ad
10ae 0 10e8 2c
:3 0 2d :3 0 10b0
10b1 0 2c :3 0
3d :3 0 10b3 10b4
0 5e :2 0 2
:4 0 172 :2 0 3f
:2 0 14 :2 0 634
10b9 10bb :3 0 637
10b5 10bd 10b2 10bf
10be :2 0 2f :3 0
40 :3 0 10c1 10c2
0 31 :4 0 173
:4 0 34 :2 0 35
:3 0 63b 10c6 10c8
:3 0 34 :2 0 45
:4 0 63e 10ca 10cc
:3 0 34 :2 0 61
:4 0 641 10ce 10d0
:3 0 34 :2 0 5c
:3 0 644 10d2 10d4
:3 0 34 :2 0 62
:4 0 647 10d6 10d8
:3 0 34 :2 0 63
:3 0 64 :3 0 14
:2 0 65 :2 0 64a
10db 10df 64e 10da
10e1 :3 0 651 10c3
10e3 :2 0 10e5 654
10e6 10c0 10e5 0
10e7 656 0 10e8
658 10eb :3 0 10eb
0 10eb 10ea 10e8
10e9 :6 0 10ed 1e
:3 0 65b 10ef 65d
10ee 10ed :2 0 10f0
65f :2 0 10f2 0
10f2 10f1 10a8 10f0
:6 0 1204 1 :3 0
9 :3 0 5b :3 0
10f4 10f5 0 df
:4 0 10f7 10f8 :3 0
10f6 10f9 0 1204
e0 :3 0 59 :3 0
b8 :3 0 e6 :3 0
e7 :3 0 e8 :3 0
e9 :3 0 ea :3 0
eb :3 0 ec :3 0
a2 :3 0 ae :3 0
a2 :3 0 ca :3 0
55 :3 0 e6 :3 0
55 :3 0 e7 :3 0
55 :3 0 e8 :3 0
55 :3 0 e9 :3 0
55 :3 0 ea :3 0
55 :3 0 eb :3 0
55 :3 0 ec :3 0
16b :3 0 55 :3 0
a4 :3 0 cb :3 0
a2 :3 0 55 :3 0
a6 :3 0 a2 :3 0
ae :3 0 55 :3 0
9b :3 0 a4 :3 0
a5 :3 0 c5 :3 0
c5 :3 0 59 :3 0
a2 :3 0 cc :3 0
a4 :3 0 a5 :3 0
bb :3 0 bb :3 0
59 :3 0 c5 :3 0
9c :4 0 174 1
:8 0 1146 a8 :4 0
1131 :3 0 4e :3 0
4f :2 0 663 1134
1135 :3 0 9 :3 0
5b :3 0 1137 1138
0 16 :2 0 1139
113a 0 113c 666
1143 9 :3 0 5b
:3 0 113d 113e 0
a9 :2 0 113f 1140
0 1142 668 1144
1136 113c 0 1145
0 1142 0 1145
66a 0 1146 66d
1190 5d :3 0 9
:3 0 5b :3 0 1149
114a 0 5c :3 0
114b 114c 0 1186
2c :3 0 2d :3 0
114e 114f 0 2c
:3 0 3d :3 0 1151
1152 0 5e :2 0
2 :4 0 175 :2 0
3f :2 0 14 :2 0
670 1157 1159 :3 0
673 1153 115b 1150
115d 115c :2 0 2f
:3 0 40 :3 0 115f
1160 0 31 :4 0
176 :4 0 34 :2 0
35 :3 0 677 1164
1166 :3 0 34 :2 0
45 :4 0 67a 1168
116a :3 0 34 :2 0
61 :4 0 67d 116c
116e :3 0 34 :2 0
5c :3 0 680 1170
1172 :3 0 34 :2 0
62 :4 0 683 1174
1176 :3 0 34 :2 0
63 :3 0 64 :3 0
14 :2 0 65 :2 0
686 1179 117d 68a
1178 117f :3 0 68d
1161 1181 :2 0 1183
690 1184 115e 1183
0 1185 692 0
1186 694 1189 :3 0
1189 0 1189 1188
1186 1187 :6 0 118b
20 :3 0 697 118d
699 118c 118b :2 0
118e 69b :2 0 1190
0 1190 118f 1146
118e :6 0 1204 1
:3 0 b2 :3 0 21
:3 0 55 :3 0 9b
:3 0 59 :3 0 cf
:3 0 b6 :3 0 b7
:3 0 b8 :3 0 54
:3 0 b6 :3 0 ba
:3 0 55 :3 0 e6
:3 0 55 :3 0 e7
:3 0 55 :3 0 e8
:3 0 55 :3 0 e9
:3 0 55 :3 0 ea
:3 0 55 :3 0 eb
:3 0 55 :3 0 ec
:3 0 ed :3 0 17
:3 0 56 :3 0 ee
:3 0 ef :3 0 f0
:3 0 f1 :3 0 f2
:3 0 f3 :3 0 b6
:3 0 103 :3 0 c3
:3 0 82 :3 0 16b
:3 0 55 :3 0 a4
:3 0 c4 :3 0 b6
:3 0 55 :3 0 a6
:3 0 55 :3 0 9b
:3 0 b6 :3 0 9b
:3 0 59 :3 0 cf
:3 0 b8 :3 0 54
:3 0 ba :3 0 e6
:3 0 e7 :3 0 e8
:3 0 e9 :3 0 ea
:3 0 eb :3 0 ec
:3 0 ed :3 0 17
:3 0 56 :3 0 ee
:3 0 ef :3 0 f0
:3 0 f1 :3 0 f2
:3 0 f3 :3 0 103
:3 0 c3 :3 0 82
:3 0 e0 :3 0 54
:4 0 177 1 :a 0
11e0 :2 0 1204 1193
11de :2 0 2c :3 0
2d :3 0 11e1 11e2
0 2c :3 0 3d
:3 0 11e4 11e5 0
14 :2 0 2 :4 0
178 :2 0 3f :2 0
14 :2 0 69d 11ea
11ec :3 0 6a0 11e6
11ee 11e3 11f0 11ef
:2 0 2f :3 0 40
:3 0 11f2 11f3 0
31 :4 0 179 :4 0
34 :2 0 35 :3 0
6a4 11f7 11f9 :3 0
6a7 11f4 11fb :2 0
11fd 6aa 11fe 11f1
11fd 0 11ff 6ac
0 1204 8 :3 0
21 :3 0 1201 :2 0
1204 73 :3 0 6ae
1205 1060 1204 0
1e83 39 :3 0 15
:3 0 16 :2 0 6b7
1206 1209 4f :2 0
17a :2 0 6bc 120b
120d :3 0 97 :3 0
98 :3 0 16a :4 0
1211 :4 0 1212 :2 0
13fd 9 :3 0 5b
:3 0 1214 1215 0
16 :2 0 1216 1217
0 13fd 16b :3 0
9b :3 0 a6 :3 0
e6 :3 0 e7 :3 0
e8 :3 0 e9 :3 0
ea :3 0 eb :3 0
ec :3 0 9b :3 0
a6 :3 0 16c :3 0
e6 :3 0 e6 :3 0
16d :3 0 e7 :3 0
e7 :3 0 16e :3 0
f1 :3 0 e8 :3 0
16c :3 0 16f :3 0
e9 :3 0 16d :3 0
170 :3 0 ea :3 0
16e :3 0 15a :3 0
eb :3 0 16e :3 0
134 :3 0 ec :3 0
75 :3 0 53 :3 0
d :3 0 d9 :3 0
9b :3 0 a6 :4 0
171 1 :8 0 1256
a8 :4 0 1241 :3 0
4e :3 0 4f :2 0
6c1 1244 1245 :3 0
9 :3 0 5b :3 0
1247 1248 0 16
:2 0 1249 124a 0
124c 6c4 1253 9
:3 0 5b :3 0 124d
124e 0 a9 :2 0
124f 1250 0 1252
6c6 1254 1246 124c
0 1255 0 1252
0 1255 6c8 0
1256 6cb 12a0 5d
:3 0 9 :3 0 5b
:3 0 1259 125a 0
5c :3 0 125b 125c
0 1296 2c :3 0
2d :3 0 125e 125f
0 2c :3 0 3d
:3 0 1261 1262 0
5e :2 0 2 :4 0
17b :2 0 3f :2 0
14 :2 0 6ce 1267
1269 :3 0 6d1 1263
126b 1260 126d 126c
:2 0 2f :3 0 40
:3 0 126f 1270 0
31 :4 0 17c :4 0
34 :2 0 35 :3 0
6d5 1274 1276 :3 0
34 :2 0 45 :4 0
6d8 1278 127a :3 0
34 :2 0 61 :4 0
6db 127c 127e :3 0
34 :2 0 5c :3 0
6de 1280 1282 :3 0
34 :2 0 62 :4 0
6e1 1284 1286 :3 0
34 :2 0 63 :3 0
64 :3 0 14 :2 0
65 :2 0 6e4 1289
128d 6e8 1288 128f
:3 0 6eb 1271 1291
:2 0 1293 6ee 1294
126e 1293 0 1295
6f0 0 1296 6f2
1299 :3 0 1299 0
1299 1298 1296 1297
:6 0 129b 22 :3 0
6f5 129d 6f7 129c
129b :2 0 129e 6f9
:2 0 12a0 0 12a0
129f 1256 129e :6 0
13fd 1 :3 0 9
:3 0 5b :3 0 12a2
12a3 0 df :4 0
12a5 12a6 :3 0 12a4
12a7 0 13fd e0
:3 0 59 :3 0 b8
:3 0 a6 :3 0 54
:3 0 ba :3 0 e6
:3 0 e7 :3 0 e8
:3 0 e9 :3 0 ea
:3 0 eb :3 0 ec
:3 0 103 :3 0 a2
:3 0 ae :3 0 a2
:3 0 ca :3 0 55
:3 0 e6 :3 0 55
:3 0 e7 :3 0 55
:3 0 e8 :3 0 55
:3 0 e9 :3 0 55
:3 0 ea :3 0 55
:3 0 eb :3 0 55
:3 0 ec :3 0 16b
:3 0 55 :3 0 a4
:3 0 cb :3 0 a2
:3 0 55 :3 0 a6
:3 0 a2 :3 0 ae
:3 0 55 :3 0 9b
:3 0 a4 :3 0 a5
:3 0 c5 :3 0 c5
:3 0 59 :3 0 a2
:3 0 cc :3 0 a4
:3 0 a5 :3 0 bb
:3 0 bb :3 0 59
:3 0 c5 :3 0 9c
:3 0 d8 :3 0 9b
:3 0 b6 :3 0 b7
:3 0 b6 :3 0 ba
:3 0 e5 :3 0 e5
:3 0 e5 :3 0 e5
:3 0 b6 :3 0 103
:3 0 a3 :3 0 d8
:3 0 c4 :3 0 b6
:3 0 d8 :3 0 53
:3 0 d :3 0 d8
:3 0 9b :3 0 b6
:3 0 9b :3 0 b3
:3 0 76 :3 0 75
:3 0 b3 :3 0 b3
:3 0 cf :3 0 55
:3 0 cf :3 0 a3
:3 0 55 :3 0 55
:3 0 53 :3 0 d8
:3 0 53 :3 0 55
:3 0 9b :3 0 d8
:3 0 9b :4 0 17d
1 :8 0 1321 a8
:4 0 130c :3 0 4e
:3 0 4f :2 0 6fd
130f 1310 :3 0 9
:3 0 5b :3 0 1312
1313 0 16 :2 0
1314 1315 0 1317
700 131e 9 :3 0
5b :3 0 1318 1319
0 a9 :2 0 131a
131b 0 131d 702
131f 1311 1317 0
1320 0 131d 0
1320 704 0 1321
707 136b 5d :3 0
9 :3 0 5b :3 0
1324 1325 0 5c
:3 0 1326 1327 0
1361 2c :3 0 2d
:3 0 1329 132a 0
2c :3 0 3d :3 0
132c 132d 0 5e
:2 0 2 :4 0 17e
:2 0 3f :2 0 14
:2 0 70a 1332 1334
:3 0 70d 132e 1336
132b 1338 1337 :2 0
2f :3 0 40 :3 0
133a 133b 0 31
:4 0 17f :4 0 34
:2 0 35 :3 0 711
133f 1341 :3 0 34
:2 0 45 :4 0 714
1343 1345 :3 0 34
:2 0 61 :4 0 717
1347 1349 :3 0 34
:2 0 5c :3 0 71a
134b 134d :3 0 34
:2 0 62 :4 0 71d
134f 1351 :3 0 34
:2 0 63 :3 0 64
:3 0 14 :2 0 65
:2 0 720 1354 1358
724 1353 135a :3 0
727 133c 135c :2 0
135e 72a 135f 1339
135e 0 1360 72c
0 1361 72e 1364
:3 0 1364 0 1364
1363 1361 1362 :6 0
1366 24 :3 0 731
1368 733 1367 1366
:2 0 1369 735 :2 0
136b 0 136b 136a
1321 1369 :6 0 13fd
1 :3 0 b2 :3 0
22 :3 0 55 :3 0
9b :3 0 59 :3 0
cf :3 0 b6 :3 0
b7 :3 0 b8 :3 0
54 :3 0 b6 :3 0
ba :3 0 55 :3 0
e6 :3 0 55 :3 0
e7 :3 0 55 :3 0
e8 :3 0 55 :3 0
e9 :3 0 55 :3 0
ea :3 0 55 :3 0
eb :3 0 55 :3 0
ec :3 0 ed :3 0
17 :3 0 56 :3 0
ee :3 0 ef :3 0
f0 :3 0 f1 :3 0
f2 :3 0 f3 :3 0
b6 :3 0 103 :3 0
c3 :3 0 82 :3 0
16b :3 0 55 :3 0
a4 :3 0 c4 :3 0
b6 :3 0 55 :3 0
a6 :3 0 55 :3 0
9b :3 0 b6 :3 0
9b :3 0 59 :3 0
cf :3 0 b8 :3 0
54 :3 0 ba :3 0
e6 :3 0 e7 :3 0
e8 :3 0 e9 :3 0
ea :3 0 eb :3 0
ec :3 0 ed :3 0
17 :3 0 56 :3 0
ee :3 0 ef :3 0
f0 :3 0 f1 :3 0
f2 :3 0 f3 :3 0
103 :3 0 c3 :3 0
82 :3 0 e0 :3 0
a6 :3 0 54 :3 0
59 :3 0 cf :3 0
b8 :3 0 54 :3 0
ba :3 0 e6 :3 0
e7 :3 0 e8 :3 0
e9 :3 0 ea :3 0
eb :3 0 ec :3 0
ed :3 0 17 :3 0
56 :3 0 ee :3 0
ef :3 0 f0 :3 0
f1 :3 0 f2 :3 0
f3 :3 0 103 :3 0
c3 :3 0 82 :3 0
e0 :3 0 a6 :3 0
54 :3 0 54 :3 0
b8 :4 0 180 1
:a 0 13d9 :2 0 13fd
136e 13d7 :2 0 2c
:3 0 2d :3 0 13da
13db 0 2c :3 0
3d :3 0 13dd 13de
0 14 :2 0 2
:4 0 181 :2 0 3f
:2 0 14 :2 0 737
13e3 13e5 :3 0 73a
13df 13e7 13dc 13e9
13e8 :2 0 2f :3 0
40 :3 0 13eb 13ec
0 31 :4 0 182
:4 0 34 :2 0 35
:3 0 73e 13f0 13f2
:3 0 741 13ed 13f4
:2 0 13f6 744 13f7
13ea 13f6 0 13f8
746 0 13fd 8
:3 0 22 :3 0 13fa
:2 0 13fd 73 :3 0
748 13fe 120e 13fd
0 1e83 39 :3 0
15 :3 0 16 :2 0
751 13ff 1402 4f
:2 0 183 :2 0 756
1404 1406 :3 0 b2
:3 0 23 :3 0 da
:3 0 9b :3 0 59
:3 0 da :3 0 cf
:3 0 b6 :3 0 b7
:3 0 b8 :3 0 54
:3 0 b6 :3 0 ba
:3 0 52 :3 0 e6
:3 0 52 :3 0 e7
:3 0 52 :3 0 165
:3 0 e8 :3 0 52
:3 0 f1 :3 0 184
:3 0 55 :3 0 12f
:3 0 e9 :3 0 55
:3 0 130 :3 0 ea
:3 0 55 :3 0 165
:3 0 eb :3 0 55
:3 0 15a :3 0 ec
:3 0 17 :3 0 56
:3 0 ee :3 0 ef
:3 0 f0 :3 0 f1
:3 0 f2 :3 0 f3
:3 0 b6 :3 0 103
:3 0 c3 :3 0 82
:3 0 185 :3 0 bf
:3 0 185 :3 0 101
:3 0 185 :3 0 c1
:3 0 185 :3 0 102
:3 0 185 :3 0 186
:3 0 185 :3 0 187
:3 0 185 :3 0 188
:3 0 185 :3 0 189
:3 0 185 :3 0 18a
:3 0 185 :3 0 18b
:3 0 185 :3 0 18c
:3 0 185 :3 0 18d
:3 0 185 :3 0 18e
:3 0 185 :3 0 18f
:3 0 185 :3 0 190
:3 0 a3 :3 0 da
:3 0 a4 :3 0 191
:3 0 185 :3 0 185
:3 0 53 :3 0 d
:3 0 185 :3 0 9b
:3 0 da :3 0 9b
:3 0 c6 :3 0 a4
:3 0 75 :3 0 55
:3 0 55 :3 0 cf
:3 0 da :3 0 cf
:3 0 55 :3 0 11a
:3 0 c6 :3 0 a4
:3 0 75 :3 0 52
:3 0 52 :3 0 cf
:3 0 da :3 0 cf
:3 0 52 :3 0 11a
:3 0 a4 :3 0 c4
:3 0 b6 :3 0 da
:3 0 9b :3 0 b6
:3 0 9b :3 0 da
:3 0 59 :3 0 d
:3 0 da :3 0 a6
:3 0 55 :3 0 76
:3 0 52 :3 0 76
:3 0 da :3 0 9b
:3 0 59 :3 0 55
:3 0 cf :3 0 b6
:3 0 ca :3 0 b8
:3 0 54 :3 0 ba
:3 0 da :3 0 e6
:3 0 da :3 0 e7
:3 0 da :3 0 165
:3 0 e8 :3 0 da
:3 0 f1 :3 0 184
:3 0 e5 :3 0 e9
:3 0 e5 :3 0 ea
:3 0 eb :3 0 ec
:3 0 17 :3 0 56
:3 0 ee :3 0 ef
:3 0 f0 :3 0 f1
:3 0 f2 :3 0 da
:3 0 f3 :3 0 103
:3 0 c3 :3 0 82
:3 0 185 :3 0 bf
:3 0 185 :3 0 101
:3 0 185 :3 0 c1
:3 0 185 :3 0 102
:3 0 185 :3 0 186
:3 0 185 :3 0 187
:3 0 185 :3 0 188
:3 0 185 :3 0 189
:3 0 185 :3 0 18a
:3 0 185 :3 0 18b
:3 0 185 :3 0 18c
:3 0 185 :3 0 18d
:3 0 185 :3 0 18e
:3 0 185 :3 0 18f
:3 0 185 :3 0 190
:3 0 a3 :3 0 55
:3 0 a4 :3 0 cb
:3 0 b6 :3 0 55
:3 0 9b :3 0 b6
:3 0 ae :3 0 a4
:3 0 75 :3 0 da
:3 0 da :3 0 cf
:3 0 55 :3 0 cf
:3 0 a4 :3 0 191
:3 0 185 :3 0 185
:3 0 53 :3 0 d
:3 0 185 :3 0 9b
:3 0 55 :3 0 9b
:3 0 55 :3 0 59
:3 0 d :3 0 55
:3 0 a6 :3 0 54
:3 0 b8 :4 0 192
1 :a 0 14ec :2 0
1510 1409 14ea :2 0
2c :3 0 2d :3 0
14ed 14ee 0 2c
:3 0 3d :3 0 14f0
14f1 0 14 :2 0
2 :4 0 193 :2 0
3f :2 0 14 :2 0
759 14f6 14f8 :3 0
75c 14f2 14fa 14ef
14fc 14fb :2 0 2f
:3 0 40 :3 0 14fe
14ff 0 31 :4 0
194 :4 0 34 :2 0
35 :3 0 760 1503
1505 :3 0 763 1500
1507 :2 0 1509 766
150a 14fd 1509 0
150b 768 0 1510
8 :3 0 23 :3 0
150d :2 0 1510 73
:3 0 76a 1511 1407
1510 0 1e83 39
:3 0 15 :3 0 16
:2 0 76e 1512 1515
4f :2 0 195 :2 0
773 1517 1519 :3 0
97 :3 0 98 :3 0
196 :4 0 151d :4 0
151e :2 0 1800 9
:3 0 5b :3 0 1520
1521 0 16 :2 0
1522 1523 0 1800
197 :3 0 9b :3 0
a6 :3 0 198 :3 0
199 :3 0 184 :3 0
e8 :3 0 19a :3 0
19b :3 0 19c :3 0
eb :3 0 54 :3 0
9b :3 0 a6 :3 0
16c :3 0 e6 :3 0
198 :3 0 16d :3 0
e7 :3 0 199 :3 0
16e :3 0 f1 :3 0
184 :3 0 16e :3 0
11a :3 0 165 :3 0
e8 :3 0 16c :3 0
16f :3 0 19a :3 0
16d :3 0 170 :3 0
19b :3 0 16e :3 0
15a :3 0 19c :3 0
16e :3 0 11a :3 0
165 :3 0 eb :3 0
75 :3 0 53 :3 0
d :3 0 db :3 0
d :3 0 9b :3 0
a6 :4 0 19d 1
:8 0 156a a8 :4 0
1555 :3 0 4e :3 0
4f :2 0 778 1558
1559 :3 0 9 :3 0
5b :3 0 155b 155c
0 16 :2 0 155d
155e 0 1560 77b
1567 9 :3 0 5b
:3 0 1561 1562 0
a9 :2 0 1563 1564
0 1566 77d 1568
155a 1560 0 1569
0 1566 0 1569
77f 0 156a 782
15b4 5d :3 0 9
:3 0 5b :3 0 156d
156e 0 5c :3 0
156f 1570 0 15aa
2c :3 0 2d :3 0
1572 1573 0 2c
:3 0 3d :3 0 1575
1576 0 5e :2 0
2 :4 0 19e :2 0
3f :2 0 14 :2 0
785 157b 157d :3 0
788 1577 157f 1574
1581 1580 :2 0 2f
:3 0 40 :3 0 1583
1584 0 31 :4 0
19f :4 0 34 :2 0
35 :3 0 78c 1588
158a :3 0 34 :2 0
45 :4 0 78f 158c
158e :3 0 34 :2 0
61 :4 0 792 1590
1592 :3 0 34 :2 0
5c :3 0 795 1594
1596 :3 0 34 :2 0
62 :4 0 798 1598
159a :3 0 34 :2 0
63 :3 0 64 :3 0
14 :2 0 65 :2 0
79b 159d 15a1 79f
159c 15a3 :3 0 7a2
1585 15a5 :2 0 15a7
7a5 15a8 1582 15a7
0 15a9 7a7 0
15aa 7a9 15ad :3 0
15ad 0 15ad 15ac
15aa 15ab :6 0 15af
26 :3 0 7ac 15b1
7ae 15b0 15af :2 0
15b2 7b0 :2 0 15b4
0 15b4 15b3 156a
15b2 :6 0 1800 1
:3 0 97 :3 0 98
:3 0 1a0 :4 0 15b8
:4 0 15b9 :2 0 1800
9 :3 0 5b :3 0
15bb 15bc 0 16
:2 0 15bd 15be 0
1800 1a1 :3 0 9b
:3 0 a6 :3 0 e6
:3 0 e7 :3 0 e8
:3 0 e9 :3 0 ea
:3 0 eb :3 0 ec
:3 0 198 :3 0 199
:3 0 184 :3 0 19a
:3 0 19b :3 0 19c
:3 0 187 :3 0 188
:3 0 189 :3 0 18a
:3 0 18b :3 0 18c
:3 0 18d :3 0 18e
:3 0 18f :3 0 190
:3 0 bf :3 0 101
:3 0 c1 :3 0 102
:3 0 54 :3 0 186
:3 0 55 :3 0 9b
:3 0 55 :3 0 a6
:3 0 55 :3 0 e6
:3 0 55 :3 0 e7
:3 0 55 :3 0 f1
:3 0 55 :3 0 16f
:3 0 55 :3 0 170
:3 0 55 :3 0 15a
:3 0 55 :3 0 134
:3 0 52 :3 0 198
:3 0 52 :3 0 199
:3 0 52 :3 0 184
:3 0 52 :3 0 19a
:3 0 52 :3 0 19b
:3 0 52 :3 0 19c
:3 0 55 :3 0 187
:3 0 55 :3 0 188
:3 0 55 :3 0 189
:3 0 55 :3 0 18a
:3 0 55 :3 0 18b
:3 0 55 :3 0 18c
:3 0 55 :3 0 18d
:3 0 55 :3 0 18e
:3 0 55 :3 0 18f
:3 0 55 :3 0 190
:3 0 55 :3 0 bf
:3 0 55 :3 0 101
:3 0 55 :3 0 c1
:3 0 55 :3 0 102
:3 0 39 :3 0 52
:3 0 54 :3 0 55
:3 0 f1 :3 0 55
:3 0 15a :3 0 55
:3 0 186 :3 0 191
:3 0 55 :3 0 c6
:3 0 c7 :3 0 a4
:3 0 197 :3 0 52
:3 0 55 :3 0 9b
:3 0 52 :3 0 9b
:3 0 55 :3 0 53
:3 0 d :4 0 1a2
1 :8 0 1647 a8
:4 0 1632 :3 0 4e
:3 0 4f :2 0 7b4
1635 1636 :3 0 9
:3 0 5b :3 0 1638
1639 0 16 :2 0
163a 163b 0 163d
7b7 1644 9 :3 0
5b :3 0 163e 163f
0 a9 :2 0 1640
1641 0 1643 7b9
1645 1637 163d 0
1646 0 1643 0
1646 7bb 0 1647
7be 1691 5d :3 0
9 :3 0 5b :3 0
164a 164b 0 5c
:3 0 164c 164d 0
1687 2c :3 0 2d
:3 0 164f 1650 0
2c :3 0 3d :3 0
1652 1653 0 5e
:2 0 2 :4 0 1a3
:2 0 3f :2 0 14
:2 0 7c1 1658 165a
:3 0 7c4 1654 165c
1651 165e 165d :2 0
2f :3 0 40 :3 0
1660 1661 0 31
:4 0 1a4 :4 0 34
:2 0 35 :3 0 7c8
1665 1667 :3 0 34
:2 0 45 :4 0 7cb
1669 166b :3 0 34
:2 0 61 :4 0 7ce
166d 166f :3 0 34
:2 0 5c :3 0 7d1
1671 1673 :3 0 34
:2 0 62 :4 0 7d4
1675 1677 :3 0 34
:2 0 63 :3 0 64
:3 0 14 :2 0 65
:2 0 7d7 167a 167e
7db 1679 1680 :3 0
7de 1662 1682 :2 0
1684 7e1 1685 165f
1684 0 1686 7e3
0 1687 7e5 168a
:3 0 168a 0 168a
1689 1687 1688 :6 0
168c 28 :3 0 7e8
168e 7ea 168d 168c
:2 0 168f 7ec :2 0
1691 0 1691 1690
1647 168f :6 0 1800
1 :3 0 1a1 :3 0
1a5 :3 0 54 :3 0
54 :3 0 db :3 0
75 :3 0 da :3 0
da :3 0 53 :3 0
d :3 0 da :3 0
9b :3 0 1a5 :3 0
9b :3 0 da :3 0
a6 :4 0 1a6 1
:8 0 16b9 a8 :4 0
16a4 :3 0 4e :3 0
4f :2 0 7f0 16a7
16a8 :3 0 9 :3 0
5b :3 0 16aa 16ab
0 16 :2 0 16ac
16ad 0 16af 7f3
16b6 9 :3 0 5b
:3 0 16b0 16b1 0
a9 :2 0 16b2 16b3
0 16b5 7f5 16b7
16a9 16af 0 16b8
0 16b5 0 16b8
7f7 0 16b9 7fa
1703 5d :3 0 9
:3 0 5b :3 0 16bc
16bd 0 5c :3 0
16be 16bf 0 16f9
2c :3 0 2d :3 0
16c1 16c2 0 2c
:3 0 3d :3 0 16c4
16c5 0 5e :2 0
2 :4 0 1a7 :2 0
3f :2 0 14 :2 0
7fd 16ca 16cc :3 0
800 16c6 16ce 16c3
16d0 16cf :2 0 2f
:3 0 40 :3 0 16d2
16d3 0 31 :4 0
1a8 :4 0 34 :2 0
35 :3 0 804 16d7
16d9 :3 0 34 :2 0
45 :4 0 807 16db
16dd :3 0 34 :2 0
61 :4 0 80a 16df
16e1 :3 0 34 :2 0
5c :3 0 80d 16e3
16e5 :3 0 34 :2 0
62 :4 0 810 16e7
16e9 :3 0 34 :2 0
63 :3 0 64 :3 0
14 :2 0 65 :2 0
813 16ec 16f0 817
16eb 16f2 :3 0 81a
16d4 16f4 :2 0 16f6
81d 16f7 16d1 16f6
0 16f8 81f 0
16f9 821 16fc :3 0
16fc 0 16fc 16fb
16f9 16fa :6 0 16fe
2a :3 0 824 1700
826 16ff 16fe :2 0
1701 828 :2 0 1703
0 1703 1702 16b9
1701 :6 0 1800 1
:3 0 b2 :3 0 24
:3 0 55 :3 0 9b
:3 0 59 :3 0 cf
:3 0 b6 :3 0 b7
:3 0 b8 :3 0 55
:3 0 54 :3 0 b6
:3 0 ba :3 0 55
:3 0 e6 :3 0 55
:3 0 e7 :3 0 55
:3 0 e8 :3 0 55
:3 0 e9 :3 0 55
:3 0 ea :3 0 55
:3 0 eb :3 0 55
:3 0 ec :3 0 ed
:3 0 17 :3 0 56
:3 0 ee :3 0 ef
:3 0 f0 :3 0 f1
:3 0 f2 :3 0 f3
:3 0 b6 :3 0 103
:3 0 c3 :3 0 82
:3 0 55 :3 0 198
:3 0 55 :3 0 19a
:3 0 55 :3 0 9b
:3 0 d9 :3 0 55
:3 0 198 :3 0 55
:3 0 199 :3 0 55
:3 0 184 :3 0 55
:3 0 19a :3 0 55
:3 0 19b :3 0 55
:3 0 19c :3 0 d
:3 0 53 :3 0 55
:3 0 187 :3 0 55
:3 0 188 :3 0 55
:3 0 189 :3 0 55
:3 0 18a :3 0 55
:3 0 18b :3 0 55
:3 0 18c :3 0 55
:3 0 18d :3 0 55
:3 0 18e :3 0 55
:3 0 18f :3 0 55
:3 0 190 :3 0 55
:3 0 bf :3 0 55
:3 0 101 :3 0 55
:3 0 c1 :3 0 55
:3 0 102 :3 0 55
:3 0 186 :3 0 1a1
:3 0 55 :3 0 a4
:3 0 c4 :3 0 b6
:3 0 55 :3 0 a6
:3 0 55 :3 0 9b
:3 0 b6 :3 0 9b
:3 0 a2 :3 0 ae
:3 0 59 :3 0 cf
:3 0 a2 :3 0 ca
:3 0 b8 :3 0 54
:3 0 ba :3 0 55
:3 0 e6 :3 0 55
:3 0 e7 :3 0 55
:3 0 e8 :3 0 55
:3 0 e9 :3 0 55
:3 0 ea :3 0 55
:3 0 eb :3 0 55
:3 0 ec :3 0 ed
:3 0 17 :3 0 56
:3 0 ee :3 0 ef
:3 0 f0 :3 0 f1
:3 0 f2 :3 0 f3
:3 0 103 :3 0 c3
:3 0 82 :3 0 55
:3 0 198 :3 0 55
:3 0 19a :3 0 55
:3 0 9b :3 0 d9
:3 0 55 :3 0 198
:3 0 55 :3 0 199
:3 0 55 :3 0 184
:3 0 55 :3 0 19a
:3 0 55 :3 0 19b
:3 0 55 :3 0 19c
:3 0 d :3 0 53
:3 0 55 :3 0 187
:3 0 55 :3 0 188
:3 0 55 :3 0 189
:3 0 55 :3 0 18a
:3 0 55 :3 0 18b
:3 0 55 :3 0 18c
:3 0 55 :3 0 18d
:3 0 55 :3 0 18e
:3 0 55 :3 0 18f
:3 0 55 :3 0 190
:3 0 55 :3 0 bf
:3 0 55 :3 0 101
:3 0 55 :3 0 c1
:3 0 55 :3 0 102
:3 0 55 :3 0 186
:3 0 1a1 :3 0 55
:3 0 a4 :3 0 cb
:3 0 a2 :3 0 55
:3 0 a6 :3 0 a2
:3 0 ae :3 0 55
:3 0 9b :3 0 a4
:3 0 a5 :3 0 c5
:3 0 c5 :3 0 59
:3 0 a2 :3 0 cc
:3 0 a4 :3 0 a5
:3 0 bb :3 0 bb
:3 0 59 :3 0 c5
:3 0 9c :4 0 1a9
1 :a 0 17dc :2 0
1800 1706 17da :2 0
2c :3 0 2d :3 0
17dd 17de 0 2c
:3 0 3d :3 0 17e0
17e1 0 14 :2 0
2 :4 0 1aa :2 0
3f :2 0 14 :2 0
82a 17e6 17e8 :3 0
82d 17e2 17ea 17df
17ec 17eb :2 0 2f
:3 0 40 :3 0 17ee
17ef 0 31 :4 0
1ab :4 0 34 :2 0
35 :3 0 831 17f3
17f5 :3 0 834 17f0
17f7 :2 0 17f9 837
17fa 17ed 17f9 0
17fb 839 0 1800
8 :3 0 24 :3 0
17fd :2 0 1800 73
:3 0 83b 1801 151a
1800 0 1e83 39
:3 0 15 :3 0 16
:2 0 846 1802 1805
47 :3 0 4f :2 0
8c :3 0 1807 1809
0 84b 1808 180b
:3 0 ca :3 0 11
:3 0 cb :3 0 ae
:3 0 d :4 0 1ac
1 :8 0 1818 9
:3 0 5b :3 0 1813
1814 0 5c :3 0
1815 1816 0 1818
84e 1862 5d :3 0
9 :3 0 5b :3 0
181b 181c 0 5c
:3 0 181d 181e 0
1858 2c :3 0 2d
:3 0 1820 1821 0
2c :3 0 3d :3 0
1823 1824 0 5e
:2 0 2 :4 0 1ad
:2 0 3f :2 0 14
:2 0 851 1829 182b
:3 0 854 1825 182d
1822 182f 182e :2 0
2f :3 0 40 :3 0
1831 1832 0 31
:4 0 1ae :4 0 34
:2 0 35 :3 0 858
1836 1838 :3 0 34
:2 0 45 :4 0 85b
183a 183c :3 0 34
:2 0 61 :4 0 85e
183e 1840 :3 0 34
:2 0 5c :3 0 861
1842 1844 :3 0 34
:2 0 62 :4 0 864
1846 1848 :3 0 34
:2 0 63 :3 0 64
:3 0 14 :2 0 65
:2 0 867 184b 184f
86b 184a 1851 :3 0
86e 1833 1853 :2 0
1855 871 1856 1830
1855 0 1857 873
0 1858 875 185b
:3 0 185b 0 185b
185a 1858 1859 :6 0
185d 2c :3 0 878
185f 87a 185e 185d
:2 0 1860 87c :2 0
1862 0 1862 1861
1818 1860 :6 0 1931
1 :3 0 9 :3 0
5b :3 0 1864 1865
0 9 :3 0 4f
:2 0 1af :3 0 1867
1869 0 880 1868
186b :3 0 186c :2 0
b2 :3 0 25 :3 0
d :3 0 59 :3 0
11 :3 0 b8 :3 0
54 :3 0 1b0 :3 0
b6 :3 0 cc :3 0
11 :3 0 bc :3 0
1b1 :3 0 1b2 :3 0
b8 :3 0 1b3 :3 0
1b4 :3 0 1b5 :3 0
b8 :3 0 1b6 :3 0
1b7 :3 0 1b8 :3 0
b8 :3 0 1b9 :3 0
cb :3 0 b6 :3 0
c6 :3 0 a4 :3 0
1ba :3 0 1b2 :3 0
1b2 :3 0 59 :3 0
1b1 :3 0 c6 :3 0
a4 :3 0 1bb :3 0
1b5 :3 0 1b5 :3 0
59 :3 0 1b4 :3 0
c6 :3 0 a4 :3 0
6b :3 0 1b8 :3 0
1b8 :3 0 59 :3 0
1b7 :3 0 b6 :3 0
ae :3 0 d :3 0
d :3 0 59 :3 0
11 :3 0 b8 :3 0
54 :3 0 1bc :3 0
54 :3 0 1b0 :3 0
1bd :3 0 59 :3 0
cc :3 0 1be :3 0
1bf :3 0 1be :3 0
1bf :3 0 1c0 :3 0
1bc :3 0 b8 :3 0
1c0 :3 0 1bd :3 0
b8 :3 0 bc :3 0
1b1 :3 0 1b3 :3 0
1b4 :3 0 1b6 :3 0
1b7 :3 0 1b9 :3 0
d1 :3 0 a2 :3 0
c6 :3 0 c7 :3 0
a4 :3 0 a5 :3 0
1bd :3 0 a2 :3 0
cc :3 0 1bd :3 0
59 :3 0 c6 :3 0
c7 :3 0 a4 :3 0
a5 :3 0 1bc :3 0
1bc :3 0 59 :3 0
1bd :3 0 9c :3 0
a2 :3 0 cf :3 0
d :3 0 d :3 0
59 :3 0 11 :3 0
b8 :3 0 54 :3 0
1bc :3 0 54 :3 0
1b0 :3 0 1bd :3 0
59 :3 0 cc :3 0
1be :3 0 1bf :3 0
1be :3 0 1bf :3 0
1c0 :3 0 1bc :3 0
b8 :3 0 1c0 :3 0
1bd :3 0 b8 :3 0
bc :3 0 1b1 :3 0
1b3 :3 0 1b4 :3 0
1b6 :3 0 1b7 :3 0
1b9 :3 0 cd :3 0
ce :3 0 c6 :3 0
c7 :3 0 a4 :3 0
a5 :3 0 1bd :3 0
ce :3 0 d0 :3 0
1bd :3 0 59 :3 0
c6 :3 0 c7 :3 0
a4 :3 0 a5 :3 0
1bc :3 0 1bc :3 0
59 :3 0 1bd :3 0
9c :3 0 ce :3 0
cf :3 0 d :3 0
59 :3 0 54 :4 0
1c1 1 :a 0 190a
:2 0 192d 186f 1908
:2 0 2c :3 0 2d
:3 0 190b 190c 0
2c :3 0 3d :3 0
190e 190f 0 14
:2 0 2 :4 0 1c2
:2 0 3f :2 0 14
:2 0 883 1914 1916
:3 0 886 1910 1918
190d 191a 1919 :2 0
2f :3 0 40 :3 0
191c 191d 0 31
:4 0 1c3 :4 0 34
:2 0 35 :3 0 88a
1921 1923 :3 0 88d
191e 1925 :2 0 1927
890 1928 191b 1927
0 1929 892 0
192d 8 :3 0 25
:3 0 192b :2 0 192d
894 192e 186d 192d
0 192f 898 0
1931 73 :3 0 89a
1932 180c 1931 0
1e83 39 :3 0 15
:3 0 16 :2 0 89d
1933 1936 4f :2 0
74 :2 0 8a2 1938
193a :3 0 b2 :3 0
26 :3 0 da :3 0
76 :3 0 da :3 0
76 :3 0 55 :3 0
cf :3 0 59 :3 0
55 :3 0 9b :3 0
55 :3 0 a6 :3 0
b6 :3 0 ca :3 0
cb :3 0 b6 :3 0
55 :3 0 9b :3 0
b6 :3 0 ae :3 0
a2 :3 0 b7 :3 0
c4 :3 0 a2 :3 0
55 :3 0 9b :3 0
a2 :3 0 9b :3 0
b8 :3 0 da :3 0
76 :3 0 55 :3 0
a6 :3 0 54 :3 0
55 :3 0 cf :3 0
55 :3 0 f7 :3 0
da :3 0 f8 :3 0
da :3 0 f9 :3 0
da :3 0 126 :3 0
da :3 0 127 :3 0
da :3 0 159 :3 0
e6 :3 0 da :3 0
153 :3 0 e7 :3 0
11a :3 0 15a :3 0
f1 :3 0 f1 :3 0
11a :3 0 15a :3 0
129 :3 0 f1 :3 0
ec :3 0 da :3 0
15b :3 0 da :3 0
15c :3 0 da :3 0
15b :3 0 da :3 0
15c :3 0 12a :3 0
12b :3 0 da :3 0
129 :3 0 12c :3 0
12d :3 0 da :3 0
129 :3 0 12d :3 0
f1 :3 0 15a :3 0
12e :3 0 da :3 0
12f :3 0 da :3 0
130 :3 0 da :3 0
131 :3 0 da :3 0
132 :3 0 da :3 0
133 :3 0 da :3 0
134 :3 0 da :3 0
121 :3 0 da :3 0
135 :3 0 da :3 0
129 :3 0 136 :3 0
137 :3 0 138 :3 0
13a :3 0 17 :3 0
56 :3 0 55 :3 0
fa :3 0 55 :3 0
fb :3 0 fc :3 0
b8 :3 0 fd :3 0
39 :3 0 55 :3 0
fe :3 0 55 :3 0
fb :3 0 fe :3 0
ff :3 0 b8 :3 0
100 :3 0 da :3 0
bf :3 0 da :3 0
101 :3 0 da :3 0
c1 :3 0 da :3 0
102 :3 0 55 :3 0
a6 :3 0 a2 :3 0
103 :3 0 c4 :3 0
a2 :3 0 55 :3 0
9b :3 0 a2 :3 0
9b :3 0 103 :3 0
55 :3 0 104 :3 0
da :3 0 f3 :3 0
da :3 0 13b :3 0
da :3 0 13c :3 0
da :3 0 13e :3 0
da :3 0 d9 :3 0
da :3 0 105 :3 0
106 :3 0 b8 :3 0
13f :3 0 da :3 0
ed :3 0 da :3 0
108 :3 0 da :3 0
109 :3 0 da :3 0
10a :3 0 da :3 0
10b :3 0 da :3 0
10c :3 0 da :3 0
10d :3 0 da :3 0
140 :3 0 da :3 0
10e :3 0 da :3 0
11a :3 0 da :3 0
11a :3 0 11a :3 0
da :3 0 141 :3 0
142 :3 0 da :3 0
143 :3 0 144 :3 0
1b :3 0 39 :3 0
da :3 0 145 :3 0
da :3 0 159 :3 0
e5 :3 0 145 :3 0
1b :3 0 39 :3 0
da :3 0 146 :3 0
da :3 0 153 :3 0
e5 :3 0 146 :3 0
1b :3 0 da :3 0
148 :3 0 da :3 0
134 :3 0 da :3 0
148 :3 0 148 :3 0
da :3 0 12b :3 0
149 :3 0 14a :3 0
da :3 0 76 :3 0
da :3 0 d9 :3 0
da :3 0 76 :3 0
da :3 0 145 :3 0
da :3 0 159 :3 0
da :3 0 146 :3 0
da :3 0 153 :3 0
14b :3 0 da :3 0
14c :3 0 15d :3 0
b8 :3 0 14d :3 0
da :3 0 14e :3 0
15e :3 0 b8 :3 0
14f :3 0 da :3 0
150 :3 0 da :3 0
151 :3 0 15f :3 0
b8 :3 0 152 :3 0
a3 :3 0 55 :3 0
a4 :3 0 75 :3 0
da :3 0 da :3 0
76 :3 0 d :3 0
55 :3 0 cf :3 0
da :3 0 cf :3 0
c6 :3 0 c7 :3 0
a4 :3 0 10f :3 0
fc :3 0 55 :3 0
fb :3 0 fc :3 0
59 :3 0 c6 :3 0
c7 :3 0 a4 :3 0
10f :3 0 ff :3 0
39 :3 0 55 :3 0
fe :3 0 55 :3 0
fb :3 0 ff :3 0
59 :3 0 c6 :3 0
c7 :3 0 a4 :3 0
110 :3 0 106 :3 0
106 :3 0 59 :3 0
da :3 0 105 :3 0
c6 :3 0 c7 :3 0
a4 :3 0 160 :3 0
15d :3 0 15d :3 0
59 :3 0 da :3 0
14c :3 0 c6 :3 0
c7 :3 0 a4 :3 0
160 :3 0 15e :3 0
15e :3 0 59 :3 0
da :3 0 14e :3 0
c6 :3 0 c7 :3 0
a4 :3 0 161 :3 0
15f :3 0 15f :3 0
59 :3 0 da :3 0
151 :3 0 54 :3 0
b8 :4 0 1c4 1
:a 0 1a7c :2 0 1aa0
193d 1a7a :2 0 2c
:3 0 2d :3 0 1a7d
1a7e 0 2c :3 0
3d :3 0 1a80 1a81
0 14 :2 0 2
:4 0 1c5 :2 0 3f
:2 0 14 :2 0 8a5
1a86 1a88 :3 0 8a8
1a82 1a8a 1a7f 1a8c
1a8b :2 0 2f :3 0
40 :3 0 1a8e 1a8f
0 31 :4 0 1c6
:4 0 34 :2 0 35
:3 0 8ac 1a93 1a95
:3 0 8af 1a90 1a97
:2 0 1a99 8b2 1a9a
1a8d 1a99 0 1a9b
8b4 0 1aa0 8
:3 0 26 :3 0 1a9d
:2 0 1aa0 73 :3 0
8b6 1aa1 193b 1aa0
0 1e83 39 :3 0
15 :3 0 16 :2 0
8ba 1aa2 1aa5 4f
:2 0 8d :2 0 8bf
1aa7 1aa9 :3 0 b2
:3 0 27 :3 0 55
:3 0 cf :3 0 59
:3 0 55 :3 0 9b
:3 0 55 :3 0 a6
:3 0 b6 :3 0 ca
:3 0 cb :3 0 b6
:3 0 55 :3 0 9b
:3 0 b6 :3 0 ae
:3 0 a2 :3 0 b7
:3 0 c4 :3 0 a2
:3 0 55 :3 0 9b
:3 0 a2 :3 0 9b
:3 0 b8 :3 0 55
:3 0 a6 :3 0 47
:3 0 1c7 :3 0 54
:3 0 55 :3 0 cf
:3 0 55 :3 0 f7
:3 0 e5 :3 0 e6
:3 0 e5 :3 0 e7
:3 0 f1 :3 0 e5
:3 0 f8 :3 0 e5
:3 0 f9 :3 0 e5
:3 0 16f :3 0 e5
:3 0 170 :3 0 15a
:3 0 e5 :3 0 12f
:3 0 e5 :3 0 130
:3 0 131 :3 0 e5
:3 0 132 :3 0 e5
:3 0 133 :3 0 134
:3 0 e5 :3 0 121
:3 0 e5 :3 0 135
:3 0 136 :3 0 17
:3 0 56 :3 0 55
:3 0 fa :3 0 e5
:3 0 1c8 :3 0 55
:3 0 fb :3 0 fc
:3 0 b8 :3 0 fd
:3 0 39 :3 0 55
:3 0 fe :3 0 55
:3 0 fb :3 0 fe
:3 0 ff :3 0 b8
:3 0 100 :3 0 bf
:3 0 101 :3 0 c1
:3 0 102 :3 0 55
:3 0 a6 :3 0 a2
:3 0 103 :3 0 c4
:3 0 a2 :3 0 55
:3 0 9b :3 0 a2
:3 0 9b :3 0 103
:3 0 55 :3 0 104
:3 0 f3 :3 0 e5
:3 0 13b :3 0 e5
:3 0 13c :3 0 13e
:3 0 d9 :3 0 105
:3 0 13f :3 0 ed
:3 0 108 :3 0 109
:3 0 10a :3 0 10b
:3 0 10c :3 0 10d
:3 0 1c9 :3 0 a3
:3 0 55 :3 0 c6
:3 0 c7 :3 0 a4
:3 0 10f :3 0 fc
:3 0 55 :3 0 fb
:3 0 fc :3 0 59
:3 0 c6 :3 0 c7
:3 0 a4 :3 0 10f
:3 0 ff :3 0 39
:3 0 55 :3 0 fe
:3 0 55 :3 0 fb
:3 0 ff :3 0 59
:3 0 55 :3 0 104
:3 0 55 :3 0 59
:3 0 d :3 0 54
:3 0 b8 :4 0 1ca
1 :a 0 1b41 :2 0
1b65 1aac 1b3f :2 0
2c :3 0 2d :3 0
1b42 1b43 0 2c
:3 0 3d :3 0 1b45
1b46 0 14 :2 0
2 :4 0 1cb :2 0
3f :2 0 14 :2 0
8c2 1b4b 1b4d :3 0
8c5 1b47 1b4f 1b44
1b51 1b50 :2 0 2f
:3 0 40 :3 0 1b53
1b54 0 31 :4 0
1cc :4 0 34 :2 0
35 :3 0 8c9 1b58
1b5a :3 0 8cc 1b55
1b5c :2 0 1b5e 8cf
1b5f 1b52 1b5e 0
1b60 8d1 0 1b65
8 :3 0 27 :3 0
1b62 :2 0 1b65 73
:3 0 8d3 1b66 1aaa
1b65 0 1e83 39
:3 0 15 :3 0 16
:2 0 8d7 1b67 1b6a
4f :2 0 1cd :2 0
8dc 1b6c 1b6e :3 0
97 :3 0 98 :3 0
1ce :4 0 1b72 :4 0
1b73 :2 0 1d8a 9
:3 0 5b :3 0 1b75
1b76 0 16 :2 0
1b77 1b78 0 1d8a
1cf :3 0 9b :3 0
a6 :3 0 1d0 :3 0
9b :3 0 a6 :3 0
1d0 :3 0 75 :3 0
53 :3 0 d :3 0
d9 :3 0 1d1 :3 0
47 :3 0 1d2 :3 0
9b :3 0 a6 :4 0
1d3 1 :8 0 1ba0
a8 :4 0 1b8b :3 0
4e :3 0 4f :2 0
8e1 1b8e 1b8f :3 0
9 :3 0 5b :3 0
1b91 1b92 0 16
:2 0 1b93 1b94 0
1b96 8e4 1b9d 9
:3 0 5b :3 0 1b97
1b98 0 a9 :2 0
1b99 1b9a 0 1b9c
8e6 1b9e 1b90 1b96
0 1b9f 0 1b9c
0 1b9f 8e8 0
1ba0 8eb 1bea 5d
:3 0 9 :3 0 5b
:3 0 1ba3 1ba4 0
5c :3 0 1ba5 1ba6
0 1be0 2c :3 0
2d :3 0 1ba8 1ba9
0 2c :3 0 3d
:3 0 1bab 1bac 0
5e :2 0 2 :4 0
1d4 :2 0 3f :2 0
14 :2 0 8ee 1bb1
1bb3 :3 0 8f1 1bad
1bb5 1baa 1bb7 1bb6
:2 0 2f :3 0 40
:3 0 1bb9 1bba 0
31 :4 0 1d5 :4 0
34 :2 0 35 :3 0
8f5 1bbe 1bc0 :3 0
34 :2 0 45 :4 0
8f8 1bc2 1bc4 :3 0
34 :2 0 61 :4 0
8fb 1bc6 1bc8 :3 0
34 :2 0 5c :3 0
8fe 1bca 1bcc :3 0
34 :2 0 62 :4 0
901 1bce 1bd0 :3 0
34 :2 0 63 :3 0
64 :3 0 14 :2 0
65 :2 0 904 1bd3
1bd7 908 1bd2 1bd9
:3 0 90b 1bbb 1bdb
:2 0 1bdd 90e 1bde
1bb8 1bdd 0 1bdf
910 0 1be0 912
1be3 :3 0 1be3 0
1be3 1be2 1be0 1be1
:6 0 1be5 2e :3 0
915 1be7 917 1be6
1be5 :2 0 1be8 919
:2 0 1bea 0 1bea
1be9 1ba0 1be8 :6 0
1d8a 1 :3 0 97
:3 0 98 :3 0 1d6
:4 0 1bee :4 0 1bef
:2 0 1d8a 9 :3 0
5b :3 0 1bf1 1bf2
0 16 :2 0 1bf3
1bf4 0 1d8a 1d7
:3 0 9b :3 0 a6
:3 0 1d0 :3 0 9b
:3 0 a6 :3 0 1d0
:3 0 75 :3 0 53
:3 0 d :3 0 db
:3 0 d :3 0 9b
:3 0 a6 :4 0 1d8
1 :8 0 1c1a a8
:4 0 1c05 :3 0 4e
:3 0 4f :2 0 91d
1c08 1c09 :3 0 9
:3 0 5b :3 0 1c0b
1c0c 0 16 :2 0
1c0d 1c0e 0 1c10
920 1c17 9 :3 0
5b :3 0 1c11 1c12
0 a9 :2 0 1c13
1c14 0 1c16 922
1c18 1c0a 1c10 0
1c19 0 1c16 0
1c19 924 0 1c1a
927 1c64 5d :3 0
9 :3 0 5b :3 0
1c1d 1c1e 0 5c
:3 0 1c1f 1c20 0
1c5a 2c :3 0 2d
:3 0 1c22 1c23 0
2c :3 0 3d :3 0
1c25 1c26 0 5e
:2 0 2 :4 0 1d9
:2 0 3f :2 0 14
:2 0 92a 1c2b 1c2d
:3 0 92d 1c27 1c2f
1c24 1c31 1c30 :2 0
2f :3 0 40 :3 0
1c33 1c34 0 31
:4 0 1da :4 0 34
:2 0 35 :3 0 931
1c38 1c3a :3 0 34
:2 0 45 :4 0 934
1c3c 1c3e :3 0 34
:2 0 61 :4 0 937
1c40 1c42 :3 0 34
:2 0 5c :3 0 93a
1c44 1c46 :3 0 34
:2 0 62 :4 0 93d
1c48 1c4a :3 0 34
:2 0 63 :3 0 64
:3 0 14 :2 0 65
:2 0 940 1c4d 1c51
944 1c4c 1c53 :3 0
947 1c35 1c55 :2 0
1c57 94a 1c58 1c32
1c57 0 1c59 94c
0 1c5a 94e 1c5d
:3 0 1c5d 0 1c5d
1c5c 1c5a 1c5b :6 0
1c5f 30 :3 0 951
1c61 953 1c60 1c5f
:2 0 1c62 955 :2 0
1c64 0 1c64 1c63
1c1a 1c62 :6 0 1d8a
1 :3 0 97 :3 0
98 :3 0 1db :4 0
1c68 :4 0 1c69 :2 0
1d8a 9 :3 0 5b
:3 0 1c6b 1c6c 0
16 :2 0 1c6d 1c6e
0 1d8a 1dc :3 0
9b :3 0 a6 :3 0
1d0 :3 0 55 :3 0
9b :3 0 55 :3 0
a6 :3 0 55 :3 0
1d0 :3 0 1cf :3 0
55 :3 0 c6 :3 0
c7 :3 0 a4 :3 0
1d7 :3 0 52 :3 0
55 :3 0 9b :3 0
52 :3 0 9b :3 0
52 :3 0 9b :3 0
52 :3 0 a6 :3 0
52 :3 0 1d0 :3 0
1d7 :3 0 52 :3 0
c6 :3 0 c7 :3 0
a4 :3 0 1cf :3 0
55 :3 0 55 :3 0
9b :3 0 52 :3 0
9b :4 0 1dd 1
:8 0 1cac a8 :4 0
1c97 :3 0 4e :3 0
4f :2 0 959 1c9a
1c9b :3 0 9 :3 0
5b :3 0 1c9d 1c9e
0 16 :2 0 1c9f
1ca0 0 1ca2 95c
1ca9 9 :3 0 5b
:3 0 1ca3 1ca4 0
a9 :2 0 1ca5 1ca6
0 1ca8 95e 1caa
1c9c 1ca2 0 1cab
0 1ca8 0 1cab
960 0 1cac 963
1cf6 5d :3 0 9
:3 0 5b :3 0 1caf
1cb0 0 5c :3 0
1cb1 1cb2 0 1cec
2c :3 0 2d :3 0
1cb4 1cb5 0 2c
:3 0 3d :3 0 1cb7
1cb8 0 5e :2 0
2 :4 0 1de :2 0
3f :2 0 14 :2 0
966 1cbd 1cbf :3 0
969 1cb9 1cc1 1cb6
1cc3 1cc2 :2 0 2f
:3 0 40 :3 0 1cc5
1cc6 0 31 :4 0
1df :4 0 34 :2 0
35 :3 0 96d 1cca
1ccc :3 0 34 :2 0
45 :4 0 970 1cce
1cd0 :3 0 34 :2 0
61 :4 0 973 1cd2
1cd4 :3 0 34 :2 0
5c :3 0 976 1cd6
1cd8 :3 0 34 :2 0
62 :4 0 979 1cda
1cdc :3 0 34 :2 0
63 :3 0 64 :3 0
14 :2 0 65 :2 0
97c 1cdf 1ce3 980
1cde 1ce5 :3 0 983
1cc7 1ce7 :2 0 1ce9
986 1cea 1cc4 1ce9
0 1ceb 988 0
1cec 98a 1cef :3 0
1cef 0 1cef 1cee
1cec 1ced :6 0 1cf1
32 :3 0 98d 1cf3
98f 1cf2 1cf1 :2 0
1cf4 991 :2 0 1cf6
0 1cf6 1cf5 1cac
1cf4 :6 0 1d8a 1
:3 0 b2 :3 0 28
:3 0 55 :3 0 9b
:3 0 59 :3 0 b6
:3 0 b7 :3 0 b8
:3 0 54 :3 0 b6
:3 0 1e0 :3 0 55
:3 0 1d0 :3 0 1dc
:3 0 55 :3 0 a4
:3 0 c4 :3 0 b6
:3 0 55 :3 0 a6
:3 0 55 :3 0 9b
:3 0 b6 :3 0 9b
:3 0 c6 :3 0 c7
:3 0 a4 :3 0 1d7
:3 0 1e1 :3 0 55
:3 0 9b :3 0 1e1
:3 0 9b :3 0 a2
:3 0 ae :3 0 59
:3 0 a2 :3 0 ca
:3 0 b8 :3 0 54
:3 0 1e0 :3 0 55
:3 0 1d0 :3 0 1dc
:3 0 55 :3 0 a4
:3 0 cb :3 0 a2
:3 0 55 :3 0 a6
:3 0 a2 :3 0 ae
:3 0 55 :3 0 9b
:3 0 a4 :3 0 a5
:3 0 c5 :3 0 c5
:3 0 59 :3 0 a2
:3 0 cc :3 0 a4
:3 0 a5 :3 0 bb
:3 0 bb :3 0 59
:3 0 c5 :3 0 9c
:3 0 c6 :3 0 c7
:3 0 a4 :3 0 1d7
:3 0 1e1 :3 0 55
:3 0 9b :3 0 1e1
:3 0 9b :3 0 d8
:3 0 9b :3 0 59
:3 0 b6 :3 0 b7
:3 0 b8 :3 0 54
:3 0 b6 :3 0 1e0
:3 0 1d0 :3 0 a3
:3 0 d8 :3 0 c4
:3 0 b6 :3 0 d8
:3 0 53 :3 0 d
:3 0 d8 :3 0 9b
:3 0 b6 :3 0 9b
:3 0 1e2 :3 0 9b
:3 0 1dc :3 0 1e2
:3 0 d8 :3 0 9b
:3 0 1e2 :3 0 9b
:3 0 54 :3 0 b8
:4 0 1e3 1 :a 0
1d66 :2 0 1d8a 1cf9
1d64 :2 0 2c :3 0
2d :3 0 1d67 1d68
0 2c :3 0 3d
:3 0 1d6a 1d6b 0
14 :2 0 2 :4 0
1e4 :2 0 3f :2 0
14 :2 0 993 1d70
1d72 :3 0 996 1d6c
1d74 1d69 1d76 1d75
:2 0 2f :3 0 40
:3 0 1d78 1d79 0
31 :4 0 1e5 :4 0
34 :2 0 35 :3 0
99a 1d7d 1d7f :3 0
99d 1d7a 1d81 :2 0
1d83 9a0 1d84 1d77
1d83 0 1d85 9a2
0 1d8a 8 :3 0
28 :3 0 1d87 :2 0
1d8a 73 :3 0 9a4
1d8b 1b6f 1d8a 0
1e83 39 :3 0 15
:3 0 16 :2 0 9b1
1d8c 1d8f 4f :2 0
81 :2 0 9b6 1d91
1d93 :3 0 b2 :3 0
29 :3 0 da :3 0
59 :3 0 b6 :3 0
b7 :3 0 b8 :3 0
54 :3 0 b6 :3 0
1e0 :3 0 1d0 :3 0
6b :3 0 da :3 0
a4 :3 0 c4 :3 0
b6 :3 0 da :3 0
59 :3 0 b6 :3 0
9b :3 0 da :3 0
54 :3 0 da :3 0
82 :3 0 b :3 0
b8 :4 0 1e6 1
:a 0 1db1 :2 0 1dd5
1d96 1daf :2 0 2c
:3 0 2d :3 0 1db2
1db3 0 2c :3 0
3d :3 0 1db5 1db6
0 14 :2 0 2
:4 0 1e7 :2 0 3f
:2 0 14 :2 0 9b9
1dbb 1dbd :3 0 9bc
1db7 1dbf 1db4 1dc1
1dc0 :2 0 2f :3 0
40 :3 0 1dc3 1dc4
0 31 :4 0 1e8
:4 0 34 :2 0 35
:3 0 9c0 1dc8 1dca
:3 0 9c3 1dc5 1dcc
:2 0 1dce 9c6 1dcf
1dc2 1dce 0 1dd0
9c8 0 1dd5 8
:3 0 29 :3 0 1dd2
:2 0 1dd5 73 :3 0
9ca 1dd6 1d94 1dd5
0 1e83 39 :3 0
15 :3 0 16 :2 0
9ce 1dd7 1dda 47
:3 0 4f :2 0 8e
:3 0 1ddc 1dde 0
9d3 1ddd 1de0 :3 0
1de1 :2 0 39 :3 0
15 :3 0 16 :2 0
9d6 1de3 1de6 47
:3 0 4f :2 0 8f
:3 0 1de8 1dea 0
9db 1de9 1dec :3 0
1ded :2 0 1de2 1def
1dee :2 0 b2 :3 0
2a :3 0 a2 :3 0
9b :3 0 59 :3 0
a2 :3 0 b7 :3 0
b8 :3 0 47 :3 0
1e9 :3 0 54 :3 0
a2 :3 0 1e0 :3 0
1d0 :3 0 191 :3 0
d8 :3 0 c4 :3 0
a2 :3 0 d8 :3 0
53 :3 0 d :3 0
d8 :3 0 9b :3 0
a2 :3 0 9b :3 0
b8 :4 0 1ea 1
:a 0 1e0d :2 0 1e30
1df2 1e0b :2 0 2c
:3 0 2d :3 0 1e0e
1e0f 0 2c :3 0
3d :3 0 1e11 1e12
0 14 :2 0 2
:4 0 1eb :2 0 3f
:2 0 14 :2 0 9de
1e17 1e19 :3 0 9e1
1e13 1e1b 1e10 1e1d
1e1c :2 0 2f :3 0
40 :3 0 1e1f 1e20
0 31 :4 0 1ec
:4 0 34 :2 0 35
:3 0 9e5 1e24 1e26
:3 0 9e8 1e21 1e28
:2 0 1e2a 9eb 1e2b
1e1e 1e2a 0 1e2c
9ed 0 1e30 8
:3 0 2a :3 0 1e2e
:2 0 1e30 9ef 1e31
1df0 1e30 0 1e83
2c :3 0 2d :3 0
1e32 1e33 0 2c
:3 0 3d :3 0 1e35
1e36 0 169 :2 0
2 :4 0 1ed :2 0
3f :2 0 14 :2 0
9f3 1e3b 1e3d :3 0
9f6 1e37 1e3f 1e34
1e41 1e40 :2 0 2f
:3 0 40 :3 0 1e43
1e44 0 31 :4 0
1ee :4 0 34 :2 0
35 :3 0 9fa 1e48
1e4a :3 0 34 :2 0
45 :4 0 9fd 1e4c
1e4e :3 0 34 :2 0
46 :4 0 a00 1e50
1e52 :3 0 34 :2 0
39 :3 0 3a :3 0
47 :3 0 48 :3 0
1e57 1e58 0 a03
1e56 1e5a 3b :4 0
a05 1e55 1e5d a08
1e54 1e5f :3 0 34
:2 0 49 :4 0 a0b
1e61 1e63 :3 0 34
:2 0 37 :4 0 a0e
1e65 1e67 :3 0 34
:2 0 3 :3 0 a11
1e69 1e6b :3 0 34
:2 0 37 :4 0 a14
1e6d 1e6f :3 0 a17
1e45 1e71 :2 0 1e73
a1a 1e74 1e42 1e73
0 1e75 a1c 0
1e80 4c :3 0 1ef
:3 0 1e76 1e77 0
47 :3 0 48 :3 0
1e79 1e7a 0 3
:3 0 4e :3 0 a1e
1e78 1e7e :2 0 1e80
a22 1e82 6be 913
0 1e83 0 1e80
0 1e83 a25 0
1e84 a35 1f25 9
:3 0 1f0 :2 0 4
1e85 1e86 0 2c
:3 0 2d :3 0 1e88
1e89 0 2c :3 0
3d :3 0 1e8b 1e8c
0 5e :2 0 2
:4 0 1f1 :2 0 3f
:2 0 14 :2 0 a3e
1e91 1e93 :3 0 a41
1e8d 1e95 1e8a 1e97
1e96 :2 0 2f :3 0
40 :3 0 1e99 1e9a
0 31 :4 0 1f2
:4 0 34 :2 0 35
:3 0 a45 1e9e 1ea0
:3 0 a48 1e9b 1ea2
:2 0 1ebb 2f :3 0
40 :3 0 1ea4 1ea5
0 31 :4 0 1f3
:4 0 34 :2 0 9
:3 0 1f4 :3 0 1eaa
1eab 0 a4b 1ea9
1ead :3 0 34 :2 0
49 :4 0 a4e 1eaf
1eb1 :3 0 34 :2 0
9 :3 0 1f5 :3 0
1eb4 1eb5 0 a51
1eb3 1eb7 :3 0 a54
1ea6 1eb9 :2 0 1ebb
a57 1ebc 1e98 1ebb
0 1ebd a5a 0
1ecd b2 :3 0 2b
:3 0 9 :3 0 1f4
:3 0 1f6 :3 0 9
:3 0 1f5 :3 0 1f7
:3 0 119 :4 0 1f8
1 :a 0 1ec9 :2 0
1ecd 1ebf 1ec7 :2 0
8 :3 0 2b :3 0
1ecb :2 0 1ecd a5c
1ecf a60 1ece 1ecd
:2 0 1f23 5d :3 0
9 :3 0 5b :3 0
1ed2 1ed3 0 5c
:3 0 1ed4 1ed5 0
1f1b 2c :3 0 2d
:3 0 1ed7 1ed8 0
2c :3 0 3d :3 0
1eda 1edb 0 5e
:2 0 2 :4 0 1f9
:2 0 3f :2 0 14
:2 0 a62 1ee0 1ee2
:3 0 a65 1edc 1ee4
1ed9 1ee6 1ee5 :2 0
2f :3 0 40 :3 0
1ee8 1ee9 0 31
:4 0 1fa :4 0 34
:2 0 35 :3 0 a69
1eed 1eef :3 0 a6c
1eea 1ef1 :2 0 1f0b
2f :3 0 40 :3 0
1ef3 1ef4 0 31
:4 0 61 :4 0 34
:2 0 5c :3 0 a6f
1ef8 1efa :3 0 34
:2 0 62 :4 0 a72
1efc 1efe :3 0 34
:2 0 63 :3 0 64
:3 0 14 :2 0 65
:2 0 a75 1f01 1f05
a79 1f00 1f07 :3 0
a7c 1ef5 1f09 :2 0
1f0b a7f 1f0c 1ee7
1f0b 0 1f0d a82
0 1f1b b2 :3 0
2b :3 0 1f6 :3 0
9 :3 0 1f5 :3 0
1f7 :3 0 119 :4 0
1fb 1 :a 0 1f17
:2 0 1f1b 1f0f 1f15
:2 0 8 :3 0 2b
:3 0 1f19 :2 0 1f1b
a84 1f1e :3 0 1f1e
0 1f1e 1f1d 1f1b
1f1c :6 0 1f20 1
:3 0 a89 1f22 a8b
1f21 1f20 :2 0 1f23
a8d :2 0 1f25 a90
1f25 1f24 1e84 1f23
:6 0 1f26 :2 0 2
14 1f25 1f29 :3 0
1f28 1f26 1f2a :8 0

aad
4
:3 0 1 3 1
7 1 b 3
6 a e 1
18 1 16 1
1f 1 1d 1
26 1 24 1
2d 1 2b 1
34 1 32 1
3b 1 39 1
40 1 46 1
4c 1 52 1
58 1 5e 1
64 1 6b 1
72 1 79 1
80 1 87 1
8e 1 95 1
9c 1 a3 1
aa 1 b1 1
b8 1 bf 1
c6 1 cd 1
da 1 e6 2
e9 eb 2 ee
f0 2 f2 f4
2 f6 f8 2
fa fc 1 102
2 104 105 2
fe 107 2 109
10b 2 10d 10f
2 111 113 2
115 117 2 119
11b 4 e2 e8
ed 11d 1 11f
1 121 2 12b
12d 3 129 12a
12f 2 138 13a
2 137 13c 1
13e 1 140 1
142 2 14f 151
3 14d 14e 153
2 15c 15e 2
160 162 2 164
166 1 16e 2
170 171 2 168
173 2 175 177
2 179 17b 2
17d 17f 2 181
183 2 15b 185
1 187 1 189
2 193 195 3
191 192 197 2
1a0 1a2 2 19f
1a4 1 1a6 1
1a8 3 1af 1b0
1b1 3 18a 1a9
1b3 1 1b5 2
1c1 1c2 1 1c6
2 1c4 1c6 2
1cb 1cc 1 1d0
2 1ce 1d0 2
1ee 1f3 2 204
206 3 202 203
208 2 211 213
2 215 217 2
219 21b 2 21d
21f 2 221 223
3 228 229 22a
2 225 22c 2
210 22e 1 230
1 232 2 1fb
233 1 237 1
1f6 1 23b 1
246 2 242 246
2 25f 264 2
275 277 3 273
274 279 2 282
284 2 286 288
2 28a 28c 2
28e 290 2 292
294 3 299 29a
29b 2 296 29d
2 281 29f 1
2a1 1 2a3 2
26c 2a4 1 2a8
1 267 1 2ac
1 2b7 2 2b3
2b7 2 2bf 2c4
2 2d5 2d7 3
2d3 2d4 2d9 2
2e2 2e4 2 2e6
2e8 2 2ea 2ec
2 2ee 2f0 2
2f2 2f4 3 2f9
2fa 2fb 2 2f6
2fd 2 2e1 2ff
1 301 1 303
2 2cc 304 1
308 1 2c7 1
30c 1 317 2
313 317 2 323
325 3 321 322
327 2 330 332
2 334 336 2
338 33a 1 342
2 344 345 2
33c 347 2 349
34b 2 34d 34f
2 351 353 2
355 357 2 32f
359 1 35b 1
35d 2 367 369
3 365 366 36b
2 374 376 2
373 378 1 37a
1 37c 3 383
384 385 3 35e
37d 387 1 389
2 30f 38a 1
38c 2 2af 38d
1 38f 2 23e
390 2 394 395
1 399 2 397
399 2 3a1 3a6
2 3b7 3b9 3
3b5 3b6 3bb 2
3c4 3c6 2 3c8
3ca 2 3cc 3ce
2 3d0 3d2 2
3d4 3d6 3 3db
3dc 3dd 2 3d8
3df 2 3c3 3e1
1 3e3 1 3e5
2 3ae 3e6 1
3ea 1 3a9 1
3ee 1 3f9 2
3f5 3f9 2 405
407 3 403 404
409 2 412 414
2 416 418 2
41a 41c 1 424
2 426 427 2
41e 429 2 42b
42d 2 42f 431
2 433 435 2
437 439 2 411
43b 1 43d 1
43f 2 449 44b
3 447 448 44d
2 456 458 2
455 45a 1 45c
1 45e 3 465
466 467 3 440
45f 469 1 46b
2 475 47a 2
48b 48d 3 489
48a 48f 2 498
49a 2 49c 49e
2 4a0 4a2 2
4a4 4a6 2 4a8
4aa 3 4af 4b0
4b1 2 4ac 4b3
2 497 4b5 1
4b7 1 4b9 2
482 4ba 1 4be
1 47d 1 4c2
3 3f1 46c 4c5
2 4cb 4cc 1
4d0 2 4ce 4d0
2 4d8 4dd 2
4ee 4f0 3 4ec
4ed 4f2 2 4fb
4fd 2 4ff 501
2 503 505 2
507 509 2 50b
50d 3 512 513
514 2 50f 516
2 4fa 518 1
51a 1 51c 2
4e5 51d 1 521
1 4e0 1 525
1 530 2 52c
530 2 53c 53e
3 53a 53b 540
2 549 54b 2
54d 54f 2 551
553 1 55b 2
55d 55e 2 555
560 2 562 564
2 566 568 2
56a 56c 2 56e
570 2 548 572
1 574 1 576
2 580 582 3
57e 57f 584 2
58d 58f 2 58c
591 1 593 1
595 3 59c 59d
59e 3 577 596
5a0 1 5a2 3
528 5a3 5a6 2
5ab 5ac 1 5b2
2 5ae 5b2 2
5b7 5b8 1 5bc
2 5ba 5bc 2
5c3 5c4 1 5ca
2 5c6 5ca 2
5d1 5d2 1 5d8
2 5d4 5d8 2
5e6 5eb 2 5fc
5fe 3 5fa 5fb
600 2 609 60b
2 60d 60f 2
611 613 2 615
617 2 619 61b
3 620 621 622
2 61d 624 2
608 626 1 628
1 62a 2 5f3
62b 1 62f 1
5ee 1 633 1
63e 2 63a 63e
2 64a 64c 3
648 649 64e 2
657 659 2 65b
65d 2 65f 661
1 669 2 66b
66c 2 663 66e
2 670 672 2
674 676 2 678
67a 2 67c 67e
2 656 680 1
682 1 684 2
68e 690 3 68c
68d 692 2 69b
69d 2 69a 69f
1 6a1 1 6a3
3 6aa 6ab 6ac
3 685 6a4 6ae
1 6b0 2 636
6b1 4 6b4 4c9
5a9 6b3 2 6b7
6b8 1 6bc 2
6ba 6bc 1 6ee
2 6ed 6ee 1
6f6 1 6fc 2
6fe 6ff 2 6eb
700 2 711 713
3 70f 710 715
2 71e 720 2
722 724 2 726
728 2 72a 72c
2 72e 730 3
735 736 737 2
732 739 2 71d
73b 1 73d 1
73f 2 708 740
1 744 1 703
1 748 1 761
2 760 761 1
769 1 76f 2
771 772 2 75e
773 2 784 786
3 782 783 788
2 791 793 2
795 797 2 799
79b 2 79d 79f
2 7a1 7a3 3
7a8 7a9 7aa 2
7a5 7ac 2 790
7ae 1 7b0 1
7b2 2 77b 7b3
1 7b7 1 776
1 7bb 2 8f8
8fa 3 8f6 8f7
8fc 2 905 907
2 904 909 1
90b 1 90d 9
6c3 6c8 74b 751
756 7be 8ee 90e
911 2 915 916
1 91a 2 918
91a 2 91f 920
1 924 2 922
924 1 95d 2
95c 95d 1 965
1 96b 2 96d
96e 2 95a 96f
2 980 982 3
97e 97f 984 2
98d 98f 2 991
993 2 995 997
2 999 99b 2
99d 99f 3 9a4
9a5 9a6 2 9a1
9a8 2 98c 9aa
1 9ac 1 9ae
2 977 9af 1
9b3 1 972 1
9b7 1 9f4 2
9f3 9f4 1 9fc
1 a02 2 a04
a05 2 9f1 a06
2 a17 a19 3
a15 a16 a1b 2
a24 a26 2 a28
a2a 2 a2c a2e
2 a30 a32 2
a34 a36 3 a3b
a3c a3d 2 a38
a3f 2 a23 a41
1 a43 1 a45
2 a0e a46 1
a4a 1 a09 1
a4e 2 aa7 aa9
3 aa5 aa6 aab
2 ab4 ab6 2
ab3 ab8 1 aba
1 abc 8 92e
933 9ba 9c2 a51
a9d abd ac0 2
ac5 ac6 1 aca
2 ac8 aca 2
b65 b67 3 b63
b64 b69 2 b72
b74 2 b71 b76
1 b78 1 b7a
3 b5b b7b b7e
2 b83 b84 1
b88 2 b86 b88
2 b8d b8e 1
b90 1 b94 2
b92 b94 2 ba1
ba6 2 bb7 bb9
3 bb5 bb6 bbb
2 bc4 bc6 2
bc8 bca 2 bcc
bce 2 bd0 bd2
2 bd4 bd6 3
bdb bdc bdd 2
bd8 bdf 2 bc3
be1 1 be3 1
be5 2 bae be6
1 bea 1 ba9
1 bee 2 bf4
bf5 1 bf9 2
bf7 bf9 1 bfe
2 c09 c0e 2
c1f c21 3 c1d
c1e c23 2 c2c
c2e 2 c30 c32
2 c34 c36 2
c38 c3a 2 c3c
c3e 3 c43 c44
c45 2 c40 c47
2 c2b c49 1
c4b 1 c4d 2
c16 c4e 1 c52
1 c11 1 c56
2 c5c c5d 1
c61 2 c5f c61
2 c80 c85 2
c96 c98 3 c94
c95 c9a 2 ca3
ca5 2 ca7 ca9
2 cab cad 2
caf cb1 2 cb3
cb5 3 cba cbb
cbc 2 cb7 cbe
2 ca2 cc0 1
cc2 1 cc4 2
c8d cc5 1 cc9
1 c88 1 ccd
2 cd3 cd4 1
cd8 2 cd6 cd8
1 cdd 1 ce1
2 ce3 ce4 2
cd0 ce5 1 ce9
2 ceb cec 2
c59 ced 2 cef
cf0 2 ef4 ef6
3 ef2 ef3 ef8
2 f01 f03 2
f00 f05 1 f07
1 f09 6 b99
bf1 cf1 eea f0a
f0d 2 1037 1039
3 1035 1036 103b
2 1044 1046 2
1043 1048 1 104a
1 104c 3 102d
104d 1050 2 1052
1053 1 1054 2
1059 105a 1 105e
2 105c 105e 1
1095 2 1094 1095
1 109d 1 10a3
2 10a5 10a6 2
1092 10a7 2 10b8
10ba 3 10b6 10b7
10bc 2 10c5 10c7
2 10c9 10cb 2
10cd 10cf 2 10d1
10d3 2 10d5 10d7
3 10dc 10dd 10de
2 10d9 10e0 2
10c4 10e2 1 10e4
1 10e6 2 10af
10e7 1 10eb 1
10aa 1 10ef 1
1133 2 1132 1133
1 113b 1 1141
2 1143 1144 2
1130 1145 2 1156
1158 3 1154 1155
115a 2 1163 1165
2 1167 1169 2
116b 116d 2 116f
1171 2 1173 1175
3 117a 117b 117c
2 1177 117e 2
1162 1180 1 1182
1 1184 2 114d
1185 1 1189 1
1148 1 118d 2
11e9 11eb 3 11e7
11e8 11ed 2 11f6
11f8 2 11f5 11fa
1 11fc 1 11fe
8 1065 106a 10f2
10fa 1190 11df 11ff
1202 2 1207 1208
1 120c 2 120a
120c 1 1243 2
1242 1243 1 124b
1 1251 2 1253
1254 2 1240 1255
2 1266 1268 3
1264 1265 126a 2
1273 1275 2 1277
1279 2 127b 127d
2 127f 1281 2
1283 1285 3 128a
128b 128c 2 1287
128e 2 1272 1290
1 1292 1 1294
2 125d 1295 1
1299 1 1258 1
129d 1 130e 2
130d 130e 1 1316
1 131c 2 131e
131f 2 130b 1320
2 1331 1333 3
132f 1330 1335 2
133e 1340 2 1342
1344 2 1346 1348
2 134a 134c 2
134e 1350 3 1355
1356 1357 2 1352
1359 2 133d 135b
1 135d 1 135f
2 1328 1360 1
1364 1 1323 1
1368 2 13e2 13e4
3 13e0 13e1 13e6
2 13ef 13f1 2
13ee 13f3 1 13f5
1 13f7 8 1213
1218 12a0 12a8 136b
13d8 13f8 13fb 2
1400 1401 1 1405
2 1403 1405 2
14f5 14f7 3 14f3
14f4 14f9 2 1502
1504 2 1501 1506
1 1508 1 150a
3 14eb 150b 150e
2 1513 1514 1
1518 2 1516 1518
1 1557 2 1556
1557 1 155f 1
1565 2 1567 1568
2 1554 1569 2
157a 157c 3 1578
1579 157e 2 1587
1589 2 158b 158d
2 158f 1591 2
1593 1595 2 1597
1599 3 159e 159f
15a0 2 159b 15a2
2 1586 15a4 1
15a6 1 15a8 2
1571 15a9 1 15ad
1 156c 1 15b1
1 1634 2 1633
1634 1 163c 1
1642 2 1644 1645
2 1631 1646 2
1657 1659 3 1655
1656 165b 2 1664
1666 2 1668 166a
2 166c 166e 2
1670 1672 2 1674
1676 3 167b 167c
167d 2 1678 167f
2 1663 1681 1
1683 1 1685 2
164e 1686 1 168a
1 1649 1 168e
1 16a6 2 16a5
16a6 1 16ae 1
16b4 2 16b6 16b7
2 16a3 16b8 2
16c9 16cb 3 16c7
16c8 16cd 2 16d6
16d8 2 16da 16dc
2 16de 16e0 2
16e2 16e4 2 16e6
16e8 3 16ed 16ee
16ef 2 16ea 16f1
2 16d5 16f3 1
16f5 1 16f7 2
16c0 16f8 1 16fc
1 16bb 1 1700
2 17e5 17e7 3
17e3 17e4 17e9 2
17f2 17f4 2 17f1
17f6 1 17f8 1
17fa a 151f 1524
15b4 15ba 15bf 1691
1703 17db 17fb 17fe
2 1803 1804 1
180a 2 1806 180a
2 1812 1817 2
1828 182a 3 1826
1827 182c 2 1835
1837 2 1839 183b
2 183d 183f 2
1841 1843 2 1845
1847 3 184c 184d
184e 2 1849 1850
2 1834 1852 1
1854 1 1856 2
181f 1857 1 185b
1 181a 1 185f
1 186a 2 1866
186a 2 1913 1915
3 1911 1912 1917
2 1920 1922 2
191f 1924 1 1926
1 1928 3 1909
1929 192c 1 192e
2 1862 192f 2
1934 1935 1 1939
2 1937 1939 2
1a85 1a87 3 1a83
1a84 1a89 2 1a92
1a94 2 1a91 1a96
1 1a98 1 1a9a
3 1a7b 1a9b 1a9e
2 1aa3 1aa4 1
1aa8 2 1aa6 1aa8
2 1b4a 1b4c 3
1b48 1b49 1b4e 2
1b57 1b59 2 1b56
1b5b 1 1b5d 1
1b5f 3 1b40 1b60
1b63 2 1b68 1b69
1 1b6d 2 1b6b
1b6d 1 1b8d 2
1b8c 1b8d 1 1b95
1 1b9b 2 1b9d
1b9e 2 1b8a 1b9f
2 1bb0 1bb2 3
1bae 1baf 1bb4 2
1bbd 1bbf 2 1bc1
1bc3 2 1bc5 1bc7
2 1bc9 1bcb 2
1bcd 1bcf 3 1bd4
1bd5 1bd6 2 1bd1
1bd8 2 1bbc 1bda
1 1bdc 1 1bde
2 1ba7 1bdf 1
1be3 1 1ba2 1
1be7 1 1c07 2
1c06 1c07 1 1c0f
1 1c15 2 1c17
1c18 2 1c04 1c19
2 1c2a 1c2c 3
1c28 1c29 1c2e 2
1c37 1c39 2 1c3b
1c3d 2 1c3f 1c41
2 1c43 1c45 2
1c47 1c49 3 1c4e
1c4f 1c50 2 1c4b
1c52 2 1c36 1c54
1 1c56 1 1c58
2 1c21 1c59 1
1c5d 1 1c1c 1
1c61 1 1c99 2
1c98 1c99 1 1ca1
1 1ca7 2 1ca9
1caa 2 1c96 1cab
2 1cbc 1cbe 3
1cba 1cbb 1cc0 2
1cc9 1ccb 2 1ccd
1ccf 2 1cd1 1cd3
2 1cd5 1cd7 2
1cd9 1cdb 3 1ce0
1ce1 1ce2 2 1cdd
1ce4 2 1cc8 1ce6
1 1ce8 1 1cea
2 1cb3 1ceb 1
1cef 1 1cae 1
1cf3 2 1d6f 1d71
3 1d6d 1d6e 1d73
2 1d7c 1d7e 2
1d7b 1d80 1 1d82
1 1d84 c 1b74
1b79 1bea 1bf0 1bf5
1c64 1c6a 1c6f 1cf6
1d65 1d85 1d88 2
1d8d 1d8e 1 1d92
2 1d90 1d92 2
1dba 1dbc 3 1db8
1db9 1dbe 2 1dc7
1dc9 2 1dc6 1dcb
1 1dcd 1 1dcf
3 1db0 1dd0 1dd3
2 1dd8 1dd9 1
1ddf 2 1ddb 1ddf
2 1de4 1de5 1
1deb 2 1de7 1deb
2 1e16 1e18 3
1e14 1e15 1e1a 2
1e23 1e25 2 1e22
1e27 1 1e29 1
1e2b 3 1e0c 1e2c
1e2f 2 1e3a 1e3c
3 1e38 1e39 1e3e
2 1e47 1e49 2
1e4b 1e4d 2 1e4f
1e51 1 1e59 2
1e5b 1e5c 2 1e53
1e5e 2 1e60 1e62
2 1e64 1e66 2
1e68 1e6a 2 1e6c
1e6e 2 1e46 1e70
1 1e72 1 1e74
3 1e7b 1e7c 1e7d
2 1e75 1e7f f
1e81 ac3 b81 1057
1205 13fe 1511 1801
1932 1aa1 1b66 1d8b
1dd6 1e31 1e82 8
122 141 1b6 1b9
1bc 1bf 6b5 1e83
2 1e90 1e92 3
1e8e 1e8f 1e94 2
1e9d 1e9f 2 1e9c
1ea1 2 1ea8 1eac
2 1eae 1eb0 2
1eb2 1eb6 2 1ea7
1eb8 2 1ea3 1eba
1 1ebc 3 1ebd
1ec8 1ecc 1 1e87
2 1edf 1ee1 3
1edd 1ede 1ee3 2
1eec 1eee 2 1eeb
1ef0 2 1ef7 1ef9
2 1efb 1efd 3
1f02 1f03 1f04 2
1eff 1f06 2 1ef6
1f08 2 1ef2 1f0a
1 1f0c 4 1ed6
1f0d 1f16 1f1a 1
1f1e 1 1ed1 2
1ecf 1f22 1c 1b
22 29 30 37
3e 44 4a 50
56 5c 62 69
70 77 7e 85
8c 93 9a a1
a8 af b6 bd
c4 cb d2 
1
4
0 
1f29
0
1
50
34
20
0 1 2 1 4 1 6 1
8 1 a 1 c 1 e 1
10 1 12 1 14 1 16 1
18 1 1a 1 1c 1 1e 1
20 1 22 1 24 1 26 1
28 1 2a 1 2c 1 2e 1
30 1 32 1 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0

c6 1 0
b 1 0
bf 1 0
52 1 0
2 0 1
64 1 0
6b 1 0
72 1 0
58 1 0
80 1 0
4c 1 0
87 1 0
8e 1 0
95 1 0
9c 1 0
a3 1 0
3 1 0
aa 1 0
b1 1 0
b8 1 0
79 1 0
40 1 0
1d 1 0
16 1 0
5e 1 0
39 1 0
32 1 0
2b 1 0
46 1 0
7 1 0
24 1 0
cd 1 0
0

/
SHOW ERRORS FUNCTION SP_S_PROFILE;
ALTER FUNCTION SP_S_PROFILE COMPILE DEBUG;
/*********************************************************************************************************************************************/
Prompt == FUNCTION FC_U_NAMES ==
CREATE OR REPLACE FUNCTION FC_U_NAMES wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
6e
2 :e:
1FUNCTION:
1FC_U_NAMES:
1A_ELEMENT_ID:
1OUT:
1NOCOPY:
1VARCHAR2:
1H_FULL_NAME:
1A_PARTICIPANT_ID:
1SH_H_TABLE_TYPE:
1PLS_INTEGER:
1RETURN:
1H_TABLE_TYPE:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= FC_U_NAMES(:
1':
1, :
1COALESCE:
1TO_CHAR:
1NULL:
1);:
1CHECK_TRACE:
11:
119:
1+:
1FPUT:
1               ENTER:: FC_U_NAMES(20) :: cplan.sql(13636) :: :
1PMO_CNST:
1SC_TABLE_SCD:
1TMT_ASSIGNED_SCORECARDS:
1ASSIGN_NAMES:
1INSTR:
1REPLACE:
1LENGTH:
1ELEMENT_ID:
1UPDATE TMT_ASSIGNED_SCORECARDS SET ASSIGN_NAMES =:n            CASE:n        +
1    WHEN InStr( ASSIGN_NAMES, h_full_name || ';') > 0:n            THEN h_ful+
1l_name || ';' || REPLACE( ASSIGN_NAMES, h_full_name || ';', ''):n            +
1ELSE:n            CASE:n            WHEN LENGTH(h_full_name) + LENGTH(ASSIGN_+
1NAMES) > 2040 THEN ASSIGN_NAMES:n            ELSE h_full_name || ';' || ASSIG+
1N_NAMES:n            END:n            END:n            WHERE ELEMENT_ID = a_e+
1lement_id:
1FOUND:
1TRUE:
1=:
1PMO_DB2M:
1SC_STATE:
10:
1100:
1OTHERS:
1SQLCODE:
116:
146:
1           EXCEPTION:: FC_U_NAMES(47) :: cplan.sql(13663) :: :
1 :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1SC_TABLE_POL:
1TMT_POOLS:
1MANAGER_ID:
1UPDATE TMT_POOLS SET MANAGER_ID = a_participant_id, ASSIGN_NAMES =:n         +
1   CASE:n            WHEN InStr( ASSIGN_NAMES, h_full_name || ';') > 0:n     +
1       THEN h_full_name || ';' || REPLACE( ASSIGN_NAMES, h_full_name || ';', +
1''):n            ELSE:n            CASE:n            WHEN LENGTH(h_full_name)+
1 + LENGTH(ASSIGN_NAMES) > 2040 THEN ASSIGN_NAMES:n            ELSE h_full_nam+
1e || ';' || ASSIGN_NAMES:n            END:n            END:n            WHERE+
1 ELEMENT_ID = a_element_id:
176:
1           EXCEPTION:: FC_U_NAMES(77) :: cplan.sql(13693) :: :
1SC_TABLE_CRI:
1TMT_CRI:
1UPDATE TMT_CRI SET ASSIGN_NAMES =:n            CASE:n            WHEN InStr( +
1ASSIGN_NAMES, h_full_name || ';') > 0:n            THEN h_full_name || ';' ||+
1 REPLACE( ASSIGN_NAMES, h_full_name || ';', ''):n            ELSE:n          +
1  CASE:n            WHEN LENGTH(h_full_name) + LENGTH(ASSIGN_NAMES) > 2040 TH+
1EN ASSIGN_NAMES:n            ELSE h_full_name || ';' || ASSIGN_NAMES:n       +
1     END:n            END:n            WHERE ELEMENT_ID = a_element_id:
1105:
1           EXCEPTION:: FC_U_NAMES(106) :: cplan.sql(13722) :: :
1SC_TABLE_DOC:
1TMT_DOCUMENTS:
1UPDATE TMT_DOCUMENTS SET ASSIGN_NAMES =:n            CASE:n            WHEN I+
1nStr( ASSIGN_NAMES, h_full_name || ';') > 0:n            THEN h_full_name || +
1';' || REPLACE( ASSIGN_NAMES, h_full_name || ';', ''):n            ELSE:n    +
1        CASE:n            WHEN LENGTH(h_full_name) + LENGTH(ASSIGN_NAMES) > 2+
1040 THEN ASSIGN_NAMES:n            ELSE h_full_name || ';' || ASSIGN_NAMES:n +
1           END:n            END:n            WHERE ELEMENT_ID = a_element_id:
1135:
1           EXCEPTION:: FC_U_NAMES(136) :: cplan.sql(13752) :: :
1SC_TABLE_POL_DOC:
1TMT_POOL_DOCUMENTS:
1UPDATE TMT_POOL_DOCUMENTS SET ASSIGN_NAMES =:n            CASE:n            W+
1HEN InStr( ASSIGN_NAMES, h_full_name || ';') > 0:n            THEN h_full_nam+
1e || ';' || REPLACE( ASSIGN_NAMES, h_full_name || ';', ''):n            ELSE+
1:n            CASE:n            WHEN LENGTH(h_full_name) + LENGTH(ASSIGN_NAME+
1S) > 2040 THEN ASSIGN_NAMES:n            ELSE h_full_name || ';' || ASSIGN_NA+
1MES:n            END:n            END:n            WHERE ELEMENT_ID = a_eleme+
1nt_id:
1165:
1           EXCEPTION:: FC_U_NAMES(166) :: cplan.sql(13782) :: :
1SC_TABLE_RES_DOC:
1TMT_RESOURCE_DOCUMENTS:
1UPDATE TMT_RESOURCE_DOCUMENTS SET ASSIGN_NAMES =:n            CASE:n         +
1   WHEN InStr( ASSIGN_NAMES, h_full_name || ';') > 0:n            THEN h_full+
1_name || ';' || REPLACE( ASSIGN_NAMES, h_full_name || ';', ''):n            E+
1LSE:n            CASE:n            WHEN LENGTH(h_full_name) + LENGTH(ASSIGN_N+
1AMES) > 2040 THEN ASSIGN_NAMES:n            ELSE h_full_name || ';' || ASSIGN+
1_NAMES:n            END:n            END:n            WHERE ELEMENT_ID = a_el+
1ement_id:
1195:
1           EXCEPTION:: FC_U_NAMES(196) :: cplan.sql(13812) :: :
1SC_TABLE_AST_DOC:
1TMT_ASSET_DOCUMENTS:
1UPDATE TMT_ASSET_DOCUMENTS SET ASSIGN_NAMES =:n            CASE:n            +
1WHEN InStr( ASSIGN_NAMES, h_full_name || ';') > 0:n            THEN h_full_na+
1me || ';' || REPLACE( ASSIGN_NAMES, h_full_name || ';', ''):n            ELSE+
1:n            CASE:n            WHEN LENGTH(h_full_name) + LENGTH(ASSIGN_NAME+
1S) > 2040 THEN ASSIGN_NAMES:n            ELSE h_full_name || ';' || ASSIGN_NA+
1MES:n            END:n            END:n            WHERE ELEMENT_ID = a_eleme+
1nt_id:
1225:
1           EXCEPTION:: FC_U_NAMES(226) :: cplan.sql(13842) :: :
1SC_TABLE_CLN_DOC:
1TMT_CLIENT_DOCUMENTS:
1UPDATE TMT_CLIENT_DOCUMENTS SET ASSIGN_NAMES =:n            CASE:n           +
1 WHEN InStr( ASSIGN_NAMES, h_full_name || ';') > 0:n            THEN h_full_n+
1ame || ';' || REPLACE( ASSIGN_NAMES, h_full_name || ';', ''):n            ELS+
1E:n            CASE:n            WHEN LENGTH(h_full_name) + LENGTH(ASSIGN_NAM+
1ES) > 2040 THEN ASSIGN_NAMES:n            ELSE h_full_name || ';' || ASSIGN_N+
1AMES:n            END:n            END:n            WHERE ELEMENT_ID = a_elem+
1ent_id:
1255:
1           EXCEPTION:: FC_U_NAMES(256) :: cplan.sql(13872) :: :
1SC_TABLE_VDR_DOC:
1TMT_VENDOR_DOCUMENTS:
1UPDATE TMT_VENDOR_DOCUMENTS SET ASSIGN_NAMES =:n            CASE:n           +
1 WHEN InStr( ASSIGN_NAMES, h_full_name || ';') > 0:n            THEN h_full_n+
1ame || ';' || REPLACE( ASSIGN_NAMES, h_full_name || ';', ''):n            ELS+
1E:n            CASE:n            WHEN LENGTH(h_full_name) + LENGTH(ASSIGN_NAM+
1ES) > 2040 THEN ASSIGN_NAMES:n            ELSE h_full_name || ';' || ASSIGN_N+
1AMES:n            END:n            END:n            WHERE ELEMENT_ID = a_elem+
1ent_id:
1285:
1           EXCEPTION:: FC_U_NAMES(286) :: cplan.sql(13902) :: :
1TMT_WBS:
1UPDATE TMT_WBS SET ASSIGN_NAMES =:n            CASE:n            WHEN InStr( +
1ASSIGN_NAMES, h_full_name || ';') > 0:n            THEN h_full_name || ';' ||+
1 REPLACE( ASSIGN_NAMES, h_full_name || ';', ''):n            ELSE:n          +
1  CASE:n            WHEN LENGTH(h_full_name) + LENGTH(ASSIGN_NAMES) > 2040 TH+
1EN ASSIGN_NAMES:n            ELSE h_full_name || ';' || ASSIGN_NAMES:n       +
1     END:n            END:n            WHERE ELEMENT_ID = a_element_id:
1315:
1           EXCEPTION:: FC_U_NAMES(316) :: cplan.sql(13932) :: :
1323:
1                EXIT:: FC_U_NAMES(324) :: cplan.sql(13940) :: :
1STATE:: :
0

0
0
5a2
2
0 a0 8d 90 :3 a0 b0 3f 90
:3 a0 b0 3f 90 :3 a0 b0 3f 8f
a0 b0 3d b4 :2 a0 2c 6a a3
a0 1c a0 81 b0 :2 a0 6b :2 a0
6b 6e a5 b a 10 :2 a0 6b
6e :2 a0 6b 6e a5 b 6e 7e
a0 b4 2e 6e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :3 a0 a5 b
6e a5 b b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :3 a0 6b :12 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 a6 9 :2 a0
6b :14 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 a6 9 :2 a0 6b :12 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 a6 9 :2 a0 6b :12 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 a6
9 :2 a0 6b :12 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 a6 9 :2 a0
6b :12 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 a6 9 :2 a0 6b :12 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 a6 9 :2 a0 6b :12 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 a6
9 :2 a0 6b :12 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 a6 9 :12 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 9 a4 14 :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :2 a0 6b b4 2e a5
57 b7 19 3c :3 a0 6b 65 b7
a4 b1 11 68 4f 1d 17 b5 
5a2
2
0 3 7 2b 1f 23 27 1e
32 47 3b 3f 43 1b 4e 5f
53 57 5b 3a 66 73 6f 37
7b 6e 80 84 88 8c a9 94
98 a0 a4 6b 90 b0 b4 b7
bb bf c2 c7 c8 1 ca cf
d3 d7 da df e3 e7 ea ef
f0 f2 f7 fa fe ff 104 109
10c 111 112 117 11a 11e 11f 124
127 12c 12d 132 135 13a 13b 140
143 148 149 14e 151 155 156 15b
15e 163 164 169 16c 171 172 177
17a 17f 180 185 188 18c 18d 192
195 19a 19b 1a0 1a3 1a8 1a9 1ae
1b1 1b5 1b9 1bd 1be 1c0 1c5 1c6
1c8 1c9 1ce 1d1 1d6 1d7 1dc 1dd
1e2 1e4 1e8 1eb 1ef 1f3 1f6 1fa
1fe 201 204 209 20c 20f 212 213
218 219 1 21b 220 224 228 22b
230 235 238 23c 23d 242 243 248
24a 24e 251 255 259 25d 260 264
268 26c 270 274 278 27c 280 284
288 28c 290 294 298 29c 2a0 2a4
2a8 2b4 2b8 2bd 2c1 2c4 2c5 2ca
2ce 2d2 2d5 2d8 2dc 2de 2e2 2e6
2e9 2ec 2f0 2f2 2f6 2fa 2fd 2ff
1 303 307 30b 30e 312 316 31a
31e 321 325 329 32c 32f 334 337
33a 33d 33e 343 344 1 346 34b
34f 353 356 35b 360 363 367 368
36d 370 375 376 37b 37e 383 384
389 38c 390 391 396 399 39e 39f
3a4 3a7 3ab 3af 3b2 3b5 3b6 3b8
3b9 3be 3bf 3c4 3c6 3ca 3cd 3cf
3d3 3d5 3e1 3e3 3e5 3e6 3eb 3ef
3f1 3fd 3ff 401 402 407 40b 40f
412 416 41a 41e 422 426 42a 42e
432 436 43a 43e 442 446 44a 44e
452 456 45a 45e 462 46e 472 477
47b 47e 47f 484 488 48c 48f 492
496 498 49c 4a0 4a3 4a6 4aa 4ac
4b0 4b4 4b7 4b9 1 4bd 4c1 4c5
4c8 4cc 4d0 4d4 4d8 4db 4df 4e3
4e6 4e9 4ee 4f1 4f4 4f7 4f8 4fd
4fe 1 500 505 509 50d 510 515
51a 51d 521 522 527 52a 52f 530
535 538 53d 53e 543 546 54a 54b
550 553 558 559 55e 561 565 569
56c 56f 570 572 573 578 579 57e
580 584 587 589 58d 58f 59b 59d
59f 5a0 5a5 5a9 5ab 5b7 5b9 5bb
5bc 5c1 5c5 5c9 5cc 5d0 5d4 5d8
5dc 5e0 5e4 5e8 5ec 5f0 5f4 5f8
5fc 600 604 608 60c 610 614 620
624 629 62d 630 631 636 63a 63e
641 644 648 64a 64e 652 655 658
65c 65e 662 666 669 66b 1 66f
673 677 67a 67e 682 686 68a 68d
691 695 698 69b 6a0 6a3 6a6 6a9
6aa 6af 6b0 1 6b2 6b7 6bb 6bf
6c2 6c7 6cc 6cf 6d3 6d4 6d9 6dc
6e1 6e2 6e7 6ea 6ef 6f0 6f5 6f8
6fc 6fd 702 705 70a 70b 710 713
717 71b 71e 721 722 724 725 72a
72b 730 732 736 739 73b 73f 741
74d 74f 751 752 757 75b 75d 769
76b 76d 76e 773 777 77b 77e 782
786 78a 78e 792 796 79a 79e 7a2
7a6 7aa 7ae 7b2 7b6 7ba 7be 7c2
7c6 7d2 7d6 7db 7df 7e2 7e3 7e8
7ec 7f0 7f3 7f6 7fa 7fc 800 804
807 80a 80e 810 814 818 81b 81d
1 821 825 829 82c 830 834 838
83c 83f 843 847 84a 84d 852 855
858 85b 85c 861 862 1 864 869
86d 871 874 879 87e 881 885 886
88b 88e 893 894 899 89c 8a1 8a2
8a7 8aa 8ae 8af 8b4 8b7 8bc 8bd
8c2 8c5 8c9 8cd 8d0 8d3 8d4 8d6
8d7 8dc 8dd 8e2 8e4 8e8 8eb 8ed
8f1 8f3 8ff 901 903 904 909 90d
90f 91b 91d 91f 920 925 929 92d
930 934 938 93c 940 944 948 94c
950 954 958 95c 960 964 968 96c
970 974 978 984 988 98d 991 994
995 99a 99e 9a2 9a5 9a8 9ac 9ae
9b2 9b6 9b9 9bc 9c0 9c2 9c6 9ca
9cd 9cf 1 9d3 9d7 9db 9de 9e2
9e6 9ea 9ee 9f1 9f5 9f9 9fc 9ff
a04 a07 a0a a0d a0e a13 a14 1
a16 a1b a1f a23 a26 a2b a30 a33
a37 a38 a3d a40 a45 a46 a4b a4e
a53 a54 a59 a5c a60 a61 a66 a69
a6e a6f a74 a77 a7b a7f a82 a85
a86 a88 a89 a8e a8f a94 a96 a9a
a9d a9f aa3 aa5 ab1 ab3 ab5 ab6
abb abf ac1 acd acf ad1 ad2 ad7
adb adf ae2 ae6 aea aee af2 af6
afa afe b02 b06 b0a b0e b12 b16
b1a b1e b22 b26 b2a b36 b3a b3f
b43 b46 b47 b4c b50 b54 b57 b5a
b5e b60 b64 b68 b6b b6e b72 b74
b78 b7c b7f b81 1 b85 b89 b8d
b90 b94 b98 b9c ba0 ba3 ba7 bab
bae bb1 bb6 bb9 bbc bbf bc0 bc5
bc6 1 bc8 bcd bd1 bd5 bd8 bdd
be2 be5 be9 bea bef bf2 bf7 bf8
bfd c00 c05 c06 c0b c0e c12 c13
c18 c1b c20 c21 c26 c29 c2d c31
c34 c37 c38 c3a c3b c40 c41 c46
c48 c4c c4f c51 c55 c57 c63 c65
c67 c68 c6d c71 c73 c7f c81 c83
c84 c89 c8d c91 c94 c98 c9c ca0
ca4 ca8 cac cb0 cb4 cb8 cbc cc0
cc4 cc8 ccc cd0 cd4 cd8 cdc ce8
cec cf1 cf5 cf8 cf9 cfe d02 d06
d09 d0c d10 d12 d16 d1a d1d d20
d24 d26 d2a d2e d31 d33 1 d37
d3b d3f d42 d46 d4a d4e d52 d55
d59 d5d d60 d63 d68 d6b d6e d71
d72 d77 d78 1 d7a d7f d83 d87
d8a d8f d94 d97 d9b d9c da1 da4
da9 daa daf db2 db7 db8 dbd dc0
dc4 dc5 dca dcd dd2 dd3 dd8 ddb
ddf de3 de6 de9 dea dec ded df2
df3 df8 dfa dfe e01 e03 e07 e09
e15 e17 e19 e1a e1f e23 e25 e31
e33 e35 e36 e3b e3f e43 e46 e4a
e4e e52 e56 e5a e5e e62 e66 e6a
e6e e72 e76 e7a e7e e82 e86 e8a
e8e e9a e9e ea3 ea7 eaa eab eb0
eb4 eb8 ebb ebe ec2 ec4 ec8 ecc
ecf ed2 ed6 ed8 edc ee0 ee3 ee5
1 ee9 eed ef1 ef4 ef8 efc f00
f04 f07 f0b f0f f12 f15 f1a f1d
f20 f23 f24 f29 f2a 1 f2c f31
f35 f39 f3c f41 f46 f49 f4d f4e
f53 f56 f5b f5c f61 f64 f69 f6a
f6f f72 f76 f77 f7c f7f f84 f85
f8a f8d f91 f95 f98 f9b f9c f9e
f9f fa4 fa5 faa fac fb0 fb3 fb5
fb9 fbb fc7 fc9 fcb fcc fd1 fd5
fd7 fe3 fe5 fe7 fe8 fed ff1 ff5
ff8 ffc 1000 1004 1008 100c 1010 1014
1018 101c 1020 1024 1028 102c 1030 1034
1038 103c 1040 104c 1050 1055 1059 105c
105d 1062 1066 106a 106d 1070 1074 1076
107a 107e 1081 1084 1088 108a 108e 1092
1095 1097 1 109b 109f 10a3 10a6 10aa
10ae 10b2 10b6 10b9 10bd 10c1 10c4 10c7
10cc 10cf 10d2 10d5 10d6 10db 10dc 1
10de 10e3 10e7 10eb 10ee 10f3 10f8 10fb
10ff 1100 1105 1108 110d 110e 1113 1116
111b 111c 1121 1124 1128 1129 112e 1131
1136 1137 113c 113f 1143 1147 114a 114d
114e 1150 1151 1156 1157 115c 115e 1162
1165 1167 116b 116d 1179 117b 117d 117e
1183 1187 1189 1195 1197 1199 119a 119f
11a3 11a7 11ab 11af 11b3 11b7 11bb 11bf
11c3 11c7 11cb 11cf 11d3 11d7 11db 11df
11e3 11e7 11f3 11f7 11fc 1200 1203 1204
1209 120d 1211 1214 1217 121b 121d 1221
1225 1228 122b 122f 1231 1235 1239 123c
123e 1 1242 1246 124a 124d 1251 1255
1259 125d 1260 1264 1268 126b 126e 1273
1276 1279 127c 127d 1282 1283 1 1285
128a 128e 1292 1295 129a 129f 12a2 12a6
12a7 12ac 12af 12b4 12b5 12ba 12bd 12c2
12c3 12c8 12cb 12cf 12d0 12d5 12d8 12dd
12de 12e3 12e6 12ea 12ee 12f1 12f4 12f5
12f7 12f8 12fd 12fe 1303 1305 1309 130c
130e 1312 1314 1320 1322 1324 1325 132a
132e 1330 133c 133e 1340 1345 1349 134e
1352 1356 1359 135d 1361 1364 1367 136c
136f 1372 1375 1376 137b 137c 1 137e
1383 1387 138b 138e 1393 1398 139b 139f
13a0 13a5 13a8 13ad 13ae 13b3 13b6 13bb
13bc 13c1 13c4 13c8 13cc 13cf 13d0 13d5
13d6 13db 13dd 13e1 13e4 13e8 13ec 13f0
13f3 13f7 13f9 13fd 13ff 140b 140f 1411
1412 141b 
5a2
2
0 1 a 6 16 1a 21 :3 6
15 19 20 :3 6 1a 1e 25 :3 6
16 :2 6 1 3 a :2 1 4 :2 11
20 11 4 7 :2 11 23 :2 2d 3a
:2 23 :3 7 :2 d 19 25 :2 2f 43 :2 25
52 58 5b :2 52 69 7d 8 :2 69
d 10 :2 69 1d 20 :2 69 b e
:2 69 13 16 :2 69 1b 1e :2 69 2a
2d :2 69 b e :2 69 13 16 :2 69
1b 1e :2 69 2f 32 :2 69 b e
:2 69 13 16 1f 27 :2 1f 39 :2 16
:2 69 41 44 :2 69 :2 7 48 :2 4 7
:2 11 23 :2 2d 39 3c 4a 4c 4d
:2 4a :2 23 :3 7 :2 d 12 1e 5b 5e
:2 1e :2 7 50 :2 4 9 c :2 15 14
30 12 19 27 12 28 31 3f
12 19 28 2f 49 12 28 13
20 d 14 10 1c :3 1a 10 :2 19
25 10 21 10 :2 19 25 10 :4 d
a :2 12 10 :2 19 25 10 13 :2 1d
2f :2 39 45 49 57 59 5a :2 57
:2 2f :3 13 :2 19 1e 2a 67 6a :2 2a
77 7a :2 2a 7e 81 :2 2a 8d 90
:2 2a 98 9b :2 2a a7 aa b1 ba
bd :2 aa :2 2a :2 13 5d :2 10 :2 d :4 19
:2 d a :4 22 :2 7 c :2 15 14 22
2f 41 12 19 27 12 28 31
3f 12 19 28 2f 49 12 28
13 20 d 14 10 1c :3 1a 10
:2 19 25 10 21 10 :2 19 25 10
:4 d a :2 12 10 :2 19 25 10 13
:2 1d 2f :2 39 45 49 57 59 5a
:2 57 :2 2f :3 13 :2 19 1e 2a 67 6a
:2 2a 77 7a :2 2a 7e 81 :2 2a 8d
90 :2 2a 98 9b :2 2a a7 aa b1
ba bd :2 aa :2 2a :2 13 5d :2 10 :2 d
:4 19 :2 d a :4 22 :2 7 c :2 15 14
20 12 19 27 12 28 31 3f
12 19 28 2f 49 12 28 13
20 d 14 10 1c :3 1a 10 :2 19
25 10 21 10 :2 19 25 10 :4 d
a :2 12 10 :2 19 25 10 13 :2 1d
2f :2 39 45 49 57 5a 5b :2 57
:2 2f :3 13 :2 19 1e 2a 68 6b :2 2a
78 7b :2 2a 7f 82 :2 2a 8e 91
:2 2a 99 9c :2 2a a8 ab b2 bb
be :2 ab :2 2a :2 13 5e :2 10 :2 d :4 19
:2 d a :4 22 :2 7 c :2 15 14 26
12 19 27 12 28 31 3f 12
19 28 2f 49 12 28 13 20
d 14 10 1c :3 1a 10 :2 19 25
10 21 10 :2 19 25 10 :4 d a
:2 12 10 :2 19 25 10 13 :2 1d 2f
:2 39 45 49 57 5a 5b :2 57 :2 2f
:3 13 :2 19 1e 2a 68 6b :2 2a 78
7b :2 2a 7f 82 :2 2a 8e 91 :2 2a
99 9c :2 2a a8 ab b2 bb be
:2 ab :2 2a :2 13 5e :2 10 :2 d :4 19 :2 d
a :4 22 :2 7 c :2 15 14 2b 12
19 27 12 28 31 3f 12 19
28 2f 49 12 28 13 20 d
14 10 1c :3 1a 10 :2 19 25 10
21 10 :2 19 25 10 :4 d a :2 12
10 :2 19 25 10 13 :2 1d 2f :2 39
45 49 57 5a 5b :2 57 :2 2f :3 13
:2 19 1e 2a 68 6b :2 2a 78 7b
:2 2a 7f 82 :2 2a 8e 91 :2 2a 99
9c :2 2a a8 ab b2 bb be :2 ab
:2 2a :2 13 5e :2 10 :2 d :4 19 :2 d a
:4 26 :2 7 c :2 15 14 2f 12 19
27 12 28 31 3f 12 19 28
2f 49 12 28 13 20 d 14
10 1c :3 1a 10 :2 19 25 10 21
10 :2 19 25 10 :4 d a :2 12 10
:2 19 25 10 13 :2 1d 2f :2 39 45
49 57 5a 5b :2 57 :2 2f :3 13 :2 19
1e 2a 68 6b :2 2a 78 7b :2 2a
7f 82 :2 2a 8e 91 :2 2a 99 9c
:2 2a a8 ab b2 bb be :2 ab :2 2a
:2 13 5e :2 10 :2 d :4 19 :2 d a :4 26
:2 7 c :2 15 14 2c 12 19 27
12 28 31 3f 12 19 28 2f
49 12 28 13 20 d 14 10
1c :3 1a 10 :2 19 25 10 21 10
:2 19 25 10 :4 d a :2 12 10 :2 19
25 10 13 :2 1d 2f :2 39 45 49
57 5a 5b :2 57 :2 2f :3 13 :2 19 1e
2a 68 6b :2 2a 78 7b :2 2a 7f
82 :2 2a 8e 91 :2 2a 99 9c :2 2a
a8 ab b2 bb be :2 ab :2 2a :2 13
5e :2 10 :2 d :4 19 :2 d a :4 26 :2 7
c :2 15 14 2d 12 19 27 12
28 31 3f 12 19 28 2f 49
12 28 13 20 d 14 10 1c
:3 1a 10 :2 19 25 10 21 10 :2 19
25 10 :4 d a :2 12 10 :2 19 25
10 13 :2 1d 2f :2 39 45 49 57
5a 5b :2 57 :2 2f :3 13 :2 19 1e 2a
68 6b :2 2a 78 7b :2 2a 7f 82
:2 2a 8e 91 :2 2a 99 9c :2 2a a8
ab b2 bb be :2 ab :2 2a :2 13 5e
:2 10 :2 d :4 19 :2 d a :4 26 :2 7 c
:2 15 14 2d 12 19 27 12 28
31 3f 12 19 28 2f 49 12
28 13 20 d 14 10 1c :3 1a
10 :2 19 25 10 21 10 :2 19 25
10 :4 d a :2 12 10 :2 19 25 10
13 :2 1d 2f :2 39 45 49 57 5a
5b :2 57 :2 2f :3 13 :2 19 1e 2a 68
6b :2 2a 78 7b :2 2a 7f 82 :2 2a
8e 91 :2 2a 99 9c :2 2a a8 ab
b2 bb be :2 ab :2 2a :2 13 5e :2 10
:2 d :4 19 :2 d a :4 26 :2 7 14 20
12 19 27 12 28 31 3f 12
19 28 2f 49 12 28 13 20
d 14 10 1c :3 1a 10 :2 19 25
10 21 10 :2 19 25 10 :4 d a
:2 12 10 :2 19 25 10 13 :2 1d 2f
:2 39 45 49 57 5a 5b :2 57 :2 2f
:3 13 :2 19 1e 2a 68 6b :2 2a 78
7b :2 2a 7f 82 :2 2a 8e 91 :2 2a
99 9c :2 2a a8 ab b2 bb be
:2 ab :2 2a :2 13 5e :2 10 :2 d :4 19 :2 d
a :4 7 :3 4 7 :2 11 23 :2 2d 39
3c 4a 4d 4e :2 4a :2 23 :3 7 :2 d
12 1e 5c 5f :2 1e 6c 6f :2 1e
73 76 :2 1e 80 83 :2 8c :2 1e :2 7
51 :3 4 b :2 14 4 :9 1 
5a2
4
0 :2 1 :6 3 :6 4
:6 5 :4 6 2 :2 7
:2 1 :6 9 :b b :11 c
d :2 c :2 d :2 c
:2 d :2 c :2 e :2 c
:2 e :2 c :2 e :2 c
:2 e :2 c :2 f :2 c
:2 f :2 c :2 f :2 c
:2 f :2 c :2 10 :2 c
:9 10 :2 c :2 10 :4 c
:3 b :11 13 :b 14 :3 13
17 :3 18 :2 1a :3 1c
:4 1d :5 20 :2 21 :2 24
1a :6 25 :5 26 25
:5 28 27 :3 25 19
:2 2b :5 2d :11 2e :24 2f
:3 2e :2 2c :6 2b 2a
:6 18 :3 36 :4 38 :3 3a
:4 3b :5 3e :2 3f :2 42
38 :6 43 :5 44 43
:5 46 45 :3 43 37
:2 49 :5 4b :11 4c :24 4d
:3 4c :2 4a :6 49 48
:6 36 :3 53 :2 55 :3 57
:4 58 :5 5b :2 5c :2 5f
55 :6 60 :5 61 60
:5 63 62 :3 60 54
:2 66 :5 68 :11 69 :24 6a
:3 69 :2 67 :6 66 65
:6 53 :3 71 :2 73 :3 75
:4 76 :5 79 :2 7a :2 7d
73 :6 7e :5 7f 7e
:5 81 80 :3 7e 72
:2 84 :5 86 :11 87 :24 88
:3 87 :2 85 :6 84 83
:6 71 :3 8f :2 91 :3 93
:4 94 :5 97 :2 98 :2 9b
91 :6 9c :5 9d 9c
:5 9f 9e :3 9c 90
:2 a2 :5 a4 :11 a5 :24 a6
:3 a5 :2 a3 :6 a2 a1
:6 8f :3 ad :2 af :3 b1
:4 b2 :5 b5 :2 b6 :2 b9
af :6 ba :5 bb ba
:5 bd bc :3 ba ae
:2 c0 :5 c2 :11 c3 :24 c4
:3 c3 :2 c1 :6 c0 bf
:6 ad :3 cb :2 cd :3 cf
:4 d0 :5 d3 :2 d4 :2 d7
cd :6 d8 :5 d9 d8
:5 db da :3 d8 cc
:2 de :5 e0 :11 e1 :24 e2
:3 e1 :2 df :6 de dd
:6 cb :3 e9 :2 eb :3 ed
:4 ee :5 f1 :2 f2 :2 f5
eb :6 f6 :5 f7 f6
:5 f9 f8 :3 f6 ea
:2 fc :5 fe :11 ff :24 100
:3 ff :2 fd :6 fc fb
:6 e9 :3 107 :2 109 :3 10b
:4 10c :5 10f :2 110 :2 113
109 :6 114 :5 115 114
:5 117 116 :3 114 108
:2 11a :5 11c :11 11d :24 11e
:3 11d :2 11b :6 11a 119
:6 107 :2 127 :3 129 :4 12a
:5 12d :2 12e :2 131 127
:6 132 :5 133 132 :5 135
134 :3 132 126 :2 138
:5 13a :11 13b :24 13c :3 13b
:2 139 :6 138 137 :4 125
:3 17 :11 143 :19 144 :3 143
:5 146 :2 a :7 1 
141d
4
:3 0 1 :3 0 2
:a 0 59d 1 :7 0
5 37 0 3
4 :3 0 5 :3 0
6 :3 0 3 :5 0
1 7 6 :3 0
9 6b 0 7
4 :3 0 5 :3 0
6 :3 0 7 :5 0
1 d c :3 0
4 :3 0 5 :3 0
6 :3 0 8 :5 0
1 13 12 :3 0
10 90 0 b
a :3 0 9 :7 0
17 16 :3 0 b
:3 0 a :3 0 19
1b 0 59d 2
1c :2 0 d :3 0
a :3 0 1f :7 0
9 :3 0 23 20
21 59b 0 c
:6 0 e :3 0 24
25 0 d :3 0
f :3 0 27 28
0 2 :4 0 12
29 2b 26 2d
2c :2 0 10 :3 0
11 :3 0 2f 30
0 12 :4 0 d
:3 0 13 :3 0 33
34 0 2 :4 0
14 35 37 14
:4 0 15 :2 0 16
:3 0 16 3a 3c
:3 0 17 :4 0 15
:2 0 18 :4 0 19
3f 41 :3 0 15
:2 0 3 :3 0 1c
43 45 :3 0 15
:2 0 18 :4 0 1f
47 49 :3 0 15
:2 0 19 :4 0 22
4b 4d :3 0 15
:2 0 18 :4 0 25
4f 51 :3 0 15
:2 0 7 :3 0 28
53 55 :3 0 15
:2 0 18 :4 0 2b
57 59 :3 0 15
:2 0 19 :4 0 2e
5b 5d :3 0 15
:2 0 18 :4 0 31
5f 61 :3 0 15
:2 0 8 :3 0 34
63 65 :3 0 15
:2 0 18 :4 0 37
67 69 :3 0 15
:2 0 19 :4 0 3a
6b 6d :3 0 15
:2 0 1a :3 0 1b
:3 0 9 :3 0 3d
71 73 1c :4 0
3f 70 76 42
6f 78 :3 0 15
:2 0 1d :4 0 45
7a 7c :3 0 48
31 7e :2 0 80
4d 81 2e 80
0 82 4f 0
599 d :3 0 e
:3 0 83 84 0
d :3 0 1e :3 0
86 87 0 1f
:2 0 2 :4 0 20
:2 0 21 :2 0 1f
:2 0 51 8c 8e
:3 0 54 88 90
85 92 91 :2 0
10 :3 0 22 :3 0
94 95 0 12
:4 0 23 :4 0 15
:2 0 16 :3 0 58
99 9b :3 0 5b
96 9d :2 0 9f
5e a0 93 9f
0 a1 60 0
599 c :3 0 24
:3 0 25 :3 0 a3
a4 0 26 :3 0
27 :3 0 28 :3 0
27 :3 0 7 :3 0
7 :3 0 29 :3 0
27 :3 0 7 :3 0
2a :3 0 7 :3 0
2a :3 0 27 :3 0
27 :3 0 7 :3 0
27 :3 0 2b :3 0
3 :4 0 2c 1
:8 0 ce 2d :4 0
b9 :3 0 2e :3 0
2f :2 0 64 bc
bd :3 0 30 :3 0
31 :3 0 bf c0
0 32 :2 0 c1
c2 0 c4 67
cb 30 :3 0 31
:3 0 c5 c6 0
33 :2 0 c7 c8
0 ca 69 cc
be c4 0 cd
0 ca 0 cd
6b 0 ce 6e
118 34 :3 0 30
:3 0 31 :3 0 d1
d2 0 35 :3 0
d3 d4 0 10e
d :3 0 e :3 0
d6 d7 0 d
:3 0 1e :3 0 d9
da 0 36 :2 0
2 :4 0 37 :2 0
21 :2 0 1f :2 0
71 df e1 :3 0
74 db e3 d8
e5 e4 :2 0 10
:3 0 22 :3 0 e7
e8 0 12 :4 0
38 :4 0 15 :2 0
16 :3 0 78 ec
ee :3 0 15 :2 0
39 :4 0 7b f0
f2 :3 0 15 :2 0
3a :4 0 7e f4
f6 :3 0 15 :2 0
35 :3 0 81 f8
fa :3 0 15 :2 0
3b :4 0 84 fc
fe :3 0 15 :2 0
3c :3 0 3d :3 0
1f :2 0 3e :2 0
87 101 105 8b
100 107 :3 0 8e
e9 109 :2 0 10b
91 10c e6 10b
0 10d 93 0
10e 95 111 :3 0
111 0 111 110
10e 10f :6 0 113
2 :3 0 98 115
9a 114 113 :2 0
116 9c :2 0 118
0 118 117 ce
116 :6 0 11a 1
:3 0 9e 11c a0
11b 11a :2 0 565
24 :3 0 3f :3 0
11d 11e 0 40
:3 0 41 :3 0 8
:3 0 27 :3 0 28
:3 0 27 :3 0 7
:3 0 7 :3 0 29
:3 0 27 :3 0 7
:3 0 2a :3 0 7
:3 0 2a :3 0 27
:3 0 27 :3 0 7
:3 0 27 :3 0 2b
:3 0 3 :4 0 42
1 :8 0 14a 2d
:4 0 135 :3 0 2e
:3 0 2f :2 0 a4
138 139 :3 0 30
:3 0 31 :3 0 13b
13c 0 32 :2 0
13d 13e 0 140
a7 147 30 :3 0
31 :3 0 141 142
0 33 :2 0 143
144 0 146 a9
148 13a 140 0
149 0 146 0
149 ab 0 14a
ae 194 34 :3 0
30 :3 0 31 :3 0
14d 14e 0 35
:3 0 14f 150 0
18a d :3 0 e
:3 0 152 153 0
d :3 0 1e :3 0
155 156 0 36
:2 0 2 :4 0 43
:2 0 21 :2 0 1f
:2 0 b1 15b 15d
:3 0 b4 157 15f
154 161 160 :2 0
10 :3 0 22 :3 0
163 164 0 12
:4 0 44 :4 0 15
:2 0 16 :3 0 b8
168 16a :3 0 15
:2 0 39 :4 0 bb
16c 16e :3 0 15
:2 0 3a :4 0 be
170 172 :3 0 15
:2 0 35 :3 0 c1
174 176 :3 0 15
:2 0 3b :4 0 c4
178 17a :3 0 15
:2 0 3c :3 0 3d
:3 0 1f :2 0 3e
:2 0 c7 17d 181
cb 17c 183 :3 0
ce 165 185 :2 0
187 d1 188 162
187 0 189 d3
0 18a d5 18d
:3 0 18d 0 18d
18c 18a 18b :6 0
18f 4 :3 0 d8
191 da 190 18f
:2 0 192 dc :2 0
194 0 194 193
14a 192 :6 0 196
1 :3 0 de 198
e0 197 196 :2 0
565 24 :3 0 45
:3 0 199 19a 0
46 :3 0 27 :3 0
28 :3 0 27 :3 0
7 :3 0 7 :3 0
29 :3 0 27 :3 0
7 :3 0 2a :3 0
7 :3 0 2a :3 0
27 :3 0 27 :3 0
7 :3 0 27 :3 0
2b :3 0 3 :4 0
47 1 :8 0 1c4
2d :4 0 1af :3 0
2e :3 0 2f :2 0
e4 1b2 1b3 :3 0
30 :3 0 31 :3 0
1b5 1b6 0 32
:2 0 1b7 1b8 0
1ba e7 1c1 30
:3 0 31 :3 0 1bb
1bc 0 33 :2 0
1bd 1be 0 1c0
e9 1c2 1b4 1ba
0 1c3 0 1c0
0 1c3 eb 0
1c4 ee 20e 34
:3 0 30 :3 0 31
:3 0 1c7 1c8 0
35 :3 0 1c9 1ca
0 204 d :3 0
e :3 0 1cc 1cd
0 d :3 0 1e
:3 0 1cf 1d0 0
36 :2 0 2 :4 0
48 :2 0 21 :2 0
1f :2 0 f1 1d5
1d7 :3 0 f4 1d1
1d9 1ce 1db 1da
:2 0 10 :3 0 22
:3 0 1dd 1de 0
12 :4 0 49 :4 0
15 :2 0 16 :3 0
f8 1e2 1e4 :3 0
15 :2 0 39 :4 0
fb 1e6 1e8 :3 0
15 :2 0 3a :4 0
fe 1ea 1ec :3 0
15 :2 0 35 :3 0
101 1ee 1f0 :3 0
15 :2 0 3b :4 0
104 1f2 1f4 :3 0
15 :2 0 3c :3 0
3d :3 0 1f :2 0
3e :2 0 107 1f7
1fb 10b 1f6 1fd
:3 0 10e 1df 1ff
:2 0 201 111 202
1dc 201 0 203
113 0 204 115
207 :3 0 207 0
207 206 204 205
:6 0 209 6 :3 0
118 20b 11a 20a
209 :2 0 20c 11c
:2 0 20e 0 20e
20d 1c4 20c :6 0
210 1 :3 0 11e
212 120 211 210
:2 0 565 24 :3 0
4a :3 0 213 214
0 4b :3 0 27
:3 0 28 :3 0 27
:3 0 7 :3 0 7
:3 0 29 :3 0 27
:3 0 7 :3 0 2a
:3 0 7 :3 0 2a
:3 0 27 :3 0 27
:3 0 7 :3 0 27
:3 0 2b :3 0 3
:4 0 4c 1 :8 0
23e 2d :4 0 229
:3 0 2e :3 0 2f
:2 0 124 22c 22d
:3 0 30 :3 0 31
:3 0 22f 230 0
32 :2 0 231 232
0 234 127 23b
30 :3 0 31 :3 0
235 236 0 33
:2 0 237 238 0
23a 129 23c 22e
234 0 23d 0
23a 0 23d 12b
0 23e 12e 288
34 :3 0 30 :3 0
31 :3 0 241 242
0 35 :3 0 243
244 0 27e d
:3 0 e :3 0 246
247 0 d :3 0
1e :3 0 249 24a
0 36 :2 0 2
:4 0 4d :2 0 21
:2 0 1f :2 0 131
24f 251 :3 0 134
24b 253 248 255
254 :2 0 10 :3 0
22 :3 0 257 258
0 12 :4 0 4e
:4 0 15 :2 0 16
:3 0 138 25c 25e
:3 0 15 :2 0 39
:4 0 13b 260 262
:3 0 15 :2 0 3a
:4 0 13e 264 266
:3 0 15 :2 0 35
:3 0 141 268 26a
:3 0 15 :2 0 3b
:4 0 144 26c 26e
:3 0 15 :2 0 3c
:3 0 3d :3 0 1f
:2 0 3e :2 0 147
271 275 14b 270
277 :3 0 14e 259
279 :2 0 27b 151
27c 256 27b 0
27d 153 0 27e
155 281 :3 0 281
0 281 280 27e
27f :6 0 283 8
:3 0 158 285 15a
284 283 :2 0 286
15c :2 0 288 0
288 287 23e 286
:6 0 28a 1 :3 0
15e 28c 160 28b
28a :2 0 565 24
:3 0 4f :3 0 28d
28e 0 50 :3 0
27 :3 0 28 :3 0
27 :3 0 7 :3 0
7 :3 0 29 :3 0
27 :3 0 7 :3 0
2a :3 0 7 :3 0
2a :3 0 27 :3 0
27 :3 0 7 :3 0
27 :3 0 2b :3 0
3 :4 0 51 1
:8 0 2b8 2d :4 0
2a3 :3 0 2e :3 0
2f :2 0 164 2a6
2a7 :3 0 30 :3 0
31 :3 0 2a9 2aa
0 32 :2 0 2ab
2ac 0 2ae 167
2b5 30 :3 0 31
:3 0 2af 2b0 0
33 :2 0 2b1 2b2
0 2b4 169 2b6
2a8 2ae 0 2b7
0 2b4 0 2b7
16b 0 2b8 16e
302 34 :3 0 30
:3 0 31 :3 0 2bb
2bc 0 35 :3 0
2bd 2be 0 2f8
d :3 0 e :3 0
2c0 2c1 0 d
:3 0 1e :3 0 2c3
2c4 0 36 :2 0
2 :4 0 52 :2 0
21 :2 0 1f :2 0
171 2c9 2cb :3 0
174 2c5 2cd 2c2
2cf 2ce :2 0 10
:3 0 22 :3 0 2d1
2d2 0 12 :4 0
53 :4 0 15 :2 0
16 :3 0 178 2d6
2d8 :3 0 15 :2 0
39 :4 0 17b 2da
2dc :3 0 15 :2 0
3a :4 0 17e 2de
2e0 :3 0 15 :2 0
35 :3 0 181 2e2
2e4 :3 0 15 :2 0
3b :4 0 184 2e6
2e8 :3 0 15 :2 0
3c :3 0 3d :3 0
1f :2 0 3e :2 0
187 2eb 2ef 18b
2ea 2f1 :3 0 18e
2d3 2f3 :2 0 2f5
191 2f6 2d0 2f5
0 2f7 193 0
2f8 195 2fb :3 0
2fb 0 2fb 2fa
2f8 2f9 :6 0 2fd
a :3 0 198 2ff
19a 2fe 2fd :2 0
300 19c :2 0 302
0 302 301 2b8
300 :6 0 304 1
:3 0 19e 306 1a0
305 304 :2 0 565
24 :3 0 54 :3 0
307 308 0 55
:3 0 27 :3 0 28
:3 0 27 :3 0 7
:3 0 7 :3 0 29
:3 0 27 :3 0 7
:3 0 2a :3 0 7
:3 0 2a :3 0 27
:3 0 27 :3 0 7
:3 0 27 :3 0 2b
:3 0 3 :4 0 56
1 :8 0 332 2d
:4 0 31d :3 0 2e
:3 0 2f :2 0 1a4
320 321 :3 0 30
:3 0 31 :3 0 323
324 0 32 :2 0
325 326 0 328
1a7 32f 30 :3 0
31 :3 0 329 32a
0 33 :2 0 32b
32c 0 32e 1a9
330 322 328 0
331 0 32e 0
331 1ab 0 332
1ae 37c 34 :3 0
30 :3 0 31 :3 0
335 336 0 35
:3 0 337 338 0
372 d :3 0 e
:3 0 33a 33b 0
d :3 0 1e :3 0
33d 33e 0 36
:2 0 2 :4 0 57
:2 0 21 :2 0 1f
:2 0 1b1 343 345
:3 0 1b4 33f 347
33c 349 348 :2 0
10 :3 0 22 :3 0
34b 34c 0 12
:4 0 58 :4 0 15
:2 0 16 :3 0 1b8
350 352 :3 0 15
:2 0 39 :4 0 1bb
354 356 :3 0 15
:2 0 3a :4 0 1be
358 35a :3 0 15
:2 0 35 :3 0 1c1
35c 35e :3 0 15
:2 0 3b :4 0 1c4
360 362 :3 0 15
:2 0 3c :3 0 3d
:3 0 1f :2 0 3e
:2 0 1c7 365 369
1cb 364 36b :3 0
1ce 34d 36d :2 0
36f 1d1 370 34a
36f 0 371 1d3
0 372 1d5 375
:3 0 375 0 375
374 372 373 :6 0
377 c :3 0 1d8
379 1da 378 377
:2 0 37a 1dc :2 0
37c 0 37c 37b
332 37a :6 0 37e
1 :3 0 1de 380
1e0 37f 37e :2 0
565 24 :3 0 59
:3 0 381 382 0
5a :3 0 27 :3 0
28 :3 0 27 :3 0
7 :3 0 7 :3 0
29 :3 0 27 :3 0
7 :3 0 2a :3 0
7 :3 0 2a :3 0
27 :3 0 27 :3 0
7 :3 0 27 :3 0
2b :3 0 3 :4 0
5b 1 :8 0 3ac
2d :4 0 397 :3 0
2e :3 0 2f :2 0
1e4 39a 39b :3 0
30 :3 0 31 :3 0
39d 39e 0 32
:2 0 39f 3a0 0
3a2 1e7 3a9 30
:3 0 31 :3 0 3a3
3a4 0 33 :2 0
3a5 3a6 0 3a8
1e9 3aa 39c 3a2
0 3ab 0 3a8
0 3ab 1eb 0
3ac 1ee 3f6 34
:3 0 30 :3 0 31
:3 0 3af 3b0 0
35 :3 0 3b1 3b2
0 3ec d :3 0
e :3 0 3b4 3b5
0 d :3 0 1e
:3 0 3b7 3b8 0
36 :2 0 2 :4 0
5c :2 0 21 :2 0
1f :2 0 1f1 3bd
3bf :3 0 1f4 3b9
3c1 3b6 3c3 3c2
:2 0 10 :3 0 22
:3 0 3c5 3c6 0
12 :4 0 5d :4 0
15 :2 0 16 :3 0
1f8 3ca 3cc :3 0
15 :2 0 39 :4 0
1fb 3ce 3d0 :3 0
15 :2 0 3a :4 0
1fe 3d2 3d4 :3 0
15 :2 0 35 :3 0
201 3d6 3d8 :3 0
15 :2 0 3b :4 0
204 3da 3dc :3 0
15 :2 0 3c :3 0
3d :3 0 1f :2 0
3e :2 0 207 3df
3e3 20b 3de 3e5
:3 0 20e 3c7 3e7
:2 0 3e9 211 3ea
3c4 3e9 0 3eb
213 0 3ec 215
3ef :3 0 3ef 0
3ef 3ee 3ec 3ed
:6 0 3f1 e :3 0
218 3f3 21a 3f2
3f1 :2 0 3f4 21c
:2 0 3f6 0 3f6
3f5 3ac 3f4 :6 0
3f8 1 :3 0 21e
3fa 220 3f9 3f8
:2 0 565 24 :3 0
5e :3 0 3fb 3fc
0 5f :3 0 27
:3 0 28 :3 0 27
:3 0 7 :3 0 7
:3 0 29 :3 0 27
:3 0 7 :3 0 2a
:3 0 7 :3 0 2a
:3 0 27 :3 0 27
:3 0 7 :3 0 27
:3 0 2b :3 0 3
:4 0 60 1 :8 0
426 2d :4 0 411
:3 0 2e :3 0 2f
:2 0 224 414 415
:3 0 30 :3 0 31
:3 0 417 418 0
32 :2 0 419 41a
0 41c 227 423
30 :3 0 31 :3 0
41d 41e 0 33
:2 0 41f 420 0
422 229 424 416
41c 0 425 0
422 0 425 22b
0 426 22e 470
34 :3 0 30 :3 0
31 :3 0 429 42a
0 35 :3 0 42b
42c 0 466 d
:3 0 e :3 0 42e
42f 0 d :3 0
1e :3 0 431 432
0 36 :2 0 2
:4 0 61 :2 0 21
:2 0 1f :2 0 231
437 439 :3 0 234
433 43b 430 43d
43c :2 0 10 :3 0
22 :3 0 43f 440
0 12 :4 0 62
:4 0 15 :2 0 16
:3 0 238 444 446
:3 0 15 :2 0 39
:4 0 23b 448 44a
:3 0 15 :2 0 3a
:4 0 23e 44c 44e
:3 0 15 :2 0 35
:3 0 241 450 452
:3 0 15 :2 0 3b
:4 0 244 454 456
:3 0 15 :2 0 3c
:3 0 3d :3 0 1f
:2 0 3e :2 0 247
459 45d 24b 458
45f :3 0 24e 441
461 :2 0 463 251
464 43e 463 0
465 253 0 466
255 469 :3 0 469
0 469 468 466
467 :6 0 46b 10
:3 0 258 46d 25a
46c 46b :2 0 46e
25c :2 0 470 0
470 46f 426 46e
:6 0 472 1 :3 0
25e 474 260 473
472 :2 0 565 24
:3 0 63 :3 0 475
476 0 64 :3 0
27 :3 0 28 :3 0
27 :3 0 7 :3 0
7 :3 0 29 :3 0
27 :3 0 7 :3 0
2a :3 0 7 :3 0
2a :3 0 27 :3 0
27 :3 0 7 :3 0
27 :3 0 2b :3 0
3 :4 0 65 1
:8 0 4a0 2d :4 0
48b :3 0 2e :3 0
2f :2 0 264 48e
48f :3 0 30 :3 0
31 :3 0 491 492
0 32 :2 0 493
494 0 496 267
49d 30 :3 0 31
:3 0 497 498 0
33 :2 0 499 49a
0 49c 269 49e
490 496 0 49f
0 49c 0 49f
26b 0 4a0 26e
4ea 34 :3 0 30
:3 0 31 :3 0 4a3
4a4 0 35 :3 0
4a5 4a6 0 4e0
d :3 0 e :3 0
4a8 4a9 0 d
:3 0 1e :3 0 4ab
4ac 0 36 :2 0
2 :4 0 66 :2 0
21 :2 0 1f :2 0
271 4b1 4b3 :3 0
274 4ad 4b5 4aa
4b7 4b6 :2 0 10
:3 0 22 :3 0 4b9
4ba 0 12 :4 0
67 :4 0 15 :2 0
16 :3 0 278 4be
4c0 :3 0 15 :2 0
39 :4 0 27b 4c2
4c4 :3 0 15 :2 0
3a :4 0 27e 4c6
4c8 :3 0 15 :2 0
35 :3 0 281 4ca
4cc :3 0 15 :2 0
3b :4 0 284 4ce
4d0 :3 0 15 :2 0
3c :3 0 3d :3 0
1f :2 0 3e :2 0
287 4d3 4d7 28b
4d2 4d9 :3 0 28e
4bb 4db :2 0 4dd
291 4de 4b8 4dd
0 4df 293 0
4e0 295 4e3 :3 0
4e3 0 4e3 4e2
4e0 4e1 :6 0 4e5
12 :3 0 298 4e7
29a 4e6 4e5 :2 0
4e8 29c :2 0 4ea
0 4ea 4e9 4a0
4e8 :6 0 4ec 1
:3 0 29e 4ee 2a0
4ed 4ec :2 0 565
68 :3 0 27 :3 0
28 :3 0 27 :3 0
7 :3 0 7 :3 0
29 :3 0 27 :3 0
7 :3 0 2a :3 0
7 :3 0 2a :3 0
27 :3 0 27 :3 0
7 :3 0 27 :3 0
2b :3 0 3 :4 0
69 1 :8 0 517
2d :4 0 502 :3 0
2e :3 0 2f :2 0
2a4 505 506 :3 0
30 :3 0 31 :3 0
508 509 0 32
:2 0 50a 50b 0
50d 2a7 514 30
:3 0 31 :3 0 50e
50f 0 33 :2 0
510 511 0 513
2a9 515 507 50d
0 516 0 513
0 516 2ab 0
517 2ae 561 34
:3 0 30 :3 0 31
:3 0 51a 51b 0
35 :3 0 51c 51d
0 557 d :3 0
e :3 0 51f 520
0 d :3 0 1e
:3 0 522 523 0
36 :2 0 2 :4 0
6a :2 0 21 :2 0
1f :2 0 2b1 528
52a :3 0 2b4 524
52c 521 52e 52d
:2 0 10 :3 0 22
:3 0 530 531 0
12 :4 0 6b :4 0
15 :2 0 16 :3 0
2b8 535 537 :3 0
15 :2 0 39 :4 0
2bb 539 53b :3 0
15 :2 0 3a :4 0
2be 53d 53f :3 0
15 :2 0 35 :3 0
2c1 541 543 :3 0
15 :2 0 3b :4 0
2c4 545 547 :3 0
15 :2 0 3c :3 0
3d :3 0 1f :2 0
3e :2 0 2c7 54a
54e 2cb 549 550
:3 0 2ce 532 552
:2 0 554 2d1 555
52f 554 0 556
2d3 0 557 2d5
55a :3 0 55a 0
55a 559 557 558
:6 0 55c 14 :3 0
2d8 55e 2da 55d
55c :2 0 55f 2dc
:2 0 561 0 561
560 517 55f :6 0
563 1 :3 0 2de
564 0 563 :2 0
565 2e0 :2 0 566
a2 565 0 599
0 d :3 0 e
:3 0 567 568 0
d :3 0 1e :3 0
56a 56b 0 1f
:2 0 2 :4 0 6c
:2 0 21 :2 0 1f
:2 0 2eb 570 572
:3 0 2ee 56c 574
569 576 575 :2 0
10 :3 0 22 :3 0
578 579 0 12
:4 0 6d :4 0 15
:2 0 16 :3 0 2f2
57d 57f :3 0 15
:2 0 39 :4 0 2f5
581 583 :3 0 15
:2 0 6e :4 0 2f8
585 587 :3 0 15
:2 0 30 :3 0 31
:3 0 58a 58b 0
2fb 589 58d :3 0
2fe 57a 58f :2 0
591 301 592 577
591 0 593 303
0 599 b :3 0
30 :3 0 31 :3 0
595 596 0 597
:2 0 599 305 59c
:3 0 59c 30b 59c
59b 599 59a :6 0
59d :2 0 2 1c
59c 5a0 :3 0 59f
59d 5a1 :8 0 
30d
4
:3 0 1 3 1
9 1 f 1
15 4 8 e
14 18 1 1e
1 2a 1 36
2 39 3b 2
3e 40 2 42
44 2 46 48
2 4a 4c 2
4e 50 2 52
54 2 56 58
2 5a 5c 2
5e 60 2 62
64 2 66 68
2 6a 6c 1
72 2 74 75
2 6e 77 2
79 7b 4 32
38 3d 7d 1
7f 1 81 2
8b 8d 3 89
8a 8f 2 98
9a 2 97 9c
1 9e 1 a0
1 bb 2 ba
bb 1 c3 1
c9 2 cb cc
2 b8 cd 2
de e0 3 dc
dd e2 2 eb
ed 2 ef f1
2 f3 f5 2
f7 f9 2 fb
fd 3 102 103
104 2 ff 106
2 ea 108 1
10a 1 10c 2
d5 10d 1 111
1 d0 1 115
1 118 1 a5
1 137 2 136
137 1 13f 1
145 2 147 148
2 134 149 2
15a 15c 3 158
159 15e 2 167
169 2 16b 16d
2 16f 171 2
173 175 2 177
179 3 17e 17f
180 2 17b 182
2 166 184 1
186 1 188 2
151 189 1 18d
1 14c 1 191
1 194 1 11f
1 1b1 2 1b0
1b1 1 1b9 1
1bf 2 1c1 1c2
2 1ae 1c3 2
1d4 1d6 3 1d2
1d3 1d8 2 1e1
1e3 2 1e5 1e7
2 1e9 1eb 2
1ed 1ef 2 1f1
1f3 3 1f8 1f9
1fa 2 1f5 1fc
2 1e0 1fe 1
200 1 202 2
1cb 203 1 207
1 1c6 1 20b
1 20e 1 19b
1 22b 2 22a
22b 1 233 1
239 2 23b 23c
2 228 23d 2
24e 250 3 24c
24d 252 2 25b
25d 2 25f 261
2 263 265 2
267 269 2 26b
26d 3 272 273
274 2 26f 276
2 25a 278 1
27a 1 27c 2
245 27d 1 281
1 240 1 285
1 288 1 215
1 2a5 2 2a4
2a5 1 2ad 1
2b3 2 2b5 2b6
2 2a2 2b7 2
2c8 2ca 3 2c6
2c7 2cc 2 2d5
2d7 2 2d9 2db
2 2dd 2df 2
2e1 2e3 2 2e5
2e7 3 2ec 2ed
2ee 2 2e9 2f0
2 2d4 2f2 1
2f4 1 2f6 2
2bf 2f7 1 2fb
1 2ba 1 2ff
1 302 1 28f
1 31f 2 31e
31f 1 327 1
32d 2 32f 330
2 31c 331 2
342 344 3 340
341 346 2 34f
351 2 353 355
2 357 359 2
35b 35d 2 35f
361 3 366 367
368 2 363 36a
2 34e 36c 1
36e 1 370 2
339 371 1 375
1 334 1 379
1 37c 1 309
1 399 2 398
399 1 3a1 1
3a7 2 3a9 3aa
2 396 3ab 2
3bc 3be 3 3ba
3bb 3c0 2 3c9
3cb 2 3cd 3cf
2 3d1 3d3 2
3d5 3d7 2 3d9
3db 3 3e0 3e1
3e2 2 3dd 3e4
2 3c8 3e6 1
3e8 1 3ea 2
3b3 3eb 1 3ef
1 3ae 1 3f3
1 3f6 1 383
1 413 2 412
413 1 41b 1
421 2 423 424
2 410 425 2
436 438 3 434
435 43a 2 443
445 2 447 449
2 44b 44d 2
44f 451 2 453
455 3 45a 45b
45c 2 457 45e
2 442 460 1
462 1 464 2
42d 465 1 469
1 428 1 46d
1 470 1 3fd
1 48d 2 48c
48d 1 495 1
49b 2 49d 49e
2 48a 49f 2
4b0 4b2 3 4ae
4af 4b4 2 4bd
4bf 2 4c1 4c3
2 4c5 4c7 2
4c9 4cb 2 4cd
4cf 3 4d4 4d5
4d6 2 4d1 4d8
2 4bc 4da 1
4dc 1 4de 2
4a7 4df 1 4e3
1 4a2 1 4e7
1 4ea 1 477
1 504 2 503
504 1 50c 1
512 2 514 515
2 501 516 2
527 529 3 525
526 52b 2 534
536 2 538 53a
2 53c 53e 2
540 542 2 544
546 3 54b 54c
54d 2 548 54f
2 533 551 1
553 1 555 2
51e 556 1 55a
1 519 1 55e
1 561 a 11c
198 212 28c 306
380 3fa 474 4ee
564 2 56f 571
3 56d 56e 573
2 57c 57e 2
580 582 2 584
586 2 588 58c
2 57b 58e 1
590 1 592 5
82 a1 566 593
598 1 22 
1
4
0 
5a0
0
1
28
15
6
0 1 2 1 4 1 6 1
8 1 a 1 c 1 e 1
10 1 12 1 14 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0

2 0 1
f 1 0
3 1 0
1e 1 0
9 1 0
15 1 0
0

/
SHOW ERRORS FUNCTION FC_U_NAMES;
ALTER FUNCTION FC_U_NAMES COMPILE DEBUG;
/******************************************************************************************************************
update resource assignments SECURITY
assign_id:      RES_ASSIGNMENT_ID or TSK_ASSIGNMENT_ID
security_id:    SECURITY_ID in TMT_GLOBAL_SECURITY
*******************************************************************************************************************/
Prompt == FUNCTION SP_U_WP_DATES ==
CREATE OR REPLACE FUNCTION SP_U_WP_DATES wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
ee
2 :e:
1FUNCTION:
1SP_U_WP_DATES:
1ASSIGN_ID:
1VARCHAR2:
1P_PLANNED_START:
1TIMESTAMP:
1P_PLANNED_FINISH:
1RES_ID001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_TSK_ASSIGNMENT_ID:
132:
1H_PRJ_ASSIGN_ID:
1H_PROJECT_ID:
1H_ACTUAL_START:
1H_START_DATE:
1H_FINISH_DATE:
1H_SCHED_START:
1H_SCHED_FINISH:
1H_SD:
1DATE:
1H_FD:
1H_BIT_FLAG:
11:
1H_RES_TYPE:
1H_BILLABLE:
1PLS_INTEGER:
10:
1H_CAPITAL_EXPENSE:
1H_TPH_DELETE:
1H_DAYOFYEAR:
1H_LAST_SUBMITTED:
1H_PARTICIPANT:
1H_UPDATE:
1H_TABLE_TYPE:
1H_TRANSFED_CRI:
1H_TASK_ID:
1H_RES_ID:
1H_REC_USER:
1H_EFFORT:
1H_CONTOUR:
1H_DELAY:
1H_PERCENT_UNITS:
1H_WORK_PERCENT:
1H_WORK_TODATE:
1H_NEW_ACTUAL:
1H_WORK:
1H_SKIP:
1H_LAST_DAY:
1H_MINUTES:
1H_PER_DAY:
1H_WORK_TYPE:
1H_ASSIGN_COUNT:
1H_DURATION:
1H_BITFLAG:
1H_CONSIDER:
1H_EUNIT:
1H_UNIT:
1H_SCHED_EFFORT:
1H_TEMP_SC_STATE:
1H_TEMP_VAR:
1H_REG_COST:
1NUMBER:
1H_REG_SALE:
1H_SPEC_COST:
1H_SPEC_SALE:
1H_B_REG_COST:
1H_B_REG_SALE:
1H_B_SPEC_COST:
1H_B_SPEC_SALE:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_U_WP_DATES(:
1':
1, :
1COALESCE:
1NULLIF:
1'':
1NULL:
1);:
1CHECK_TRACE:
174:
1+:
1FPUT:
1               ENTER:: SP_U_WP_DATES(75) :: cplan.sql(14030) :: :
1PROJECT_ASSIGNMENT_ID:
1PROJECT_ID:
1RESOURCE_ID:
1RESOURCE_TYPE:
1BIT_FLAG:
1LAST_SUBMITTED:
1C_CONTOUR:
1C_EFFORT:
1T_UNIT:
1C_UNIT:
1UNITS_MSP:
1ACTUAL_START:
1WORK_TODATE:
1UNRESOLVED_START:
1UNRESOLVED_FINISH:
1PLANNED_WORK:
1SCHED_WORK:
1ASSIGNMENT_DELAY:
1LAST_SCHED_MIN:
1TO_DATE:
1SUBSTR:
1BILLABLE:
1CAPITAL_EXPENSE:
1REGULAR_COST:
1SPECIAL_COST:
1REGULAR_RATE:
1SPECIAL_RATE:
1B_REGULAR_COST:
1B_SPECIAL_COST:
1B_REGULAR_RATE:
1B_SPECIAL_RATE:
1MILESTONE_PERCENT:
1TASK_ID:
1TASK_ASSIGNMENTS:
1TSK_ASSIGNMENT_ID:
1SELECT PROJECT_ASSIGNMENT_ID, PROJECT_ID, RESOURCE_ID,:n      RESOURCE_TYPE, +
1BIT_FLAG, LAST_SUBMITTED, C_CONTOUR, C_EFFORT, T_UNIT, C_UNIT,:n      UNITS_M+
1SP, ACTUAL_START, WORK_TODATE, UNRESOLVED_START, UNRESOLVED_FINISH,:n      CA+
1SE WHEN BIT_FLAG = '0' THEN PLANNED_WORK ELSE SCHED_WORK END, ASSIGNMENT_DELA+
1Y, LAST_SCHED_MIN,:n      TO_DATE(SubStr(UNRESOLVED_START, 1, 10)), TO_DATE(S+
1ubStr(UNRESOLVED_FINISH, 1, 10)), BILLABLE, CAPITAL_EXPENSE,:n      REGULAR_C+
1OST, SPECIAL_COST, REGULAR_RATE, SPECIAL_RATE,:n      B_REGULAR_COST, B_SPECI+
1AL_COST, B_REGULAR_RATE, B_SPECIAL_RATE,:n      MILESTONE_PERCENT, TASK_ID:n +
1     INTO h_prj_assign_id, h_project_id, h_res_id,:n      h_res_type, h_bit_f+
1lag, h_last_submitted, h_contour, h_work, h_eunit, h_unit,:n      h_percent_u+
1nits, h_actual_start, h_work_todate, h_start_date, h_finish_date,:n      h_ef+
1fort, h_delay, h_last_day,:n      h_SD, h_FD, h_billable, h_capital_expense,+
1:n      h_reg_cost, h_spec_cost, h_reg_sale, h_spec_sale,:n      h_b_reg_cost+
1, h_b_spec_cost, h_b_reg_sale, h_b_spec_sale,:n      h_work_percent, h_task_i+
1d:n      FROM TASK_ASSIGNMENTS:n      WHERE TSK_ASSIGNMENT_ID = h_tsk_assignm+
1ent_id:
1SC_STATE:
1SQLCODE:
1OTHERS:
116:
1108:
1           EXCEPTION:: SP_U_WP_DATES(109) :: cplan.sql(14064) :: :
1 :
1SQLCODE:: :
1 SQLERR:: :
1SQLERRM:
1500:
1=:
1SC_SQL_NO_DATA:
1116:
1        RETURN_ERROR:: SP_U_WP_DATES(117) :: cplan.sql(14072) :: :
1STATE:: :
1TO_CHAR:
1PMO_CNST:
1RECORD_NOT_FOUND:
1 ID:: :
1119:
1                EXIT:: SP_U_WP_DATES(120) :: cplan.sql(14075) :: :
1PMODEFINES:
1PMO_RETURN_ERROR_SP:
1TRUE:
1IS NOT NULL:
1PMO_ORASTD:
1STRNCMP:
110:
1>:
1!=:
1132:
1        RETURN_ERROR:: SP_U_WP_DATES(133) :: cplan.sql(14088) :: :
1F_DATE_EARLIER_THAN_S_DATE:
1135:
1                EXIT:: SP_U_WP_DATES(136) :: cplan.sql(14091) :: :
1MINUTE_PER_DAY:
1TMT_WBS:
1ELEMENT_ID:
1SELECT PROJECT_ID, MINUTE_PER_DAY:n         INTO h_project_id, h_per_day:n   +
1      FROM TMT_WBS WHERE PROJECT_ID = h_project_id AND ELEMENT_ID = h_task_id:
1151:
1           EXCEPTION:: SP_U_WP_DATES(152) :: cplan.sql(14107) :: :
18:
1163:
1      RETURN_INVALID:: SP_U_WP_DATES(164) :: cplan.sql(14119) :: :
1INVALID_PARAMS:
1166:
1                EXIT:: SP_U_WP_DATES(167) :: cplan.sql(14122) :: :
1PMO_RETURN_INVALID_SP:
1-:
1FC_TPHASE_SCHED_ASSIGN:
1FC_U_TDY_LAST_ACTUAL:
1FC_DEL_NOACTUAL:
12:
1DB2TIMESTAMP:
1TIME:
1DUAL:
1SELECT PMO_ORASTD.DB2TIMESTAMP(TO_DATE(SubStr(h_last_submitted, 1, 10)), PMO_+
1ORASTD.TIME(h_start_date)) + 1     :n         INTO h_start_date:n         FRO+
1M DUAL:
1205:
1           EXCEPTION:: SP_U_WP_DATES(206) :: cplan.sql(14161) :: :
1FC_RESCHEDULE:
1222:
1        RETURN_ERROR:: SP_U_WP_DATES(223) :: cplan.sql(14178) :: :
1TASK_ASSIGNMENT_ERROR:
1225:
1                EXIT:: SP_U_WP_DATES(226) :: cplan.sql(14181) :: :
1CONSIDER:
1ROLLUP_BITS:
1PMO_STPU:
1BIT_OR:
1SC_SCHED_BIT:
1SC_PLANNED_BIT:
1BAK_START_DT:
1SCHED_START:
1PLANNED_START:
1BAK_FINISH_DT:
1SCHED_FINISH:
1PLANNED_FINISH:
1BAK_ASSIGN_STRING:
1ASSIGN_STRING:
1UPDATE TASK_ASSIGNMENTS SET CONSIDER = 7, ROLLUP_BITS = PMO_STPU.BIT_OR(ROLLU+
1P_BITS,(PMO_CNST.SC_SCHED_BIT+PMO_CNST.SC_PLANNED_BIT)),:n         BAK_START_+
1DT = COALESCE(SCHED_START,PLANNED_START), BAK_FINISH_DT = COALESCE(SCHED_FINI+
1SH,PLANNED_FINISH),:n         BAK_ASSIGN_STRING = ASSIGN_STRING:n         WHE+
1RE TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
1FOUND:
1100:
1245:
1           EXCEPTION:: SP_U_WP_DATES(246) :: cplan.sql(14201) :: :
1FC_ROLLUP:
1253:
1        RETURN_ERROR:: SP_U_WP_DATES(254) :: cplan.sql(14209) :: :
1256:
1                EXIT:: SP_U_WP_DATES(257) :: cplan.sql(14212) :: :
14:
1262:
1       RETURN_STATUS:: SP_U_WP_DATES(263) :: cplan.sql(14218) :: :
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
1269:
1           EXCEPTION:: SP_U_WP_DATES(270) :: cplan.sql(14225) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1ID:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
1281:
1           EXCEPTION:: SP_U_WP_DATES(282) :: cplan.sql(14237) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
7cb
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d b4 :3 a0 6b 2c 6a
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 1c
81 b0 a3 a0 1c 81 b0 a3
a0 1c 81 b0 a3 a0 1c 81
b0 a3 a0 1c 81 b0 a3 a0
1c 81 b0 a3 a0 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 81 b0 a3 a0 1c
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 :2 a0 6b 1c 81
b0 :2 a0 6b :2 a0 6b 6e a5 b
a 10 :2 a0 6b 6e :2 a0 6b 6e
a5 b 6e 7e a0 b4 2e 6e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :2 a0 6e 7e a0 b4 2e 7e
6e b4 2e 6e a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
:2 a0 6e 7e a0 b4 2e 7e 6e
b4 2e 6e a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 d
:2 a0 d :49 a0 12a :2 a0 6b a0 d
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 6b a0
7e a0 6b b4 2e 5a :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b :2 a0 a5 57 b7 19 3c
a0 7e b4 2e 5a a0 7e b4
2e 5a a 10 :2 a0 d :2 a0 d
:2 a0 6b :2 a0 51 a5 b 7e 51
b4 2e 5a :2 a0 6b :2 a0 51 a5
b 7e 51 b4 2e 5a a 10
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b :2 a0 a5 57 b7
19 3c :9 a0 12a :2 a0 6b a0 d
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 6b :2 a0
51 a5 b 7e 51 b4 2e :2 a0
d a0 51 d b7 :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b a0 a5 57 b7 :2 19 3c b7
19 3c a0 7e 51 b4 2e d
:c a0 a5 b d :2 a0 51 a5 b
7e 51 b4 2e 5a a0 7e b4
2e :2 5a a 10 :9 a0 51 a5 b
d b7 19 3c a0 7e b4 2e
5a :4 a0 51 a5 b d b7 :2 a0
:2 51 a5 b 7e 6e b4 2e :4 a0
51 a5 b d b7 :4 a0 51 a5
b d b7 :2 19 3c b7 :2 19 3c
a0 7e b4 2e 5a :a a0 12a :2 a0
6b a0 d b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:3 a0 51 a5 b 7e :2 a0 51 a5
b b4 2e d b7 19 3c a0
51 d :a a0 51 a5 b :2 a0 51
a5 b a5 b d :2 a0 51 a5
b 7e 51 b4 2e :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b :2 a0 a5 57 b7 :16 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 :2 19
3c :3 a0 a5 b d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :3 a0 a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 51
a5 b :2 a0 a5 57 :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b :2 a0 a5
57 b7 :2 a0 6b :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 :2 a0 6b :2 6e 7e
:2 a0 6b b4 2e 7e 6e b4 2e
7e :2 a0 6b b4 2e a5 57 b7
19 3c :9 a0 12a e9 dd :2 a0 65
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
:7 a0 12a e9 dd :2 a0 65 b7 a4
b1 11 4f b7 a6 9 a4 b1
11 68 4f 1d 17 b5 
7cb
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 5e
5a 30 66 59 6b 6f 73 56
77 7b 98 83 87 8a 8b 93
82 b5 a3 7f a7 a8 b0 a2
d2 c0 9f c4 c5 cd bf ee
dd e1 e9 bc 106 f5 f9 101
dc 122 111 115 11d d9 13a 129
12d 135 110 156 145 149 151 10d
16e 15d 161 169 144 18a 179 17d
185 141 1a6 191 195 198 199 1a1
178 1c3 1b1 175 1b5 1b6 1be 1b0
1df 1ce 1d2 1ad 1da 1cd 1fb 1ea
1ee 1ca 1f6 1e9 217 206 20a 1e6
212 205 233 222 226 22e 202 24b
23a 23e 246 221 267 256 25a 21e
262 255 283 272 276 252 27e 271
29f 28e 292 26e 29a 28d 2bb 2aa
2ae 28a 2b6 2a9 2d8 2c6 2a6 2ca
2cb 2d3 2c5 2f5 2e3 2c2 2e7 2e8
2f0 2e2 312 300 2df 304 305 30d
2ff 32e 31d 321 2fc 329 31c 34a
339 33d 319 345 338 366 355 359
335 361 354 382 371 375 351 37d
370 39e 38d 391 36d 399 38c 3ba
3a9 3ad 389 3b5 3a8 3d6 3c5 3c9
3a5 3d1 3c4 3f2 3e1 3e5 3c1 3ed
3e0 40e 3fd 401 3dd 409 3fc 42a
419 41d 3f9 425 418 446 435 439
415 441 434 462 451 455 431 45d
450 47e 46d 471 44d 479 46c 49a
489 48d 469 495 488 4b6 4a5 4a9
485 4b1 4a4 4d2 4c1 4c5 4a1 4cd
4c0 4ee 4dd 4e1 4bd 4e9 4dc 50a
4f9 4fd 4d9 505 4f8 526 515 519
4f5 521 514 542 531 535 511 53d
530 55e 54d 551 52d 559 54c 57a
569 56d 549 575 568 596 585 589
565 591 584 5b2 5a1 5a5 581 5ad
5a0 5ce 5bd 5c1 59d 5c9 5bc 5ea
5d9 5dd 5b9 5e5 5d8 606 5f5 5f9
5d5 601 5f4 622 611 615 5f1 61d
610 63e 62d 631 60d 639 62c 65a
649 64d 629 655 648 67a 665 669
645 66d 675 664 681 685 661 689
68d 691 694 699 69a 1 69c 6a1
6a5 6a9 6ac 6b1 6b5 6b9 6bc 6c1
6c2 6c4 6c9 6cc 6d0 6d1 6d6 6db
6de 6e3 6e4 6e9 6ec 6f0 6f1 6f6
6f9 6fe 6ff 704 707 70c 70d 712
715 719 71d 722 725 729 72a 72f
732 737 738 73d 742 743 745 74a
74b 74d 74e 753 756 75b 75c 761
764 768 76c 771 774 778 779 77e
781 786 787 78c 791 792 794 799
79a 79c 79d 7a2 7a5 7aa 7ab 7b0
7b3 7b8 7b9 7be 7c1 7c5 7c6 7cb
7ce 7d3 7d4 7d9 7dc 7e1 7e2 7e7
7e8 7ed 7ef 7f3 7f6 7fa 7fe 801
805 809 80c 80f 814 817 81a 81d
81e 823 824 1 826 82b 82f 833
836 83b 840 843 847 848 84d 84e
853 855 859 85c 860 864 868 86c
870 874 878 87c 880 884 888 88c
890 894 898 89c 8a0 8a4 8a8 8ac
8b0 8b4 8b8 8bc 8c0 8c4 8c8 8cc
8d0 8d4 8d8 8dc 8e0 8e4 8e8 8ec
8f0 8f4 8f8 8fc 900 904 908 90c
910 914 918 91c 920 924 928 92c
930 934 938 93c 940 944 948 94c
950 954 958 95c 960 964 968 96c
970 974 978 97c 980 984 988 98c
990 994 998 9a4 9a8 9ac 9af 9b3
9b7 9b9 1 9bd 9c1 9c5 9c8 9cc
9d0 9d4 9d8 9db 9df 9e3 9e6 9e9
9ee 9f1 9f4 9f7 9f8 9fd 9fe 1
a00 a05 a09 a0d a10 a15 a1a a1d
a21 a22 a27 a2a a2f a30 a35 a38
a3d a3e a43 a46 a4a a4b a50 a53
a58 a59 a5e a61 a65 a69 a6c a6f
a70 a72 a73 a78 a79 a7e a80 a84
a87 a89 a8d a8f a9b a9d a9f aa0
aa5 aa9 aab ab7 ab9 abd ac1 ac4
ac8 acb acf ad2 ad3 ad8 adb adf
ae3 ae6 aea aee af1 af4 af9 afc
aff b02 b03 b08 b09 1 b0b b10
b14 b18 b1b b20 b25 b28 b2c b2d
b32 b35 b3a b3b b40 b43 b48 b49
b4e b51 b55 b59 b5d b61 b64 b65
b67 b6c b6d b6f b70 b75 b78 b7d
b7e b83 b86 b8b b8c b91 b94 b98
b99 b9e ba1 ba6 ba7 bac bad bb2
bb4 bb8 bbb bbf bc3 bc6 bca bce
bd1 bd4 bd9 bdc bdf be2 be3 be8
be9 1 beb bf0 bf4 bf8 bfb c00
c05 c08 c0c c0d c12 c13 c18 c1a
c1e c21 c25 c29 c2c c30 c34 c37
c3b c3f c40 c45 c47 c4b c4e c52
c55 c56 c5b c5e c62 c65 c66 c6b
1 c6e c73 c77 c7b c7f c83 c87
c8b c8f c93 c96 c9a c9e ca1 ca2
ca4 ca7 caa cab cb0 cb3 cb7 cbb
cbe cc2 cc6 cc9 cca ccc ccf cd2
cd3 cd8 1 cdb ce0 ce4 ce8 ceb
cef cf3 cf6 cf9 cfe d01 d04 d07
d08 d0d d0e 1 d10 d15 d19 d1d
d20 d25 d2a d2d d31 d32 d37 d3a
d3f d40 d45 d48 d4d d4e d53 d56
d5a d5e d62 d66 d69 d6a d6c d71
d72 d74 d75 d7a d7d d82 d83 d88
d8b d90 d91 d96 d99 d9d d9e da3
da6 dab dac db1 db2 db7 db9 dbd
dc0 dc4 dc8 dcb dcf dd3 dd6 dd9
dde de1 de4 de7 de8 ded dee 1
df0 df5 df9 dfd e00 e05 e0a e0d
e11 e12 e17 e18 e1d e1f e23 e26
e2a e2e e31 e35 e39 e3c e40 e44
e45 e4a e4c e50 e53 e57 e5b e5f
e63 e67 e6b e6f e73 e77 e83 e87
e8b e8e e92 e96 e98 1 e9c ea0
ea4 ea7 eab eaf eb3 eb7 eba ebe
ec2 ec5 ec8 ecd ed0 ed3 ed6 ed7
edc edd 1 edf ee4 ee8 eec eef
ef4 ef9 efc f00 f01 f06 f09 f0e
f0f f14 f17 f1c f1d f22 f25 f29
f2a f2f f32 f37 f38 f3d f40 f44
f48 f4b f4e f4f f51 f52 f57 f58
f5d f5f f63 f66 f68 f6c f6e f7a
f7c f7e f7f f84 f88 f8a f96 f98
f9c fa0 fa3 fa7 fab fae faf fb1
fb4 fb7 fb8 fbd fc1 fc5 fc9 fcd
fd0 fd4 fd6 fda fde fe1 fe5 fe9
fec fef ff4 ff7 ffa ffd ffe 1003
1004 1 1006 100b 100f 1013 1016 101b
1020 1023 1027 1028 102d 1030 1035 1036
103b 103e 1043 1044 1049 104c 1050 1054
1058 105c 105f 1060 1062 1067 1068 106a
106b 1070 1071 1076 1078 107c 107f 1083
1087 108a 108e 1092 1095 1098 109d 10a0
10a3 10a6 10a7 10ac 10ad 1 10af 10b4
10b8 10bc 10bf 10c4 10c9 10cc 10d0 10d1
10d6 10d7 10dc 10de 10e2 10e5 10e9 10ed
10f0 10f4 10f8 10fb 10ff 1100 1105 1107
110b 110f 1112 1114 1118 111b 111f 1122
1125 1126 112b 112f 1133 1137 113b 113f
1143 1147 114b 114f 1153 1157 115b 115f
1160 1162 1166 116a 116e 1171 1172 1174
1177 117a 117b 1180 1183 1187 118a 118b
1190 1193 1 1196 119b 119f 11a3 11a7
11ab 11af 11b3 11b7 11bb 11bf 11c2 11c3
11c5 11c9 11cb 11cf 11d2 11d6 11d9 11da
11df 11e2 11e6 11ea 11ee 11f2 11f5 11f6
11f8 11fc 11fe 1202 1206 1209 120c 120d
120f 1212 1217 1218 121d 1221 1225 1229
122d 1230 1231 1233 1237 1239 123d 1241
1245 1249 124c 124d 124f 1253 1255 1259
125d 1260 1262 1266 126a 126d 1271 1274
1275 127a 127d 1281 1285 1289 128d 1291
1295 1299 129d 12a1 12a5 12b1 12b5 12b9
12bc 12c0 12c4 12c6 1 12ca 12ce 12d2
12d5 12d9 12dd 12e1 12e5 12e8 12ec 12f0
12f3 12f6 12fb 12fe 1301 1304 1305 130a
130b 1 130d 1312 1316 131a 131d 1322
1327 132a 132e 132f 1334 1337 133c 133d
1342 1345 134a 134b 1350 1353 1357 1358
135d 1360 1365 1366 136b 136e 1372 1376
1379 137c 137d 137f 1380 1385 1386 138b
138d 1391 1394 1396 139a 139c 13a8 13aa
13ac 13ad 13b2 13b6 13b8 13c4 13c6 13ca
13ce 13d2 13d5 13d6 13d8 13db 13df 13e3
13e6 13e7 13e9 13ea 13ef 13f3 13f5 13f9
13fc 1400 1403 1407 140b 140f 1413 1417
141b 141f 1423 1427 142b 142f 1432 1433
1435 1439 143d 1440 1441 1443 1444 1446
144a 144e 1452 1455 1456 1458 145b 145e
145f 1464 1468 146c 146f 1473 1477 147a
147d 1482 1485 1488 148b 148c 1491 1492
1 1494 1499 149d 14a1 14a4 14a9 14ae
14b1 14b5 14b6 14bb 14be 14c3 14c4 14c9
14cc 14d1 14d2 14d7 14da 14de 14e2 14e6
14ea 14ed 14ee 14f0 14f5 14f6 14f8 14f9
14fe 1501 1506 1507 150c 150f 1514 1515
151a 151d 1521 1522 1527 152a 152f 1530
1535 1536 153b 153d 1541 1544 1548 154c
154f 1553 1557 155a 155d 1562 1565 1568
156b 156c 1571 1572 1 1574 1579 157d
1581 1584 1589 158e 1591 1595 1596 159b
159c 15a1 15a3 15a7 15aa 15ae 15b2 15b5
15b9 15bd 15c0 15c4 15c8 15c9 15ce 15d0
15d4 15d8 15dc 15e0 15e4 15e8 15ec 15f0
15f4 15f8 15fc 1600 1604 1608 160c 1610
1614 1618 161c 1620 1624 1628 1634 1638
163d 1641 1644 1645 164a 164e 1652 1655
1658 165c 165e 1662 1666 1669 166c 1670
1672 1676 167a 167d 167f 1 1683 1687
168b 168e 1692 1696 169a 169e 16a1 16a5
16a9 16ac 16af 16b4 16b7 16ba 16bd 16be
16c3 16c4 1 16c6 16cb 16cf 16d3 16d6
16db 16e0 16e3 16e7 16e8 16ed 16f0 16f5
16f6 16fb 16fe 1703 1704 1709 170c 1710
1711 1716 1719 171e 171f 1724 1727 172b
172f 1732 1735 1736 1738 1739 173e 173f
1744 1746 174a 174d 174f 1753 1755 1761
1763 1765 1766 176b 176f 1771 177d 177f
1781 1785 1789 178c 1790 1794 1798 1799
179b 179f 17a3 17a7 17aa 17ae 17b2 17b5
17b8 17bd 17c0 17c3 17c6 17c7 17cc 17cd
1 17cf 17d4 17d8 17dc 17df 17e4 17e9
17ec 17f0 17f1 17f6 17f9 17fe 17ff 1804
1807 180c 180d 1812 1815 1819 181d 1821
1822 1824 1829 182a 182c 182d 1832 1835
183a 183b 1840 1843 1848 1849 184e 1851
1855 1856 185b 185e 1863 1864 1869 186a
186f 1871 1875 1878 187c 1880 1883 1887
188b 188e 1891 1896 1899 189c 189f 18a0
18a5 18a6 1 18a8 18ad 18b1 18b5 18b8
18bd 18c2 18c5 18c9 18ca 18cf 18d0 18d5
18d7 18db 18de 18e2 18e6 18e9 18ed 18f1
18f4 18f5 18f7 18fb 18ff 1900 1905 1909
190d 1910 1914 1918 191b 191e 1923 1926
1929 192c 192d 1932 1933 1 1935 193a
193e 1942 1945 194a 194f 1952 1956 1957
195c 195f 1964 1965 196a 196d 1972 1973
1978 197b 197f 1983 1987 198b 198e 198f
1991 1996 1997 1999 199a 199f 19a2 19a7
19a8 19ad 19b0 19b5 19b6 19bb 19be 19c2
19c3 19c8 19cb 19d0 19d1 19d6 19d7 19dc
19de 19e2 19e5 19e9 19ed 19f0 19f4 19f8
19fb 19ff 1a03 1a04 1a09 1a0b 1a0f 1a13
1a16 1a1a 1a1e 1a21 1a25 1a29 1a2c 1a2f
1a34 1a37 1a3a 1a3d 1a3e 1a43 1a44 1
1a46 1a4b 1a4f 1a53 1a56 1a5b 1a60 1a63
1a67 1a68 1a6d 1a6e 1a73 1a77 1a7b 1a7e
1a83 1a88 1a8b 1a8f 1a93 1a96 1a97 1a9c
1a9f 1aa4 1aa5 1aaa 1aad 1ab1 1ab5 1ab8
1ab9 1abe 1abf 1ac4 1ac6 1aca 1acd 1ad1
1ad5 1ad9 1add 1ae1 1ae5 1ae9 1aed 1af1
1afd 1b02 1b06 1b0a 1b0e 1b12 1b14 1b15
1b1a 1 1b1e 1b22 1b26 1b29 1b2d 1b31
1b35 1b39 1b3c 1b40 1b44 1b47 1b4a 1b4f
1b52 1b55 1b58 1b59 1b5e 1b5f 1 1b61
1b66 1b6a 1b6e 1b71 1b76 1b7b 1b7e 1b82
1b83 1b88 1b89 1b8e 1b92 1b96 1b99 1b9e
1ba3 1ba6 1baa 1bab 1bb0 1bb3 1bb8 1bb9
1bbe 1bc1 1bc5 1bc9 1bcc 1bcf 1bd0 1bd2
1bd3 1bd8 1bd9 1bde 1be0 1be4 1be7 1beb
1bef 1bf3 1bf7 1bfb 1bff 1c03 1c0f 1c14
1c18 1c1c 1c20 1c24 1c26 1c2a 1c2c 1c38
1c3a 1c3c 1c3d 1c42 1c46 1c48 1c54 1c58
1c5a 1c5b 1c64 
7cb
2
0 1 a 6 10 :3 6 16 :3 6
17 :3 6 10 :2 6 1 3 a 13
a :2 1 4 18 21 20 :2 18 :2 4
14 1d 1c :2 14 :2 4 11 1a 19
:2 11 :2 4 :3 13 :2 4 :3 11 :2 4 :3 12 :2 4
:3 12 :2 4 :3 13 :2 4 :3 9 :2 4 :3 9 :2 4
f 18 17 :2 f :2 4 f 18 17
:2 f :2 4 :2 f 1e f :2 4 :2 16 25
16 :2 4 :2 11 20 11 :2 4 :3 10 :2 4
:3 15 :2 4 :2 12 21 12 :2 4 :2 d 1c
d :2 4 :2 11 20 11 :2 4 :2 13 22
13 :2 4 e 17 16 :2 e :2 4 d
16 15 :2 d :2 4 f 18 17 :2 f
:2 4 :2 d 1c d :2 4 :2 e 1d e
:2 4 :2 c 1b c :2 4 :2 14 23 14
:2 4 :2 13 22 13 :2 4 :2 12 21 12
:2 4 :2 11 20 11 :2 4 :2 b 1a b
:2 4 :2 b 1a b :2 4 :2 f 1e f
:2 4 :2 e 1d e :2 4 :2 e 1d e
:2 4 :2 10 1f 10 :2 4 :2 13 22 13
:2 4 :2 f 1e f :2 4 :2 e 1d e
:2 4 :2 f 1e f :2 4 :2 c 1b c
:2 4 :2 b 1a b :2 4 :2 13 22 13
:2 4 :2 14 23 14 :2 4 :2 f 1e f
:2 4 :2 f 19 f :2 4 :2 f 19 f
:2 4 :2 10 1a 10 :2 4 :2 10 1a 10
:2 4 :2 11 1b 11 :2 4 :2 11 1b 11
:2 4 :2 12 1c 12 :2 4 :2 12 1c 12
:2 4 e 17 :3 e 4 7 :2 11 23
:2 2d 3a :2 23 :3 7 :2 d 19 25 :2 2f
43 :2 25 55 5b 5e :2 55 6c 83
8 :2 6c d 10 :2 6c 1a 1d :2 6c
b e :2 6c 13 16 1f 26 2b
2e :2 26 3e 41 :2 26 46 :2 1f 4f
:2 16 :2 6c b e :2 6c 13 16 1f
26 2b 2e :2 26 3f 42 :2 26 47
:2 1f 50 :2 16 :2 6c b e :2 6c 13
16 :2 6c 1b 1e :2 6c 28 2b :2 6c
30 33 :2 6c :2 7 4b :2 4 7 :2 11
23 :2 2d 39 3c 4d 4f 50 :2 4d
:2 23 :3 7 :2 d 12 1e 5e 61 :2 1e
:2 7 53 :3 4 1b :2 4 12 4 e
25 31 7 16 20 30 3b 45
4d 7 12 20 2d 3f 11 25
37 47 59 7 f 16 31 39
40 5c 66 7 15 23 31 7
17 27 37 7 1a c 1d 2b
7 13 1f 31 3c 44 4d 7
18 28 37 45 7 11 1a 7
d 13 1f 7 13 20 2c 7
15 24 32 7 17 c d 21
:2 7 :2 10 1c 7 4 :2 c a :2 13
1f a d :2 17 29 :2 33 3f 43
54 57 58 :2 54 :2 29 :3 d :2 13 18
24 65 68 :2 24 75 78 :2 24 7c
7f :2 24 8b 8e :2 24 96 99 :2 24
a5 a8 af b8 bb :2 a8 :2 24 :2 d
5b :2 a :2 7 :4 13 :2 7 4 :3 1 8
:2 11 1c 1a :2 25 :2 1a 7 a :2 14
26 :2 30 3c 40 51 54 55 :2 51
:2 26 :3 a :2 10 15 21 62 65 :2 21
72 75 :2 21 79 7c :2 21 86 89
92 9a :2 a3 :2 92 b6 :2 89 :2 21 be
c1 :2 21 c9 cc :2 21 d1 d4 :2 21
e8 eb :2 21 :2 a 58 :2 7 a :2 14
26 :2 30 3c 3f 50 53 54 :2 50
:2 26 :3 a :2 10 15 21 62 65 :2 21
:2 a 57 :3 7 :2 12 26 :2 2f 41 f
:2 7 35 :2 4 :4 8 7 :4 2a 29 :3 7
18 :2 7 19 7 b :2 16 1e 2d
3d :2 b 41 43 :2 41 a 4b :2 56
d 1d 2c :2 4b 30 33 :2 30 4a
:2 a d :2 17 29 :2 33 3f 43 54
57 58 :2 54 :2 29 :3 d :2 13 18 24
65 68 :2 24 75 78 :2 24 7c 7f
:2 24 89 8c 95 9d :2 a6 :2 95 c3
:2 8c :2 24 cb ce :2 24 d6 d9 :2 24
de e1 :2 24 f5 f8 :2 24 :2 d 5b
:2 a d :2 17 29 :2 33 3f 42 53
56 57 :2 53 :2 29 :3 d :2 13 18 24
65 68 :2 24 :2 d 5a :3 a :2 15 29
:2 32 4e 12 :2 a 36 :2 7 11 1d
f 1d f 1d 2a 3b 48 :2 a
:2 13 1f a 7 :2 f d :2 16 22
d 10 :2 1a 2c :2 36 42 46 57
5a 5b :2 57 :2 2c :3 10 :2 16 1b 27
68 6b :2 27 78 7b :2 27 7f 82
:2 27 8e 91 :2 27 99 9c :2 27 a8
ab b2 bb be :2 ab :2 27 :2 10 5e
:2 d :2 a :4 16 :2 a 7 :3 48 a :2 15
1d 2c 3a :2 a 3e 41 :2 3e a
1a :2 a 15 a 43 d :2 17 29
:2 33 3f 42 53 56 57 :2 53 :2 29
:3 d :2 13 18 24 65 68 :2 24 75
78 :2 24 7c 7f :2 24 89 8c 95
9d :2 a6 :2 95 b7 :2 8c :2 24 :2 d 5a
:2 a d :2 17 29 :2 33 3f 42 53
56 57 :2 53 :2 29 :3 d :2 13 18 24
65 68 :2 24 :2 d 5a :3 a :2 15 2b
:2 34 44 :2 a :4 7 48 :3 4 14 15
:2 14 :2 4 17 2e 3c 47 5c 62
2d 39 45 53 2d :2 17 4 8
11 1d :2 8 20 22 :2 20 7 :4 2b
2a 29 :3 7 15 2a 38 43 4d
26 3b 4d 59 :2 15 7 4a :2 4
:4 8 :2 7 1a 2a 38 4d :2 1a 7
25 a 11 1d 20 :2 a 23 25
:2 23 a 1d 2d 3b 50 :2 1d a
29 a 1d 2d 3b 50 :2 1d a
:4 7 :4 4 :4 8 7 11 1c 29 31
38 53 5e 63 :2 f :2 a :2 13 1f
a 7 :2 f d :2 16 22 d 10
:2 1a 2c :2 36 42 46 57 5a 5b
:2 57 :2 2c :3 10 :2 16 1b 27 68 6b
:2 27 78 7b :2 27 7f 82 :2 27 8e
91 :2 27 99 9c :2 27 a8 ab b2
bb be :2 ab :2 27 :2 10 5e :2 d :2 a
:4 16 :2 a 7 :3 26 7 13 1c 26
:2 13 29 2b 34 43 :2 2b :2 13 7
26 :3 4 12 :2 4 17 25 3a 48
52 5e 24 30 39 42 :2 30 46
4f 60 :2 46 :2 17 4 7 10 21
:2 7 24 27 :2 24 a :2 14 26 :2 30
3c 40 51 54 55 :2 51 :2 26 :3 a
:2 10 15 21 62 65 :2 21 72 75
:2 21 79 7c :2 21 86 89 92 9a
:2 a3 :2 92 bb :2 89 :2 21 c3 c6 :2 21
ce d1 :2 21 d6 d9 :2 21 ed f0
:2 21 :2 a 58 :2 7 a :2 14 26 :2 30
3c 3f 50 53 54 :2 50 :2 26 :3 a
:2 10 15 21 62 65 :2 21 :2 a 57
:3 7 :2 12 26 :2 2f 46 f :2 7 29
11 26 34 42 4b 52 5f 68
75 7e a 19 22 2e 3e 4e
57 64 a 1e 10 24 a 11
d 19 :3 17 d :2 16 22 d 1e
d :2 16 22 d :4 a 7 :2 f d
:2 16 22 d 10 :2 1a 2c :2 36 42
46 57 5a 5b :2 57 :2 2c :3 10 :2 16
1b 27 68 6b :2 27 78 7b :2 27
7f 82 :2 27 8e 91 :2 27 99 9c
:2 27 a8 ab b2 bb be :2 ab :2 27
:2 10 5e :2 d :2 a :4 16 :2 a 7 :8 4
12 1c :2 12 4 7 :2 11 23 :2 2d
39 3d 4e 51 52 :2 4e :2 23 :3 7
:2 d 12 1e 5f 62 :2 1e 6f 72
:2 1e 76 79 :2 1e 83 86 8f 97
:2 8f a4 :2 86 :2 1e ac af :2 1e b7
ba :2 1e bf c2 :2 1e d6 d9 :2 1e
:2 7 55 :2 4 7 :2 11 23 :2 2d 39
3c 4d 50 51 :2 4d :2 23 :3 7 :2 d
12 1e 5f 62 :2 1e :2 7 54 :3 4
:2 f 23 2c 38 :2 23 3c c :2 4
7 :2 11 23 :2 2d 39 3c 4d 50
51 :2 4d :2 23 :3 7 :2 d 12 1e 5f
62 :2 1e 6f 72 :2 1e 76 79 :2 1e
83 86 8f 97 :2 a0 :2 8f ab :2 86
:2 1e b3 b6 :2 1e be c1 :2 1e c6
c9 :2 1e dd e0 :2 1e :2 7 54 :3 4
:2 f 21 :2 2a 34 49 :2 4 1 9
12 9 a :2 14 26 :2 30 3c 40
51 54 55 :2 51 :2 26 :3 a :2 10 15
21 62 65 :2 21 :3 a :2 10 15 39
5c 5f :2 68 :2 39 76 79 :2 39 81
84 :2 8d :2 39 :2 a 58 :3 7 c 15
1e 2c a 13 1e f e 7
e 7 e 7 29 :2 4 :2 9 7
:2 10 1c :2 7 :2 11 23 :2 2d 39 3d
4e 51 52 :2 4e :2 23 :3 7 :2 d 12
1e 5f 62 :2 1e :3 7 :2 d 12 36
42 45 :2 36 4d 50 :2 36 5c 5f
66 6f 72 :2 5f :2 36 :2 7 55 :2 4
7 c 1b a 13 1e f e
7 e 7 e 7 :2 4 :4 10 :2 4
:8 1 
7cb
4
0 :2 1 :4 3 :4 4
:4 5 :4 6 2 :4 7
:2 1 :7 9 :7 a :7 b
:5 c :5 d :5 e :5 f
:5 10 :5 11 :5 12 :7 13
:7 14 :6 15 :6 16 :6 17
:5 18 :5 19 :6 1a :6 1b
:6 1c :6 1d :7 1e :7 1f
:7 20 :6 21 :6 22 :6 23
:6 24 :6 25 :6 26 :6 27
:6 28 :6 29 :6 2a :6 2b
:6 2c :6 2d :6 2e :6 2f
:6 30 :6 31 :6 32 :6 33
:6 34 :6 35 :6 36 :6 37
:6 38 :6 39 :6 3a :6 3b
:6 3c :6 3d :6 3e :7 40
:b 42 :11 43 44 :2 43
:2 44 :2 43 :2 44 :2 43
:2 45 :2 43 :12 45 :2 43
:2 46 :2 43 :12 46 :2 43
:2 47 :2 43 :2 47 :2 43
:2 47 :2 43 :2 47 :2 43
:2 47 :4 43 :3 42 :11 4a
:b 4b :3 4a :3 51 :3 52
:3 55 :7 56 :5 57 :5 58
:8 59 :4 5a :4 5b :2 5c
:3 5d :7 5e :5 5f :3 60
:4 61 :4 62 :4 63 :2 64
65 :2 66 55 :5 67
54 :2 69 :5 6b :11 6c
:24 6d :3 6c :2 6a :6 69
68 :3 41 :a 73 :11 74
:30 75 :3 74 :11 77 :b 78
:3 77 :7 7a 7b :2 7a
:3 73 :c 7e :3 7f :3 80
:10 82 :3 83 :2 82 :4 83
:3 82 :11 84 :30 85 :3 84
:11 87 :b 88 :3 87 :7 8a
8b :2 8a 83 :2 82
:2 8f :2 90 :5 91 8f
:5 92 8e :2 94 :5 96
:11 97 :24 98 :3 97 :2 95
:6 94 93 :3 7e :c 9f
:3 a0 :3 a1 9f :11 a3
:20 a4 :3 a3 :11 a6 :b a7
:3 a6 :9 a9 a2 :3 9f
:3 7e :6 ae :7 af :4 b0
b1 :3 af :12 b3 :6 b4
:4 b5 :3 b4 :3 b3 :5 b9
:8 ba b9 :a bc :8 bd
bc :8 bf be :3 bc
bb :3 b9 :5 c3 :8 c5
c6 c7 c5 :5 c8
c4 :2 ca :5 cc :11 cd
:24 ce :3 cd :2 cb :6 ca
c9 :3 c3 :f d3 :3 c3
:3 d8 :7 d9 :b da :3 d9
:9 dd :11 de :30 df :3 de
:11 e1 :b e2 :3 e1 :7 e4
e5 :2 e4 dd :a e8
:8 e9 :2 ea :2 eb e8
:6 ec :5 ed ec :5 ef
ee :3 ec e7 :2 f2
:5 f4 :11 f5 :24 f6 :3 f5
:2 f3 :6 f2 f1 :4 e6
:3 dd :6 fc :11 fd :2e fe
:3 fd :11 100 :b 101 :3 100
:9 103 104 :2 103 :11 106
:30 107 :3 106 :a 109 41
:3 10c :11 10d :b 10e :17 10f
:3 10d :2 111 :3 112 :3 113
114 112 111 112
:3 115 :3 10c :2 116 :5 118
:11 119 :b 11a :18 11b :3 119
:2 11d 11e :3 11f 120
11e 11d 11e :3 121
:2 117 :6 116 10b :7 1

1c66
4
:3 0 1 :3 0 2
:a 0 7c6 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
56 0 7 6
:3 0 5 :7 0 9
8 :3 0 6 :3 0
7 :7 0 d c
:3 0 15 16 0
b 4 :3 0 8
:7 0 11 10 :3 0
9 :3 0 a :3 0
b :2 0 4 13
17 0 7c6 2
18 :2 0 d :2 0
12 4 :3 0 d
:2 0 10 1b 1d
:6 0 20 1e 0
7c4 0 c :6 0
d :2 0 16 4
:3 0 14 22 24
:6 0 27 25 0
7c4 0 e :6 0
1c d9 0 1a
4 :3 0 18 29
2b :6 0 2e 2c
0 7c4 0 f
:6 0 20 10d 0
1e 6 :3 0 30
:7 0 33 31 0
7c4 0 10 :6 0
6 :3 0 35 :7 0
38 36 0 7c4
0 11 :6 0 24
141 0 22 6
:3 0 3a :7 0 3d
3b 0 7c4 0
12 :6 0 6 :3 0
3f :7 0 42 40
0 7c4 0 13
:6 0 28 175 0
26 6 :3 0 44
:7 0 47 45 0
7c4 0 14 :6 0
16 :3 0 49 :7 0
4c 4a 0 7c4
0 15 :6 0 19
:2 0 2c 16 :3 0
4e :7 0 51 4f
0 7c4 0 17
:6 0 4 :3 0 19
:2 0 2a 53 55
:6 0 58 56 0
7c4 0 18 :6 0
1d :2 0 30 4
:3 0 2e 5a 5c
:6 0 5f 5d 0
7c4 0 1a :6 0
1d :2 0 32 1c
:3 0 61 :7 0 65
62 63 7c4 0
1b :6 0 1d :2 0
34 1c :3 0 67
:7 0 6b 68 69
7c4 0 1e :6 0
38 21e 0 36
1c :3 0 6d :7 0
71 6e 6f 7c4
0 1f :6 0 1d
:2 0 3a 16 :3 0
73 :7 0 76 74
0 7c4 0 20
:6 0 16 :3 0 78
:7 0 7b 79 0
7c4 0 21 :6 0
1d :2 0 3c 1c
:3 0 7d :7 0 81
7e 7f 7c4 0
22 :6 0 1d :2 0
3e 1c :3 0 83
:7 0 87 84 85
7c4 0 23 :6 0
1d :2 0 40 1c
:3 0 89 :7 0 8d
8a 8b 7c4 0
24 :6 0 d :2 0
42 1c :3 0 8f
:7 0 93 90 91
7c4 0 25 :6 0
d :2 0 46 4
:3 0 44 95 97
:6 0 9a 98 0
7c4 0 26 :6 0
d :2 0 4a 4
:3 0 48 9c 9e
:6 0 a1 9f 0
7c4 0 27 :6 0
1d :2 0 4e 4
:3 0 4c a3 a5
:6 0 a8 a6 0
7c4 0 28 :6 0
1d :2 0 50 1c
:3 0 aa :7 0 ae
ab ac 7c4 0
29 :6 0 1d :2 0
52 1c :3 0 b0
:7 0 b4 b1 b2
7c4 0 2a :6 0
1d :2 0 54 1c
:3 0 b6 :7 0 ba
b7 b8 7c4 0
2b :6 0 1d :2 0
56 1c :3 0 bc
:7 0 c0 bd be
7c4 0 2c :6 0
1d :2 0 58 1c
:3 0 c2 :7 0 c6
c3 c4 7c4 0
2d :6 0 1d :2 0
5a 1c :3 0 c8
:7 0 cc c9 ca
7c4 0 2e :6 0
1d :2 0 5c 1c
:3 0 ce :7 0 d2
cf d0 7c4 0
2f :6 0 1d :2 0
5e 1c :3 0 d4
:7 0 d8 d5 d6
7c4 0 30 :6 0
1d :2 0 60 1c
:3 0 da :7 0 de
db dc 7c4 0
31 :6 0 1d :2 0
62 1c :3 0 e0
:7 0 e4 e1 e2
7c4 0 32 :6 0
1d :2 0 64 1c
:3 0 e6 :7 0 ea
e7 e8 7c4 0
33 :6 0 1d :2 0
66 1c :3 0 ec
:7 0 f0 ed ee
7c4 0 34 :6 0
1d :2 0 68 1c
:3 0 f2 :7 0 f6
f3 f4 7c4 0
35 :6 0 1d :2 0
6a 1c :3 0 f8
:7 0 fc f9 fa
7c4 0 36 :6 0
1d :2 0 6c 1c
:3 0 fe :7 0 102
ff 100 7c4 0
37 :6 0 1d :2 0
6e 1c :3 0 104
:7 0 108 105 106
7c4 0 38 :6 0
1d :2 0 70 1c
:3 0 10a :7 0 10e
10b 10c 7c4 0
39 :6 0 1d :2 0
72 1c :3 0 110
:7 0 114 111 112
7c4 0 3a :6 0
1d :2 0 74 1c
:3 0 116 :7 0 11a
117 118 7c4 0
3b :6 0 1d :2 0
76 1c :3 0 11c
:7 0 120 11d 11e
7c4 0 3c :6 0
1d :2 0 78 1c
:3 0 122 :7 0 126
123 124 7c4 0
3d :6 0 1d :2 0
7a 1c :3 0 128
:7 0 12c 129 12a
7c4 0 3e :6 0
1d :2 0 7c 40
:3 0 12e :7 0 132
12f 130 7c4 0
3f :6 0 1d :2 0
7e 40 :3 0 134
:7 0 138 135 136
7c4 0 41 :6 0
1d :2 0 80 40
:3 0 13a :7 0 13e
13b 13c 7c4 0
42 :6 0 1d :2 0
82 40 :3 0 140
:7 0 144 141 142
7c4 0 43 :6 0
1d :2 0 84 40
:3 0 146 :7 0 14a
147 148 7c4 0
44 :6 0 1d :2 0
86 40 :3 0 14c
:7 0 150 14d 14e
7c4 0 45 :6 0
1d :2 0 88 40
:3 0 152 :7 0 156
153 154 7c4 0
46 :6 0 15e 15f
0 8a 40 :3 0
158 :7 0 15c 159
15a 7c4 0 47
:6 0 164 165 0
8c a :3 0 b
:2 0 4 160 :7 0
163 161 0 7c4
0 48 :6 0 49
:3 0 4a :3 0 49
:3 0 4b :3 0 167
168 0 2 :4 0
8e 169 16b 166
16d 16c :2 0 4c
:3 0 4d :3 0 16f
170 0 4e :4 0
49 :3 0 4f :3 0
173 174 0 2
:4 0 90 175 177
50 :4 0 51 :2 0
52 :3 0 92 17a
17c :3 0 53 :4 0
51 :2 0 54 :4 0
95 17f 181 :3 0
51 :2 0 3 :3 0
98 183 185 :3 0
51 :2 0 54 :4 0
9b 187 189 :3 0
51 :2 0 55 :4 0
9e 18b 18d :3 0
51 :2 0 56 :3 0
57 :3 0 54 :4 0
51 :2 0 5 :3 0
a1 193 195 :3 0
51 :2 0 54 :4 0
a4 197 199 :3 0
58 :4 0 a7 191
19c 59 :4 0 aa
190 19f ad 18f
1a1 :3 0 51 :2 0
55 :4 0 b0 1a3
1a5 :3 0 51 :2 0
56 :3 0 57 :3 0
54 :4 0 51 :2 0
7 :3 0 b3 1ab
1ad :3 0 51 :2 0
54 :4 0 b6 1af
1b1 :3 0 58 :4 0
b9 1a9 1b4 59
:4 0 bc 1a8 1b7
bf 1a7 1b9 :3 0
51 :2 0 55 :4 0
c2 1bb 1bd :3 0
51 :2 0 54 :4 0
c5 1bf 1c1 :3 0
51 :2 0 8 :3 0
c8 1c3 1c5 :3 0
51 :2 0 54 :4 0
cb 1c7 1c9 :3 0
51 :2 0 5a :4 0
ce 1cb 1cd :3 0
d1 171 1cf :2 0
1d1 d6 1d2 16e
1d1 0 1d3 d8
0 724 49 :3 0
4a :3 0 1d4 1d5
0 49 :3 0 5b
:3 0 1d7 1d8 0
19 :2 0 2 :4 0
5c :2 0 5d :2 0
19 :2 0 da 1dd
1df :3 0 dd 1d9
1e1 1d6 1e3 1e2
:2 0 4c :3 0 5e
:3 0 1e5 1e6 0
4e :4 0 5f :4 0
51 :2 0 52 :3 0
e1 1ea 1ec :3 0
e4 1e7 1ee :2 0
1f0 e7 1f1 1e4
1f0 0 1f2 e9
0 724 c :3 0
3 :3 0 1f3 1f4
0 724 28 :3 0
8 :3 0 1f6 1f7
0 724 60 :3 0
61 :3 0 62 :3 0
63 :3 0 64 :3 0
65 :3 0 66 :3 0
67 :3 0 68 :3 0
69 :3 0 6a :3 0
6b :3 0 6c :3 0
6d :3 0 6e :3 0
64 :3 0 6f :3 0
70 :3 0 71 :3 0
72 :3 0 73 :3 0
74 :3 0 6d :3 0
73 :3 0 74 :3 0
6e :3 0 75 :3 0
76 :3 0 77 :3 0
78 :3 0 79 :3 0
7a :3 0 7b :3 0
7c :3 0 7d :3 0
7e :3 0 7f :3 0
80 :3 0 e :3 0
f :3 0 27 :3 0
1a :3 0 18 :3 0
21 :3 0 2a :3 0
30 :3 0 3a :3 0
3b :3 0 2c :3 0
10 :3 0 2e :3 0
11 :3 0 12 :3 0
29 :3 0 2b :3 0
32 :3 0 15 :3 0
17 :3 0 1b :3 0
1e :3 0 3f :3 0
42 :3 0 41 :3 0
43 :3 0 44 :3 0
46 :3 0 45 :3 0
47 :3 0 2d :3 0
26 :3 0 81 :3 0
82 :3 0 c :4 0
83 1 :8 0 248
a :3 0 84 :3 0
243 244 0 85
:3 0 245 246 0
248 eb 292 86
:3 0 a :3 0 84
:3 0 24b 24c 0
85 :3 0 24d 24e
0 288 49 :3 0
4a :3 0 250 251
0 49 :3 0 5b
:3 0 253 254 0
87 :2 0 2 :4 0
88 :2 0 5d :2 0
19 :2 0 ee 259
25b :3 0 f1 255
25d 252 25f 25e
:2 0 4c :3 0 5e
:3 0 261 262 0
4e :4 0 89 :4 0
51 :2 0 52 :3 0
f5 266 268 :3 0
51 :2 0 8a :4 0
f8 26a 26c :3 0
51 :2 0 8b :4 0
fb 26e 270 :3 0
51 :2 0 85 :3 0
fe 272 274 :3 0
51 :2 0 8c :4 0
101 276 278 :3 0
51 :2 0 74 :3 0
8d :3 0 19 :2 0
8e :2 0 104 27b
27f 108 27a 281
:3 0 10b 263 283
:2 0 285 10e 286
260 285 0 287
110 0 288 112
28b :3 0 28b 0
28b 28a 288 289
:6 0 28d 2 :3 0
115 28f 117 28e
28d :2 0 290 119
:2 0 292 0 292
291 248 290 :6 0
724 1 :3 0 a
:3 0 84 :3 0 294
295 0 a :3 0
8f :2 0 90 :3 0
297 299 0 11d
298 29b :3 0 29c
:2 0 49 :3 0 4a
:3 0 29e 29f 0
49 :3 0 5b :3 0
2a1 2a2 0 d
:2 0 2 :4 0 91
:2 0 5d :2 0 19
:2 0 120 2a7 2a9
:3 0 123 2a3 2ab
2a0 2ad 2ac :2 0
4c :3 0 5e :3 0
2af 2b0 0 4e
:4 0 92 :4 0 51
:2 0 52 :3 0 127
2b4 2b6 :3 0 51
:2 0 8a :4 0 12a
2b8 2ba :3 0 51
:2 0 93 :4 0 12d
2bc 2be :3 0 51
:2 0 56 :3 0 94
:3 0 95 :3 0 96
:3 0 2c3 2c4 0
130 2c2 2c6 59
:4 0 132 2c1 2c9
135 2c0 2cb :3 0
51 :2 0 97 :4 0
138 2cd 2cf :3 0
51 :2 0 54 :4 0
13b 2d1 2d3 :3 0
51 :2 0 c :3 0
13e 2d5 2d7 :3 0
51 :2 0 54 :4 0
141 2d9 2db :3 0
144 2b1 2dd :2 0
2df 147 2e0 2ae
2df 0 2e1 149
0 30b 49 :3 0
4a :3 0 2e2 2e3
0 49 :3 0 5b
:3 0 2e5 2e6 0
19 :2 0 2 :4 0
98 :2 0 5d :2 0
19 :2 0 14b 2eb
2ed :3 0 14e 2e7
2ef 2e4 2f1 2f0
:2 0 4c :3 0 5e
:3 0 2f3 2f4 0
4e :4 0 99 :4 0
51 :2 0 52 :3 0
152 2f8 2fa :3 0
155 2f5 2fc :2 0
2fe 158 2ff 2f2
2fe 0 300 15a
0 30b 9a :3 0
9b :3 0 301 302
0 95 :3 0 96
:3 0 304 305 0
c :3 0 9c :3 0
15c 303 309 :2 0
30b 160 30c 29d
30b 0 30d 164
0 724 5 :3 0
9d :2 0 166 30f
310 :3 0 311 :2 0
7 :3 0 9d :2 0
168 314 315 :3 0
316 :2 0 312 318
317 :2 0 13 :3 0
5 :3 0 31a 31b
0 47a 14 :3 0
7 :3 0 31d 31e
0 47a 9e :3 0
9f :3 0 320 321
0 13 :3 0 14
:3 0 a0 :2 0 16a
322 326 a1 :2 0
1d :2 0 170 328
32a :3 0 32b :2 0
9e :3 0 9f :3 0
32d 32e 0 14
:3 0 12 :3 0 a0
:2 0 173 32f 333
a2 :2 0 1d :2 0
179 335 337 :3 0
338 :2 0 32c 33a
339 :2 0 49 :3 0
4a :3 0 33c 33d
0 49 :3 0 5b
:3 0 33f 340 0
d :2 0 2 :4 0
a3 :2 0 5d :2 0
19 :2 0 17c 345
347 :3 0 17f 341
349 33e 34b 34a
:2 0 4c :3 0 5e
:3 0 34d 34e 0
4e :4 0 a4 :4 0
51 :2 0 52 :3 0
183 352 354 :3 0
51 :2 0 8a :4 0
186 356 358 :3 0
51 :2 0 93 :4 0
189 35a 35c :3 0
51 :2 0 56 :3 0
94 :3 0 95 :3 0
a5 :3 0 361 362
0 18c 360 364
59 :4 0 18e 35f
367 191 35e 369
:3 0 51 :2 0 97
:4 0 194 36b 36d
:3 0 51 :2 0 54
:4 0 197 36f 371
:3 0 51 :2 0 c
:3 0 19a 373 375
:3 0 51 :2 0 54
:4 0 19d 377 379
:3 0 1a0 34f 37b
:2 0 37d 1a3 37e
34c 37d 0 37f
1a5 0 3a9 49
:3 0 4a :3 0 380
381 0 49 :3 0
5b :3 0 383 384
0 19 :2 0 2
:4 0 a6 :2 0 5d
:2 0 19 :2 0 1a7
389 38b :3 0 1aa
385 38d 382 38f
38e :2 0 4c :3 0
5e :3 0 391 392
0 4e :4 0 a7
:4 0 51 :2 0 52
:3 0 1ae 396 398
:3 0 1b1 393 39a
:2 0 39c 1b4 39d
390 39c 0 39e
1b6 0 3a9 9a
:3 0 9b :3 0 39f
3a0 0 95 :3 0
a5 :3 0 3a2 3a3
0 c :3 0 9c
:3 0 1b8 3a1 3a7
:2 0 3a9 1bc 3aa
33b 3a9 0 3ab
1c0 0 47a 61
:3 0 a8 :3 0 f
:3 0 34 :3 0 a9
:3 0 61 :3 0 f
:3 0 aa :3 0 26
:4 0 ab 1 :8 0
3bb a :3 0 84
:3 0 3b6 3b7 0
85 :3 0 3b8 3b9
0 3bb 1c2 405
86 :3 0 a :3 0
84 :3 0 3be 3bf
0 85 :3 0 3c0
3c1 0 3fb 49
:3 0 4a :3 0 3c3
3c4 0 49 :3 0
5b :3 0 3c6 3c7
0 87 :2 0 2
:4 0 ac :2 0 5d
:2 0 19 :2 0 1c5
3cc 3ce :3 0 1c8
3c8 3d0 3c5 3d2
3d1 :2 0 4c :3 0
5e :3 0 3d4 3d5
0 4e :4 0 ad
:4 0 51 :2 0 52
:3 0 1cc 3d9 3db
:3 0 51 :2 0 8a
:4 0 1cf 3dd 3df
:3 0 51 :2 0 8b
:4 0 1d2 3e1 3e3
:3 0 51 :2 0 85
:3 0 1d5 3e5 3e7
:3 0 51 :2 0 8c
:4 0 1d8 3e9 3eb
:3 0 51 :2 0 74
:3 0 8d :3 0 19
:2 0 8e :2 0 1db
3ee 3f2 1df 3ed
3f4 :3 0 1e2 3d6
3f6 :2 0 3f8 1e5
3f9 3d3 3f8 0
3fa 1e7 0 3fb
1e9 3fe :3 0 3fe
0 3fe 3fd 3fb
3fc :6 0 400 4
:3 0 1ec 402 1ee
401 400 :2 0 403
1f0 :2 0 405 0
405 404 3bb 403
:6 0 47a 1 :3 0
9e :3 0 9f :3 0
407 408 0 13
:3 0 11 :3 0 a0
:2 0 1f2 409 40d
a2 :2 0 1d :2 0
1f8 40f 411 :3 0
11 :3 0 13 :3 0
413 414 0 419
2b :3 0 1d :2 0
416 417 0 419
1fb 477 49 :3 0
4a :3 0 41a 41b
0 49 :3 0 5b
:3 0 41d 41e 0
ae :2 0 2 :4 0
af :2 0 5d :2 0
19 :2 0 1fe 423
425 :3 0 201 41f
427 41c 429 428
:2 0 4c :3 0 5e
:3 0 42b 42c 0
4e :4 0 b0 :4 0
51 :2 0 52 :3 0
205 430 432 :3 0
51 :2 0 8a :4 0
208 434 436 :3 0
51 :2 0 93 :4 0
20b 438 43a :3 0
51 :2 0 56 :3 0
94 :3 0 95 :3 0
b1 :3 0 43f 440
0 20e 43e 442
59 :4 0 210 43d
445 213 43c 447
:3 0 216 42d 449
:2 0 44b 219 44c
42a 44b 0 44d
21b 0 476 49
:3 0 4a :3 0 44e
44f 0 49 :3 0
5b :3 0 451 452
0 19 :2 0 2
:4 0 b2 :2 0 5d
:2 0 19 :2 0 21d
457 459 :3 0 220
453 45b 450 45d
45c :2 0 4c :3 0
5e :3 0 45f 460
0 4e :4 0 b3
:4 0 51 :2 0 52
:3 0 224 464 466
:3 0 227 461 468
:2 0 46a 22a 46b
45e 46a 0 46c
22c 0 476 9a
:3 0 b4 :3 0 46d
46e 0 95 :3 0
b1 :3 0 470 471
0 9c :3 0 22e
46f 474 :2 0 476
231 478 412 419
0 479 0 476
0 479 235 0
47a 238 47b 319
47a 0 47c 23e
0 724 1f :3 0
b5 :2 0 19 :2 0
240 47e 480 :3 0
47d 481 0 724
3d :3 0 b6 :3 0
f :3 0 26 :3 0
c :3 0 15 :3 0
17 :3 0 3f :3 0
41 :3 0 1f :3 0
1e :3 0 1b :3 0
242 484 48f 483
490 0 724 56
:3 0 32 :3 0 1d
:2 0 24d 492 495
a1 :2 0 1d :2 0
252 497 499 :3 0
49a :2 0 21 :3 0
9d :2 0 255 49d
49e :3 0 49f :2 0
4a0 :2 0 49b 4a2
4a1 :2 0 3e :3 0
b7 :3 0 f :3 0
26 :3 0 27 :3 0
e :3 0 c :3 0
21 :3 0 32 :3 0
1d :2 0 257 4a5
4ae 4a4 4af 0
4b1 260 4b2 4a3
4b1 0 4b3 262
0 724 e :3 0
9d :2 0 264 4b5
4b6 :3 0 4b7 :2 0
3d :3 0 b8 :3 0
f :3 0 c :3 0
b9 :2 0 266 4ba
4be 4b9 4bf 0
4c1 26a 4e2 74
:3 0 18 :3 0 19
:2 0 19 :2 0 26c
4c2 4c6 8f :2 0
b9 :4 0 272 4c8
4ca :3 0 3d :3 0
b8 :3 0 f :3 0
c :3 0 1d :2 0
275 4cd 4d1 4cc
4d2 0 4d4 279
4de 3d :3 0 b8
:3 0 f :3 0 c
:3 0 19 :2 0 27b
4d6 4da 4d5 4db
0 4dd 27f 4df
4cb 4d4 0 4e0
0 4dd 0 4e0
281 0 4e1 284
4e3 4b8 4c1 0
4e4 0 4e1 0
4e4 286 0 724
21 :3 0 9d :2 0
289 4e6 4e7 :3 0
4e8 :2 0 9e :3 0
ba :3 0 73 :3 0
74 :3 0 21 :3 0
9e :3 0 bb :3 0
11 :3 0 11 :3 0
bc :4 0 bd 1
:8 0 4fa a :3 0
84 :3 0 4f5 4f6
0 85 :3 0 4f7
4f8 0 4fa 28b
544 86 :3 0 a
:3 0 84 :3 0 4fd
4fe 0 85 :3 0
4ff 500 0 53a
49 :3 0 4a :3 0
502 503 0 49
:3 0 5b :3 0 505
506 0 87 :2 0
2 :4 0 be :2 0
5d :2 0 19 :2 0
28e 50b 50d :3 0
291 507 50f 504
511 510 :2 0 4c
:3 0 5e :3 0 513
514 0 4e :4 0
bf :4 0 51 :2 0
52 :3 0 295 518
51a :3 0 51 :2 0
8a :4 0 298 51c
51e :3 0 51 :2 0
8b :4 0 29b 520
522 :3 0 51 :2 0
85 :3 0 29e 524
526 :3 0 51 :2 0
8c :4 0 2a1 528
52a :3 0 51 :2 0
74 :3 0 8d :3 0
19 :2 0 8e :2 0
2a4 52d 531 2a8
52c 533 :3 0 2ab
515 535 :2 0 537
2ae 538 512 537
0 539 2b0 0
53a 2b2 53d :3 0
53d 0 53d 53c
53a 53b :6 0 53f
6 :3 0 2b5 541
2b7 540 53f :2 0
542 2b9 :2 0 544
0 544 543 4fa
542 :6 0 555 1
:3 0 29 :3 0 56
:3 0 29 :3 0 1d
:2 0 2bb 547 54a
b5 :2 0 56 :3 0
2e :3 0 1d :2 0
2be 54d 550 2c1
54c 552 :3 0 546
553 0 555 2c4
556 4e9 555 0
557 2c7 0 724
3e :3 0 b9 :2 0
558 559 0 724
3d :3 0 c0 :3 0
c :3 0 11 :3 0
29 :3 0 3e :3 0
2a :3 0 28 :3 0
56 :3 0 2b :3 0
1d :2 0 2c9 563
566 56 :3 0 2c
:3 0 1d :2 0 2cc
568 56b 2cf 55c
56d 55b 56e 0
724 56 :3 0 3d
:3 0 1d :2 0 2d8
570 573 a2 :2 0
1d :2 0 2dd 575
577 :3 0 49 :3 0
4a :3 0 579 57a
0 49 :3 0 5b
:3 0 57c 57d 0
d :2 0 2 :4 0
c1 :2 0 5d :2 0
19 :2 0 2e0 582
584 :3 0 2e3 57e
586 57b 588 587
:2 0 4c :3 0 5e
:3 0 58a 58b 0
4e :4 0 c2 :4 0
51 :2 0 52 :3 0
2e7 58f 591 :3 0
51 :2 0 8a :4 0
2ea 593 595 :3 0
51 :2 0 93 :4 0
2ed 597 599 :3 0
51 :2 0 56 :3 0
94 :3 0 95 :3 0
c3 :3 0 59e 59f
0 2f0 59d 5a1
59 :4 0 2f2 59c
5a4 2f5 59b 5a6
:3 0 51 :2 0 97
:4 0 2f8 5a8 5aa
:3 0 51 :2 0 54
:4 0 2fb 5ac 5ae
:3 0 51 :2 0 c
:3 0 2fe 5b0 5b2
:3 0 51 :2 0 54
:4 0 301 5b4 5b6
:3 0 304 58c 5b8
:2 0 5ba 307 5bb
589 5ba 0 5bc
309 0 5e6 49
:3 0 4a :3 0 5bd
5be 0 49 :3 0
5b :3 0 5c0 5c1
0 19 :2 0 2
:4 0 c4 :2 0 5d
:2 0 19 :2 0 30b
5c6 5c8 :3 0 30e
5c2 5ca 5bf 5cc
5cb :2 0 4c :3 0
5e :3 0 5ce 5cf
0 4e :4 0 c5
:4 0 51 :2 0 52
:3 0 312 5d3 5d5
:3 0 315 5d0 5d7
:2 0 5d9 318 5da
5cd 5d9 0 5db
31a 0 5e6 9a
:3 0 9b :3 0 5dc
5dd 0 95 :3 0
c3 :3 0 5df 5e0
0 c :3 0 9c
:3 0 31c 5de 5e4
:2 0 5e6 320 660
81 :3 0 c6 :3 0
c7 :3 0 c8 :3 0
c9 :3 0 c7 :3 0
95 :3 0 ca :3 0
95 :3 0 cb :3 0
cc :3 0 56 :3 0
cd :3 0 ce :3 0
cf :3 0 56 :3 0
d0 :3 0 d1 :3 0
d2 :3 0 d3 :3 0
82 :3 0 c :4 0
d4 1 :8 0 613
d5 :4 0 5fe :3 0
9c :3 0 8f :2 0
326 601 602 :3 0
a :3 0 84 :3 0
604 605 0 1d
:2 0 606 607 0
609 329 610 a
:3 0 84 :3 0 60a
60b 0 d6 :2 0
60c 60d 0 60f
32b 611 603 609
0 612 0 60f
0 612 32d 0
613 330 65d 86
:3 0 a :3 0 84
:3 0 616 617 0
85 :3 0 618 619
0 653 49 :3 0
4a :3 0 61b 61c
0 49 :3 0 5b
:3 0 61e 61f 0
87 :2 0 2 :4 0
d7 :2 0 5d :2 0
19 :2 0 333 624
626 :3 0 336 620
628 61d 62a 629
:2 0 4c :3 0 5e
:3 0 62c 62d 0
4e :4 0 d8 :4 0
51 :2 0 52 :3 0
33a 631 633 :3 0
51 :2 0 8a :4 0
33d 635 637 :3 0
51 :2 0 8b :4 0
340 639 63b :3 0
51 :2 0 85 :3 0
343 63d 63f :3 0
51 :2 0 8c :4 0
346 641 643 :3 0
51 :2 0 74 :3 0
8d :3 0 19 :2 0
8e :2 0 349 646
64a 34d 645 64c
:3 0 350 62e 64e
:2 0 650 353 651
62b 650 0 652
355 0 653 357
656 :3 0 656 0
656 655 653 654
:6 0 658 8 :3 0
35a 65a 35c 659
658 :2 0 65b 35e
:2 0 65d 0 65d
65c 613 65b :6 0
65f 1 :3 0 360
661 578 5e6 0
662 0 65f 0
662 362 0 724
3e :3 0 d9 :3 0
f :3 0 365 664
666 663 667 0
724 49 :3 0 4a
:3 0 669 66a 0
49 :3 0 5b :3 0
66c 66d 0 d
:2 0 2 :4 0 da
:2 0 5d :2 0 19
:2 0 367 672 674
:3 0 36a 66e 676
66b 678 677 :2 0
4c :3 0 5e :3 0
67a 67b 0 4e
:4 0 db :4 0 51
:2 0 52 :3 0 36e
67f 681 :3 0 51
:2 0 8a :4 0 371
683 685 :3 0 51
:2 0 93 :4 0 374
687 689 :3 0 51
:2 0 56 :3 0 94
:3 0 3e :3 0 377
68d 68f 59 :4 0
379 68c 692 37c
68b 694 :3 0 51
:2 0 97 :4 0 37f
696 698 :3 0 51
:2 0 54 :4 0 382
69a 69c :3 0 51
:2 0 c :3 0 385
69e 6a0 :3 0 51
:2 0 54 :4 0 388
6a2 6a4 :3 0 38b
67c 6a6 :2 0 6a8
38e 6a9 679 6a8
0 6aa 390 0
724 49 :3 0 4a
:3 0 6ab 6ac 0
49 :3 0 5b :3 0
6ae 6af 0 19
:2 0 2 :4 0 dc
:2 0 5d :2 0 19
:2 0 392 6b4 6b6
:3 0 395 6b0 6b8
6ad 6ba 6b9 :2 0
4c :3 0 5e :3 0
6bc 6bd 0 4e
:4 0 dd :4 0 51
:2 0 52 :3 0 399
6c1 6c3 :3 0 39c
6be 6c5 :2 0 6c7
39f 6c8 6bb 6c7
0 6c9 3a1 0
724 9a :3 0 9b
:3 0 6ca 6cb 0
56 :3 0 3e :3 0
1d :2 0 3a3 6cd
6d0 c :3 0 9c
:3 0 3a6 6cc 6d4
:2 0 724 49 :3 0
4a :3 0 6d6 6d7
0 49 :3 0 5b
:3 0 6d9 6da 0
de :2 0 2 :4 0
df :2 0 5d :2 0
19 :2 0 3aa 6df
6e1 :3 0 3ad 6db
6e3 6d8 6e5 6e4
:2 0 4c :3 0 5e
:3 0 6e7 6e8 0
4e :4 0 e0 :4 0
51 :2 0 52 :3 0
3b1 6ec 6ee :3 0
51 :2 0 8a :4 0
3b4 6f0 6f2 :3 0
51 :2 0 93 :4 0
3b7 6f4 6f6 :3 0
51 :2 0 56 :3 0
94 :3 0 a :3 0
84 :3 0 6fb 6fc
0 3ba 6fa 6fe
59 :4 0 3bc 6f9
701 3bf 6f8 703
:3 0 51 :2 0 97
:4 0 3c2 705 707
:3 0 51 :2 0 54
:4 0 3c5 709 70b
:3 0 51 :2 0 c
:3 0 3c8 70d 70f
:3 0 51 :2 0 54
:4 0 3cb 711 713
:3 0 3ce 6e9 715
:2 0 717 3d1 718
6e6 717 0 719
3d3 0 724 9a
:3 0 e1 :3 0 71a
71b 0 a :3 0
84 :3 0 71d 71e
0 c :3 0 9c
:3 0 3d5 71c 722
:2 0 724 3d9 7c5
a :3 0 e2 :2 0
4 725 726 0
49 :3 0 4a :3 0
728 729 0 49
:3 0 5b :3 0 72b
72c 0 87 :2 0
2 :4 0 e3 :2 0
5d :2 0 19 :2 0
3ef 731 733 :3 0
3f2 72d 735 72a
737 736 :2 0 4c
:3 0 5e :3 0 739
73a 0 4e :4 0
e4 :4 0 51 :2 0
52 :3 0 3f6 73e
740 :3 0 3f9 73b
742 :2 0 75b 4c
:3 0 5e :3 0 744
745 0 4e :4 0
e5 :4 0 51 :2 0
a :3 0 e6 :3 0
74a 74b 0 3fc
749 74d :3 0 51
:2 0 97 :4 0 3ff
74f 751 :3 0 51
:2 0 a :3 0 e7
:3 0 754 755 0
402 753 757 :3 0
405 746 759 :2 0
75b 408 75c 738
75b 0 75d 40b
0 76d e8 :3 0
48 :3 0 a :3 0
e6 :3 0 e9 :3 0
a :3 0 e7 :3 0
ea :3 0 bc :4 0
eb 1 :a 0 769
:2 0 76d 75f 767
:2 0 9 :3 0 48
:3 0 76b :2 0 76d
40d 76f 411 76e
76d :2 0 7c3 86
:3 0 a :3 0 84
:3 0 772 773 0
85 :3 0 774 775
0 7bb 49 :3 0
4a :3 0 777 778
0 49 :3 0 5b
:3 0 77a 77b 0
87 :2 0 2 :4 0
ec :2 0 5d :2 0
19 :2 0 413 780
782 :3 0 416 77c
784 779 786 785
:2 0 4c :3 0 5e
:3 0 788 789 0
4e :4 0 ed :4 0
51 :2 0 52 :3 0
41a 78d 78f :3 0
41d 78a 791 :2 0
7ab 4c :3 0 5e
:3 0 793 794 0
4e :4 0 8b :4 0
51 :2 0 85 :3 0
420 798 79a :3 0
51 :2 0 8c :4 0
423 79c 79e :3 0
51 :2 0 74 :3 0
8d :3 0 19 :2 0
8e :2 0 426 7a1
7a5 42a 7a0 7a7
:3 0 42d 795 7a9
:2 0 7ab 430 7ac
787 7ab 0 7ad
433 0 7bb e8
:3 0 48 :3 0 e9
:3 0 a :3 0 e7
:3 0 ea :3 0 bc
:4 0 ee 1 :a 0
7b7 :2 0 7bb 7af
7b5 :2 0 9 :3 0
48 :3 0 7b9 :2 0
7bb 435 7be :3 0
7be 0 7be 7bd
7bb 7bc :6 0 7c0
1 :3 0 43a 7c2
43c 7c1 7c0 :2 0
7c3 43e :2 0 7c5
441 7c5 7c4 724
7c3 :6 0 7c6 :2 0
2 18 7c5 7c9
:3 0 7c8 7c6 7ca
:8 0 
479
4
:3 0 1 3 1
7 1 b 1
f 4 6 a
e 12 1 1c
1 1a 1 23
1 21 1 2a
1 28 1 2f
1 34 1 39
1 3e 1 43
1 48 1 4d
1 54 1 52
1 5b 1 59
1 60 1 66
1 6c 1 72
1 77 1 7c
1 82 1 88
1 8e 1 96
1 94 1 9d
1 9b 1 a4
1 a2 1 a9
1 af 1 b5
1 bb 1 c1
1 c7 1 cd
1 d3 1 d9
1 df 1 e5
1 eb 1 f1
1 f7 1 fd
1 103 1 109
1 10f 1 115
1 11b 1 121
1 127 1 12d
1 133 1 139
1 13f 1 145
1 14b 1 151
1 157 1 15d
1 16a 1 176
2 179 17b 2
17e 180 2 182
184 2 186 188
2 18a 18c 2
192 194 2 196
198 2 19a 19b
2 19d 19e 2
18e 1a0 2 1a2
1a4 2 1aa 1ac
2 1ae 1b0 2
1b2 1b3 2 1b5
1b6 2 1a6 1b8
2 1ba 1bc 2
1be 1c0 2 1c2
1c4 2 1c6 1c8
2 1ca 1cc 4
172 178 17d 1ce
1 1d0 1 1d2
2 1dc 1de 3
1da 1db 1e0 2
1e9 1eb 2 1e8
1ed 1 1ef 1
1f1 2 242 247
2 258 25a 3
256 257 25c 2
265 267 2 269
26b 2 26d 26f
2 271 273 2
275 277 3 27c
27d 27e 2 279
280 2 264 282
1 284 1 286
2 24f 287 1
28b 1 24a 1
28f 1 29a 2
296 29a 2 2a6
2a8 3 2a4 2a5
2aa 2 2b3 2b5
2 2b7 2b9 2
2bb 2bd 1 2c5
2 2c7 2c8 2
2bf 2ca 2 2cc
2ce 2 2d0 2d2
2 2d4 2d6 2
2d8 2da 2 2b2
2dc 1 2de 1
2e0 2 2ea 2ec
3 2e8 2e9 2ee
2 2f7 2f9 2
2f6 2fb 1 2fd
1 2ff 3 306
307 308 3 2e1
300 30a 1 30c
1 30e 1 313
3 323 324 325
1 329 2 327
329 3 330 331
332 1 336 2
334 336 2 344
346 3 342 343
348 2 351 353
2 355 357 2
359 35b 1 363
2 365 366 2
35d 368 2 36a
36c 2 36e 370
2 372 374 2
376 378 2 350
37a 1 37c 1
37e 2 388 38a
3 386 387 38c
2 395 397 2
394 399 1 39b
1 39d 3 3a4
3a5 3a6 3 37f
39e 3a8 1 3aa
2 3b5 3ba 2
3cb 3cd 3 3c9
3ca 3cf 2 3d8
3da 2 3dc 3de
2 3e0 3e2 2
3e4 3e6 2 3e8
3ea 3 3ef 3f0
3f1 2 3ec 3f3
2 3d7 3f5 1
3f7 1 3f9 2
3c2 3fa 1 3fe
1 3bd 1 402
3 40a 40b 40c
1 410 2 40e
410 2 415 418
2 422 424 3
420 421 426 2
42f 431 2 433
435 2 437 439
1 441 2 443
444 2 43b 446
2 42e 448 1
44a 1 44c 2
456 458 3 454
455 45a 2 463
465 2 462 467
1 469 1 46b
2 472 473 3
44d 46c 475 2
477 478 5 31c
31f 3ab 405 479
1 47b 1 47f
a 485 486 487
488 489 48a 48b
48c 48d 48e 2
493 494 1 498
2 496 498 1
49c 8 4a6 4a7
4a8 4a9 4aa 4ab
4ac 4ad 1 4b0
1 4b2 1 4b4
3 4bb 4bc 4bd
1 4c0 3 4c3
4c4 4c5 1 4c9
2 4c7 4c9 3
4ce 4cf 4d0 1
4d3 3 4d7 4d8
4d9 1 4dc 2
4de 4df 1 4e0
2 4e2 4e3 1
4e5 2 4f4 4f9
2 50a 50c 3
508 509 50e 2
517 519 2 51b
51d 2 51f 521
2 523 525 2
527 529 3 52e
52f 530 2 52b
532 2 516 534
1 536 1 538
2 501 539 1
53d 1 4fc 1
541 2 548 549
2 54e 54f 2
54b 551 2 544
554 1 556 2
564 565 2 569
56a 8 55d 55e
55f 560 561 562
567 56c 2 571
572 1 576 2
574 576 2 581
583 3 57f 580
585 2 58e 590
2 592 594 2
596 598 1 5a0
2 5a2 5a3 2
59a 5a5 2 5a7
5a9 2 5ab 5ad
2 5af 5b1 2
5b3 5b5 2 58d
5b7 1 5b9 1
5bb 2 5c5 5c7
3 5c3 5c4 5c9
2 5d2 5d4 2
5d1 5d6 1 5d8
1 5da 3 5e1
5e2 5e3 3 5bc
5db 5e5 1 600
2 5ff 600 1
608 1 60e 2
610 611 2 5fd
612 2 623 625
3 621 622 627
2 630 632 2
634 636 2 638
63a 2 63c 63e
2 640 642 3
647 648 649 2
644 64b 2 62f
64d 1 64f 1
651 2 61a 652
1 656 1 615
1 65a 1 65d
2 660 661 1
665 2 671 673
3 66f 670 675
2 67e 680 2
682 684 2 686
688 1 68e 2
690 691 2 68a
693 2 695 697
2 699 69b 2
69d 69f 2 6a1
6a3 2 67d 6a5
1 6a7 1 6a9
2 6b3 6b5 3
6b1 6b2 6b7 2
6c0 6c2 2 6bf
6c4 1 6c6 1
6c8 2 6ce 6cf
3 6d1 6d2 6d3
2 6de 6e0 3
6dc 6dd 6e2 2
6eb 6ed 2 6ef
6f1 2 6f3 6f5
1 6fd 2 6ff
700 2 6f7 702
2 704 706 2
708 70a 2 70c
70e 2 710 712
2 6ea 714 1
716 1 718 3
71f 720 721 15
1d3 1f2 1f5 1f8
292 30d 47c 482
491 4b3 4e4 557
55a 56f 662 668
6aa 6c9 6d5 719
723 2 730 732
3 72e 72f 734
2 73d 73f 2
73c 741 2 748
74c 2 74e 750
2 752 756 2
747 758 2 743
75a 1 75c 3
75d 768 76c 1
727 2 77f 781
3 77d 77e 783
2 78c 78e 2
78b 790 2 797
799 2 79b 79d
3 7a2 7a3 7a4
2 79f 7a6 2
796 7a8 2 792
7aa 1 7ac 4
776 7ad 7b6 7ba
1 7be 1 771
2 76f 7c2 37
1f 26 2d 32
37 3c 41 46
4b 50 57 5e
64 6a 70 75
7a 80 86 8c
92 99 a0 a7
ad b3 b9 bf
c5 cb d1 d7
dd e3 e9 ef
f5 fb 101 107
10d 113 119 11f
125 12b 131 137
13d 143 149 14f
155 15b 162 
1
4
0 
7c9
0
1
14
a
3c
0 1 2 1 4 1 6 1
8 1 0 0 0 0 0 0
0 0 0 0 
11b 1 0
157 1 0
43 1 0
b5 1 0
127 1 0
d9 1 0
b 1 0
109 1 0
39 1 0
1a 1 0
6c 1 0
cd 1 0
df 1 0
f 1 0
59 1 0
3e 1 0
133 1 0
82 1 0
139 1 0
7c 1 0
72 1 0
121 1 0
e5 1 0
bb 1 0
f7 1 0
115 1 0
77 1 0
a9 1 0
c1 1 0
34 1 0
145 1 0
8e 1 0
60 1 0
103 1 0
4d 1 0
151 1 0
3 1 0
66 1 0
94 1 0
2f 1 0
c7 1 0
10f 1 0
d3 1 0
f1 1 0
52 1 0
13f 1 0
88 1 0
9b 1 0
28 1 0
eb 1 0
7 1 0
21 1 0
2 0 1
12d 1 0
48 1 0
fd 1 0
a2 1 0
af 1 0
14b 1 0
15d 1 0
0

/
SHOW ERRORS FUNCTION SP_U_WP_DATES;
ALTER FUNCTION SP_U_WP_DATES COMPILE DEBUG;
/**************************************************************************/
Prompt == FUNCTION FC_U_WP_ACTUAL ==
CREATE OR REPLACE FUNCTION FC_U_WP_ACTUAL wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
145
2 :e:
1FUNCTION:
1FC_U_WP_ACTUAL:
1H_ASSIGN_ID:
1OUT:
1NOCOPY:
1VARCHAR2:
1SH_H_NEW_WORK_PERCENT:
1PLS_INTEGER:
1SH_H_ACTUAL:
1SH_H_UNITS:
1H_REC_USER:
1H_ERROR_ID:
1RETURN:
1H_NEW_WORK_PERCENT:
1H_ACTUAL:
1H_UNITS:
1H_ID:
132:
1H_PRJ_ASSIGN_ID:
1H_PROJECT_ID:
1H_TASK_ID:
1H_RES_ID:
1H_SD:
1DATE:
1H_FD:
1H_START_DATE:
1TIMESTAMP:
1H_FINISH_DATE:
1H_LAST_SUBMITTED:
1H_WEEK_OF:
1H_BIT_FLAG:
11:
1H_RES_TYPE:
1H_REC_STATUS:
1H_BILLABLE:
10:
1H_CAPITAL_EXPENSE:
1H_EFFORT:
1H_WORK_PERCENT:
1H_PERCENT_UNITS:
1H_WORK_TODATE:
1H_NEW_ACTUAL:
1H_LAST_DAY:
1H_PER_DAY:
1H_TASK_TYPE:
1H_TPH_DELETE:
1H_TEMP_VAR:
1H_MINUTES:
1H_DURATION:
1H_CONTOUR:
1H_BITFLAG:
1H_CONSIDER:
1H_EUNIT:
1H_UNIT:
1H_WORK:
1H_SCHED_EFFORT:
1H_WORK_TYPE:
1H_ETC:
1H_CLOSE_TASK:
1H_REMAINING:
1H_ROLLUP_BITS:
1H_BITID:
1RAW:
136:
1PMO_CNST:
1SC_ZERO_BIT:
1H_BITID1:
1H_ASSIGN_STRING:
18192:
1H_REG_COST:
1NUMBER:
1H_REG_SALE:
1H_SPEC_COST:
1H_SPEC_SALE:
1H_B_REG_COST:
1H_B_REG_SALE:
1H_B_SPEC_COST:
1H_B_SPEC_SALE:
1DEBUG_PERFTIMING:
1T_TOTAL:
1S_TIME_1:
1S_TIME_2:
1S_TIME_3:
1S_TIME_4:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= FC_U_WP_ACTUAL(:
1':
1, :
1COALESCE:
1TO_CHAR:
1NULL:
1);:
1CHECK_TRACE:
182:
1+:
1FPUT:
1               ENTER:: FC_U_WP_ACTUAL(83) :: cplan.sql(14336) :: :
1PROJECT_ID:
1RESOURCE_ID:
1RESOURCE_TYPE:
1BIT_FLAG:
1LAST_SUBMITTED:
1WORK_TODATE:
1SCHED_WORK:
1ETC:
1LAST_SCHED_MIN:
1PROJECT_ASSIGNMENT_ID:
1C_CONTOUR:
1C_EFFORT:
1T_UNIT:
1C_UNIT:
1ASSIGN_UNITS:
1UNITS_MSP:
1UNRESOLVED_START:
1UNRESOLVED_FINISH:
1TO_DATE:
1SUBSTR:
1BILLABLE:
1CAPITAL_EXPENSE:
1REGULAR_COST:
1SPECIAL_COST:
1REGULAR_RATE:
1SPECIAL_RATE:
1B_REGULAR_COST:
1B_SPECIAL_COST:
1B_REGULAR_RATE:
1B_SPECIAL_RATE:
1MILESTONE_PERCENT:
1TASK_ID:
1ROLLUP_BITS:
1TASK_ASSIGNMENTS:
1TSK_ASSIGNMENT_ID:
1SELECT PROJECT_ID, RESOURCE_ID, RESOURCE_TYPE, BIT_FLAG, LAST_SUBMITTED, WORK+
1_TODATE, SCHED_WORK-WORK_TODATE, ETC,:n      SCHED_WORK, LAST_SCHED_MIN, PROJ+
1ECT_ASSIGNMENT_ID, C_CONTOUR, C_EFFORT, T_UNIT, C_UNIT, CASE WHEN ASSIGN_UNIT+
1S > UNITS_MSP THEN ASSIGN_UNITS ELSE UNITS_MSP END,:n      UNRESOLVED_START, +
1UNRESOLVED_FINISH, TO_DATE(SubStr(UNRESOLVED_START, 1, 10)), TO_DATE(SubStr(U+
1NRESOLVED_FINISH, 1, 10)), BILLABLE, CAPITAL_EXPENSE,:n      REGULAR_COST, SP+
1ECIAL_COST, REGULAR_RATE, SPECIAL_RATE,:n      B_REGULAR_COST, B_SPECIAL_COST+
1, B_REGULAR_RATE, B_SPECIAL_RATE,:n      MILESTONE_PERCENT, TASK_ID, ROLLUP_B+
1ITS:n      INTO h_project_id, h_res_id, h_res_type, h_bit_flag, h_last_submit+
1ted, h_work_todate, h_remaining, h_etc,:n      h_effort, h_last_day, h_prj_as+
1sign_id, h_contour, h_work, h_eunit, h_unit, h_percent_units,:n      h_start_+
1date, h_finish_date, h_SD, h_FD, h_billable, h_capital_expense,:n      h_reg_+
1cost, h_spec_cost, h_reg_sale, h_spec_sale,:n      h_b_reg_cost, h_b_spec_cos+
1t, h_b_reg_sale, h_b_spec_sale,:n      h_work_percent, h_task_id, h_rollup_bi+
1ts:n      FROM TASK_ASSIGNMENTS:n      WHERE TSK_ASSIGNMENT_ID = h_id:
1PMO_DB2M:
1SC_STATE:
1SQLCODE:
1OTHERS:
116:
1108:
1           EXCEPTION:: FC_U_WP_ACTUAL(109) :: cplan.sql(14362) :: :
1 :
1SQLCODE:: :
1 SQLERR:: :
1SQLERRM:
1500:
1=:
1SC_SQL_NO_DATA:
1TASK_TYPE:
1SCHED_EFFORT:
1SCHED_DURATION:
1TMT_WBS:
1ELEMENT_ID:
1SELECT PROJECT_ID, TASK_TYPE, SCHED_EFFORT, WORK_TODATE, MILESTONE_PERCENT, S+
1CHED_DURATION:n         INTO h_project_id, h_task_type, h_effort, h_work_toda+
1te, h_work_percent, h_duration:n         FROM TMT_WBS:n         WHERE ELEMENT+
1_ID = h_id:
1125:
1           EXCEPTION:: FC_U_WP_ACTUAL(126) :: cplan.sql(14379) :: :
1133:
1                EXIT:: FC_U_WP_ACTUAL(134) :: cplan.sql(14387) :: :
1RECORD_NOT_FOUND:
1LEVEL_LOCK:
1PROJECT_DETAILS:
1SELECT LEVEL_LOCK:n         INTO h_temp_var:n         FROM PROJECT_DETAILS:n +
1        WHERE PROJECT_ID = h_project_id:
1150:
1           EXCEPTION:: FC_U_WP_ACTUAL(151) :: cplan.sql(14404) :: :
1>:
1REC_STATUS:
1SELECT REC_STATUS:n            INTO h_rec_status:n            FROM TMT_WBS:n +
1           WHERE ELEMENT_ID = h_project_id:
1167:
1           EXCEPTION:: FC_U_WP_ACTUAL(168) :: cplan.sql(14421) :: :
1PMO_ORASTD:
1STRCMP:
1L:
1175:
1                EXIT:: FC_U_WP_ACTUAL(176) :: cplan.sql(14429) :: :
1LEV_LOCKED_BY_COPY:
1COUNT:
1DUAL:
1A:
1TA:
1ACTIVITIES:
1TYPE_ID:
1SC_TIMESHEET_ACTIVITY:
1SELECT COUNT('X'):n         INTO h_temp_var:n         FROM DUAL:n         WHE+
1RE EXISTS(:n         SELECT A.ELEMENT_ID:n         FROM TASK_ASSIGNMENTS TA, +
1ACTIVITIES A:n         WHERE TA.PROJECT_ID = h_project_id:n         AND TA.TA+
1SK_ID = h_id:n         AND TA.TSK_ASSIGNMENT_ID = A.TSK_ASSIGNMENT_ID:n      +
1   AND A.TSK_ASSIGNMENT_ID <> A.ELEMENT_ID:n         AND A.TYPE_ID = PMO_CNST+
1.SC_TIMESHEET_ACTIVITY):
1200:
1           EXCEPTION:: FC_U_WP_ACTUAL(201) :: cplan.sql(14454) :: :
1208:
1                EXIT:: FC_U_WP_ACTUAL(209) :: cplan.sql(14462) :: :
1SC_TIMESHEET_STEP_EXISTS:
18:
1215:
1      RETURN_INVALID:: FC_U_WP_ACTUAL(216) :: cplan.sql(14469) :: :
1STATE:: :
1INVALID_PARAMS:
1218:
1                EXIT:: FC_U_WP_ACTUAL(219) :: cplan.sql(14472) :: :
1PMODEFINES:
1PMO_RETURN_INVALID:
1FALSE:
1ELSIF:
1!=:
1226:
1                EXIT:: FC_U_WP_ACTUAL(227) :: cplan.sql(14480) :: :
1SC_TASK_ACTUAL_GRATER_THAN_SCH:
1FC_U_TASK_PERCENT:
1238:
1      RETURN_INVALID:: FC_U_WP_ACTUAL(239) :: cplan.sql(14492) :: :
1241:
1                EXIT:: FC_U_WP_ACTUAL(242) :: cplan.sql(14495) :: :
1249:
1                EXIT:: FC_U_WP_ACTUAL(250) :: cplan.sql(14503) :: :
1266:
1           EXCEPTION:: FC_U_WP_ACTUAL(267) :: cplan.sql(14520) :: :
1283:
1           EXCEPTION:: FC_U_WP_ACTUAL(284) :: cplan.sql(14537) :: :
1291:
1                EXIT:: FC_U_WP_ACTUAL(292) :: cplan.sql(14545) :: :
1SELECT COUNT('X'):n         INTO h_temp_var:n         FROM DUAL:n         WHE+
1RE EXISTS(:n         SELECT ELEMENT_ID:n         FROM ACTIVITIES:n         WH+
1ERE TSK_ASSIGNMENT_ID = h_id:n         AND TSK_ASSIGNMENT_ID <> ELEMENT_ID:n +
1        AND TYPE_ID = PMO_CNST.SC_TIMESHEET_ACTIVITY):
1314:
1           EXCEPTION:: FC_U_WP_ACTUAL(315) :: cplan.sql(14568) :: :
1322:
1                EXIT:: FC_U_WP_ACTUAL(323) :: cplan.sql(14576) :: :
1MINUTE_PER_DAY:
1SELECT PROJECT_ID, MINUTE_PER_DAY:n         INTO h_project_id, h_per_day:n   +
1      FROM TMT_WBS:n         WHERE PROJECT_ID = h_project_id:n         AND EL+
1EMENT_ID = h_task_id:
1339:
1           EXCEPTION:: FC_U_WP_ACTUAL(340) :: cplan.sql(14593) :: :
1-:
1FC_TPHASE_SCHED_ASSIGN:
110000:
1<:
1CONSIDER:
1PMO_STPU:
1BIT_OR:
1SC_SCHED_BIT:
1UPDATE TASK_ASSIGNMENTS:n                           SET CONSIDER = 7,:n      +
1                     ROLLUP_BITS = PMO_STPU.BIT_OR(ROLLUP_BITS,PMO_CNST.SC_SC+
1HED_BIT),:n                           SCHED_WORK = h_new_actual,:n           +
1                WORK_TODATE = h_new_actual,:n                           ETC =+
1 h_etc,:n                           MILESTONE_PERCENT = 10000:n              +
1             WHERE TSK_ASSIGNMENT_ID = h_id:
1FOUND:
1TRUE:
1100:
1380:
1           EXCEPTION:: FC_U_WP_ACTUAL(381) :: cplan.sql(14634) :: :
1PMO_FUNC:
1SC_BIT_30:
1UPDATE TASK_ASSIGNMENTS:n                           SET CONSIDER = 7,:n      +
1                     ROLLUP_BITS = PMO_STPU.BIT_OR(ROLLUP_BITS,PMO_CNST.SC_SC+
1HED_BIT),:n                           SCHED_WORK = h_new_actual,:n           +
1                WORK_TODATE = h_new_actual,:n                           ETC =+
1 0,:n                           MILESTONE_PERCENT = 10000:n                  +
1         WHERE TSK_ASSIGNMENT_ID = h_id:
1406:
1           EXCEPTION:: FC_U_WP_ACTUAL(407) :: cplan.sql(14660) :: :
1TRUNC:
1TO_NUMBER:
1/:
1*:
110000.00:
10.4:
1UPDATE TASK_ASSIGNMENTS:n                           SET CONSIDER = 7,:n      +
1                     ROLLUP_BITS = PMO_STPU.BIT_OR(ROLLUP_BITS,PMO_CNST.SC_SC+
1HED_BIT),:n                           SCHED_WORK = h_etc,:n                  +
1         WORK_TODATE = h_new_actual:n                           WHERE TSK_ASS+
1IGNMENT_ID = h_id:
1434:
1           EXCEPTION:: FC_U_WP_ACTUAL(435) :: cplan.sql(14688) :: :
1461:
1           EXCEPTION:: FC_U_WP_ACTUAL(462) :: cplan.sql(14715) :: :
1UPDATE TASK_ASSIGNMENTS:n                     SET CONSIDER = 7,:n            +
1         ROLLUP_BITS = PMO_STPU.BIT_OR(ROLLUP_BITS,PMO_CNST.SC_SCHED_BIT),:n +
1                    SCHED_WORK = h_new_actual,:n                     WORK_TOD+
1ATE = h_new_actual,:n                     ETC = 0,:n                     MILE+
1STONE_PERCENT = 10000:n                     WHERE TSK_ASSIGNMENT_ID = h_id:
1490:
1           EXCEPTION:: FC_U_WP_ACTUAL(491) :: cplan.sql(14744) :: :
1IS NOT NULL:
1MAX:
1WEEK_OF:
1TIMESHEET_APPROVAL_STATUS:
1SELECT MAX(WEEK_OF):n                     INTO h_week_of:n                   +
1  FROM TIMESHEET_APPROVAL_STATUS:n                     WHERE ELEMENT_ID = h_p+
1roject_id:n                     AND RESOURCE_ID = h_res_id:
1510:
1           EXCEPTION:: FC_U_WP_ACTUAL(511) :: cplan.sql(14764) :: :
1SELECT TO_DATE(SubStr(h_week_of, 1, 10)) + 7      INTO h_week_of FROM DUAL:
1525:
1           EXCEPTION:: FC_U_WP_ACTUAL(526) :: cplan.sql(14779) :: :
1STRNCMP:
110:
1DB2TIMESTAMP:
1TIME:
1SELECT PMO_ORASTD.DB2TIMESTAMP(TO_DATE(SubStr(h_last_submitted, 1, 10)), PMO_+
1ORASTD.TIME(h_start_date)):n                        INTO h_start_date:n      +
1                  FROM DUAL:
1546:
1           EXCEPTION:: FC_U_WP_ACTUAL(547) :: cplan.sql(14800) :: :
1SELECT PMO_ORASTD.DB2TIMESTAMP(TO_DATE(SubStr(h_last_submitted, 1, 10)), PMO_+
1ORASTD.TIME(h_start_date)) + 1     :n                        INTO h_start_dat+
1e:n                        FROM DUAL:
1561:
1           EXCEPTION:: FC_U_WP_ACTUAL(562) :: cplan.sql(14815) :: :
1FC_DEL_NOACTUAL:
12:
1FC_RESCHEDULE:
1587:
1                EXIT:: FC_U_WP_ACTUAL(588) :: cplan.sql(14841) :: :
1FC_U_ASSIGN_PERCENT:
1613:
1                EXIT:: FC_U_WP_ACTUAL(614) :: cplan.sql(14867) :: :
1SC_PERCENT_COMPLETE_BIT:
1UPDATE TASK_ASSIGNMENTS:n            SET MILESTONE_PERCENT = h_new_work_perce+
1nt,:n            ROLLUP_BITS = PMO_STPU.BIT_OR(ROLLUP_BITS,PMO_CNST.SC_PERCEN+
1T_COMPLETE_BIT):n            WHERE TSK_ASSIGNMENT_ID = h_id:
1665:
1           EXCEPTION:: FC_U_WP_ACTUAL(666) :: cplan.sql(14919) :: :
1UPDATE TMT_WBS:n            SET ROLLUP_BITS = PMO_STPU.BIT_OR(ROLLUP_BITS,PMO+
1_CNST.SC_PERCENT_COMPLETE_BIT):n            WHERE PROJECT_ID = h_project_id:n+
1            AND ELEMENT_ID = h_task_id:
1690:
1           EXCEPTION:: FC_U_WP_ACTUAL(691) :: cplan.sql(14944) :: :
1103079040:
1703:
1                EXIT:: FC_U_WP_ACTUAL(704) :: cplan.sql(14957) :: :
1SELECT UNITS_MSP:n               INTO h_temp_var:n               FROM TASK_AS+
1SIGNMENTS:n               WHERE TSK_ASSIGNMENT_ID = h_prj_assign_id:
1723:
1           EXCEPTION:: FC_U_WP_ACTUAL(724) :: cplan.sql(14977) :: :
1SC_SQL_SUCCESS:
1733:
1                EXIT:: FC_U_WP_ACTUAL(734) :: cplan.sql(14987) :: :
1TASK_ASSIGNMENT_ERROR:
1FC_U_TDY_LAST_ACTUAL:
1SELECT PMO_ORASTD.DB2TIMESTAMP(TO_DATE(SubStr(h_last_submitted, 1, 10)), PMO_+
1ORASTD.TIME(h_start_date)) + 1     :n               INTO h_start_date:n      +
1         FROM DUAL:
1827:
1           EXCEPTION:: FC_U_WP_ACTUAL(828) :: cplan.sql(15081) :: :
1846:
1                EXIT:: FC_U_WP_ACTUAL(847) :: cplan.sql(15100) :: :
1CONTOUR_TYPE:
1SC_PLANNED_BIT:
1UPDATE TASK_ASSIGNMENTS:n               SET CONSIDER = 7,:n               UNI+
1TS_MSP = h_percent_units,:n               C_EFFORT = 0,:n               C_UNI+
1T = 0,:n               C_CONTOUR = 0,:n               CONTOUR_TYPE = 0,:n    +
1           ROLLUP_BITS = PMO_STPU.BIT_OR(ROLLUP_BITS,(PMO_CNST.SC_SCHED_BIT+P+
1MO_CNST.SC_PLANNED_BIT)):n               WHERE TSK_ASSIGNMENT_ID = h_id:
1870:
1           EXCEPTION:: FC_U_WP_ACTUAL(871) :: cplan.sql(15124) :: :
1FC_ROLLUP:
1888:
1                EXIT:: FC_U_WP_ACTUAL(889) :: cplan.sql(15142) :: :
0

0
0
122a
2
0 a0 8d 90 :3 a0 b0 3f 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 90 :3 a0 b0 3f 90
:3 a0 b0 3f b4 :2 a0 2c 6a a3
a0 1c a0 81 b0 a3 a0 1c
a0 81 b0 a3 a0 1c a0 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 1c 81
b0 a3 a0 1c 81 b0 a3 a0
1c 81 b0 a3 a0 1c 81 b0
a3 a0 1c 81 b0 a3 a0 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 51 a5 1c
:2 a0 6b 81 b0 a3 a0 51 a5
1c :2 a0 6b 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
:2 a0 6b :2 a0 6b 6e a5 b a
10 :2 a0 6b 6e :2 a0 6b 6e a5
b 6e 7e a0 b4 2e 6e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:3 a0 a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e :3 a0 a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e :3 a0 a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 d
:4d a0 12a :2 a0 6b a0 d b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 6b a0 7e a0
6b b4 2e 5a :f a0 12a :2 a0 6b
a0 d b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
6b a0 7e a0 6b b4 2e 5a
:2 a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :3 a0 6b 65
b7 19 3c a0 51 d :5 a0 12a
:2 a0 6b a0 d b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 51 a5 b 7e 51 b4
2e :5 a0 12a :2 a0 6b a0 d b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 6b a0 6e
a5 b 7e 51 b4 2e :2 a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :3 a0 6b 65 b7 19
3c b7 19 3c :1b a0 12a :2 a0 6b
a0 d b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
51 a5 b 7e 51 b4 2e :2 a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :3 a0 6b 65 b7
19 3c :2 a0 51 a5 b 7e 51
b4 2e :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :3 a0 6b :2 a0 6b a0 a5
b 65 a0 b7 :2 a0 51 a5 b
a0 7e a0 51 a5 b b4 2e
a0 51 d :2 a0 51 a5 b a0
7e a0 51 a5 b b4 2e :2 a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :3 a0 6b 65 a0
b7 :2 a0 51 a5 b a0 7e a0
51 a5 b b4 2e a0 51 d
b7 :2 19 3c :2 a0 d :8 a0 51 a5
b a5 b d b7 19 :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :3 a0 6b
:2 a0 6b a0 a5 b 65 b7 :2 19
3c b7 :2 a0 51 a5 b 7e 51
b4 2e :2 a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :3 a0
6b 65 b7 19 3c a0 51 d
:5 a0 12a :2 a0 6b a0 d b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 51 a5 b 7e
51 b4 2e :5 a0 12a :2 a0 6b a0
d b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
a0 6e a5 b 7e 51 b4 2e
:2 a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :3 a0 6b 65
b7 19 3c b7 19 3c :c a0 12a
:2 a0 6b a0 d b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 51 a5 b 7e 51 b4
2e :2 a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :3 a0 6b
65 b7 19 3c :9 a0 12a :2 a0 6b
a0 d b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :3 a0
51 a5 b d :2 a0 51 a5 b
a0 7e a0 51 a5 b b4 2e
:2 a0 d :2 a0 51 a5 b a0 7e
a0 51 a5 b b4 2e a0 7e
51 b4 2e d :c a0 a5 b d
:2 a0 51 a5 b 7e 51 b4 2e
:2 a0 51 a5 b a0 7e a0 51
a5 b b4 2e :2 a0 6b :2 a0 a5
b 7e 51 b4 2e :3 a0 51 a5
b 7e :2 a0 51 a5 b b4 2e
d a0 51 d :2 a0 51 a5 b
7e :2 a0 51 a5 b 7e :2 a0 51
a5 b b4 2e 5a b4 2e :3 a0
51 a5 b 7e :2 a0 51 a5 b
b4 2e 5a 7e :2 a0 51 a5 b
b4 2e d :11 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :3 a0 6b :2 a0 51
a5 b :2 a0 6b a5 b d b7
:10 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 :2 19 3c b7 :2 a0 51 a5
b 7e :2 a0 51 a5 b 7e :2 a0
51 a5 b b4 2e 5a b4 2e
:3 a0 51 a5 b 7e :2 a0 51 a5
b b4 2e d :5 a0 a5 b 51
a5 b 7e :3 a0 a5 b 51 a5
b b4 2e 5a 7e 51 b4 2e
5a 7e 51 b4 2e a5 b d
:e a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 :3 a0 51 a5 b 7e :2 a0
51 a5 b b4 2e d a0 51
d :10 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 :2 19 3c b7 :2 19 3c
b7 :3 a0 51 a5 b 7e :2 a0 51
a5 b b4 2e d a0 51 d
:10 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 :2 19 3c a0 7e b4 2e
5a a0 4d d :8 a0 12a :2 a0 6b
a0 d b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f a0
7e b4 2e 5a :5 a0 12a :2 a0 6b
a0 d b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
6b :2 a0 51 a5 b 7e 51 b4
2e :2 a0 d b7 19 3c a0 b7
:2 a0 51 a5 b 7e 51 b4 2e
:3 a0 6b :2 a0 51 a5 b :2 a0 6b
a5 b 5a d :a a0 12a :2 a0 6b
a0 d b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
19 :a a0 12a :2 a0 6b a0 d b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 :2 19 3c b7
19 3c a0 7e b4 2e 5a :4 a0
51 a5 b d b7 :2 a0 :2 51 a5
b 7e 6e b4 2e :4 a0 51 a5
b d b7 :4 a0 51 a5 b d
b7 :2 19 3c b7 :2 19 3c a0 51
d :8 a0 51 :2 a0 51 a5 b a5
b d :2 a0 51 a5 b 7e 51
b4 2e :2 a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :3 a0
51 a5 b 65 b7 19 3c :2 a0
d b7 19 3c b7 :5 a0 a5 b
51 a5 b 7e :3 a0 a5 b 51
a5 b b4 2e 5a 7e 51 b4
2e 5a 7e 51 b4 2e a5 b
d b7 :2 19 3c :1b a0 51 a5 b
a5 b d :2 a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:3 a0 51 a5 b 65 a0 b7 :2 a0
51 a5 b a0 7e a0 51 a5
b b4 2e :b a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :b a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f a0 b7 19
:2 a0 51 a5 b a0 7e a0 51
a5 b b4 2e :2 a0 51 a5 b
7e 51 b4 2e a0 51 d b7
:2 a0 51 a5 b 7e 51 b4 2e
5a :2 a0 51 a5 b 7e 51 b4
2e 5a 52 10 :2 a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :3 a0 6b 65 b7 19 3c :3 a0
51 a5 b d b7 :2 19 3c a0
7e b4 2e 5a :5 a0 12a :2 a0 6b
a0 d b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
6b a0 7e a0 6b b4 2e 5a
:2 a0 51 a5 b a0 7e a0 51
a5 b b4 2e 5a a 10 :2 a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :3 a0 6b 65 b7
19 3c b7 19 3c a0 7e 51
b4 2e d :c a0 a5 b d :2 a0
51 a5 b 7e 51 b4 2e 5a
a0 7e b4 2e :2 5a a 10 :9 a0
51 a5 b d b7 19 3c a0
7e b4 2e 5a :4 a0 51 a5 b
d b7 :2 a0 :2 51 a5 b 7e 6e
b4 2e :4 a0 51 a5 b d b7
:4 a0 51 a5 b d b7 :2 19 3c
b7 :2 19 3c a0 7e b4 2e 5a
:a a0 12a :2 a0 6b a0 d b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :3 a0 51 a5 b 7e
:2 a0 51 a5 b b4 2e d b7
19 3c a0 51 d a0 51 d
:8 a0 51 :2 a0 51 a5 b a5 b
d :2 a0 51 a5 b 7e 51 b4
2e :2 a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :3 a0 6b
65 b7 :12 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 :2 19 3c b7 :2 19
3c b7 :2 19 3c :2 a0 6b :2 a0 a5
b d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :2 a0 6b b4 2e a5 57 b7
19 3c :3 a0 6b 65 b7 a4 b1
11 68 4f 1d 17 b5 
122a
2
0 3 7 2b 1f 23 27 1e
32 3f 3b 1b 47 50 4c 3a
58 65 61 37 6d 7e 72 76
7a 60 85 9a 8e 92 96 5d
a1 8d a6 aa ae b2 cf ba
be c6 ca 8a eb d6 da e2
e6 b9 10b f6 fa 102 106 b6
127 112 116 119 11a 122 f5 144
132 f2 136 137 13f 131 161 14f
12e 153 154 15c 14e 17e 16c 14b
170 171 179 16b 19b 189 168 18d
18e 196 188 1b7 1a6 1aa 1b2 185
1cf 1be 1c2 1ca 1a5 1eb 1da 1de
1e6 1a2 203 1f2 1f6 1fe 1d9 21f
20e 212 21a 1d6 237 226 22a 232
20d 254 242 20a 246 247 24f 241
271 25f 23e 263 264 26c 25e 28e
27c 25b 280 281 289 27b 2aa 299
29d 278 2a5 298 2c6 2b5 2b9 295
2c1 2b4 2e2 2d1 2d5 2b1 2dd 2d0
2fe 2ed 2f1 2cd 2f9 2ec 31a 309
30d 2e9 315 308 336 325 329 305
331 324 352 341 345 321 34d 340
36e 35d 361 33d 369 35c 38a 379
37d 359 385 378 3a6 395 399 375
3a1 394 3c2 3b1 3b5 391 3bd 3b0
3de 3cd 3d1 3ad 3d9 3cc 3fa 3e9
3ed 3c9 3f5 3e8 416 405 409 3e5
411 404 432 421 425 401 42d 420
44e 43d 441 41d 449 43c 46a 459
45d 439 465 458 486 475 479 455
481 474 4a2 491 495 471 49d 490
4be 4ad 4b1 48d 4b9 4ac 4da 4c9
4cd 4a9 4d5 4c8 4f6 4e5 4e9 4c5
4f1 4e4 512 501 505 4e1 50d 500
52e 51d 521 4fd 529 51c 54a 539
53d 519 545 538 566 555 559 535
561 554 58e 571 551 575 576 57e
582 586 589 570 5b6 599 56d 59d
59e 5a6 5aa 5ae 5b1 598 5d3 5c1
595 5c5 5c6 5ce 5c0 5ef 5de 5e2
5bd 5ea 5dd 60b 5fa 5fe 5da 606
5f9 627 616 61a 5f6 622 615 643
632 636 612 63e 631 65f 64e 652
62e 65a 64d 67b 66a 66e 64a 676
669 697 686 68a 666 692 685 6b3
6a2 6a6 682 6ae 6a1 6cf 6be 6c2
69e 6ca 6bd 6eb 6da 6de 6ba 6e6
6d9 707 6f6 6fa 6d6 702 6f5 723
712 716 6f2 71e 711 73f 72e 732
70e 73a 72d 75b 74a 74e 72a 756
749 762 766 746 76a 76e 772 775
77a 77b 1 77d 782 786 78a 78d
792 796 79a 79d 7a2 7a3 7a5 7aa
7ad 7b1 7b2 7b7 7bc 7bf 7c4 7c5
7ca 7cd 7d1 7d2 7d7 7da 7df 7e0
7e5 7e8 7ed 7ee 7f3 7f6 7fa 7fe
802 803 805 80a 80b 80d 80e 813
816 81b 81c 821 824 828 82c 830
831 833 838 839 83b 83c 841 844
849 84a 84f 852 856 85a 85e 85f
861 866 867 869 86a 86f 872 877
878 87d 880 885 886 88b 88e 892
893 898 89b 8a0 8a1 8a6 8a9 8ae
8af 8b4 8b7 8bc 8bd 8c2 8c5 8c9
8ca 8cf 8d2 8d7 8d8 8dd 8e0 8e5
8e6 8eb 8ec 8f1 8f3 8f7 8fa 8fe
902 905 909 90d 910 913 918 91b
91e 921 922 927 928 1 92a 92f
933 937 93a 93f 944 947 94b 94c
951 952 957 959 95d 960 964 968
96c 970 974 978 97c 980 984 988
98c 990 994 998 99c 9a0 9a4 9a8
9ac 9b0 9b4 9b8 9bc 9c0 9c4 9c8
9cc 9d0 9d4 9d8 9dc 9e0 9e4 9e8
9ec 9f0 9f4 9f8 9fc a00 a04 a08
a0c a10 a14 a18 a1c a20 a24 a28
a2c a30 a34 a38 a3c a40 a44 a48
a4c a50 a54 a58 a5c a60 a64 a68
a6c a70 a74 a78 a7c a80 a84 a88
a8c a90 a94 a98 a9c aa0 aac ab0
ab4 ab7 abb abf ac1 1 ac5 ac9
acd ad0 ad4 ad8 adc ae0 ae3 ae7
aeb aee af1 af6 af9 afc aff b00
b05 b06 1 b08 b0d b11 b15 b18
b1d b22 b25 b29 b2a b2f b32 b37
b38 b3d b40 b45 b46 b4b b4e b52
b53 b58 b5b b60 b61 b66 b69 b6d
b71 b74 b77 b78 b7a b7b b80 b81
b86 b88 b8c b8f b91 b95 b97 ba3
ba5 ba7 ba8 bad bb1 bb3 bbf bc1
bc5 bc9 bcc bd0 bd3 bd7 bda bdb
be0 be3 be7 beb bef bf3 bf7 bfb
bff c03 c07 c0b c0f c13 c17 c1b
c1f c2b c2f c33 c36 c3a c3e c40
1 c44 c48 c4c c4f c53 c57 c5b
c5f c62 c66 c6a c6d c70 c75 c78
c7b c7e c7f c84 c85 1 c87 c8c
c90 c94 c97 c9c ca1 ca4 ca8 ca9
cae cb1 cb6 cb7 cbc cbf cc4 cc5
cca ccd cd1 cd2 cd7 cda cdf ce0
ce5 ce8 cec cf0 cf3 cf6 cf7 cf9
cfa cff d00 d05 d07 d0b d0e d10
d14 d16 d22 d24 d26 d27 d2c d30
d32 d3e d40 d44 d48 d4b d4f d52
d56 d59 d5a d5f d62 d66 d6a d6e
d72 d76 d79 d7d d81 d84 d87 d8c
d8f d92 d95 d96 d9b d9c 1 d9e
da3 da7 dab dae db3 db8 dbb dbf
dc0 dc5 dc6 dcb dcd dd1 dd4 dd8
ddc de0 de3 de7 de9 ded df0 df4
df7 dfb dff e03 e07 e0b e0f e1b
e1f e23 e26 e2a e2e e30 1 e34
e38 e3c e3f e43 e47 e4b e4f e52
e56 e5a e5d e60 e65 e68 e6b e6e
e6f e74 e75 1 e77 e7c e80 e84
e87 e8c e91 e94 e98 e99 e9e ea1
ea6 ea7 eac eaf eb4 eb5 eba ebd
ec1 ec2 ec7 eca ecf ed0 ed5 ed8
edc ee0 ee3 ee6 ee7 ee9 eea eef
ef0 ef5 ef7 efb efe f00 f04 f06
f12 f14 f16 f17 f1c f20 f22 f2e
f30 f34 f38 f3b f3c f3e f41 f44
f45 f4a f4e f52 f56 f5a f5e f6a
f6e f72 f75 f79 f7d f7f 1 f83
f87 f8b f8e f92 f96 f9a f9e fa1
fa5 fa9 fac faf fb4 fb7 fba fbd
fbe fc3 fc4 1 fc6 fcb fcf fd3
fd6 fdb fe0 fe3 fe7 fe8 fed ff0
ff5 ff6 ffb ffe 1003 1004 1009 100c
1010 1011 1016 1019 101e 101f 1024 1027
102b 102f 1032 1035 1036 1038 1039 103e
103f 1044 1046 104a 104d 104f 1053 1055
1061 1063 1065 1066 106b 106f 1071 107d
107f 1083 1087 108a 108e 1093 1094 1096
1099 109c 109d 10a2 10a6 10aa 10ae 10b2
10b6 10b9 10bd 10c1 10c4 10c7 10cc 10cf
10d2 10d5 10d6 10db 10dc 1 10de 10e3
10e7 10eb 10ee 10f3 10f8 10fb 10ff 1100
1105 1106 110b 110d 1111 1114 1118 111c
1120 1123 1127 1129 112d 1130 1132 1136
1139 113d 1141 1145 1149 114d 1151 1155
1159 115d 1161 1165 1169 116d 1171 1175
1179 117d 1181 1185 1189 118d 1191 1195
1199 119d 11a1 11a5 11b1 11b5 11b9 11bc
11c0 11c4 11c6 1 11ca 11ce 11d2 11d5
11d9 11dd 11e1 11e5 11e8 11ec 11f0 11f3
11f6 11fb 11fe 1201 1204 1205 120a 120b
1 120d 1212 1216 121a 121d 1222 1227
122a 122e 122f 1234 1237 123c 123d 1242
1245 124a 124b 1250 1253 1257 1258 125d
1260 1265 1266 126b 126e 1272 1276 1279
127c 127d 127f 1280 1285 1286 128b 128d
1291 1294 1296 129a 129c 12a8 12aa 12ac
12ad 12b2 12b6 12b8 12c4 12c6 12ca 12ce
12d1 12d2 12d4 12d7 12da 12db 12e0 12e4
12e8 12ec 12f0 12f4 12f7 12fb 12ff 1302
1305 130a 130d 1310 1313 1314 1319 131a
1 131c 1321 1325 1329 132c 1331 1336
1339 133d 133e 1343 1344 1349 134b 134f
1352 1356 135a 135e 1361 1365 1367 136b
136e 1372 1376 1379 137a 137c 137f 1382
1383 1388 138c 1390 1393 1397 139b 139e
13a1 13a6 13a9 13ac 13af 13b0 13b5 13b6
1 13b8 13bd 13c1 13c5 13c8 13cd 13d2
13d5 13d9 13da 13df 13e2 13e7 13e8 13ed
13f0 13f5 13f6 13fb 13fe 1402 1406 140a
140e 1411 1412 1414 1419 141a 141c 141d
1422 1423 1428 142a 142e 1431 1435 1439
143c 1440 1444 1447 144a 144f 1452 1455
1458 1459 145e 145f 1 1461 1466 146a
146e 1471 1476 147b 147e 1482 1483 1488
1489 148e 1490 1494 1497 149b 149f 14a3
14a6 14aa 14ae 14b1 14b5 14b6 14b8 14bc
14c0 14c2 14c6 14ca 14cd 14ce 14d0 14d4
14d7 14db 14de 14df 14e1 14e2 14e7 14eb
14ee 14f2 14f6 14fa 14fd 14fe 1500 1504
1507 150b 150e 150f 1511 1512 1517 151b
151f 1523 1527 152b 152e 1532 1536 1539
153c 1541 1544 1547 154a 154b 1550 1551
1 1553 1558 155c 1560 1563 1568 156d
1570 1574 1575 157a 157b 1580 1582 1586
1589 158d 1591 1595 1598 159c 15a0 15a2
15a6 15aa 15ad 15ae 15b0 15b4 15b7 15bb
15be 15bf 15c1 15c2 15c7 15cb 15ce 15d2
15d4 15d8 15dc 15df 15e3 15e7 15eb 15ef
15f3 15f7 15fb 15ff 1603 1607 160b 160e
160f 1611 1612 1614 1618 161a 161e 1622
1626 1629 162d 1631 1634 1637 163c 163f
1642 1645 1646 164b 164c 1 164e 1653
1657 165b 165e 1663 1668 166b 166f 1670
1675 1678 167d 167e 1683 1686 168b 168c
1691 1694 1698 169c 16a0 16a4 16a7 16a8
16aa 16af 16b0 16b2 16b3 16b8 16b9 16be
16c0 16c4 16c7 16cb 16cf 16d2 16d6 16da
16dd 16e0 16e5 16e8 16eb 16ee 16ef 16f4
16f5 1 16f7 16fc 1700 1704 1707 170c
1711 1714 1718 1719 171e 171f 1724 1726
172a 172d 1731 1735 1739 173c 1740 1744
1747 174b 174c 174e 1752 1754 1758 175c
175f 1761 1765 1769 176c 176d 176f 1772
1775 1776 177b 177f 1783 1787 178b 178f
1792 1796 179a 179d 17a0 17a5 17a8 17ab
17ae 17af 17b4 17b5 1 17b7 17bc 17c0
17c4 17c7 17cc 17d1 17d4 17d8 17d9 17de
17df 17e4 17e6 17ea 17ed 17f1 17f5 17f9
17fc 1800 1802 1806 1809 180d 1810 1814
1818 181c 1820 1824 1828 1834 1838 183c
183f 1843 1847 1849 1 184d 1851 1855
1858 185c 1860 1864 1868 186b 186f 1873
1876 1879 187e 1881 1884 1887 1888 188d
188e 1 1890 1895 1899 189d 18a0 18a5
18aa 18ad 18b1 18b2 18b7 18ba 18bf 18c0
18c5 18c8 18cd 18ce 18d3 18d6 18da 18db
18e0 18e3 18e8 18e9 18ee 18f1 18f5 18f9
18fc 18ff 1900 1902 1903 1908 1909 190e
1910 1914 1917 1919 191d 191f 192b 192d
192f 1930 1935 1939 193b 1947 1949 194d
1951 1954 1955 1957 195a 195d 195e 1963
1967 196b 196f 1973 1977 1983 1987 198b
198e 1992 1996 1998 1 199c 19a0 19a4
19a7 19ab 19af 19b3 19b7 19ba 19be 19c2
19c5 19c8 19cd 19d0 19d3 19d6 19d7 19dc
19dd 1 19df 19e4 19e8 19ec 19ef 19f4
19f9 19fc 1a00 1a01 1a06 1a09 1a0e 1a0f
1a14 1a17 1a1c 1a1d 1a22 1a25 1a29 1a2a
1a2f 1a32 1a37 1a38 1a3d 1a40 1a44 1a48
1a4b 1a4e 1a4f 1a51 1a52 1a57 1a58 1a5d
1a5f 1a63 1a66 1a68 1a6c 1a6e 1a7a 1a7c
1a7e 1a7f 1a84 1a88 1a8a 1a96 1a98 1a9c
1aa0 1aa3 1aa7 1aac 1aad 1aaf 1ab2 1ab5
1ab6 1abb 1abf 1ac3 1ac7 1acb 1acf 1ad2
1ad6 1ada 1add 1ae0 1ae5 1ae8 1aeb 1aee
1aef 1af4 1af5 1 1af7 1afc 1b00 1b04
1b07 1b0c 1b11 1b14 1b18 1b19 1b1e 1b1f
1b24 1b26 1b2a 1b2d 1b31 1b35 1b39 1b3c
1b40 1b42 1b46 1b49 1b4b 1b4f 1b52 1b56
1b5a 1b5e 1b62 1b66 1b6a 1b6e 1b72 1b76
1b7a 1b7e 1b82 1b8e 1b92 1b96 1b99 1b9d
1ba1 1ba3 1 1ba7 1bab 1baf 1bb2 1bb6
1bba 1bbe 1bc2 1bc5 1bc9 1bcd 1bd0 1bd3
1bd8 1bdb 1bde 1be1 1be2 1be7 1be8 1
1bea 1bef 1bf3 1bf7 1bfa 1bff 1c04 1c07
1c0b 1c0c 1c11 1c14 1c19 1c1a 1c1f 1c22
1c27 1c28 1c2d 1c30 1c34 1c35 1c3a 1c3d
1c42 1c43 1c48 1c4b 1c4f 1c53 1c56 1c59
1c5a 1c5c 1c5d 1c62 1c63 1c68 1c6a 1c6e
1c71 1c73 1c77 1c79 1c85 1c87 1c89 1c8a
1c8f 1c93 1c95 1ca1 1ca3 1ca7 1cab 1cae
1caf 1cb1 1cb4 1cb7 1cb8 1cbd 1cc1 1cc5
1cc9 1ccd 1cd1 1cd4 1cd8 1cdc 1cdf 1ce2
1ce7 1cea 1ced 1cf0 1cf1 1cf6 1cf7 1
1cf9 1cfe 1d02 1d06 1d09 1d0e 1d13 1d16
1d1a 1d1b 1d20 1d21 1d26 1d28 1d2c 1d2f
1d33 1d37 1d3b 1d3e 1d42 1d44 1d48 1d4b
1d4f 1d53 1d57 1d5b 1d5f 1d63 1d67 1d6b
1d6f 1d7b 1d7f 1d83 1d86 1d8a 1d8e 1d90
1 1d94 1d98 1d9c 1d9f 1da3 1da7 1dab
1daf 1db2 1db6 1dba 1dbd 1dc0 1dc5 1dc8
1dcb 1dce 1dcf 1dd4 1dd5 1 1dd7 1ddc
1de0 1de4 1de7 1dec 1df1 1df4 1df8 1df9
1dfe 1e01 1e06 1e07 1e0c 1e0f 1e14 1e15
1e1a 1e1d 1e21 1e22 1e27 1e2a 1e2f 1e30
1e35 1e38 1e3c 1e40 1e43 1e46 1e47 1e49
1e4a 1e4f 1e50 1e55 1e57 1e5b 1e5e 1e60
1e64 1e66 1e72 1e74 1e76 1e77 1e7c 1e80
1e82 1e8e 1e90 1e94 1e98 1e9c 1e9f 1ea0
1ea2 1ea6 1eaa 1eae 1eb1 1eb2 1eb4 1eb8
1ebb 1ebf 1ec2 1ec3 1ec5 1ec6 1ecb 1ecf
1ed3 1ed7 1edb 1edf 1ee2 1ee3 1ee5 1ee9
1eec 1ef0 1ef3 1ef4 1ef6 1ef7 1efc 1f00
1f03 1f06 1f07 1f0c 1f10 1f14 1f18 1f1c
1f20 1f24 1f28 1f2c 1f30 1f34 1f38 1f3c
1f40 1f41 1f43 1f47 1f4b 1f4f 1f52 1f53
1f55 1f58 1f5b 1f5c 1f61 1f65 1f69 1f6c
1f6d 1f6f 1f73 1f76 1f7a 1f7d 1f7e 1f80
1f81 1f86 1f8a 1f8e 1f91 1f95 1f99 1f9a
1f9c 1f9f 1fa2 1fa3 1fa8 1fac 1fb0 1fb4
1fb7 1fb8 1fba 1fbd 1fc1 1fc5 1fc8 1fc9
1fcb 1fcc 1fd1 1fd5 1fd9 1fdc 1fe0 1fe4
1fe8 1feb 1fec 1fee 1ff1 1ff5 1ff9 1ffc
1ffd 1fff 2002 2006 200a 200d 200e 2010
2011 2016 2019 201a 201f 2023 2027 202b
202e 202f 2031 2034 2038 203c 203f 2040
2042 2043 2048 204b 204e 2052 2056 2059
205a 205c 205d 2062 2066 206a 206e 2072
2076 207a 207e 2082 2086 208a 208e 2092
2096 209a 209e 20a2 20a6 20aa 20b6 20ba
20bf 20c3 20c6 20c7 20cc 20d0 20d4 20d7
20da 20de 20e0 20e4 20e8 20eb 20ee 20f2
20f4 20f8 20fc 20ff 2101 1 2105 2109
210d 2110 2114 2118 211c 2120 2123 2127
212b 212e 2131 2136 2139 213c 213f 2140
2145 2146 1 2148 214d 2151 2155 2158
215d 2162 2165 2169 216a 216f 2172 2177
2178 217d 2180 2185 2186 218b 218e 2192
2193 2198 219b 21a0 21a1 21a6 21a9 21ad
21b1 21b4 21b7 21b8 21ba 21bb 21c0 21c1
21c6 21c8 21cc 21cf 21d1 21d5 21d7 21e3
21e5 21e7 21e8 21ed 21f1 21f3 21ff 2201
2205 2209 220d 2210 2214 2218 221b 221c
221e 2222 2226 2229 222a 222c 2230 2232
2236 223a 223e 2242 2246 224a 224e 2252
2256 225a 225e 2262 2266 226a 226e 2272
227e 2282 2287 228b 228e 228f 2294 2298
229c 229f 22a2 22a6 22a8 22ac 22b0 22b3
22b6 22ba 22bc 22c0 22c4 22c7 22c9 1
22cd 22d1 22d5 22d8 22dc 22e0 22e4 22e8
22eb 22ef 22f3 22f6 22f9 22fe 2301 2304
2307 2308 230d 230e 1 2310 2315 2319
231d 2320 2325 232a 232d 2331 2332 2337
233a 233f 2340 2345 2348 234d 234e 2353
2356 235a 235b 2360 2363 2368 2369 236e
2371 2375 2379 237c 237f 2380 2382 2383
2388 2389 238e 2390 2394 2397 2399 239d
239f 23ab 23ad 23af 23b0 23b5 23b9 23bb
23c7 23c9 23cb 23cf 23d3 23d6 23d8 23dc
23e0 23e3 23e4 23e6 23e9 23ed 23f1 23f4
23f5 23f7 23fa 23fe 2402 2405 2406 2408
2409 240e 2411 2412 2417 241b 241f 2423
2426 2427 2429 242c 2430 2434 2437 2438
243a 243b 2440 2444 2448 244c 2450 2454
2458 2459 245b 245e 245f 2461 2464 2468
246c 2470 2471 2473 2476 2477 2479 247a
247f 2482 2485 2488 2489 248e 2491 2494
2497 2498 249d 249e 24a0 24a4 24a8 24ac
24b0 24b4 24b8 24bc 24c0 24c4 24c8 24cc
24d0 24d4 24d8 24dc 24e8 24ec 24f1 24f5
24f8 24f9 24fe 2502 2506 2509 250c 2510
2512 2516 251a 251d 2520 2524 2526 252a
252e 2531 2533 1 2537 253b 253f 2542
2546 254a 254e 2552 2555 2559 255d 2560
2563 2568 256b 256e 2571 2572 2577 2578
1 257a 257f 2583 2587 258a 258f 2594
2597 259b 259c 25a1 25a4 25a9 25aa 25af
25b2 25b7 25b8 25bd 25c0 25c4 25c5 25ca
25cd 25d2 25d3 25d8 25db 25df 25e3 25e6
25e9 25ea 25ec 25ed 25f2 25f3 25f8 25fa
25fe 2601 2603 2607 2609 2615 2617 2619
261a 261f 2623 2625 2631 2633 2635 2639
263d 2641 2644 2645 2647 264a 264e 2652
2655 2656 2658 2659 265e 2662 2666 2669
266d 2671 2675 2679 267d 2681 2685 2689
268d 2691 2695 2699 269d 26a1 26a5 26a9
26ad 26b9 26bd 26c2 26c6 26c9 26ca 26cf
26d3 26d7 26da 26dd 26e1 26e3 26e7 26eb
26ee 26f1 26f5 26f7 26fb 26ff 2702 2704
1 2708 270c 2710 2713 2717 271b 271f
2723 2726 272a 272e 2731 2734 2739 273c
273f 2742 2743 2748 2749 1 274b 2750
2754 2758 275b 2760 2765 2768 276c 276d
2772 2775 277a 277b 2780 2783 2788 2789
278e 2791 2795 2796 279b 279e 27a3 27a4
27a9 27ac 27b0 27b4 27b7 27ba 27bb 27bd
27be 27c3 27c4 27c9 27cb 27cf 27d2 27d4
27d8 27da 27e6 27e8 27ea 27eb 27f0 27f4
27f6 2802 2804 2806 280a 280e 2811 2813
2817 281b 281e 2820 2824 2828 282c 282f
2830 2832 2835 2839 283d 2840 2841 2843
2844 2849 284d 2851 2854 2858 285c 2860
2864 2868 286c 2870 2874 2878 287c 2880
2884 2888 288c 2890 2894 2898 28a4 28a8
28ad 28b1 28b4 28b5 28ba 28be 28c2 28c5
28c8 28cc 28ce 28d2 28d6 28d9 28dc 28e0
28e2 28e6 28ea 28ed 28ef 1 28f3 28f7
28fb 28fe 2902 2906 290a 290e 2911 2915
2919 291c 291f 2924 2927 292a 292d 292e
2933 2934 1 2936 293b 293f 2943 2946
294b 2950 2953 2957 2958 295d 2960 2965
2966 296b 296e 2973 2974 2979 297c 2980
2981 2986 2989 298e 298f 2994 2997 299b
299f 29a2 29a5 29a6 29a8 29a9 29ae 29af
29b4 29b6 29ba 29bd 29bf 29c3 29c5 29d1
29d3 29d5 29d6 29db 29df 29e1 29ed 29ef
29f1 29f5 29f9 29fc 2a00 2a03 2a04 2a09
2a0c 2a10 2a11 2a15 2a19 2a1d 2a21 2a25
2a29 2a2d 2a31 2a35 2a41 2a45 2a49 2a4c
2a50 2a54 2a56 1 2a5a 2a5e 2a62 2a65
2a69 2a6d 2a71 2a75 2a78 2a7c 2a80 2a83
2a86 2a8b 2a8e 2a91 2a94 2a95 2a9a 2a9b
1 2a9d 2aa2 2aa6 2aaa 2aad 2ab2 2ab7
2aba 2abe 2abf 2ac4 2ac7 2acc 2acd 2ad2
2ad5 2ada 2adb 2ae0 2ae3 2ae7 2ae8 2aed
2af0 2af5 2af6 2afb 2afe 2b02 2b06 2b09
2b0c 2b0d 2b0f 2b10 2b15 2b16 2b1b 2b1d
2b21 2b24 2b26 2b2a 2b2c 2b38 2b3a 2b3c
2b3d 2b42 2b46 2b48 2b54 2b56 2b5a 2b5d
2b5e 2b63 2b66 2b6a 2b6e 2b72 2b76 2b7a
2b86 2b8a 2b8e 2b91 2b95 2b99 2b9b 1
2b9f 2ba3 2ba7 2baa 2bae 2bb2 2bb6 2bba
2bbd 2bc1 2bc5 2bc8 2bcb 2bd0 2bd3 2bd6
2bd9 2bda 2bdf 2be0 1 2be2 2be7 2beb
2bef 2bf2 2bf7 2bfc 2bff 2c03 2c04 2c09
2c0c 2c11 2c12 2c17 2c1a 2c1f 2c20 2c25
2c28 2c2c 2c2d 2c32 2c35 2c3a 2c3b 2c40
2c43 2c47 2c4b 2c4e 2c51 2c52 2c54 2c55
2c5a 2c5b 2c60 2c62 2c66 2c69 2c6b 2c6f
2c71 2c7d 2c7f 2c81 2c82 2c87 2c8b 2c8d
2c99 2c9b 2c9f 2ca3 2ca6 2caa 2cae 2cb1
2cb2 2cb4 2cb7 2cba 2cbb 2cc0 2cc4 2cc8
2ccc 2cce 2cd2 2cd5 2cd9 2cdb 2cdf 2ce3
2ce6 2ce7 2ce9 2cec 2cef 2cf0 2cf5 2cf9
2cfd 2d01 2d04 2d08 2d0c 2d0f 2d10 2d12
2d16 2d1a 2d1d 2d1e 2d20 2d23 2d27 2d2b
2d2f 2d33 2d37 2d3b 2d3f 2d43 2d47 2d4b
2d4f 2d5b 2d5f 2d63 2d66 2d6a 2d6e 2d70
1 2d74 2d78 2d7c 2d7f 2d83 2d87 2d8b
2d8f 2d92 2d96 2d9a 2d9d 2da0 2da5 2da8
2dab 2dae 2daf 2db4 2db5 1 2db7 2dbc
2dc0 2dc4 2dc7 2dcc 2dd1 2dd4 2dd8 2dd9
2dde 2de1 2de6 2de7 2dec 2def 2df4 2df5
2dfa 2dfd 2e01 2e02 2e07 2e0a 2e0f 2e10
2e15 2e18 2e1c 2e20 2e23 2e26 2e27 2e29
2e2a 2e2f 2e30 2e35 2e37 2e3b 2e3e 2e40
2e44 2e46 2e52 2e54 2e56 2e57 2e5c 2e60
2e62 2e6e 2e70 2e72 2e76 2e7a 2e7e 2e82
2e86 2e8a 2e8e 2e92 2e96 2e9a 2e9e 2eaa
2eae 2eb2 2eb5 2eb9 2ebd 2ebf 1 2ec3
2ec7 2ecb 2ece 2ed2 2ed6 2eda 2ede 2ee1
2ee5 2ee9 2eec 2eef 2ef4 2ef7 2efa 2efd
2efe 2f03 2f04 1 2f06 2f0b 2f0f 2f13
2f16 2f1b 2f20 2f23 2f27 2f28 2f2d 2f30
2f35 2f36 2f3b 2f3e 2f43 2f44 2f49 2f4c
2f50 2f51 2f56 2f59 2f5e 2f5f 2f64 2f67
2f6b 2f6f 2f72 2f75 2f76 2f78 2f79 2f7e
2f7f 2f84 2f86 2f8a 2f8d 2f8f 2f93 2f95
2fa1 2fa3 2fa5 2fa6 2fab 2faf 2fb1 2fbd
2fbf 2fc1 2fc5 2fc9 2fcc 2fce 2fd2 2fd5
2fd9 2fdc 2fdd 2fe2 2fe5 2fe9 2fed 2ff1
2ff5 2ff8 2ff9 2ffb 2fff 3001 3005 3009
300c 300f 3010 3012 3015 301a 301b 3020
3024 3028 302c 3030 3033 3034 3036 303a
303c 3040 3044 3048 304c 304f 3050 3052
3056 3058 305c 3060 3063 3065 3069 306d
3070 3074 3077 307b 307f 3083 3087 308b
308f 3093 3097 309b 309e 30a2 30a6 30a9
30aa 30ac 30ad 30af 30b3 30b7 30bb 30be
30bf 30c1 30c4 30c7 30c8 30cd 30d1 30d5
30d9 30dd 30e1 30e4 30e8 30ec 30ef 30f2
30f7 30fa 30fd 3100 3101 3106 3107 1
3109 310e 3112 3116 3119 311e 3123 3126
312a 312b 3130 3131 3136 3138 313c 313f
3143 3147 314b 314e 314f 3151 3155 3157
315b 315e 3162 3166 316a 316c 3170 3173
3175 3179 317d 3181 3185 3189 318a 318c
318f 3190 3192 3195 3199 319d 31a1 31a2
31a4 31a7 31a8 31aa 31ab 31b0 31b3 31b6
31b9 31ba 31bf 31c2 31c5 31c8 31c9 31ce
31cf 31d1 31d5 31d7 31db 31df 31e2 31e6
31ea 31ee 31f2 31f6 31fa 31fe 3202 3206
320a 320e 3212 3216 321a 321e 3222 3226
322a 322e 3232 3236 323a 323e 3242 3246
324a 324e 3251 3252 3254 3255 3257 325b
325f 3263 3267 326b 326f 3272 3276 327a
327d 3280 3285 3288 328b 328e 328f 3294
3295 1 3297 329c 32a0 32a4 32a7 32ac
32b1 32b4 32b8 32b9 32be 32bf 32c4 32c6
32ca 32cd 32d1 32d5 32d9 32dc 32dd 32df
32e3 32e7 32e9 32ed 32f1 32f4 32f5 32f7
32fb 32fe 3302 3305 3306 3308 3309 330e
3312 3316 331a 331e 3322 3326 332a 332e
3332 3336 333a 3346 334a 334f 3353 3356
3357 335c 3360 3364 3367 336a 336e 3370
3374 3378 337b 337e 3382 3384 3388 338c
338f 3391 1 3395 3399 339d 33a0 33a4
33a8 33ac 33b0 33b3 33b7 33bb 33be 33c1
33c6 33c9 33cc 33cf 33d0 33d5 33d6 1
33d8 33dd 33e1 33e5 33e8 33ed 33f2 33f5
33f9 33fa 33ff 3402 3407 3408 340d 3410
3415 3416 341b 341e 3422 3423 3428 342b
3430 3431 3436 3439 343d 3441 3444 3447
3448 344a 344b 3450 3451 3456 3458 345c
345f 3461 3465 3467 3473 3475 3477 3478
347d 3481 3483 348f 3491 3495 3499 349d
34a1 34a5 34a9 34ad 34b1 34b5 34b9 34bd
34c9 34cd 34d2 34d6 34d9 34da 34df 34e3
34e7 34ea 34ed 34f1 34f3 34f7 34fb 34fe
3501 3505 3507 350b 350f 3512 3514 1
3518 351c 3520 3523 3527 352b 352f 3533
3536 353a 353e 3541 3544 3549 354c 354f
3552 3553 3558 3559 1 355b 3560 3564
3568 356b 3570 3575 3578 357c 357d 3582
3585 358a 358b 3590 3593 3598 3599 359e
35a1 35a5 35a6 35ab 35ae 35b3 35b4 35b9
35bc 35c0 35c4 35c7 35ca 35cb 35cd 35ce
35d3 35d4 35d9 35db 35df 35e2 35e4 35e8
35ea 35f6 35f8 35fa 35fb 3600 3604 3606
3612 3614 3618 361a 361e 3622 3626 3629
362a 362c 3630 3633 3637 363a 363b 363d
363e 3643 3647 364b 364e 364f 3651 3654
3657 3658 365d 3661 3664 3668 366a 366e
3672 3675 3676 3678 367b 367e 367f 3684
3687 368b 368f 3692 3693 3695 3698 369b
369c 36a1 1 36a4 36a9 36ad 36b1 36b5
36b9 36bd 36c0 36c4 36c8 36cb 36ce 36d3
36d6 36d9 36dc 36dd 36e2 36e3 1 36e5
36ea 36ee 36f2 36f5 36fa 36ff 3702 3706
3707 370c 370d 3712 3714 3718 371b 371f
3723 3727 372a 372e 3730 3734 3737 373b
373f 3743 3746 3747 3749 374d 374f 3753
3757 375a 375e 3761 3762 3767 376a 376e
3772 3776 377a 377e 378a 378e 3792 3795
3799 379d 379f 1 37a3 37a7 37ab 37ae
37b2 37b6 37ba 37be 37c1 37c5 37c9 37cc
37cf 37d4 37d7 37da 37dd 37de 37e3 37e4
1 37e6 37eb 37ef 37f3 37f6 37fb 3800
3803 3807 3808 380d 3810 3815 3816 381b
381e 3823 3824 3829 382c 3830 3831 3836
3839 383e 383f 3844 3847 384b 384f 3852
3855 3856 3858 3859 385e 385f 3864 3866
386a 386d 386f 3873 3875 3881 3883 3885
3886 388b 388f 3891 389d 389f 38a3 38a7
38aa 38ae 38b1 38b5 38b8 38b9 38be 38c1
38c5 38c9 38cc 38cd 38cf 38d3 38d6 38da
38dd 38de 38e0 38e1 38e6 1 38e9 38ee
38f2 38f6 38fa 38fe 3902 3905 3909 390d
3910 3913 3918 391b 391e 3921 3922 3927
3928 1 392a 392f 3933 3937 393a 393f
3944 3947 394b 394c 3951 3952 3957 3959
395d 3960 3964 3968 396c 396f 3973 3975
3979 397c 397e 3982 3985 3989 398c 398f
3990 3995 3999 399d 39a1 39a5 39a9 39ad
39b1 39b5 39b9 39bd 39c1 39c5 39c9 39ca
39cc 39d0 39d4 39d8 39db 39dc 39de 39e1
39e4 39e5 39ea 39ed 39f1 39f4 39f5 39fa
39fd 1 3a00 3a05 3a09 3a0d 3a11 3a15
3a19 3a1d 3a21 3a25 3a29 3a2c 3a2d 3a2f
3a33 3a35 3a39 3a3c 3a40 3a43 3a44 3a49
3a4c 3a50 3a54 3a58 3a5c 3a5f 3a60 3a62
3a66 3a68 3a6c 3a70 3a73 3a76 3a77 3a79
3a7c 3a81 3a82 3a87 3a8b 3a8f 3a93 3a97
3a9a 3a9b 3a9d 3aa1 3aa3 3aa7 3aab 3aaf
3ab3 3ab6 3ab7 3ab9 3abd 3abf 3ac3 3ac7
3aca 3acc 3ad0 3ad4 3ad7 3adb 3ade 3adf
3ae4 3ae7 3aeb 3aef 3af3 3af7 3afb 3aff
3b03 3b07 3b0b 3b0f 3b1b 3b1f 3b23 3b26
3b2a 3b2e 3b30 1 3b34 3b38 3b3c 3b3f
3b43 3b47 3b4b 3b4f 3b52 3b56 3b5a 3b5d
3b60 3b65 3b68 3b6b 3b6e 3b6f 3b74 3b75
1 3b77 3b7c 3b80 3b84 3b87 3b8c 3b91
3b94 3b98 3b99 3b9e 3ba1 3ba6 3ba7 3bac
3baf 3bb4 3bb5 3bba 3bbd 3bc1 3bc2 3bc7
3bca 3bcf 3bd0 3bd5 3bd8 3bdc 3be0 3be3
3be6 3be7 3be9 3bea 3bef 3bf0 3bf5 3bf7
3bfb 3bfe 3c00 3c04 3c06 3c12 3c14 3c16
3c17 3c1c 3c20 3c22 3c2e 3c30 3c34 3c38
3c3c 3c3f 3c40 3c42 3c45 3c49 3c4d 3c50
3c51 3c53 3c54 3c59 3c5d 3c5f 3c63 3c66
3c6a 3c6d 3c71 3c75 3c78 3c7c 3c80 3c84
3c88 3c8c 3c90 3c94 3c98 3c9c 3c9f 3ca3
3ca7 3caa 3cab 3cad 3cae 3cb0 3cb4 3cb8
3cbc 3cbf 3cc0 3cc2 3cc5 3cc8 3cc9 3cce
3cd2 3cd6 3cda 3cde 3ce2 3ce5 3ce9 3ced
3cf0 3cf3 3cf8 3cfb 3cfe 3d01 3d02 3d07
3d08 1 3d0a 3d0f 3d13 3d17 3d1a 3d1f
3d24 3d27 3d2b 3d2c 3d31 3d32 3d37 3d39
3d3d 3d40 3d44 3d48 3d4c 3d4f 3d53 3d55
3d59 3d5d 3d61 3d65 3d69 3d6d 3d71 3d75
3d79 3d7d 3d81 3d85 3d89 3d8d 3d91 3d95
3d99 3d9d 3da9 3dad 3db2 3db6 3db9 3dba
3dbf 3dc3 3dc7 3dca 3dcd 3dd1 3dd3 3dd7
3ddb 3dde 3de1 3de5 3de7 3deb 3def 3df2
3df4 1 3df8 3dfc 3e00 3e03 3e07 3e0b
3e0f 3e13 3e16 3e1a 3e1e 3e21 3e24 3e29
3e2c 3e2f 3e32 3e33 3e38 3e39 1 3e3b
3e40 3e44 3e48 3e4b 3e50 3e55 3e58 3e5c
3e5d 3e62 3e65 3e6a 3e6b 3e70 3e73 3e78
3e79 3e7e 3e81 3e85 3e86 3e8b 3e8e 3e93
3e94 3e99 3e9c 3ea0 3ea4 3ea7 3eaa 3eab
3ead 3eae 3eb3 3eb4 3eb9 3ebb 3ebf 3ec2
3ec4 3ec8 3eca 3ed6 3ed8 3eda 3edb 3ee0
3ee4 3ee6 3ef2 3ef4 3ef6 3efa 3efe 3f01
3f03 3f07 3f0b 3f0e 3f10 3f14 3f18 3f1b
3f1f 3f23 3f26 3f2a 3f2e 3f2f 3f31 3f35
3f39 3f3d 3f40 3f44 3f48 3f4b 3f4e 3f53
3f56 3f59 3f5c 3f5d 3f62 3f63 1 3f65
3f6a 3f6e 3f72 3f75 3f7a 3f7f 3f82 3f86
3f87 3f8c 3f8f 3f94 3f95 3f9a 3f9d 3fa2
3fa3 3fa8 3fab 3faf 3fb3 3fb6 3fb7 3fbc
3fbd 3fc2 3fc4 3fc8 3fcb 3fcf 3fd3 3fd7
3fda 3fde 3fe0 3fe4 3fe6 3ff2 3ff6 3ff8
3ff9 4002 
122a
2
0 1 a 6 15 19 20 :3 6
1c :3 6 12 :3 6 11 :3 6 14 18
1f :3 6 14 18 1f :2 6 1 3
a :2 1 4 :2 17 26 17 :2 4 :2 d
1c d :2 4 :2 c 1b c :2 4 9
12 11 :2 9 :2 4 14 1d 1c :2 14
:2 4 11 1a 19 :2 11 :2 4 e 17
16 :2 e :2 4 d 16 15 :2 d :2 4
:3 9 :2 4 :3 9 :2 4 :3 11 :2 4 :3 12 :2 4
:3 15 :2 4 :3 e :2 4 f 18 17 :2 f
:2 4 f 18 17 :2 f :2 4 11 1a
19 :2 11 :2 4 :2 f 1e f :2 4 :2 16
25 16 :2 4 :2 d 1c d :2 4 :2 13
22 13 :2 4 :2 14 23 14 :2 4 :2 12
21 12 :2 4 :2 11 20 11 :2 4 :2 f
1e f :2 4 :2 e 1d e :2 4 :2 10
1f 10 :2 4 :2 11 20 11 :2 4 :2 f
1e f :2 4 :2 e 1d e :2 4 :2 f
1e f :2 4 :2 e 1d e :2 4 :2 e
1d e :2 4 :2 f 1e f :2 4 :2 c
1b c :2 4 :2 b 1a b :2 4 :2 b
1a b :2 4 :2 13 22 13 :2 4 :2 10
1f 10 :2 4 :2 a 19 a :2 4 :2 11
20 11 :2 4 :2 10 1f 10 :2 4 :2 12
21 12 :2 4 c 10 f c 20
:2 29 c :2 4 d 11 10 d 21
:2 2a d :2 4 14 1d 1c :2 14 :2 4
:2 f 19 f :2 4 :2 f 19 f :2 4
:2 10 1a 10 :2 4 :2 10 1a 10 :2 4
:2 11 1b 11 :2 4 :2 11 1b 11 :2 4
:2 12 1c 12 :2 4 :2 12 1c 12 :2 4
:2 15 24 15 :2 4 :2 c 16 c :2 4
:2 d 1c d :2 4 :2 d 1c d :2 4
:2 d 1c d :2 4 :2 d 1c d 4
7 :2 11 23 :2 2d 3a :2 23 :3 7 :2 d
19 25 :2 2f 43 :2 25 56 5c 5f
:2 56 6d 85 8 :2 6d d 10 :2 6d
1c 1f :2 6d b e :2 6d 13 16
1f 27 :2 1f 3f :2 16 :2 6d b e
:2 6d 13 16 1f 27 :2 1f 35 :2 16
:2 6d b e :2 6d 13 16 1f 27
:2 1f 34 :2 16 :2 6d b e :2 6d 13
16 :2 6d 1b 1e :2 6d 29 2c :2 6d
b e :2 6d 13 16 :2 6d 1b 1e
:2 6d 29 2c :2 6d 31 34 :2 6d :2 7
4c :2 4 7 :2 11 23 :2 2d 39 3c
4e 50 51 :2 4e :2 23 :3 7 :2 d 12
1e 5f 62 :2 1e :2 7 54 :3 4 c
4 e 1a 27 36 40 50 5d
68 75 7 13 23 3a 45 4f
57 69 78 87 99 7 19 2c
34 3b 56 5e 65 81 8b 7
15 23 31 7 17 27 37 7
1a 23 c 1a 24 30 3c 4e
5d 6a 7 11 1d 2e 39 41
4a 52 7 15 24 2a 30 3c
7 13 20 2c 7 15 24 32
7 17 22 c d 21 :2 7 :2 10
1c 7 4 :2 c a :2 13 1f a
d :2 17 29 :2 33 3f 43 55 58
59 :2 55 :2 29 :3 d :2 13 18 24 66
69 :2 24 76 79 :2 24 7d 80 :2 24
8c 8f :2 24 97 9a :2 24 a6 a9
b0 b9 bc :2 a9 :2 24 :2 d 5c :2 a
:2 7 :4 13 :2 7 4 :3 1 8 :2 11 1c
1a :2 25 :2 1a 7 11 1d 28 36
43 56 f 1d 2a 34 43 53
f 10 1d :2 a :2 13 1f a 7
:2 f d :2 16 22 d 10 :2 1a 2c
:2 36 42 46 58 5b 5c :2 58 :2 2c
:3 10 :2 16 1b 27 69 6c :2 27 79
7c :2 27 80 83 :2 27 8f 92 :2 27
9a 9d :2 27 a9 ac b3 bc bf
:2 ac :2 27 :2 10 5f :2 d :2 a :4 16 :2 a
7 :3 35 b :2 14 1f 1d :2 28 :2 1d
:2 a 18 a d :2 17 29 :2 33 3f
42 54 57 58 :2 54 :2 29 :3 d :2 13
18 24 66 69 :2 24 :2 d 5b :3 a
11 :2 1a a 38 :3 7 15 7 11
:2 f 10 1d :2 a :2 13 1f a 7
:2 f d :2 16 22 d 10 :2 1a 2c
:2 36 42 46 58 5b 5c :2 58 :2 2c
:3 10 :2 16 1b 27 69 6c :2 27 79
7c :2 27 80 83 :2 27 8f 92 :2 27
9a 9d :2 27 a9 ac b3 bc bf
:2 ac :2 27 :2 10 5f :2 d :2 a :4 16 :2 a
7 :3 35 a 13 1f :2 a 22 24
:2 22 14 :2 12 13 20 :2 d :2 16 22
d a :2 12 10 :2 19 25 10 13
:2 1d 2f :2 39 45 49 5b 5e 5f
:2 5b :2 2f :3 13 :2 19 1e 2a 6c 6f
:2 2a 7c 7f :2 2a 83 86 :2 2a 92
95 :2 2a 9d a0 :2 2a ac af b6
bf c2 :2 af :2 2a :2 13 62 :2 10 :2 d
:4 19 :2 d a :3 26 d :2 18 1f 2d
:2 d 32 34 :2 32 d 1b d 10
:2 1a 2c :2 36 42 45 57 5a 5b
:2 57 :2 2c :3 10 :2 16 1b 27 69 6c
:2 27 :2 10 5e :3 d 14 :2 1d d 36
:2 a 26 :2 7 11 :2 f 11 13 f
20 24 2f 10 13 20 e 11
1b e 11 25 27 e 10 25
27 e 10 1a 23 :2 a :2 13 1f
a 7 :2 f d :2 16 22 d 10
:2 1a 2c :2 36 42 46 58 5b 5c
:2 58 :2 2c :3 10 :2 16 1b 27 69 6c
:2 27 79 7c :2 27 80 83 :2 27 8f
92 :2 27 9a 9d :2 27 a9 ac b3
bc bf :2 ac :2 27 :2 10 5f :2 d :2 a
:4 16 :2 a 7 :3 35 a 13 1f :2 a
22 24 :2 22 a 18 a d :2 17
29 :2 33 3f 42 54 57 58 :2 54
:2 29 :3 d :2 13 18 24 66 69 :2 24
:2 d 5b :3 a 11 :2 1a a 26 :2 7
a 13 1d :2 a 20 22 :2 20 d
:2 17 29 :2 33 3f 42 54 57 58
:2 54 :2 29 :3 d :2 13 18 24 66 69
:2 24 76 79 :2 24 7d 80 :2 24 8a
8d 96 9e :2 a7 :2 96 b8 :2 8d :2 24
:2 d 5b :2 a d :2 17 29 :2 33 3f
42 54 57 58 :2 54 :2 29 :3 d :2 13
18 24 66 69 :2 24 :2 d 5b :3 a
11 :2 1c 2f :2 38 48 :2 11 a 7
24 d 16 20 :2 d 26 23 2f
3e :2 26 :2 23 a 1a a d 16
20 :2 d 25 23 2e 38 :2 25 :2 23
d 1b d 10 :2 1a 2c :2 36 42
45 57 5a 5b :2 57 :2 2c :3 10 :2 16
1b 27 69 6c :2 27 :2 10 5e :3 d
14 :2 1d d a 3b 10 19 23
:2 10 28 26 31 3b :2 28 :2 26 d
1d d 3e 3b :3 a 1a :2 a 18
2a 38 3e 4c 58 21 2f :2 58
:2 18 a 41 24 d :2 17 29 :2 33
3f 42 54 57 58 :2 54 :2 29 :3 d
:2 13 18 24 66 69 :2 24 76 79
:2 24 7d 80 :2 24 8a 8d 96 9e
:2 a7 :2 96 b8 :2 8d :2 24 :2 d 5b :2 a
d :2 17 29 :2 33 3f 42 54 57
58 :2 54 :2 29 :3 d :2 13 18 24 66
69 :2 24 :2 d 5b :3 a 11 :2 1c 2f
:2 38 48 :2 11 a :4 7 35 a 13
1d :2 a 20 22 :2 20 a 18 a
d :2 17 29 :2 33 3f 42 54 57
58 :2 54 :2 29 :3 d :2 13 18 24 66
69 :2 24 :2 d 5b :3 a 11 :2 1a a
24 :3 7 15 7 11 :2 f 10 1d
:2 a :2 13 1f a 7 :2 f d :2 16
22 d 10 :2 1a 2c :2 36 42 46
58 5b 5c :2 58 :2 2c :3 10 :2 16 1b
27 69 6c :2 27 79 7c :2 27 80
83 :2 27 8f 92 :2 27 9a 9d :2 27
a9 ac b3 bc bf :2 ac :2 27 :2 10
5f :2 d :2 a :4 16 :2 a 7 :3 4 a
13 1f :2 a 22 24 :2 22 14 :2 12
13 20 :2 d :2 16 22 d a :2 12
10 :2 19 25 10 13 :2 1d 2f :2 39
45 49 5b 5e 5f :2 5b :2 2f :3 13
:2 19 1e 2a 6c 6f :2 2a 7c 7f
:2 2a 83 86 :2 2a 92 95 :2 2a 9d
a0 :2 2a ac af b6 bf c2 :2 af
:2 2a :2 13 62 :2 10 :2 d :4 19 :2 d a
:3 26 d :2 18 1f 2d :2 d 32 34
:2 32 d 1b d 10 :2 1a 2c :2 36
42 45 57 5a 5b :2 57 :2 2c :3 10
:2 16 1b 27 69 6c :2 27 :2 10 5e
:3 d 14 :2 1d d 36 :2 a 26 :2 7
11 :2 f 11 f 10 24 e 23
e 18 21 :2 a :2 13 1f a 7
:2 f d :2 16 22 d 10 :2 1a 2c
:2 36 42 46 58 5b 5c :2 58 :2 2c
:3 10 :2 16 1b 27 69 6c :2 27 79
7c :2 27 80 83 :2 27 8f 92 :2 27
9a 9d :2 27 a9 ac b3 bc bf
:2 ac :2 27 :2 10 5f :2 d :2 a :4 16 :2 a
7 :3 4 a 13 1f :2 a 22 24
:2 22 a 18 a d :2 17 29 :2 33
3f 42 54 57 58 :2 54 :2 29 :3 d
:2 13 18 24 66 69 :2 24 :2 d 5b
:3 a 11 :2 1a a 26 :2 7 11 1d
f 1d f 10 1d e 1b :2 a
:2 13 1f a 7 :2 f d :2 16 22
d 10 :2 1a 2c :2 36 42 46 58
5b 5c :2 58 :2 2c :3 10 :2 16 1b 27
69 6c :2 27 79 7c :2 27 80 83
:2 27 8f 92 :2 27 9a 9d :2 27 a9
ac b3 bc bf :2 ac :2 27 :2 10 5f
:2 d :2 a :4 16 :2 a 7 :3 4 7 19
22 2c :2 19 7 a 13 1d :2 a
23 20 2c 3b :2 23 :2 20 a 1a
a d 16 24 :2 d 29 27 32
3c :2 29 :2 27 d 1d 1e :2 1d :2 d
1b 32 40 4b 51 57 5d 28
34 42 55 :2 1b d 10 19 25
:2 10 28 2a :2 28 13 1c 29 :2 13
2f 2c 38 3f :2 2f :2 2c 16 :2 21
28 32 :2 16 3e 40 :2 3e 16 22
2b 39 :2 22 3c 3e 47 51 :2 3e
:2 22 :2 16 28 16 19 22 30 :2 19
33 36 3f 4e :2 36 51 53 5c
63 :2 53 :2 36 35 :2 33 19 23 2c
3b :2 23 3e 40 49 50 :2 40 :2 23
22 54 56 5f 6d :2 56 :2 22 19
23 20 1c 2a 33 3a 46 4f
1c 29 1c 2a 1c 22 1c 22
36 1c 23 1f 2b :3 29 1f :2 28
34 1f 30 1f :2 28 34 1f :4 1c
19 :2 21 1f :2 28 34 1f 22 :2 2c
3e :2 48 54 58 6a 6d 6e :2 6a
:2 3e :3 22 :2 28 2d 39 7b 7e :2 39
8b 8e :2 39 92 95 :2 39 a1 a4
:2 39 ac af :2 39 bb be c5 ce
d1 :2 be :2 39 :2 22 71 :2 1f :2 1c :4 28
:2 1c 19 :3 67 19 2b :2 34 3b 44
54 :2 3b 58 :2 61 :2 2b 19 67 23
20 1c 2a 33 3a 46 4f 1c
29 1c 2a :2 1c 22 36 1c 23
1f 2b :3 29 1f :2 28 34 1f 30
1f :2 28 34 1f :4 1c 19 :2 21 1f
:2 28 34 1f 22 :2 2c 3e :2 48 54
58 6a 6d 6e :2 6a :2 3e :3 22 :2 28
2d 39 7b 7e :2 39 8b 8e :2 39
92 95 :2 39 a1 a4 :2 39 ac af
:2 39 bb be c5 ce d1 :2 be :2 39
:2 22 71 :2 1f :2 1c :4 28 :2 1c 19 :7 16
42 19 22 30 :2 19 33 36 3f
4e :2 36 51 53 5c 63 :2 53 :2 36
35 :2 33 19 25 2e 35 :2 25 38
3a 43 4d :2 3a :2 25 :2 19 2b 33
3c 46 :2 3c 55 :2 33 58 5a 63
6d :2 63 78 :2 5a :2 33 32 24 26
:2 32 31 30 32 :2 31 :2 2b 19 23
20 1c 2a 33 3a 46 4f 1c
29 1c 2a 22 36 1c 23 1f
2b :3 29 1f :2 28 34 1f 30 1f
:2 28 34 1f :4 1c 19 :2 21 1f :2 28
34 1f 22 :2 2c 3e :2 48 54 58
6a 6d 6e :2 6a :2 3e :3 22 :2 28 2d
39 7b 7e :2 39 8b 8e :2 39 92
95 :2 39 a1 a4 :2 39 ac af :2 39
bb be c5 ce d1 :2 be :2 39 :2 22
71 :2 1f :2 1c :4 28 :2 1c 19 :4 67 19
25 2e 3c :2 25 3f 41 4a 54
:2 41 :2 25 :2 19 2b 19 23 20 1c
2a 33 3a 46 4f 1c 29 1c
2a :2 1c 22 36 1c 23 1f 2b
:3 29 1f :2 28 34 1f 30 1f :2 28
34 1f :4 1c 19 :2 21 1f :2 28 34
1f 22 :2 2c 3e :2 48 54 58 6a
6d 6e :2 6a :2 3e :3 22 :2 28 2d 39
7b 7e :2 39 8b 8e :2 39 92 95
:2 39 a1 a4 :2 39 ac af :2 39 bb
be c5 ce d1 :2 be :2 39 :2 22 71
:2 1f :2 1c :4 28 :2 1c 19 :7 16 :4 13 42
13 1f 28 36 :2 1f 39 3b 44
53 :2 3b :2 1f :2 13 25 13 1d 1a
16 24 2d 34 40 49 16 23
16 24 :2 16 1c 30 16 1d 19
25 :3 23 19 :2 22 2e 19 2a 19
:2 22 2e 19 :4 16 13 :2 1b 19 :2 22
2e 19 1c :2 26 38 :2 42 4e 52
64 67 68 :2 64 :2 38 :3 1c :2 22 27
33 75 78 :2 33 85 88 :2 33 8c
8f :2 33 9b 9e :2 33 a6 a9 :2 33
b5 b8 bf c8 cb :2 b8 :2 33 :2 1c
6b :2 19 :2 16 :4 22 :2 16 13 :7 10 :4 14
:2 13 20 13 1d 21 :2 1b 1c 29
1a 28 :2 16 :2 1f 2b 16 13 :2 1b
19 :2 22 2e 19 1c :2 26 38 :2 42
4e 52 64 67 68 :2 64 :2 38 :3 1c
:2 22 27 33 75 78 :2 33 85 88
:2 33 8c 8f :2 33 9b 9e :2 33 a6
a9 :2 33 b5 b8 bf c8 cb :2 b8
:2 33 :2 1c 6b :2 19 :2 16 :4 22 :2 16 13
:3 32 :4 17 16 20 28 2f 50 5f
:2 19 :2 22 2e 19 16 :2 1e 1c :2 25
31 1c 1f :2 29 3b :2 45 51 55
67 6a 6b :2 67 :2 3b :3 1f :2 25 2a
36 78 7b :2 36 88 8b :2 36 8f
92 :2 36 9e a1 :2 36 a9 ac :2 36
b8 bb c2 cb ce :2 bb :2 36 :2 1f
6e :2 1c :2 19 :4 25 :2 19 16 :3 2e 19
:2 24 2c 3e 49 :2 19 4d 4f :2 4d
19 29 19 51 :2 16 13 2e 19
22 2d :2 19 30 32 :2 30 16 24
:2 2d 34 3d 48 :2 34 4c :2 55 :2 24
23 16 20 2b 38 40 47 62
6d 72 :2 1e :2 19 :2 22 2e 19 16
:2 1e 1c :2 25 31 1c 1f :2 29 3b
:2 45 51 55 67 6a 6b :2 67 :2 3b
:3 1f :2 25 2a 36 78 7b :2 36 88
8b :2 36 8f 92 :2 36 9e a1 :2 36
a9 ac :2 36 b8 bb c2 cb ce
:2 bb :2 36 :2 1f 6e :2 1c :2 19 :4 25 :2 19
16 :4 34 2e 20 2b 38 40 47
62 6d 72 :2 1e :2 19 :2 22 2e 19
16 :2 1e 1c :2 25 31 1c 1f :2 29
3b :2 45 51 55 67 6a 6b :2 67
:2 3b :3 1f :2 25 2a 36 78 7b :2 36
88 8b :2 36 8f 92 :2 36 9e a1
:2 36 a9 ac :2 36 b8 bb c2 cb
ce :2 bb :2 36 :2 1f 6e :2 1c :2 19 :4 25
:2 19 16 :7 13 32 :2 10 :4 14 :2 13 21
31 3f 45 :2 21 13 31 16 1d
29 2c :2 16 2f 31 :2 2f 16 24
34 42 48 :2 24 16 35 16 24
34 42 48 :2 24 16 :4 13 :5 10 1e
:2 10 1e 2c 32 40 4a 56 61
6d 1f 28 39 :2 1f :2 1e 10 13
1c 28 :2 13 2b 2e :2 2b 13 21
13 16 :2 20 32 :2 3c 48 4b 5d
60 61 :2 5d :2 32 :3 16 :2 1c 21 2d
6f 72 :2 2d :2 16 64 :3 13 1a 23
2f :2 1a 13 30 :3 10 1c 10 2c
:2 d 3f d 1f 27 30 3a :2 30
49 :2 27 4c 4e 57 61 :2 57 6c
:2 4e :2 27 26 24 :3 26 25 30 32
:2 25 :2 1f d :5 a 18 2c 3a 45
4f 55 25 31 3b 49 25 34
44 50 25 31 3e 4c 25 33
42 55 25 31 3d 46 51 :2 3d
:2 18 :2 a 18 a d :2 17 29 :2 33
3f 42 54 57 58 :2 54 :2 29 :3 d
:2 13 18 24 66 69 :2 24 :2 d 5b
:3 a 11 1a 26 :2 11 a 7 3e
d 16 2a :2 d 30 2d 39 49
:2 30 :2 2d 14 11 25 d 1b 24
2b 37 40 13 27 d 14 10
1c :3 1a 10 :2 19 25 10 21 10
:2 19 25 10 :4 d a :2 12 10 :2 19
25 10 13 :2 1d 2f :2 39 45 49
5b 5e 5f :2 5b :2 2f :3 13 :2 19 1e
2a 6c 6f :2 2a 7c 7f :2 2a 83
86 :2 2a 92 95 :2 2a 9d a0 :2 2a
ac af b6 bf c2 :2 af :2 2a :2 13
62 :2 10 :2 d :4 19 :2 d a :3 4c 14
11 1f 28 2f 3b 44 13 20
11 1e d 14 10 1c :3 1a 10
:2 19 25 10 21 10 :2 19 25 10
:4 d a :2 12 10 :2 19 25 10 13
:2 1d 2f :2 39 45 49 5b 5e 5f
:2 5b :2 2f :3 13 :2 19 1e 2a 6c 6f
:2 2a 7c 7f :2 2a 83 86 :2 2a 92
95 :2 2a 9d a0 :2 2a ac af b6
bf c2 :2 af :2 2a :2 13 62 :2 10 :2 d
:4 19 :2 d a :3 4c 7 4c 3e d
16 1f :2 d 25 22 2e 3f :2 25
:2 22 d 16 1f :2 d 22 24 :2 22
d 20 d 26 11 1a 23 :2 11
26 28 :2 26 10 2f 38 41 :2 2f
44 46 :2 44 2e :3 10 1e 10 13
:2 1d 2f :2 39 45 48 5a 5d 5e
:2 5a :2 2f :3 13 :2 19 1e 2a 6c 6f
:2 2a :2 13 61 :3 10 17 :2 20 10 51
:3 d 20 29 32 :2 20 d :4 a :4 e
d 17 :2 15 16 2a :2 10 :2 19 25
10 d :2 15 13 :2 1c 28 13 16
:2 20 32 :2 3c 48 4c 5e 61 62
:2 5e :2 32 :3 16 :2 1c 21 2d 6f 72
:2 2d 7f 82 :2 2d 86 89 :2 2d 95
98 :2 2d a0 a3 :2 2d af b2 b9
c2 c5 :2 b2 :2 2d :2 16 65 :2 13 :2 10
:4 1c :2 10 d :3 2b 11 :2 1a 25 23
:2 2e :2 23 10 43 4c 5d :2 43 62
60 13 1f :2 62 :2 60 42 :3 10 1e
10 13 :2 1d 2f :2 39 45 48 5a
5d 5e :2 5a :2 2f :3 13 :2 19 1e 2a
6c 6f :2 2a :2 13 61 :3 10 17 :2 20
10 23 :2 d 2b :3 a 1a 1b :2 1a
:2 a 18 2f 3d 48 4e 54 5a
28 34 42 55 :2 18 a e 17
23 :2 e 26 28 :2 26 d :4 31 30
2f :3 d 1b 30 3e 49 53 64
26 38 44 :2 1b d 50 :2 a :4 e
:2 d 1b 2b 39 3f :2 1b d 2b
10 17 23 26 :2 10 29 2b :2 29
10 1e 2e 3c 42 :2 1e 10 2f
10 1e 2e 3c 42 :2 1e 10 :4 d
:4 a :4 e d 17 22 2f 37 3e
59 64 69 :2 15 :2 10 :2 19 25 10
d :2 15 13 :2 1c 28 13 16 :2 20
32 :2 3c 48 4c 5e 61 62 :2 5e
:2 32 :3 16 :2 1c 21 2d 6f 72 :2 2d
7f 82 :2 2d 86 89 :2 2d 95 98
:2 2d a0 a3 :2 2d af b2 b9 c2
c5 :2 b2 :2 2d :2 16 65 :2 13 :2 10 :4 1c
:2 10 d :3 2c d 19 22 2c :2 19
2f 31 3a 49 :2 31 :2 19 d 2c
:3 a 17 :2 a 18 :2 a 18 26 2c
3a 44 50 5b 67 1f 28 39
:2 1f :2 18 a d 16 22 :2 d 25
28 :2 25 d 1b d 10 :2 1a 2c
:2 36 42 45 57 5a 5b :2 57 :2 2c
:3 10 :2 16 1b 27 69 6c :2 27 :2 10
5e :3 d 14 :2 1d d 2a 17 14
10 1c :5 10 1e 27 2e 3b 44
51 5a 16 2a 10 17 13 1f
:3 1d 13 :2 1c 28 13 24 13 :2 1c
28 13 :4 10 d :2 15 13 :2 1c 28
13 16 :2 20 32 :2 3c 48 4c 5e
61 62 :2 5e :2 32 :3 16 :2 1c 21 2d
6f 72 :2 2d 7f 82 :2 2d 86 89
:2 2d 95 98 :2 2d a0 a3 :2 2d af
b2 b9 c2 c5 :2 b2 :2 2d :2 16 65
:2 13 :2 10 :4 1c :2 10 d :7 a 42 3e
:2 7 :5 4 :2 d 19 23 :2 19 4 7
:2 11 23 :2 2d 39 3c 4e 51 52
:2 4e :2 23 :3 7 :2 d 12 1e 60 63
:2 1e 70 73 :2 1e 77 7a :2 1e 84
87 :2 90 :2 1e :2 7 55 :3 4 b :2 14
4 :9 1 
122a
4
0 :2 1 :6 3 :4 4
:4 5 :4 6 :6 7 :6 8
2 :2 9 :2 1 :6 b
:6 c :6 d :7 e :7 f
:7 10 :7 11 :7 12 :5 13
:5 14 :5 15 :5 16 :5 17
:5 18 :7 19 :7 1a :7 1b
:6 1c :6 1d :6 1e :6 1f
:6 20 :6 21 :6 22 :6 23
:6 24 :6 25 :6 26 :6 27
:6 28 :6 29 :6 2a :6 2b
:6 2c :6 2d :6 2e :6 2f
:6 30 :6 31 :6 32 :6 33
:6 34 :6 35 :a 36 :a 37
:7 38 :6 39 :6 3a :6 3b
:6 3c :6 3d :6 3e :6 3f
:6 40 :6 41 :6 42 :6 43
:6 44 :6 45 :6 46 :b 48
:11 49 4a :2 49 :2 4a
:2 49 :2 4a :2 49 :2 4b
:2 49 :9 4b :2 49 :2 4c
:2 49 :9 4c :2 49 :2 4d
:2 49 :9 4d :2 49 :2 4e
:2 49 :2 4e :2 49 :2 4e
:2 49 :2 4e :2 49 :2 4f
:2 49 :2 4f :2 49 :2 4f
:2 49 :2 4f :2 49 :2 4f
:4 49 :3 48 :11 52 :b 53
:3 52 :3 56 :9 59 :b 5a
:a 5b :4 5c :4 5d :3 5e
:8 5f :8 60 :6 61 :4 62
:4 63 :3 64 65 :2 66
59 :5 67 58 :2 69
:5 6b :11 6c :24 6d :3 6c
:2 6a :6 69 68 :3 47
:a 72 :6 74 :6 75 76
:2 77 74 :5 78 73
:2 7a :5 7c :11 7d :24 7e
:3 7d :2 7b :6 7a 79
:3 72 :a 83 :3 84 :11 85
:b 86 :3 85 :5 88 :3 83
:3 8b 8d 8e 8f
:2 90 8d :5 91 8c
:2 93 :5 95 :11 96 :24 97
:3 96 :2 94 :6 93 92
:3 72 :9 9c 9e 9f
a0 :2 a1 9e :5 a2
9d :2 a4 :5 a6 :11 a7
:24 a8 :3 a7 :2 a5 :6 a4
a3 :3 9c :b ad :3 ae
:11 af :b b0 :3 af :5 b2
:3 ad :3 9c b8 b9
ba :2 bc :4 bd :3 be
:3 bf :4 c0 :4 c1 :4 c2
b8 :5 c3 b7 :2 c5
:5 c7 :11 c8 :24 c9 :3 c8
:2 c6 :6 c5 c4 :3 72
:9 ce :3 cf :11 d0 :b d1
:3 d0 :5 d3 :3 ce :9 d6
:11 d7 :20 d8 :3 d7 :11 da
:b db :3 da :b dd de
d6 :d de :3 df :d e0
:3 e1 :11 e2 :b e3 :3 e2
:5 e5 e6 e0 :d e6
:3 e7 e6 :3 e0 :3 ea
:7 eb :2 ec :5 eb de
d6 :11 ee :20 ef :3 ee
:11 f1 :b f2 :3 f1 :b f4
ed :3 d6 72 :9 f7
:3 f8 :11 f9 :b fa :3 f9
:5 fc :3 f7 :3 ff 101
102 103 :2 104 101
:5 105 100 :2 107 :5 109
:11 10a :24 10b :3 10a :2 108
:6 107 106 :3 f6 :9 110
112 113 114 :2 115
112 :5 116 111 :2 118
:5 11a :11 11b :24 11c :3 11b
:2 119 :6 118 117 :3 110
:b 121 :3 122 :11 123 :b 124
:3 123 :5 126 :3 121 :3 110
12c 12d 12e 130
131 :2 132 :2 133 :3 134
12c :5 135 12b :2 137
:5 139 :11 13a :24 13b :3 13a
:2 138 :6 137 136 :3 f6
:9 140 :3 141 :11 142 :b 143
:3 142 :5 145 :3 140 :2 149
:2 14a 14b :2 14c :2 14d
149 :5 14e 148 :2 150
:5 152 :11 153 :24 154 :3 153
:2 151 :6 150 14f :3 f6
:7 159 :d 15a :3 15b :d 15d
:6 15e :8 15f :4 160 :3 15f
:9 162 :d 163 :b 164 :f 165
:3 166 :16 168 :18 169 16b
16c :6 16d :2 16e :2 16f
:2 170 171 :2 172 16b
:6 173 :5 174 173 :5 176
175 :3 173 16a :2 179
:5 17b :11 17c :24 17d :3 17c
:2 17a :6 179 178 :3 168
:f 182 168 185 186
:6 187 :2 188 :2 189 18a
18b :2 18c 185 :6 18d
:5 18e 18d :5 190 18f
:3 18d 184 :2 193 :5 195
:11 196 :24 197 :3 196 :2 194
:6 193 192 :4 183 :3 168
164 :16 19d :f 19e :16 19f
:2 1a0 :3 19f :2 1a0 :5 19f
1a3 1a4 :6 1a5 :2 1a6
:2 1a7 :2 1a8 1a3 :6 1a9
:5 1aa 1a9 :5 1ac 1ab
:3 1a9 1a2 :2 1af :5 1b1
:11 1b2 :24 1b3 :3 1b2 :2 1b0
:6 1af 1ae :4 19d :f 1b8
:3 1b9 1bc 1bd :6 1be
:2 1bf :2 1c0 1c1 1c2
:2 1c3 1bc :6 1c4 :5 1c5
1c4 :5 1c7 1c6 :3 1c4
1bb :2 1ca :5 1cc :11 1cd
:24 1ce :3 1cd :2 1cb :6 1ca
1c9 :4 1b7 :3 19d 19c
:3 164 163 :f 1d5 :3 1d6
1d9 1da :6 1db :2 1dc
:2 1dd 1de 1df :2 1e0
1d9 :6 1e1 :5 1e2 1e1
:5 1e4 1e3 :3 1e1 1d8
:2 1e7 :5 1e9 :11 1ea :24 1eb
:3 1ea :2 1e8 :6 1e7 1e6
:4 1d4 :3 163 :5 1f1 :3 1f2
:2 1f4 1f5 1f6 :2 1f7
:2 1f8 1f4 :5 1f9 1f3
:2 1fb :5 1fd :11 1fe :24 1ff
:3 1fe :2 1fc :6 1fb 1fa
:3 1f1 :5 205 :6 207 :5 208
206 :2 20a :5 20c :11 20d
:24 20e :3 20d :2 20b :6 20a
209 :3 205 :c 213 :3 214
:3 213 216 205 :9 216
:10 217 :8 21a 21b 21c
21a :5 21d 219 :2 21f
:5 221 :11 222 :24 223 :3 222
:2 220 :6 21f 21e :4 216
205 :8 229 22a 22b
229 :5 22c 228 :2 22e
:5 230 :11 231 :24 232 :3 231
:2 22f :6 22e 22d :4 227
:3 205 :3 1f1 :5 23b :8 23c
23b :a 23e :8 23f 23e
:8 241 240 :3 23e 23d
:3 23b :3 245 :9 246 :5 247
:3 246 :9 249 :3 24a :11 24b
:b 24c :3 24b :7 24e :3 249
:3 251 :3 162 15d :16 255
:2 256 :3 255 :2 256 :5 255
253 :3 15d :7 25c :4 25d
:4 25e :4 25f :4 260 :7 261
:3 25c :3 264 :11 265 :b 266
:3 265 :7 268 269 15a
:d 269 28c :2 28d :6 28e
:2 28f 28c :6 290 :5 291
290 :5 293 292 :3 290
28b :2 296 :5 298 :11 299
:24 29a :3 299 :2 297 :6 296
295 :3 269 2a5 :6 2a6
:2 2a7 :2 2a8 2a5 :6 2a9
:5 2aa 2a9 :5 2ac 2ab
:3 2a9 2a4 :2 2af :5 2b1
:11 2b2 :24 2b3 :3 2b2 :2 2b0
:6 2af 2ae :3 269 2b9
269 15a :d 2b9 :9 2ba
:3 2bb 2ba :16 2bd :3 2be
:11 2bf :b 2c0 :3 2bf :5 2c2
:3 2bd :7 2c5 2bc :3 2ba
:5 2c8 2ca 2cb 2cc
:2 2cd 2ca :5 2ce 2c9
:2 2d0 :5 2d2 :11 2d3 :24 2d4
:3 2d3 :2 2d1 :6 2d0 2cf
:3 2c8 :11 2da :2 2db :7 2da
:3 2dc :11 2dd :b 2de :3 2dd
:5 2e0 2db :2 2da :3 2c8
:6 31d :8 31e :4 31f :3 31e
:12 321 :7 322 :3 323 :3 322
:3 321 :5 327 :8 328 327
:a 32a :8 32b 32a :8 32d
32c :3 32a 329 :3 327
:5 331 :8 333 334 335
333 :5 336 332 :2 338
:5 33a :11 33b :24 33c :3 33b
:2 339 :6 338 337 :3 331
:f 341 :3 331 :3 346 :3 347
:9 348 :5 349 :3 348 :9 34c
:3 34d :11 34e :b 34f :3 34e
:5 351 34c 354 355
:2 356 357 358 359
35a :8 35b :2 35c 354
:6 35d :5 35e 35d :5 360
35f :3 35d 353 :2 363
:5 365 :11 366 :24 367 :3 366
:2 364 :6 363 362 :4 352
:3 34c 2b9 :3 15a f6
:3 72 :8 371 :11 378 :19 379
:3 378 :5 37b :2 47 :7 1

4004
4
:3 0 1 :3 0 2
:a 0 1225 1 :7 0
5 37 0 3
4 :3 0 5 :3 0
6 :3 0 3 :5 0
1 7 6 :3 0
9 5d 0 7
8 :3 0 7 :7 0
b a :3 0 8
:3 0 9 :7 0 f
e :3 0 d 8a
0 b 8 :3 0
a :7 0 13 12
:3 0 4 :3 0 5
:3 0 6 :3 0 b
:5 0 1 19 18
:3 0 16 b6 0
f 4 :3 0 5
:3 0 6 :3 0 c
:5 0 1 1f 1e
:3 0 d :3 0 8
:3 0 21 23 0
1225 2 24 :2 0
1a f2 0 18
8 :3 0 27 :7 0
7 :3 0 2b 28
29 1223 0 e
:6 0 8 :3 0 2d
:7 0 9 :3 0 31
2e 2f 1223 0
f :6 0 12 :2 0
1e 8 :3 0 33
:7 0 a :3 0 37
34 35 1223 0
10 :6 0 6 :3 0
12 :2 0 1c 39
3b :6 0 3e 3c
0 1223 0 11
:6 0 12 :2 0 22
6 :3 0 20 40
42 :6 0 45 43
0 1223 0 13
:6 0 12 :2 0 26
6 :3 0 24 47
49 :6 0 4c 4a
0 1223 0 14
:6 0 12 :2 0 2a
6 :3 0 28 4e
50 :6 0 53 51
0 1223 0 15
:6 0 30 1a2 0
2e 6 :3 0 2c
55 57 :6 0 5a
58 0 1223 0
16 :6 0 34 1d6
0 32 18 :3 0
5c :7 0 5f 5d
0 1223 0 17
:6 0 18 :3 0 61
:7 0 64 62 0
1223 0 19 :6 0
38 20a 0 36
1b :3 0 66 :7 0
69 67 0 1223
0 1a :6 0 1b
:3 0 6b :7 0 6e
6c 0 1223 0
1c :6 0 20 :2 0
3a 18 :3 0 70
:7 0 73 71 0
1223 0 1d :6 0
18 :3 0 75 :7 0
78 76 0 1223
0 1e :6 0 20
:2 0 3e 6 :3 0
3c 7a 7c :6 0
7f 7d 0 1223
0 1f :6 0 20
:2 0 42 6 :3 0
40 81 83 :6 0
86 84 0 1223
0 21 :6 0 24
:2 0 46 6 :3 0
44 88 8a :6 0
8d 8b 0 1223
0 22 :6 0 24
:2 0 48 8 :3 0
8f :7 0 93 90
91 1223 0 23
:6 0 24 :2 0 4a
8 :3 0 95 :7 0
99 96 97 1223
0 25 :6 0 24
:2 0 4c 8 :3 0
9b :7 0 9f 9c
9d 1223 0 26
:6 0 24 :2 0 4e
8 :3 0 a1 :7 0
a5 a2 a3 1223
0 27 :6 0 24
:2 0 50 8 :3 0
a7 :7 0 ab a8
a9 1223 0 28
:6 0 24 :2 0 52
8 :3 0 ad :7 0
b1 ae af 1223
0 29 :6 0 24
:2 0 54 8 :3 0
b3 :7 0 b7 b4
b5 1223 0 2a
:6 0 24 :2 0 56
8 :3 0 b9 :7 0
bd ba bb 1223
0 2b :6 0 24
:2 0 58 8 :3 0
bf :7 0 c3 c0
c1 1223 0 2c
:6 0 24 :2 0 5a
8 :3 0 c5 :7 0
c9 c6 c7 1223
0 2d :6 0 24
:2 0 5c 8 :3 0
cb :7 0 cf cc
cd 1223 0 2e
:6 0 24 :2 0 5e
8 :3 0 d1 :7 0
d5 d2 d3 1223
0 2f :6 0 24
:2 0 60 8 :3 0
d7 :7 0 db d8
d9 1223 0 30
:6 0 24 :2 0 62
8 :3 0 dd :7 0
e1 de df 1223
0 31 :6 0 24
:2 0 64 8 :3 0
e3 :7 0 e7 e4
e5 1223 0 32
:6 0 24 :2 0 66
8 :3 0 e9 :7 0
ed ea eb 1223
0 33 :6 0 24
:2 0 68 8 :3 0
ef :7 0 f3 f0
f1 1223 0 34
:6 0 24 :2 0 6a
8 :3 0 f5 :7 0
f9 f6 f7 1223
0 35 :6 0 24
:2 0 6c 8 :3 0
fb :7 0 ff fc
fd 1223 0 36
:6 0 24 :2 0 6e
8 :3 0 101 :7 0
105 102 103 1223
0 37 :6 0 24
:2 0 70 8 :3 0
107 :7 0 10b 108
109 1223 0 38
:6 0 24 :2 0 72
8 :3 0 10d :7 0
111 10e 10f 1223
0 39 :6 0 24
:2 0 74 8 :3 0
113 :7 0 117 114
115 1223 0 3a
:6 0 24 :2 0 76
8 :3 0 119 :7 0
11d 11a 11b 1223
0 3b :6 0 24
:2 0 78 8 :3 0
11f :7 0 123 120
121 1223 0 3c
:6 0 40 :2 0 7a
8 :3 0 125 :7 0
129 126 127 1223
0 3d :6 0 40
:2 0 7e 3f :3 0
7c 12b 12d 2
:5 0 41 :3 0 42
:3 0 12f 130 0
133 12e 131 1223
0 3e :6 0 45
:2 0 82 3f :3 0
80 135 137 2
:5 0 41 :3 0 42
:3 0 139 13a 0
13d 138 13b 1223
0 43 :6 0 24
:2 0 86 6 :3 0
84 13f 141 :6 0
144 142 0 1223
0 44 :6 0 24
:2 0 88 47 :3 0
146 :7 0 14a 147
148 1223 0 46
:6 0 24 :2 0 8a
47 :3 0 14c :7 0
150 14d 14e 1223
0 48 :6 0 24
:2 0 8c 47 :3 0
152 :7 0 156 153
154 1223 0 49
:6 0 24 :2 0 8e
47 :3 0 158 :7 0
15c 159 15a 1223
0 4a :6 0 24
:2 0 90 47 :3 0
15e :7 0 162 15f
160 1223 0 4b
:6 0 24 :2 0 92
47 :3 0 164 :7 0
168 165 166 1223
0 4c :6 0 24
:2 0 94 47 :3 0
16a :7 0 16e 16b
16c 1223 0 4d
:6 0 24 :2 0 96
47 :3 0 170 :7 0
174 171 172 1223
0 4e :6 0 24
:2 0 98 8 :3 0
176 :7 0 17a 177
178 1223 0 4f
:6 0 24 :2 0 9a
47 :3 0 17c :7 0
180 17d 17e 1223
0 50 :6 0 24
:2 0 9c 8 :3 0
182 :7 0 186 183
184 1223 0 51
:6 0 24 :2 0 9e
8 :3 0 188 :7 0
18c 189 18a 1223
0 52 :6 0 24
:2 0 a0 8 :3 0
18e :7 0 192 18f
190 1223 0 53
:6 0 199 19a 0
a2 8 :3 0 194
:7 0 198 195 196
1223 0 54 :6 0
55 :3 0 56 :3 0
55 :3 0 57 :3 0
19c 19d 0 2
:4 0 a4 19e 1a0
19b 1a2 1a1 :2 0
58 :3 0 59 :3 0
1a4 1a5 0 5a
:4 0 55 :3 0 5b
:3 0 1a8 1a9 0
2 :4 0 a6 1aa
1ac 5c :4 0 5d
:2 0 5e :3 0 a8
1af 1b1 :3 0 5f
:4 0 5d :2 0 60
:4 0 ab 1b4 1b6
:3 0 5d :2 0 3
:3 0 ae 1b8 1ba
:3 0 5d :2 0 60
:4 0 b1 1bc 1be
:3 0 5d :2 0 61
:4 0 b4 1c0 1c2
:3 0 5d :2 0 62
:3 0 63 :3 0 7
:3 0 b7 1c6 1c8
64 :4 0 b9 1c5
1cb bc 1c4 1cd
:3 0 5d :2 0 61
:4 0 bf 1cf 1d1
:3 0 5d :2 0 62
:3 0 63 :3 0 9
:3 0 c2 1d5 1d7
64 :4 0 c4 1d4
1da c7 1d3 1dc
:3 0 5d :2 0 61
:4 0 ca 1de 1e0
:3 0 5d :2 0 62
:3 0 63 :3 0 a
:3 0 cd 1e4 1e6
64 :4 0 cf 1e3
1e9 d2 1e2 1eb
:3 0 5d :2 0 61
:4 0 d5 1ed 1ef
:3 0 5d :2 0 60
:4 0 d8 1f1 1f3
:3 0 5d :2 0 b
:3 0 db 1f5 1f7
:3 0 5d :2 0 60
:4 0 de 1f9 1fb
:3 0 5d :2 0 61
:4 0 e1 1fd 1ff
:3 0 5d :2 0 60
:4 0 e4 201 203
:3 0 5d :2 0 c
:3 0 e7 205 207
:3 0 5d :2 0 60
:4 0 ea 209 20b
:3 0 5d :2 0 65
:4 0 ed 20d 20f
:3 0 f0 1a6 211
:2 0 213 f5 214
1a3 213 0 215
f7 0 1221 55
:3 0 56 :3 0 216
217 0 55 :3 0
66 :3 0 219 21a
0 20 :2 0 2
:4 0 67 :2 0 68
:2 0 20 :2 0 f9
21f 221 :3 0 fc
21b 223 218 225
224 :2 0 58 :3 0
69 :3 0 227 228
0 5a :4 0 6a
:4 0 5d :2 0 5e
:3 0 100 22c 22e
:3 0 103 229 230
:2 0 232 106 233
226 232 0 234
108 0 1221 11
:3 0 3 :3 0 235
236 0 1221 6b
:3 0 6c :3 0 6d
:3 0 6e :3 0 6f
:3 0 70 :3 0 71
:3 0 70 :3 0 72
:3 0 71 :3 0 73
:3 0 74 :3 0 75
:3 0 76 :3 0 77
:3 0 78 :3 0 79
:3 0 7a :3 0 79
:3 0 7a :3 0 7b
:3 0 7c :3 0 7d
:3 0 7e :3 0 7b
:3 0 7d :3 0 7e
:3 0 7c :3 0 7f
:3 0 80 :3 0 81
:3 0 82 :3 0 83
:3 0 84 :3 0 85
:3 0 86 :3 0 87
:3 0 88 :3 0 89
:3 0 8a :3 0 8b
:3 0 14 :3 0 16
:3 0 21 :3 0 1f
:3 0 1d :3 0 29
:3 0 3c :3 0 3a
:3 0 26 :3 0 2b
:3 0 13 :3 0 32
:3 0 37 :3 0 35
:3 0 36 :3 0 28
:3 0 1a :3 0 1c
:3 0 17 :3 0 19
:3 0 23 :3 0 25
:3 0 46 :3 0 49
:3 0 48 :3 0 4a
:3 0 4b :3 0 4d
:3 0 4c :3 0 4e
:3 0 27 :3 0 15
:3 0 3d :3 0 8c
:3 0 8d :3 0 11
:4 0 8e 1 :8 0
28b 8f :3 0 90
:3 0 286 287 0
91 :3 0 288 289
0 28b 10a 2d5
92 :3 0 8f :3 0
90 :3 0 28e 28f
0 91 :3 0 290
291 0 2cb 55
:3 0 56 :3 0 293
294 0 55 :3 0
66 :3 0 296 297
0 93 :2 0 2
:4 0 94 :2 0 68
:2 0 20 :2 0 10d
29c 29e :3 0 110
298 2a0 295 2a2
2a1 :2 0 58 :3 0
69 :3 0 2a4 2a5
0 5a :4 0 95
:4 0 5d :2 0 5e
:3 0 114 2a9 2ab
:3 0 5d :2 0 96
:4 0 117 2ad 2af
:3 0 5d :2 0 97
:4 0 11a 2b1 2b3
:3 0 5d :2 0 91
:3 0 11d 2b5 2b7
:3 0 5d :2 0 98
:4 0 120 2b9 2bb
:3 0 5d :2 0 7e
:3 0 99 :3 0 20
:2 0 9a :2 0 123
2be 2c2 127 2bd
2c4 :3 0 12a 2a6
2c6 :2 0 2c8 12d
2c9 2a3 2c8 0
2ca 12f 0 2cb
131 2ce :3 0 2ce
0 2ce 2cd 2cb
2cc :6 0 2d0 2
:3 0 134 2d2 136
2d1 2d0 :2 0 2d3
138 :2 0 2d5 0
2d5 2d4 28b 2d3
:6 0 1221 1 :3 0
8f :3 0 90 :3 0
2d7 2d8 0 8f
:3 0 9b :2 0 9c
:3 0 2da 2dc 0
13c 2db 2de :3 0
2df :2 0 6b :3 0
9d :3 0 9e :3 0
70 :3 0 89 :3 0
9f :3 0 14 :3 0
2d :3 0 26 :3 0
29 :3 0 27 :3 0
31 :3 0 a0 :3 0
a1 :3 0 11 :4 0
a2 1 :8 0 2f6
8f :3 0 90 :3 0
2f1 2f2 0 91
:3 0 2f3 2f4 0
2f6 13f 340 92
:3 0 8f :3 0 90
:3 0 2f9 2fa 0
91 :3 0 2fb 2fc
0 336 55 :3 0
56 :3 0 2fe 2ff
0 55 :3 0 66
:3 0 301 302 0
93 :2 0 2 :4 0
a3 :2 0 68 :2 0
20 :2 0 142 307
309 :3 0 145 303
30b 300 30d 30c
:2 0 58 :3 0 69
:3 0 30f 310 0
5a :4 0 a4 :4 0
5d :2 0 5e :3 0
149 314 316 :3 0
5d :2 0 96 :4 0
14c 318 31a :3 0
5d :2 0 97 :4 0
14f 31c 31e :3 0
5d :2 0 91 :3 0
152 320 322 :3 0
5d :2 0 98 :4 0
155 324 326 :3 0
5d :2 0 7e :3 0
99 :3 0 20 :2 0
9a :2 0 158 329
32d 15c 328 32f
:3 0 15f 311 331
:2 0 333 162 334
30e 333 0 335
164 0 336 166
339 :3 0 339 0
339 338 336 337
:6 0 33b 4 :3 0
169 33d 16b 33c
33b :2 0 33e 16d
:2 0 340 0 340
33f 2f6 33e :6 0
640 1 :3 0 8f
:3 0 90 :3 0 342
343 0 8f :3 0
9b :2 0 9c :3 0
345 347 0 171
346 349 :3 0 34a
:2 0 c :3 0 11
:3 0 34c 34d 0
373 55 :3 0 56
:3 0 34f 350 0
55 :3 0 66 :3 0
352 353 0 20
:2 0 2 :4 0 a5
:2 0 68 :2 0 20
:2 0 174 358 35a
:3 0 177 354 35c
351 35e 35d :2 0
58 :3 0 69 :3 0
360 361 0 5a
:4 0 a6 :4 0 5d
:2 0 5e :3 0 17b
365 367 :3 0 17e
362 369 :2 0 36b
181 36c 35f 36b
0 36d 183 0
373 d :3 0 41
:3 0 a7 :3 0 36f
370 0 371 :2 0
373 185 374 34b
373 0 375 189
0 640 2f :3 0
24 :2 0 376 377
0 640 a8 :3 0
2f :3 0 a9 :3 0
6b :3 0 14 :4 0
aa 1 :8 0 384
8f :3 0 90 :3 0
37f 380 0 91
:3 0 381 382 0
384 18b 3ce 92
:3 0 8f :3 0 90
:3 0 387 388 0
91 :3 0 389 38a
0 3c4 55 :3 0
56 :3 0 38c 38d
0 55 :3 0 66
:3 0 38f 390 0
93 :2 0 2 :4 0
ab :2 0 68 :2 0
20 :2 0 18e 395
397 :3 0 191 391
399 38e 39b 39a
:2 0 58 :3 0 69
:3 0 39d 39e 0
5a :4 0 ac :4 0
5d :2 0 5e :3 0
195 3a2 3a4 :3 0
5d :2 0 96 :4 0
198 3a6 3a8 :3 0
5d :2 0 97 :4 0
19b 3aa 3ac :3 0
5d :2 0 91 :3 0
19e 3ae 3b0 :3 0
5d :2 0 98 :4 0
1a1 3b2 3b4 :3 0
5d :2 0 7e :3 0
99 :3 0 20 :2 0
9a :2 0 1a4 3b7
3bb 1a8 3b6 3bd
:3 0 1ab 39f 3bf
:2 0 3c1 1ae 3c2
39c 3c1 0 3c3
1b0 0 3c4 1b2
3c7 :3 0 3c7 0
3c7 3c6 3c4 3c5
:6 0 3c9 6 :3 0
1b5 3cb 1b7 3ca
3c9 :2 0 3cc 1b9
:2 0 3ce 0 3ce
3cd 384 3cc :6 0
640 1 :3 0 62
:3 0 2f :3 0 24
:2 0 1bb 3d0 3d3
ad :2 0 24 :2 0
1c0 3d5 3d7 :3 0
ae :3 0 22 :3 0
a0 :3 0 a1 :3 0
14 :4 0 af 1
:8 0 3e4 8f :3 0
90 :3 0 3df 3e0
0 91 :3 0 3e1
3e2 0 3e4 1c3
42e 92 :3 0 8f
:3 0 90 :3 0 3e7
3e8 0 91 :3 0
3e9 3ea 0 424
55 :3 0 56 :3 0
3ec 3ed 0 55
:3 0 66 :3 0 3ef
3f0 0 93 :2 0
2 :4 0 b0 :2 0
68 :2 0 20 :2 0
1c6 3f5 3f7 :3 0
1c9 3f1 3f9 3ee
3fb 3fa :2 0 58
:3 0 69 :3 0 3fd
3fe 0 5a :4 0
b1 :4 0 5d :2 0
5e :3 0 1cd 402
404 :3 0 5d :2 0
96 :4 0 1d0 406
408 :3 0 5d :2 0
97 :4 0 1d3 40a
40c :3 0 5d :2 0
91 :3 0 1d6 40e
410 :3 0 5d :2 0
98 :4 0 1d9 412
414 :3 0 5d :2 0
7e :3 0 99 :3 0
20 :2 0 9a :2 0
1dc 417 41b 1e0
416 41d :3 0 1e3
3ff 41f :2 0 421
1e6 422 3fc 421
0 423 1e8 0
424 1ea 427 :3 0
427 0 427 426
424 425 :6 0 429
8 :3 0 1ed 42b
1ef 42a 429 :2 0
42c 1f1 :2 0 42e
0 42e 42d 3e4
42c :6 0 465 1
:3 0 b2 :3 0 b3
:3 0 430 431 0
22 :3 0 b4 :4 0
1f3 432 435 9b
:2 0 24 :2 0 1f8
437 439 :3 0 c
:3 0 14 :3 0 43b
43c 0 462 55
:3 0 56 :3 0 43e
43f 0 55 :3 0
66 :3 0 441 442
0 20 :2 0 2
:4 0 b5 :2 0 68
:2 0 20 :2 0 1fb
447 449 :3 0 1fe
443 44b 440 44d
44c :2 0 58 :3 0
69 :3 0 44f 450
0 5a :4 0 b6
:4 0 5d :2 0 5e
:3 0 202 454 456
:3 0 205 451 458
:2 0 45a 208 45b
44e 45a 0 45c
20a 0 462 d
:3 0 41 :3 0 b7
:3 0 45e 45f 0
460 :2 0 462 20c
463 43a 462 0
464 210 0 465
212 466 3d8 465
0 467 215 0
640 b8 :3 0 2f
:3 0 b9 :3 0 ba
:3 0 a1 :3 0 8c
:3 0 bb :3 0 bc
:3 0 ba :3 0 bb
:3 0 6b :3 0 14
:3 0 bb :3 0 8a
:3 0 11 :3 0 bb
:3 0 8d :3 0 ba
:3 0 8d :3 0 ba
:3 0 8d :3 0 ba
:3 0 a1 :3 0 ba
:3 0 bd :3 0 41
:3 0 be :4 0 bf
1 :8 0 489 8f
:3 0 90 :3 0 484
485 0 91 :3 0
486 487 0 489
217 4d3 92 :3 0
8f :3 0 90 :3 0
48c 48d 0 91
:3 0 48e 48f 0
4c9 55 :3 0 56
:3 0 491 492 0
55 :3 0 66 :3 0
494 495 0 93
:2 0 2 :4 0 c0
:2 0 68 :2 0 20
:2 0 21a 49a 49c
:3 0 21d 496 49e
493 4a0 49f :2 0
58 :3 0 69 :3 0
4a2 4a3 0 5a
:4 0 c1 :4 0 5d
:2 0 5e :3 0 221
4a7 4a9 :3 0 5d
:2 0 96 :4 0 224
4ab 4ad :3 0 5d
:2 0 97 :4 0 227
4af 4b1 :3 0 5d
:2 0 91 :3 0 22a
4b3 4b5 :3 0 5d
:2 0 98 :4 0 22d
4b7 4b9 :3 0 5d
:2 0 7e :3 0 99
:3 0 20 :2 0 9a
:2 0 230 4bc 4c0
234 4bb 4c2 :3 0
237 4a4 4c4 :2 0
4c6 23a 4c7 4a1
4c6 0 4c8 23c
0 4c9 23e 4cc
:3 0 4cc 0 4cc
4cb 4c9 4ca :6 0
4ce a :3 0 241
4d0 243 4cf 4ce
:2 0 4d1 245 :2 0
4d3 0 4d3 4d2
489 4d1 :6 0 640
1 :3 0 62 :3 0
2f :3 0 24 :2 0
247 4d5 4d8 ad
:2 0 24 :2 0 24c
4da 4dc :3 0 c
:3 0 11 :3 0 4de
4df 0 505 55
:3 0 56 :3 0 4e1
4e2 0 55 :3 0
66 :3 0 4e4 4e5
0 20 :2 0 2
:4 0 c2 :2 0 68
:2 0 20 :2 0 24f
4ea 4ec :3 0 252
4e6 4ee 4e3 4f0
4ef :2 0 58 :3 0
69 :3 0 4f2 4f3
0 5a :4 0 c3
:4 0 5d :2 0 5e
:3 0 256 4f7 4f9
:3 0 259 4f4 4fb
:2 0 4fd 25c 4fe
4f1 4fd 0 4ff
25e 0 505 d
:3 0 41 :3 0 c4
:3 0 501 502 0
503 :2 0 505 260
506 4dd 505 0
507 264 0 640
62 :3 0 26 :3 0
24 :2 0 266 508
50b 9b :2 0 24
:2 0 26b 50d 50f
:3 0 55 :3 0 56
:3 0 511 512 0
55 :3 0 66 :3 0
514 515 0 c5
:2 0 2 :4 0 c6
:2 0 68 :2 0 20
:2 0 26e 51a 51c
:3 0 271 516 51e
513 520 51f :2 0
58 :3 0 69 :3 0
522 523 0 5a
:4 0 c7 :4 0 5d
:2 0 5e :3 0 275
527 529 :3 0 5d
:2 0 96 :4 0 278
52b 52d :3 0 5d
:2 0 c8 :4 0 27b
52f 531 :3 0 5d
:2 0 62 :3 0 63
:3 0 41 :3 0 c9
:3 0 536 537 0
27e 535 539 64
:4 0 280 534 53c
283 533 53e :3 0
286 524 540 :2 0
542 289 543 521
542 0 544 28b
0 570 55 :3 0
56 :3 0 545 546
0 55 :3 0 66
:3 0 548 549 0
20 :2 0 2 :4 0
ca :2 0 68 :2 0
20 :2 0 28d 54e
550 :3 0 290 54a
552 547 554 553
:2 0 58 :3 0 69
:3 0 556 557 0
5a :4 0 cb :4 0
5d :2 0 5e :3 0
294 55b 55d :3 0
297 558 55f :2 0
561 29a 562 555
561 0 563 29c
0 570 d :3 0
cc :3 0 cd :3 0
565 566 0 41
:3 0 c9 :3 0 568
569 0 ce :3 0
29e 567 56c 56d
:2 0 570 cf :3 0
2a1 63d 62 :3 0
f :3 0 24 :2 0
2a5 571 574 62
:3 0 d0 :2 0 29
:3 0 24 :2 0 2a8
576 57a 2ad 577
57c :3 0 3b :3 0
24 :2 0 57e 57f
0 5dc 62 :3 0
f :3 0 24 :2 0
2b0 581 584 62
:3 0 ad :2 0 26
:3 0 24 :2 0 2b3
586 58a 2b8 587
58c :3 0 c :3 0
11 :3 0 58e 58f
0 5b6 55 :3 0
56 :3 0 591 592
0 55 :3 0 66
:3 0 594 595 0
20 :2 0 2 :4 0
d1 :2 0 68 :2 0
20 :2 0 2bb 59a
59c :3 0 2be 596
59e 593 5a0 59f
:2 0 58 :3 0 69
:3 0 5a2 5a3 0
5a :4 0 d2 :4 0
5d :2 0 5e :3 0
2c2 5a7 5a9 :3 0
2c5 5a4 5ab :2 0
5ad 2c8 5ae 5a1
5ad 0 5af 2ca
0 5b6 d :3 0
41 :3 0 d3 :3 0
5b1 5b2 0 5b3
:2 0 5b6 cf :3 0
2cc 5c9 62 :3 0
f :3 0 24 :2 0
2d0 5b7 5ba 62
:3 0 9b :2 0 26
:3 0 24 :2 0 2d3
5bc 5c0 2d8 5bd
5c2 :3 0 3b :3 0
20 :2 0 5c4 5c5
0 5c7 2db 5c8
5c3 5c7 0 5ca
58d 5b6 0 5ca
2dd 0 5dc 2a
:3 0 f :3 0 5cb
5cc 0 5dc 2f
:3 0 d4 :3 0 14
:3 0 11 :3 0 2a
:3 0 b :3 0 62
:3 0 3b :3 0 24
:2 0 2e0 5d4 5d7
2e3 5cf 5d9 5ce
5da 0 5dc 2e9
5dd 57d 5dc 0
63f 55 :3 0 56
:3 0 5de 5df 0
55 :3 0 66 :3 0
5e1 5e2 0 c5
:2 0 2 :4 0 d5
:2 0 68 :2 0 20
:2 0 2ee 5e7 5e9
:3 0 2f1 5e3 5eb
5e0 5ed 5ec :2 0
58 :3 0 69 :3 0
5ef 5f0 0 5a
:4 0 d6 :4 0 5d
:2 0 5e :3 0 2f5
5f4 5f6 :3 0 5d
:2 0 96 :4 0 2f8
5f8 5fa :3 0 5d
:2 0 c8 :4 0 2fb
5fc 5fe :3 0 5d
:2 0 62 :3 0 63
:3 0 41 :3 0 c9
:3 0 603 604 0
2fe 602 606 64
:4 0 300 601 609
303 600 60b :3 0
306 5f1 60d :2 0
60f 309 610 5ee
60f 0 611 30b
0 63c 55 :3 0
56 :3 0 612 613
0 55 :3 0 66
:3 0 615 616 0
20 :2 0 2 :4 0
d7 :2 0 68 :2 0
20 :2 0 30d 61b
61d :3 0 310 617
61f 614 621 620
:2 0 58 :3 0 69
:3 0 623 624 0
5a :4 0 d8 :4 0
5d :2 0 5e :3 0
314 628 62a :3 0
317 625 62c :2 0
62e 31a 62f 622
62e 0 630 31c
0 63c d :3 0
cc :3 0 cd :3 0
632 633 0 41
:3 0 c9 :3 0 635
636 0 ce :3 0
31e 634 639 63a
:2 0 63c 321 63e
510 570 0 63f
0 63c 0 63f
325 0 640 329
11e4 62 :3 0 26
:3 0 24 :2 0 332
641 644 9b :2 0
24 :2 0 337 646
648 :3 0 c :3 0
11 :3 0 64a 64b
0 671 55 :3 0
56 :3 0 64d 64e
0 55 :3 0 66
:3 0 650 651 0
20 :2 0 2 :4 0
d9 :2 0 68 :2 0
20 :2 0 33a 656
658 :3 0 33d 652
65a 64f 65c 65b
:2 0 58 :3 0 69
:3 0 65e 65f 0
5a :4 0 da :4 0
5d :2 0 5e :3 0
341 663 665 :3 0
344 660 667 :2 0
669 347 66a 65d
669 0 66b 349
0 671 d :3 0
41 :3 0 c9 :3 0
66d 66e 0 66f
:2 0 671 34b 672
649 671 0 673
34f 0 11e3 2f
:3 0 24 :2 0 674
675 0 11e3 a8
:3 0 2f :3 0 a9
:3 0 6b :3 0 14
:4 0 aa 1 :8 0
682 8f :3 0 90
:3 0 67d 67e 0
91 :3 0 67f 680
0 682 351 6cc
92 :3 0 8f :3 0
90 :3 0 685 686
0 91 :3 0 687
688 0 6c2 55
:3 0 56 :3 0 68a
68b 0 55 :3 0
66 :3 0 68d 68e
0 93 :2 0 2
:4 0 db :2 0 68
:2 0 20 :2 0 354
693 695 :3 0 357
68f 697 68c 699
698 :2 0 58 :3 0
69 :3 0 69b 69c
0 5a :4 0 dc
:4 0 5d :2 0 5e
:3 0 35b 6a0 6a2
:3 0 5d :2 0 96
:4 0 35e 6a4 6a6
:3 0 5d :2 0 97
:4 0 361 6a8 6aa
:3 0 5d :2 0 91
:3 0 364 6ac 6ae
:3 0 5d :2 0 98
:4 0 367 6b0 6b2
:3 0 5d :2 0 7e
:3 0 99 :3 0 20
:2 0 9a :2 0 36a
6b5 6b9 36e 6b4
6bb :3 0 371 69d
6bd :2 0 6bf 374
6c0 69a 6bf 0
6c1 376 0 6c2
378 6c5 :3 0 6c5
0 6c5 6c4 6c2
6c3 :6 0 6c7 c
:3 0 37b 6c9 37d
6c8 6c7 :2 0 6ca
37f :2 0 6cc 0
6cc 6cb 682 6ca
:6 0 11e3 1 :3 0
62 :3 0 2f :3 0
24 :2 0 381 6ce
6d1 ad :2 0 24
:2 0 386 6d3 6d5
:3 0 ae :3 0 22
:3 0 a0 :3 0 a1
:3 0 14 :4 0 af
1 :8 0 6e2 8f
:3 0 90 :3 0 6dd
6de 0 91 :3 0
6df 6e0 0 6e2
389 72c 92 :3 0
8f :3 0 90 :3 0
6e5 6e6 0 91
:3 0 6e7 6e8 0
722 55 :3 0 56
:3 0 6ea 6eb 0
55 :3 0 66 :3 0
6ed 6ee 0 93
:2 0 2 :4 0 dd
:2 0 68 :2 0 20
:2 0 38c 6f3 6f5
:3 0 38f 6ef 6f7
6ec 6f9 6f8 :2 0
58 :3 0 69 :3 0
6fb 6fc 0 5a
:4 0 de :4 0 5d
:2 0 5e :3 0 393
700 702 :3 0 5d
:2 0 96 :4 0 396
704 706 :3 0 5d
:2 0 97 :4 0 399
708 70a :3 0 5d
:2 0 91 :3 0 39c
70c 70e :3 0 5d
:2 0 98 :4 0 39f
710 712 :3 0 5d
:2 0 7e :3 0 99
:3 0 20 :2 0 9a
:2 0 3a2 715 719
3a6 714 71b :3 0
3a9 6fd 71d :2 0
71f 3ac 720 6fa
71f 0 721 3ae
0 722 3b0 725
:3 0 725 0 725
724 722 723 :6 0
727 e :3 0 3b3
729 3b5 728 727
:2 0 72a 3b7 :2 0
72c 0 72c 72b
6e2 72a :6 0 763
1 :3 0 b2 :3 0
b3 :3 0 72e 72f
0 22 :3 0 b4
:4 0 3b9 730 733
9b :2 0 24 :2 0
3be 735 737 :3 0
c :3 0 14 :3 0
739 73a 0 760
55 :3 0 56 :3 0
73c 73d 0 55
:3 0 66 :3 0 73f
740 0 20 :2 0
2 :4 0 df :2 0
68 :2 0 20 :2 0
3c1 745 747 :3 0
3c4 741 749 73e
74b 74a :2 0 58
:3 0 69 :3 0 74d
74e 0 5a :4 0
e0 :4 0 5d :2 0
5e :3 0 3c8 752
754 :3 0 3cb 74f
756 :2 0 758 3ce
759 74c 758 0
75a 3d0 0 760
d :3 0 41 :3 0
b7 :3 0 75c 75d
0 75e :2 0 760
3d2 761 738 760
0 762 3d6 0
763 3d8 764 6d6
763 0 765 3db
0 11e3 b8 :3 0
2f :3 0 b9 :3 0
a1 :3 0 bc :3 0
8d :3 0 11 :3 0
8d :3 0 a1 :3 0
bd :3 0 41 :3 0
be :4 0 e1 1
:8 0 778 8f :3 0
90 :3 0 773 774
0 91 :3 0 775
776 0 778 3dd
7c2 92 :3 0 8f
:3 0 90 :3 0 77b
77c 0 91 :3 0
77d 77e 0 7b8
55 :3 0 56 :3 0
780 781 0 55
:3 0 66 :3 0 783
784 0 93 :2 0
2 :4 0 e2 :2 0
68 :2 0 20 :2 0
3e0 789 78b :3 0
3e3 785 78d 782
78f 78e :2 0 58
:3 0 69 :3 0 791
792 0 5a :4 0
e3 :4 0 5d :2 0
5e :3 0 3e7 796
798 :3 0 5d :2 0
96 :4 0 3ea 79a
79c :3 0 5d :2 0
97 :4 0 3ed 79e
7a0 :3 0 5d :2 0
91 :3 0 3f0 7a2
7a4 :3 0 5d :2 0
98 :4 0 3f3 7a6
7a8 :3 0 5d :2 0
7e :3 0 99 :3 0
20 :2 0 9a :2 0
3f6 7ab 7af 3fa
7aa 7b1 :3 0 3fd
793 7b3 :2 0 7b5
400 7b6 790 7b5
0 7b7 402 0
7b8 404 7bb :3 0
7bb 0 7bb 7ba
7b8 7b9 :6 0 7bd
10 :3 0 407 7bf
409 7be 7bd :2 0
7c0 40b :2 0 7c2
0 7c2 7c1 778
7c0 :6 0 11e3 1
:3 0 62 :3 0 2f
:3 0 24 :2 0 40d
7c4 7c7 ad :2 0
24 :2 0 412 7c9
7cb :3 0 c :3 0
11 :3 0 7cd 7ce
0 7f4 55 :3 0
56 :3 0 7d0 7d1
0 55 :3 0 66
:3 0 7d3 7d4 0
20 :2 0 2 :4 0
e4 :2 0 68 :2 0
20 :2 0 415 7d9
7db :3 0 418 7d5
7dd 7d2 7df 7de
:2 0 58 :3 0 69
:3 0 7e1 7e2 0
5a :4 0 e5 :4 0
5d :2 0 5e :3 0
41c 7e6 7e8 :3 0
41f 7e3 7ea :2 0
7ec 422 7ed 7e0
7ec 0 7ee 424
0 7f4 d :3 0
41 :3 0 c4 :3 0
7f0 7f1 0 7f2
:2 0 7f4 426 7f5
7cc 7f4 0 7f6
42a 0 11e3 6b
:3 0 e6 :3 0 14
:3 0 2c :3 0 a0
:3 0 6b :3 0 14
:3 0 a1 :3 0 15
:4 0 e7 1 :8 0
806 8f :3 0 90
:3 0 801 802 0
91 :3 0 803 804
0 806 42c 850
92 :3 0 8f :3 0
90 :3 0 809 80a
0 91 :3 0 80b
80c 0 846 55
:3 0 56 :3 0 80e
80f 0 55 :3 0
66 :3 0 811 812
0 93 :2 0 2
:4 0 e8 :2 0 68
:2 0 20 :2 0 42f
817 819 :3 0 432
813 81b 810 81d
81c :2 0 58 :3 0
69 :3 0 81f 820
0 5a :4 0 e9
:4 0 5d :2 0 5e
:3 0 436 824 826
:3 0 5d :2 0 96
:4 0 439 828 82a
:3 0 5d :2 0 97
:4 0 43c 82c 82e
:3 0 5d :2 0 91
:3 0 43f 830 832
:3 0 5d :2 0 98
:4 0 442 834 836
:3 0 5d :2 0 7e
:3 0 99 :3 0 20
:2 0 9a :2 0 445
839 83d 449 838
83f :3 0 44c 821
841 :2 0 843 44f
844 81e 843 0
845 451 0 846
453 849 :3 0 849
0 849 848 846
847 :6 0 84b 12
:3 0 456 84d 458
84c 84b :2 0 84e
45a :2 0 850 0
850 84f 806 84e
:6 0 11e3 1 :3 0
38 :3 0 62 :3 0
26 :3 0 24 :2 0
45c 853 856 852
857 0 11e3 62
:3 0 f :3 0 24
:2 0 45f 859 85c
62 :3 0 d0 :2 0
29 :3 0 24 :2 0
462 85e 862 467
85f 864 :3 0 2a
:3 0 f :3 0 866
867 0 e51 62
:3 0 2a :3 0 24
:2 0 46a 869 86c
62 :3 0 ad :2 0
26 :3 0 24 :2 0
46d 86e 872 472
86f 874 :3 0 2e
:3 0 ea :2 0 20
:2 0 475 877 879
:3 0 876 87a 0
ddf 2f :3 0 eb
:3 0 14 :3 0 15
:3 0 11 :3 0 17
:3 0 19 :3 0 46
:3 0 48 :3 0 2e
:3 0 25 :3 0 23
:3 0 477 87d 888
87c 889 0 ddf
62 :3 0 2f :3 0
24 :2 0 482 88b
88e 9b :2 0 24
:2 0 487 890 892
:3 0 62 :3 0 3c
:3 0 24 :2 0 48a
894 897 62 :3 0
d0 :2 0 3a :3 0
24 :2 0 48d 899
89d 492 89a 89f
:3 0 b2 :3 0 b3
:3 0 8a1 8a2 0
16 :3 0 b :3 0
495 8a3 8a6 9b
:2 0 24 :2 0 49a
8a8 8aa :3 0 26
:3 0 62 :3 0 2a
:3 0 24 :2 0 49d
8ad 8b0 ea :2 0
62 :3 0 26 :3 0
24 :2 0 4a0 8b3
8b6 4a3 8b2 8b8
:3 0 8ac 8b9 0
9e5 27 :3 0 ec
:2 0 8bb 8bc 0
9e5 62 :3 0 2a
:3 0 24 :2 0 4a6
8be 8c1 ed :2 0
62 :3 0 29 :3 0
24 :2 0 4a9 8c4
8c7 68 :2 0 62
:3 0 3a :3 0 24
:2 0 4ac 8ca 8cd
4af 8c9 8cf :3 0
8d0 :2 0 4b4 8c3
8d2 :3 0 3a :3 0
62 :3 0 29 :3 0
24 :2 0 4b7 8d5
8d8 68 :2 0 62
:3 0 3a :3 0 24
:2 0 4ba 8db 8de
4bd 8da 8e0 :3 0
8e1 :2 0 ea :2 0
62 :3 0 2a :3 0
24 :2 0 4c0 8e4
8e7 4c3 8e3 8e9
:3 0 8d4 8ea 0
96e 8c :3 0 ee
:3 0 8b :3 0 ef
:3 0 f0 :3 0 8b
:3 0 41 :3 0 f1
:3 0 71 :3 0 2a
:3 0 70 :3 0 2a
:3 0 72 :3 0 3a
:3 0 89 :3 0 8d
:3 0 11 :4 0 f2
1 :8 0 913 f3
:4 0 8fe :3 0 f4
:3 0 9b :2 0 4c8
901 902 :3 0 8f
:3 0 90 :3 0 904
905 0 24 :2 0
906 907 0 909
4cb 910 8f :3 0
90 :3 0 90a 90b
0 f5 :2 0 90c
90d 0 90f 4cd
911 903 909 0
912 0 90f 0
912 4cf 0 913
4d2 95d 92 :3 0
8f :3 0 90 :3 0
916 917 0 91
:3 0 918 919 0
953 55 :3 0 56
:3 0 91b 91c 0
55 :3 0 66 :3 0
91e 91f 0 93
:2 0 2 :4 0 f6
:2 0 68 :2 0 20
:2 0 4d5 924 926
:3 0 4d8 920 928
91d 92a 929 :2 0
58 :3 0 69 :3 0
92c 92d 0 5a
:4 0 f7 :4 0 5d
:2 0 5e :3 0 4dc
931 933 :3 0 5d
:2 0 96 :4 0 4df
935 937 :3 0 5d
:2 0 97 :4 0 4e2
939 93b :3 0 5d
:2 0 91 :3 0 4e5
93d 93f :3 0 5d
:2 0 98 :4 0 4e8
941 943 :3 0 5d
:2 0 7e :3 0 99
:3 0 20 :2 0 9a
:2 0 4eb 946 94a
4ef 945 94c :3 0
4f2 92e 94e :2 0
950 4f5 951 92b
950 0 952 4f7
0 953 4f9 956
:3 0 956 0 956
955 953 954 :6 0
958 14 :3 0 4fc
95a 4fe 959 958
:2 0 95b 500 :2 0
95d 0 95d 95c
913 95b :6 0 96e
1 :3 0 27 :3 0
f8 :3 0 f0 :3 0
960 961 0 62
:3 0 27 :3 0 24
:2 0 502 963 966
41 :3 0 f9 :3 0
968 969 0 505
962 96b 95f 96c
0 96e 508 9e2
8c :3 0 ee :3 0
8b :3 0 ef :3 0
f0 :3 0 8b :3 0
41 :3 0 f1 :3 0
71 :3 0 2a :3 0
70 :3 0 2a :3 0
72 :3 0 89 :3 0
8d :3 0 11 :4 0
fa 1 :8 0 995
f3 :4 0 980 :3 0
f4 :3 0 9b :2 0
50e 983 984 :3 0
8f :3 0 90 :3 0
986 987 0 24
:2 0 988 989 0
98b 511 992 8f
:3 0 90 :3 0 98c
98d 0 f5 :2 0
98e 98f 0 991
513 993 985 98b
0 994 0 991
0 994 515 0
995 518 9df 92
:3 0 8f :3 0 90
:3 0 998 999 0
91 :3 0 99a 99b
0 9d5 55 :3 0
56 :3 0 99d 99e
0 55 :3 0 66
:3 0 9a0 9a1 0
93 :2 0 2 :4 0
fb :2 0 68 :2 0
20 :2 0 51b 9a6
9a8 :3 0 51e 9a2
9aa 99f 9ac 9ab
:2 0 58 :3 0 69
:3 0 9ae 9af 0
5a :4 0 fc :4 0
5d :2 0 5e :3 0
522 9b3 9b5 :3 0
5d :2 0 96 :4 0
525 9b7 9b9 :3 0
5d :2 0 97 :4 0
528 9bb 9bd :3 0
5d :2 0 91 :3 0
52b 9bf 9c1 :3 0
5d :2 0 98 :4 0
52e 9c3 9c5 :3 0
5d :2 0 7e :3 0
99 :3 0 20 :2 0
9a :2 0 531 9c8
9cc 535 9c7 9ce
:3 0 538 9b0 9d0
:2 0 9d2 53b 9d3
9ad 9d2 0 9d4
53d 0 9d5 53f
9d8 :3 0 9d8 0
9d8 9d7 9d5 9d6
:6 0 9da 16 :3 0
542 9dc 544 9db
9da :2 0 9dd 546
:2 0 9df 0 9df
9de 995 9dd :6 0
9e1 1 :3 0 548
9e3 8d3 96e 0
9e4 0 9e1 0
9e4 54a 0 9e5
54d b27 62 :3 0
2a :3 0 24 :2 0
551 9e6 9e9 ed
:2 0 62 :3 0 29
:3 0 24 :2 0 554
9ec 9ef 68 :2 0
62 :3 0 3a :3 0
24 :2 0 557 9f2
9f5 55a 9f1 9f7
:3 0 9f8 :2 0 55f
9eb 9fa :3 0 26
:3 0 62 :3 0 3a
:3 0 24 :2 0 562
9fd a00 ea :2 0
62 :3 0 26 :3 0
24 :2 0 565 a03
a06 568 a02 a08
:3 0 9fc a09 0
a9d 27 :3 0 fd
:3 0 62 :3 0 fe
:3 0 2a :3 0 56b
a0e a10 24 :2 0
56d a0d a13 ff
:2 0 62 :3 0 fe
:3 0 26 :3 0 570
a17 a19 24 :2 0
572 a16 a1c 575
a15 a1e :3 0 a1f
:2 0 100 :2 0 101
:2 0 578 a21 a23
:3 0 a24 :2 0 68
:2 0 102 :2 0 57b
a26 a28 :3 0 57e
a0c a2a a0b a2b
0 a9d 8c :3 0
ee :3 0 8b :3 0
ef :3 0 f0 :3 0
8b :3 0 41 :3 0
f1 :3 0 71 :3 0
3a :3 0 70 :3 0
2a :3 0 8d :3 0
11 :4 0 103 1
:8 0 a51 f3 :4 0
a3c :3 0 f4 :3 0
9b :2 0 582 a3f
a40 :3 0 8f :3 0
90 :3 0 a42 a43
0 24 :2 0 a44
a45 0 a47 585
a4e 8f :3 0 90
:3 0 a48 a49 0
f5 :2 0 a4a a4b
0 a4d 587 a4f
a41 a47 0 a50
0 a4d 0 a50
589 0 a51 58c
a9b 92 :3 0 8f
:3 0 90 :3 0 a54
a55 0 91 :3 0
a56 a57 0 a91
55 :3 0 56 :3 0
a59 a5a 0 55
:3 0 66 :3 0 a5c
a5d 0 93 :2 0
2 :4 0 104 :2 0
68 :2 0 20 :2 0
58f a62 a64 :3 0
592 a5e a66 a5b
a68 a67 :2 0 58
:3 0 69 :3 0 a6a
a6b 0 5a :4 0
105 :4 0 5d :2 0
5e :3 0 596 a6f
a71 :3 0 5d :2 0
96 :4 0 599 a73
a75 :3 0 5d :2 0
97 :4 0 59c a77
a79 :3 0 5d :2 0
91 :3 0 59f a7b
a7d :3 0 5d :2 0
98 :4 0 5a2 a7f
a81 :3 0 5d :2 0
7e :3 0 99 :3 0
20 :2 0 9a :2 0
5a5 a84 a88 5a9
a83 a8a :3 0 5ac
a6c a8c :2 0 a8e
5af a8f a69 a8e
0 a90 5b1 0
a91 5b3 a94 :3 0
a94 0 a94 a93
a91 a92 :6 0 a96
18 :3 0 5b6 a98
5b8 a97 a96 :2 0
a99 5ba :2 0 a9b
0 a9b a9a a51
a99 :6 0 a9d 1
:3 0 5bc b23 26
:3 0 62 :3 0 2a
:3 0 24 :2 0 5c0
a9f aa2 ea :2 0
62 :3 0 26 :3 0
24 :2 0 5c3 aa5
aa8 5c6 aa4 aaa
:3 0 a9e aab 0
b22 27 :3 0 ec
:2 0 aad aae 0
b22 8c :3 0 ee
:3 0 8b :3 0 ef
:3 0 f0 :3 0 8b
:3 0 41 :3 0 f1
:3 0 71 :3 0 2a
:3 0 70 :3 0 2a
:3 0 72 :3 0 89
:3 0 8d :3 0 11
:4 0 fa 1 :8 0
ad6 f3 :4 0 ac1
:3 0 f4 :3 0 9b
:2 0 5cb ac4 ac5
:3 0 8f :3 0 90
:3 0 ac7 ac8 0
24 :2 0 ac9 aca
0 acc 5ce ad3
8f :3 0 90 :3 0
acd ace 0 f5
:2 0 acf ad0 0
ad2 5d0 ad4 ac6
acc 0 ad5 0
ad2 0 ad5 5d2
0 ad6 5d5 b20
92 :3 0 8f :3 0
90 :3 0 ad9 ada
0 91 :3 0 adb
adc 0 b16 55
:3 0 56 :3 0 ade
adf 0 55 :3 0
66 :3 0 ae1 ae2
0 93 :2 0 2
:4 0 106 :2 0 68
:2 0 20 :2 0 5d8
ae7 ae9 :3 0 5db
ae3 aeb ae0 aed
aec :2 0 58 :3 0
69 :3 0 aef af0
0 5a :4 0 107
:4 0 5d :2 0 5e
:3 0 5df af4 af6
:3 0 5d :2 0 96
:4 0 5e2 af8 afa
:3 0 5d :2 0 97
:4 0 5e5 afc afe
:3 0 5d :2 0 91
:3 0 5e8 b00 b02
:3 0 5d :2 0 98
:4 0 5eb b04 b06
:3 0 5d :2 0 7e
:3 0 99 :3 0 20
:2 0 9a :2 0 5ee
b09 b0d 5f2 b08
b0f :3 0 5f5 af1
b11 :2 0 b13 5f8
b14 aee b13 0
b15 5fa 0 b16
5fc b19 :3 0 b19
0 b19 b18 b16
b17 :6 0 b1b 1a
:3 0 5ff b1d 601
b1c b1b :2 0 b1e
603 :2 0 b20 0
b20 b1f ad6 b1e
:6 0 b22 1 :3 0
605 b24 9fb a9d
0 b25 0 b22
0 b25 609 0
b26 60c b28 8ab
9e5 0 b29 0
b26 0 b29 60e
0 b2a 611 bb0
26 :3 0 62 :3 0
2a :3 0 24 :2 0
613 b2c b2f ea
:2 0 62 :3 0 29
:3 0 24 :2 0 616
b32 b35 619 b31
b37 :3 0 b2b b38
0 baf 27 :3 0
ec :2 0 b3a b3b
0 baf 8c :3 0
ee :3 0 8b :3 0
ef :3 0 f0 :3 0
8b :3 0 41 :3 0
f1 :3 0 71 :3 0
2a :3 0 70 :3 0
2a :3 0 72 :3 0
89 :3 0 8d :3 0
11 :4 0 108 1
:8 0 b63 f3 :4 0
b4e :3 0 f4 :3 0
9b :2 0 61e b51
b52 :3 0 8f :3 0
90 :3 0 b54 b55
0 24 :2 0 b56
b57 0 b59 621
b60 8f :3 0 90
:3 0 b5a b5b 0
f5 :2 0 b5c b5d
0 b5f 623 b61
b53 b59 0 b62
0 b5f 0 b62
625 0 b63 628
bad 92 :3 0 8f
:3 0 90 :3 0 b66
b67 0 91 :3 0
b68 b69 0 ba3
55 :3 0 56 :3 0
b6b b6c 0 55
:3 0 66 :3 0 b6e
b6f 0 93 :2 0
2 :4 0 109 :2 0
68 :2 0 20 :2 0
62b b74 b76 :3 0
62e b70 b78 b6d
b7a b79 :2 0 58
:3 0 69 :3 0 b7c
b7d 0 5a :4 0
10a :4 0 5d :2 0
5e :3 0 632 b81
b83 :3 0 5d :2 0
96 :4 0 635 b85
b87 :3 0 5d :2 0
97 :4 0 638 b89
b8b :3 0 5d :2 0
91 :3 0 63b b8d
b8f :3 0 5d :2 0
98 :4 0 63e b91
b93 :3 0 5d :2 0
7e :3 0 99 :3 0
20 :2 0 9a :2 0
641 b96 b9a 645
b95 b9c :3 0 648
b7e b9e :2 0 ba0
64b ba1 b7b ba0
0 ba2 64d 0
ba3 64f ba6 :3 0
ba6 0 ba6 ba5
ba3 ba4 :6 0 ba8
1c :3 0 652 baa
654 ba9 ba8 :2 0
bab 656 :2 0 bad
0 bad bac b63
bab :6 0 baf 1
:3 0 658 bb1 8a0
b2a 0 bb2 0
baf 0 bb2 65c
0 ddc 1d :3 0
10b :2 0 65f bb4
bb5 :3 0 bb6 :2 0
1e :4 0 bb8 bb9
0 d5c 10c :3 0
10d :3 0 1e :3 0
10e :3 0 a1 :3 0
14 :3 0 6c :3 0
16 :4 0 10f 1
:8 0 bc9 8f :3 0
90 :3 0 bc4 bc5
0 91 :3 0 bc6
bc7 0 bc9 661
c13 92 :3 0 8f
:3 0 90 :3 0 bcc
bcd 0 91 :3 0
bce bcf 0 c09
55 :3 0 56 :3 0
bd1 bd2 0 55
:3 0 66 :3 0 bd4
bd5 0 93 :2 0
2 :4 0 110 :2 0
68 :2 0 20 :2 0
664 bda bdc :3 0
667 bd6 bde bd3
be0 bdf :2 0 58
:3 0 69 :3 0 be2
be3 0 5a :4 0
111 :4 0 5d :2 0
5e :3 0 66b be7
be9 :3 0 5d :2 0
96 :4 0 66e beb
bed :3 0 5d :2 0
97 :4 0 671 bef
bf1 :3 0 5d :2 0
91 :3 0 674 bf3
bf5 :3 0 5d :2 0
98 :4 0 677 bf7
bf9 :3 0 5d :2 0
7e :3 0 99 :3 0
20 :2 0 9a :2 0
67a bfc c00 67e
bfb c02 :3 0 681
be4 c04 :2 0 c06
684 c07 be1 c06
0 c08 686 0
c09 688 c0c :3 0
c0c 0 c0c c0b
c09 c0a :6 0 c0e
1e :3 0 68b c10
68d c0f c0e :2 0
c11 68f :2 0 c13
0 c13 c12 bc9
c11 :6 0 d5c 1
:3 0 1e :3 0 10b
:2 0 691 c16 c17
:3 0 c18 :2 0 7d
:3 0 7e :3 0 1e
:3 0 1e :3 0 b9
:4 0 112 1 :8 0
c25 8f :3 0 90
:3 0 c20 c21 0
91 :3 0 c22 c23
0 c25 693 c6f
92 :3 0 8f :3 0
90 :3 0 c28 c29
0 91 :3 0 c2a
c2b 0 c65 55
:3 0 56 :3 0 c2d
c2e 0 55 :3 0
66 :3 0 c30 c31
0 93 :2 0 2
:4 0 113 :2 0 68
:2 0 20 :2 0 696
c36 c38 :3 0 699
c32 c3a c2f c3c
c3b :2 0 58 :3 0
69 :3 0 c3e c3f
0 5a :4 0 114
:4 0 5d :2 0 5e
:3 0 69d c43 c45
:3 0 5d :2 0 96
:4 0 6a0 c47 c49
:3 0 5d :2 0 97
:4 0 6a3 c4b c4d
:3 0 5d :2 0 91
:3 0 6a6 c4f c51
:3 0 5d :2 0 98
:4 0 6a9 c53 c55
:3 0 5d :2 0 7e
:3 0 99 :3 0 20
:2 0 9a :2 0 6ac
c58 c5c 6b0 c57
c5e :3 0 6b3 c40
c60 :2 0 c62 6b6
c63 c3d c62 0
c64 6b8 0 c65
6ba c68 :3 0 c68
0 c68 c67 c65
c66 :6 0 c6a 20
:3 0 6bd c6c 6bf
c6b c6a :2 0 c6d
6c1 :2 0 c6f 0
c6f c6e c25 c6d
:6 0 c84 1 :3 0
b2 :3 0 115 :3 0
c71 c72 0 1d
:3 0 1e :3 0 116
:2 0 6c3 c73 c77
ed :2 0 24 :2 0
6c9 c79 c7b :3 0
1a :3 0 1e :3 0
c7d c7e 0 c80
6cc c81 c7c c80
0 c82 6ce 0
c84 cf :3 0 6d0
d59 62 :3 0 32
:3 0 24 :2 0 6d3
c85 c88 ad :2 0
24 :2 0 6d8 c8a
c8c :3 0 32 :3 0
f8 :3 0 f0 :3 0
c8f c90 0 62
:3 0 32 :3 0 24
:2 0 6db c92 c95
41 :3 0 f9 :3 0
c97 c98 0 6de
c91 c9a c9b :2 0
c8e c9c 0 cfa
b2 :3 0 117 :3 0
7d :3 0 7e :3 0
1d :3 0 b2 :3 0
118 :3 0 1a :3 0
1a :3 0 b9 :4 0
119 1 :8 0 cae
8f :3 0 90 :3 0
ca9 caa 0 91
:3 0 cab cac 0
cae 6e1 cf8 92
:3 0 8f :3 0 90
:3 0 cb1 cb2 0
91 :3 0 cb3 cb4
0 cee 55 :3 0
56 :3 0 cb6 cb7
0 55 :3 0 66
:3 0 cb9 cba 0
93 :2 0 2 :4 0
11a :2 0 68 :2 0
20 :2 0 6e4 cbf
cc1 :3 0 6e7 cbb
cc3 cb8 cc5 cc4
:2 0 58 :3 0 69
:3 0 cc7 cc8 0
5a :4 0 11b :4 0
5d :2 0 5e :3 0
6eb ccc cce :3 0
5d :2 0 96 :4 0
6ee cd0 cd2 :3 0
5d :2 0 97 :4 0
6f1 cd4 cd6 :3 0
5d :2 0 91 :3 0
6f4 cd8 cda :3 0
5d :2 0 98 :4 0
6f7 cdc cde :3 0
5d :2 0 7e :3 0
99 :3 0 20 :2 0
9a :2 0 6fa ce1
ce5 6fe ce0 ce7
:3 0 701 cc9 ce9
:2 0 ceb 704 cec
cc6 ceb 0 ced
706 0 cee 708
cf1 :3 0 cf1 0
cf1 cf0 cee cef
:6 0 cf3 22 :3 0
70b cf5 70d cf4
cf3 :2 0 cf6 70f
:2 0 cf8 0 cf8
cf7 cae cf6 :6 0
cfa 1 :3 0 711
cfb c8d cfa 0
d5b b2 :3 0 117
:3 0 7d :3 0 7e
:3 0 1d :3 0 b2
:3 0 118 :3 0 1a
:3 0 1a :3 0 b9
:4 0 11c 1 :8 0
d0c 8f :3 0 90
:3 0 d07 d08 0
91 :3 0 d09 d0a
0 d0c 714 d56
92 :3 0 8f :3 0
90 :3 0 d0f d10
0 91 :3 0 d11
d12 0 d4c 55
:3 0 56 :3 0 d14
d15 0 55 :3 0
66 :3 0 d17 d18
0 93 :2 0 2
:4 0 11d :2 0 68
:2 0 20 :2 0 717
d1d d1f :3 0 71a
d19 d21 d16 d23
d22 :2 0 58 :3 0
69 :3 0 d25 d26
0 5a :4 0 11e
:4 0 5d :2 0 5e
:3 0 71e d2a d2c
:3 0 5d :2 0 96
:4 0 721 d2e d30
:3 0 5d :2 0 97
:4 0 724 d32 d34
:3 0 5d :2 0 91
:3 0 727 d36 d38
:3 0 5d :2 0 98
:4 0 72a d3a d3c
:3 0 5d :2 0 7e
:3 0 99 :3 0 20
:2 0 9a :2 0 72d
d3f d43 731 d3e
d45 :3 0 734 d27
d47 :2 0 d49 737
d4a d24 d49 0
d4b 739 0 d4c
73b d4f :3 0 d4f
0 d4f d4e d4c
d4d :6 0 d51 24
:3 0 73e d53 740
d52 d51 :2 0 d54
742 :2 0 d56 0
d56 d55 d0c d54
:6 0 d58 1 :3 0
744 d5a c19 c84
0 d5b 0 d58
0 d5b 746 0
d5c 74a d5d bb7
d5c 0 d5e 74e
0 ddc 13 :3 0
10b :2 0 750 d60
d61 :3 0 d62 :2 0
2f :3 0 11f :3 0
14 :3 0 11 :3 0
120 :2 0 752 d65
d69 d64 d6a 0
d6c 756 d8d 7e
:3 0 1f :3 0 20
:2 0 20 :2 0 758
d6d d71 9b :2 0
120 :4 0 75e d73
d75 :3 0 2f :3 0
11f :3 0 14 :3 0
11 :3 0 24 :2 0
761 d78 d7c d77
d7d 0 d7f 765
d89 2f :3 0 11f
:3 0 14 :3 0 11
:3 0 20 :2 0 767
d81 d85 d80 d86
0 d88 76b d8a
d76 d7f 0 d8b
0 d88 0 d8b
76d 0 d8c 770
d8e d63 d6c 0
d8f 0 d8c 0
d8f 772 0 ddc
2f :3 0 120 :2 0
d90 d91 0 ddc
2f :3 0 121 :3 0
11 :3 0 1a :3 0
26 :3 0 2f :3 0
32 :3 0 b :3 0
24 :2 0 62 :3 0
28 :3 0 24 :2 0
775 d9c d9f 778
d94 da1 d93 da2
0 ddc 62 :3 0
2f :3 0 24 :2 0
781 da4 da7 d0
:2 0 24 :2 0 786
da9 dab :3 0 c
:3 0 11 :3 0 dad
dae 0 dd6 55
:3 0 56 :3 0 db0
db1 0 55 :3 0
66 :3 0 db3 db4
0 20 :2 0 2
:4 0 122 :2 0 68
:2 0 20 :2 0 789
db9 dbb :3 0 78c
db5 dbd db2 dbf
dbe :2 0 58 :3 0
69 :3 0 dc1 dc2
0 5a :4 0 123
:4 0 5d :2 0 5e
:3 0 790 dc6 dc8
:3 0 793 dc3 dca
:2 0 dcc 796 dcd
dc0 dcc 0 dce
798 0 dd6 d
:3 0 62 :3 0 2f
:3 0 24 :2 0 79a
dd0 dd3 dd4 :2 0
dd6 79d dd7 dac
dd6 0 dd8 7a1
0 ddc 26 :3 0
2a :3 0 dd9 dda
0 ddc 7a3 ddd
893 ddc 0 dde
7ab 0 ddf 7ad
e03 27 :3 0 fd
:3 0 62 :3 0 fe
:3 0 2a :3 0 7b1
de3 de5 24 :2 0
7b3 de2 de8 ff
:2 0 62 :3 0 fe
:3 0 26 :3 0 7b6
dec dee 24 :2 0
7b8 deb df1 7bb
dea df3 :3 0 df4
:2 0 100 :2 0 101
:2 0 7be df6 df8
:3 0 df9 :2 0 68
:2 0 102 :2 0 7c1
dfb dfd :3 0 7c4
de1 dff de0 e00
0 e02 7c6 e04
875 ddf 0 e05
0 e02 0 e05
7c8 0 e51 2f
:3 0 124 :3 0 14
:3 0 15 :3 0 16
:3 0 11 :3 0 1d
:3 0 1f :3 0 26
:3 0 2a :3 0 38
:3 0 29 :3 0 27
:3 0 46 :3 0 49
:3 0 48 :3 0 4a
:3 0 4b :3 0 4d
:3 0 4c :3 0 4e
:3 0 25 :3 0 23
:3 0 2b :3 0 b
:3 0 62 :3 0 2c
:3 0 24 :2 0 7cb
e1f e22 7ce e07
e24 e06 e25 0
e51 c :3 0 11
:3 0 e27 e28 0
e51 55 :3 0 56
:3 0 e2a e2b 0
55 :3 0 66 :3 0
e2d e2e 0 20
:2 0 2 :4 0 125
:2 0 68 :2 0 20
:2 0 7e7 e33 e35
:3 0 7ea e2f e37
e2c e39 e38 :2 0
58 :3 0 69 :3 0
e3b e3c 0 5a
:4 0 126 :4 0 5d
:2 0 5e :3 0 7ee
e40 e42 :3 0 7f1
e3d e44 :2 0 e46
7f4 e47 e3a e46
0 e48 7f6 0
e51 d :3 0 62
:3 0 2f :3 0 24
:2 0 7f8 e4a e4d
e4e :2 0 e51 cf
:3 0 7fb 11e1 62
:3 0 e :3 0 24
:2 0 802 e52 e55
62 :3 0 d0 :2 0
27 :3 0 24 :2 0
805 e57 e5b 80a
e58 e5d :3 0 8c
:3 0 89 :3 0 e
:3 0 8b :3 0 ef
:3 0 f0 :3 0 8b
:3 0 41 :3 0 127
:3 0 8d :3 0 11
:4 0 128 1 :8 0
e80 f3 :4 0 e6b
:3 0 f4 :3 0 9b
:2 0 80f e6e e6f
:3 0 8f :3 0 90
:3 0 e71 e72 0
24 :2 0 e73 e74
0 e76 812 e7d
8f :3 0 90 :3 0
e77 e78 0 f5
:2 0 e79 e7a 0
e7c 814 e7e e70
e76 0 e7f 0
e7c 0 e7f 816
0 e80 819 eca
92 :3 0 8f :3 0
90 :3 0 e83 e84
0 91 :3 0 e85
e86 0 ec0 55
:3 0 56 :3 0 e88
e89 0 55 :3 0
66 :3 0 e8b e8c
0 93 :2 0 2
:4 0 129 :2 0 68
:2 0 20 :2 0 81c
e91 e93 :3 0 81f
e8d e95 e8a e97
e96 :2 0 58 :3 0
69 :3 0 e99 e9a
0 5a :4 0 12a
:4 0 5d :2 0 5e
:3 0 823 e9e ea0
:3 0 5d :2 0 96
:4 0 826 ea2 ea4
:3 0 5d :2 0 97
:4 0 829 ea6 ea8
:3 0 5d :2 0 91
:3 0 82c eaa eac
:3 0 5d :2 0 98
:4 0 82f eae eb0
:3 0 5d :2 0 7e
:3 0 99 :3 0 20
:2 0 9a :2 0 832
eb3 eb7 836 eb2
eb9 :3 0 839 e9b
ebb :2 0 ebd 83c
ebe e98 ebd 0
ebf 83e 0 ec0
840 ec3 :3 0 ec3
0 ec3 ec2 ec0
ec1 :6 0 ec5 26
:3 0 843 ec7 845
ec6 ec5 :2 0 ec8
847 :2 0 eca 0
eca ec9 e80 ec8
:6 0 f3a 1 :3 0
a0 :3 0 8b :3 0
ef :3 0 f0 :3 0
8b :3 0 41 :3 0
127 :3 0 6b :3 0
14 :3 0 a1 :3 0
15 :4 0 12b 1
:8 0 eed f3 :4 0
ed8 :3 0 f4 :3 0
9b :2 0 84b edb
edc :3 0 8f :3 0
90 :3 0 ede edf
0 24 :2 0 ee0
ee1 0 ee3 84e
eea 8f :3 0 90
:3 0 ee4 ee5 0
f5 :2 0 ee6 ee7
0 ee9 850 eeb
edd ee3 0 eec
0 ee9 0 eec
852 0 eed 855
f37 92 :3 0 8f
:3 0 90 :3 0 ef0
ef1 0 91 :3 0
ef2 ef3 0 f2d
55 :3 0 56 :3 0
ef5 ef6 0 55
:3 0 66 :3 0 ef8
ef9 0 93 :2 0
2 :4 0 12c :2 0
68 :2 0 20 :2 0
858 efe f00 :3 0
85b efa f02 ef7
f04 f03 :2 0 58
:3 0 69 :3 0 f06
f07 0 5a :4 0
12d :4 0 5d :2 0
5e :3 0 85f f0b
f0d :3 0 5d :2 0
96 :4 0 862 f0f
f11 :3 0 5d :2 0
97 :4 0 865 f13
f15 :3 0 5d :2 0
91 :3 0 868 f17
f19 :3 0 5d :2 0
98 :4 0 86b f1b
f1d :3 0 5d :2 0
7e :3 0 99 :3 0
20 :2 0 9a :2 0
86e f20 f24 872
f1f f26 :3 0 875
f08 f28 :2 0 f2a
878 f2b f05 f2a
0 f2c 87a 0
f2d 87c f30 :3 0
f30 0 f30 f2f
f2d f2e :6 0 f32
28 :3 0 87f f34
881 f33 f32 :2 0
f35 883 :2 0 f37
0 f37 f36 eed
f35 :6 0 f3a 1
:3 0 cf :3 0 885
f3b e5e f3a 0
11e2 62 :3 0 10
:3 0 24 :2 0 888
f3c f3f 62 :3 0
d0 :2 0 28 :3 0
24 :2 0 88b f41
f45 890 f42 f47
:3 0 62 :3 0 10
:3 0 24 :2 0 893
f49 f4c 9b :2 0
24 :2 0 898 f4e
f50 :3 0 28 :3 0
f5 :2 0 f52 f53
0 f55 89b f9e
62 :3 0 10 :3 0
24 :2 0 89d f56
f59 ed :2 0 20
:2 0 8a2 f5b f5d
:3 0 f5e :2 0 62
:3 0 10 :3 0 24
:2 0 8a5 f60 f63
ad :2 0 12e :2 0
8aa f65 f67 :3 0
f68 :2 0 f5f f6a
f69 :2 0 c :3 0
11 :3 0 f6c f6d
0 f93 55 :3 0
56 :3 0 f6f f70
0 55 :3 0 66
:3 0 f72 f73 0
20 :2 0 2 :4 0
12f :2 0 68 :2 0
20 :2 0 8ad f78
f7a :3 0 8b0 f74
f7c f71 f7e f7d
:2 0 58 :3 0 69
:3 0 f80 f81 0
5a :4 0 130 :4 0
5d :2 0 5e :3 0
8b4 f85 f87 :3 0
8b7 f82 f89 :2 0
f8b 8ba f8c f7f
f8b 0 f8d 8bc
0 f93 d :3 0
41 :3 0 c9 :3 0
f8f f90 0 f91
:2 0 f93 8be f94
f6b f93 0 f95
8c2 0 f9d 28
:3 0 62 :3 0 10
:3 0 24 :2 0 8c4
f97 f9a f96 f9b
0 f9d 8c7 f9f
f51 f55 0 fa0
0 f9d 0 fa0
8ca 0 11df 13
:3 0 10b :2 0 8cd
fa2 fa3 :3 0 fa4
:2 0 7a :3 0 2f
:3 0 8c :3 0 8d
:3 0 13 :4 0 131
1 :8 0 fb1 8f
:3 0 90 :3 0 fac
fad 0 91 :3 0
fae faf 0 fb1
8cf ffb 92 :3 0
8f :3 0 90 :3 0
fb4 fb5 0 91
:3 0 fb6 fb7 0
ff1 55 :3 0 56
:3 0 fb9 fba 0
55 :3 0 66 :3 0
fbc fbd 0 93
:2 0 2 :4 0 132
:2 0 68 :2 0 20
:2 0 8d2 fc2 fc4
:3 0 8d5 fbe fc6
fbb fc8 fc7 :2 0
58 :3 0 69 :3 0
fca fcb 0 5a
:4 0 133 :4 0 5d
:2 0 5e :3 0 8d9
fcf fd1 :3 0 5d
:2 0 96 :4 0 8dc
fd3 fd5 :3 0 5d
:2 0 97 :4 0 8df
fd7 fd9 :3 0 5d
:2 0 91 :3 0 8e2
fdb fdd :3 0 5d
:2 0 98 :4 0 8e5
fdf fe1 :3 0 5d
:2 0 7e :3 0 99
:3 0 20 :2 0 9a
:2 0 8e8 fe4 fe8
8ec fe3 fea :3 0
8ef fcc fec :2 0
fee 8f2 fef fc9
fee 0 ff0 8f4
0 ff1 8f6 ff4
:3 0 ff4 0 ff4
ff3 ff1 ff2 :6 0
ff6 2a :3 0 8f9
ff8 8fb ff7 ff6
:2 0 ff9 8fd :2 0
ffb 0 ffb ffa
fb1 ff9 :6 0 1041
1 :3 0 8f :3 0
90 :3 0 ffd ffe
0 8f :3 0 9b
:2 0 134 :3 0 1000
1002 0 901 1001
1004 :3 0 1005 :2 0
62 :3 0 28 :3 0
24 :2 0 904 1007
100a 62 :3 0 ad
:2 0 2f :3 0 24
:2 0 907 100c 1010
90c 100d 1012 :3 0
1013 :2 0 1006 1015
1014 :2 0 c :3 0
13 :3 0 1017 1018
0 103e 55 :3 0
56 :3 0 101a 101b
0 55 :3 0 66
:3 0 101d 101e 0
20 :2 0 2 :4 0
135 :2 0 68 :2 0
20 :2 0 90f 1023
1025 :3 0 912 101f
1027 101c 1029 1028
:2 0 58 :3 0 69
:3 0 102b 102c 0
5a :4 0 136 :4 0
5d :2 0 5e :3 0
916 1030 1032 :3 0
919 102d 1034 :2 0
1036 91c 1037 102a
1036 0 1038 91e
0 103e d :3 0
41 :3 0 137 :3 0
103a 103b 0 103c
:2 0 103e 920 103f
1016 103e 0 1040
924 0 1041 926
1042 fa5 1041 0
1043 929 0 11df
2e :3 0 ea :2 0
20 :2 0 92b 1045
1047 :3 0 1044 1048
0 11df 2f :3 0
eb :3 0 14 :3 0
15 :3 0 11 :3 0
17 :3 0 19 :3 0
46 :3 0 48 :3 0
2e :3 0 25 :3 0
23 :3 0 92d 104b
1056 104a 1057 0
11df 62 :3 0 2b
:3 0 24 :2 0 938
1059 105c ad :2 0
24 :2 0 93d 105e
1060 :3 0 1061 :2 0
1d :3 0 10b :2 0
940 1064 1065 :3 0
1066 :2 0 1067 :2 0
1062 1069 1068 :2 0
2f :3 0 138 :3 0
14 :3 0 15 :3 0
16 :3 0 13 :3 0
11 :3 0 1d :3 0
2b :3 0 24 :2 0
942 106c 1075 106b
1076 0 1078 94b
1079 106a 1078 0
107a 94d 0 11df
13 :3 0 10b :2 0
94f 107c 107d :3 0
107e :2 0 2f :3 0
11f :3 0 14 :3 0
11 :3 0 120 :2 0
951 1081 1085 1080
1086 0 1088 955
10a9 7e :3 0 1f
:3 0 20 :2 0 20
:2 0 957 1089 108d
9b :2 0 120 :4 0
95d 108f 1091 :3 0
2f :3 0 11f :3 0
14 :3 0 11 :3 0
24 :2 0 960 1094
1098 1093 1099 0
109b 964 10a5 2f
:3 0 11f :3 0 14
:3 0 11 :3 0 20
:2 0 966 109d 10a1
109c 10a2 0 10a4
96a 10a6 1092 109b
0 10a7 0 10a4
0 10a7 96c 0
10a8 96f 10aa 107f
1088 0 10ab 0
10a8 0 10ab 971
0 11df 1d :3 0
10b :2 0 974 10ad
10ae :3 0 10af :2 0
b2 :3 0 117 :3 0
7d :3 0 7e :3 0
1d :3 0 b2 :3 0
118 :3 0 1a :3 0
1a :3 0 b9 :4 0
139 1 :8 0 10c1
8f :3 0 90 :3 0
10bc 10bd 0 91
:3 0 10be 10bf 0
10c1 976 110b 92
:3 0 8f :3 0 90
:3 0 10c4 10c5 0
91 :3 0 10c6 10c7
0 1101 55 :3 0
56 :3 0 10c9 10ca
0 55 :3 0 66
:3 0 10cc 10cd 0
93 :2 0 2 :4 0
13a :2 0 68 :2 0
20 :2 0 979 10d2
10d4 :3 0 97c 10ce
10d6 10cb 10d8 10d7
:2 0 58 :3 0 69
:3 0 10da 10db 0
5a :4 0 13b :4 0
5d :2 0 5e :3 0
980 10df 10e1 :3 0
5d :2 0 96 :4 0
983 10e3 10e5 :3 0
5d :2 0 97 :4 0
986 10e7 10e9 :3 0
5d :2 0 91 :3 0
989 10eb 10ed :3 0
5d :2 0 98 :4 0
98c 10ef 10f1 :3 0
5d :2 0 7e :3 0
99 :3 0 20 :2 0
9a :2 0 98f 10f4
10f8 993 10f3 10fa
:3 0 996 10dc 10fc
:2 0 10fe 999 10ff
10d9 10fe 0 1100
99b 0 1101 99d
1104 :3 0 1104 0
1104 1103 1101 1102
:6 0 1106 2c :3 0
9a0 1108 9a2 1107
1106 :2 0 1109 9a4
:2 0 110b 0 110b
110a 10c1 1109 :6 0
111c 1 :3 0 26
:3 0 62 :3 0 26
:3 0 24 :2 0 9a6
110e 1111 ea :2 0
62 :3 0 29 :3 0
24 :2 0 9a9 1114
1117 9ac 1113 1119
:3 0 110d 111a 0
111c 9af 111d 10b0
111c 0 111e 9b2
0 11df 32 :3 0
24 :2 0 111f 1120
0 11df 2f :3 0
120 :2 0 1122 1123
0 11df 2f :3 0
121 :3 0 11 :3 0
1a :3 0 26 :3 0
2f :3 0 32 :3 0
b :3 0 24 :2 0
62 :3 0 28 :3 0
24 :2 0 9b4 112e
1131 9b7 1126 1133
1125 1134 0 11df
62 :3 0 2f :3 0
24 :2 0 9c0 1136
1139 d0 :2 0 24
:2 0 9c5 113b 113d
:3 0 c :3 0 11
:3 0 113f 1140 0
1166 55 :3 0 56
:3 0 1142 1143 0
55 :3 0 66 :3 0
1145 1146 0 20
:2 0 2 :4 0 13c
:2 0 68 :2 0 20
:2 0 9c8 114b 114d
:3 0 9cb 1147 114f
1144 1151 1150 :2 0
58 :3 0 69 :3 0
1153 1154 0 5a
:4 0 13d :4 0 5d
:2 0 5e :3 0 9cf
1158 115a :3 0 9d2
1155 115c :2 0 115e
9d5 115f 1152 115e
0 1160 9d7 0
1166 d :3 0 41
:3 0 137 :3 0 1162
1163 0 1164 :2 0
1166 9d9 11dc 8c
:3 0 ee :3 0 7a
:3 0 28 :3 0 76
:3 0 78 :3 0 75
:3 0 13e :3 0 8b
:3 0 ef :3 0 f0
:3 0 8b :3 0 41
:3 0 f1 :3 0 41
:3 0 13f :3 0 8d
:3 0 11 :4 0 140
1 :8 0 118f f3
:4 0 117a :3 0 f4
:3 0 9b :2 0 9df
117d 117e :3 0 8f
:3 0 90 :3 0 1180
1181 0 24 :2 0
1182 1183 0 1185
9e2 118c 8f :3 0
90 :3 0 1186 1187
0 f5 :2 0 1188
1189 0 118b 9e4
118d 117f 1185 0
118e 0 118b 0
118e 9e6 0 118f
9e9 11d9 92 :3 0
8f :3 0 90 :3 0
1192 1193 0 91
:3 0 1194 1195 0
11cf 55 :3 0 56
:3 0 1197 1198 0
55 :3 0 66 :3 0
119a 119b 0 93
:2 0 2 :4 0 141
:2 0 68 :2 0 20
:2 0 9ec 11a0 11a2
:3 0 9ef 119c 11a4
1199 11a6 11a5 :2 0
58 :3 0 69 :3 0
11a8 11a9 0 5a
:4 0 142 :4 0 5d
:2 0 5e :3 0 9f3
11ad 11af :3 0 5d
:2 0 96 :4 0 9f6
11b1 11b3 :3 0 5d
:2 0 97 :4 0 9f9
11b5 11b7 :3 0 5d
:2 0 91 :3 0 9fc
11b9 11bb :3 0 5d
:2 0 98 :4 0 9ff
11bd 11bf :3 0 5d
:2 0 7e :3 0 99
:3 0 20 :2 0 9a
:2 0 a02 11c2 11c6
a06 11c1 11c8 :3 0
a09 11aa 11ca :2 0
11cc a0c 11cd 11a7
11cc 0 11ce a0e
0 11cf a10 11d2
:3 0 11d2 0 11d2
11d1 11cf 11d0 :6 0
11d4 2e :3 0 a13
11d6 a15 11d5 11d4
:2 0 11d7 a17 :2 0
11d9 0 11d9 11d8
118f 11d7 :6 0 11db
1 :3 0 a19 11dd
113e 1166 0 11de
0 11db 0 11de
a1b 0 11df a1e
11e0 f48 11df 0
11e2 865 e51 0
11e2 a2a 0 11e3
a2e 11e5 2e0 640
0 11e6 0 11e3
0 11e6 a38 0
1221 8f :3 0 90
:3 0 11e7 11e8 0
143 :3 0 14 :3 0
a3b 11ea 11ec 11e9
11ed 0 1221 55
:3 0 56 :3 0 11ef
11f0 0 55 :3 0
66 :3 0 11f2 11f3
0 20 :2 0 2
:4 0 144 :2 0 68
:2 0 20 :2 0 a3d
11f8 11fa :3 0 a40
11f4 11fc 11f1 11fe
11fd :2 0 58 :3 0
69 :3 0 1200 1201
0 5a :4 0 145
:4 0 5d :2 0 5e
:3 0 a44 1205 1207
:3 0 5d :2 0 96
:4 0 a47 1209 120b
:3 0 5d :2 0 c8
:4 0 a4a 120d 120f
:3 0 5d :2 0 8f
:3 0 90 :3 0 1212
1213 0 a4d 1211
1215 :3 0 a50 1202
1217 :2 0 1219 a53
121a 11ff 1219 0
121b a55 0 1221
d :3 0 8f :3 0
90 :3 0 121d 121e
0 121f :2 0 1221
a57 1224 :3 0 1224
a60 1224 1223 1221
1222 :6 0 1225 :2 0
2 24 1224 1228
:3 0 1227 1225 1229
:8 0 
a9d
4
:3 0 1 3 1
9 1 d 1
11 1 15 1
1b 6 8 c
10 14 1a 20
1 26 1 2c
1 32 1 3a
1 38 1 41
1 3f 1 48
1 46 1 4f
1 4d 1 56
1 54 1 5b
1 60 1 65
1 6a 1 6f
1 74 1 7b
1 79 1 82
1 80 1 89
1 87 1 8e
1 94 1 9a
1 a0 1 a6
1 ac 1 b2
1 b8 1 be
1 c4 1 ca
1 d0 1 d6
1 dc 1 e2
1 e8 1 ee
1 f4 1 fa
1 100 1 106
1 10c 1 112
1 118 1 11e
1 124 1 12c
1 12a 1 136
1 134 1 140
1 13e 1 145
1 14b 1 151
1 157 1 15d
1 163 1 169
1 16f 1 175
1 17b 1 181
1 187 1 18d
1 193 1 19f
1 1ab 2 1ae
1b0 2 1b3 1b5
2 1b7 1b9 2
1bb 1bd 2 1bf
1c1 1 1c7 2
1c9 1ca 2 1c3
1cc 2 1ce 1d0
1 1d6 2 1d8
1d9 2 1d2 1db
2 1dd 1df 1
1e5 2 1e7 1e8
2 1e1 1ea 2
1ec 1ee 2 1f0
1f2 2 1f4 1f6
2 1f8 1fa 2
1fc 1fe 2 200
202 2 204 206
2 208 20a 2
20c 20e 4 1a7
1ad 1b2 210 1
212 1 214 2
21e 220 3 21c
21d 222 2 22b
22d 2 22a 22f
1 231 1 233
2 285 28a 2
29b 29d 3 299
29a 29f 2 2a8
2aa 2 2ac 2ae
2 2b0 2b2 2
2b4 2b6 2 2b8
2ba 3 2bf 2c0
2c1 2 2bc 2c3
2 2a7 2c5 1
2c7 1 2c9 2
292 2ca 1 2ce
1 28d 1 2d2
1 2dd 2 2d9
2dd 2 2f0 2f5
2 306 308 3
304 305 30a 2
313 315 2 317
319 2 31b 31d
2 31f 321 2
323 325 3 32a
32b 32c 2 327
32e 2 312 330
1 332 1 334
2 2fd 335 1
339 1 2f8 1
33d 1 348 2
344 348 2 357
359 3 355 356
35b 2 364 366
2 363 368 1
36a 1 36c 3
34e 36d 372 1
374 2 37e 383
2 394 396 3
392 393 398 2
3a1 3a3 2 3a5
3a7 2 3a9 3ab
2 3ad 3af 2
3b1 3b3 3 3b8
3b9 3ba 2 3b5
3bc 2 3a0 3be
1 3c0 1 3c2
2 38b 3c3 1
3c7 1 386 1
3cb 2 3d1 3d2
1 3d6 2 3d4
3d6 2 3de 3e3
2 3f4 3f6 3
3f2 3f3 3f8 2
401 403 2 405
407 2 409 40b
2 40d 40f 2
411 413 3 418
419 41a 2 415
41c 2 400 41e
1 420 1 422
2 3eb 423 1
427 1 3e6 1
42b 2 433 434
1 438 2 436
438 2 446 448
3 444 445 44a
2 453 455 2
452 457 1 459
1 45b 3 43d
45c 461 1 463
2 42e 464 1
466 2 483 488
2 499 49b 3
497 498 49d 2
4a6 4a8 2 4aa
4ac 2 4ae 4b0
2 4b2 4b4 2
4b6 4b8 3 4bd
4be 4bf 2 4ba
4c1 2 4a5 4c3
1 4c5 1 4c7
2 490 4c8 1
4cc 1 48b 1
4d0 2 4d6 4d7
1 4db 2 4d9
4db 2 4e9 4eb
3 4e7 4e8 4ed
2 4f6 4f8 2
4f5 4fa 1 4fc
1 4fe 3 4e0
4ff 504 1 506
2 509 50a 1
50e 2 50c 50e
2 519 51b 3
517 518 51d 2
526 528 2 52a
52c 2 52e 530
1 538 2 53a
53b 2 532 53d
2 525 53f 1
541 1 543 2
54d 54f 3 54b
54c 551 2 55a
55c 2 559 55e
1 560 1 562
2 56a 56b 3
544 563 56e 2
572 573 2 578
579 1 57b 2
575 57b 2 582
583 2 588 589
1 58b 2 585
58b 2 599 59b
3 597 598 59d
2 5a6 5a8 2
5a5 5aa 1 5ac
1 5ae 3 590
5af 5b4 2 5b8
5b9 2 5be 5bf
1 5c1 2 5bb
5c1 1 5c6 2
5c9 5c8 2 5d5
5d6 5 5d0 5d1
5d2 5d3 5d8 4
580 5ca 5cd 5db
2 5e6 5e8 3
5e4 5e5 5ea 2
5f3 5f5 2 5f7
5f9 2 5fb 5fd
1 605 2 607
608 2 5ff 60a
2 5f2 60c 1
60e 1 610 2
61a 61c 3 618
619 61e 2 627
629 2 626 62b
1 62d 1 62f
2 637 638 3
611 630 63b 3
63d 5dd 63e 8
340 375 378 3ce
467 4d3 507 63f
2 642 643 1
647 2 645 647
2 655 657 3
653 654 659 2
662 664 2 661
666 1 668 1
66a 3 64c 66b
670 1 672 2
67c 681 2 692
694 3 690 691
696 2 69f 6a1
2 6a3 6a5 2
6a7 6a9 2 6ab
6ad 2 6af 6b1
3 6b6 6b7 6b8
2 6b3 6ba 2
69e 6bc 1 6be
1 6c0 2 689
6c1 1 6c5 1
684 1 6c9 2
6cf 6d0 1 6d4
2 6d2 6d4 2
6dc 6e1 2 6f2
6f4 3 6f0 6f1
6f6 2 6ff 701
2 703 705 2
707 709 2 70b
70d 2 70f 711
3 716 717 718
2 713 71a 2
6fe 71c 1 71e
1 720 2 6e9
721 1 725 1
6e4 1 729 2
731 732 1 736
2 734 736 2
744 746 3 742
743 748 2 751
753 2 750 755
1 757 1 759
3 73b 75a 75f
1 761 2 72c
762 1 764 2
772 777 2 788
78a 3 786 787
78c 2 795 797
2 799 79b 2
79d 79f 2 7a1
7a3 2 7a5 7a7
3 7ac 7ad 7ae
2 7a9 7b0 2
794 7b2 1 7b4
1 7b6 2 77f
7b7 1 7bb 1
77a 1 7bf 2
7c5 7c6 1 7ca
2 7c8 7ca 2
7d8 7da 3 7d6
7d7 7dc 2 7e5
7e7 2 7e4 7e9
1 7eb 1 7ed
3 7cf 7ee 7f3
1 7f5 2 800
805 2 816 818
3 814 815 81a
2 823 825 2
827 829 2 82b
82d 2 82f 831
2 833 835 3
83a 83b 83c 2
837 83e 2 822
840 1 842 1
844 2 80d 845
1 849 1 808
1 84d 2 854
855 2 85a 85b
2 860 861 1
863 2 85d 863
2 86a 86b 2
870 871 1 873
2 86d 873 1
878 a 87e 87f
880 881 882 883
884 885 886 887
2 88c 88d 1
891 2 88f 891
2 895 896 2
89b 89c 1 89e
2 898 89e 2
8a4 8a5 1 8a9
2 8a7 8a9 2
8ae 8af 2 8b4
8b5 2 8b1 8b7
2 8bf 8c0 2
8c5 8c6 2 8cb
8cc 2 8c8 8ce
1 8d1 2 8c2
8d1 2 8d6 8d7
2 8dc 8dd 2
8d9 8df 2 8e5
8e6 2 8e2 8e8
1 900 2 8ff
900 1 908 1
90e 2 910 911
2 8fd 912 2
923 925 3 921
922 927 2 930
932 2 934 936
2 938 93a 2
93c 93e 2 940
942 3 947 948
949 2 944 94b
2 92f 94d 1
94f 1 951 2
91a 952 1 956
1 915 1 95a
2 964 965 2
967 96a 3 8eb
95d 96d 1 982
2 981 982 1
98a 1 990 2
992 993 2 97f
994 2 9a5 9a7
3 9a3 9a4 9a9
2 9b2 9b4 2
9b6 9b8 2 9ba
9bc 2 9be 9c0
2 9c2 9c4 3
9c9 9ca 9cb 2
9c6 9cd 2 9b1
9cf 1 9d1 1
9d3 2 99c 9d4
1 9d8 1 997
1 9dc 1 9df
2 9e2 9e3 3
8ba 8bd 9e4 2
9e7 9e8 2 9ed
9ee 2 9f3 9f4
2 9f0 9f6 1
9f9 2 9ea 9f9
2 9fe 9ff 2
a04 a05 2 a01
a07 1 a0f 2
a11 a12 1 a18
2 a1a a1b 2
a14 a1d 2 a20
a22 2 a25 a27
1 a29 1 a3e
2 a3d a3e 1
a46 1 a4c 2
a4e a4f 2 a3b
a50 2 a61 a63
3 a5f a60 a65
2 a6e a70 2
a72 a74 2 a76
a78 2 a7a a7c
2 a7e a80 3
a85 a86 a87 2
a82 a89 2 a6d
a8b 1 a8d 1
a8f 2 a58 a90
1 a94 1 a53
1 a98 3 a0a
a2c a9b 2 aa0
aa1 2 aa6 aa7
2 aa3 aa9 1
ac3 2 ac2 ac3
1 acb 1 ad1
2 ad3 ad4 2
ac0 ad5 2 ae6
ae8 3 ae4 ae5
aea 2 af3 af5
2 af7 af9 2
afb afd 2 aff
b01 2 b03 b05
3 b0a b0b b0c
2 b07 b0e 2
af2 b10 1 b12
1 b14 2 add
b15 1 b19 1
ad8 1 b1d 3
aac aaf b20 2
b23 b24 1 b25
2 b27 b28 1
b29 2 b2d b2e
2 b33 b34 2
b30 b36 1 b50
2 b4f b50 1
b58 1 b5e 2
b60 b61 2 b4d
b62 2 b73 b75
3 b71 b72 b77
2 b80 b82 2
b84 b86 2 b88
b8a 2 b8c b8e
2 b90 b92 3
b97 b98 b99 2
b94 b9b 2 b7f
b9d 1 b9f 1
ba1 2 b6a ba2
1 ba6 1 b65
1 baa 3 b39
b3c bad 2 bb0
bb1 1 bb3 2
bc3 bc8 2 bd9
bdb 3 bd7 bd8
bdd 2 be6 be8
2 bea bec 2
bee bf0 2 bf2
bf4 2 bf6 bf8
3 bfd bfe bff
2 bfa c01 2
be5 c03 1 c05
1 c07 2 bd0
c08 1 c0c 1
bcb 1 c10 1
c15 2 c1f c24
2 c35 c37 3
c33 c34 c39 2
c42 c44 2 c46
c48 2 c4a c4c
2 c4e c50 2
c52 c54 3 c59
c5a c5b 2 c56
c5d 2 c41 c5f
1 c61 1 c63
2 c2c c64 1
c68 1 c27 1
c6c 3 c74 c75
c76 1 c7a 2
c78 c7a 1 c7f
1 c81 2 c6f
c82 2 c86 c87
1 c8b 2 c89
c8b 2 c93 c94
2 c96 c99 2
ca8 cad 2 cbe
cc0 3 cbc cbd
cc2 2 ccb ccd
2 ccf cd1 2
cd3 cd5 2 cd7
cd9 2 cdb cdd
3 ce2 ce3 ce4
2 cdf ce6 2
cca ce8 1 cea
1 cec 2 cb5
ced 1 cf1 1
cb0 1 cf5 2
c9d cf8 2 d06
d0b 2 d1c d1e
3 d1a d1b d20
2 d29 d2b 2
d2d d2f 2 d31
d33 2 d35 d37
2 d39 d3b 3
d40 d41 d42 2
d3d d44 2 d28
d46 1 d48 1
d4a 2 d13 d4b
1 d4f 1 d0e
1 d53 1 d56
3 d59 cfb d5a
3 bba c13 d5b
1 d5d 1 d5f
3 d66 d67 d68
1 d6b 3 d6e
d6f d70 1 d74
2 d72 d74 3
d79 d7a d7b 1
d7e 3 d82 d83
d84 1 d87 2
d89 d8a 1 d8b
2 d8d d8e 2
d9d d9e 8 d95
d96 d97 d98 d99
d9a d9b da0 2
da5 da6 1 daa
2 da8 daa 2
db8 dba 3 db6
db7 dbc 2 dc5
dc7 2 dc4 dc9
1 dcb 1 dcd
2 dd1 dd2 3
daf dce dd5 1
dd7 7 bb2 d5e
d8f d92 da3 dd8
ddb 1 ddd 3
87b 88a dde 1
de4 2 de6 de7
1 ded 2 def
df0 2 de9 df2
2 df5 df7 2
dfa dfc 1 dfe
1 e01 2 e03
e04 2 e20 e21
18 e08 e09 e0a
e0b e0c e0d e0e
e0f e10 e11 e12
e13 e14 e15 e16
e17 e18 e19 e1a
e1b e1c e1d e1e
e23 2 e32 e34
3 e30 e31 e36
2 e3f e41 2
e3e e43 1 e45
1 e47 2 e4b
e4c 6 868 e05
e26 e29 e48 e4f
2 e53 e54 2
e59 e5a 1 e5c
2 e56 e5c 1
e6d 2 e6c e6d
1 e75 1 e7b
2 e7d e7e 2
e6a e7f 2 e90
e92 3 e8e e8f
e94 2 e9d e9f
2 ea1 ea3 2
ea5 ea7 2 ea9
eab 2 ead eaf
3 eb4 eb5 eb6
2 eb1 eb8 2
e9c eba 1 ebc
1 ebe 2 e87
ebf 1 ec3 1
e82 1 ec7 1
eda 2 ed9 eda
1 ee2 1 ee8
2 eea eeb 2
ed7 eec 2 efd
eff 3 efb efc
f01 2 f0a f0c
2 f0e f10 2
f12 f14 2 f16
f18 2 f1a f1c
3 f21 f22 f23
2 f1e f25 2
f09 f27 1 f29
1 f2b 2 ef4
f2c 1 f30 1
eef 1 f34 2
eca f37 2 f3d
f3e 2 f43 f44
1 f46 2 f40
f46 2 f4a f4b
1 f4f 2 f4d
f4f 1 f54 2
f57 f58 1 f5c
2 f5a f5c 2
f61 f62 1 f66
2 f64 f66 2
f77 f79 3 f75
f76 f7b 2 f84
f86 2 f83 f88
1 f8a 1 f8c
3 f6e f8d f92
1 f94 2 f98
f99 2 f95 f9c
2 f9e f9f 1
fa1 2 fab fb0
2 fc1 fc3 3
fbf fc0 fc5 2
fce fd0 2 fd2
fd4 2 fd6 fd8
2 fda fdc 2
fde fe0 3 fe5
fe6 fe7 2 fe2
fe9 2 fcd feb
1 fed 1 fef
2 fb8 ff0 1
ff4 1 fb3 1
ff8 1 1003 2
fff 1003 2 1008
1009 2 100e 100f
1 1011 2 100b
1011 2 1022 1024
3 1020 1021 1026
2 102f 1031 2
102e 1033 1 1035
1 1037 3 1019
1038 103d 1 103f
2 ffb 1040 1
1042 1 1046 a
104c 104d 104e 104f
1050 1051 1052 1053
1054 1055 2 105a
105b 1 105f 2
105d 105f 1 1063
8 106d 106e 106f
1070 1071 1072 1073
1074 1 1077 1
1079 1 107b 3
1082 1083 1084 1
1087 3 108a 108b
108c 1 1090 2
108e 1090 3 1095
1096 1097 1 109a
3 109e 109f 10a0
1 10a3 2 10a5
10a6 1 10a7 2
10a9 10aa 1 10ac
2 10bb 10c0 2
10d1 10d3 3 10cf
10d0 10d5 2 10de
10e0 2 10e2 10e4
2 10e6 10e8 2
10ea 10ec 2 10ee
10f0 3 10f5 10f6
10f7 2 10f2 10f9
2 10dd 10fb 1
10fd 1 10ff 2
10c8 1100 1 1104
1 10c3 1 1108
2 110f 1110 2
1115 1116 2 1112
1118 2 110b 111b
1 111d 2 112f
1130 8 1127 1128
1129 112a 112b 112c
112d 1132 2 1137
1138 1 113c 2
113a 113c 2 114a
114c 3 1148 1149
114e 2 1157 1159
2 1156 115b 1
115d 1 115f 3
1141 1160 1165 1
117c 2 117b 117c
1 1184 1 118a
2 118c 118d 2
1179 118e 2 119f
11a1 3 119d 119e
11a3 2 11ac 11ae
2 11b0 11b2 2
11b4 11b6 2 11b8
11ba 2 11bc 11be
3 11c3 11c4 11c5
2 11c0 11c7 2
11ab 11c9 1 11cb
1 11cd 2 1196
11ce 1 11d2 1
1191 1 11d6 1
11d9 2 11dc 11dd
b fa0 1043 1049
1058 107a 10ab 111e
1121 1124 1135 11de
3 11e1 f3b 11e0
9 673 676 6cc
765 7c2 7f6 850
858 11e2 2 11e4
11e5 1 11eb 2
11f7 11f9 3 11f5
11f6 11fb 2 1204
1206 2 1208 120a
2 120c 120e 2
1210 1214 2 1203
1216 1 1218 1
121a 8 215 234
237 2d5 11e6 11ee
121b 1220 3c 2a
30 36 3d 44
4b 52 59 5e
63 68 6d 72
77 7e 85 8c
92 98 9e a4
aa b0 b6 bc
c2 c8 ce d4
da e0 e6 ec
f2 f8 fe 104
10a 110 116 11c
122 128 132 13c
143 149 14f 155
15b 161 167 16d
173 179 17f 185
18b 191 197 
1
4
0 
1228
0
1
50
2f
43
0 1 2 1 4 1 6 1
8 1 a 1 c 1 e 1
10 1 12 1 14 1 16 1
18 1 1a 1 1c 1 1e 1
20 1 22 1 24 1 26 1
28 1 2a 1 2c 1 2e 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0

106 1 0
1b 1 0
16f 1 0
11e 1 0
d0 1 0
ee 1 0
6a 1 0
118 1 0
ca 1 0
b2 1 0
112 1 0
b8 1 0
134 1 0
80 1 0
175 1 0
14b 1 0
17b 1 0
3 1 0
26 1 0
151 1 0
12a 1 0
d6 1 0
d 1 0
a6 1 0
fa 1 0
6f 1 0
9a 1 0
87 1 0
a0 1 0
65 1 0
15d 1 0
8e 1 0
9 1 0
e8 1 0
124 1 0
11 1 0
60 1 0
169 1 0
2c 1 0
94 1 0
4d 1 0
38 1 0
ac 1 0
f4 1 0
2 0 1
100 1 0
32 1 0
10c 1 0
79 1 0
74 1 0
157 1 0
c4 1 0
54 1 0
46 1 0
be 1 0
3f 1 0
145 1 0
5b 1 0
181 1 0
187 1 0
dc 1 0
15 1 0
18d 1 0
193 1 0
13e 1 0
e2 1 0
163 1 0
0

/
SHOW ERRORS FUNCTION FC_U_WP_ACTUAL;
ALTER FUNCTION FC_U_WP_ACTUAL COMPILE DEBUG;
/******************************************************************************************************************
update Actual Work, %W, %C in Work Packages
assign_id:      TSK_ASSIGNMENT_ID or TASK_ID
*******************************************************************************************************************/
Prompt == FUNCTION SP_U_WP_ACTUAL ==
CREATE OR REPLACE FUNCTION SP_U_WP_ACTUAL wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
4d
2 :e:
1FUNCTION:
1SP_U_WP_ACTUAL:
1ASSIGN_ID:
1VARCHAR2:
1P_WORK_PERCENT:
1PLS_INTEGER:
1P_ACTUAL:
1P_UNITS:
1RES_ID001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_ASSIGN_ID:
132:
1H_NEW_WORK_PERCENT:
10:
1H_ACTUAL:
1H_UNITS:
1H_REC_USER:
1H_ERROR_ID:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_U_WP_ACTUAL(:
1':
1, :
1COALESCE:
1TO_CHAR:
1NULL:
1);:
1CHECK_TRACE:
11:
128:
1+:
1FPUT:
1               ENTER:: SP_U_WP_ACTUAL(29) :: cplan.sql(15184) :: :
1SC_STATE:
1FC_U_WP_ACTUAL:
14:
143:
1       RETURN_STATUS:: SP_U_WP_ACTUAL(44) :: cplan.sql(15199) :: :
1 :
1STATE:: :
1 ID:: :
1PMODEFINES:
1PMO_RETURN_STATUS:
1TRUE:
1RETURN_ERROR_EXCEPTION:
116:
150:
1           EXCEPTION:: SP_U_WP_ACTUAL(51) :: cplan.sql(15206) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1ID:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
1OTHERS:
1SQLCODE:
162:
1           EXCEPTION:: SP_U_WP_ACTUAL(63) :: cplan.sql(15218) :: :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
1ec
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 :2 a0 6b 1c 81
b0 :2 a0 6b :2 a0 6b 6e a5 b
a 10 :2 a0 6b 6e :2 a0 6b 6e
a5 b 6e 7e a0 b4 2e 6e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :3 a0 a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e :3 a0 a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c a0
4d d :2 a0 d :2 a0 d :2 a0 d
:2 a0 d :2 a0 d :2 a0 6b :7 a0 a5
b d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b :2 a0 a5 57 b7 :2 a0
6b :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 :2 a0 6b :2 6e 7e :2 a0 6b b4
2e 7e 6e b4 2e 7e :2 a0 6b
b4 2e a5 57 b7 19 3c :9 a0
12a e9 dd :2 a0 65 b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c :7 a0 12a e9
dd :2 a0 65 b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 68 4f
1d 17 b5 
1ec
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 5e
5a 30 66 6f 6b 59 77 56
7c 80 84 88 8b 8f ac 97
9b 9e 9f a7 96 c8 b7 bb
93 c3 b6 e4 d3 d7 b3 df
d2 100 ef f3 cf fb ee 11d
10b eb 10f 110 118 10a 13a 128
107 12c 12d 135 127 15a 145 149
124 14d 155 144 161 165 141 169
16d 171 174 179 17a 1 17c 181
185 189 18c 191 195 199 19c 1a1
1a2 1a4 1a9 1ac 1b0 1b1 1b6 1bb
1be 1c3 1c4 1c9 1cc 1d0 1d1 1d6
1d9 1de 1df 1e4 1e7 1ec 1ed 1f2
1f5 1f9 1fd 201 202 204 209 20a
20c 20d 212 215 21a 21b 220 223
227 22b 22f 230 232 237 238 23a
23b 240 243 248 249 24e 251 255
259 25d 25e 260 265 266 268 269
26e 271 276 277 27c 27f 284 285
28a 28d 291 292 297 29a 29f 2a0
2a5 2a8 2ad 2ae 2b3 2b4 2b9 2bb
2bf 2c2 2c6 2ca 2cd 2d1 2d5 2d8
2db 2e0 2e3 2e6 2e9 2ea 2ef 2f0
1 2f2 2f7 2fb 2ff 302 307 30c
30f 313 314 319 31a 31f 321 325
328 32c 32d 331 335 339 33d 341
345 349 34d 351 355 359 35d 361
365 369 36d 371 375 378 37c 380
384 388 38c 390 394 395 397 39b
39f 3a3 3a6 3aa 3ae 3b1 3b4 3b9
3bc 3bf 3c2 3c3 3c8 3c9 1 3cb
3d0 3d4 3d8 3db 3e0 3e5 3e8 3ec
3ed 3f2 3f5 3fa 3fb 400 403 408
409 40e 411 415 419 41d 421 424
425 427 42c 42d 42f 430 435 438
43d 43e 443 446 44b 44c 451 454
458 459 45e 461 466 467 46c 46d
472 474 478 47b 47f 483 486 48a
48e 491 495 499 49a 49f 4a1 4a5
4a9 4ac 4b0 4b4 4b7 4bb 4bf 4c2
4c5 4ca 4cd 4d0 4d3 4d4 4d9 4da
1 4dc 4e1 4e5 4e9 4ec 4f1 4f6
4f9 4fd 4fe 503 504 509 50d 511
514 519 51e 521 525 529 52c 52d
532 535 53a 53b 540 543 547 54b
54e 54f 554 555 55a 55c 560 563
567 56b 56f 573 577 57b 57f 583
587 593 598 59c 5a0 5a4 5a8 5aa
5ab 5b0 1 5b4 5b8 5bc 5bf 5c3
5c7 5cb 5cf 5d2 5d6 5da 5dd 5e0
5e5 5e8 5eb 5ee 5ef 5f4 5f5 1
5f7 5fc 600 604 607 60c 611 614
618 619 61e 61f 624 628 62c 62f
634 639 63c 640 641 646 649 64e
64f 654 657 65b 65f 662 665 666
668 669 66e 66f 674 676 67a 67d
681 685 689 68d 691 695 699 6a5
6aa 6ae 6b2 6b6 6ba 6bc 6c0 6c2
6ce 6d0 6d2 6d3 6d8 6dc 6de 6ea
6ee 6f0 6f1 6fa 
1ec
2
0 1 a 6 10 :3 6 15 :3 6
f :3 6 e :3 6 10 :2 6 1 3
a 13 a :2 1 4 10 19 18
:2 10 :2 4 :2 17 26 17 :2 4 :2 d 1c
d :2 4 :2 c 1b c :2 4 f 18
17 :2 f :2 4 f 18 17 :2 f :2 4
e 17 :3 e 4 7 :2 11 23 :2 2d
3a :2 23 :3 7 :2 d 19 25 :2 2f 43
:2 25 56 5c 5f :2 56 6d 85 8
:2 6d d 10 :2 6d 1a 1d :2 6d b
e :2 6d 13 16 1f 27 :2 1f 38
:2 16 :2 6d b e :2 6d 13 16 1f
27 :2 1f 32 :2 16 :2 6d b e :2 6d
13 16 1f 27 :2 1f 31 :2 16 :2 6d
b e :2 6d 13 16 :2 6d 1b 1e
:2 6d 28 2b :2 6d 30 33 :2 6d :2 7
4c :2 4 7 :2 11 23 :2 2d 39 3c
4e 50 51 :2 4e :2 23 :3 7 :2 d 12
1e 5f 62 :2 1e :2 7 54 :3 4 12
:2 4 13 :2 4 1a :2 4 10 :2 4 f
:2 4 12 :2 4 :2 d 19 28 35 49
53 5c 27 :2 19 4 7 :2 11 23
:2 2d 39 3c 4e 50 51 :2 4e :2 23
:3 7 :2 d 12 1e 5f 62 :2 1e 6f
72 :2 1e 76 79 :2 1e 83 86 8f
97 :2 a0 :2 8f ab :2 86 :2 1e b3 b6
:2 1e be c1 :2 1e c6 c9 :2 1e d4
d7 :2 1e :2 7 54 :3 4 :2 f 21 :2 2a
34 40 :2 4 1 9 12 9 a
:2 14 26 :2 30 3c 40 52 54 55
:2 52 :2 26 :3 a :2 10 15 21 62 65
:2 21 :3 a :2 10 15 39 5c 5f :2 68
:2 39 76 79 :2 39 81 84 :2 8d :2 39
:2 a 58 :3 7 c 15 1e 2c a
13 1e f e 7 e 7 e
7 29 :2 4 :2 9 7 :2 10 1c :2 7
:2 11 23 :2 2d 39 3d 4f 51 52
:2 4f :2 23 :3 7 :2 d 12 1e 5f 62
:2 1e :3 7 :2 d 12 36 42 45 :2 36
4d 50 :2 36 5c 5f 66 6f 72
:2 5f :2 36 :2 7 55 :2 4 7 c 1b
a 13 1e f e 7 e 7
e 7 :2 4 :4 10 :2 4 :8 1 
1ec
4
0 :2 1 :4 3 :4 4
:4 5 :4 6 :4 7 2
:4 8 :2 1 :7 a :6 b
:6 c :6 d :7 e :7 f
:7 11 :b 13 :11 14 15
:2 14 :2 15 :2 14 :2 15
:2 14 :2 16 :2 14 :9 16
:2 14 :2 17 :2 14 :9 17
:2 14 :2 18 :2 14 :9 18
:2 14 :2 19 :2 14 :2 19
:2 14 :2 19 :2 14 :2 19
:2 14 :2 19 :4 14 :3 13
:11 1c :b 1d :3 1c :3 20
:3 22 :3 23 :3 24 :3 25
:3 26 :9 28 29 :3 28
:11 2b :30 2c :3 2b :a 2e
12 :3 31 :11 32 :b 33
:17 34 :3 32 :2 36 :3 37
:3 38 39 37 36
37 :3 3a :3 31 :2 3b
:5 3d :11 3e :b 3f :18 40
:3 3e :2 42 43 :3 44
45 43 42 43
:3 46 :2 3c :6 3b 30
:7 1 
6fc
4
:3 0 1 :3 0 2
:a 0 1e7 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
56 0 7 6
:3 0 5 :7 0 9
8 :3 0 6 :3 0
7 :7 0 d c
:3 0 d :2 0 b
6 :3 0 8 :7 0
11 10 :3 0 4
:3 0 9 :7 0 15
14 :3 0 a :3 0
b :3 0 c :2 0
4 19 1a 0
17 1b 0 1e7
2 1c :2 0 10
:2 0 15 4 :3 0
e :2 0 13 1f
21 :6 0 24 22
0 1e5 0 d
:6 0 10 :2 0 17
6 :3 0 26 :7 0
2a 27 28 1e5
0 f :6 0 10
:2 0 19 6 :3 0
2c :7 0 30 2d
2e 1e5 0 11
:6 0 e :2 0 1b
6 :3 0 32 :7 0
36 33 34 1e5
0 12 :6 0 e
:2 0 1f 4 :3 0
1d 38 3a :6 0
3d 3b 0 1e5
0 13 :6 0 46
47 0 23 4
:3 0 21 3f 41
:6 0 44 42 0
1e5 0 14 :6 0
4c 4d 0 25
b :3 0 c :2 0
4 48 :7 0 4b
49 0 1e5 0
15 :6 0 16 :3 0
17 :3 0 16 :3 0
18 :3 0 4f 50
0 2 :4 0 27
51 53 4e 55
54 :2 0 19 :3 0
1a :3 0 57 58
0 1b :4 0 16
:3 0 1c :3 0 5b
5c 0 2 :4 0
29 5d 5f 1d
:4 0 1e :2 0 1f
:3 0 2b 62 64
:3 0 20 :4 0 1e
:2 0 21 :4 0 2e
67 69 :3 0 1e
:2 0 3 :3 0 31
6b 6d :3 0 1e
:2 0 21 :4 0 34
6f 71 :3 0 1e
:2 0 22 :4 0 37
73 75 :3 0 1e
:2 0 23 :3 0 24
:3 0 5 :3 0 3a
79 7b 25 :4 0
3c 78 7e 3f
77 80 :3 0 1e
:2 0 22 :4 0 42
82 84 :3 0 1e
:2 0 23 :3 0 24
:3 0 7 :3 0 45
88 8a 25 :4 0
47 87 8d 4a
86 8f :3 0 1e
:2 0 22 :4 0 4d
91 93 :3 0 1e
:2 0 23 :3 0 24
:3 0 8 :3 0 50
97 99 25 :4 0
52 96 9c 55
95 9e :3 0 1e
:2 0 22 :4 0 58
a0 a2 :3 0 1e
:2 0 21 :4 0 5b
a4 a6 :3 0 1e
:2 0 9 :3 0 5e
a8 aa :3 0 1e
:2 0 21 :4 0 61
ac ae :3 0 1e
:2 0 26 :4 0 64
b0 b2 :3 0 67
59 b4 :2 0 b6
6c b7 56 b6
0 b8 6e 0
145 16 :3 0 17
:3 0 b9 ba 0
16 :3 0 27 :3 0
bc bd 0 28
:2 0 2 :4 0 29
:2 0 2a :2 0 28
:2 0 70 c2 c4
:3 0 73 be c6
bb c8 c7 :2 0
19 :3 0 2b :3 0
ca cb 0 1b
:4 0 2c :4 0 1e
:2 0 1f :3 0 77
cf d1 :3 0 7a
cc d3 :2 0 d5
7d d6 c9 d5
0 d7 7f 0
145 14 :4 0 d8
d9 0 145 d
:3 0 3 :3 0 db
dc 0 145 f
:3 0 5 :3 0 de
df 0 145 11
:3 0 7 :3 0 e1
e2 0 145 12
:3 0 8 :3 0 e4
e5 0 145 13
:3 0 9 :3 0 e7
e8 0 145 b
:3 0 2d :3 0 ea
eb 0 2e :3 0
d :3 0 f :3 0
11 :3 0 12 :3 0
13 :3 0 14 :3 0
81 ed f4 ec
f5 0 145 16
:3 0 17 :3 0 f7
f8 0 16 :3 0
27 :3 0 fa fb
0 2f :2 0 2
:4 0 30 :2 0 2a
:2 0 28 :2 0 88
100 102 :3 0 8b
fc 104 f9 106
105 :2 0 19 :3 0
2b :3 0 108 109
0 1b :4 0 31
:4 0 1e :2 0 1f
:3 0 8f 10d 10f
:3 0 1e :2 0 32
:4 0 92 111 113
:3 0 1e :2 0 33
:4 0 95 115 117
:3 0 1e :2 0 23
:3 0 24 :3 0 b
:3 0 2d :3 0 11c
11d 0 98 11b
11f 25 :4 0 9a
11a 122 9d 119
124 :3 0 1e :2 0
34 :4 0 a0 126
128 :3 0 1e :2 0
21 :4 0 a3 12a
12c :3 0 1e :2 0
14 :3 0 a6 12e
130 :3 0 1e :2 0
21 :4 0 a9 132
134 :3 0 ac 10a
136 :2 0 138 af
139 107 138 0
13a b1 0 145
35 :3 0 36 :3 0
13b 13c 0 b
:3 0 2d :3 0 13e
13f 0 14 :3 0
37 :3 0 b3 13d
143 :2 0 145 b7
1e6 b :3 0 38
:2 0 4 146 147
0 16 :3 0 17
:3 0 149 14a 0
16 :3 0 27 :3 0
14c 14d 0 39
:2 0 2 :4 0 3a
:2 0 2a :2 0 28
:2 0 c3 152 154
:3 0 c6 14e 156
14b 158 157 :2 0
19 :3 0 2b :3 0
15a 15b 0 1b
:4 0 3b :4 0 1e
:2 0 1f :3 0 ca
15f 161 :3 0 cd
15c 163 :2 0 17c
19 :3 0 2b :3 0
165 166 0 1b
:4 0 3c :4 0 1e
:2 0 b :3 0 3d
:3 0 16b 16c 0
d0 16a 16e :3 0
1e :2 0 34 :4 0
d3 170 172 :3 0
1e :2 0 b :3 0
3e :3 0 175 176
0 d6 174 178
:3 0 d9 167 17a
:2 0 17c dc 17d
159 17c 0 17e
df 0 18e 3f
:3 0 15 :3 0 b
:3 0 3d :3 0 40
:3 0 b :3 0 3e
:3 0 41 :3 0 42
:4 0 43 1 :a 0
18a :2 0 18e 180
188 :2 0 a :3 0
15 :3 0 18c :2 0
18e e1 190 e5
18f 18e :2 0 1e4
44 :3 0 b :3 0
2d :3 0 193 194
0 45 :3 0 195
196 0 1dc 16
:3 0 17 :3 0 198
199 0 16 :3 0
27 :3 0 19b 19c
0 39 :2 0 2
:4 0 46 :2 0 2a
:2 0 28 :2 0 e7
1a1 1a3 :3 0 ea
19d 1a5 19a 1a7
1a6 :2 0 19 :3 0
2b :3 0 1a9 1aa
0 1b :4 0 47
:4 0 1e :2 0 1f
:3 0 ee 1ae 1b0
:3 0 f1 1ab 1b2
:2 0 1cc 19 :3 0
2b :3 0 1b4 1b5
0 1b :4 0 48
:4 0 1e :2 0 45
:3 0 f4 1b9 1bb
:3 0 1e :2 0 49
:4 0 f7 1bd 1bf
:3 0 1e :2 0 4a
:3 0 4b :3 0 28
:2 0 4c :2 0 fa
1c2 1c6 fe 1c1
1c8 :3 0 101 1b6
1ca :2 0 1cc 104
1cd 1a8 1cc 0
1ce 107 0 1dc
3f :3 0 15 :3 0
40 :3 0 b :3 0
3e :3 0 41 :3 0
42 :4 0 4d 1
:a 0 1d8 :2 0 1dc
1d0 1d6 :2 0 a
:3 0 15 :3 0 1da
:2 0 1dc 109 1df
:3 0 1df 0 1df
1de 1dc 1dd :6 0
1e1 1 :3 0 10e
1e3 110 1e2 1e1
:2 0 1e4 112 :2 0
1e6 115 1e6 1e5
145 1e4 :6 0 1e7
:2 0 2 1c 1e6
1ea :3 0 1e9 1e7
1eb :8 0 
11d
4
:3 0 1 3 1
7 1 b 1
f 1 13 5
6 a e 12
16 1 20 1
1e 1 25 1
2b 1 31 1
39 1 37 1
40 1 3e 1
45 1 52 1
5e 2 61 63
2 66 68 2
6a 6c 2 6e
70 2 72 74
1 7a 2 7c
7d 2 76 7f
2 81 83 1
89 2 8b 8c
2 85 8e 2
90 92 1 98
2 9a 9b 2
94 9d 2 9f
a1 2 a3 a5
2 a7 a9 2
ab ad 2 af
b1 4 5a 60
65 b3 1 b5
1 b7 2 c1
c3 3 bf c0
c5 2 ce d0
2 cd d2 1
d4 1 d6 6
ee ef f0 f1
f2 f3 2 ff
101 3 fd fe
103 2 10c 10e
2 110 112 2
114 116 1 11e
2 120 121 2
118 123 2 125
127 2 129 12b
2 12d 12f 2
131 133 2 10b
135 1 137 1
139 3 140 141
142 b b8 d7
da dd e0 e3
e6 e9 f6 13a
144 2 151 153
3 14f 150 155
2 15e 160 2
15d 162 2 169
16d 2 16f 171
2 173 177 2
168 179 2 164
17b 1 17d 3
17e 189 18d 1
148 2 1a0 1a2
3 19e 19f 1a4
2 1ad 1af 2
1ac 1b1 2 1b8
1ba 2 1bc 1be
3 1c3 1c4 1c5
2 1c0 1c7 2
1b7 1c9 2 1b3
1cb 1 1cd 4
197 1ce 1d7 1db
1 1df 1 192
2 190 1e3 7
23 29 2f 35
3c 43 4a 
1
4
0 
1ea
0
1
14
2
d
0 1 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 
3e 1 0
2 0 1
13 1 0
1e 1 0
25 1 0
2b 1 0
3 1 0
31 1 0
f 1 0
7 1 0
b 1 0
37 1 0
45 1 0
0

/
SHOW ERRORS FUNCTION SP_U_WP_ACTUAL;
ALTER FUNCTION SP_U_WP_ACTUAL COMPILE DEBUG;
/******************************************************************************************************************
update resource assignments SECURITY
assign_id:      RES_ASSIGNMENT_ID or TSK_ASSIGNMENT_ID
security_id:    SECURITY_ID in TMT_GLOBAL_SECURITY
*******************************************************************************************************************/
Prompt == FUNCTION SP_U_PARTICIPANT ==
CREATE OR REPLACE FUNCTION SP_U_PARTICIPANT wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
216
2 :e:
1FUNCTION:
1SP_U_PARTICIPANT:
1ASSIGN_ID:
1VARCHAR2:
1SECURITY_ID001:
1P_PLANNED_START:
1TIMESTAMP:
1P_PLANNED_FINISH:
1P_DELAY:
1PLS_INTEGER:
1P_UNITS:
1P_WORK_PERCENT:
1P_ACTUAL:
1RES_ID001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_SECURITY_ID:
132:
1A_ELEMENT_ID:
1A_PARTICIPANT_ID:
1255:
1A_PARTICIPANT_NAME:
1A_SECURITY_NAME:
1H_FULL_NAME:
1A_RES_ASSIGNMENT_ID:
1A_SECURITY_ID:
1A_TEMP_ID:
1H_PRJ_ASSIGN_ID:
1H_CREATED_BY:
1H_PROJECT_ID:
1H_CRI_SECURITY_ID:
1H_ACTUAL_START:
1H_START_DATE:
1H_FINISH_DATE:
1H_SCHED_START:
1H_SCHED_FINISH:
1H_START_DT:
1H_SD:
1DATE:
1H_FD:
1H_WEEK_OF:
1H_BIT_FLAG:
11:
1H_RES_TYPE:
1H_BILLABLE:
10:
1H_CAPITAL_EXPENSE:
1H_TPH_DELETE:
1H_DAYOFYEAR:
1H_LAST_SUBMITTED:
1A_ASSIGNMENT_COUNT:
1A_ELEMENT_TYPE:
1H_RESPONSIBLE:
1A_PARTICIPANT:
1A_RESOURCE_TYPE:
1A_SECURITY_VALUE:
1H_PARTICIPANT:
1H_UPDATE:
1H_TABLE_TYPE:
1H_TRANSFED_CRI:
1H_TASK_ID:
1H_RES_ID:
1H_REC_USER:
1H_EFFORT:
1H_CONTOUR:
1H_DELAY:
1H_PERCENT_UNITS:
1H_WORK_PERCENT:
1H_WORK_TODATE:
1H_NEW_ACTUAL:
1H_WORK:
1H_LAST_DAY:
1H_MINUTES:
1H_TASK_TYPE:
1H_PER_DAY:
1H_WORK_TYPE:
1H_ASSIGN_COUNT:
1H_DURATION:
1H_BITFLAG:
1H_CONSIDER:
1H_EUNIT:
1H_UNIT:
1H_SCHED_EFFORT:
1H_ETC:
1H_ROLLUP_BITS:
1H_CLOSE_TASK:
1H_DAY_MIN:
1H_ASSIGN_STRING:
18192:
1H_TEMP_RES_TYPE:
1H_TEMP_PARTICIPANT:
1H_TEMP_SECURITY_ID:
1H_TEMP_BITFLAG:
1H_TEMP_SC_STATE:
1H_TEMP_VAR:
1H_REG_COST:
1NUMBER:
1H_REG_SALE:
1H_SPEC_COST:
1H_SPEC_SALE:
1H_B_REG_COST:
1H_B_REG_SALE:
1H_B_SPEC_COST:
1H_B_SPEC_SALE:
1STMT:
17999:
1I_RESCHED:
1I_BITFLAG:
1C_P_DELAY:
1C_R_DELAY:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_U_PARTICIPANT(:
1':
1, :
1COALESCE:
1NULLIF:
1'':
1NULL:
1TO_CHAR:
1);:
1CHECK_TRACE:
1120:
1+:
1FPUT:
1               ENTER:: SP_U_PARTICIPANT(121) :: cplan.sql(15360) :: :
1:
1RA:
1RES_ASSIGNMENT_ID:
1PARTICIPANT:
1ELEMENT_ID:
1ELEMENT_TYPE:
1RESOURCE_TYPE:
1CRI_SECURITY_ID:
1RESOURCE_ID:
1PROJECT_ID:
1TABLE_TYPE:
1RESOURCE_ASSIGNMENTS:
1SELECT ra.RES_ASSIGNMENT_ID, ra.PARTICIPANT, ra.ELEMENT_ID, ra.ELEMENT_TYPE,+
1:n      CASE WHEN ra.RESOURCE_TYPE = '0' THEN 0 ELSE 1 END,:n      CASE WHEN +
1ra.CRI_SECURITY_ID IS NuLL THEN 0 ELSE 1 END,:n      ra.RESOURCE_ID,:n      r+
1a.PROJECT_ID, ra.TABLE_TYPE:n      INTO a_res_assignment_id, a_participant, a+
1_element_id, a_element_type,:n      a_resource_type,:n      h_transfed_cri,:n+
1      a_participant_id,:n      h_project_id, h_table_type:n      FROM RESOURC+
1E_ASSIGNMENTS ra:n      WHERE ra.RES_ASSIGNMENT_ID = a_temp_id:
1SC_STATE:
1SQLCODE:
1OTHERS:
116:
1152:
1           EXCEPTION:: SP_U_PARTICIPANT(153) :: cplan.sql(15392) :: :
1 :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1=:
1SC_SQL_NO_DATA:
1PROJECT_ASSIGNMENT_ID:
1BIT_FLAG:
1LAST_SUBMITTED:
1C_CONTOUR:
1C_EFFORT:
1T_UNIT:
1C_UNIT:
1CONTOUR_TYPE:
1ASSIGN_UNITS:
1UNITS_MSP:
1ACTUAL_START:
1WORK_TODATE:
1UNRESOLVED_START:
1UNRESOLVED_FINISH:
1PLANNED_WORK:
1SCHED_WORK:
1ASSIGNMENT_DELAY:
1LAST_SCHED_MIN:
1TO_DATE:
1BILLABLE:
1CAPITAL_EXPENSE:
1REGULAR_COST:
1SPECIAL_COST:
1REGULAR_RATE:
1SPECIAL_RATE:
1B_REGULAR_COST:
1B_SPECIAL_COST:
1B_REGULAR_RATE:
1B_SPECIAL_RATE:
1MILESTONE_PERCENT:
1TASK_ID:
1ROLLUP_BITS:
1TASK_ASSIGNMENTS:
1TSK_ASSIGNMENT_ID:
1SELECT RES_ASSIGNMENT_ID, PROJECT_ASSIGNMENT_ID, PROJECT_ID, RESOURCE_ID,:n  +
1       RESOURCE_TYPE, BIT_FLAG, LAST_SUBMITTED, C_CONTOUR, C_EFFORT, T_UNIT, +
1C_UNIT, CONTOUR_TYPE, :n         CASE WHEN ASSIGN_UNITS > UNITS_MSP THEN ASSI+
1GN_UNITS ELSE UNITS_MSP END, ACTUAL_START, WORK_TODATE, UNRESOLVED_START, UNR+
1ESOLVED_FINISH,:n         CASE WHEN BIT_FLAG = '0' THEN PLANNED_WORK ELSE SCH+
1ED_WORK END, ASSIGNMENT_DELAY,LAST_SCHED_MIN,:n         TO_DATE(SubStr(UNRESO+
1LVED_START, 1, 10)), TO_DATE(SubStr(UNRESOLVED_FINISH, 1, 10)), BILLABLE, CAP+
1ITAL_EXPENSE,:n         REGULAR_COST, SPECIAL_COST, REGULAR_RATE, SPECIAL_RAT+
1E,:n         B_REGULAR_COST, B_SPECIAL_COST, B_REGULAR_RATE, B_SPECIAL_RATE,+
1:n         MILESTONE_PERCENT, TASK_ID, ROLLUP_BITS:n         INTO a_res_assig+
1nment_id, h_prj_assign_id, h_project_id, h_res_id,:n         h_res_type, h_bi+
1t_flag, h_last_submitted, h_contour, h_work, h_eunit, h_unit, h_bitflag,:n   +
1      h_percent_units, h_actual_start, h_work_todate, h_start_date, h_finish_+
1date,:n         h_effort, h_delay, h_last_day,:n         h_SD, h_FD, h_billab+
1le, h_capital_expense,:n         h_reg_cost, h_spec_cost, h_reg_sale, h_spec_+
1sale,:n         h_b_reg_cost, h_b_spec_cost, h_b_reg_sale, h_b_spec_sale,:n  +
1       h_work_percent, h_task_id, h_rollup_bits:n         FROM TASK_ASSIGNMEN+
1TS:n         WHERE TSK_ASSIGNMENT_ID = a_temp_id:
1184:
1           EXCEPTION:: SP_U_PARTICIPANT(185) :: cplan.sql(15424) :: :
1TASK_TYPE:
1MINUTE_PER_DAY:
1START_DT:
1FINISH_DT:
1UNRESOLVED_DURATION:
1ASSIGN_COUNT:
1SD:
1PLANNED_EFFORT:
1SCHED_EFFORT:
1WORK_PERCENT:
1ETC:
1FORECAST_START:
1FORECAST_FINISH:
1TMT_WBS:
1SELECT PROJECT_ID, TASK_TYPE, MINUTE_PER_DAY,/*UNRESOLVED_START, UNRESOLVED_F+
1INISH*/ START_DT, FINISH_DT, UNRESOLVED_DURATION,:n            ASSIGN_COUNT, +
1SD, WORK_TODATE, PLANNED_EFFORT + SCHED_EFFORT, WORK_PERCENT, ETC, COALESCE(F+
1ORECAST_START,FORECAST_FINISH):n            INTO h_project_id, h_task_type, h+
1_per_day, h_start_date, h_finish_date, h_duration,:n            h_assign_coun+
1t, h_work_type, h_work_todate, h_effort, h_work_percent, h_etc, h_start_DT:n +
1           FROM TMT_WBS WHERE ELEMENT_ID = a_temp_id:
1204:
1           EXCEPTION:: SP_U_PARTICIPANT(205) :: cplan.sql(15444) :: :
1212:
1        RETURN_ERROR:: SP_U_PARTICIPANT(213) :: cplan.sql(15452) :: :
1STATE:: :
1PMO_CNST:
1RECORD_NOT_FOUND:
1 ID:: :
1215:
1                EXIT:: SP_U_PARTICIPANT(216) :: cplan.sql(15455) :: :
1PMODEFINES:
1PMO_RETURN_ERROR_SP:
1TRUE:
1PMO_ORASTD:
1STRNCMP:
110:
1>:
1!=:
1225:
1        RETURN_ERROR:: SP_U_PARTICIPANT(226) :: cplan.sql(15465) :: :
1F_DATE_EARLIER_THAN_S_DATE:
1228:
1                EXIT:: SP_U_PARTICIPANT(229) :: cplan.sql(15468) :: :
1IS NOT NULL:
1-:
1240:
1        RETURN_ERROR:: SP_U_PARTICIPANT(241) :: cplan.sql(15480) :: :
1CANNOT_UPDATE_ASSIGN_ACCEPT_RE:
1243:
1                EXIT:: SP_U_PARTICIPANT(244) :: cplan.sql(15483) :: :
1DB2TIMESTAMP:
1DAY_YEAR:
1TIME:
1PMO_STPU:
1FIRST_AVAIL_TIME:
1BIT_SCHED:
1CALENDAR_DAY_OF_YEAR:
1SELECT PMO_ORASTD.DB2TIMESTAMP(DAY_YEAR, PMO_ORASTD.TIME(PMO_STPU.FIRST_AVAIL+
1_TIME(BIT_SCHED))) INTO h_sched_start:n                     FROM CALENDAR_DAY+
1_OF_YEAR:n                     WHERE ELEMENT_ID = h_project_id:n             +
1        AND DAY_YEAR = TO_DATE(SubStr(h_sched_start, 1, 10)):
1264:
1           EXCEPTION:: SP_U_PARTICIPANT(265) :: cplan.sql(15504) :: :
1DUAL:
1SELECT PMO_ORASTD.DB2TIMESTAMP(TO_DATE(SubStr(h_sched_start, 1, 10)), PMO_ORA+
1STD.TIME('08::00')) INTO h_sched_start:n                        FROM DUAL:
1279:
1           EXCEPTION:: SP_U_PARTICIPANT(280) :: cplan.sql(15519) :: :
1LAST_AVAIL_TIME:
1SELECT PMO_ORASTD.DB2TIMESTAMP(DAY_YEAR, PMO_ORASTD.TIME(PMO_STPU.LAST_AVAIL_+
1TIME(BIT_SCHED))) INTO h_sched_finish:n                     FROM CALENDAR_DAY+
1_OF_YEAR:n                     WHERE ELEMENT_ID = h_project_id:n             +
1        AND DAY_YEAR = TO_DATE(SubStr(h_sched_finish, 1, 10)):
1300:
1           EXCEPTION:: SP_U_PARTICIPANT(301) :: cplan.sql(15540) :: :
1SELECT PMO_ORASTD.DB2TIMESTAMP(TO_DATE(SubStr(h_sched_finish, 1, 10)), PMO_OR+
1ASTD.TIME('17::00')) INTO h_sched_finish:n                        FROM DUAL:
1315:
1           EXCEPTION:: SP_U_PARTICIPANT(316) :: cplan.sql(15555) :: :
1SC_SS:
1SCHED_START:
1SCHED_FINISH:
1SCHED_DURATION:
1UPDATE TMT_WBS SET SCHED_START = h_sched_start, SCHED_FINISH = h_sched_finish+
1, SCHED_DURATION = h_duration:n                     WHERE ELEMENT_ID = a_temp+
1_id:
1FOUND:
1100:
1338:
1           EXCEPTION:: SP_U_PARTICIPANT(339) :: cplan.sql(15578) :: :
1PLANNED_START:
1PLANNED_FINISH:
1PLANNED_DURATION:
1UPDATE TMT_WBS SET PLANNED_START = h_sched_start, PLANNED_FINISH = h_sched_fi+
1nish, PLANNED_DURATION = h_duration:n                     WHERE ELEMENT_ID = +
1a_temp_id:
1356:
1           EXCEPTION:: SP_U_PARTICIPANT(357) :: cplan.sql(15596) :: :
1SC_SQL_SUCCESS:
1FC_ROLLUP:
1COUNT:
1SELECT COUNT('X') INTO h_temp_var FROM DUAL WHERE EXISTS (:n                 +
1 SELECT 'X' FROM TASK_ASSIGNMENTS:n                  WHERE PROJECT_ID = h_pro+
1ject_id AND TASK_ID = a_temp_id:n                  AND ACTUAL_START IS NOT Nu+
1LL):
1377:
1           EXCEPTION:: SP_U_PARTICIPANT(378) :: cplan.sql(15617) :: :
1385:
1        RETURN_ERROR:: SP_U_PARTICIPANT(386) :: cplan.sql(15625) :: :
1CANNOT_UPDATE_HAS_ACTUAL:
1388:
1                EXIT:: SP_U_PARTICIPANT(389) :: cplan.sql(15628) :: :
1406:
1           EXCEPTION:: SP_U_PARTICIPANT(407) :: cplan.sql(15646) :: :
1421:
1           EXCEPTION:: SP_U_PARTICIPANT(422) :: cplan.sql(15661) :: :
1438:
1           EXCEPTION:: SP_U_PARTICIPANT(439) :: cplan.sql(15678) :: :
1453:
1           EXCEPTION:: SP_U_PARTICIPANT(454) :: cplan.sql(15693) :: :
1FC_CHANGE_TA_DATES:
1468:
1        RETURN_ERROR:: SP_U_PARTICIPANT(469) :: cplan.sql(15708) :: :
1471:
1                EXIT:: SP_U_PARTICIPANT(472) :: cplan.sql(15711) :: :
1ELSIF:
18:
1480:
1      RETURN_INVALID:: SP_U_PARTICIPANT(481) :: cplan.sql(15720) :: :
1SC_TASK_ACTUAL_GRATER_THAN_SCH:
1483:
1                EXIT:: SP_U_PARTICIPANT(484) :: cplan.sql(15723) :: :
1PMO_RETURN_INVALID_SP:
1A:
1TA:
1ACTIVITIES:
1TYPE_ID:
1SC_TIMESHEET_ACTIVITY:
1SELECT COUNT('X') INTO h_temp_var:n               FROM DUAL:n               W+
1HERE EXISTS(SELECT A.ELEMENT_ID FROM TASK_ASSIGNMENTS TA, ACTIVITIES A:n     +
1          WHERE TA.TASK_ID = a_temp_id:n               AND TA.TSK_ASSIGNMENT_+
1ID = A.TSK_ASSIGNMENT_ID:n               AND A.TSK_ASSIGNMENT_ID <> A.ELEMENT+
1_ID:n               AND A.TYPE_ID = PMO_CNST.SC_TIMESHEET_ACTIVITY):
1506:
1           EXCEPTION:: SP_U_PARTICIPANT(507) :: cplan.sql(15746) :: :
1513:
1        RETURN_ERROR:: SP_U_PARTICIPANT(514) :: cplan.sql(15753) :: :
1SC_TIMESHEET_STEP_EXISTS:
1516:
1                EXIT:: SP_U_PARTICIPANT(517) :: cplan.sql(15756) :: :
1JOIN:
1TIMESHEET_APPROVAL_STATUS:
1APV:
1WEEK_OF:
1SELECT COUNT('X') INTO h_temp_var FROM DUAL WHERE EXISTS (:n               SE+
1LECT 'X' FROM TASK_ASSIGNMENTS ta JOIN TIMESHEET_APPROVAL_STATUS apv:n       +
1        ON apv.ELEMENT_ID = ta.PROJECT_ID AND apv.RESOURCE_ID = ta.RESOURCE_I+
1D:n               WHERE ta.PROJECT_ID = h_project_id AND ta.TASK_ID = a_temp_+
1id AND:n               (TO_DATE(SubStr(ta.ACTUAL_START, 1, 10)) - 7     ) <= +
1apv.WEEK_OF):
1535:
1           EXCEPTION:: SP_U_PARTICIPANT(536) :: cplan.sql(15775) :: :
1543:
1        RETURN_ERROR:: SP_U_PARTICIPANT(544) :: cplan.sql(15783) :: :
1TS_APPROVAL_ERROR:
1546:
1                EXIT:: SP_U_PARTICIPANT(547) :: cplan.sql(15786) :: :
1FC_U_TASK_PERCENT:
1567:
1        RETURN_ERROR:: SP_U_PARTICIPANT(568) :: cplan.sql(15807) :: :
1570:
1                EXIT:: SP_U_PARTICIPANT(571) :: cplan.sql(15810) :: :
1580:
1        RETURN_ERROR:: SP_U_PARTICIPANT(581) :: cplan.sql(15820) :: :
1583:
1                EXIT:: SP_U_PARTICIPANT(584) :: cplan.sql(15823) :: :
1SELECT PROJECT_ID, TASK_TYPE, MINUTE_PER_DAY:n            INTO h_project_id, +
1h_task_type, h_per_day:n            FROM TMT_WBS WHERE PROJECT_ID = h_project+
1_id AND ELEMENT_ID = h_task_id:
1599:
1           EXCEPTION:: SP_U_PARTICIPANT(600) :: cplan.sql(15839) :: :
1SELECT TASK_TYPE, MINUTE_PER_DAY INTO h_task_type, h_per_day:n               +
1   FROM TMT_WBS:n                  WHERE PROJECT_ID = h_project_id AND ELEMEN+
1T_ID = h_task_id:
1633:
1           EXCEPTION:: SP_U_PARTICIPANT(634) :: cplan.sql(15873) :: :
1SELECT PMO_ORASTD.DB2TIMESTAMP(TO_DATE(SubStr(h_sched_finish, 1, 10)), PMO_OR+
1ASTD.TIME(h_finish_date)):n                  INTO h_sched_finish:n           +
1       FROM DUAL:
1732:
1           EXCEPTION:: SP_U_PARTICIPANT(733) :: cplan.sql(15972) :: :
1STRCMP:
1FC_TPHASE_SCHED_ASSIGN:
1TASK_DAY_OF_YEAR:
1SCHED_MIN:
1ACTUAL_MIN:
1UPDATE TASK_DAY_OF_YEAR SET SCHED_MIN = ACTUAL_MIN:n                     WHER+
1E PROJECT_ID = h_project_id AND TSK_ASSIGNMENT_ID = a_temp_id AND DAY_YEAR = +
1TO_DATE(SubStr(h_last_submitted, 1, 10)):
1757:
1           EXCEPTION:: SP_U_PARTICIPANT(758) :: cplan.sql(15997) :: :
12:
1FC_FD_CTD_TDY:
1SELECT TO_DATE(SubStr(h_start_date, 1, 10)), TO_DATE(SubStr(h_sched_finish, 1+
1, 10)), BILLABLE, CAPITAL_EXPENSE, REGULAR_COST, REGULAR_RATE:n              +
1    INTO h_SD, h_FD, h_billable, h_capital_expense, h_reg_cost, h_reg_sale:n +
1                 FROM TASK_ASSIGNMENTS:n                  WHERE TSK_ASSIGNMEN+
1T_ID = a_temp_id:
1784:
1           EXCEPTION:: SP_U_PARTICIPANT(785) :: cplan.sql(16024) :: :
14:
1797:
1       RETURN_STATUS:: SP_U_PARTICIPANT(798) :: cplan.sql(16037) :: :
1PMO_RETURN_STATUS:
1<:
1SELECT START_DT INTO h_start_date:n                  FROM TMT_WBS:n          +
1        WHERE ELEMENT_ID = h_task_id:
1817:
1           EXCEPTION:: SP_U_PARTICIPANT(818) :: cplan.sql(16057) :: :
1SELECT * FROM (SELECT DAY_YEAR FROM CALENDAR_DAY_OF_YEAR :
1WHERE ELEMENT_ID = ':
1' AND DAY_YEAR < TO_DATE(SubStr(':
1', 1, 10)) :
1ORDER BY DAY_YEAR DESC) WHERE ROWNUM<=:
1OPEN:
1LOOP:
1EXIT:
1CLOSE:
1873:
1           EXCEPTION:: SP_U_PARTICIPANT(874) :: cplan.sql(16113) :: :
1886:
1           EXCEPTION:: SP_U_PARTICIPANT(887) :: cplan.sql(16126) :: :
1IS NULL:
1896:
1        RETURN_ERROR:: SP_U_PARTICIPANT(897) :: cplan.sql(16136) :: :
1899:
1                EXIT:: SP_U_PARTICIPANT(900) :: cplan.sql(16139) :: :
1904:
1        RETURN_ERROR:: SP_U_PARTICIPANT(905) :: cplan.sql(16144) :: :
1907:
1                EXIT:: SP_U_PARTICIPANT(908) :: cplan.sql(16147) :: :
1SELECT PMO_ORASTD.DB2TIMESTAMP(TO_DATE(SubStr(h_dayofyear, 1, 10)), PMO_ORAST+
1D.TIME(h_start_date)):n                  INTO h_start_date:n                 +
1 FROM DUAL:
1923:
1           EXCEPTION:: SP_U_PARTICIPANT(924) :: cplan.sql(16163) :: :
1934:
1        RETURN_ERROR:: SP_U_PARTICIPANT(935) :: cplan.sql(16174) :: :
1937:
1                EXIT:: SP_U_PARTICIPANT(938) :: cplan.sql(16177) :: :
1103079040:
1947:
1      RETURN_INVALID:: SP_U_PARTICIPANT(948) :: cplan.sql(16187) :: :
1INVALID_PARAMS:
1950:
1                EXIT:: SP_U_PARTICIPANT(951) :: cplan.sql(16190) :: :
1SELECT UNITS_MSP INTO h_temp_var:n                  FROM TASK_ASSIGNMENTS:n  +
1                WHERE TSK_ASSIGNMENT_ID = h_prj_assign_id:
1982:
1           EXCEPTION:: SP_U_PARTICIPANT(983) :: cplan.sql(16222) :: :
1990:
1        RETURN_ERROR:: SP_U_PARTICIPANT(991) :: cplan.sql(16230) :: :
1TASK_ASSIGNMENT_ERROR:
1993:
1                EXIT:: SP_U_PARTICIPANT(994) :: cplan.sql(16233) :: :
190:
1CONSIDER:
1BIT_OR:
1SC_SCHED_BIT:
1SC_PLANNED_BIT:
1UPDATE TASK_ASSIGNMENTS SET CONSIDER = 7, UNITS_MSP = h_percent_units,:n     +
1          C_EFFORT = 0, C_UNIT = 0, C_CONTOUR = 0, CONTOUR_TYPE = 1,:n       +
1        ROLLUP_BITS = PMO_STPU.BIT_OR(ROLLUP_BITS,(PMO_CNST.SC_SCHED_BIT+PMO_+
1CNST.SC_PLANNED_BIT)):n               WHERE TSK_ASSIGNMENT_ID = a_temp_id:
11081:
1           EXCEPTION:: SP_U_PARTICIPANT(1082) :: cplan.sql(16321) :: :
1FC_U_TDY_LAST_ACTUAL:
1FC_DEL_NOACTUAL:
1PMO_FUNC:
1SC_BIT_30:
1SELECT PMO_ORASTD.DB2TIMESTAMP(TO_DATE(SubStr(h_last_submitted, 1, 10)), PMO_+
1ORASTD.TIME(h_start_date)):n                     INTO h_start_date:n         +
1            FROM DUAL:
11129:
1           EXCEPTION:: SP_U_PARTICIPANT(1130) :: cplan.sql(16369) :: :
1SELECT PMO_ORASTD.DB2TIMESTAMP(TO_DATE(SubStr(h_last_submitted, 1, 10)), PMO_+
1ORASTD.TIME(h_start_date)) + 1     :n                     INTO h_start_date:n+
1                     FROM DUAL:
11144:
1           EXCEPTION:: SP_U_PARTICIPANT(1145) :: cplan.sql(16384) :: :
1FC_RESCHEDULE:
11162:
1        RETURN_ERROR:: SP_U_PARTICIPANT(1163) :: cplan.sql(16402) :: :
11165:
1                EXIT:: SP_U_PARTICIPANT(1166) :: cplan.sql(16405) :: :
1BAK_START_DT:
1BAK_FINISH_DT:
1BAK_ASSIGN_STRING:
1ASSIGN_STRING:
1UPDATE TASK_ASSIGNMENTS SET CONSIDER = 7, ROLLUP_BITS = PMO_STPU.BIT_OR(ROLLU+
1P_BITS,(PMO_CNST.SC_SCHED_BIT+PMO_CNST.SC_PLANNED_BIT)),:n                  B+
1AK_START_DT = COALESCE(SCHED_START,PLANNED_START), BAK_FINISH_DT = COALESCE(S+
1CHED_FINISH,PLANNED_FINISH),:n                  BAK_ASSIGN_STRING = ASSIGN_ST+
1RING:n                  WHERE TSK_ASSIGNMENT_ID = a_temp_id:
11184:
1           EXCEPTION:: SP_U_PARTICIPANT(1185) :: cplan.sql(16424) :: :
11192:
1        RETURN_ERROR:: SP_U_PARTICIPANT(1193) :: cplan.sql(16432) :: :
11195:
1                EXIT:: SP_U_PARTICIPANT(1196) :: cplan.sql(16435) :: :
1SELECT COUNT('X') INTO h_temp_var:n               FROM DUAL:n               W+
1HERE EXISTS(SELECT ELEMENT_ID FROM ACTIVITIES:n               WHERE TSK_ASSIG+
1NMENT_ID = a_temp_id:n               AND TSK_ASSIGNMENT_ID <> ELEMENT_ID:n   +
1            AND TYPE_ID = PMO_CNST.SC_TIMESHEET_ACTIVITY):
11215:
1           EXCEPTION:: SP_U_PARTICIPANT(1216) :: cplan.sql(16455) :: :
11222:
1        RETURN_ERROR:: SP_U_PARTICIPANT(1223) :: cplan.sql(16462) :: :
11225:
1                EXIT:: SP_U_PARTICIPANT(1226) :: cplan.sql(16465) :: :
1SELECT PMO_ORASTD.DB2TIMESTAMP(TO_DATE(SubStr(h_last_submitted, 1, 10)), PMO_+
1ORASTD.TIME(h_start_date)):n                        INTO h_start_date:n      +
1                  FROM DUAL:
11263:
1           EXCEPTION:: SP_U_PARTICIPANT(1264) :: cplan.sql(16503) :: :
1SELECT PMO_ORASTD.DB2TIMESTAMP(TO_DATE(SubStr(h_last_submitted, 1, 10)), PMO_+
1ORASTD.TIME(h_start_date)) + 1     :n                        INTO h_start_dat+
1e:n                        FROM DUAL:
11278:
1           EXCEPTION:: SP_U_PARTICIPANT(1279) :: cplan.sql(16518) :: :
1SELECT SCHED_MIN - ACTUAL_MIN INTO h_minutes:n                        FROM TA+
1SK_DAY_OF_YEAR :n                        WHERE PROJECT_ID = h_project_id AND +
1TSK_ASSIGNMENT_ID = a_temp_id AND DAY_YEAR = TO_DATE(SubStr(h_last_submitted,+
1 1, 10)):
11295:
1           EXCEPTION:: SP_U_PARTICIPANT(1296) :: cplan.sql(16535) :: :
110000:
1FORECAST_DURATION:
1UPDATE TASK_ASSIGNMENTS SET CONSIDER = 7, ROLLUP_BITS = PMO_STPU.BIT_OR(ROLLU+
1P_BITS,PMO_CNST.SC_SCHED_BIT),:n                  SCHED_WORK = h_new_actual, +
1WORK_TODATE = h_new_actual, ETC = 0, MILESTONE_PERCENT = 10000,:n            +
1      FORECAST_START = NuLL, FORECAST_FINISH = NuLL, FORECAST_DURATION = 0:n +
1                 WHERE TSK_ASSIGNMENT_ID = a_temp_id:
11321:
1           EXCEPTION:: SP_U_PARTICIPANT(1322) :: cplan.sql(16561) :: :
11335:
1        RETURN_ERROR:: SP_U_PARTICIPANT(1336) :: cplan.sql(16575) :: :
11338:
1                EXIT:: SP_U_PARTICIPANT(1339) :: cplan.sql(16578) :: :
1TRUNC:
1TO_NUMBER:
1/:
1*:
110000.00:
10.4:
1FC_U_ASSIGN_PERCENT:
11361:
1        RETURN_ERROR:: SP_U_PARTICIPANT(1362) :: cplan.sql(16601) :: :
11364:
1                EXIT:: SP_U_PARTICIPANT(1365) :: cplan.sql(16604) :: :
11370:
1        RETURN_ERROR:: SP_U_PARTICIPANT(1371) :: cplan.sql(16610) :: :
11373:
1                EXIT:: SP_U_PARTICIPANT(1374) :: cplan.sql(16613) :: :
1SC_PERCENT_COMPLETE_BIT:
1UPDATE TASK_ASSIGNMENTS SET MILESTONE_PERCENT = p_work_percent,:n            +
1   ROLLUP_BITS = PMO_STPU.BIT_OR(ROLLUP_BITS,PMO_CNST.SC_PERCENT_COMPLETE_BIT+
1):n               WHERE TSK_ASSIGNMENT_ID = a_temp_id:
11425:
1           EXCEPTION:: SP_U_PARTICIPANT(1426) :: cplan.sql(16665) :: :
1UPDATE TMT_WBS SET ROLLUP_BITS = PMO_STPU.BIT_OR(ROLLUP_BITS,PMO_CNST.SC_PERC+
1ENT_COMPLETE_BIT):n               WHERE PROJECT_ID = h_project_id AND ELEMENT+
1_ID = h_task_id:
11447:
1           EXCEPTION:: SP_U_PARTICIPANT(1448) :: cplan.sql(16687) :: :
11457:
1        RETURN_ERROR:: SP_U_PARTICIPANT(1458) :: cplan.sql(16697) :: :
11460:
1                EXIT:: SP_U_PARTICIPANT(1461) :: cplan.sql(16700) :: :
1SECURITY_ID:
1SELECT ra.SECURITY_ID, ra.PARTICIPANT, ra.ELEMENT_ID, ra.ELEMENT_TYPE,:n     +
1       CASE WHEN ra.RESOURCE_TYPE = '0' THEN 0 ELSE 1 END,:n            CASE +
1WHEN ra.CRI_SECURITY_ID IS NuLL THEN 0 ELSE 1 END,:n            ra.RESOURCE_I+
1D,:n            ra.PROJECT_ID, ra.TABLE_TYPE:n            INTO h_security_id,+
1 a_participant, a_element_id, a_element_type,:n            a_resource_type,:n+
1            h_transfed_cri,:n            a_participant_id,:n            h_pro+
1ject_id, h_table_type:n            FROM RESOURCE_ASSIGNMENTS ra WHERE ra.RES_+
1ASSIGNMENT_ID = a_res_assignment_id:
11482:
1           EXCEPTION:: SP_U_PARTICIPANT(1483) :: cplan.sql(16722) :: :
1NOT:
11490:
1        RETURN_ERROR:: SP_U_PARTICIPANT(1491) :: cplan.sql(16730) :: :
11493:
1                EXIT:: SP_U_PARTICIPANT(1494) :: cplan.sql(16733) :: :
11502:
1        RETURN_ERROR:: SP_U_PARTICIPANT(1503) :: cplan.sql(16742) :: :
11505:
1                EXIT:: SP_U_PARTICIPANT(1506) :: cplan.sql(16745) :: :
1SC_TABLE_WBS:
1FC_U_ASSIGNED_SECURITY:
11520:
1       RETURN_STATUS:: SP_U_PARTICIPANT(1521) :: cplan.sql(16760) :: :
1RETURN_ERROR_EXCEPTION:
11527:
1           EXCEPTION:: SP_U_PARTICIPANT(1528) :: cplan.sql(16767) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1ERROR:
1ID:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
11539:
1           EXCEPTION:: SP_U_PARTICIPANT(1540) :: cplan.sql(16779) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
24cd
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 1c 81 b0 a3 a0 1c 81
b0 a3 a0 1c 81 b0 a3 a0
1c 81 b0 a3 a0 1c 81 b0
a3 a0 1c 81 b0 a3 a0 1c
81 b0 a3 a0 1c 81 b0 a3
a0 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 81
b0 a3 a0 1c 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 1c
51 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 1c 81 b0
a3 a0 1c 81 b0 a3 :2 a0 6b
1c 81 b0 a3 :2 a0 6b 1c 81
b0 a3 :2 a0 6b 1c 81 b0 :2 a0
6b :2 a0 6b 6e a5 b a 10
:2 a0 6b 6e :2 a0 6b 6e a5 b
6e 7e a0 b4 2e 6e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :2 a0
6e 7e a0 b4 2e 7e 6e b4
2e 6e a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e :2 a0 6e
7e a0 b4 2e 7e 6e b4 2e
6e a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e :3 a0 a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e :3 a0 a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e :3 a0
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e :3 a0 a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
a0 51 d a0 6e d :2 a0 d
:2 a0 d :2 a0 d :20 a0 12a :2 a0 6b
a0 d b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
6b a0 7e a0 6b b4 2e 5a
:52 a0 12a :2 a0 6b a0 d b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 6b a0 7e a0
6b b4 2e 5a :20 a0 12a :2 a0 6b
a0 d b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
6b a0 7e a0 6b b4 2e 5a
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b :2 a0 a5 57 b7
19 3c :2 a0 d :2 a0 d :2 a0 6b
:2 a0 51 a5 b 7e 51 b4 2e
5a :2 a0 6b :2 a0 51 a5 b 7e
51 b4 2e 5a a 10 :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b :2 a0 a5 57 b7 19 3c
a0 7e b4 2e :2 5a :2 a0 51 a5
b 7e :2 a0 51 a5 b b4 2e
5a a0 7e a0 51 a5 b b4
2e 5a 52 10 :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :4 a0 6b a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
:2 a0 a5 57 b7 19 3c :2 a0 6b
:2 a0 51 a5 b 7e 51 b4 2e
5a :2 a0 6b :2 a0 51 a5 b 7e
51 b4 2e 5a 52 10 :2 a0 51
a5 b 7e 51 b4 2e :2 a0 6b
:2 a0 51 a5 b 7e 51 b4 2e
:10 a0 12a :2 a0 6b a0 d b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 6b a0 7e a0
6b b4 2e 5a :9 a0 12a :2 a0 6b
a0 d b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
19 3c :2 a0 6b :2 a0 51 a5 b
7e 51 b4 2e a0 4d d b7
19 3c b7 :10 a0 12a :2 a0 6b a0
d b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
a0 7e a0 6b b4 2e 5a :9 a0
12a :2 a0 6b a0 d b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 19 3c a0 51 d
b7 :2 19 3c :2 a0 51 a5 b a0
7e a0 6b b4 2e :9 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 :9 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 :2 19 3c :2 a0 6b a0 7e a0
6b b4 2e 5a :3 a0 a5 b d
b7 19 3c b7 :9 a0 12a :2 a0 6b
a0 d b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
51 a5 b 7e 51 b4 2e :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b :2 a0 a5 57 b7 19
3c :2 a0 6b :2 a0 51 a5 b 7e
51 b4 2e :10 a0 12a :2 a0 6b a0
d b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
a0 7e a0 6b b4 2e 5a :9 a0
12a :2 a0 6b a0 d b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 19 3c b7 :10 a0 12a
:2 a0 6b a0 d b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6b a0 7e a0 6b b4
2e 5a :9 a0 12a :2 a0 6b a0 d
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 19 3c
b7 :2 19 3c :c a0 51 a5 b 51
a5 b d :2 a0 51 a5 b 7e
51 b4 2e :3 a0 a5 b d b7
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :3 a0
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 51 a5 b :2 a0 a5 57
b7 :2 19 3c b7 :2 19 3c a0 b7
:2 a0 51 a5 b a0 7e a0 51
a5 b b4 2e 5a :2 a0 51 a5
b 7e 51 b4 2e 5a a 10
a0 51 d :2 a0 51 a5 b a0
7e a0 51 a5 b b4 2e :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b a0 a5 57 a0 b7
:2 a0 51 a5 b a0 7e a0 51
a5 b b4 2e a0 51 d b7
:2 19 3c a0 51 d :18 a0 12a :2 a0
6b a0 d b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 51 a5 b 7e 51 b4 2e
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b :2 a0 a5 57 b7
19 3c :1c a0 12a :2 a0 6b a0 d
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 51 a5
b 7e 51 b4 2e :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b :2 a0 a5 57 b7 19 3c :2 a0
d :8 a0 51 a5 b a5 b d
b7 :2 19 3c :2 a0 51 a5 b 7e
51 b4 2e :3 a0 a5 b d b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :3 a0 a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 51 a5 b :2 a0
a5 57 a0 b7 a0 7e b4 2e
5a a0 7e b4 2e 5a a 10
:2 a0 d :2 a0 d :2 a0 6b :2 a0 51
a5 b 7e 51 b4 2e 5a :2 a0
6b :2 a0 51 a5 b 7e 51 b4
2e 5a a 10 :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :4 a0 6b a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
:2 a0 a5 57 b7 19 3c :b a0 12a
:2 a0 6b a0 d b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 :2 51 a5 b 7e 6e b4
2e a0 51 d b7 a0 51 d
b7 :2 19 3c a0 51 d a0 51
d :2 a0 6b :2 a0 51 a5 b 7e
51 b4 2e 5a :2 a0 6b :2 a0 51
a5 b 7e 51 b4 2e 5a 52
10 :2 a0 51 a5 b a0 7e a0
51 a5 b b4 2e 5a 52 10
:2 a0 6b :2 a0 51 a5 b 7e 51
b4 2e :9 a0 12a :2 a0 6b a0 d
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 d a0
51 d a0 51 d a0 b7 :2 a0
6b :2 a0 51 a5 b 7e 51 b4
2e :a a0 12a :2 a0 6b a0 d b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :3 a0 6b :2 a0 a5
b d a0 7e 51 b4 2e d
:c a0 a5 b d :2 a0 51 a5 b
7e 51 b4 2e 5a a0 7e b4
2e :2 5a a 10 :b a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 19 3c
:2 a0 :2 51 a5 b 7e 6e b4 2e
a0 51 d b7 a0 51 d b7
:2 19 3c :f a0 51 a0 51 a5 b
d :13 a0 12a :2 a0 6b a0 d b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f a0 51 d :c a0
a5 b d :3 a0 a5 b d :2 a0
6b 51 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b :2 a0 a5 57 a0
b7 19 :2 a0 51 a5 b a0 7e
a0 51 a5 b b4 2e :3 a0 51
a5 b 7e :2 a0 51 a5 b b4
2e d a0 51 d a0 b7 19
:2 a0 51 a5 b 7e 51 b4 2e
a0 51 d a0 51 d :5 a0 12a
:2 a0 6b a0 d b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f a0 b7 19 :2 a0 51 a5 b
a0 7e a0 51 a5 b b4 2e
:3 a0 51 a5 b 7e :2 a0 51 a5
b b4 2e d a0 4d d a0
6e d :2 a0 51 a5 b 7e 51
b4 2e a0 6e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :3 a0 51 a5
b a5 b b4 2e d :3 a0 11c
11d b7 a0 6e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :3 a0 51 a5
b a5 b b4 2e d :3 a0 11c
11d b7 :2 19 3c :3 a0 51 a5 b
7e 51 b4 2e :2 a0 e9 d3 :2 a0
f :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :2 a0 e9
d3 :2 a0 f :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:2 19 3c :2 a0 6b a0 7e a0 6b
b4 2e 5a a0 2b b7 19 3c
b7 a0 47 :2 a0 51 a5 b 7e
51 b4 2e :2 a0 e9 c1 :2 a0 6b
a0 d b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
:2 a0 e9 c1 :2 a0 6b a0 d b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 :2 19 3c a0
7e b4 2e 5a :2 a0 51 a5 b
7e 51 b4 2e :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :4 a0 6b a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
:2 a0 a5 57 b7 :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :4 a0 6b a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
:2 a0 a5 57 b7 :2 19 3c b7 19
3c :a a0 12a :2 a0 6b a0 d b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f a0 51 d a0
51 d b7 :2 19 3c a0 b7 :2 a0
51 a5 b a0 7e a0 51 a5
b b4 2e :2 a0 51 a5 b a0
7e a0 51 a5 b b4 2e :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b :2 a0 a5 57 b7 19
3c :2 a0 51 a5 b 7e 51 b4
2e a0 51 d b7 :2 a0 51 a5
b 7e 51 b4 2e 5a :2 a0 51
a5 b 7e 51 b4 2e 5a 52
10 :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b a0 a5 57
b7 19 3c :2 a0 d b7 :2 19 3c
a0 7e b4 2e 5a :5 a0 12a :2 a0
6b a0 d b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 6b a0 7e a0 6b b4 2e
5a :2 a0 51 a5 b a0 7e a0
51 a5 b b4 2e 5a a 10
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b :2 a0 a5 57 b7
19 3c b7 19 3c a0 51 d
a0 51 d :2 a0 51 a5 b 7e
51 b4 2e a0 51 d b7 19
3c :12 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 51 a5 b 7e 51
b4 2e a0 51 d b7 19 3c
b7 :2 19 3c a0 7e 51 b4 2e
a0 7e 51 b4 2e d :c a0 a5
b d :2 a0 51 a5 b 7e 51
b4 2e 5a a0 7e b4 2e :2 5a
a 10 :9 a0 51 a5 b d b7
19 3c a0 7e b4 2e 5a :4 a0
51 a5 b d b7 :2 a0 :2 51 a5
b 7e 6e b4 2e :4 a0 51 a5
b d b7 :4 a0 51 a5 b d
b7 :2 19 3c b7 :2 19 3c a0 7e
b4 2e 5a :2 a0 51 a5 b 7e
51 b4 2e :3 a0 6b :2 a0 51 a5
b :2 a0 6b a5 b 5a d :a a0
12a :2 a0 6b a0 d b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 :a a0 12a :2 a0 6b a0
d b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 :2 19
3c :3 a0 51 a5 b 7e :2 a0 51
a5 b b4 2e d b7 19 3c
a0 51 d :a a0 51 a5 b :2 a0
51 a5 b a5 b d :2 a0 51
a5 b 7e 51 b4 2e :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b :2 a0 a5 57 a0 b7 a0
7e 51 b4 2e :16 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 :2 19 3c
:3 a0 a5 b d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 51 a5
b :2 a0 a5 57 b7 19 3c :2 a0
51 a5 b a0 7e a0 51 a5
b b4 2e :c a0 12a :2 a0 6b a0
d b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 51
a5 b 7e 51 b4 2e :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b :2 a0 a5 57 b7 19 3c
:2 a0 d :3 a0 51 a5 b d :2 a0
51 a5 b a0 7e a0 51 a5
b b4 2e a0 7e 51 b4 2e
d :c a0 a5 b d a0 7e b4
2e 5a :4 a0 51 a5 b d b7
:2 a0 :2 51 a5 b 7e 6e b4 2e
:4 a0 51 a5 b d b7 :4 a0 51
a5 b d b7 :2 19 3c b7 :2 19
3c a0 51 d a0 7e b4 2e
5a :2 a0 51 a5 b 7e 51 b4
2e :3 a0 6b :2 a0 51 a5 b :2 a0
6b a5 b 5a d :a a0 12a :2 a0
6b a0 d b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 :a a0 12a :2 a0 6b a0 d b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 :2 19 3c :2 a0
51 a5 b 7e 51 b4 2e :c a0
12a :2 a0 6b a0 d b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 19 3c b7 19 3c
:3 a0 51 a5 b 7e :2 a0 51 a5
b b4 2e 7e :2 a0 51 a5 b
b4 2e d a0 51 d :13 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
6b a0 7e a0 6b b4 2e 5a
a0 51 d :8 a0 51 :2 a0 51 a5
b a5 b d :2 a0 51 a5 b
7e 51 b4 2e :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 51 a5
b :2 a0 a5 57 b7 19 3c b7
19 3c :3 a0 51 a5 b d b7
:5 a0 a5 b 51 a5 b 7e :3 a0
a5 b 51 a5 b b4 2e 5a
7e 51 b4 2e 5a 7e 51 b4
2e a5 b d b7 :2 19 3c :1b a0
51 a5 b a5 b d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :3 a0 a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
51 a5 b :2 a0 a5 57 a0 b7
:2 a0 51 a5 b a0 7e a0 51
a5 b b4 2e :2 a0 51 a5 b
7e 51 b4 2e 5a :2 a0 51 a5
b 7e 51 b4 2e 5a a 10
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b :2 a0 a5 57 b7
19 3c :b a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :b a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 :2 19 3c :3 a0
a5 b d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :3 a0 a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 51 a5 b
:2 a0 a5 57 b7 19 :20 a0 12a :2 a0
6b a0 d b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 6b a0 7e a0 6b b4 2e
5a 7e b4 2e :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :4 a0 6b a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
:2 a0 a5 57 b7 19 3c :2 a0 6b
:2 a0 a5 b 7e 51 b4 2e :2 a0
6b 51 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b :2 a0
a5 57 b7 19 3c b7 :2 19 3c
b7 19 3c :2 a0 d :2 a0 d :2 a0
d :3 a0 6b d :2 a0 6b :5 a0 a5
b d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b :2 a0 a5 57 b7 :2 a0
6b :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 :2 a0 6b :2 6e 7e :2 a0 6b b4
2e 7e 6e b4 2e 7e :2 a0 6b
b4 2e a5 57 b7 19 3c :9 a0
12a e9 dd :2 a0 65 b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c :7 a0 12a e9
dd :2 a0 65 b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 68 4f
1d 17 b5 
24cd
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 5e
5a 30 66 6f 6b 59 77 84
80 56 8c 95 91 7f 9d aa
a6 7c b2 bb b7 a5 c3 a2
c8 cc d0 d4 d7 db f8 e3
e7 ea eb f3 e2 115 103 df
107 108 110 102 132 120 ff 124
125 12d 11f 14f 13d 11c 141 142
14a 13c 16c 15a 139 15e 15f 167
159 189 177 156 17b 17c 184 176
1a6 194 173 198 199 1a1 193 1c3
1b1 190 1b5 1b6 1be 1b0 1e0 1ce
1ad 1d2 1d3 1db 1cd 1fd 1eb 1ca
1ef 1f0 1f8 1ea 21a 208 1e7 20c
20d 215 207 237 225 204 229 22a
232 224 254 242 221 246 247 24f
241 270 25f 263 26b 23e 288 277
27b 283 25e 2a4 293 297 29f 25b
2bc 2ab 2af 2b7 292 2d8 2c7 2cb
2d3 28f 2f0 2df 2e3 2eb 2c6 30c
2fb 2ff 307 2c3 324 313 317 31f
2fa 340 32f 333 33b 2f7 35c 347
34b 34e 34f 357 32e 379 367 32b
36b 36c 374 366 395 384 388 363
390 383 3b1 3a0 3a4 380 3ac 39f
3cd 3bc 3c0 39c 3c8 3bb 3e9 3d8
3dc 3e4 3b8 401 3f0 3f4 3fc 3d7
41d 40c 410 3d4 418 40b 439 428
42c 408 434 427 455 444 448 424
450 443 471 460 464 440 46c 45f
48d 47c 480 45c 488 47b 4a9 498
49c 478 4a4 497 4c5 4b4 4b8 494
4c0 4b3 4e1 4d0 4d4 4b0 4dc 4cf
4fd 4ec 4f0 4cc 4f8 4eb 519 508
50c 4e8 514 507 536 524 504 528
529 531 523 553 541 520 545 546
54e 540 570 55e 53d 562 563 56b
55d 58c 57b 57f 55a 587 57a 5a8
597 59b 577 5a3 596 5c4 5b3 5b7
593 5bf 5b2 5e0 5cf 5d3 5af 5db
5ce 5fc 5eb 5ef 5cb 5f7 5ea 618
607 60b 5e7 613 606 634 623 627
603 62f 622 650 63f 643 61f 64b
63e 66c 65b 65f 63b 667 65a 688
677 67b 657 683 676 6a4 693 697
673 69f 692 6c0 6af 6b3 68f 6bb
6ae 6dc 6cb 6cf 6ab 6d7 6ca 6f8
6e7 6eb 6c7 6f3 6e6 714 703 707
6e3 70f 702 730 71f 723 6ff 72b
71e 74c 73b 73f 71b 747 73a 768
757 75b 737 763 756 784 773 777
753 77f 772 7a0 78f 793 76f 79b
78e 7bc 7ab 7af 78b 7b7 7aa 7d8
7c7 7cb 7a7 7d3 7c6 7f4 7e3 7e7
7c3 7ef 7e2 810 7ff 803 7df 80b
7fe 82d 81b 7fb 81f 820 828 81a
84a 838 817 83c 83d 845 837 866
855 859 834 861 854 883 871 851
875 876 87e 870 89f 88e 892 86d
89a 88d 8bb 8aa 8ae 88a 8b6 8a9
8d7 8c6 8ca 8a6 8d2 8c5 8f3 8e2
8e6 8c2 8ee 8e1 90f 8fe 902 8de
90a 8fd 92b 91a 91e 8fa 926 919
947 936 93a 916 942 935 963 952
956 932 95e 951 97f 96e 972 94e
97a 96d 99b 98a 98e 96a 996 989
9b7 9a6 9aa 986 9b2 9a5 9d4 9c2
9a2 9c6 9c7 9cf 9c1 9f0 9df 9e3
9eb 9be a08 9f7 9fb a03 9de a28
a13 a17 9db a1b a23 a12 a48 a33
a37 a0f a3b a43 a32 a68 a53 a57
a2f a5b a63 a52 a6f a73 a4f a77
a7b a7f a82 a87 a88 1 a8a a8f
a93 a97 a9a a9f aa3 aa7 aaa aaf
ab0 ab2 ab7 aba abe abf ac4 ac9
acc ad1 ad2 ad7 ada ade adf ae4
ae7 aec aed af2 af5 afa afb b00
b03 b08 b09 b0e b11 b15 b16 b1b
b1e b23 b24 b29 b2c b31 b32 b37
b3a b3e b42 b47 b4a b4e b4f b54
b57 b5c b5d b62 b67 b68 b6a b6f
b70 b72 b73 b78 b7b b80 b81 b86
b89 b8d b91 b96 b99 b9d b9e ba3
ba6 bab bac bb1 bb6 bb7 bb9 bbe
bbf bc1 bc2 bc7 bca bcf bd0 bd5
bd8 bdc be0 be4 be5 be7 bec bed
bef bf0 bf5 bf8 bfd bfe c03 c06
c0a c0e c12 c13 c15 c1a c1b c1d
c1e c23 c26 c2b c2c c31 c34 c38
c3c c40 c41 c43 c48 c49 c4b c4c
c51 c54 c59 c5a c5f c62 c66 c6a
c6e c6f c71 c76 c77 c79 c7a c7f
c82 c87 c88 c8d c90 c95 c96 c9b
c9e ca2 ca3 ca8 cab cb0 cb1 cb6
cb9 cbe cbf cc4 cc5 cca ccc cd0
cd3 cd7 cdb cde ce2 ce6 ce9 cec
cf1 cf4 cf7 cfa cfb d00 d01 1
d03 d08 d0c d10 d13 d18 d1d d20
d24 d25 d2a d2b d30 d32 d36 d39
d3d d40 d44 d48 d4d d51 d55 d59
d5d d61 d65 d69 d6d d71 d75 d79
d7d d81 d85 d89 d8d d91 d95 d99
d9d da1 da5 da9 dad db1 db5 db9
dbd dc1 dc5 dc9 dcd dd1 dd5 dd9
ddd de1 de5 de9 ded df1 df5 e01
e05 e09 e0c e10 e14 e16 1 e1a
e1e e22 e25 e29 e2d e31 e35 e38
e3c e40 e43 e46 e4b e4e e51 e54
e55 e5a e5b 1 e5d e62 e66 e6a
e6d e72 e77 e7a e7e e7f e84 e87
e8c e8d e92 e95 e9a e9b ea0 ea3
ea7 ea8 ead eb0 eb5 eb6 ebb ebe
ec2 ec6 ec9 ecc ecd ecf ed0 ed5
ed6 edb edd ee1 ee4 ee6 eea eec
ef8 efa efc efd f02 f06 f08 f14
f16 f1a f1e f21 f25 f28 f2c f2f
f30 f35 f38 f3c f40 f44 f48 f4c
f50 f54 f58 f5c f60 f64 f68 f6c
f70 f74 f78 f7c f80 f84 f88 f8c
f90 f94 f98 f9c fa0 fa4 fa8 fac
fb0 fb4 fb8 fbc fc0 fc4 fc8 fcc
fd0 fd4 fd8 fdc fe0 fe4 fe8 fec
ff0 ff4 ff8 ffc 1000 1004 1008 100c
1010 1014 1018 101c 1020 1024 1028 102c
1030 1034 1038 103c 1040 1044 1048 104c
1050 1054 1058 105c 1060 1064 1068 106c
1070 1074 1078 107c 1080 108c 1090 1094
1097 109b 109f 10a1 1 10a5 10a9 10ad
10b0 10b4 10b8 10bc 10c0 10c3 10c7 10cb
10ce 10d1 10d6 10d9 10dc 10df 10e0 10e5
10e6 1 10e8 10ed 10f1 10f5 10f8 10fd
1102 1105 1109 110a 110f 1112 1117 1118
111d 1120 1125 1126 112b 112e 1132 1133
1138 113b 1140 1141 1146 1149 114d 1151
1154 1157 1158 115a 115b 1160 1161 1166
1168 116c 116f 1171 1175 1177 1183 1185
1187 1188 118d 1191 1193 119f 11a1 11a5
11a9 11ac 11b0 11b3 11b7 11ba 11bb 11c0
11c3 11c7 11cb 11cf 11d3 11d7 11db 11df
11e3 11e7 11eb 11ef 11f3 11f7 11fb 11ff
1203 1207 120b 120f 1213 1217 121b 121f
1223 1227 122b 122f 1233 1237 123b 123f
1243 124f 1253 1257 125a 125e 1262 1264
1 1268 126c 1270 1273 1277 127b 127f
1283 1286 128a 128e 1291 1294 1299 129c
129f 12a2 12a3 12a8 12a9 1 12ab 12b0
12b4 12b8 12bb 12c0 12c5 12c8 12cc 12cd
12d2 12d5 12da 12db 12e0 12e3 12e8 12e9
12ee 12f1 12f5 12f6 12fb 12fe 1303 1304
1309 130c 1310 1314 1317 131a 131b 131d
131e 1323 1324 1329 132b 132f 1332 1334
1338 133a 1346 1348 134a 134b 1350 1354
1356 1362 1364 1368 136c 136f 1373 1376
137a 137d 137e 1383 1386 138a 138e 1391
1395 1399 139c 139f 13a4 13a7 13aa 13ad
13ae 13b3 13b4 1 13b6 13bb 13bf 13c3
13c6 13cb 13d0 13d3 13d7 13d8 13dd 13e0
13e5 13e6 13eb 13ee 13f3 13f4 13f9 13fc
1400 1404 1408 140c 140f 1410 1412 1417
1418 141a 141b 1420 1423 1428 1429 142e
1431 1436 1437 143c 143f 1443 1444 1449
144c 1451 1452 1457 1458 145d 145f 1463
1466 146a 146e 1471 1475 1479 147c 147f
1484 1487 148a 148d 148e 1493 1494 1
1496 149b 149f 14a3 14a6 14ab 14b0 14b3
14b7 14b8 14bd 14be 14c3 14c5 14c9 14cc
14d0 14d4 14d7 14db 14df 14e2 14e6 14ea
14eb 14f0 14f2 14f6 14f9 14fd 1501 1505
1509 150d 1511 1515 1519 151c 1520 1524
1527 1528 152a 152d 1530 1531 1536 1539
153d 1541 1544 1548 154c 154f 1550 1552
1555 1558 1559 155e 1 1561 1566 156a
156e 1571 1575 1579 157c 157f 1584 1587
158a 158d 158e 1593 1594 1 1596 159b
159f 15a3 15a6 15ab 15b0 15b3 15b7 15b8
15bd 15c0 15c5 15c6 15cb 15ce 15d3 15d4
15d9 15dc 15e0 15e4 15e8 15ec 15ef 15f0
15f2 15f7 15f8 15fa 15fb 1600 1603 1608
1609 160e 1611 1616 1617 161c 161f 1623
1624 1629 162c 1631 1632 1637 1638 163d
163f 1643 1646 164a 164e 1651 1655 1659
165c 165f 1664 1667 166a 166d 166e 1673
1674 1 1676 167b 167f 1683 1686 168b
1690 1693 1697 1698 169d 169e 16a3 16a5
16a9 16ac 16b0 16b4 16b7 16bb 16bf 16c2
16c6 16ca 16cb 16d0 16d2 16d6 16d9 16dd
16e0 16e1 16e6 16e9 16ec 16f0 16f4 16f7
16f8 16fa 16fd 1701 1705 1708 1709 170b
170c 1711 1714 1718 171b 171f 1722 1723
1725 1726 172b 1 172e 1733 1737 173b
173e 1742 1746 1749 174c 1751 1754 1757
175a 175b 1760 1761 1 1763 1768 176c
1770 1773 1778 177d 1780 1784 1785 178a
178d 1792 1793 1798 179b 17a0 17a1 17a6
17a9 17ad 17b1 17b5 17b9 17bc 17bd 17bf
17c4 17c5 17c7 17c8 17cd 17d0 17d5 17d6
17db 17de 17e3 17e4 17e9 17ec 17f0 17f1
17f6 17f9 17fe 17ff 1804 1805 180a 180c
1810 1813 1817 181b 181e 1822 1826 1829
182c 1831 1834 1837 183a 183b 1840 1841
1 1843 1848 184c 1850 1853 1858 185d
1860 1864 1865 186a 186b 1870 1872 1876
1879 187d 1881 1884 1888 188c 188f 1893
1897 1898 189d 189f 18a3 18a6 18aa 18ae
18b1 18b5 18b9 18bc 18bd 18bf 18c2 18c5
18c6 18cb 18ce 18d2 18d6 18d9 18dd 18e1
18e4 18e5 18e7 18ea 18ed 18ee 18f3 1
18f6 18fb 18ff 1903 1906 1907 1909 190c
190f 1910 1915 1919 191d 1920 1924 1928
192b 192c 192e 1931 1934 1935 193a 193e
1942 1946 194a 194e 1952 1956 195a 195e
1962 1966 196a 196e 1972 1976 197a 1986
198a 198e 1991 1995 1999 199b 1 199f
19a3 19a7 19aa 19ae 19b2 19b6 19ba 19bd
19c1 19c5 19c8 19cb 19d0 19d3 19d6 19d9
19da 19df 19e0 1 19e2 19e7 19eb 19ef
19f2 19f7 19fc 19ff 1a03 1a04 1a09 1a0c
1a11 1a12 1a17 1a1a 1a1f 1a20 1a25 1a28
1a2c 1a2d 1a32 1a35 1a3a 1a3b 1a40 1a43
1a47 1a4b 1a4e 1a51 1a52 1a54 1a55 1a5a
1a5b 1a60 1a62 1a66 1a69 1a6b 1a6f 1a71
1a7d 1a7f 1a81 1a82 1a87 1a8b 1a8d 1a99
1a9b 1a9f 1aa3 1aa6 1aaa 1aad 1ab1 1ab4
1ab5 1aba 1abd 1ac1 1ac5 1ac9 1acd 1ad1
1ad5 1ad9 1add 1ae1 1aed 1af1 1af5 1af8
1afc 1b00 1b02 1 1b06 1b0a 1b0e 1b11
1b15 1b19 1b1d 1b21 1b24 1b28 1b2c 1b2f
1b32 1b37 1b3a 1b3d 1b40 1b41 1b46 1b47
1 1b49 1b4e 1b52 1b56 1b59 1b5e 1b63
1b66 1b6a 1b6b 1b70 1b73 1b78 1b79 1b7e
1b81 1b86 1b87 1b8c 1b8f 1b93 1b94 1b99
1b9c 1ba1 1ba2 1ba7 1baa 1bae 1bb2 1bb5
1bb8 1bb9 1bbb 1bbc 1bc1 1bc2 1bc7 1bc9
1bcd 1bd0 1bd2 1bd6 1bd8 1be4 1be6 1be8
1be9 1bee 1bf2 1bf4 1c00 1c02 1c04 1c08
1c0b 1c0f 1c13 1c16 1c1a 1c1e 1c21 1c22
1c24 1c27 1c2a 1c2b 1c30 1c34 1c35 1c39
1c3b 1c3f 1c42 1c44 1c48 1c4c 1c50 1c54
1c58 1c5c 1c60 1c64 1c68 1c6c 1c70 1c74
1c78 1c7c 1c80 1c84 1c90 1c94 1c98 1c9b
1c9f 1ca3 1ca5 1 1ca9 1cad 1cb1 1cb4
1cb8 1cbc 1cc0 1cc4 1cc7 1ccb 1ccf 1cd2
1cd5 1cda 1cdd 1ce0 1ce3 1ce4 1ce9 1cea
1 1cec 1cf1 1cf5 1cf9 1cfc 1d01 1d06
1d09 1d0d 1d0e 1d13 1d16 1d1b 1d1c 1d21
1d24 1d29 1d2a 1d2f 1d32 1d36 1d37 1d3c
1d3f 1d44 1d45 1d4a 1d4d 1d51 1d55 1d58
1d5b 1d5c 1d5e 1d5f 1d64 1d65 1d6a 1d6c
1d70 1d73 1d75 1d79 1d7b 1d87 1d89 1d8b
1d8c 1d91 1d95 1d97 1da3 1da5 1da9 1dad
1db0 1db4 1db7 1dbb 1dbe 1dbf 1dc4 1dc7
1dcb 1dcf 1dd3 1dd7 1ddb 1ddf 1de3 1de7
1deb 1df7 1dfb 1dff 1e02 1e06 1e0a 1e0c
1 1e10 1e14 1e18 1e1b 1e1f 1e23 1e27
1e2b 1e2e 1e32 1e36 1e39 1e3c 1e41 1e44
1e47 1e4a 1e4b 1e50 1e51 1 1e53 1e58
1e5c 1e60 1e63 1e68 1e6d 1e70 1e74 1e75
1e7a 1e7d 1e82 1e83 1e88 1e8b 1e90 1e91
1e96 1e99 1e9d 1e9e 1ea3 1ea6 1eab 1eac
1eb1 1eb4 1eb8 1ebc 1ebf 1ec2 1ec3 1ec5
1ec6 1ecb 1ecc 1ed1 1ed3 1ed7 1eda 1edc
1ee0 1ee2 1eee 1ef0 1ef2 1ef3 1ef8 1efc
1efe 1f0a 1f0c 1f0e 1f12 1f15 1f19 1f1c
1f20 1f22 1f26 1f2a 1f2d 1f31 1f35 1f38
1f39 1f3b 1f3f 1f42 1f46 1f49 1f4a 1f4f
1f53 1f57 1f5b 1f5f 1f63 1f67 1f6b 1f6f
1f73 1f7f 1f83 1f88 1f8c 1f8f 1f90 1f95
1f99 1f9d 1fa0 1fa3 1fa7 1fa9 1fad 1fb1
1fb4 1fb7 1fbb 1fbd 1fc1 1fc5 1fc8 1fca
1 1fce 1fd2 1fd6 1fd9 1fdd 1fe1 1fe5
1fe9 1fec 1ff0 1ff4 1ff7 1ffa 1fff 2002
2005 2008 2009 200e 200f 1 2011 2016
201a 201e 2021 2026 202b 202e 2032 2033
2038 203b 2040 2041 2046 2049 204e 204f
2054 2057 205b 205c 2061 2064 2069 206a
206f 2072 2076 207a 207d 2080 2081 2083
2084 2089 208a 208f 2091 2095 2098 209a
209e 20a0 20ac 20ae 20b0 20b1 20b6 20ba
20bc 20c8 20ca 20cc 20d0 20d4 20d8 20dc
20e0 20e4 20e8 20ec 20f0 20fc 2100 2105
2109 210c 210d 2112 2116 211a 211d 2120
2124 2126 212a 212e 2131 2134 2138 213a
213e 2142 2145 2147 1 214b 214f 2153
2156 215a 215e 2162 2166 2169 216d 2171
2174 2177 217c 217f 2182 2185 2186 218b
218c 1 218e 2193 2197 219b 219e 21a3
21a8 21ab 21af 21b0 21b5 21b8 21bd 21be
21c3 21c6 21cb 21cc 21d1 21d4 21d8 21d9
21de 21e1 21e6 21e7 21ec 21ef 21f3 21f7
21fa 21fd 21fe 2200 2201 2206 2207 220c
220e 2212 2215 2217 221b 221d 2229 222b
222d 222e 2233 2237 2239 2245 2247 2249
224d 2251 2254 2258 225c 225f 2263 2266
226a 226d 226e 2273 2276 227a 227e 2282
2283 2285 2289 228b 228f 2292 2294 2298
229c 22a0 22a4 22a8 22ac 22b0 22b4 22b8
22c4 22c8 22cc 22cf 22d3 22d7 22d9 1
22dd 22e1 22e5 22e8 22ec 22f0 22f4 22f8
22fb 22ff 2303 2306 2309 230e 2311 2314
2317 2318 231d 231e 1 2320 2325 2329
232d 2330 2335 233a 233d 2341 2342 2347
234a 234f 2350 2355 2358 235d 235e 2363
2366 236a 236b 2370 2373 2378 2379 237e
2381 2385 2389 238c 238f 2390 2392 2393
2398 2399 239e 23a0 23a4 23a7 23a9 23ad
23af 23bb 23bd 23bf 23c0 23c5 23c9 23cb
23d7 23d9 23dd 23e1 23e4 23e5 23e7 23ea
23ed 23ee 23f3 23f7 23fb 23fe 2402 2406
2409 240c 2411 2414 2417 241a 241b 2420
2421 1 2423 2428 242c 2430 2433 2438
243d 2440 2444 2445 244a 244d 2452 2453
2458 245b 2460 2461 2466 2469 246d 2471
2475 2479 247c 247d 247f 2484 2485 2487
2488 248d 2490 2495 2496 249b 249e 24a3
24a4 24a9 24ac 24b0 24b1 24b6 24b9 24be
24bf 24c4 24c5 24ca 24cc 24d0 24d3 24d7
24db 24de 24e2 24e6 24e9 24ec 24f1 24f4
24f7 24fa 24fb 2500 2501 1 2503 2508
250c 2510 2513 2518 251d 2520 2524 2525
252a 252b 2530 2532 2536 2539 253d 2541
2544 2548 254c 254f 2553 2557 2558 255d
255f 2563 2566 256a 256e 2571 2575 2579
257c 257d 257f 2582 2585 2586 258b 258f
2593 2597 259b 259f 25a3 25a7 25ab 25af
25b3 25b7 25bb 25bf 25c3 25c7 25cb 25d7
25db 25df 25e2 25e6 25ea 25ec 1 25f0
25f4 25f8 25fb 25ff 2603 2607 260b 260e
2612 2616 2619 261c 2621 2624 2627 262a
262b 2630 2631 1 2633 2638 263c 2640
2643 2648 264d 2650 2654 2655 265a 265d
2662 2663 2668 266b 2670 2671 2676 2679
267d 267e 2683 2686 268b 268c 2691 2694
2698 269c 269f 26a2 26a3 26a5 26a6 26ab
26ac 26b1 26b3 26b7 26ba 26bc 26c0 26c2
26ce 26d0 26d2 26d3 26d8 26dc 26de 26ea
26ec 26f0 26f4 26f7 26fb 26fe 2702 2705
2706 270b 270e 2712 2716 271a 271e 2722
2726 272a 272e 2732 273e 2742 2746 2749
274d 2751 2753 1 2757 275b 275f 2762
2766 276a 276e 2772 2775 2779 277d 2780
2783 2788 278b 278e 2791 2792 2797 2798
1 279a 279f 27a3 27a7 27aa 27af 27b4
27b7 27bb 27bc 27c1 27c4 27c9 27ca 27cf
27d2 27d7 27d8 27dd 27e0 27e4 27e5 27ea
27ed 27f2 27f3 27f8 27fb 27ff 2803 2806
2809 280a 280c 280d 2812 2813 2818 281a
281e 2821 2823 2827 2829 2835 2837 2839
283a 283f 2843 2845 2851 2853 2855 2859
285c 285e 2862 2866 286a 286e 2872 2876
287a 287e 2882 2886 288a 288e 2892 2896
289a 289e 28aa 28ae 28b2 28b5 28b9 28bd
28bf 1 28c3 28c7 28cb 28ce 28d2 28d6
28da 28de 28e1 28e5 28e9 28ec 28ef 28f4
28f7 28fa 28fd 28fe 2903 2904 1 2906
290b 290f 2913 2916 291b 2920 2923 2927
2928 292d 2930 2935 2936 293b 293e 2943
2944 2949 294c 2950 2951 2956 2959 295e
295f 2964 2967 296b 296f 2972 2975 2976
2978 2979 297e 297f 2984 2986 298a 298d
298f 2993 2995 29a1 29a3 29a5 29a6 29ab
29af 29b1 29bd 29bf 29c3 29c7 29ca 29ce
29d1 29d5 29d8 29d9 29de 29e1 29e5 29e9
29ed 29f1 29f5 29f9 29fd 2a01 2a05 2a11
2a15 2a19 2a1c 2a20 2a24 2a26 1 2a2a
2a2e 2a32 2a35 2a39 2a3d 2a41 2a45 2a48
2a4c 2a50 2a53 2a56 2a5b 2a5e 2a61 2a64
2a65 2a6a 2a6b 1 2a6d 2a72 2a76 2a7a
2a7d 2a82 2a87 2a8a 2a8e 2a8f 2a94 2a97
2a9c 2a9d 2aa2 2aa5 2aaa 2aab 2ab0 2ab3
2ab7 2ab8 2abd 2ac0 2ac5 2ac6 2acb 2ace
2ad2 2ad6 2ad9 2adc 2add 2adf 2ae0 2ae5
2ae6 2aeb 2aed 2af1 2af4 2af6 2afa 2afc
2b08 2b0a 2b0c 2b0d 2b12 2b16 2b18 2b24
2b26 2b28 2b2c 2b2f 2b31 2b35 2b39 2b3c
2b40 2b44 2b48 2b4c 2b50 2b54 2b58 2b5c
2b60 2b64 2b68 2b6c 2b6f 2b70 2b72 2b75
2b76 2b78 2b7c 2b80 2b84 2b87 2b88 2b8a
2b8d 2b90 2b91 2b96 2b9a 2b9e 2ba2 2ba3
2ba5 2ba9 2bab 2baf 2bb3 2bb6 2bba 2bbe
2bc1 2bc4 2bc9 2bcc 2bcf 2bd2 2bd3 2bd8
2bd9 1 2bdb 2be0 2be4 2be8 2beb 2bf0
2bf5 2bf8 2bfc 2bfd 2c02 2c05 2c0a 2c0b
2c10 2c13 2c18 2c19 2c1e 2c21 2c25 2c29
2c2d 2c2e 2c30 2c35 2c36 2c38 2c39 2c3e
2c41 2c46 2c47 2c4c 2c4f 2c54 2c55 2c5a
2c5d 2c61 2c62 2c67 2c6a 2c6f 2c70 2c75
2c76 2c7b 2c7d 2c81 2c84 2c88 2c8c 2c8f
2c93 2c97 2c9a 2c9d 2ca2 2ca5 2ca8 2cab
2cac 2cb1 2cb2 1 2cb4 2cb9 2cbd 2cc1
2cc4 2cc9 2cce 2cd1 2cd5 2cd6 2cdb 2cdc
2ce1 2ce3 2ce7 2cea 2cee 2cf2 2cf5 2cf9
2cfd 2d00 2d01 2d03 2d07 2d0b 2d0c 2d11
2d13 2d17 2d1b 2d1e 2d20 2d24 2d28 2d2b
2d2f 2d31 2d35 2d39 2d3c 2d3d 2d3f 2d43
2d46 2d4a 2d4d 2d4e 2d50 2d51 2d56 2d59
2d5d 2d61 2d64 2d65 2d67 2d6a 2d6d 2d6e
2d73 1 2d76 2d7b 2d7f 2d82 2d86 2d8a
2d8e 2d91 2d92 2d94 2d98 2d9b 2d9f 2da2
2da3 2da5 2da6 2dab 2daf 2db3 2db6 2dba
2dbe 2dc1 2dc4 2dc9 2dcc 2dcf 2dd2 2dd3
2dd8 2dd9 1 2ddb 2de0 2de4 2de8 2deb
2df0 2df5 2df8 2dfc 2dfd 2e02 2e05 2e0a
2e0b 2e10 2e13 2e18 2e19 2e1e 2e21 2e25
2e29 2e2d 2e31 2e34 2e35 2e37 2e3c 2e3d
2e3f 2e40 2e45 2e46 2e4b 2e4d 2e51 2e54
2e58 2e5c 2e5f 2e63 2e67 2e6a 2e6d 2e72
2e75 2e78 2e7b 2e7c 2e81 2e82 1 2e84
2e89 2e8d 2e91 2e94 2e99 2e9e 2ea1 2ea5
2ea6 2eab 2eac 2eb1 2eb3 2eb7 2eba 2ebe
2ec2 2ec5 2ec9 2ecd 2ed0 2ed4 2ed5 2eda
2ede 2ee0 2ee4 2ee8 2eeb 2eec 2eee 2ef2
2ef5 2ef9 2efc 2efd 2eff 2f00 2f05 2f09
2f0c 2f10 2f12 2f16 2f1a 2f1d 2f21 2f24
2f28 2f2c 2f30 2f34 2f38 2f3c 2f40 2f44
2f48 2f4c 2f50 2f54 2f58 2f5c 2f60 2f64
2f68 2f6c 2f70 2f74 2f78 2f7c 2f80 2f84
2f88 2f94 2f98 2f9c 2f9f 2fa3 2fa7 2fa9
1 2fad 2fb1 2fb5 2fb8 2fbc 2fc0 2fc4
2fc8 2fcb 2fcf 2fd3 2fd6 2fd9 2fde 2fe1
2fe4 2fe7 2fe8 2fed 2fee 1 2ff0 2ff5
2ff9 2ffd 3000 3005 300a 300d 3011 3012
3017 301a 301f 3020 3025 3028 302d 302e
3033 3036 303a 303b 3040 3043 3048 3049
304e 3051 3055 3059 305c 305f 3060 3062
3063 3068 3069 306e 3070 3074 3077 3079
307d 307f 308b 308d 308f 3090 3095 3099
309b 30a7 30a9 30ad 30b1 30b4 30b5 30b7
30ba 30bd 30be 30c3 30c7 30cb 30ce 30d2
30d6 30d9 30dc 30e1 30e4 30e7 30ea 30eb
30f0 30f1 1 30f3 30f8 30fc 3100 3103
3108 310d 3110 3114 3115 311a 311d 3122
3123 3128 312b 3130 3131 3136 3139 313d
3141 3145 3149 314c 314d 314f 3154 3155
3157 3158 315d 3160 3165 3166 316b 316e
3173 3174 3179 317c 3180 3181 3186 3189
318e 318f 3194 3195 319a 319c 31a0 31a3
31a7 31ab 31ae 31b2 31b6 31b9 31bc 31c1
31c4 31c7 31ca 31cb 31d0 31d1 1 31d3
31d8 31dc 31e0 31e3 31e8 31ed 31f0 31f4
31f5 31fa 31fb 3200 3202 3206 3209 320d
3211 3214 3218 321c 321f 3223 3227 3228
322d 322f 3233 3236 323a 323e 3242 3246
324a 324e 3252 3256 325a 325e 3262 3266
326a 326e 3272 3276 327a 327e 3282 3286
328a 328e 3292 3296 329a 329e 32a2 32a6
32b2 32b6 32ba 32bd 32c1 32c5 32c7 1
32cb 32cf 32d3 32d6 32da 32de 32e2 32e6
32e9 32ed 32f1 32f4 32f7 32fc 32ff 3302
3305 3306 330b 330c 1 330e 3313 3317
331b 331e 3323 3328 332b 332f 3330 3335
3338 333d 333e 3343 3346 334b 334c 3351
3354 3358 3359 335e 3361 3366 3367 336c
336f 3373 3377 337a 337d 337e 3380 3381
3386 3387 338c 338e 3392 3395 3397 339b
339d 33a9 33ab 33ad 33ae 33b3 33b7 33b9
33c5 33c7 33cb 33cf 33d2 33d3 33d5 33d8
33db 33dc 33e1 33e5 33e9 33ec 33f0 33f4
33f7 33fa 33ff 3402 3405 3408 3409 340e
340f 1 3411 3416 341a 341e 3421 3426
342b 342e 3432 3433 3438 343b 3440 3441
3446 3449 344e 344f 3454 3457 345b 345f
3463 3467 346a 346b 346d 3472 3473 3475
3476 347b 347e 3483 3484 3489 348c 3491
3492 3497 349a 349e 349f 34a4 34a7 34ac
34ad 34b2 34b3 34b8 34ba 34be 34c1 34c5
34c9 34cc 34d0 34d4 34d7 34da 34df 34e2
34e5 34e8 34e9 34ee 34ef 1 34f1 34f6
34fa 34fe 3501 3506 350b 350e 3512 3513
3518 3519 351e 3520 3524 3527 352b 352f
3532 3536 353a 353d 3541 3545 3546 354b
354d 3551 3554 3558 355c 3560 3564 3568
356c 3570 3574 3578 357c 3580 3583 3584
3586 3587 3589 358d 358f 3593 3597 359a
359e 35a2 35a5 35a6 35a8 35ab 35ae 35af
35b4 35b8 35bc 35c0 35c1 35c3 35c7 35c9
35cd 35d0 35d4 35d8 35db 35df 35e3 35e6
35e9 35ee 35f1 35f4 35f7 35f8 35fd 35fe
1 3600 3605 3609 360d 3610 3615 361a
361d 3621 3622 3627 362a 362f 3630 3635
3638 363d 363e 3643 3646 364a 364e 3652
3653 3655 365a 365b 365d 365e 3663 3666
366b 366c 3671 3674 3679 367a 367f 3682
3686 3687 368c 368f 3694 3695 369a 369b
36a0 36a2 36a6 36a9 36ad 36b1 36b4 36b8
36bc 36bf 36c2 36c7 36ca 36cd 36d0 36d1
36d6 36d7 1 36d9 36de 36e2 36e6 36e9
36ee 36f3 36f6 36fa 36fb 3700 3701 3706
3708 370c 370f 3713 3717 371a 371e 3722
3725 3726 3728 372c 3730 3731 3736 373a
373c 3740 3743 3744 3749 374c 3750 3753
3754 3759 1 375c 3761 3765 3769 376d
3771 3775 3779 377d 3781 3784 3788 378c
378f 3790 3792 3795 3798 3799 379e 37a1
37a5 37a9 37ac 37b0 37b4 37b7 37b8 37ba
37bd 37c0 37c1 37c6 1 37c9 37ce 37d2
37d6 37d9 37dd 37e1 37e4 37e7 37ec 37ef
37f2 37f5 37f6 37fb 37fc 1 37fe 3803
3807 380b 380e 3813 3818 381b 381f 3820
3825 3828 382d 382e 3833 3836 383b 383c
3841 3844 3848 384c 3850 3854 3857 3858
385a 385f 3860 3862 3863 3868 386b 3870
3871 3876 3879 387e 387f 3884 3887 388b
388c 3891 3894 3899 389a 389f 38a0 38a5
38a7 38ab 38ae 38b2 38b6 38b9 38bd 38c1
38c4 38c7 38cc 38cf 38d2 38d5 38d6 38db
38dc 1 38de 38e3 38e7 38eb 38ee 38f3
38f8 38fb 38ff 3900 3905 3906 390b 390d
3911 3914 3918 391c 391f 3923 3927 392a
392e 3932 3933 3938 393a 393e 3941 3945
3949 394d 3951 3955 3959 395d 3961 3965
3969 396d 3979 397d 3981 3984 3988 398c
398e 1 3992 3996 399a 399d 39a1 39a5
39a9 39ad 39b0 39b4 39b8 39bb 39be 39c3
39c6 39c9 39cc 39cd 39d2 39d3 1 39d5
39da 39de 39e2 39e5 39ea 39ef 39f2 39f6
39f7 39fc 39ff 3a04 3a05 3a0a 3a0d 3a12
3a13 3a18 3a1b 3a1f 3a20 3a25 3a28 3a2d
3a2e 3a33 3a36 3a3a 3a3e 3a41 3a44 3a45
3a47 3a48 3a4d 3a4e 3a53 3a55 3a59 3a5c
3a5e 3a62 3a64 3a70 3a72 3a74 3a75 3a7a
3a7e 3a80 3a8c 3a8e 3a92 3a96 3a99 3a9c
3a9d 3a9f 3aa2 3aa7 3aa8 3aad 3ab1 3ab4
3ab8 3aba 3abe 3ac1 3ac5 3ac7 3acb 3acf
3ad2 3ad6 3ad9 3add 3ae1 3ae4 3ae8 3aec
3af0 3af3 3af7 3afb 3afe 3aff 3b01 3b04
3b07 3b08 3b0d 3b10 3b14 3b18 3b1b 3b1f
3b23 3b26 3b27 3b29 3b2c 3b2f 3b30 3b35
1 3b38 3b3d 3b41 3b45 3b48 3b49 3b4b
3b4f 3b52 3b56 3b59 3b5a 3b5c 3b5d 3b62
1 3b65 3b6a 3b6e 3b72 3b75 3b79 3b7d
3b80 3b81 3b83 3b86 3b89 3b8a 3b8f 3b93
3b97 3b9b 3b9f 3ba3 3ba7 3bab 3baf 3bb3
3bbf 3bc3 3bc7 3bca 3bce 3bd2 3bd4 1
3bd8 3bdc 3be0 3be3 3be7 3beb 3bef 3bf3
3bf6 3bfa 3bfe 3c01 3c04 3c09 3c0c 3c0f
3c12 3c13 3c18 3c19 1 3c1b 3c20 3c24
3c28 3c2b 3c30 3c35 3c38 3c3c 3c3d 3c42
3c45 3c4a 3c4b 3c50 3c53 3c58 3c59 3c5e
3c61 3c65 3c66 3c6b 3c6e 3c73 3c74 3c79
3c7c 3c80 3c84 3c87 3c8a 3c8b 3c8d 3c8e
3c93 3c94 3c99 3c9b 3c9f 3ca2 3ca4 3ca8
3caa 3cb6 3cb8 3cba 3cbb 3cc0 3cc4 3cc6
3cd2 3cd4 3cd8 3cdc 3ce0 3ce4 3ce7 3ceb
3cef 3cf2 3cf6 3cfa 3cfc 3d00 3d04 3d07
3d0b 3d0f 3d12 3d13 3d15 3d18 3d1b 3d1c
3d21 3d25 3d29 3d2d 3d31 3d35 3d39 3d3d
3d41 3d45 3d49 3d55 3d59 3d5d 3d60 3d64
3d68 3d6a 1 3d6e 3d72 3d76 3d79 3d7d
3d81 3d85 3d89 3d8c 3d90 3d94 3d97 3d9a
3d9f 3da2 3da5 3da8 3da9 3dae 3daf 1
3db1 3db6 3dba 3dbe 3dc1 3dc6 3dcb 3dce
3dd2 3dd3 3dd8 3ddb 3de0 3de1 3de6 3de9
3dee 3def 3df4 3df7 3dfb 3dfc 3e01 3e04
3e09 3e0a 3e0f 3e12 3e16 3e1a 3e1d 3e20
3e21 3e23 3e24 3e29 3e2a 3e2f 3e31 3e35
3e38 3e3a 3e3e 3e40 3e4c 3e4e 3e50 3e51
3e56 3e5a 3e5c 3e68 3e6a 3e6e 3e72 3e76
3e79 3e7d 3e81 3e82 3e84 3e88 3e8c 3e8f
3e92 3e93 3e98 3e9c 3ea0 3ea4 3ea8 3eac
3eb0 3eb4 3eb8 3ebc 3ec0 3ec4 3ec8 3ecc
3ecd 3ecf 3ed3 3ed7 3edb 3ede 3edf 3ee1
3ee4 3ee7 3ee8 3eed 3ef0 3ef4 3ef7 3ef8
3efd 3f00 1 3f03 3f08 3f0c 3f10 3f14
3f18 3f1c 3f20 3f24 3f28 3f2c 3f30 3f34
3f40 3f44 3f49 3f4d 3f50 3f51 3f56 3f5a
3f5e 3f61 3f64 3f68 3f6a 3f6e 3f72 3f75
3f78 3f7c 3f7e 3f82 3f86 3f89 3f8b 1
3f8f 3f93 3f97 3f9a 3f9e 3fa2 3fa6 3faa
3fad 3fb1 3fb5 3fb8 3fbb 3fc0 3fc3 3fc6
3fc9 3fca 3fcf 3fd0 1 3fd2 3fd7 3fdb
3fdf 3fe2 3fe7 3fec 3fef 3ff3 3ff4 3ff9
3ffc 4001 4002 4007 400a 400f 4010 4015
4018 401c 401d 4022 4025 402a 402b 4030
4033 4037 403b 403e 4041 4042 4044 4045
404a 404b 4050 4052 4056 4059 405b 405f
4061 406d 406f 4071 4072 4077 407b 407d
4089 408b 408d 4091 4094 4098 409c 409f
40a2 40a3 40a5 40a8 40ad 40ae 40b3 40b7
40ba 40be 40c0 40c4 40c7 40cb 40cd 40d1
40d5 40d8 40dc 40e0 40e4 40e8 40ec 40f0
40f4 40f8 40fc 4100 4104 4108 410c 4110
4114 4117 411b 411e 411f 4121 4125 4129
412d 4131 4135 4139 413d 4141 4145 4149
414d 4151 4155 4159 415d 4161 4165 4169
416d 4171 417d 4181 4185 4188 418c 4190
4192 1 4196 419a 419e 41a1 41a5 41a9
41ad 41b1 41b4 41b8 41bc 41bf 41c2 41c7
41ca 41cd 41d0 41d1 41d6 41d7 1 41d9
41de 41e2 41e6 41e9 41ee 41f3 41f6 41fa
41fb 4200 4203 4208 4209 420e 4211 4216
4217 421c 421f 4223 4224 4229 422c 4231
4232 4237 423a 423e 4242 4245 4248 4249
424b 424c 4251 4252 4257 4259 425d 4260
4262 4266 4268 4274 4276 4278 4279 427e
4282 4284 4290 4292 4296 4299 429d 42a1
42a5 42a9 42ad 42b1 42b5 42b9 42bd 42c1
42c5 42c9 42cd 42ce 42d0 42d4 42d8 42dc
42e0 42e1 42e3 42e7 42eb 42ef 42f2 42f5
42f9 42fd 4301 4304 4308 430c 430f 4312
4317 431a 431d 4320 4321 4326 4327 1
4329 432e 4332 4336 4339 433e 4343 4346
434a 434b 4350 4353 4358 4359 435e 4361
4366 4367 436c 436f 4373 4377 437b 437f
4382 4383 4385 438a 438b 438d 438e 4393
4396 439b 439c 43a1 43a4 43a9 43aa 43af
43b2 43b6 43b7 43bc 43bf 43c4 43c5 43ca
43cb 43d0 43d2 43d6 43d9 43dd 43e1 43e4
43e8 43ec 43ef 43f3 43f7 43f8 43fd 4401
4403 4407 440b 440f 4412 4413 4415 4419
441c 4420 4423 4424 4426 4427 442c 4430
4434 4438 443b 443c 443e 4441 4445 4449
444c 444d 444f 4450 4455 4459 445d 4460
4464 4468 446a 446e 4472 4476 4479 447a
447c 447f 4482 4483 4488 448c 448f 4493
4497 449a 449e 44a2 44a6 44aa 44ae 44b2
44be 44c2 44c6 44c9 44cd 44d1 44d3 1
44d7 44db 44df 44e2 44e6 44ea 44ee 44f2
44f5 44f9 44fd 4500 4503 4508 450b 450e
4511 4512 4517 4518 1 451a 451f 4523
4527 452a 452f 4534 4537 453b 453c 4541
4544 4549 454a 454f 4552 4557 4558 455d
4560 4564 4565 456a 456d 4572 4573 4578
457b 457f 4583 4586 4589 458a 458c 458d
4592 4593 4598 459a 459e 45a1 45a3 45a7
45a9 45b5 45b7 45b9 45ba 45bf 45c3 45c5
45d1 45d3 45d7 45d9 45dd 45e1 45e5 45e8
45e9 45eb 45ef 45f2 45f6 45f9 45fa 45fc
45fd 4602 4606 460a 460e 4611 4612 4614
4617 461b 461f 4622 4623 4625 4626 462b
462f 4633 4634 4638 463c 4641 4645 4649
464d 4650 4651 4653 4656 4659 465a 465f
4663 4668 466b 4670 4671 4676 4679 467d
467e 4683 4686 468b 468c 4691 4694 4698
4699 469e 46a1 46a6 46a7 46ac 46af 46b4
46b5 46ba 46bd 46c1 46c5 46c9 46cc 46cd
46cf 46d0 46d2 46d3 46d8 46dc 46e0 46e4
46e8 46eb 46ef 46f1 46f5 46fa 46fd 4702
4703 4708 470b 470f 4710 4715 4718 471d
471e 4723 4726 472a 472b 4730 4733 4738
4739 473e 4741 4746 4747 474c 474f 4753
4757 475b 475e 475f 4761 4762 4764 4765
476a 476e 4772 4776 477a 477d 4781 4783
4787 478b 478e 4792 4796 479a 479d 479e
47a0 47a3 47a6 47a7 47ac 47b0 47b4 47b9
47be 47c2 47c6 47cb 47cf 47d3 47d6 47d9
47dd 47df 47e3 47e7 47ea 47ed 47f1 47f3
47f7 47fb 47fe 4800 4804 4808 480d 4812
4816 481a 481f 4823 4827 482a 482d 4831
4833 4837 483b 483e 4841 4845 4847 484b
484f 4852 4854 4858 485c 485f 4863 4867
486a 486e 4871 4875 4878 4879 487e 4881
4885 488b 488d 4891 4894 4896 489a 48a1
48a5 48a9 48ac 48ad 48af 48b2 48b5 48b6
48bb 48bf 48c3 48c8 48ca 48ce 48d2 48d5
48d9 48dd 48df 1 48e3 48e7 48eb 48ee
48f2 48f6 48fa 48fe 4901 4905 4909 490c
490f 4914 4917 491a 491d 491e 4923 4924
1 4926 492b 492f 4933 4936 493b 4940
4943 4947 4948 494d 4950 4955 4956 495b
495e 4963 4964 4969 496c 4970 4971 4976
4979 497e 497f 4984 4987 498b 498f 4992
4995 4996 4998 4999 499e 499f 49a4 49a6
49aa 49ad 49af 49b3 49b5 49c1 49c3 49c5
49c6 49cb 49cf 49d1 49dd 49df 49e1 49e5
49e9 49ee 49f0 49f4 49f8 49fb 49ff 4a03
4a05 1 4a09 4a0d 4a11 4a14 4a18 4a1c
4a20 4a24 4a27 4a2b 4a2f 4a32 4a35 4a3a
4a3d 4a40 4a43 4a44 4a49 4a4a 1 4a4c
4a51 4a55 4a59 4a5c 4a61 4a66 4a69 4a6d
4a6e 4a73 4a76 4a7b 4a7c 4a81 4a84 4a89
4a8a 4a8f 4a92 4a96 4a97 4a9c 4a9f 4aa4
4aa5 4aaa 4aad 4ab1 4ab5 4ab8 4abb 4abc
4abe 4abf 4ac4 4ac5 4aca 4acc 4ad0 4ad3
4ad5 4ad9 4adb 4ae7 4ae9 4aeb 4aec 4af1
4af5 4af7 4b03 4b05 4b07 4b0b 4b0f 4b12
4b16 4b19 4b1a 4b1f 4b22 4b26 4b2a 4b2d
4b2e 4b30 4b33 4b36 4b37 4b3c 4b40 4b44
4b47 4b4b 4b4f 4b52 4b55 4b5a 4b5d 4b60
4b63 4b64 4b69 4b6a 1 4b6c 4b71 4b75
4b79 4b7c 4b81 4b86 4b89 4b8d 4b8e 4b93
4b96 4b9b 4b9c 4ba1 4ba4 4ba9 4baa 4baf
4bb2 4bb6 4bba 4bbe 4bc2 4bc5 4bc6 4bc8
4bcd 4bce 4bd0 4bd1 4bd6 4bd9 4bde 4bdf
4be4 4be7 4bec 4bed 4bf2 4bf5 4bf9 4bfa
4bff 4c02 4c07 4c08 4c0d 4c0e 4c13 4c15
4c19 4c1c 4c20 4c24 4c27 4c2b 4c2f 4c32
4c35 4c3a 4c3d 4c40 4c43 4c44 4c49 4c4a
1 4c4c 4c51 4c55 4c59 4c5c 4c61 4c66
4c69 4c6d 4c6e 4c73 4c74 4c79 4c7b 4c7f
4c82 4c86 4c8a 4c8d 4c91 4c95 4c98 4c9c
4ca0 4ca1 4ca6 4ca8 4cac 4cb0 4cb3 4cb7
4cbb 4cbe 4cc1 4cc6 4cc9 4ccc 4ccf 4cd0
4cd5 4cd6 1 4cd8 4cdd 4ce1 4ce5 4ce8
4ced 4cf2 4cf5 4cf9 4cfa 4cff 4d02 4d07
4d08 4d0d 4d10 4d15 4d16 4d1b 4d1e 4d22
4d26 4d2a 4d2e 4d31 4d32 4d34 4d39 4d3a
4d3c 4d3d 4d42 4d45 4d4a 4d4b 4d50 4d53
4d58 4d59 4d5e 4d61 4d65 4d66 4d6b 4d6e
4d73 4d74 4d79 4d7a 4d7f 4d81 4d85 4d88
4d8c 4d90 4d93 4d97 4d9b 4d9e 4da1 4da6
4da9 4dac 4daf 4db0 4db5 4db6 1 4db8
4dbd 4dc1 4dc5 4dc8 4dcd 4dd2 4dd5 4dd9
4dda 4ddf 4de0 4de5 4de7 4deb 4dee 4df2
4df6 4df9 4dfd 4e01 4e04 4e08 4e0c 4e0d
4e12 4e14 4e18 4e1c 4e1f 4e21 4e25 4e28
4e2c 4e30 4e34 4e38 4e3c 4e40 4e44 4e48
4e4c 4e50 4e5c 4e60 4e64 4e67 4e6b 4e6f
4e71 1 4e75 4e79 4e7d 4e80 4e84 4e88
4e8c 4e90 4e93 4e97 4e9b 4e9e 4ea1 4ea6
4ea9 4eac 4eaf 4eb0 4eb5 4eb6 1 4eb8
4ebd 4ec1 4ec5 4ec8 4ecd 4ed2 4ed5 4ed9
4eda 4edf 4ee2 4ee7 4ee8 4eed 4ef0 4ef5
4ef6 4efb 4efe 4f02 4f03 4f08 4f0b 4f10
4f11 4f16 4f19 4f1d 4f21 4f24 4f27 4f28
4f2a 4f2b 4f30 4f31 4f36 4f38 4f3c 4f3f
4f41 4f45 4f47 4f53 4f55 4f57 4f58 4f5d
4f61 4f63 4f6f 4f71 4f75 4f78 4f7c 4f80
4f83 4f87 4f89 4f8d 4f91 4f94 4f98 4f9a
4f9e 4fa2 4fa5 4fa6 4fa8 4fac 4faf 4fb3
4fb6 4fb7 4fb9 4fba 4fbf 4fc3 4fc7 4fca
4fcb 4fcd 4fd1 4fd4 4fd8 4fdb 4fdc 4fde
4fdf 4fe4 4fe8 4fec 4fef 4ff3 4ff7 4ffa
4ffd 5002 5005 5008 500b 500c 5011 5012
1 5014 5019 501d 5021 5024 5029 502e
5031 5035 5036 503b 503e 5043 5044 5049
504c 5051 5052 5057 505a 505e 5062 5066
506a 506d 506e 5070 5075 5076 5078 5079
507e 5081 5086 5087 508c 508f 5094 5095
509a 509d 50a1 50a2 50a7 50aa 50af 50b0
50b5 50b6 50bb 50bd 50c1 50c4 50c8 50cc
50cf 50d3 50d7 50da 50dd 50e2 50e5 50e8
50eb 50ec 50f1 50f2 1 50f4 50f9 50fd
5101 5104 5109 510e 5111 5115 5116 511b
511c 5121 5123 5127 512a 512e 5132 5135
5139 513d 5140 5144 5148 5149 514e 5150
5154 5157 515b 515f 5162 5163 5165 5168
516b 516c 5171 5175 5178 517c 517e 5182
5186 5189 518a 518c 518f 5192 5193 5198
519b 519f 51a3 51a6 51a7 51a9 51ac 51af
51b0 51b5 1 51b8 51bd 51c1 51c5 51c8
51cc 51d0 51d3 51d6 51db 51de 51e1 51e4
51e5 51ea 51eb 1 51ed 51f2 51f6 51fa
51fd 5202 5207 520a 520e 520f 5214 5217
521c 521d 5222 5225 522a 522b 5230 5233
5237 523b 523f 5243 5246 5247 5249 524e
524f 5251 5252 5257 5258 525d 525f 5263
5266 526a 526e 5271 5275 5279 527c 527f
5284 5287 528a 528d 528e 5293 5294 1
5296 529b 529f 52a3 52a6 52ab 52b0 52b3
52b7 52b8 52bd 52be 52c3 52c5 52c9 52cc
52d0 52d4 52d7 52db 52df 52e2 52e6 52e7
52ec 52ee 52f2 52f5 52f9 52fd 5301 5303
5307 530b 530e 5312 5315 5316 531b 531e
5322 5326 532a 532e 5332 533e 5342 5346
5349 534d 5351 5353 1 5357 535b 535f
5362 5366 536a 536e 5372 5375 5379 537d
5380 5383 5388 538b 538e 5391 5392 5397
5398 1 539a 539f 53a3 53a7 53aa 53af
53b4 53b7 53bb 53bc 53c1 53c4 53c9 53ca
53cf 53d2 53d7 53d8 53dd 53e0 53e4 53e5
53ea 53ed 53f2 53f3 53f8 53fb 53ff 5403
5406 5409 540a 540c 540d 5412 5413 5418
541a 541e 5421 5423 5427 5429 5435 5437
5439 543a 543f 5443 5445 5451 5453 5457
545b 545e 5462 5465 5469 546c 546d 5472
5475 5479 547d 5480 5481 5483 5487 548a
548e 5491 5492 5494 5495 549a 1 549d
54a2 54a6 54aa 54ad 54b1 54b5 54b8 54bb
54c0 54c3 54c6 54c9 54ca 54cf 54d0 1
54d2 54d7 54db 54df 54e2 54e7 54ec 54ef
54f3 54f4 54f9 54fc 5501 5502 5507 550a
550f 5510 5515 5518 551c 5520 5524 5528
552b 552c 552e 5533 5534 5536 5537 553c
553f 5544 5545 554a 554d 5552 5553 5558
555b 555f 5560 5565 5568 556d 556e 5573
5574 5579 557b 557f 5582 5586 558a 558d
5591 5595 5598 559b 55a0 55a3 55a6 55a9
55aa 55af 55b0 1 55b2 55b7 55bb 55bf
55c2 55c7 55cc 55cf 55d3 55d4 55d9 55da
55df 55e1 55e5 55e8 55ec 55f0 55f3 55f7
55fb 55fe 5602 5606 5607 560c 560e 5612
5615 5617 561b 561e 5622 5625 5629 562d
5630 5634 5638 563c 563f 5640 5642 5645
5648 5649 564e 5652 5655 5659 565b 565f
5662 5666 566a 566e 5672 5676 567a 567e
5682 5686 568a 568e 5692 5696 569a 569e
56a2 56a6 56aa 56b6 56ba 56bf 56c3 56c6
56c7 56cc 56d0 56d4 56d7 56da 56de 56e0
56e4 56e8 56eb 56ee 56f2 56f4 56f8 56fc
56ff 5701 1 5705 5709 570d 5710 5714
5718 571c 5720 5723 5727 572b 572e 5731
5736 5739 573c 573f 5740 5745 5746 1
5748 574d 5751 5755 5758 575d 5762 5765
5769 576a 576f 5772 5777 5778 577d 5780
5785 5786 578b 578e 5792 5793 5798 579b
57a0 57a1 57a6 57a9 57ad 57b1 57b4 57b7
57b8 57ba 57bb 57c0 57c1 57c6 57c8 57cc
57cf 57d1 57d5 57d7 57e3 57e5 57e7 57e8
57ed 57f1 57f3 57ff 5801 5805 5809 580c
580d 580f 5812 5815 5816 581b 581f 5822
5826 5828 582c 582f 5831 5835 5839 583c
5840 5843 5846 5847 584c 5850 5853 5856
5857 585c 5860 5864 5868 586c 5870 5874
5878 587c 5880 5884 5888 588c 5890 5891
5893 5897 589b 589f 58a2 58a3 58a5 58a8
58ab 58ac 58b1 58b4 58b8 58bb 58bc 58c1
58c4 1 58c7 58cc 58d0 58d4 58d8 58dc
58e0 58e4 58e8 58ec 58f0 58f3 58f4 58f6
58fa 58fc 5900 5903 5907 590a 590b 5910
5913 5917 591b 591f 5923 5926 5927 5929
592d 592f 5933 5937 593a 593d 593e 5940
5943 5948 5949 594e 5952 5956 595a 595e
5961 5962 5964 5968 596a 596e 5972 5976
597a 597d 597e 5980 5984 5986 598a 598e
5991 5993 5997 599b 599e 59a2 59a5 59a6
59ab 59ae 59b2 59b6 59b9 59ba 59bc 59bf
59c2 59c3 59c8 59cc 59d0 59d4 59d7 59db
59df 59e2 59e3 59e5 59e9 59ed 59f0 59f1
59f3 59f6 59fa 59fe 5a02 5a06 5a0a 5a0e
5a12 5a16 5a1a 5a1e 5a22 5a2e 5a32 5a36
5a39 5a3d 5a41 5a43 1 5a47 5a4b 5a4f
5a52 5a56 5a5a 5a5e 5a62 5a65 5a69 5a6d
5a70 5a73 5a78 5a7b 5a7e 5a81 5a82 5a87
5a88 1 5a8a 5a8f 5a93 5a97 5a9a 5a9f
5aa4 5aa7 5aab 5aac 5ab1 5ab4 5ab9 5aba
5abf 5ac2 5ac7 5ac8 5acd 5ad0 5ad4 5ad5
5ada 5add 5ae2 5ae3 5ae8 5aeb 5aef 5af3
5af6 5af9 5afa 5afc 5afd 5b02 5b03 5b08
5b0a 5b0e 5b11 5b13 5b17 5b19 5b25 5b27
5b29 5b2a 5b2f 5b33 5b35 5b41 5b43 5b45
5b49 5b4d 5b51 5b55 5b59 5b5d 5b61 5b65
5b69 5b6d 5b79 5b7d 5b81 5b84 5b88 5b8c
5b8e 1 5b92 5b96 5b9a 5b9d 5ba1 5ba5
5ba9 5bad 5bb0 5bb4 5bb8 5bbb 5bbe 5bc3
5bc6 5bc9 5bcc 5bcd 5bd2 5bd3 1 5bd5
5bda 5bde 5be2 5be5 5bea 5bef 5bf2 5bf6
5bf7 5bfc 5bff 5c04 5c05 5c0a 5c0d 5c12
5c13 5c18 5c1b 5c1f 5c20 5c25 5c28 5c2d
5c2e 5c33 5c36 5c3a 5c3e 5c41 5c44 5c45
5c47 5c48 5c4d 5c4e 5c53 5c55 5c59 5c5c
5c5e 5c62 5c64 5c70 5c72 5c74 5c75 5c7a
5c7e 5c80 5c8c 5c8e 5c90 5c94 5c98 5c9b
5c9f 5ca3 5ca7 5caa 5cab 5cad 5cb0 5cb4
5cb8 5cbb 5cbc 5cbe 5cbf 5cc4 5cc8 5cca
5cce 5cd1 5cd5 5cd8 5cdc 5ce0 5ce4 5ce8
5cec 5cf0 5cf4 5cf8 5cfc 5d00 5d04 5d07
5d08 5d0a 5d0e 5d12 5d15 5d16 5d18 5d19
5d1b 5d1f 5d23 5d27 5d2a 5d2b 5d2d 5d30
5d33 5d34 5d39 5d3d 5d41 5d44 5d48 5d4c
5d4f 5d52 5d57 5d5a 5d5d 5d60 5d61 5d66
5d67 1 5d69 5d6e 5d72 5d76 5d79 5d7e
5d83 5d86 5d8a 5d8b 5d90 5d93 5d98 5d99
5d9e 5da1 5da6 5da7 5dac 5daf 5db3 5db7
5dbb 5dbf 5dc2 5dc3 5dc5 5dca 5dcb 5dcd
5dce 5dd3 5dd6 5ddb 5ddc 5de1 5de4 5de9
5dea 5def 5df2 5df6 5df7 5dfc 5dff 5e04
5e05 5e0a 5e0b 5e10 5e12 5e16 5e19 5e1d
5e21 5e24 5e28 5e2c 5e2f 5e32 5e37 5e3a
5e3d 5e40 5e41 5e46 5e47 1 5e49 5e4e
5e52 5e56 5e59 5e5e 5e63 5e66 5e6a 5e6b
5e70 5e71 5e76 5e78 5e7c 5e7f 5e83 5e87
5e8a 5e8e 5e92 5e95 5e99 5e9d 5e9e 5ea3
5ea7 5ea9 5ead 5eb0 5eb3 5eb4 5eb9 5ebd
5ec1 5ec5 5ec9 5ecd 5ed1 5ed5 5ed9 5edd
5ee1 5ee5 5ee9 5eed 5ef1 5ef5 5ef9 5efd
5f01 5f05 5f09 5f0d 5f11 5f1d 5f21 5f26
5f2a 5f2d 5f2e 5f33 5f37 5f3b 5f3e 5f41
5f45 5f47 5f4b 5f4f 5f52 5f55 5f59 5f5b
5f5f 5f63 5f66 5f68 1 5f6c 5f70 5f74
5f77 5f7b 5f7f 5f83 5f87 5f8a 5f8e 5f92
5f95 5f98 5f9d 5fa0 5fa3 5fa6 5fa7 5fac
5fad 1 5faf 5fb4 5fb8 5fbc 5fbf 5fc4
5fc9 5fcc 5fd0 5fd1 5fd6 5fd9 5fde 5fdf
5fe4 5fe7 5fec 5fed 5ff2 5ff5 5ff9 5ffa
5fff 6002 6007 6008 600d 6010 6014 6018
601b 601e 601f 6021 6022 6027 6028 602d
602f 6033 6036 6038 603c 603e 604a 604c
604e 604f 6054 6058 605a 6066 6068 606a
606e 6072 6075 6079 607d 6081 6082 6084
6088 608c 6090 6093 6097 609b 609e 60a1
60a6 60a9 60ac 60af 60b0 60b5 60b6 1
60b8 60bd 60c1 60c5 60c8 60cd 60d2 60d5
60d9 60da 60df 60e2 60e7 60e8 60ed 60f0
60f5 60f6 60fb 60fe 6102 6106 610a 610b
610d 6112 6113 6115 6116 611b 611e 6123
6124 6129 612c 6131 6132 6137 613a 613e
613f 6144 6147 614c 614d 6152 6153 6158
615a 615e 6161 6165 6169 616c 6170 6174
6177 617a 617f 6182 6185 6188 6189 618e
618f 1 6191 6196 619a 619e 61a1 61a6
61ab 61ae 61b2 61b3 61b8 61b9 61be 61c0
61c4 61c7 61cb 61cf 61d2 61d6 61da 61dd
61de 61e0 61e4 61e8 61e9 61ee 61f0 61f4
61f7 61fb 61ff 6202 6203 6205 6209 620c
6210 6213 6214 6216 6217 621c 6220 6224
6228 622c 6230 6234 6238 623c 6240 6244
6248 624c 6258 625c 6260 6263 6267 626b
626d 1 6271 6275 6279 627c 6280 6284
6288 628c 628f 6293 6297 629a 629d 62a2
62a5 62a8 62ab 62ac 62b1 62b2 1 62b4
62b9 62bd 62c1 62c4 62c9 62ce 62d1 62d5
62d6 62db 62de 62e3 62e4 62e9 62ec 62f1
62f2 62f7 62fa 62fe 62ff 6304 6307 630c
630d 6312 6315 6319 631d 6320 6323 6324
6326 6327 632c 632d 6332 6334 6338 633b
633d 6341 6343 634f 6351 6353 6354 6359
635d 635f 636b 636d 6371 6375 6378 6379
637b 637e 6381 6382 6387 638b 638f 6392
6396 639a 639d 63a0 63a5 63a8 63ab 63ae
63af 63b4 63b5 1 63b7 63bc 63c0 63c4
63c7 63cc 63d1 63d4 63d8 63d9 63de 63e1
63e6 63e7 63ec 63ef 63f4 63f5 63fa 63fd
6401 6405 6409 640d 6410 6411 6413 6418
6419 641b 641c 6421 6424 6429 642a 642f
6432 6437 6438 643d 6440 6444 6445 644a
644d 6452 6453 6458 6459 645e 6460 6464
6467 646b 646f 6472 6476 647a 647d 6480
6485 6488 648b 648e 648f 6494 6495 1
6497 649c 64a0 64a4 64a7 64ac 64b1 64b4
64b8 64b9 64be 64bf 64c4 64c6 64ca 64cd
64d1 64d5 64d8 64dc 64e0 64e3 64e7 64eb
64ec 64f1 64f3 64f7 64fa 64fe 6502 6506
650a 650e 6512 6515 6516 6518 651c 6520
6524 6527 6528 652a 652e 6531 6535 6538
6539 653b 653c 6541 6545 6548 654b 654c
6551 6555 6559 655d 6561 6565 6569 656d
6571 6575 6579 657d 6581 6585 6586 6588
658c 6590 6593 6594 6599 659c 65a0 65a4
65a8 65ac 65af 65b0 65b2 65b6 65b8 65bc
65c0 65c3 65c6 65c7 65c9 65cc 65d1 65d2
65d7 65db 65df 65e3 65e7 65ea 65eb 65ed
65f1 65f3 65f7 65fb 65ff 6603 6606 6607
6609 660d 660f 6613 6617 661a 661c 6620
6624 6627 662b 662e 6632 6636 6639 663a
663f 6642 6646 664a 664d 664e 6650 6653
6656 6657 665c 6660 6664 6668 666b 666f
6673 6676 6677 6679 667d 6681 6684 6685
6687 668a 668e 6692 6696 669a 669e 66a2
66a6 66aa 66ae 66b2 66b6 66c2 66c6 66ca
66cd 66d1 66d5 66d7 1 66db 66df 66e3
66e6 66ea 66ee 66f2 66f6 66f9 66fd 6701
6704 6707 670c 670f 6712 6715 6716 671b
671c 1 671e 6723 6727 672b 672e 6733
6738 673b 673f 6740 6745 6748 674d 674e
6753 6756 675b 675c 6761 6764 6768 6769
676e 6771 6776 6777 677c 677f 6783 6787
678a 678d 678e 6790 6791 6796 6797 679c
679e 67a2 67a5 67a7 67ab 67ad 67b9 67bb
67bd 67be 67c3 67c7 67c9 67d5 67d7 67d9
67dd 67e1 67e5 67e9 67ed 67f1 67f5 67f9
67fd 6801 680d 6811 6815 6818 681c 6820
6822 1 6826 682a 682e 6831 6835 6839
683d 6841 6844 6848 684c 684f 6852 6857
685a 685d 6860 6861 6866 6867 1 6869
686e 6872 6876 6879 687e 6883 6886 688a
688b 6890 6893 6898 6899 689e 68a1 68a6
68a7 68ac 68af 68b3 68b4 68b9 68bc 68c1
68c2 68c7 68ca 68ce 68d2 68d5 68d8 68d9
68db 68dc 68e1 68e2 68e7 68e9 68ed 68f0
68f2 68f6 68f8 6904 6906 6908 6909 690e
6912 6914 6920 6922 6924 6928 692c 692f
6933 6937 693a 693b 693d 6940 6943 6944
6949 694d 6951 6955 6959 695d 6961 6965
6969 696d 6971 6975 6979 6985 6989 698d
6990 6994 6998 699a 1 699e 69a2 69a6
69a9 69ad 69b1 69b5 69b9 69bc 69c0 69c4
69c7 69ca 69cf 69d2 69d5 69d8 69d9 69de
69df 1 69e1 69e6 69ea 69ee 69f1 69f6
69fb 69fe 6a02 6a03 6a08 6a0b 6a10 6a11
6a16 6a19 6a1e 6a1f 6a24 6a27 6a2b 6a2c
6a31 6a34 6a39 6a3a 6a3f 6a42 6a46 6a4a
6a4d 6a50 6a51 6a53 6a54 6a59 6a5a 6a5f
6a61 6a65 6a68 6a6a 6a6e 6a70 6a7c 6a7e
6a80 6a81 6a86 6a8a 6a8c 6a98 6a9a 6a9c
6aa0 6aa3 6aa5 6aa9 6aac 6ab0 6ab4 6ab8
6abb 6abc 6abe 6ac1 6ac5 6ac9 6acc 6acd
6acf 6ad0 6ad5 6ad8 6adc 6ae0 6ae3 6ae4
6ae6 6ae7 6aec 6af0 6af4 6af7 6afb 6aff
6b03 6b07 6b0b 6b0f 6b13 6b17 6b1b 6b1f
6b23 6b27 6b2b 6b2f 6b33 6b37 6b3b 6b3f
6b43 6b47 6b53 6b57 6b5c 6b60 6b63 6b64
6b69 6b6d 6b71 6b74 6b77 6b7b 6b7d 6b81
6b85 6b88 6b8b 6b8f 6b91 6b95 6b99 6b9c
6b9e 1 6ba2 6ba6 6baa 6bad 6bb1 6bb5
6bb9 6bbd 6bc0 6bc4 6bc8 6bcb 6bce 6bd3
6bd6 6bd9 6bdc 6bdd 6be2 6be3 1 6be5
6bea 6bee 6bf2 6bf5 6bfa 6bff 6c02 6c06
6c07 6c0c 6c0f 6c14 6c15 6c1a 6c1d 6c22
6c23 6c28 6c2b 6c2f 6c30 6c35 6c38 6c3d
6c3e 6c43 6c46 6c4a 6c4e 6c51 6c54 6c55
6c57 6c58 6c5d 6c5e 6c63 6c65 6c69 6c6c
6c6e 6c72 6c74 6c80 6c82 6c84 6c85 6c8a
6c8e 6c90 6c9c 6c9e 6ca2 6ca6 6ca9 6cad
6cb0 6cb4 6cb7 6cb8 6cbd 6cc0 6cc4 6cc7
6ccb 6ccf 6cd3 6cd7 6cdb 6cdf 6ce3 6ce7
6ceb 6cee 6cf2 6cf6 6cf9 6cfa 6cfc 6cfd
6cff 6d03 6d07 6d0b 6d0e 6d0f 6d11 6d14
6d17 6d18 6d1d 6d21 6d25 6d28 6d2c 6d30
6d33 6d36 6d3b 6d3e 6d41 6d44 6d45 6d4a
6d4b 1 6d4d 6d52 6d56 6d5a 6d5d 6d62
6d67 6d6a 6d6e 6d6f 6d74 6d77 6d7c 6d7d
6d82 6d85 6d8a 6d8b 6d90 6d93 6d97 6d9b
6d9f 6da0 6da2 6da7 6da8 6daa 6dab 6db0
6db3 6db8 6db9 6dbe 6dc1 6dc6 6dc7 6dcc
6dcf 6dd3 6dd4 6dd9 6ddc 6de1 6de2 6de7
6de8 6ded 6def 6df3 6df6 6dfa 6dfe 6e01
6e05 6e09 6e0c 6e0f 6e14 6e17 6e1a 6e1d
6e1e 6e23 6e24 1 6e26 6e2b 6e2f 6e33
6e36 6e3b 6e40 6e43 6e47 6e48 6e4d 6e4e
6e53 6e55 6e59 6e5c 6e60 6e64 6e67 6e6b
6e6f 6e72 6e73 6e75 6e79 6e7d 6e7e 6e83
6e85 6e89 6e8c 6e8e 6e92 6e95 6e99 6e9d
6ea1 6ea4 6ea5 6ea7 6eab 6ead 6eb1 6eb5
6eb9 6ebd 6ec1 6ec2 6ec4 6ec7 6ec8 6eca
6ecd 6ed1 6ed5 6ed9 6eda 6edc 6edf 6ee0
6ee2 6ee3 6ee8 6eeb 6eee 6ef1 6ef2 6ef7
6efa 6efd 6f00 6f01 6f06 6f07 6f09 6f0d
6f0f 6f13 6f17 6f1a 6f1e 6f22 6f26 6f2a
6f2e 6f32 6f36 6f3a 6f3e 6f42 6f46 6f4a
6f4e 6f52 6f56 6f5a 6f5e 6f62 6f66 6f6a
6f6e 6f72 6f76 6f7a 6f7e 6f82 6f86 6f89
6f8a 6f8c 6f8d 6f8f 6f93 6f97 6f9b 6f9e
6fa2 6fa6 6fa9 6fac 6fb1 6fb4 6fb7 6fba
6fbb 6fc0 6fc1 1 6fc3 6fc8 6fcc 6fd0
6fd3 6fd8 6fdd 6fe0 6fe4 6fe5 6fea 6fed
6ff2 6ff3 6ff8 6ffb 7000 7001 7006 7009
700d 7011 7015 7016 7018 701d 701e 7020
7021 7026 7029 702e 702f 7034 7037 703c
703d 7042 7045 7049 704a 704f 7052 7057
7058 705d 705e 7063 7065 7069 706c 7070
7074 7077 707b 707f 7082 7085 708a 708d
7090 7093 7094 7099 709a 1 709c 70a1
70a5 70a9 70ac 70b1 70b6 70b9 70bd 70be
70c3 70c4 70c9 70cb 70cf 70d2 70d6 70da
70dd 70e1 70e5 70e8 70e9 70eb 70ef 70f3
70f4 70f9 70fd 70ff 7103 7107 710a 710b
710d 7111 7114 7118 711b 711c 711e 711f
7124 7128 712c 712f 7130 7132 7135 7138
7139 713e 7141 7145 7149 714c 714d 714f
7152 7155 7156 715b 1 715e 7163 7167
716b 716e 7172 7176 7179 717c 7181 7184
7187 718a 718b 7190 7191 1 7193 7198
719c 71a0 71a3 71a8 71ad 71b0 71b4 71b5
71ba 71bd 71c2 71c3 71c8 71cb 71d0 71d1
71d6 71d9 71dd 71e1 71e5 71e9 71ec 71ed
71ef 71f4 71f5 71f7 71f8 71fd 7200 7205
7206 720b 720e 7213 7214 7219 721c 7220
7221 7226 7229 722e 722f 7234 7235 723a
723c 7240 7243 7247 724b 724e 7252 7256
7259 725c 7261 7264 7267 726a 726b 7270
7271 1 7273 7278 727c 7280 7283 7288
728d 7290 7294 7295 729a 729b 72a0 72a2
72a6 72a9 72ad 72b1 72b4 72b8 72bc 72bf
72c3 72c7 72c8 72cd 72cf 72d3 72d6 72da
72de 72e2 72e6 72ea 72ee 72f2 72f6 72fa
72fe 7302 730e 7312 7317 731b 731e 731f
7324 7328 732c 732f 7332 7336 7338 733c
7340 7343 7346 734a 734c 7350 7354 7357
7359 1 735d 7361 7365 7368 736c 7370
7374 7378 737b 737f 7383 7386 7389 738e
7391 7394 7397 7398 739d 739e 1 73a0
73a5 73a9 73ad 73b0 73b5 73ba 73bd 73c1
73c2 73c7 73ca 73cf 73d0 73d5 73d8 73dd
73de 73e3 73e6 73ea 73eb 73f0 73f3 73f8
73f9 73fe 7401 7405 7409 740c 740f 7410
7412 7413 7418 7419 741e 7420 7424 7427
7429 742d 742f 743b 743d 743f 7440 7445
7449 744b 7457 7459 745d 7461 7465 7469
746d 7471 7475 7479 747d 7481 7485 7491
7495 749a 749e 74a1 74a2 74a7 74ab 74af
74b2 74b5 74b9 74bb 74bf 74c3 74c6 74c9
74cd 74cf 74d3 74d7 74da 74dc 1 74e0
74e4 74e8 74eb 74ef 74f3 74f7 74fb 74fe
7502 7506 7509 750c 7511 7514 7517 751a
751b 7520 7521 1 7523 7528 752c 7530
7533 7538 753d 7540 7544 7545 754a 754d
7552 7553 7558 755b 7560 7561 7566 7569
756d 756e 7573 7576 757b 757c 7581 7584
7588 758c 758f 7592 7593 7595 7596 759b
759c 75a1 75a3 75a7 75aa 75ac 75b0 75b2
75be 75c0 75c2 75c3 75c8 75cc 75ce 75da
75dc 75de 75e2 75e6 75e9 75ed 75f1 75f5
75f6 75f8 75fc 7600 7604 7607 760b 760f
7612 7615 761a 761d 7620 7623 7624 7629
762a 1 762c 7631 7635 7639 763c 7641
7646 7649 764d 764e 7653 7656 765b 765c
7661 7664 7669 766a 766f 7672 7676 767a
767e 767f 7681 7686 7687 7689 768a 768f
7692 7697 7698 769d 76a0 76a5 76a6 76ab
76ae 76b2 76b3 76b8 76bb 76c0 76c1 76c6
76c7 76cc 76ce 76d2 76d5 76d9 76dd 76e0
76e4 76e8 76eb 76ee 76f3 76f6 76f9 76fc
76fd 7702 7703 1 7705 770a 770e 7712
7715 771a 771f 7722 7726 7727 772c 772d
7732 7734 7738 773b 773f 7743 7746 774a
774e 7751 7752 7754 7758 775c 775d 7762
7764 7768 776c 7770 7774 7778 777c 7780
7784 7788 778c 7790 7794 7798 779c 77a0
77a4 77a8 77ac 77b0 77b4 77b8 77bc 77c0
77c4 77c8 77cc 77d0 77d4 77d8 77dc 77e0
77e4 77e8 77f4 77f8 77fc 77ff 7803 7807
7809 1 780d 7811 7815 7818 781c 7820
7824 7828 782b 782f 7833 7836 7839 783e
7841 7844 7847 7848 784d 784e 1 7850
7855 7859 785d 7860 7865 786a 786d 7871
7872 7877 787a 787f 7880 7885 7888 788d
788e 7893 7896 789a 789b 78a0 78a3 78a8
78a9 78ae 78b1 78b5 78b9 78bc 78bf 78c0
78c2 78c3 78c8 78c9 78ce 78d0 78d4 78d7
78d9 78dd 78df 78eb 78ed 78ef 78f0 78f5
78f9 78fb 7907 7909 790d 7911 7914 7918
791b 791f 7922 7923 7928 792b 792e 792f
7934 7938 793c 793f 7943 7947 794a 794d
7952 7955 7958 795b 795c 7961 7962 1
7964 7969 796d 7971 7974 7979 797e 7981
7985 7986 798b 798e 7993 7994 7999 799c
79a1 79a2 79a7 79aa 79ae 79b2 79b6 79ba
79bd 79be 79c0 79c5 79c6 79c8 79c9 79ce
79d1 79d6 79d7 79dc 79df 79e4 79e5 79ea
79ed 79f1 79f2 79f7 79fa 79ff 7a00 7a05
7a06 7a0b 7a0d 7a11 7a14 7a18 7a1c 7a1f
7a23 7a27 7a2a 7a2d 7a32 7a35 7a38 7a3b
7a3c 7a41 7a42 1 7a44 7a49 7a4d 7a51
7a54 7a59 7a5e 7a61 7a65 7a66 7a6b 7a6c
7a71 7a73 7a77 7a7a 7a7e 7a82 7a85 7a89
7a8d 7a90 7a94 7a98 7a99 7a9e 7aa0 7aa4
7aa7 7aab 7aaf 7ab2 7ab6 7aba 7abb 7abd
7ac0 7ac3 7ac4 7ac9 7acd 7ad1 7ad4 7ad7
7adb 7adf 7ae3 7ae6 7aea 7aee 7af1 7af4
7af9 7afc 7aff 7b02 7b03 7b08 7b09 1
7b0b 7b10 7b14 7b18 7b1b 7b20 7b25 7b28
7b2c 7b2d 7b32 7b35 7b3a 7b3b 7b40 7b43
7b48 7b49 7b4e 7b51 7b55 7b59 7b5d 7b61
7b64 7b65 7b67 7b6c 7b6d 7b6f 7b70 7b75
7b78 7b7d 7b7e 7b83 7b86 7b8b 7b8c 7b91
7b94 7b98 7b99 7b9e 7ba1 7ba6 7ba7 7bac
7bad 7bb2 7bb4 7bb8 7bbb 7bbf 7bc3 7bc6
7bca 7bce 7bd1 7bd4 7bd9 7bdc 7bdf 7be2
7be3 7be8 7be9 1 7beb 7bf0 7bf4 7bf8
7bfb 7c00 7c05 7c08 7c0c 7c0d 7c12 7c13
7c18 7c1a 7c1e 7c21 7c25 7c29 7c2c 7c30
7c34 7c37 7c3b 7c3f 7c40 7c45 7c47 7c4b
7c4e 7c50 7c54 7c58 7c5b 7c5d 7c61 7c64
7c68 7c6c 7c70 7c74 7c78 7c7c 7c80 7c84
7c88 7c8c 7c90 7c94 7c97 7c9b 7c9f 7ca3
7ca6 7caa 7cae 7cb2 7cb6 7cba 7cbb 7cbd
7cc1 7cc5 7cc9 7ccc 7cd0 7cd4 7cd7 7cda
7cdf 7ce2 7ce5 7ce8 7ce9 7cee 7cef 1
7cf1 7cf6 7cfa 7cfe 7d01 7d06 7d0b 7d0e
7d12 7d13 7d18 7d1b 7d20 7d21 7d26 7d29
7d2e 7d2f 7d34 7d37 7d3b 7d3f 7d43 7d47
7d4a 7d4b 7d4d 7d52 7d53 7d55 7d56 7d5b
7d5e 7d63 7d64 7d69 7d6c 7d71 7d72 7d77
7d7a 7d7e 7d7f 7d84 7d87 7d8c 7d8d 7d92
7d93 7d98 7d9a 7d9e 7da1 7da5 7da9 7dac
7db0 7db4 7db7 7dbb 7dbf 7dc0 7dc5 7dc7
7dcb 7dcf 7dd2 7dd6 7dda 7ddd 7de1 7de5
7de8 7deb 7df0 7df3 7df6 7df9 7dfa 7dff
7e00 1 7e02 7e07 7e0b 7e0f 7e12 7e17
7e1c 7e1f 7e23 7e24 7e29 7e2a 7e2f 7e33
7e37 7e3a 7e3f 7e44 7e47 7e4b 7e4f 7e52
7e53 7e58 7e5b 7e60 7e61 7e66 7e69 7e6d
7e71 7e74 7e75 7e7a 7e7b 7e80 7e82 7e86
7e89 7e8d 7e91 7e95 7e99 7e9d 7ea1 7ea5
7ea9 7ead 7eb9 7ebe 7ec2 7ec6 7eca 7ece
7ed0 7ed1 7ed6 1 7eda 7ede 7ee2 7ee5
7ee9 7eed 7ef1 7ef5 7ef8 7efc 7f00 7f03
7f06 7f0b 7f0e 7f11 7f14 7f15 7f1a 7f1b
1 7f1d 7f22 7f26 7f2a 7f2d 7f32 7f37
7f3a 7f3e 7f3f 7f44 7f45 7f4a 7f4e 7f52
7f55 7f5a 7f5f 7f62 7f66 7f67 7f6c 7f6f
7f74 7f75 7f7a 7f7d 7f81 7f85 7f88 7f8b
7f8c 7f8e 7f8f 7f94 7f95 7f9a 7f9c 7fa0
7fa3 7fa7 7fab 7faf 7fb3 7fb7 7fbb 7fbf
7fcb 7fd0 7fd4 7fd8 7fdc 7fe0 7fe2 7fe6
7fe8 7ff4 7ff6 7ff8 7ff9 7ffe 8002 8004
8010 8014 8016 8017 8020 
24cd
2
0 1 a 6 10 :3 6 15 :3 6
16 :3 6 17 :3 6 e :3 6 e :3 6
15 :3 6 f :3 6 10 :2 6 1 3
a 13 a :2 1 4 12 1b 1a
:2 12 :2 4 11 1a 19 :2 11 :2 4 15
1e 1d :2 15 :2 4 17 20 1f :2 17
:2 4 14 1d 1c :2 14 :2 4 10 19
18 :2 10 :2 4 18 21 20 :2 18 :2 4
12 1b 1a :2 12 :2 4 e 17 16
:2 e :2 4 14 1d 1c :2 14 :2 4 11
1a 19 :2 11 :2 4 11 1a 19 :2 11
:2 4 16 1f 1e :2 16 :2 4 :3 13 :2 4
:3 11 :2 4 :3 12 :2 4 :3 12 :2 4 :3 13 :2 4
:3 f :2 4 :3 9 :2 4 :3 9 :2 4 :3 e :2 4
f 18 17 :2 f :2 4 f 18 17
:2 f :2 4 :2 f 1e f :2 4 :2 16 25
16 :2 4 :2 11 20 11 :2 4 :3 10 :2 4
:3 15 :2 4 :2 17 26 17 :2 4 :2 13 22
13 :2 4 :2 12 21 12 :2 4 :2 12 21
12 :2 4 :2 14 23 14 :2 4 :2 15 24
15 :2 4 :2 12 21 12 :2 4 :2 d 1c
d :2 4 :2 11 20 11 :2 4 :2 13 22
13 :2 4 e 17 16 :2 e :2 4 d
16 15 :2 d :2 4 f 18 17 :2 f
:2 4 :2 d 1c d :2 4 :2 e 1d e
:2 4 :2 c 1b c :2 4 :2 14 23 14
:2 4 :2 13 22 13 :2 4 :2 12 21 12
:2 4 :2 11 20 11 :2 4 :2 b 1a b
:2 4 :2 f 1e f :2 4 :2 e 1d e
:2 4 :2 10 1f 10 :2 4 :2 e 1d e
:2 4 :2 10 1f 10 :2 4 :2 13 22 13
:2 4 :2 f 1e f :2 4 :2 e 1d e
:2 4 :2 f 1e f :2 4 :2 c 1b c
:2 4 :2 b 1a b :2 4 :2 13 22 13
:2 4 :2 a 19 a :2 4 :2 12 21 12
:2 4 :2 11 20 11 :2 4 :2 e 1d e
:2 4 14 1d 1c :2 14 :2 4 14 1d
1c :2 14 :2 4 :2 17 26 17 :2 4 17
20 1f :2 17 :2 4 :2 13 22 13 :2 4
:2 14 23 14 :2 4 :2 f 1e f :2 4
:2 f 19 f :2 4 :2 f 19 f :2 4
:2 10 1a 10 :2 4 :2 10 1a 10 :2 4
:2 11 1b 11 :2 4 :2 11 1b 11 :2 4
:2 12 1c 12 :2 4 :2 12 1c 12 :2 4
9 12 11 :2 9 :2 4 :3 e :2 4 :3 e
4 7 11 1a :3 11 :2 7 11 1a
:3 11 7 4 e 17 :3 e 4 7
:2 11 23 :2 2d 3a :2 23 :3 7 :2 d 19
25 :2 2f 43 :2 25 58 5e 61 :2 58
6f 89 8 :2 6f d 10 :2 6f 1a
1d :2 6f b e :2 6f 13 16 :2 6f
1b 1e :2 6f 2d 30 :2 6f b e
:2 6f 13 16 1f 26 2b 2e :2 26
3e 41 :2 26 46 :2 1f 4f :2 16 :2 6f
b e :2 6f 13 16 1f 26 2b
2e :2 26 3f 42 :2 26 47 :2 1f 50
:2 16 :2 6f b e :2 6f 13 16 1f
27 :2 1f 31 :2 16 :2 6f b e :2 6f
13 16 1f 27 :2 1f 31 :2 16 :2 6f
b e :2 6f 13 16 1f 27 :2 1f
38 :2 16 :2 6f b e :2 6f 13 16
1f 27 :2 1f 32 :2 16 :2 6f b e
:2 6f 13 16 :2 6f 1b 1e :2 6f 28
2b :2 6f 30 33 :2 6f :2 7 4e :2 4
7 :2 11 23 :2 2d 39 3c 50 53
54 :2 50 :2 23 :3 7 :2 d 12 1e 62
65 :2 1e :2 7 57 :3 4 13 :2 4 14
:2 4 12 :2 4 15 :2 4 11 4 e
11 24 27 34 37 43 46 11
14 11 14 7 a 7 a 16
19 c 21 30 3e :4 7 15 c
21 d 10 24 :2 7 :2 10 1c 7
4 :2 c a :2 13 1f a d :2 17
29 :2 33 3f 43 57 5a 5b :2 57
:2 29 :3 d :2 13 18 24 68 6b :2 24
78 7b :2 24 7f 82 :2 24 8e 91
:2 24 99 9c :2 24 a8 ab b2 bb
be :2 ab :2 24 :2 d 5e :2 a :2 7 :4 13
:2 7 4 :3 1 8 :2 11 1c 1a :2 25
:2 1a 7 11 24 3b 47 a 19
23 33 3e 48 50 58 14 23
32 44 53 61 6e 80 14 28
3a 4a 5b a 12 19 34 3c
43 5f 69 a 18 26 34 a
1a 2a 3a a 1d 26 f 24
35 43 a 16 22 34 3f 47
50 58 a 1b 2b 3a 48 a
14 1d a 10 16 22 a 16
23 2f a 18 27 35 a 1a
25 f 10 24 :2 a :2 13 1f a
7 :2 f d :2 16 22 d 10 :2 1a
2c :2 36 42 46 5a 5d 5e :2 5a
:2 2c :3 10 :2 16 1b 27 6b 6e :2 27
7b 7e :2 27 82 85 :2 27 91 94
:2 27 9c 9f :2 27 ab ae b5 be
c1 :2 ae :2 27 :2 10 61 :2 d :2 a :4 16
:2 a 7 :3 35 b :2 14 1f 1d :2 28
:2 1d a 14 20 2b 62 6c 77
d 1b 1f 2c 3d 4b 59 5e
67 76 12 20 2d 38 46 55
d 1d 2a 39 43 53 5a 12
20 2d :2 d :2 16 22 d a :2 12
10 :2 19 25 10 13 :2 1d 2f :2 39
45 49 5d 60 61 :2 5d :2 2f :3 13
:2 19 1e 2a 6e 71 :2 2a 7e 81
:2 2a 85 88 :2 2a 94 97 :2 2a 9f
a2 :2 2a ae b1 b8 c1 c4 :2 b1
:2 2a :2 13 64 :2 10 :2 d :4 19 :2 d a
:3 38 e :2 17 22 20 :2 2b :2 20 d
10 :2 1a 2c :2 36 42 46 5a 5d
5e :2 5a :2 2c :3 10 :2 16 1b 27 6b
6e :2 27 7b 7e :2 27 82 85 :2 27
8f 92 9b a3 :2 ac :2 9b bf :2 92
:2 27 c7 ca :2 27 d2 d5 :2 27 da
dd :2 27 e7 ea :2 27 :2 10 61 :2 d
10 :2 1a 2c :2 36 42 45 59 5c
5d :2 59 :2 2c :3 10 :2 16 1b 27 6b
6e :2 27 :2 10 60 :3 d :2 18 2c :2 35
47 52 :2 d 3b :3 a 1b :2 a 1c
a e :2 19 21 30 40 :2 e 44
46 :2 44 d 4e :2 59 10 20 2f
:2 4e 33 36 :2 33 4d :2 d 10 :2 1a
2c :2 36 42 46 5a 5d 5e :2 5a
:2 2c :3 10 :2 16 1b 27 6b 6e :2 27
7b 7e :2 27 82 85 :2 27 8f 92
9b a3 :2 ac :2 9b c9 :2 92 :2 27 d1
d4 :2 27 dc df :2 27 e4 e7 :2 27
f1 f4 :2 27 :2 10 61 :2 d 10 :2 1a
2c :2 36 42 45 59 5c 5d :2 59
:2 2c :3 10 :2 16 1b 27 6b 6e :2 27
:2 10 60 :3 d :2 18 2c :2 35 51 15
:2 d 39 :2 a :4 f e d 2d 36
40 :2 2d 43 45 4e 5d :2 45 :2 2d
2c 64 61 10 17 :2 64 :2 61 2b
:2 d 10 :2 1a 2c :2 36 42 46 5a
5d 5e :2 5a :2 2c :3 10 :2 16 1b 27
6b 6e :2 27 7b 7e :2 27 82 85
:2 27 8f 92 9b a3 :2 ac :2 9b cd
:2 92 :2 27 d5 d8 :2 27 e0 e3 :2 27
e8 eb :2 27 f5 f8 :2 27 :2 10 61
:2 d 10 :2 1a 2c :2 36 42 45 59
5c 5d :2 59 :2 2c :3 10 :2 16 1b 27
6b 6e :2 27 :2 10 60 :3 d :2 18 2c
:2 35 55 15 :2 d 1b :2 a e :2 19
21 30 3e :2 e 42 45 :2 42 d
4c :2 57 5f 12 21 :2 4c 25 28
:2 25 4b :2 d 10 19 29 :2 10 2c
2e :2 2c 13 :2 1e 26 35 43 :2 13
47 4a :2 47 1d 28 35 3f 4a
4f 58 69 7b 1b 1c 29 1a
25 2d 34 :2 16 :2 1f 2b 16 13
:2 1b 19 :2 22 2e 19 1c :2 26 38
:2 42 4e 52 66 69 6a :2 66 :2 38
:3 1c :2 22 27 33 77 7a :2 33 87
8a :2 33 8e 91 :2 33 9d a0 :2 33
a8 ab :2 33 b7 ba c1 ca cd
:2 ba :2 33 :2 1c 6d :2 19 :2 16 :4 22 :2 16
13 :3 4c 17 :2 20 2b 29 :2 34 :2 29
16 20 2b 38 40 47 5f 6a
7e 1e :2 19 :2 22 2e 19 16 :2 1e
1c :2 25 31 1c 1f :2 29 3b :2 45
51 55 69 6c 6d :2 69 :2 3b :3 1f
:2 25 2a 36 7a 7d :2 36 8a 8d
:2 36 91 94 :2 36 a0 a3 :2 36 ab
ae :2 36 ba bd c4 cd d0 :2 bd
:2 36 :2 1f 70 :2 1c :2 19 :4 25 :2 19 16
:4 44 :2 13 16 :2 21 29 38 48 :2 16
4c 4e :2 4c 16 28 16 50 :2 13
4c 1d 28 35 3f 4a 4f 58
68 7a 1b 1c 29 1a 25 2d
34 :2 16 :2 1f 2b 16 13 :2 1b 19
:2 22 2e 19 1c :2 26 38 :2 42 4e
52 66 69 6a :2 66 :2 38 :3 1c :2 22
27 33 77 7a :2 33 87 8a :2 33
8e 91 :2 33 9d a0 :2 33 a8 ab
:2 33 b7 ba c1 ca cd :2 ba :2 33
:2 1c 6d :2 19 :2 16 :4 22 :2 16 13 :3 10
17 :2 20 2b 29 :2 34 :2 29 16 20
2b 38 40 47 60 6b 7f 1e
:2 19 :2 22 2e 19 16 :2 1e 1c :2 25
31 1c 1f :2 29 3b :2 45 51 55
69 6c 6d :2 69 :2 3b :3 1f :2 25 2a
36 7a 7d :2 36 8a 8d :2 36 91
94 :2 36 a0 a3 :2 36 ab ae :2 36
ba bd c4 cd d0 :2 bd :2 36 :2 1f
70 :2 1c :2 19 :4 25 :2 19 16 :4 44 :3 13
21 13 :4 10 13 1c 29 :2 13 2e
2c :2 37 :2 2c 1d 29 37 46 55
65 76 1c 29 16 1d 19 25
:3 23 19 :2 22 2e 19 2a 19 :2 22
2e 19 :4 16 13 :2 1b 19 :2 22 2e
19 1c :2 26 38 :2 42 4e 52 66
69 6a :2 66 :2 38 :3 1c :2 22 27 33
77 7a :2 33 87 8a :2 33 8e 91
:2 33 9d a0 :2 33 a8 ab :2 33 b7
ba c1 ca cd :2 ba :2 33 :2 1c 6d
:2 19 :2 16 :4 22 :2 16 13 :4 3d 1d 29
39 48 59 69 7c 1c 29 16
1d 19 25 :3 23 19 :2 22 2e 19
2a 19 :2 22 2e 19 :4 16 13 :2 1b
19 :2 22 2e 19 1c :2 26 38 :2 42
4e 52 66 69 6a :2 66 :2 38 :3 1c
:2 22 27 33 77 7a :2 33 87 8a
:2 33 8e 91 :2 33 9d a0 :2 33 a8
ab :2 33 b7 ba c1 ca cd :2 ba
:2 33 :2 1c 6d :2 19 :2 16 :4 22 :2 16 13
:7 10 14 :2 1d 28 26 :2 31 :2 26 :2 13
21 2b :2 21 13 41 :2 10 30 1a
2a 3a 23 19 26 37 41 17
:2 13 :2 1c 28 13 10 :2 18 16 :2 1f
2b 16 19 :2 23 35 :2 3f 4b 4f
63 66 67 :2 63 :2 35 :3 19 :2 1f 24
30 74 77 :2 30 84 87 :2 30 8b
8e :2 30 9a 9d :2 30 a5 a8 :2 30
b4 b7 be c7 ca :2 b7 :2 30 :2 19
6a :2 16 :2 13 :4 1f :2 13 10 :3 d 13
1c 28 :2 13 2b 2d :2 2b 16 :2 20
32 :2 3c 48 4c 60 63 64 :2 60
:2 32 :3 16 :2 1c 21 2d 71 74 :2 2d
81 84 :2 2d 88 8b :2 2d 95 98
a1 a9 :2 b2 :2 a1 cd :2 98 :2 2d d5
d8 :2 2d e0 e3 :2 2d e8 eb :2 2d
f5 f8 :2 2d :2 16 67 :2 13 16 :2 20
32 :2 3c 48 4b 5f 62 63 :2 5f
:2 32 :3 16 :2 1c 21 2d 71 74 :2 2d
:2 16 66 :3 13 :2 1e 32 :2 3b 55 1b
:2 13 2f :2 10 13 :2 1e 26 35 43
:2 13 47 4a :2 47 1d 28 35 3f
4a 4f 58 69 7b 1b 1c 29
1a 25 2d 34 :2 16 :2 1f 2b 16
13 :2 1b 19 :2 22 2e 19 1c :2 26
38 :2 42 4e 52 66 69 6a :2 66
:2 38 :3 1c :2 22 27 33 77 7a :2 33
87 8a :2 33 8e 91 :2 33 9d a0
:2 33 a8 ab :2 33 b7 ba c1 ca
cd :2 ba :2 33 :2 1c 6d :2 19 :2 16 :4 22
:2 16 13 :3 4c 17 :2 20 2b 29 :2 34
:2 29 16 20 2b 38 40 47 5f
6a 7e 1e :2 19 :2 22 2e 19 16
:2 1e 1c :2 25 31 1c 1f :2 29 3b
:2 45 51 55 69 6c 6d :2 69 :2 3b
:3 1f :2 25 2a 36 7a 7d :2 36 8a
8d :2 36 91 94 :2 36 a0 a3 :2 36
ab ae :2 36 ba bd c4 cd d0
:2 bd :2 36 :2 1f 70 :2 1c :2 19 :4 25 :2 19
16 :4 44 :2 13 4c 1d 28 35 3f
4a 4f 58 68 7a 1b 1c 29
1a 25 2d 34 :2 16 :2 1f 2b 16
13 :2 1b 19 :2 22 2e 19 1c :2 26
38 :2 42 4e 52 66 69 6a :2 66
:2 38 :3 1c :2 22 27 33 77 7a :2 33
87 8a :2 33 8e 91 :2 33 9d a0
:2 33 a8 ab :2 33 b7 ba c1 ca
cd :2 ba :2 33 :2 1c 6d :2 19 :2 16 :4 22
:2 16 13 :3 10 17 :2 20 2b 29 :2 34
:2 29 16 20 2b 38 40 47 60
6b 7f 1e :2 19 :2 22 2e 19 16
:2 1e 1c :2 25 31 1c 1f :2 29 3b
:2 45 51 55 69 6c 6d :2 69 :2 3b
:3 1f :2 25 2a 36 7a 7d :2 36 8a
8d :2 36 91 94 :2 36 a0 a3 :2 36
ab ae :2 36 ba bd c4 cd d0
:2 bd :2 36 :2 1f 70 :2 1c :2 19 :4 25 :2 19
16 :4 44 :2 13 :5 10 1e 31 3f 4a
58 67 24 34 3f 4b 54 61
:2 4b 24 :2 1e 10 13 1c 28 :2 13
2b 2d :2 2b 13 21 2b :2 21 13
2f 16 :2 20 32 :2 3c 48 4c 60
63 64 :2 60 :2 32 :3 16 :2 1c 21 2d
71 74 :2 2d 81 84 :2 2d 88 8b
:2 2d 95 98 a1 a9 :2 a1 b6 :2 98
:2 2d be c1 :2 2d c9 cc :2 2d d1
d4 :2 2d de e1 :2 2d :2 16 67 :2 13
16 :2 20 32 :2 3c 48 4b 5f 62
63 :2 5f :2 32 :3 16 :2 1c 21 2d 71
74 :2 2d :2 16 66 :3 13 :2 1e 32 3b
47 :2 32 4b 56 :2 13 :4 10 :4 d a
2b 11 1a 24 :2 11 2a 27 33
42 :2 2a :2 27 10 4b 54 5e :2 4b
61 63 :2 61 4a :2 10 d 1d d
10 19 23 :2 10 28 26 31 3b
:2 28 :2 26 13 :2 1d 2f :2 39 45 48
5c 5f 60 :2 5c :2 2f :3 13 :2 19 1e
2a 6e 71 :2 2a 7e 81 :2 2a 85
88 :2 2a 92 95 9e a6 :2 af :2 9e
d0 :2 95 :2 2a :2 13 63 :2 10 13 :2 1d
2f :2 39 45 48 5c 5f 60 :2 5c
:2 2f :3 13 :2 19 1e 2a 6e 71 :2 2a
:2 13 63 :3 10 :2 1b 31 :2 3a 5a :2 10
d 3e 13 1c 26 :2 13 2b 29
34 3e :2 2b :2 29 10 20 10 41
3e :3 d 1b d 17 27 15 24
26 36 47 4b 56 16 19 23
14 17 2b 2d 14 16 2b 2d
14 16 20 29 :2 10 :2 19 25 10
d :2 15 13 :2 1c 28 13 16 :2 20
32 :2 3c 48 4c 60 63 64 :2 60
:2 32 :3 16 :2 1c 21 2d 71 74 :2 2d
81 84 :2 2d 88 8b :2 2d 97 9a
:2 2d a2 a5 :2 2d b1 b4 bb c4
c7 :2 b4 :2 2d :2 16 67 :2 13 :2 10 :4 1c
:2 10 d :3 66 10 19 25 :2 10 28
2a :2 28 13 :2 1d 2f :2 39 45 49
5d 60 61 :2 5d :2 2f :3 13 :2 19 1e
2a 6e 71 :2 2a 7e 81 :2 2a 85
88 :2 2a 92 95 9e a6 :2 af :2 9e
ca :2 95 :2 2a d2 d5 :2 2a dd e0
:2 2a e5 e8 :2 2a f2 f5 :2 2a :2 13
64 :2 10 13 :2 1d 2f :2 39 45 48
5c 5f 60 :2 5c :2 2f :3 13 :2 19 1e
2a 6e 71 :2 2a :2 13 63 :3 10 :2 1b
2f :2 38 52 18 :2 10 2c :2 d 17
27 37 20 31 34 39 53 13
17 24 27 36 3a 48 4b 16
19 26 37 3a 44 11 19 20
23 46 4a :2 10 :2 19 25 10 d
:2 15 13 :2 1c 28 13 16 :2 20 32
:2 3c 48 4c 60 63 64 :2 60 :2 32
:3 16 :2 1c 21 2d 71 74 :2 2d 81
84 :2 2d 88 8b :2 2d 97 9a :2 2d
a2 a5 :2 2d b1 b4 bb c4 c7
:2 b4 :2 2d :2 16 67 :2 13 :2 10 :4 1c :2 10
d :3 66 10 19 25 :2 10 28 2a
:2 28 13 :2 1d 2f :2 39 45 49 5d
60 61 :2 5d :2 2f :3 13 :2 19 1e 2a
6e 71 :2 2a 7e 81 :2 2a 85 88
:2 2a 92 95 9e a6 :2 af :2 9e c3
:2 95 :2 2a cb ce :2 2a d6 d9 :2 2a
de e1 :2 2a eb ee :2 2a :2 13 64
:2 10 13 :2 1d 2f :2 39 45 48 5c
5f 60 :2 5c :2 2f :3 13 :2 19 1e 2a
6e 71 :2 2a :2 13 63 :3 10 :2 1b 2f
:2 38 4b 56 :2 10 2c :3 d 1d :2 d
1b 2d 3b 46 54 60 21 2f
:2 60 :2 1b d 66 2b :2 a d 16
22 :2 d 25 27 :2 25 d 1b 25
:2 1b d 29 :2 a d :2 17 29 :2 33
3f 43 57 5a 5b :2 57 :2 29 :3 d
:2 13 18 24 68 6b :2 24 78 7b
:2 24 7f 82 :2 24 8c 8f 98 a0
:2 98 ad :2 8f :2 24 b5 b8 :2 24 c0
c3 :2 24 c8 cb :2 24 d5 d8 :2 24
:2 d 5e :2 a d :2 17 29 :2 33 3f
42 56 59 5a :2 56 :2 29 :3 d :2 13
18 24 68 6b :2 24 :2 d 5d :3 a
:2 15 29 32 3e :2 29 42 4d :2 a
7 38 :4 e d :4 30 2f :2 d a
1b :2 a 1c a e :2 19 21 30
40 :2 e 44 46 :2 44 d 4e :2 59
10 20 2f :2 4e 33 36 :2 33 4d
:2 d 10 :2 1a 2c :2 36 42 46 5a
5d 5e :2 5a :2 2c :3 10 :2 16 1b 27
6b 6e :2 27 7b 7e :2 27 82 85
:2 27 8f 92 9b a3 :2 ac :2 9b c9
:2 92 :2 27 d1 d4 :2 27 dc df :2 27
e4 e7 :2 27 f1 f4 :2 27 :2 10 61
:2 d 10 :2 1a 2c :2 36 42 45 59
5c 5d :2 59 :2 2c :3 10 :2 16 1b 27
6b 6e :2 27 :2 10 60 :3 d :2 18 2c
:2 35 51 15 :2 d 39 :2 a 14 20
2b 12 20 2d 12 20 2d 3e
4b :2 d :2 16 22 d a :2 12 10
:2 19 25 10 13 :2 1d 2f :2 39 45
49 5d 60 61 :2 5d :2 2f :3 13 :2 19
1e 2a 6e 71 :2 2a 7e 81 :2 2a
85 88 :2 2a 94 97 :2 2a 9f a2
:2 2a ae b1 b8 c1 c4 :2 b1 :2 2a
:2 13 64 :2 10 :2 d :4 19 :2 d a :3 4e
d 14 20 23 :2 d 26 28 :2 26
d 20 d 2c d 20 d :5 a
17 :2 a 17 a e :2 19 21 30
3e :2 e 42 45 :2 42 d 4c :2 57
5f 12 21 :2 4c 25 28 :2 25 4b
:2 d 2f 38 41 :2 2f 47 44 50
59 :2 47 :2 44 2e :2 d 10 :2 1b 23
32 40 :2 10 44 47 :2 44 1a 25
39 46 18 19 26 37 44 :2 13
:2 1c 28 13 10 :2 18 16 :2 1f 2b
16 19 :2 23 35 :2 3f 4b 4f 63
66 67 :2 63 :2 35 :3 19 :2 1f 24 30
74 77 :2 30 84 87 :2 30 8b 8e
:2 30 9a 9d :2 30 a5 a8 :2 30 b4
b7 be c7 ca :2 b7 :2 30 :2 19 6a
:2 16 :2 13 :4 1f :2 13 10 :3 49 10 20
:2 10 1b :2 10 1d 10 d 49 13
:2 1e 26 36 45 :2 13 49 4c :2 49
1a 25 32 3a 41 5a 65 6a
:2 18 :2 13 :2 1c 28 13 10 :2 18 16
:2 1f 2b 16 19 :2 23 35 :2 3f 4b
4f 63 66 67 :2 63 :2 35 :3 19 :2 1f
24 30 74 77 :2 30 84 87 :2 30
8b 8e :2 30 9a 9d :2 30 a5 a8
:2 30 b4 b7 be c7 ca :2 b7 :2 30
:2 19 6a :2 16 :2 13 :4 1f :2 13 10 :3 4e
10 1d :2 28 2f 3f :2 1d :2 10 20
21 :2 20 :2 10 1e 35 43 4e 59
5f 65 28 34 42 55 :2 1e 10
14 1d 29 :2 14 2c 2e :2 2c 13
:4 37 36 35 :2 13 1d 32 3e 1c
29 3a 4e 5c 67 6f 76 16
1d 19 25 :3 23 19 :2 22 2e 19
2a 19 :2 22 2e 19 :4 16 13 :2 1b
19 :2 22 2e 19 1c :2 26 38 :2 42
4e 52 66 69 6a :2 66 :2 38 :3 1c
:2 22 27 33 77 7a :2 33 87 8a
:2 33 8e 91 :2 33 9d a0 :2 33 a8
ab :2 33 b7 ba c1 ca cd :2 ba
:2 33 :2 1c 6d :2 19 :2 16 :4 22 :2 16 13
:4 56 :2 10 13 1a 26 29 :2 13 2c
2e :2 2c 13 22 13 32 13 22
13 :5 10 1e 2c 3a 45 50 5a
66 6c 1f 2d 3d 4a 55 1f
2b 2e 39 :2 1e 10 1a 22 29
40 48 4f 68 72 83 91 18
1e 24 30 43 4f 18 19 2d
:2 13 :2 1c 28 13 10 :2 18 16 :2 1f
2b 16 19 :2 23 35 :2 3f 4b 4f
63 66 67 :2 63 :2 35 :3 19 :2 1f 24
30 74 77 :2 30 84 87 :2 30 8b
8e :2 30 9a 9d :2 30 a5 a8 :2 30
b4 b7 be c7 ca :2 b7 :2 30 :2 19
6a :2 16 :2 13 :4 1f :2 13 10 :3 4e 10
20 :2 10 1e 35 43 4e 59 5f
65 28 34 42 55 :2 1e :2 10 1e
28 :2 1e :2 10 :2 19 25 10 13 :2 1d
2f :2 39 45 48 5c 5f 60 :2 5c
:2 2f :3 13 :2 19 1e 2a 6e 71 :2 2a
7e 81 :2 2a 85 88 :2 2a 92 95
9e a6 :2 af :2 9e ba :2 95 :2 2a c2
c5 :2 2a cd d0 :2 2a d5 d8 :2 2a
ec ef :2 2a :2 13 63 :3 10 :2 1b 2d
:2 36 40 55 :2 10 d 4e 49 13
1c 25 :2 13 2a 28 33 3c :2 2a
:2 28 10 1b 24 2d :2 1b 30 32
3b 44 :2 32 :2 1b :2 10 1d 10 d
3f 49 13 1c 25 :2 13 28 2a
:2 28 10 1b :2 10 1d 10 1a 28
18 19 26 :2 13 :2 1c 28 13 10
:2 18 16 :2 1f 2b 16 19 :2 23 35
:2 3f 4b 4f 63 66 67 :2 63 :2 35
:3 19 :2 1f 24 30 74 77 :2 30 84
87 :2 30 8b 8e :2 30 9a 9d :2 30
a5 a8 :2 30 b4 b7 be c7 ca
:2 b7 :2 30 :2 19 6a :2 16 :2 13 :4 1f :2 13
10 :3 2c d 2c 49 13 1c 25
:2 13 2a 28 33 3c :2 2a :2 28 10
1b 24 2d :2 1b 30 32 3b 44
:2 32 :2 1b :2 10 1f :2 10 18 10 13
1c 2d :2 13 30 32 :2 30 13 1b
1a 1d :2 1b 35 38 :2 1b 45 48
:2 1b 1f 22 :2 1b 2f 32 :2 1b 1a
1d :2 1b 46 49 51 5a 63 :2 51
:2 49 :2 1b :2 13 18 :2 26 13 34 13
1b 1a 1d :2 1b 35 38 :2 1b 41
44 :2 1b 6a 6d :2 1b 1f 22 :2 1b
1a 1d :2 1b 46 49 51 5a 63
:2 51 :2 49 :2 1b :2 13 18 :2 26 13 :5 10
16 1f 30 :2 16 33 35 :2 33 1c
2b :2 16 19 23 :2 19 :2 22 2e 19
29 19 :2 22 2e 19 :4 16 37 1c
2b :2 16 19 23 :2 19 :2 22 2e 19
29 19 :2 22 2e 19 :4 16 :4 13 17
:2 20 2c 29 :2 35 :2 29 :3 16 45 :2 13
10 14 3f 13 1c 2d :2 13 30
32 :2 30 16 1c :3 16 :2 1f 2b 16
13 :2 1b 19 :2 22 2e 19 1c :2 26
38 :2 42 4e 52 66 69 6a :2 66
:2 38 :3 1c :2 22 27 33 77 7a :2 33
87 8a :2 33 8e 91 :2 33 9d a0
:2 33 a8 ab :2 33 b7 ba c1 ca
cd :2 ba :2 33 :2 1c 6d :2 19 :2 16 :4 22
:2 16 13 :4 34 16 1c :3 16 :2 1f 2b
16 13 :2 1b 19 :2 22 2e 19 1c
:2 26 38 :2 42 4e 52 66 69 6a
:2 66 :2 38 :3 1c :2 22 27 33 77 7a
:2 33 87 8a :2 33 8e 91 :2 33 9d
a0 :2 33 a8 ab :2 33 b7 ba c1
ca cd :2 ba :2 33 :2 1c 6d :2 19 :2 16
:4 22 :2 16 13 :7 10 :4 14 13 16 1f
30 :2 16 33 35 :2 33 19 :2 23 35
:2 3f 4b 4f 63 66 67 :2 63 :2 35
:3 19 :2 1f 24 30 74 77 :2 30 84
87 :2 30 8b 8e :2 30 98 9b a4
ac :2 b5 :2 a4 c8 :2 9b :2 30 d0 d3
:2 30 db de :2 30 e3 e6 :2 30 f3
f6 :2 30 :2 19 6a :2 16 19 :2 23 35
:2 3f 4b 4e 62 65 66 :2 62 :2 35
:3 19 :2 1f 24 30 74 77 :2 30 :2 19
69 :3 16 :2 21 35 :2 3e 50 5e :2 16
37 19 :2 23 35 :2 3f 4b 4f 63
66 67 :2 63 :2 35 :3 19 :2 1f 24 30
74 77 :2 30 84 87 :2 30 8b 8e
:2 30 98 9b a4 ac :2 b5 :2 a4 c8
:2 9b :2 30 d0 d3 :2 30 db de :2 30
e3 e6 :2 30 ef f2 :2 30 :2 19 6a
:2 16 19 :2 23 35 :2 3f 4b 4e 62
65 66 :2 62 :2 35 :3 19 :2 1f 24 30
74 77 :2 30 :2 19 69 :3 16 :2 21 35
:2 3e 50 5a :2 16 :4 13 29 :2 10 1a
25 32 3a 41 57 62 67 :2 18
:2 13 :2 1c 28 13 10 :2 18 16 :2 1f
2b 16 19 :2 23 35 :2 3f 4b 4f
63 66 67 :2 63 :2 35 :3 19 :2 1f 24
30 74 77 :2 30 84 87 :2 30 8b
8e :2 30 9a 9d :2 30 a5 a8 :2 30
b4 b7 be c7 ca :2 b7 :2 30 :2 19
6a :2 16 :2 13 :4 1f :2 13 10 :3 3f 10
1b :2 10 1d 10 3f 49 :2 d a
5d 10 19 22 :2 10 28 25 31
42 :2 28 :2 25 10 19 28 :2 10 2d
2b 36 40 :2 2d :2 2b 13 :2 1d 2f
:2 39 45 49 5d 60 61 :2 5d :2 2f
:3 13 :2 19 1e 2a 6e 71 :2 2a 7e
81 :2 2a 85 88 :2 2a 92 95 9e
a6 :2 af :2 9e ba :2 95 :2 2a c2 c5
:2 2a cd d0 :2 2a d5 d8 :2 2a e2
e5 :2 2a :2 13 64 :2 10 13 :2 1d 2f
:2 39 45 48 5c 5f 60 :2 5c :2 2f
:3 13 :2 19 1e 2a 6e 71 :2 2a :2 13
63 :3 10 :2 1b 2f :2 38 42 4d :2 10
43 :2 d 10 19 22 :2 10 25 27
:2 25 10 23 10 29 14 1d 26
:2 14 29 2b :2 29 13 32 3b 44
:2 32 47 49 :2 47 31 :2 13 16 :2 20
32 :2 3c 48 4b 5f 62 63 :2 5f
:2 32 :3 16 :2 1c 21 2d 71 74 :2 2d
81 84 :2 2d 88 8b :2 2d 95 98
a1 a9 :2 b2 :2 a1 c3 :2 98 :2 2d :2 16
66 :2 13 16 :2 20 32 :2 3c 48 4b
5f 62 63 :2 5f :2 32 :3 16 :2 1c 21
2d 71 74 :2 2d :2 16 66 :3 13 :2 1e
34 :2 3d 4d :2 13 54 :3 10 23 10
:4 d :4 11 10 1a 29 18 19 2d
:2 13 :2 1c 28 13 10 :2 18 16 :2 1f
2b 16 19 :2 23 35 :2 3f 4b 4f
63 66 67 :2 63 :2 35 :3 19 :2 1f 24
30 74 77 :2 30 84 87 :2 30 8b
8e :2 30 9a 9d :2 30 a5 a8 :2 30
b4 b7 be c7 ca :2 b7 :2 30 :2 19
6a :2 16 :2 13 :4 1f :2 13 10 :3 2e 14
:2 1d 28 26 :2 31 :2 26 13 46 4f
60 :2 46 65 63 16 22 :2 65 :2 63
45 :2 13 16 :2 20 32 :2 3c 48 4c
60 63 64 :2 60 :2 32 :3 16 :2 1c 21
2d 71 74 :2 2d 81 84 :2 2d 88
8b :2 2d 95 98 a1 a9 :2 b2 :2 a1
ca :2 98 :2 2d d2 d5 :2 2d dd e0
:2 2d e5 e8 :2 2d f8 fb :2 2d :2 16
67 :2 13 16 :2 20 32 :2 3c 48 4b
5f 62 63 :2 5f :2 32 :3 16 :2 1c 21
2d 71 74 :2 2d :2 16 66 :3 13 :2 1e
32 :2 3b 52 1b :2 13 26 :2 10 2e
:3 d 18 :2 d 1a d 10 19 24
:2 10 27 29 :2 27 10 1d 10 2c
:2 d 17 2c 3a 46 10 1e 2a
39 10 1e 27 2e 3b 44 51
5a 16 2a 10 17 13 1f :3 1d
13 :2 1c 28 13 24 13 :2 1c 28
13 :4 10 d :2 15 13 :2 1c 28 13
16 :2 20 32 :2 3c 48 4c 60 64
65 :2 60 :2 32 :3 16 :2 1c 21 2d 72
75 :2 2d 82 85 :2 2d 89 8c :2 2d
98 9b :2 2d a3 a6 :2 2d b2 b5
bc c5 c8 :2 b5 :2 2d :2 16 68 :2 13
:2 10 :4 1c :2 10 d :3 45 10 19 24
:2 10 27 2a :2 27 10 1d 10 2c
:2 d 45 5d :2 a d 17 19 :2 17
d 1d 1e :2 1d :2 d 20 37 45
50 5b 61 67 2d 39 47 5a
:2 20 d 11 1a 26 :2 11 29 2b
:2 29 10 :4 34 33 32 :3 10 1e 33
41 4c 56 67 26 38 44 :2 1e
10 53 :2 d :4 11 :2 10 23 33 41
4c :2 23 10 2e 13 1a 26 29
:2 13 2c 2e :2 2c 13 26 36 44
4f :2 26 13 32 13 26 36 44
4f :2 26 13 :4 10 :4 d :4 11 10 13
1c 27 :2 13 2a 2c :2 2a 13 21
:2 2a 31 3a 45 :2 31 49 :2 52 :2 21
20 13 1d 28 35 3d 44 5f
6a 6f :2 1b :2 16 :2 1f 2b 16 13
:2 1b 19 :2 22 2e 19 1c :2 26 38
:2 42 4e 52 66 6a 6b :2 66 :2 38
:3 1c :2 22 27 33 78 7b :2 33 88
8b :2 33 8f 92 :2 33 9e a1 :2 33
a9 ac :2 33 b8 bb c2 cb ce
:2 bb :2 33 :2 1c 6e :2 19 :2 16 :4 22 :2 16
13 :4 2e 1d 28 35 3d 44 5f
6a 6f :2 1b :2 16 :2 1f 2b 16 13
:2 1b 19 :2 22 2e 19 1c :2 26 38
:2 42 4e 52 66 6a 6b :2 66 :2 38
:3 1c :2 22 27 33 78 7b :2 33 88
8b :2 33 8f 92 :2 33 9e a1 :2 33
a9 ac :2 33 b8 bb c2 cb ce
:2 bb :2 33 :2 1c 6e :2 19 :2 16 :4 22 :2 16
13 :8 10 1c 25 2f :2 1c 32 34
3d 4c :2 34 :2 1c 10 2f :3 d 1f
:2 d 20 2e 39 47 51 61 24
30 39 42 :2 30 46 4f 60 :2 46
:2 20 d 10 19 2a :2 10 2d 30
:2 2d 13 :2 1d 2f :2 39 45 49 5d
61 62 :2 5d :2 2f :3 13 :2 19 1e 2a
6f 72 :2 2a 7f 82 :2 2a 86 89
:2 2a 93 96 9f a7 :2 b0 :2 9f c8
:2 96 :2 2a d0 d3 :2 2a db de :2 2a
e3 e6 :2 2a f0 f3 :2 2a :2 13 65
:2 10 13 :2 1d 2f :2 39 45 48 5c
60 61 :2 5c :2 2f :3 13 :2 19 1e 2a
6f 72 :2 2a :2 13 64 :3 10 :2 1b 2f
:2 38 4f 5a :2 10 d 32 13 1d
1f :2 1d 1a 2f 3d 4b 54 5b
68 71 7e 87 13 22 2b 37
47 57 60 6d 13 27 19 2d
13 1a 16 22 :3 20 16 :2 1f 2b
16 27 16 :2 1f 2b 16 :4 13 10
:2 18 16 :2 1f 2b 16 19 :2 23 35
:2 3f 4b 4f 63 67 68 :2 63 :2 35
:3 19 :2 1f 24 30 75 78 :2 30 85
88 :2 30 8c 8f :2 30 9b 9e :2 30
a6 a9 :2 30 b5 b8 bf c8 cb
:2 b8 :2 30 :2 19 6b :2 16 :2 13 :4 1f :2 13
10 :4 21 32 :3 d 1b 25 :2 1b d
10 :2 1a 2c :2 36 42 46 5a 5e
5f :2 5a :2 2c :3 10 :2 16 1b 27 6c
6f :2 27 7c 7f :2 27 83 86 :2 27
90 93 9c a4 :2 9c b1 :2 93 :2 27
b9 bc :2 27 c4 c7 :2 27 cc cf
:2 27 d9 dc :2 27 :2 10 62 :2 d 10
:2 1a 2c :2 36 42 45 59 5d 5e
:2 59 :2 2c :3 10 :2 16 1b 27 6c 6f
:2 27 :2 10 61 :3 d :2 18 2c 35 41
:2 2c 45 50 :2 d 1b :2 a d 16
20 :2 d 26 23 2f 3e :2 26 :2 23
17 27 15 24 34 16 2a 14
29 14 1e 27 :2 10 :2 19 25 10
d :2 15 13 :2 1c 28 13 16 :2 20
32 :2 3c 48 4c 60 64 65 :2 60
:2 32 :3 16 :2 1c 21 2d 72 75 :2 2d
82 85 :2 2d 89 8c :2 2d 98 9b
:2 2d a3 a6 :2 2d b2 b5 bc c5
c8 :2 b5 :2 2d :2 16 68 :2 13 :2 10 :4 1c
:2 10 d :3 41 10 19 25 :2 10 28
2a :2 28 13 :2 1d 2f :2 39 45 49
5d 61 62 :2 5d :2 2f :3 13 :2 19 1e
2a 6f 72 :2 2a 7f 82 :2 2a 86
89 :2 2a 93 96 9f a7 :2 b0 :2 9f
cb :2 96 :2 2a d3 d6 :2 2a de e1
:2 2a e6 e9 :2 2a f3 f6 :2 2a :2 13
65 :2 10 13 :2 1d 2f :2 39 45 48
5c 60 61 :2 5c :2 2f :3 13 :2 19 1e
2a 6f 72 :2 2a :2 13 64 :3 10 :2 1b
2f :2 38 52 18 :2 10 2c :3 d 1d
:2 d 1f 28 32 :2 1f d 10 19
27 :2 10 2c 2a 35 3f :2 2c :2 2a
10 20 21 :2 20 :2 10 23 3a 48
53 5e 64 6a 2d 39 47 5a
:2 23 10 :4 14 :2 13 26 36 44 4f
:2 26 13 31 16 1d 29 2c :2 16
2f 31 :2 2f 16 29 39 47 52
:2 29 16 35 16 29 39 47 52
:2 29 16 :4 13 :5 10 1d 10 :4 14 13
16 1f 2a :2 16 2d 2f :2 2d 16
24 :2 2d 34 3d 48 :2 34 4c :2 55
:2 24 23 16 20 2b 38 40 47
62 6d 72 :2 1e :2 19 :2 22 2e 19
16 :2 1e 1c :2 25 31 1c 1f :2 29
3b :2 45 51 55 69 6d 6e :2 69
:2 3b :3 1f :2 25 2a 36 7b 7e :2 36
8b 8e :2 36 92 95 :2 36 a1 a4
:2 36 ac af :2 36 bb be c5 ce
d1 :2 be :2 36 :2 1f 71 :2 1c :2 19 :4 25
:2 19 16 :4 31 20 2b 38 40 47
62 6d 72 :2 1e :2 19 :2 22 2e 19
16 :2 1e 1c :2 25 31 1c 1f :2 29
3b :2 45 51 55 69 6d 6e :2 69
:2 3b :3 1f :2 25 2a 36 7b 7e :2 36
8b 8e :2 36 92 95 :2 36 a1 a4
:2 36 ac af :2 36 bb be c5 ce
d1 :2 be :2 36 :2 1f 71 :2 1c :2 19 :4 25
:2 19 16 :7 13 16 1f 2b :2 16 2e
30 :2 2e 20 2c 3c 1e 1f 2c
3d 51 5f 6a 72 79 :2 19 :2 22
2e 19 16 :2 1e 1c :2 25 31 1c
1f :2 29 3b :2 45 51 55 69 6d
6e :2 69 :2 3b :3 1f :2 25 2a 36 7b
7e :2 36 8b 8e :2 36 92 95 :2 36
a1 a4 :2 36 ac af :2 36 bb be
c5 ce d1 :2 be :2 36 :2 1f 71 :2 1c
:2 19 :4 25 :2 19 16 :4 32 :2 13 32 :3 10
1c 25 33 :2 1c 36 38 41 50
:2 38 :2 1c 53 55 5e 69 :2 55 :2 1c
:2 10 22 10 1a 2f 3d 4b 54
5b 67 70 13 20 2e 3c 4a
53 13 2a 42 19 2d 13 1a
16 22 :3 20 16 :2 1f 2b 16 27
16 :2 1f 2b 16 :4 13 10 :2 18 16
:2 1f 2b 16 19 :2 23 35 :2 3f 4b
4f 63 67 68 :2 63 :2 35 :3 19 :2 1f
24 30 75 78 :2 30 85 88 :2 30
8c 8f :2 30 9b 9e :2 30 a6 a9
:2 30 b5 b8 bf c8 cb :2 b8 :2 30
:2 19 6b :2 16 :2 13 :4 1f :2 13 10 :3 42
14 :2 1d 28 26 :2 31 :2 26 :2 13 25
:2 13 21 2f 3a 48 52 62 6d
1f 22 2b 3c :2 22 :2 21 13 16
1f 2b :2 16 2e 31 :2 2e 19 :2 23
35 :2 3f 4b 4f 63 67 68 :2 63
:2 35 :3 19 :2 1f 24 30 75 78 :2 30
85 88 :2 30 8c 8f :2 30 99 9c
a5 ad :2 a5 ba :2 9c :2 30 c2 c5
:2 30 cd d0 :2 30 d5 d8 :2 30 e2
e5 :2 30 :2 19 6b :2 16 19 :2 23 35
:2 3f 4b 4e 62 66 67 :2 62 :2 35
:3 19 :2 1f 24 30 75 78 :2 30 :2 19
6a :3 16 :2 21 35 3e 4a :2 35 4e
59 :2 16 33 :2 13 41 :3 10 1c 25
33 :2 1c 10 42 10 22 2a 33
3d :2 33 4c :2 2a 4f 51 5a 64
:2 5a 6f :2 51 :2 2a 29 24 26 :2 29
28 30 32 :2 28 :2 22 10 :5 d 1b
2f 3d 48 52 5d 25 31 3b
49 25 34 44 50 25 31 3e
4c 25 33 42 55 25 31 3d
46 51 :2 3d :2 1b d 10 :2 1a 2c
:2 36 42 46 5a 5e 5f :2 5a :2 2c
:3 10 :2 16 1b 27 6c 6f :2 27 7c
7f :2 27 83 86 :2 27 90 93 9c
a4 :2 9c b1 :2 93 :2 27 b9 bc :2 27
c4 c7 :2 27 cc cf :2 27 d9 dc
:2 27 :2 10 62 :2 d 10 :2 1a 2c :2 36
42 45 59 5d 5e :2 59 :2 2c :3 10
:2 16 1b 27 6c 6f :2 27 :2 10 61
:3 d :2 18 2c 35 41 :2 2c 45 50
:2 d a 41 10 19 29 :2 10 2f
2c 38 48 :2 2f :2 2c 11 1a 29
:2 11 2c 2e :2 2c 10 36 3f 4f
:2 36 52 54 :2 52 35 :2 10 13 :2 1d
2f :2 39 45 49 5d 61 62 :2 5d
:2 2f :3 13 :2 19 1e 2a 6f 72 :2 2a
7f 82 :2 2a 86 89 :2 2a 93 96
9f a7 :2 b0 :2 9f bb :2 96 :2 2a c3
c6 :2 2a ce d1 :2 2a d6 d9 :2 2a
e3 e6 :2 2a :2 13 65 :2 10 13 :2 1d
2f :2 39 45 48 5c 60 61 :2 5c
:2 2f :3 13 :2 19 1e 2a 6f 72 :2 2a
:2 13 64 :3 10 :2 1b 2f :2 38 42 4d
:2 10 57 :2 d 17 2c 40 10 1e
27 2e 3a 43 16 2a 10 17
13 1f :3 1d 13 :2 1c 28 13 24
13 :2 1c 28 13 :4 10 d :2 15 13
:2 1c 28 13 16 :2 20 32 :2 3c 48
4c 60 64 65 :2 60 :2 32 :3 16 :2 1c
21 2d 72 75 :2 2d 82 85 :2 2d
89 8c :2 2d 98 9b :2 2d a3 a6
:2 2d b2 b5 bc c5 c8 :2 b5 :2 2d
:2 16 68 :2 13 :2 10 :4 1c :2 10 d :3 4b
17 23 31 3a 41 4d 56 16
23 34 41 10 17 13 1f :3 1d
13 :2 1c 28 13 24 13 :2 1c 28
13 :4 10 d :2 15 13 :2 1c 28 13
16 :2 20 32 :2 3c 48 4c 60 64
65 :2 60 :2 32 :3 16 :2 1c 21 2d 72
75 :2 2d 82 85 :2 2d 89 8c :2 2d
98 9b :2 2d a3 a6 :2 2d b2 b5
bc c5 c8 :2 b5 :2 2d :2 16 68 :2 13
:2 10 :4 1c :2 10 d :4 4b 41 :3 a 18
22 :2 18 a d :2 17 29 :2 33 3f
43 57 5b 5c :2 57 :2 29 :3 d :2 13
18 24 69 6c :2 24 79 7c :2 24
80 83 :2 24 8d 90 99 a1 :2 99
ae :2 90 :2 24 b6 b9 :2 24 c1 c4
:2 24 c9 cc :2 24 d6 d9 :2 24 :2 d
5f :2 a d :2 17 29 :2 33 3f 42
56 5a 5b :2 56 :2 29 :3 d :2 13 18
24 69 6c :2 24 :2 d 5e :3 a :2 15
29 32 3e :2 29 42 4d :2 a 4e
38 14 17 24 27 34 37 43
46 17 1a 17 1a d 10 d
10 1c 1f 12 21 30 3e :4 d
1b 12 27 30 33 47 :2 d :2 16
22 d a :2 12 10 :2 19 25 10
13 :2 1d 2f :2 39 45 49 5d 61
62 :2 5d :2 2f :3 13 :2 19 1e 2a 6f
72 :2 2a 7f 82 :2 2a 86 89 :2 2a
95 98 :2 2a a0 a3 :2 2a af b2
b9 c2 c5 :2 b2 :2 2a :2 13 65 :2 10
:2 d :4 19 :2 d a :3 7 12 :2 1b 26
24 :2 2f :2 24 11 :3 d 10 :2 1a 2c
:2 36 42 46 5a 5e 5f :2 5a :2 2c
:3 10 :2 16 1b 27 6c 6f :2 27 7c
7f :2 27 83 86 :2 27 90 93 9c
a4 :2 ad :2 9c c0 :2 93 :2 27 c8 cb
:2 27 d3 d6 :2 27 db de :2 27 f2
f5 :2 27 :2 10 62 :2 d 10 :2 1a 2c
:2 36 42 45 59 5d 5e :2 59 :2 2c
:3 10 :2 16 1b 27 6c 6f :2 27 :2 10
61 :3 d :2 18 2c :2 35 47 15 :2 d
3f :2 a d :2 18 1f 2e :2 d 3d
3f :2 3d d :2 16 22 d 10 :2 1a
2c :2 36 42 46 5a 5e 5f :2 5a
:2 2c :3 10 :2 16 1b 27 6c 6f :2 27
7c 7f :2 27 83 86 :2 27 90 93
9c a4 :2 ad :2 9c b8 :2 93 :2 27 c0
c3 :2 27 cb ce :2 27 d3 d6 :2 27
ea ed :2 27 :2 10 62 :2 d 10 :2 1a
2c :2 36 42 45 59 5d 5e :2 59
:2 2c :3 10 :2 16 1b 27 6c 6f :2 27
:2 10 61 :3 d :2 18 2c :2 35 3f 54
:2 d 41 :2 a :4 7 35 :3 4 11 :2 4
15 :2 4 12 :2 4 14 :2 1d :2 4 :2 d
19 30 3e 49 58 :2 19 4 7
:2 11 23 :2 2d 39 3c 50 54 55
:2 50 :2 23 :3 7 :2 d 12 1e 63 66
:2 1e 73 76 :2 1e 7a 7d :2 1e 87
8a 93 9b :2 a4 :2 93 af :2 8a :2 1e
b7 ba :2 1e c2 c5 :2 1e ca cd
:2 1e d7 da :2 1e :2 7 58 :3 4 :2 f
21 :2 2a 34 3f :2 4 1 9 12
9 a :2 14 26 :2 30 3c 40 54
58 59 :2 54 :2 26 :3 a :2 10 15 21
66 69 :2 21 :3 a :2 10 15 39 5c
5f :2 68 :2 39 76 79 :2 39 81 84
:2 8d :2 39 :2 a 5c :3 7 c 15 1e
2c a 13 1e f e 7 e
7 e 7 29 :2 4 :2 9 7 :2 10
1c :2 7 :2 11 23 :2 2d 39 3d 51
55 56 :2 51 :2 23 :3 7 :2 d 12 1e
63 66 :2 1e :3 7 :2 d 12 36 42
45 :2 36 4d 50 :2 36 5c 5f 66
6f 72 :2 5f :2 36 :2 7 59 :2 4 7
c 1b a 13 1e f e 7
e 7 e 7 :2 4 :4 10 :2 4 :8 1

24cd
4
0 :2 1 :4 3 :4 4
:4 5 :4 6 :4 7 :4 8
:4 9 :4 a :4 b 2
:4 c :2 1 :7 e :7 f
:7 10 :7 11 :7 12 :7 13
:7 14 :7 15 :7 16 :7 17
:7 18 :7 19 :7 1a :5 1b
:5 1c :5 1d :5 1e :5 1f
:5 20 :5 21 :5 22 :5 23
:7 24 :7 25 :6 26 :6 27
:6 28 :5 29 :5 2a :6 2b
:6 2c :6 2d :6 2e :6 2f
:6 30 :6 31 :6 32 :6 33
:6 34 :7 35 :7 36 :7 37
:6 38 :6 39 :6 3a :6 3b
:6 3c :6 3d :6 3e :6 3f
:6 40 :6 41 :6 42 :6 43
:6 44 :6 45 :6 46 :6 47
:6 48 :6 49 :6 4a :6 4b
:6 4c :6 4d :6 4e :6 4f
:7 50 :7 51 :6 52 :7 53
:6 54 :6 55 :6 56 :6 57
:6 58 :6 59 :6 5a :6 5b
:6 5c :6 5d :6 5e :7 5f
:5 60 :5 61 :7 64 :7 67
:7 69 :b 6b :11 6c 6d
:2 6c :2 6d :2 6c :2 6d
:2 6c :2 6e :2 6c :2 6e
:2 6c :2 6e :2 6c :2 6e
:2 6c :2 6f :2 6c :12 6f
:2 6c :2 70 :2 6c :12 70
:2 6c :2 71 :2 6c :9 71
:2 6c :2 72 :2 6c :9 72
:2 6c :2 73 :2 6c :9 73
:2 6c :2 74 :2 6c :9 74
:2 6c :2 75 :2 6c :2 75
:2 6c :2 75 :2 6c :2 75
:2 6c :2 75 :4 6c :3 6b
:11 78 :b 79 :3 78 :3 7e
:3 7f :3 80 :3 81 :3 84
:8 87 :2 88 :2 89 :2 8a
:4 8b :4 8c 8d 8e
8f :2 90 :2 91 :3 92
87 :5 93 86 :2 95
:5 97 :11 98 :24 99 :3 98
:2 96 :6 95 94 :3 6a
:a 9f :4 a1 :8 a2 :8 a3
:5 a4 :8 a5 :4 a6 :4 a7
:3 a8 :4 a9 :8 aa :5 ab
:3 ac :4 ad :4 ae :4 af
:3 b0 b1 :2 b2 a1
:5 b3 a0 :2 b5 :5 b7
:11 b8 :24 b9 :3 b8 :2 b6
:6 b5 b4 :3 9f :a c0
:6 c2 :a c3 :6 c4 :7 c5
:3 c6 c2 :5 c7 c1
:2 c9 :5 cb :11 cc :24 cd
:3 cc :2 ca :6 c9 c8
:3 c0 :a d3 :11 d4 :30 d5
:3 d4 :11 d7 :b d8 :3 d7
:a da :3 d3 :3 dd :3 de
:10 df :3 e0 :2 df :4 e0
:3 df :11 e1 :30 e2 :3 e1
:11 e4 :b e5 :3 e4 :7 e7
e8 :2 e7 e0 :2 df
:16 ed :2 ee :7 ed :11 f0
:30 f1 :3 f0 :11 f3 :b f4
:3 f3 :7 f6 f7 :2 f6
ee :2 ed :11 fa :2 fb
:2 fa :4 fb :3 fa :9 fc
:c fd :9 ff 100 :2 101
:4 102 ff :5 103 fe
:2 105 :5 107 :11 108 :24 109
:3 108 :2 106 :6 105 104
:3 fd :a 10e :8 110 111
110 :5 112 10f :2 114
:5 116 :11 117 :24 118 :3 117
:2 115 :6 114 113 :6 10e
:c 11e :3 11f :3 11e fd
:9 123 124 :2 125 :4 126
123 :5 127 122 :2 129
:5 12b :11 12c :24 12d :3 12c
:2 12a :6 129 128 :3 121
:a 132 :8 134 135 134
:5 136 133 :2 138 :5 13a
:11 13b :24 13c :3 13b :2 139
:6 138 137 :6 132 :3 142
121 :3 fd :b 145 :7 147
:2 148 147 :6 149 :5 14a
149 :5 14c 14b :3 149
146 :2 14f :5 151 :11 152
:24 153 :3 152 :2 150 :6 14f
14e :4 145 :7 159 :2 15a
159 :6 15b :5 15c 15b
:5 15e 15d :3 15b 158
:2 161 :5 163 :11 164 :24 165
:3 164 :2 162 :6 161 160
:4 157 :3 145 :a 16b :6 16c
:3 16b fc :3 170 171
:4 172 173 170 :5 174
16f :2 176 :5 178 :11 179
:24 17a :3 179 :2 177 :6 176
175 :3 16e :9 180 :11 181
:30 182 :3 181 :11 184 :b 185
:3 184 :7 187 188 :2 187
:3 180 :c 18b :9 18d 18e
:2 18f :4 190 18d :5 191
18c :2 193 :5 195 :11 196
:24 197 :3 196 :2 194 :6 193
192 :3 18b :a 19c :8 19e
19f 19e :5 1a0 19d
:2 1a2 :5 1a4 :11 1a5 :24 1a6
:3 1a5 :2 1a3 :6 1a2 1a1
:6 19c 18b :9 1ad 1ae
:2 1af :4 1b0 1ad :5 1b1
1ac :2 1b3 :5 1b5 :11 1b6
:24 1b7 :3 1b6 :2 1b4 :6 1b3
1b2 :3 1ab :a 1bc :8 1be
1bf 1be :5 1c0 1bd
:2 1c2 :5 1c4 :11 1c5 :24 1c6
:3 1c5 :2 1c3 :6 1c2 1c1
:6 1bc 1ab :3 18b :7 1cd
:8 1ce 1cf :3 1cd :9 1d1
:6 1d2 1d1 :11 1d4 :2e 1d5
:3 1d4 :11 1d7 :b 1d8 :3 1d7
:c 1da 1d3 :3 1d1 16e
:3 fc 1dd fb :1a 1dd
:3 1de :d 1df :11 1e0 :20 1e1
:3 1e0 :11 1e3 :b 1e4 :3 1e3
:9 1e6 1e7 1df :d 1e7
:3 1e8 1e7 :3 1df :3 1ec
:2 1ee 1ef :6 1f0 :3 1f1
:4 1f2 :4 1f3 :4 1f4 1ee
:5 1f5 1ed :2 1f7 :5 1f9
:11 1fa :24 1fb :3 1fa :2 1f8
:6 1f7 1f6 :3 1dd :9 200
:11 201 :30 202 :3 201 :11 204
:b 205 :3 204 :7 207 208
:2 207 :3 200 :3 20d :5 20e
:8 20f :6 210 :6 211 20d
:5 212 20c :2 214 :5 216
:11 217 :24 218 :3 217 :2 215
:6 214 213 :3 1dd :9 21e
:11 21f :30 220 :3 21f :11 222
:b 223 :3 222 :a 225 :3 21e
:3 228 :7 22e :2 22f :5 22e
1dd fb :2 fa :9 233
:6 234 :3 233 :11 237 :2e 238
:3 237 :11 23a :b 23b :3 23a
:c 23d 23e c0 :c 23e
:3 23f :3 240 :10 242 :3 243
:2 242 :4 243 :3 242 :11 244
:30 245 :3 244 :11 247 :b 248
:3 247 :7 24a 24b :2 24a
243 :2 242 :3 24f :3 250
:5 251 24f :5 252 24e
:2 254 :5 256 :11 257 :24 258
:3 257 :2 255 :6 254 253
:3 23e :a 25e :3 25f 25e
:3 261 260 :3 25e :3 264
:3 265 :11 26d :2 26e :2 26d
:4 26e :3 26d :e 26e :2 26d
:c 26f :4 271 272 :4 273
271 :5 274 270 :2 276
:5 278 :11 279 :24 27a :3 279
:2 277 :6 276 275 :3 26f
:3 2ce :3 2cf :3 2d0 2d2
26f :c 2d2 :8 2d4 2d5
2d6 2d4 :5 2d7 2d3
:2 2d9 :5 2db :11 2dc :24 2dd
:3 2dc :2 2da :6 2d9 2d8
:3 2d2 :9 2e2 :6 2e4 :8 2e5
:4 2e6 :3 2e5 :12 2e8 :3 2ea
:8 2eb 2ea :6 2ec :5 2ed
2ec :5 2ef 2ee :3 2ec
2e9 :2 2f2 :5 2f4 :11 2f5
:24 2f6 :3 2f5 :2 2f3 :6 2f2
2f1 :6 2e8 :a 2fc :3 2fd
2fc :3 2ff 2fe :3 2fc
:9 302 :5 303 :4 304 :3 302
:a 307 :6 308 309 :2 30a
307 :5 30b 306 :2 30d
:5 30f :11 310 :24 311 :3 310
:2 30e :6 30d 30c :3 2d2
:3 316 :8 317 :4 318 :3 317
:6 31a :5 31c :11 31d :30 31e
:3 31d :a 320 321 2d2
26f :d 321 :f 322 :3 323
324 321 26f :9 324
:3 325 :3 326 :2 329 32a
:2 32b 329 :5 32c 328
:2 32e :5 330 :11 331 :24 332
:3 331 :2 32f :6 32e 32d
:3 324 336 324 26f
:d 336 :f 337 :3 338 :3 339
:9 33b :2 33c :2 33d :2 33c
:2 33d :2 33c :2 33d :2 33c
:2 33e :2 33c :2 33e :2 33c
:2 33f :2 33c :9 33f :3 33c
:5 341 33b :2 343 :2 344
:2 343 :2 344 :2 343 :2 344
:2 343 :2 344 :2 343 :2 345
:2 343 :2 346 :2 343 :9 346
:3 343 :5 348 342 :3 33b
34b :9 34c :4 34d :3 34e
:5 34f 34e :5 351 350
:3 34e 34c :4 354 :3 355
:5 356 355 :5 358 357
:3 355 353 :3 34c :a 35c
:2 35d :3 35c 34b 35f
336 :9 361 :4 363 :5 364
362 :2 366 :5 368 :11 369
:24 36a :3 369 :2 367 :6 366
365 :4 361 :4 370 :5 371
36f :2 373 :5 375 :11 376
:24 377 :3 376 :2 374 :6 373
372 :4 36e :3 361 :5 37e
:9 37f :11 380 :30 381 :3 380
:11 383 :b 384 :3 383 :a 386
37f :11 388 :30 389 :3 388
:11 38b :b 38c :3 38b :a 38e
387 :3 37f :3 37e :8 393
394 395 393 :5 396
392 :2 398 :5 39a :11 39b
:24 39c :3 39b :2 399 :6 398
397 :3 336 :3 3a1 :3 3a2
336 :3 26f 3a4 26e
:d 3a4 :d 3a5 :11 3a6 :30 3a7
:3 3a6 :11 3a9 :b 3aa :3 3a9
:a 3ac :3 3a5 :9 3af :3 3b0
3af :16 3b2 :11 3b3 :20 3b4
:3 3b3 :11 3b6 :b 3b7 :3 3b6
:9 3b9 :3 3b2 :3 3bc 3b1
:3 3af :5 3cc :2 3ce 3cf
:2 3d0 3ce :5 3d1 3cd
:2 3d3 :5 3d5 :11 3d6 :24 3d7
:3 3d6 :2 3d4 :6 3d3 3d2
:3 3cc :11 3dc :2 3dd :7 3dc
:11 3de :30 3df :3 3de :11 3e1
:b 3e2 :3 3e1 :7 3e4 3e5
:2 3e4 3dd :2 3dc :3 3cc
:3 423 :3 424 :9 425 :3 426
:3 425 :4 42c :4 42d :8 42e
:2 42f 42c :6 430 :5 431
430 :5 433 432 :3 430
42b :2 436 :5 438 :11 439
:24 43a :3 439 :2 437 :6 436
435 :3 3a4 :9 43f :3 440
:3 43f 3a4 26e :2 26d
:5 447 :6 448 :8 449 :4 44a
:3 449 :12 44c :7 44d :3 44e
:3 44d :3 44c :5 452 :8 453
452 :a 455 :8 456 455
:8 458 457 :3 455 454
:3 452 :5 45c :9 45d :10 45e
:8 461 462 463 461
:5 464 460 :2 466 :5 468
:11 469 :24 46a :3 469 :2 467
:6 466 465 :4 45d :8 470
471 472 470 :5 473
46f :2 475 :5 477 :11 478
:24 479 :3 478 :2 476 :6 475
474 :4 46e :3 45d :f 47f
:3 45c :3 484 :7 485 :b 486
:3 485 :9 489 :11 48a :30 48b
:3 48a :11 48d :b 48e :3 48d
:a 490 491 489 :5 491
:a 493 :8 494 :2 495 :2 496
493 :6 497 :5 498 497
:5 49a 499 :3 497 492
:2 49d :5 49f :11 4a0 :24 4a1
:3 4a0 :2 49e :6 49d 49c
:4 491 :3 489 :6 4a7 :11 4a8
:2e 4a9 :3 4a8 :11 4ab :b 4ac
:3 4ab :c 4ae :3 447 :d 4b1
:2 4b4 4b5 :2 4b6 :2 4b7
:2 4b8 :3 4b9 4b4 :5 4ba
4b3 :2 4bc :5 4be :11 4bf
:24 4c0 :3 4bf :2 4bd :6 4bc
4bb :3 4b1 :9 4c5 :11 4c6
:30 4c7 :3 4c6 :11 4c9 :b 4ca
:3 4c9 :7 4cc 4cd :2 4cc
:3 4c5 :3 4d0 :7 4d2 :d 4d3
:6 4d4 :8 4d5 :4 4d6 :3 4d5
:5 4d8 :8 4d9 4d8 :a 4db
:8 4dc 4db :8 4de 4dd
:3 4db 4da :3 4d8 :3 4e2
:5 4e3 :9 4e4 :10 4e5 :8 4e7
4e8 4e9 4e7 :5 4ea
4e6 :2 4ec :5 4ee :11 4ef
:24 4f0 :3 4ef :2 4ed :6 4ec
4eb :4 4e4 :8 4f6 4f7
4f8 4f6 :5 4f9 4f5
:2 4fb :5 4fd :11 4fe :24 4ff
:3 4fe :2 4fc :6 4fb 4fa
:4 4f4 :3 4e4 :9 505 :3 507
508 :8 509 507 :5 50a
506 :2 50c :5 50e :11 50f
:24 510 :3 50f :2 50d :6 50c
50b :6 505 :3 4e3 :17 517
:3 519 :8 51c :6 51d :3 51e
:2 51f 51c :6 520 :5 521
520 :5 523 522 :3 520
51b :2 526 :5 528 :11 529
:24 52a :3 529 :2 527 :6 526
525 :3 4d3 :a 52f :3 531
:8 532 :6 533 :3 532 :9 536
:11 537 :2e 538 :3 537 :11 53a
:b 53b :3 53a :c 53d :3 536
:3 52f :7 541 4d3 :16 543
:2 544 :3 543 :2 544 :5 543
542 :3 4d3 :7 54a :4 54b
:4 54c :4 54d :4 54e :7 54f
:3 54a :11 551 :2e 552 :3 551
:11 554 :b 555 :3 554 :c 557
558 4b1 :d 558 :16 559
:11 55a :30 55b :3 55a :11 55d
:b 55e :3 55d :a 560 :3 559
:3 585 :6 586 :2 587 585
:6 588 :5 589 588 :5 58b
58a :3 588 584 :2 58e
:5 590 :11 591 :24 592 :3 591
:2 58f :6 58e 58d :3 558
:7 59c :4 59d 59c :6 59e
:5 59f 59e :5 5a1 5a0
:3 59e 59b :2 5a4 :5 5a6
:11 5a7 :24 5a8 :3 5a7 :2 5a5
:6 5a4 5a3 :4 558 :3 4b1
:6 5b0 :11 5b1 :2e 5b2 :3 5b1
:11 5b4 :b 5b5 :3 5b4 :c 5b7
23e c0 :8 5ba :2 5bb
:2 5bc :2 5bd :4 5be :4 5bf
5c0 5c1 5c2 :2 5c3
:5 5c4 5ba :5 5c5 5b9
:2 5c7 :5 5c9 :11 5ca :24 5cb
:3 5ca :2 5c8 :6 5c7 5c6
:3 5b8 :d 5d1 :11 5d2 :30 5d3
:3 5d2 :11 5d5 :b 5d6 :3 5d5
:7 5d8 5d9 :2 5d8 :3 5d1
:b 5dc :5 5dd :11 5de :30 5df
:3 5de :11 5e1 :b 5e2 :3 5e1
:a 5e4 :3 5dc 5b8 :3 c0
:3 9f :3 5e9 :3 5ea :3 5eb
:5 5ed :b 5ee :11 5f0 :30 5f1
:3 5f0 :a 5f3 6a :3 5f6
:11 5f7 :b 5f8 :17 5f9 :3 5f7
:2 5fb :3 5fc :3 5fd 5fe
5fc 5fb 5fc :3 5ff
:3 5f6 :2 600 :5 602 :11 603
:b 604 :18 605 :3 603 :2 607
608 :3 609 60a 608
607 608 :3 60b :2 601
:6 600 5f5 :7 1 
8022
4
:3 0 1 :3 0 2
:a 0 24c8 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
56 0 7 4
:3 0 5 :7 0 9
8 :3 0 7 :3 0
6 :7 0 d c
:3 0 d 7c 0
b 7 :3 0 8
:7 0 11 10 :3 0
a :3 0 9 :7 0
15 14 :3 0 11
a2 0 f a
:3 0 b :7 0 19
18 :3 0 a :3 0
c :7 0 1d 1c
:3 0 15 :2 0 13
a :3 0 d :7 0
21 20 :3 0 4
:3 0 e :7 0 25
24 :3 0 f :3 0
10 :3 0 11 :2 0
4 29 2a 0
27 2b 0 24c8
2 2c :2 0 13
:2 0 21 4 :3 0
13 :2 0 1f 2f
31 :6 0 34 32
0 24c6 0 12
:6 0 16 :2 0 25
4 :3 0 23 36
38 :6 0 3b 39
0 24c6 0 14
:6 0 16 :2 0 29
4 :3 0 27 3d
3f :6 0 42 40
0 24c6 0 15
:6 0 13 :2 0 2d
4 :3 0 2b 44
46 :6 0 49 47
0 24c6 0 17
:6 0 16 :2 0 31
4 :3 0 2f 4b
4d :6 0 50 4e
0 24c6 0 18
:6 0 13 :2 0 35
4 :3 0 33 52
54 :6 0 57 55
0 24c6 0 19
:6 0 13 :2 0 39
4 :3 0 37 59
5b :6 0 5e 5c
0 24c6 0 1a
:6 0 13 :2 0 3d
4 :3 0 3b 60
62 :6 0 65 63
0 24c6 0 1b
:6 0 13 :2 0 41
4 :3 0 3f 67
69 :6 0 6c 6a
0 24c6 0 1c
:6 0 13 :2 0 45
4 :3 0 43 6e
70 :6 0 73 71
0 24c6 0 1d
:6 0 13 :2 0 49
4 :3 0 47 75
77 :6 0 7a 78
0 24c6 0 1e
:6 0 13 :2 0 4d
4 :3 0 4b 7c
7e :6 0 81 7f
0 24c6 0 1f
:6 0 53 25b 0
51 4 :3 0 4f
83 85 :6 0 88
86 0 24c6 0
20 :6 0 57 28f
0 55 7 :3 0
8a :7 0 8d 8b
0 24c6 0 21
:6 0 7 :3 0 8f
:7 0 92 90 0
24c6 0 22 :6 0
5b 2c3 0 59
7 :3 0 94 :7 0
97 95 0 24c6
0 23 :6 0 7
:3 0 99 :7 0 9c
9a 0 24c6 0
24 :6 0 5f 2f7
0 5d 7 :3 0
9e :7 0 a1 9f
0 24c6 0 25
:6 0 7 :3 0 a3
:7 0 a6 a4 0
24c6 0 26 :6 0
63 32b 0 61
28 :3 0 a8 :7 0
ab a9 0 24c6
0 27 :6 0 28
:3 0 ad :7 0 b0
ae 0 24c6 0
29 :6 0 2c :2 0
67 28 :3 0 b2
:7 0 b5 b3 0
24c6 0 2a :6 0
4 :3 0 2c :2 0
65 b7 b9 :6 0
bc ba 0 24c6
0 2b :6 0 2f
:2 0 6b 4 :3 0
69 be c0 :6 0
c3 c1 0 24c6
0 2d :6 0 2f
:2 0 6d a :3 0
c5 :7 0 c9 c6
c7 24c6 0 2e
:6 0 2f :2 0 6f
a :3 0 cb :7 0
cf cc cd 24c6
0 30 :6 0 73
3d4 0 71 a
:3 0 d1 :7 0 d5
d2 d3 24c6 0
31 :6 0 2f :2 0
75 28 :3 0 d7
:7 0 da d8 0
24c6 0 32 :6 0
28 :3 0 dc :7 0
df dd 0 24c6
0 33 :6 0 2f
:2 0 77 a :3 0
e1 :7 0 e5 e2
e3 24c6 0 34
:6 0 2f :2 0 79
a :3 0 e7 :7 0
eb e8 e9 24c6
0 35 :6 0 2f
:2 0 7b a :3 0
ed :7 0 f1 ee
ef 24c6 0 36
:6 0 2f :2 0 7d
a :3 0 f3 :7 0
f7 f4 f5 24c6
0 37 :6 0 2f
:2 0 7f a :3 0
f9 :7 0 fd fa
fb 24c6 0 38
:6 0 2f :2 0 81
a :3 0 ff :7 0
103 100 101 24c6
0 39 :6 0 2f
:2 0 83 a :3 0
105 :7 0 109 106
107 24c6 0 3a
:6 0 2f :2 0 85
a :3 0 10b :7 0
10f 10c 10d 24c6
0 3b :6 0 2f
:2 0 87 a :3 0
111 :7 0 115 112
113 24c6 0 3c
:6 0 13 :2 0 89
a :3 0 117 :7 0
11b 118 119 24c6
0 3d :6 0 13
:2 0 8d 4 :3 0
8b 11d 11f :6 0
122 120 0 24c6
0 3e :6 0 13
:2 0 91 4 :3 0
8f 124 126 :6 0
129 127 0 24c6
0 3f :6 0 2f
:2 0 95 4 :3 0
93 12b 12d :6 0
130 12e 0 24c6
0 40 :6 0 2f
:2 0 97 a :3 0
132 :7 0 136 133
134 24c6 0 41
:6 0 2f :2 0 99
a :3 0 138 :7 0
13c 139 13a 24c6
0 42 :6 0 2f
:2 0 9b a :3 0
13e :7 0 142 13f
140 24c6 0 43
:6 0 2f :2 0 9d
a :3 0 144 :7 0
148 145 146 24c6
0 44 :6 0 2f
:2 0 9f a :3 0
14a :7 0 14e 14b
14c 24c6 0 45
:6 0 2f :2 0 a1
a :3 0 150 :7 0
154 151 152 24c6
0 46 :6 0 2f
:2 0 a3 a :3 0
156 :7 0 15a 157
158 24c6 0 47
:6 0 2f :2 0 a5
a :3 0 15c :7 0
160 15d 15e 24c6
0 48 :6 0 2f
:2 0 a7 a :3 0
162 :7 0 166 163
164 24c6 0 49
:6 0 2f :2 0 a9
a :3 0 168 :7 0
16c 169 16a 24c6
0 4a :6 0 2f
:2 0 ab a :3 0
16e :7 0 172 16f
170 24c6 0 4b
:6 0 2f :2 0 ad
a :3 0 174 :7 0
178 175 176 24c6
0 4c :6 0 2f
:2 0 af a :3 0
17a :7 0 17e 17b
17c 24c6 0 4d
:6 0 2f :2 0 b1
a :3 0 180 :7 0
184 181 182 24c6
0 4e :6 0 2f
:2 0 b3 a :3 0
186 :7 0 18a 187
188 24c6 0 4f
:6 0 2f :2 0 b5
a :3 0 18c :7 0
190 18d 18e 24c6
0 50 :6 0 2f
:2 0 b7 a :3 0
192 :7 0 196 193
194 24c6 0 51
:6 0 2f :2 0 b9
a :3 0 198 :7 0
19c 199 19a 24c6
0 52 :6 0 2f
:2 0 bb a :3 0
19e :7 0 1a2 19f
1a0 24c6 0 53
:6 0 2f :2 0 bd
a :3 0 1a4 :7 0
1a8 1a5 1a6 24c6
0 54 :6 0 2f
:2 0 bf a :3 0
1aa :7 0 1ae 1ab
1ac 24c6 0 55
:6 0 2f :2 0 c1
a :3 0 1b0 :7 0
1b4 1b1 1b2 24c6
0 56 :6 0 2f
:2 0 c3 a :3 0
1b6 :7 0 1ba 1b7
1b8 24c6 0 57
:6 0 5a :2 0 c5
a :3 0 1bc :7 0
1c0 1bd 1be 24c6
0 58 :6 0 2c
:2 0 c9 4 :3 0
c7 1c2 1c4 :6 0
1c7 1c5 0 24c6
0 59 :6 0 2f
:2 0 cd 4 :3 0
cb 1c9 1cb :6 0
1ce 1cc 0 24c6
0 5b :6 0 13
:2 0 cf a :3 0
1d0 :7 0 1d4 1d1
1d2 24c6 0 5c
:6 0 2f :2 0 d3
4 :3 0 d1 1d6
1d8 :6 0 1db 1d9
0 24c6 0 5d
:6 0 2f :2 0 d5
a :3 0 1dd :7 0
1e1 1de 1df 24c6
0 5e :6 0 2f
:2 0 d7 a :3 0
1e3 :7 0 1e7 1e4
1e5 24c6 0 5f
:6 0 2f :2 0 d9
a :3 0 1e9 :7 0
1ed 1ea 1eb 24c6
0 60 :6 0 2f
:2 0 db 62 :3 0
1ef :7 0 1f3 1f0
1f1 24c6 0 61
:6 0 2f :2 0 dd
62 :3 0 1f5 :7 0
1f9 1f6 1f7 24c6
0 63 :6 0 2f
:2 0 df 62 :3 0
1fb :7 0 1ff 1fc
1fd 24c6 0 64
:6 0 2f :2 0 e1
62 :3 0 201 :7 0
205 202 203 24c6
0 65 :6 0 2f
:2 0 e3 62 :3 0
207 :7 0 20b 208
209 24c6 0 66
:6 0 2f :2 0 e5
62 :3 0 20d :7 0
211 20e 20f 24c6
0 67 :6 0 2f
:2 0 e7 62 :3 0
213 :7 0 217 214
215 24c6 0 68
:6 0 6b :2 0 e9
62 :3 0 219 :7 0
21d 21a 21b 24c6
0 69 :6 0 ef
9db 0 ed 4
:3 0 eb 21f 221
:6 0 224 222 0
24c6 0 6a :6 0
230 231 0 f1
a :3 0 226 :7 0
229 227 0 24c6
0 6c :6 0 a
:3 0 22b :7 0 22e
22c 0 24c6 0
6d :6 0 237 238
0 f3 10 :3 0
11 :2 0 4 232
:7 0 235 233 0
24c6 0 6e :6 0
23e 23f 0 f5
10 :3 0 11 :2 0
4 239 :7 0 23c
23a 0 24c6 0
6f :6 0 244 245
0 f7 10 :3 0
11 :2 0 4 240
:7 0 243 241 0
24c6 0 70 :6 0
71 :3 0 72 :3 0
71 :3 0 73 :3 0
247 248 0 2
:4 0 f9 249 24b
246 24d 24c :2 0
74 :3 0 75 :3 0
24f 250 0 76
:4 0 71 :3 0 77
:3 0 253 254 0
2 :4 0 fb 255
257 78 :4 0 79
:2 0 7a :3 0 fd
25a 25c :3 0 7b
:4 0 79 :2 0 7c
:4 0 100 25f 261
:3 0 79 :2 0 3
:3 0 103 263 265
:3 0 79 :2 0 7c
:4 0 106 267 269
:3 0 79 :2 0 7d
:4 0 109 26b 26d
:3 0 79 :2 0 7c
:4 0 10c 26f 271
:3 0 79 :2 0 5
:3 0 10f 273 275
:3 0 79 :2 0 7c
:4 0 112 277 279
:3 0 79 :2 0 7d
:4 0 115 27b 27d
:3 0 79 :2 0 7e
:3 0 7f :3 0 7c
:4 0 79 :2 0 6
:3 0 118 283 285
:3 0 79 :2 0 7c
:4 0 11b 287 289
:3 0 80 :4 0 11e
281 28c 81 :4 0
121 280 28f 124
27f 291 :3 0 79
:2 0 7d :4 0 127
293 295 :3 0 79
:2 0 7e :3 0 7f
:3 0 7c :4 0 79
:2 0 8 :3 0 12a
29b 29d :3 0 79
:2 0 7c :4 0 12d
29f 2a1 :3 0 80
:4 0 130 299 2a4
81 :4 0 133 298
2a7 136 297 2a9
:3 0 79 :2 0 7d
:4 0 139 2ab 2ad
:3 0 79 :2 0 7e
:3 0 82 :3 0 9
:3 0 13c 2b1 2b3
81 :4 0 13e 2b0
2b6 141 2af 2b8
:3 0 79 :2 0 7d
:4 0 144 2ba 2bc
:3 0 79 :2 0 7e
:3 0 82 :3 0 b
:3 0 147 2c0 2c2
81 :4 0 149 2bf
2c5 14c 2be 2c7
:3 0 79 :2 0 7d
:4 0 14f 2c9 2cb
:3 0 79 :2 0 7e
:3 0 82 :3 0 c
:3 0 152 2cf 2d1
81 :4 0 154 2ce
2d4 157 2cd 2d6
:3 0 79 :2 0 7d
:4 0 15a 2d8 2da
:3 0 79 :2 0 7e
:3 0 82 :3 0 d
:3 0 15d 2de 2e0
81 :4 0 15f 2dd
2e3 162 2dc 2e5
:3 0 79 :2 0 7d
:4 0 165 2e7 2e9
:3 0 79 :2 0 7c
:4 0 168 2eb 2ed
:3 0 79 :2 0 e
:3 0 16b 2ef 2f1
:3 0 79 :2 0 7c
:4 0 16e 2f3 2f5
:3 0 79 :2 0 83
:4 0 171 2f7 2f9
:3 0 174 251 2fb
:2 0 2fd 179 2fe
24e 2fd 0 2ff
17b 0 2426 71
:3 0 72 :3 0 300
301 0 71 :3 0
84 :3 0 303 304
0 2c :2 0 2
:4 0 85 :2 0 86
:2 0 2c :2 0 17d
309 30b :3 0 180
305 30d 302 30f
30e :2 0 74 :3 0
87 :3 0 311 312
0 76 :4 0 88
:4 0 79 :2 0 7a
:3 0 184 316 318
:3 0 187 313 31a
:2 0 31c 18a 31d
310 31c 0 31e
18c 0 2426 4b
:3 0 2f :2 0 31f
320 0 2426 1e
:3 0 89 :4 0 322
323 0 2426 40
:3 0 e :3 0 325
326 0 2426 1b
:3 0 5 :3 0 328
329 0 2426 1c
:3 0 3 :3 0 32b
32c 0 2426 8a
:3 0 8b :3 0 8a
:3 0 8c :3 0 8a
:3 0 8d :3 0 8a
:3 0 8e :3 0 8a
:3 0 8f :3 0 8a
:3 0 90 :3 0 8a
:3 0 91 :3 0 8a
:3 0 92 :3 0 8a
:3 0 93 :3 0 1a
:3 0 37 :3 0 14
:3 0 35 :3 0 38
:3 0 3d :3 0 15
:3 0 1f :3 0 3c
:3 0 94 :3 0 8a
:3 0 8a :3 0 8b
:3 0 1c :4 0 95
1 :8 0 354 10
:3 0 96 :3 0 34f
350 0 97 :3 0
351 352 0 354
18e 39e 98 :3 0
10 :3 0 96 :3 0
357 358 0 97
:3 0 359 35a 0
394 71 :3 0 72
:3 0 35c 35d 0
71 :3 0 84 :3 0
35f 360 0 99
:2 0 2 :4 0 9a
:2 0 86 :2 0 2c
:2 0 191 365 367
:3 0 194 361 369
35e 36b 36a :2 0
74 :3 0 87 :3 0
36d 36e 0 76
:4 0 9b :4 0 79
:2 0 7a :3 0 198
372 374 :3 0 79
:2 0 9c :4 0 19b
376 378 :3 0 79
:2 0 9d :4 0 19e
37a 37c :3 0 79
:2 0 97 :3 0 1a1
37e 380 :3 0 79
:2 0 9e :4 0 1a4
382 384 :3 0 79
:2 0 9f :3 0 a0
:3 0 2c :2 0 a1
:2 0 1a7 387 38b
1ab 386 38d :3 0
1ae 36f 38f :2 0
391 1b1 392 36c
391 0 393 1b3
0 394 1b5 397
:3 0 397 0 397
396 394 395 :6 0
399 2 :3 0 1b8
39b 1ba 39a 399
:2 0 39c 1bc :2 0
39e 0 39e 39d
354 39c :6 0 2426
1 :3 0 10 :3 0
96 :3 0 3a0 3a1
0 10 :3 0 a2
:2 0 a3 :3 0 3a3
3a5 0 1c0 3a4
3a7 :3 0 3a8 :2 0
8b :3 0 a4 :3 0
92 :3 0 91 :3 0
8f :3 0 a5 :3 0
a6 :3 0 a7 :3 0
a8 :3 0 a9 :3 0
aa :3 0 ab :3 0
ac :3 0 ad :3 0
ac :3 0 ad :3 0
ae :3 0 af :3 0
b0 :3 0 b1 :3 0
a5 :3 0 b2 :3 0
b3 :3 0 b4 :3 0
b5 :3 0 b6 :3 0
9f :3 0 b0 :3 0
b6 :3 0 9f :3 0
b1 :3 0 b7 :3 0
b8 :3 0 b9 :3 0
ba :3 0 bb :3 0
bc :3 0 bd :3 0
be :3 0 bf :3 0
c0 :3 0 c1 :3 0
c2 :3 0 c3 :3 0
1a :3 0 1d :3 0
1f :3 0 3f :3 0
2d :3 0 2b :3 0
33 :3 0 42 :3 0
48 :3 0 52 :3 0
53 :3 0 50 :3 0
44 :3 0 21 :3 0
46 :3 0 22 :3 0
23 :3 0 41 :3 0
43 :3 0 49 :3 0
27 :3 0 29 :3 0
2e :3 0 30 :3 0
61 :3 0 64 :3 0
63 :3 0 65 :3 0
66 :3 0 68 :3 0
67 :3 0 69 :3 0
45 :3 0 3e :3 0
56 :3 0 c4 :3 0
c5 :3 0 1c :4 0
c6 1 :8 0 402
10 :3 0 96 :3 0
3fd 3fe 0 97
:3 0 3ff 400 0
402 1c3 44c 98
:3 0 10 :3 0 96
:3 0 405 406 0
97 :3 0 407 408
0 442 71 :3 0
72 :3 0 40a 40b
0 71 :3 0 84
:3 0 40d 40e 0
99 :2 0 2 :4 0
c7 :2 0 86 :2 0
2c :2 0 1c6 413
415 :3 0 1c9 40f
417 40c 419 418
:2 0 74 :3 0 87
:3 0 41b 41c 0
76 :4 0 c8 :4 0
79 :2 0 7a :3 0
1cd 420 422 :3 0
79 :2 0 9c :4 0
1d0 424 426 :3 0
79 :2 0 9d :4 0
1d3 428 42a :3 0
79 :2 0 97 :3 0
1d6 42c 42e :3 0
79 :2 0 9e :4 0
1d9 430 432 :3 0
79 :2 0 9f :3 0
a0 :3 0 2c :2 0
a1 :2 0 1dc 435
439 1e0 434 43b
:3 0 1e3 41d 43d
:2 0 43f 1e6 440
41a 43f 0 441
1e8 0 442 1ea
445 :3 0 445 0
445 444 442 443
:6 0 447 4 :3 0
1ed 449 1ef 448
447 :2 0 44a 1f1
:2 0 44c 0 44c
44b 402 44a :6 0
23bc 1 :3 0 10
:3 0 96 :3 0 44e
44f 0 10 :3 0
a2 :2 0 a3 :3 0
451 453 0 1f5
452 455 :3 0 456
:2 0 92 :3 0 c9
:3 0 ca :3 0 cb
:3 0 cc :3 0 cd
:3 0 ce :3 0 cf
:3 0 af :3 0 d0
:3 0 d1 :3 0 d2
:3 0 d3 :3 0 7e
:3 0 d4 :3 0 d5
:3 0 1f :3 0 4b
:3 0 4c :3 0 22
:3 0 23 :3 0 4f
:3 0 4e :3 0 4d
:3 0 46 :3 0 41
:3 0 45 :3 0 55
:3 0 26 :3 0 d6
:3 0 8d :3 0 1c
:4 0 d7 1 :8 0
47e 10 :3 0 96
:3 0 479 47a 0
97 :3 0 47b 47c
0 47e 1f8 4c8
98 :3 0 10 :3 0
96 :3 0 481 482
0 97 :3 0 483
484 0 4be 71
:3 0 72 :3 0 486
487 0 71 :3 0
84 :3 0 489 48a
0 99 :2 0 2
:4 0 d8 :2 0 86
:2 0 2c :2 0 1fb
48f 491 :3 0 1fe
48b 493 488 495
494 :2 0 74 :3 0
87 :3 0 497 498
0 76 :4 0 d9
:4 0 79 :2 0 7a
:3 0 202 49c 49e
:3 0 79 :2 0 9c
:4 0 205 4a0 4a2
:3 0 79 :2 0 9d
:4 0 208 4a4 4a6
:3 0 79 :2 0 97
:3 0 20b 4a8 4aa
:3 0 79 :2 0 9e
:4 0 20e 4ac 4ae
:3 0 79 :2 0 9f
:3 0 a0 :3 0 2c
:2 0 a1 :2 0 211
4b1 4b5 215 4b0
4b7 :3 0 218 499
4b9 :2 0 4bb 21b
4bc 496 4bb 0
4bd 21d 0 4be
21f 4c1 :3 0 4c1
0 4c1 4c0 4be
4bf :6 0 4c3 6
:3 0 222 4c5 224
4c4 4c3 :2 0 4c6
226 :2 0 4c8 0
4c8 4c7 47e 4c6
:6 0 f4f 1 :3 0
10 :3 0 96 :3 0
4ca 4cb 0 10
:3 0 a2 :2 0 a3
:3 0 4cd 4cf 0
22a 4ce 4d1 :3 0
4d2 :2 0 71 :3 0
72 :3 0 4d4 4d5
0 71 :3 0 84
:3 0 4d7 4d8 0
13 :2 0 2 :4 0
da :2 0 86 :2 0
2c :2 0 22d 4dd
4df :3 0 230 4d9
4e1 4d6 4e3 4e2
:2 0 74 :3 0 87
:3 0 4e5 4e6 0
76 :4 0 db :4 0
79 :2 0 7a :3 0
234 4ea 4ec :3 0
79 :2 0 9c :4 0
237 4ee 4f0 :3 0
79 :2 0 dc :4 0
23a 4f2 4f4 :3 0
79 :2 0 7e :3 0
82 :3 0 dd :3 0
de :3 0 4f9 4fa
0 23d 4f8 4fc
81 :4 0 23f 4f7
4ff 242 4f6 501
:3 0 79 :2 0 df
:4 0 245 503 505
:3 0 79 :2 0 7c
:4 0 248 507 509
:3 0 79 :2 0 1c
:3 0 24b 50b 50d
:3 0 79 :2 0 7c
:4 0 24e 50f 511
:3 0 251 4e7 513
:2 0 515 254 516
4e4 515 0 517
256 0 541 71
:3 0 72 :3 0 518
519 0 71 :3 0
84 :3 0 51b 51c
0 2c :2 0 2
:4 0 e0 :2 0 86
:2 0 2c :2 0 258
521 523 :3 0 25b
51d 525 51a 527
526 :2 0 74 :3 0
87 :3 0 529 52a
0 76 :4 0 e1
:4 0 79 :2 0 7a
:3 0 25f 52e 530
:3 0 262 52b 532
:2 0 534 265 535
528 534 0 536
267 0 541 e2
:3 0 e3 :3 0 537
538 0 dd :3 0
de :3 0 53a 53b
0 1c :3 0 e4
:3 0 269 539 53f
:2 0 541 26d 542
4d3 541 0 543
271 0 f4f 24
:3 0 6 :3 0 544
545 0 f4f 25
:3 0 8 :3 0 547
548 0 f4f e5
:3 0 e6 :3 0 54a
54b 0 24 :3 0
25 :3 0 e7 :2 0
273 54c 550 e8
:2 0 2f :2 0 279
552 554 :3 0 555
:2 0 e5 :3 0 e6
:3 0 557 558 0
25 :3 0 23 :3 0
e7 :2 0 27c 559
55d e9 :2 0 2f
:2 0 282 55f 561
:3 0 562 :2 0 556
564 563 :2 0 71
:3 0 72 :3 0 566
567 0 71 :3 0
84 :3 0 569 56a
0 13 :2 0 2
:4 0 ea :2 0 86
:2 0 2c :2 0 285
56f 571 :3 0 288
56b 573 568 575
574 :2 0 74 :3 0
87 :3 0 577 578
0 76 :4 0 eb
:4 0 79 :2 0 7a
:3 0 28c 57c 57e
:3 0 79 :2 0 9c
:4 0 28f 580 582
:3 0 79 :2 0 dc
:4 0 292 584 586
:3 0 79 :2 0 7e
:3 0 82 :3 0 dd
:3 0 ec :3 0 58b
58c 0 295 58a
58e 81 :4 0 297
589 591 29a 588
593 :3 0 79 :2 0
df :4 0 29d 595
597 :3 0 79 :2 0
7c :4 0 2a0 599
59b :3 0 79 :2 0
1c :3 0 2a3 59d
59f :3 0 79 :2 0
7c :4 0 2a6 5a1
5a3 :3 0 2a9 579
5a5 :2 0 5a7 2ac
5a8 576 5a7 0
5a9 2ae 0 5d3
71 :3 0 72 :3 0
5aa 5ab 0 71
:3 0 84 :3 0 5ad
5ae 0 2c :2 0
2 :4 0 ed :2 0
86 :2 0 2c :2 0
2b0 5b3 5b5 :3 0
2b3 5af 5b7 5ac
5b9 5b8 :2 0 74
:3 0 87 :3 0 5bb
5bc 0 76 :4 0
ee :4 0 79 :2 0
7a :3 0 2b7 5c0
5c2 :3 0 2ba 5bd
5c4 :2 0 5c6 2bd
5c7 5ba 5c6 0
5c8 2bf 0 5d3
e2 :3 0 e3 :3 0
5c9 5ca 0 dd
:3 0 ec :3 0 5cc
5cd 0 1c :3 0
e4 :3 0 2c1 5cb
5d1 :2 0 5d3 2c5
5d4 565 5d3 0
5d5 2c9 0 f4f
26 :3 0 ef :2 0
2cb 5d7 5d8 :3 0
5d9 :2 0 5da :2 0
7e :3 0 41 :3 0
2f :2 0 2cd 5dc
5df f0 :2 0 7e
:3 0 46 :3 0 2f
:2 0 2d0 5e2 5e5
2d3 5e1 5e7 :3 0
5e8 :2 0 7e :3 0
e9 :2 0 55 :3 0
2f :2 0 2d6 5ea
5ee 2db 5eb 5f0
:3 0 5f1 :2 0 5db
5f3 5f2 :2 0 71
:3 0 72 :3 0 5f5
5f6 0 71 :3 0
84 :3 0 5f8 5f9
0 13 :2 0 2
:4 0 f1 :2 0 86
:2 0 2c :2 0 2de
5fe 600 :3 0 2e1
5fa 602 5f7 604
603 :2 0 74 :3 0
87 :3 0 606 607
0 76 :4 0 f2
:4 0 79 :2 0 7a
:3 0 2e5 60b 60d
:3 0 79 :2 0 9c
:4 0 2e8 60f 611
:3 0 79 :2 0 dc
:4 0 2eb 613 615
:3 0 79 :2 0 7e
:3 0 82 :3 0 dd
:3 0 f3 :3 0 61a
61b 0 2ee 619
61d 81 :4 0 2f0
618 620 2f3 617
622 :3 0 79 :2 0
df :4 0 2f6 624
626 :3 0 79 :2 0
7c :4 0 2f9 628
62a :3 0 79 :2 0
1c :3 0 2fc 62c
62e :3 0 79 :2 0
7c :4 0 2ff 630
632 :3 0 302 608
634 :2 0 636 305
637 605 636 0
638 307 0 662
71 :3 0 72 :3 0
639 63a 0 71
:3 0 84 :3 0 63c
63d 0 2c :2 0
2 :4 0 f4 :2 0
86 :2 0 2c :2 0
309 642 644 :3 0
30c 63e 646 63b
648 647 :2 0 74
:3 0 87 :3 0 64a
64b 0 76 :4 0
f5 :4 0 79 :2 0
7a :3 0 310 64f
651 :3 0 313 64c
653 :2 0 655 316
656 649 655 0
657 318 0 662
e2 :3 0 e3 :3 0
658 659 0 dd
:3 0 f3 :3 0 65b
65c 0 1c :3 0
e4 :3 0 31a 65a
660 :2 0 662 31e
663 5f4 662 0
664 322 0 f4f
e5 :3 0 e6 :3 0
665 666 0 24
:3 0 22 :3 0 e7
:2 0 324 667 66b
e9 :2 0 2f :2 0
32a 66d 66f :3 0
670 :2 0 e5 :3 0
e6 :3 0 672 673
0 25 :3 0 23
:3 0 e7 :2 0 32d
674 678 e9 :2 0
2f :2 0 333 67a
67c :3 0 67d :2 0
671 67f 67e :2 0
7e :3 0 4e :3 0
2f :2 0 336 681
684 a2 :2 0 2f
:2 0 33b 686 688
:3 0 e5 :3 0 e6
:3 0 68a 68b 0
24 :3 0 22 :3 0
e7 :2 0 33e 68c
690 e9 :2 0 2f
:2 0 344 692 694
:3 0 e5 :3 0 f6
:3 0 f7 :3 0 e5
:3 0 f8 :3 0 f9
:3 0 fa :3 0 fb
:3 0 24 :3 0 fc
:3 0 8d :3 0 1f
:3 0 f7 :3 0 b6
:3 0 9f :3 0 24
:4 0 fd 1 :8 0
6ac 10 :3 0 96
:3 0 6a7 6a8 0
97 :3 0 6a9 6aa
0 6ac 347 6f6
98 :3 0 10 :3 0
96 :3 0 6af 6b0
0 97 :3 0 6b1
6b2 0 6ec 71
:3 0 72 :3 0 6b4
6b5 0 71 :3 0
84 :3 0 6b7 6b8
0 99 :2 0 2
:4 0 fe :2 0 86
:2 0 2c :2 0 34a
6bd 6bf :3 0 34d
6b9 6c1 6b6 6c3
6c2 :2 0 74 :3 0
87 :3 0 6c5 6c6
0 76 :4 0 ff
:4 0 79 :2 0 7a
:3 0 351 6ca 6cc
:3 0 79 :2 0 9c
:4 0 354 6ce 6d0
:3 0 79 :2 0 9d
:4 0 357 6d2 6d4
:3 0 79 :2 0 97
:3 0 35a 6d6 6d8
:3 0 79 :2 0 9e
:4 0 35d 6da 6dc
:3 0 79 :2 0 9f
:3 0 a0 :3 0 2c
:2 0 a1 :2 0 360
6df 6e3 364 6de
6e5 :3 0 367 6c7
6e7 :2 0 6e9 36a
6ea 6c4 6e9 0
6eb 36c 0 6ec
36e 6ef :3 0 6ef
0 6ef 6ee 6ec
6ed :6 0 6f1 8
:3 0 371 6f3 373
6f2 6f1 :2 0 6f4
375 :2 0 6f6 0
6f6 6f5 6ac 6f4
:6 0 772 1 :3 0
10 :3 0 96 :3 0
6f8 6f9 0 10
:3 0 a2 :2 0 a3
:3 0 6fb 6fd 0
379 6fc 6ff :3 0
700 :2 0 e5 :3 0
f6 :3 0 b6 :3 0
9f :3 0 24 :3 0
e5 :3 0 f8 :3 0
24 :3 0 100 :4 0
101 1 :8 0 711
10 :3 0 96 :3 0
70c 70d 0 97
:3 0 70e 70f 0
711 37c 75b 98
:3 0 10 :3 0 96
:3 0 714 715 0
97 :3 0 716 717
0 751 71 :3 0
72 :3 0 719 71a
0 71 :3 0 84
:3 0 71c 71d 0
99 :2 0 2 :4 0
102 :2 0 86 :2 0
2c :2 0 37f 722
724 :3 0 382 71e
726 71b 728 727
:2 0 74 :3 0 87
:3 0 72a 72b 0
76 :4 0 103 :4 0
79 :2 0 7a :3 0
386 72f 731 :3 0
79 :2 0 9c :4 0
389 733 735 :3 0
79 :2 0 9d :4 0
38c 737 739 :3 0
79 :2 0 97 :3 0
38f 73b 73d :3 0
79 :2 0 9e :4 0
392 73f 741 :3 0
79 :2 0 9f :3 0
a0 :3 0 2c :2 0
a1 :2 0 395 744
748 399 743 74a
:3 0 39c 72c 74c
:2 0 74e 39f 74f
729 74e 0 750
3a1 0 751 3a3
754 :3 0 754 0
754 753 751 752
:6 0 756 a :3 0
3a6 758 3a8 757
756 :2 0 759 3aa
:2 0 75b 0 75b
75a 711 759 :6 0
75d 1 :3 0 3ac
75e 701 75d 0
75f 3ae 0 772
e5 :3 0 e6 :3 0
760 761 0 24
:3 0 25 :3 0 e7
:2 0 3b0 762 766
e8 :2 0 2f :2 0
3b6 768 76a :3 0
25 :4 0 76c 76d
0 76f 3b9 770
76b 76f 0 771
3bb 0 772 3bd
841 e5 :3 0 f6
:3 0 f7 :3 0 e5
:3 0 f8 :3 0 f9
:3 0 104 :3 0 fb
:3 0 25 :3 0 fc
:3 0 8d :3 0 1f
:3 0 f7 :3 0 b6
:3 0 9f :3 0 25
:4 0 105 1 :8 0
789 10 :3 0 96
:3 0 784 785 0
97 :3 0 786 787
0 789 3c1 7d3
98 :3 0 10 :3 0
96 :3 0 78c 78d
0 97 :3 0 78e
78f 0 7c9 71
:3 0 72 :3 0 791
792 0 71 :3 0
84 :3 0 794 795
0 99 :2 0 2
:4 0 106 :2 0 86
:2 0 2c :2 0 3c4
79a 79c :3 0 3c7
796 79e 793 7a0
79f :2 0 74 :3 0
87 :3 0 7a2 7a3
0 76 :4 0 107
:4 0 79 :2 0 7a
:3 0 3cb 7a7 7a9
:3 0 79 :2 0 9c
:4 0 3ce 7ab 7ad
:3 0 79 :2 0 9d
:4 0 3d1 7af 7b1
:3 0 79 :2 0 97
:3 0 3d4 7b3 7b5
:3 0 79 :2 0 9e
:4 0 3d7 7b7 7b9
:3 0 79 :2 0 9f
:3 0 a0 :3 0 2c
:2 0 a1 :2 0 3da
7bc 7c0 3de 7bb
7c2 :3 0 3e1 7a4
7c4 :2 0 7c6 3e4
7c7 7a1 7c6 0
7c8 3e6 0 7c9
3e8 7cc :3 0 7cc
0 7cc 7cb 7c9
7ca :6 0 7ce c
:3 0 3eb 7d0 3ed
7cf 7ce :2 0 7d1
3ef :2 0 7d3 0
7d3 7d2 789 7d1
:6 0 840 1 :3 0
10 :3 0 96 :3 0
7d5 7d6 0 10
:3 0 a2 :2 0 a3
:3 0 7d8 7da 0
3f3 7d9 7dc :3 0
7dd :2 0 e5 :3 0
f6 :3 0 b6 :3 0
9f :3 0 25 :3 0
e5 :3 0 f8 :3 0
25 :3 0 100 :4 0
108 1 :8 0 7ee
10 :3 0 96 :3 0
7e9 7ea 0 97
:3 0 7eb 7ec 0
7ee 3f6 838 98
:3 0 10 :3 0 96
:3 0 7f1 7f2 0
97 :3 0 7f3 7f4
0 82e 71 :3 0
72 :3 0 7f6 7f7
0 71 :3 0 84
:3 0 7f9 7fa 0
99 :2 0 2 :4 0
109 :2 0 86 :2 0
2c :2 0 3f9 7ff
801 :3 0 3fc 7fb
803 7f8 805 804
:2 0 74 :3 0 87
:3 0 807 808 0
76 :4 0 10a :4 0
79 :2 0 7a :3 0
400 80c 80e :3 0
79 :2 0 9c :4 0
403 810 812 :3 0
79 :2 0 9d :4 0
406 814 816 :3 0
79 :2 0 97 :3 0
409 818 81a :3 0
79 :2 0 9e :4 0
40c 81c 81e :3 0
79 :2 0 9f :3 0
a0 :3 0 2c :2 0
a1 :2 0 40f 821
825 413 820 827
:3 0 416 809 829
:2 0 82b 419 82c
806 82b 0 82d
41b 0 82e 41d
831 :3 0 831 0
831 830 82e 82f
:6 0 833 e :3 0
420 835 422 834
833 :2 0 836 424
:2 0 838 0 838
837 7ee 836 :6 0
83a 1 :3 0 426
83b 7de 83a 0
83c 428 0 840
4f :3 0 2f :2 0
83d 83e 0 840
42a 842 695 772
0 843 0 840
0 843 42e 0
93d 7e :3 0 4d
:3 0 2f :2 0 431
844 847 dd :3 0
a2 :2 0 10b :3 0
849 84b 0 436
84a 84d :3 0 d6
:3 0 10c :3 0 24
:3 0 10d :3 0 25
:3 0 10e :3 0 4f
:3 0 8d :3 0 1c
:4 0 10f 1 :8 0
86e 110 :4 0 859
:3 0 e4 :3 0 a2
:2 0 43b 85c 85d
:3 0 10 :3 0 96
:3 0 85f 860 0
2f :2 0 861 862
0 864 43e 86b
10 :3 0 96 :3 0
865 866 0 111
:2 0 867 868 0
86a 440 86c 85e
864 0 86d 0
86a 0 86d 442
0 86e 445 8b8
98 :3 0 10 :3 0
96 :3 0 871 872
0 97 :3 0 873
874 0 8ae 71
:3 0 72 :3 0 876
877 0 71 :3 0
84 :3 0 879 87a
0 99 :2 0 2
:4 0 112 :2 0 86
:2 0 2c :2 0 448
87f 881 :3 0 44b
87b 883 878 885
884 :2 0 74 :3 0
87 :3 0 887 888
0 76 :4 0 113
:4 0 79 :2 0 7a
:3 0 44f 88c 88e
:3 0 79 :2 0 9c
:4 0 452 890 892
:3 0 79 :2 0 9d
:4 0 455 894 896
:3 0 79 :2 0 97
:3 0 458 898 89a
:3 0 79 :2 0 9e
:4 0 45b 89c 89e
:3 0 79 :2 0 9f
:3 0 a0 :3 0 2c
:2 0 a1 :2 0 45e
8a1 8a5 462 8a0
8a7 :3 0 465 889
8a9 :2 0 8ab 468
8ac 886 8ab 0
8ad 46a 0 8ae
46c 8b1 :3 0 8b1
0 8b1 8b0 8ae
8af :6 0 8b3 10
:3 0 46f 8b5 471
8b4 8b3 :2 0 8b6
473 :2 0 8b8 0
8b8 8b7 86e 8b6
:6 0 8ba 1 :3 0
475 927 d6 :3 0
114 :3 0 24 :3 0
115 :3 0 25 :3 0
116 :3 0 4f :3 0
8d :3 0 1c :4 0
117 1 :8 0 8da
110 :4 0 8c5 :3 0
e4 :3 0 a2 :2 0
479 8c8 8c9 :3 0
10 :3 0 96 :3 0
8cb 8cc 0 2f
:2 0 8cd 8ce 0
8d0 47c 8d7 10
:3 0 96 :3 0 8d1
8d2 0 111 :2 0
8d3 8d4 0 8d6
47e 8d8 8ca 8d0
0 8d9 0 8d6
0 8d9 480 0
8da 483 924 98
:3 0 10 :3 0 96
:3 0 8dd 8de 0
97 :3 0 8df 8e0
0 91a 71 :3 0
72 :3 0 8e2 8e3
0 71 :3 0 84
:3 0 8e5 8e6 0
99 :2 0 2 :4 0
118 :2 0 86 :2 0
2c :2 0 486 8eb
8ed :3 0 489 8e7
8ef 8e4 8f1 8f0
:2 0 74 :3 0 87
:3 0 8f3 8f4 0
76 :4 0 119 :4 0
79 :2 0 7a :3 0
48d 8f8 8fa :3 0
79 :2 0 9c :4 0
490 8fc 8fe :3 0
79 :2 0 9d :4 0
493 900 902 :3 0
79 :2 0 97 :3 0
496 904 906 :3 0
79 :2 0 9e :4 0
499 908 90a :3 0
79 :2 0 9f :3 0
a0 :3 0 2c :2 0
a1 :2 0 49c 90d
911 4a0 90c 913
:3 0 4a3 8f5 915
:2 0 917 4a6 918
8f2 917 0 919
4a8 0 91a 4aa
91d :3 0 91d 0
91d 91c 91a 91b
:6 0 91f 12 :3 0
4ad 921 4af 920
91f :2 0 922 4b1
:2 0 924 0 924
923 8da 922 :6 0
926 1 :3 0 4b3
928 84e 8ba 0
929 0 926 0
929 4b5 0 93d
10 :3 0 96 :3 0
92a 92b 0 10
:3 0 a2 :2 0 11a
:3 0 92d 92f 0
4ba 92e 931 :3 0
932 :2 0 60 :3 0
11b :3 0 1f :3 0
4bd 935 937 934
938 0 93a 4bf
93b 933 93a 0
93c 4c1 0 93d
4c3 c4c 11c :3 0
60 :3 0 100 :3 0
c4 :3 0 92 :3 0
1f :3 0 c2 :3 0
1c :3 0 ae :4 0
11d 1 :8 0 94d
10 :3 0 96 :3 0
948 949 0 97
:3 0 94a 94b 0
94d 4c7 997 98
:3 0 10 :3 0 96
:3 0 950 951 0
97 :3 0 952 953
0 98d 71 :3 0
72 :3 0 955 956
0 71 :3 0 84
:3 0 958 959 0
99 :2 0 2 :4 0
11e :2 0 86 :2 0
2c :2 0 4ca 95e
960 :3 0 4cd 95a
962 957 964 963
:2 0 74 :3 0 87
:3 0 966 967 0
76 :4 0 11f :4 0
79 :2 0 7a :3 0
4d1 96b 96d :3 0
79 :2 0 9c :4 0
4d4 96f 971 :3 0
79 :2 0 9d :4 0
4d7 973 975 :3 0
79 :2 0 97 :3 0
4da 977 979 :3 0
79 :2 0 9e :4 0
4dd 97b 97d :3 0
79 :2 0 9f :3 0
a0 :3 0 2c :2 0
a1 :2 0 4e0 980
984 4e4 97f 986
:3 0 4e7 968 988
:2 0 98a 4ea 98b
965 98a 0 98c
4ec 0 98d 4ee
990 :3 0 990 0
990 98f 98d 98e
:6 0 992 14 :3 0
4f1 994 4f3 993
992 :2 0 995 4f5
:2 0 997 0 997
996 94d 995 :6 0
c4b 1 :3 0 7e
:3 0 60 :3 0 2f
:2 0 4f7 999 99c
e8 :2 0 2f :2 0
4fc 99e 9a0 :3 0
71 :3 0 72 :3 0
9a2 9a3 0 71
:3 0 84 :3 0 9a5
9a6 0 13 :2 0
2 :4 0 120 :2 0
86 :2 0 2c :2 0
4ff 9ab 9ad :3 0
502 9a7 9af 9a4
9b1 9b0 :2 0 74
:3 0 87 :3 0 9b3
9b4 0 76 :4 0
121 :4 0 79 :2 0
7a :3 0 506 9b8
9ba :3 0 79 :2 0
9c :4 0 509 9bc
9be :3 0 79 :2 0
dc :4 0 50c 9c0
9c2 :3 0 79 :2 0
7e :3 0 82 :3 0
dd :3 0 122 :3 0
9c7 9c8 0 50f
9c6 9ca 81 :4 0
511 9c5 9cd 514
9c4 9cf :3 0 79
:2 0 df :4 0 517
9d1 9d3 :3 0 79
:2 0 7c :4 0 51a
9d5 9d7 :3 0 79
:2 0 1c :3 0 51d
9d9 9db :3 0 79
:2 0 7c :4 0 520
9dd 9df :3 0 523
9b5 9e1 :2 0 9e3
526 9e4 9b2 9e3
0 9e5 528 0
a0f 71 :3 0 72
:3 0 9e6 9e7 0
71 :3 0 84 :3 0
9e9 9ea 0 2c
:2 0 2 :4 0 123
:2 0 86 :2 0 2c
:2 0 52a 9ef 9f1
:3 0 52d 9eb 9f3
9e8 9f5 9f4 :2 0
74 :3 0 87 :3 0
9f7 9f8 0 76
:4 0 124 :4 0 79
:2 0 7a :3 0 531
9fc 9fe :3 0 534
9f9 a00 :2 0 a02
537 a03 9f6 a02
0 a04 539 0
a0f e2 :3 0 e3
:3 0 a05 a06 0
dd :3 0 122 :3 0
a08 a09 0 1c
:3 0 e4 :3 0 53b
a07 a0d :2 0 a0f
53f a10 9a1 a0f
0 a11 543 0
c4b e5 :3 0 e6
:3 0 a12 a13 0
24 :3 0 22 :3 0
e7 :2 0 545 a14
a18 e9 :2 0 2f
:2 0 54b a1a a1c
:3 0 e5 :3 0 f6
:3 0 f7 :3 0 e5
:3 0 f8 :3 0 f9
:3 0 fa :3 0 fb
:3 0 24 :3 0 fc
:3 0 8d :3 0 1f
:3 0 f7 :3 0 b6
:3 0 9f :3 0 24
:4 0 fd 1 :8 0
a34 10 :3 0 96
:3 0 a2f a30 0
97 :3 0 a31 a32
0 a34 54e a7e
98 :3 0 10 :3 0
96 :3 0 a37 a38
0 97 :3 0 a39
a3a 0 a74 71
:3 0 72 :3 0 a3c
a3d 0 71 :3 0
84 :3 0 a3f a40
0 99 :2 0 2
:4 0 125 :2 0 86
:2 0 2c :2 0 551
a45 a47 :3 0 554
a41 a49 a3e a4b
a4a :2 0 74 :3 0
87 :3 0 a4d a4e
0 76 :4 0 126
:4 0 79 :2 0 7a
:3 0 558 a52 a54
:3 0 79 :2 0 9c
:4 0 55b a56 a58
:3 0 79 :2 0 9d
:4 0 55e a5a a5c
:3 0 79 :2 0 97
:3 0 561 a5e a60
:3 0 79 :2 0 9e
:4 0 564 a62 a64
:3 0 79 :2 0 9f
:3 0 a0 :3 0 2c
:2 0 a1 :2 0 567
a67 a6b 56b a66
a6d :3 0 56e a4f
a6f :2 0 a71 571
a72 a4c a71 0
a73 573 0 a74
575 a77 :3 0 a77
0 a77 a76 a74
a75 :6 0 a79 16
:3 0 578 a7b 57a
a7a a79 :2 0 a7c
57c :2 0 a7e 0
a7e a7d a34 a7c
:6 0 ae8 1 :3 0
10 :3 0 96 :3 0
a80 a81 0 10
:3 0 a2 :2 0 a3
:3 0 a83 a85 0
580 a84 a87 :3 0
a88 :2 0 e5 :3 0
f6 :3 0 b6 :3 0
9f :3 0 24 :3 0
e5 :3 0 f8 :3 0
24 :3 0 100 :4 0
101 1 :8 0 a99
10 :3 0 96 :3 0
a94 a95 0 97
:3 0 a96 a97 0
a99 583 ae3 98
:3 0 10 :3 0 96
:3 0 a9c a9d 0
97 :3 0 a9e a9f
0 ad9 71 :3 0
72 :3 0 aa1 aa2
0 71 :3 0 84
:3 0 aa4 aa5 0
99 :2 0 2 :4 0
127 :2 0 86 :2 0
2c :2 0 586 aaa
aac :3 0 589 aa6
aae aa3 ab0 aaf
:2 0 74 :3 0 87
:3 0 ab2 ab3 0
76 :4 0 128 :4 0
79 :2 0 7a :3 0
58d ab7 ab9 :3 0
79 :2 0 9c :4 0
590 abb abd :3 0
79 :2 0 9d :4 0
593 abf ac1 :3 0
79 :2 0 97 :3 0
596 ac3 ac5 :3 0
79 :2 0 9e :4 0
599 ac7 ac9 :3 0
79 :2 0 9f :3 0
a0 :3 0 2c :2 0
a1 :2 0 59c acc
ad0 5a0 acb ad2
:3 0 5a3 ab4 ad4
:2 0 ad6 5a6 ad7
ab1 ad6 0 ad8
5a8 0 ad9 5aa
adc :3 0 adc 0
adc adb ad9 ada
:6 0 ade 18 :3 0
5ad ae0 5af adf
ade :2 0 ae1 5b1
:2 0 ae3 0 ae3
ae2 a99 ae1 :6 0
ae5 1 :3 0 5b3
ae6 a89 ae5 0
ae7 5b5 0 ae8
5b7 bb4 e5 :3 0
f6 :3 0 f7 :3 0
e5 :3 0 f8 :3 0
f9 :3 0 104 :3 0
fb :3 0 25 :3 0
fc :3 0 8d :3 0
1f :3 0 f7 :3 0
b6 :3 0 9f :3 0
25 :4 0 105 1
:8 0 aff 10 :3 0
96 :3 0 afa afb
0 97 :3 0 afc
afd 0 aff 5ba
b49 98 :3 0 10
:3 0 96 :3 0 b02
b03 0 97 :3 0
b04 b05 0 b3f
71 :3 0 72 :3 0
b07 b08 0 71
:3 0 84 :3 0 b0a
b0b 0 99 :2 0
2 :4 0 129 :2 0
86 :2 0 2c :2 0
5bd b10 b12 :3 0
5c0 b0c b14 b09
b16 b15 :2 0 74
:3 0 87 :3 0 b18
b19 0 76 :4 0
12a :4 0 79 :2 0
7a :3 0 5c4 b1d
b1f :3 0 79 :2 0
9c :4 0 5c7 b21
b23 :3 0 79 :2 0
9d :4 0 5ca b25
b27 :3 0 79 :2 0
97 :3 0 5cd b29
b2b :3 0 79 :2 0
9e :4 0 5d0 b2d
b2f :3 0 79 :2 0
9f :3 0 a0 :3 0
2c :2 0 a1 :2 0
5d3 b32 b36 5d7
b31 b38 :3 0 5da
b1a b3a :2 0 b3c
5dd b3d b17 b3c
0 b3e 5df 0
b3f 5e1 b42 :3 0
b42 0 b42 b41
b3f b40 :6 0 b44
1a :3 0 5e4 b46
5e6 b45 b44 :2 0
b47 5e8 :2 0 b49
0 b49 b48 aff
b47 :6 0 bb3 1
:3 0 10 :3 0 96
:3 0 b4b b4c 0
10 :3 0 a2 :2 0
a3 :3 0 b4e b50
0 5ec b4f b52
:3 0 b53 :2 0 e5
:3 0 f6 :3 0 b6
:3 0 9f :3 0 25
:3 0 e5 :3 0 f8
:3 0 25 :3 0 100
:4 0 108 1 :8 0
b64 10 :3 0 96
:3 0 b5f b60 0
97 :3 0 b61 b62
0 b64 5ef bae
98 :3 0 10 :3 0
96 :3 0 b67 b68
0 97 :3 0 b69
b6a 0 ba4 71
:3 0 72 :3 0 b6c
b6d 0 71 :3 0
84 :3 0 b6f b70
0 99 :2 0 2
:4 0 12b :2 0 86
:2 0 2c :2 0 5f2
b75 b77 :3 0 5f5
b71 b79 b6e b7b
b7a :2 0 74 :3 0
87 :3 0 b7d b7e
0 76 :4 0 12c
:4 0 79 :2 0 7a
:3 0 5f9 b82 b84
:3 0 79 :2 0 9c
:4 0 5fc b86 b88
:3 0 79 :2 0 9d
:4 0 5ff b8a b8c
:3 0 79 :2 0 97
:3 0 602 b8e b90
:3 0 79 :2 0 9e
:4 0 605 b92 b94
:3 0 79 :2 0 9f
:3 0 a0 :3 0 2c
:2 0 a1 :2 0 608
b97 b9b 60c b96
b9d :3 0 60f b7f
b9f :2 0 ba1 612
ba2 b7c ba1 0
ba3 614 0 ba4
616 ba7 :3 0 ba7
0 ba7 ba6 ba4
ba5 :6 0 ba9 1c
:3 0 619 bab 61b
baa ba9 :2 0 bac
61d :2 0 bae 0
bae bad b64 bac
:6 0 bb0 1 :3 0
61f bb1 b54 bb0
0 bb2 621 0
bb3 623 bb5 a1d
ae8 0 bb6 0
bb3 0 bb6 626
0 c4b 60 :3 0
12d :3 0 1f :3 0
1c :3 0 22 :3 0
23 :3 0 24 :3 0
25 :3 0 4c :3 0
40 :3 0 7e :3 0
4b :3 0 2f :2 0
629 bc1 bc4 2f
:2 0 62c bb8 bc7
bb7 bc8 0 c4b
7e :3 0 60 :3 0
2f :2 0 637 bca
bcd a2 :2 0 2f
:2 0 63c bcf bd1
:3 0 60 :3 0 11b
:3 0 1f :3 0 63f
bd4 bd6 bd3 bd7
0 bd9 641 c48
71 :3 0 72 :3 0
bda bdb 0 71
:3 0 84 :3 0 bdd
bde 0 13 :2 0
2 :4 0 12e :2 0
86 :2 0 2c :2 0
643 be3 be5 :3 0
646 bdf be7 bdc
be9 be8 :2 0 74
:3 0 87 :3 0 beb
bec 0 76 :4 0
12f :4 0 79 :2 0
7a :3 0 64a bf0
bf2 :3 0 79 :2 0
9c :4 0 64d bf4
bf6 :3 0 79 :2 0
dc :4 0 650 bf8
bfa :3 0 79 :2 0
7e :3 0 82 :3 0
60 :3 0 653 bfe
c00 81 :4 0 655
bfd c03 658 bfc
c05 :3 0 79 :2 0
df :4 0 65b c07
c09 :3 0 79 :2 0
7c :4 0 65e c0b
c0d :3 0 79 :2 0
1c :3 0 661 c0f
c11 :3 0 79 :2 0
7c :4 0 664 c13
c15 :3 0 667 bed
c17 :2 0 c19 66a
c1a bea c19 0
c1b 66c 0 c47
71 :3 0 72 :3 0
c1c c1d 0 71
:3 0 84 :3 0 c1f
c20 0 2c :2 0
2 :4 0 130 :2 0
86 :2 0 2c :2 0
66e c25 c27 :3 0
671 c21 c29 c1e
c2b c2a :2 0 74
:3 0 87 :3 0 c2d
c2e 0 76 :4 0
131 :4 0 79 :2 0
7a :3 0 675 c32
c34 :3 0 678 c2f
c36 :2 0 c38 67b
c39 c2c c38 0
c3a 67d 0 c47
e2 :3 0 e3 :3 0
c3b c3c 0 7e
:3 0 60 :3 0 2f
:2 0 67f c3e c41
1c :3 0 e4 :3 0
682 c3d c45 :2 0
c47 686 c49 bd2
bd9 0 c4a 0
c47 0 c4a 68a
0 c4b 68d c4d
689 93d 0 c4e
0 c4b 0 c4e
693 0 c50 132
:3 0 696 ecd 7e
:3 0 d :3 0 2f
:2 0 698 c51 c54
7e :3 0 e9 :2 0
46 :3 0 2f :2 0
69b c56 c5a 6a0
c57 c5c :3 0 c5d
:2 0 7e :3 0 41
:3 0 2f :2 0 6a3
c5f c62 e8 :2 0
2f :2 0 6a8 c64
c66 :3 0 c67 :2 0
c5e c69 c68 :2 0
57 :3 0 2f :2 0
c6b c6c 0 ecb
7e :3 0 d :3 0
2f :2 0 6ab c6e
c71 7e :3 0 e8
:2 0 41 :3 0 2f
:2 0 6ae c73 c77
6b3 c74 c79 :3 0
71 :3 0 72 :3 0
c7b c7c 0 71
:3 0 84 :3 0 c7e
c7f 0 133 :2 0
2 :4 0 134 :2 0
86 :2 0 2c :2 0
6b6 c84 c86 :3 0
6b9 c80 c88 c7d
c8a c89 :2 0 74
:3 0 87 :3 0 c8c
c8d 0 76 :4 0
135 :4 0 79 :2 0
7a :3 0 6bd c91
c93 :3 0 79 :2 0
9c :4 0 6c0 c95
c97 :3 0 79 :2 0
dc :4 0 6c3 c99
c9b :3 0 79 :2 0
7e :3 0 82 :3 0
dd :3 0 136 :3 0
ca0 ca1 0 6c6
c9f ca3 81 :4 0
6c8 c9e ca6 6cb
c9d ca8 :3 0 6ce
c8e caa :2 0 cac
6d1 cad c8b cac
0 cae 6d3 0
cd8 71 :3 0 72
:3 0 caf cb0 0
71 :3 0 84 :3 0
cb2 cb3 0 2c
:2 0 2 :4 0 137
:2 0 86 :2 0 2c
:2 0 6d5 cb8 cba
:3 0 6d8 cb4 cbc
cb1 cbe cbd :2 0
74 :3 0 87 :3 0
cc0 cc1 0 76
:4 0 138 :4 0 79
:2 0 7a :3 0 6dc
cc5 cc7 :3 0 6df
cc2 cc9 :2 0 ccb
6e2 ccc cbf ccb
0 ccd 6e4 0
cd8 e2 :3 0 139
:3 0 cce ccf 0
dd :3 0 136 :3 0
cd1 cd2 0 e4
:3 0 6e6 cd0 cd5
:2 0 cd8 132 :3 0
6e9 ceb 7e :3 0
d :3 0 2f :2 0
6ed cd9 cdc 7e
:3 0 a2 :2 0 41
:3 0 2f :2 0 6f0
cde ce2 6f5 cdf
ce4 :3 0 57 :3 0
2c :2 0 ce6 ce7
0 ce9 6f8 cea
ce5 ce9 0 cec
c7a cd8 0 cec
6fa 0 ecb 60
:3 0 2f :2 0 ced
cee 0 ecb 11c
:3 0 60 :3 0 100
:3 0 13a :3 0 8d
:3 0 c4 :3 0 13b
:3 0 13c :3 0 13a
:3 0 13b :3 0 c2
:3 0 1c :3 0 13b
:3 0 c5 :3 0 13a
:3 0 c5 :3 0 13a
:3 0 c5 :3 0 13a
:3 0 8d :3 0 13a
:3 0 13d :3 0 dd
:3 0 13e :4 0 13f
1 :8 0 d0e 10
:3 0 96 :3 0 d09
d0a 0 97 :3 0
d0b d0c 0 d0e
6fd d58 98 :3 0
10 :3 0 96 :3 0
d11 d12 0 97
:3 0 d13 d14 0
d4e 71 :3 0 72
:3 0 d16 d17 0
71 :3 0 84 :3 0
d19 d1a 0 99
:2 0 2 :4 0 140
:2 0 86 :2 0 2c
:2 0 700 d1f d21
:3 0 703 d1b d23
d18 d25 d24 :2 0
74 :3 0 87 :3 0
d27 d28 0 76
:4 0 141 :4 0 79
:2 0 7a :3 0 707
d2c d2e :3 0 79
:2 0 9c :4 0 70a
d30 d32 :3 0 79
:2 0 9d :4 0 70d
d34 d36 :3 0 79
:2 0 97 :3 0 710
d38 d3a :3 0 79
:2 0 9e :4 0 713
d3c d3e :3 0 79
:2 0 9f :3 0 a0
:3 0 2c :2 0 a1
:2 0 716 d41 d45
71a d40 d47 :3 0
71d d29 d49 :2 0
d4b 720 d4c d26
d4b 0 d4d 722
0 d4e 724 d51
:3 0 d51 0 d51
d50 d4e d4f :6 0
d53 1e :3 0 727
d55 729 d54 d53
:2 0 d56 72b :2 0
d58 0 d58 d57
d0e d56 :6 0 ecb
1 :3 0 7e :3 0
60 :3 0 2f :2 0
72d d5a d5d e8
:2 0 2f :2 0 732
d5f d61 :3 0 71
:3 0 72 :3 0 d63
d64 0 71 :3 0
84 :3 0 d66 d67
0 13 :2 0 2
:4 0 142 :2 0 86
:2 0 2c :2 0 735
d6c d6e :3 0 738
d68 d70 d65 d72
d71 :2 0 74 :3 0
87 :3 0 d74 d75
0 76 :4 0 143
:4 0 79 :2 0 7a
:3 0 73c d79 d7b
:3 0 79 :2 0 9c
:4 0 73f d7d d7f
:3 0 79 :2 0 dc
:4 0 742 d81 d83
:3 0 79 :2 0 7e
:3 0 82 :3 0 dd
:3 0 144 :3 0 d88
d89 0 745 d87
d8b 81 :4 0 747
d86 d8e 74a d85
d90 :3 0 79 :2 0
df :4 0 74d d92
d94 :3 0 79 :2 0
7c :4 0 750 d96
d98 :3 0 79 :2 0
1c :3 0 753 d9a
d9c :3 0 79 :2 0
7c :4 0 756 d9e
da0 :3 0 759 d76
da2 :2 0 da4 75c
da5 d73 da4 0
da6 75e 0 dd0
71 :3 0 72 :3 0
da7 da8 0 71
:3 0 84 :3 0 daa
dab 0 2c :2 0
2 :4 0 145 :2 0
86 :2 0 2c :2 0
760 db0 db2 :3 0
763 dac db4 da9
db6 db5 :2 0 74
:3 0 87 :3 0 db8
db9 0 76 :4 0
146 :4 0 79 :2 0
7a :3 0 767 dbd
dbf :3 0 76a dba
dc1 :2 0 dc3 76d
dc4 db7 dc3 0
dc5 76f 0 dd0
e2 :3 0 e3 :3 0
dc6 dc7 0 dd
:3 0 144 :3 0 dc9
dca 0 1c :3 0
e4 :3 0 771 dc8
dce :2 0 dd0 775
dd1 d62 dd0 0
dd2 779 0 ecb
11c :3 0 60 :3 0
100 :3 0 c4 :3 0
13b :3 0 147 :3 0
148 :3 0 149 :3 0
149 :3 0 8d :3 0
13b :3 0 92 :3 0
149 :3 0 91 :3 0
13b :3 0 91 :3 0
13b :3 0 92 :3 0
1f :3 0 13b :3 0
c2 :3 0 1c :3 0
b6 :3 0 9f :3 0
13b :3 0 ae :3 0
149 :3 0 14a :4 0
14b 1 :8 0 df5
10 :3 0 96 :3 0
df0 df1 0 97
:3 0 df2 df3 0
df5 77b e3f 98
:3 0 10 :3 0 96
:3 0 df8 df9 0
97 :3 0 dfa dfb
0 e35 71 :3 0
72 :3 0 dfd dfe
0 71 :3 0 84
:3 0 e00 e01 0
99 :2 0 2 :4 0
14c :2 0 86 :2 0
2c :2 0 77e e06
e08 :3 0 781 e02
e0a dff e0c e0b
:2 0 74 :3 0 87
:3 0 e0e e0f 0
76 :4 0 14d :4 0
79 :2 0 7a :3 0
785 e13 e15 :3 0
79 :2 0 9c :4 0
788 e17 e19 :3 0
79 :2 0 9d :4 0
78b e1b e1d :3 0
79 :2 0 97 :3 0
78e e1f e21 :3 0
79 :2 0 9e :4 0
791 e23 e25 :3 0
79 :2 0 9f :3 0
a0 :3 0 2c :2 0
a1 :2 0 794 e28
e2c 798 e27 e2e
:3 0 79b e10 e30
:2 0 e32 79e e33
e0d e32 0 e34
7a0 0 e35 7a2
e38 :3 0 e38 0
e38 e37 e35 e36
:6 0 e3a 20 :3 0
7a5 e3c 7a7 e3b
e3a :2 0 e3d 7a9
:2 0 e3f 0 e3f
e3e df5 e3d :6 0
ecb 1 :3 0 7e
:3 0 60 :3 0 2f
:2 0 7ab e41 e44
e8 :2 0 2f :2 0
7b0 e46 e48 :3 0
71 :3 0 72 :3 0
e4a e4b 0 71
:3 0 84 :3 0 e4d
e4e 0 13 :2 0
2 :4 0 14e :2 0
86 :2 0 2c :2 0
7b3 e53 e55 :3 0
7b6 e4f e57 e4c
e59 e58 :2 0 74
:3 0 87 :3 0 e5b
e5c 0 76 :4 0
14f :4 0 79 :2 0
7a :3 0 7ba e60
e62 :3 0 79 :2 0
9c :4 0 7bd e64
e66 :3 0 79 :2 0
dc :4 0 7c0 e68
e6a :3 0 79 :2 0
7e :3 0 82 :3 0
dd :3 0 150 :3 0
e6f e70 0 7c3
e6e e72 81 :4 0
7c5 e6d e75 7c8
e6c e77 :3 0 79
:2 0 df :4 0 7cb
e79 e7b :3 0 79
:2 0 7c :4 0 7ce
e7d e7f :3 0 79
:2 0 1c :3 0 7d1
e81 e83 :3 0 79
:2 0 7c :4 0 7d4
e85 e87 :3 0 7d7
e5d e89 :2 0 e8b
7da e8c e5a e8b
0 e8d 7dc 0
eb7 71 :3 0 72
:3 0 e8e e8f 0
71 :3 0 84 :3 0
e91 e92 0 2c
:2 0 2 :4 0 151
:2 0 86 :2 0 2c
:2 0 7de e97 e99
:3 0 7e1 e93 e9b
e90 e9d e9c :2 0
74 :3 0 87 :3 0
e9f ea0 0 76
:4 0 152 :4 0 79
:2 0 7a :3 0 7e5
ea4 ea6 :3 0 7e8
ea1 ea8 :2 0 eaa
7eb eab e9e eaa
0 eac 7ed 0
eb7 e2 :3 0 e3
:3 0 ead eae 0
dd :3 0 150 :3 0
eb0 eb1 0 1c
:3 0 e4 :3 0 7ef
eaf eb5 :2 0 eb7
7f3 eb8 e49 eb7
0 eb9 7f7 0
ecb 47 :3 0 d
:3 0 eba ebb 0
ecb 60 :3 0 153
:3 0 1f :3 0 1c
:3 0 47 :3 0 40
:3 0 7e :3 0 57
:3 0 2f :2 0 7f9
ec3 ec6 7fc ebe
ec8 ebd ec9 0
ecb 802 ecc c6a
ecb 0 ece 680
c50 0 ece 80c
0 f4f 7e :3 0
60 :3 0 2f :2 0
80f ecf ed2 a2
:2 0 2f :2 0 814
ed4 ed6 :3 0 60
:3 0 11b :3 0 1f
:3 0 817 ed9 edb
ed8 edc 0 ede
819 edf ed7 ede
0 ee0 81b 0
f4f 71 :3 0 72
:3 0 ee1 ee2 0
71 :3 0 84 :3 0
ee4 ee5 0 13
:2 0 2 :4 0 154
:2 0 86 :2 0 2c
:2 0 81d eea eec
:3 0 820 ee6 eee
ee3 ef0 eef :2 0
74 :3 0 87 :3 0
ef2 ef3 0 76
:4 0 155 :4 0 79
:2 0 7a :3 0 824
ef7 ef9 :3 0 79
:2 0 9c :4 0 827
efb efd :3 0 79
:2 0 dc :4 0 82a
eff f01 :3 0 79
:2 0 7e :3 0 82
:3 0 60 :3 0 82d
f05 f07 81 :4 0
82f f04 f0a 832
f03 f0c :3 0 79
:2 0 df :4 0 835
f0e f10 :3 0 79
:2 0 7c :4 0 838
f12 f14 :3 0 79
:2 0 1c :3 0 83b
f16 f18 :3 0 79
:2 0 7c :4 0 83e
f1a f1c :3 0 841
ef4 f1e :2 0 f20
844 f21 ef1 f20
0 f22 846 0
f4f 71 :3 0 72
:3 0 f23 f24 0
71 :3 0 84 :3 0
f26 f27 0 2c
:2 0 2 :4 0 156
:2 0 86 :2 0 2c
:2 0 848 f2c f2e
:3 0 84b f28 f30
f25 f32 f31 :2 0
74 :3 0 87 :3 0
f34 f35 0 76
:4 0 157 :4 0 79
:2 0 7a :3 0 84f
f39 f3b :3 0 852
f36 f3d :2 0 f3f
855 f40 f33 f3f
0 f41 857 0
f4f e2 :3 0 e3
:3 0 f42 f43 0
7e :3 0 60 :3 0
2f :2 0 859 f45
f48 1c :3 0 e4
:3 0 85c f44 f4c
:2 0 f4f 132 :3 0
860 23b9 6 :3 0
ef :2 0 86c f51
f52 :3 0 f53 :2 0
8 :3 0 ef :2 0
86e f56 f57 :3 0
f58 :2 0 f54 f5a
f59 :2 0 24 :3 0
6 :3 0 f5c f5d
0 2247 25 :3 0
8 :3 0 f5f f60
0 2247 e5 :3 0
e6 :3 0 f62 f63
0 24 :3 0 25
:3 0 e7 :2 0 870
f64 f68 e8 :2 0
2f :2 0 876 f6a
f6c :3 0 f6d :2 0
e5 :3 0 e6 :3 0
f6f f70 0 25
:3 0 23 :3 0 e7
:2 0 879 f71 f75
e9 :2 0 2f :2 0
87f f77 f79 :3 0
f7a :2 0 f6e f7c
f7b :2 0 71 :3 0
72 :3 0 f7e f7f
0 71 :3 0 84
:3 0 f81 f82 0
13 :2 0 2 :4 0
158 :2 0 86 :2 0
2c :2 0 882 f87
f89 :3 0 885 f83
f8b f80 f8d f8c
:2 0 74 :3 0 87
:3 0 f8f f90 0
76 :4 0 159 :4 0
79 :2 0 7a :3 0
889 f94 f96 :3 0
79 :2 0 9c :4 0
88c f98 f9a :3 0
79 :2 0 dc :4 0
88f f9c f9e :3 0
79 :2 0 7e :3 0
82 :3 0 dd :3 0
ec :3 0 fa3 fa4
0 892 fa2 fa6
81 :4 0 894 fa1
fa9 897 fa0 fab
:3 0 79 :2 0 df
:4 0 89a fad faf
:3 0 79 :2 0 7c
:4 0 89d fb1 fb3
:3 0 79 :2 0 1c
:3 0 8a0 fb5 fb7
:3 0 79 :2 0 7c
:4 0 8a3 fb9 fbb
:3 0 8a6 f91 fbd
:2 0 fbf 8a9 fc0
f8e fbf 0 fc1
8ab 0 feb 71
:3 0 72 :3 0 fc2
fc3 0 71 :3 0
84 :3 0 fc5 fc6
0 2c :2 0 2
:4 0 15a :2 0 86
:2 0 2c :2 0 8ad
fcb fcd :3 0 8b0
fc7 fcf fc4 fd1
fd0 :2 0 74 :3 0
87 :3 0 fd3 fd4
0 76 :4 0 15b
:4 0 79 :2 0 7a
:3 0 8b4 fd8 fda
:3 0 8b7 fd5 fdc
:2 0 fde 8ba fdf
fd2 fde 0 fe0
8bc 0 feb e2
:3 0 e3 :3 0 fe1
fe2 0 dd :3 0
ec :3 0 fe4 fe5
0 1c :3 0 e4
:3 0 8be fe3 fe9
:2 0 feb 8c2 fec
f7d feb 0 fed
8c6 0 2247 92
:3 0 c9 :3 0 ca
:3 0 1f :3 0 4b
:3 0 4c :3 0 d6
:3 0 92 :3 0 1f
:3 0 8d :3 0 3e
:4 0 15c 1 :8 0
fff 10 :3 0 96
:3 0 ffa ffb 0
97 :3 0 ffc ffd
0 fff 8c8 1049
98 :3 0 10 :3 0
96 :3 0 1002 1003
0 97 :3 0 1004
1005 0 103f 71
:3 0 72 :3 0 1007
1008 0 71 :3 0
84 :3 0 100a 100b
0 99 :2 0 2
:4 0 15d :2 0 86
:2 0 2c :2 0 8cb
1010 1012 :3 0 8ce
100c 1014 1009 1016
1015 :2 0 74 :3 0
87 :3 0 1018 1019
0 76 :4 0 15e
:4 0 79 :2 0 7a
:3 0 8d2 101d 101f
:3 0 79 :2 0 9c
:4 0 8d5 1021 1023
:3 0 79 :2 0 9d
:4 0 8d8 1025 1027
:3 0 79 :2 0 97
:3 0 8db 1029 102b
:3 0 79 :2 0 9e
:4 0 8de 102d 102f
:3 0 79 :2 0 9f
:3 0 a0 :3 0 2c
:2 0 a1 :2 0 8e1
1032 1036 8e5 1031
1038 :3 0 8e8 101a
103a :2 0 103c 8eb
103d 1017 103c 0
103e 8ed 0 103f
8ef 1042 :3 0 1042
0 1042 1041 103f
1040 :6 0 1044 22
:3 0 8f2 1046 8f4
1045 1044 :2 0 1047
8f6 :2 0 1049 0
1049 1048 fff 1047
:6 0 2247 1 :3 0
9f :3 0 2d :3 0
2c :2 0 2c :2 0
8f8 104b 104f a2
:2 0 2c :4 0 8fe
1051 1053 :3 0 38
:3 0 2c :2 0 1055
1056 0 1058 901
105d 38 :3 0 2f
:2 0 1059 105a 0
105c 903 105e 1054
1058 0 105f 0
105c 0 105f 905
0 2247 6c :3 0
2f :2 0 1060 1061
0 2247 6d :3 0
2f :2 0 1063 1064
0 2247 e5 :3 0
e6 :3 0 1066 1067
0 24 :3 0 22
:3 0 e7 :2 0 908
1068 106c e9 :2 0
2f :2 0 90e 106e
1070 :3 0 1071 :2 0
e5 :3 0 e6 :3 0
1073 1074 0 25
:3 0 23 :3 0 e7
:2 0 911 1075 1079
e9 :2 0 2f :2 0
917 107b 107d :3 0
107e :2 0 1072 1080
107f :2 0 7e :3 0
9 :3 0 2f :2 0
91a 1082 1085 7e
:3 0 e9 :2 0 43
:3 0 2f :2 0 91d
1087 108b 922 1088
108d :3 0 108e :2 0
1081 1090 108f :2 0
e5 :3 0 e6 :3 0
1092 1093 0 24
:3 0 22 :3 0 e7
:2 0 925 1094 1098
e9 :2 0 2f :2 0
92b 109a 109c :3 0
c9 :3 0 ca :3 0
4b :3 0 4c :3 0
d6 :3 0 92 :3 0
1f :3 0 8d :3 0
3e :4 0 15f 1
:8 0 10ad 10 :3 0
96 :3 0 10a8 10a9
0 97 :3 0 10aa
10ab 0 10ad 92e
10f7 98 :3 0 10
:3 0 96 :3 0 10b0
10b1 0 97 :3 0
10b2 10b3 0 10ed
71 :3 0 72 :3 0
10b5 10b6 0 71
:3 0 84 :3 0 10b8
10b9 0 99 :2 0
2 :4 0 160 :2 0
86 :2 0 2c :2 0
931 10be 10c0 :3 0
934 10ba 10c2 10b7
10c4 10c3 :2 0 74
:3 0 87 :3 0 10c6
10c7 0 76 :4 0
161 :4 0 79 :2 0
7a :3 0 938 10cb
10cd :3 0 79 :2 0
9c :4 0 93b 10cf
10d1 :3 0 79 :2 0
9d :4 0 93e 10d3
10d5 :3 0 79 :2 0
97 :3 0 941 10d7
10d9 :3 0 79 :2 0
9e :4 0 944 10db
10dd :3 0 79 :2 0
9f :3 0 a0 :3 0
2c :2 0 a1 :2 0
947 10e0 10e4 94b
10df 10e6 :3 0 94e
10c8 10e8 :2 0 10ea
951 10eb 10c5 10ea
0 10ec 953 0
10ed 955 10f0 :3 0
10f0 0 10f0 10ef
10ed 10ee :6 0 10f2
24 :3 0 958 10f4
95a 10f3 10f2 :2 0
10f5 95c :2 0 10f7
0 10f7 10f6 10ad
10f5 :6 0 1103 1
:3 0 22 :3 0 24
:3 0 10f9 10fa 0
1103 43 :3 0 2f
:2 0 10fc 10fd 0
1103 6c :3 0 2c
:2 0 10ff 1100 0
1103 132 :3 0 95e
1673 e5 :3 0 e6
:3 0 1104 1105 0
25 :3 0 23 :3 0
e7 :2 0 963 1106
110a e9 :2 0 2f
:2 0 969 110c 110e
:3 0 e5 :3 0 f6
:3 0 b6 :3 0 9f
:3 0 25 :3 0 e5
:3 0 f8 :3 0 23
:3 0 25 :3 0 100
:4 0 162 1 :8 0
1120 10 :3 0 96
:3 0 111b 111c 0
97 :3 0 111d 111e
0 1120 96c 116a
98 :3 0 10 :3 0
96 :3 0 1123 1124
0 97 :3 0 1125
1126 0 1160 71
:3 0 72 :3 0 1128
1129 0 71 :3 0
84 :3 0 112b 112c
0 99 :2 0 2
:4 0 163 :2 0 86
:2 0 2c :2 0 96f
1131 1133 :3 0 972
112d 1135 112a 1137
1136 :2 0 74 :3 0
87 :3 0 1139 113a
0 76 :4 0 164
:4 0 79 :2 0 7a
:3 0 976 113e 1140
:3 0 79 :2 0 9c
:4 0 979 1142 1144
:3 0 79 :2 0 9d
:4 0 97c 1146 1148
:3 0 79 :2 0 97
:3 0 97f 114a 114c
:3 0 79 :2 0 9e
:4 0 982 114e 1150
:3 0 79 :2 0 9f
:3 0 a0 :3 0 2c
:2 0 a1 :2 0 985
1153 1157 989 1152
1159 :3 0 98c 113b
115b :2 0 115d 98f
115e 1138 115d 0
115f 991 0 1160
993 1163 :3 0 1163
0 1163 1162 1160
1161 :6 0 1165 26
:3 0 996 1167 998
1166 1165 :2 0 1168
99a :2 0 116a 0
116a 1169 1120 1168
:6 0 1307 1 :3 0
6d :3 0 e5 :3 0
165 :3 0 116d 116e
0 25 :3 0 23
:3 0 99c 116f 1172
116c 1173 0 1307
31 :3 0 f0 :2 0
2c :2 0 99f 1176
1178 :3 0 1175 1179
0 1307 60 :3 0
166 :3 0 1f :3 0
3e :3 0 1c :3 0
27 :3 0 29 :3 0
61 :3 0 63 :3 0
31 :3 0 30 :3 0
2e :3 0 9a1 117c
1187 117b 1188 0
1307 7e :3 0 49
:3 0 2f :2 0 9ac
118a 118d e8 :2 0
2f :2 0 9b1 118f
1191 :3 0 1192 :2 0
33 :3 0 ef :2 0
9b4 1195 1196 :3 0
1197 :2 0 1198 :2 0
1193 119a 1199 :2 0
167 :3 0 168 :3 0
169 :3 0 92 :3 0
1f :3 0 c5 :3 0
1c :3 0 f7 :3 0
b6 :3 0 9f :3 0
33 :4 0 16a 1
:8 0 11bd 110 :4 0
11a8 :3 0 e4 :3 0
a2 :2 0 9b8 11ab
11ac :3 0 10 :3 0
96 :3 0 11ae 11af
0 2f :2 0 11b0
11b1 0 11b3 9bb
11ba 10 :3 0 96
:3 0 11b4 11b5 0
111 :2 0 11b6 11b7
0 11b9 9bd 11bb
11ad 11b3 0 11bc
0 11b9 0 11bc
9bf 0 11bd 9c2
1207 98 :3 0 10
:3 0 96 :3 0 11c0
11c1 0 97 :3 0
11c2 11c3 0 11fd
71 :3 0 72 :3 0
11c5 11c6 0 71
:3 0 84 :3 0 11c8
11c9 0 99 :2 0
2 :4 0 16b :2 0
86 :2 0 2c :2 0
9c5 11ce 11d0 :3 0
9c8 11ca 11d2 11c7
11d4 11d3 :2 0 74
:3 0 87 :3 0 11d6
11d7 0 76 :4 0
16c :4 0 79 :2 0
7a :3 0 9cc 11db
11dd :3 0 79 :2 0
9c :4 0 9cf 11df
11e1 :3 0 79 :2 0
9d :4 0 9d2 11e3
11e5 :3 0 79 :2 0
97 :3 0 9d5 11e7
11e9 :3 0 79 :2 0
9e :4 0 9d8 11eb
11ed :3 0 79 :2 0
9f :3 0 a0 :3 0
2c :2 0 a1 :2 0
9db 11f0 11f4 9df
11ef 11f6 :3 0 9e2
11d8 11f8 :2 0 11fa
9e5 11fb 11d5 11fa
0 11fc 9e7 0
11fd 9e9 1200 :3 0
1200 0 1200 11ff
11fd 11fe :6 0 1202
28 :3 0 9ec 1204
9ee 1203 1202 :2 0
1205 9f0 :2 0 1207
0 1207 1206 11bd
1205 :6 0 1209 1
:3 0 9f2 120a 119b
1209 0 120b 9f4
0 1307 9f :3 0
2b :3 0 2c :2 0
2c :2 0 9f6 120c
1210 a2 :2 0 16d
:4 0 9fc 1212 1214
:3 0 4d :3 0 16d
:2 0 1216 1217 0
1219 9ff 121e 4d
:3 0 2f :2 0 121a
121b 0 121d a01
121f 1215 1219 0
1220 0 121d 0
1220 a03 0 1307
60 :3 0 16e :3 0
1f :3 0 3e :3 0
1c :3 0 3f :3 0
2d :3 0 27 :3 0
29 :3 0 22 :3 0
25 :3 0 4d :3 0
4c :3 0 44 :3 0
40 :3 0 16d :2 0
6d :3 0 2f :2 0
a06 1222 1233 1221
1234 0 1307 b6
:3 0 9f :3 0 22
:3 0 b6 :3 0 9f
:3 0 25 :3 0 b7
:3 0 b8 :3 0 b9
:3 0 bb :3 0 27
:3 0 29 :3 0 2e
:3 0 30 :3 0 61
:3 0 63 :3 0 c4
:3 0 c5 :3 0 1c
:4 0 16f 1 :8 0
124f 10 :3 0 96
:3 0 124a 124b 0
97 :3 0 124c 124d
0 124f a17 1299
98 :3 0 10 :3 0
96 :3 0 1252 1253
0 97 :3 0 1254
1255 0 128f 71
:3 0 72 :3 0 1257
1258 0 71 :3 0
84 :3 0 125a 125b
0 99 :2 0 2
:4 0 170 :2 0 86
:2 0 2c :2 0 a1a
1260 1262 :3 0 a1d
125c 1264 1259 1266
1265 :2 0 74 :3 0
87 :3 0 1268 1269
0 76 :4 0 171
:4 0 79 :2 0 7a
:3 0 a21 126d 126f
:3 0 79 :2 0 9c
:4 0 a24 1271 1273
:3 0 79 :2 0 9d
:4 0 a27 1275 1277
:3 0 79 :2 0 97
:3 0 a2a 1279 127b
:3 0 79 :2 0 9e
:4 0 a2d 127d 127f
:3 0 79 :2 0 9f
:3 0 a0 :3 0 2c
:2 0 a1 :2 0 a30
1282 1286 a34 1281
1288 :3 0 a37 126a
128a :2 0 128c a3a
128d 1267 128c 0
128e a3c 0 128f
a3e 1292 :3 0 1292
0 1292 1291 128f
1290 :6 0 1294 2a
:3 0 a41 1296 a43
1295 1294 :2 0 1297
a45 :2 0 1299 0
1299 1298 124f 1297
:6 0 1307 1 :3 0
31 :3 0 2f :2 0
129b 129c 0 1307
60 :3 0 166 :3 0
1f :3 0 3e :3 0
1c :3 0 27 :3 0
29 :3 0 61 :3 0
63 :3 0 31 :3 0
30 :3 0 2e :3 0
a47 129f 12aa 129e
12ab 0 1307 60
:3 0 11b :3 0 1f
:3 0 a52 12ae 12b0
12ad 12b1 0 1307
10 :3 0 96 :3 0
12b3 12b4 0 2f
:2 0 12b5 12b6 0
1307 71 :3 0 72
:3 0 12b8 12b9 0
71 :3 0 84 :3 0
12bb 12bc 0 172
:2 0 2 :4 0 173
:2 0 86 :2 0 2c
:2 0 a54 12c1 12c3
:3 0 a57 12bd 12c5
12ba 12c7 12c6 :2 0
74 :3 0 87 :3 0
12c9 12ca 0 76
:4 0 174 :4 0 79
:2 0 7a :3 0 a5b
12ce 12d0 :3 0 79
:2 0 9c :4 0 a5e
12d2 12d4 :3 0 79
:2 0 dc :4 0 a61
12d6 12d8 :3 0 79
:2 0 7e :3 0 82
:3 0 10 :3 0 96
:3 0 12dd 12de 0
a64 12dc 12e0 81
:4 0 a66 12db 12e3
a69 12da 12e5 :3 0
79 :2 0 df :4 0
a6c 12e7 12e9 :3 0
79 :2 0 7c :4 0
a6f 12eb 12ed :3 0
79 :2 0 1a :3 0
a72 12ef 12f1 :3 0
79 :2 0 7c :4 0
a75 12f3 12f5 :3 0
a78 12cb 12f7 :2 0
12f9 a7b 12fa 12c8
12f9 0 12fb a7d
0 1307 e2 :3 0
175 :3 0 12fc 12fd
0 10 :3 0 96
:3 0 12ff 1300 0
1a :3 0 e4 :3 0
a7f 12fe 1304 :2 0
1307 132 :3 0 a83
1308 110f 1307 0
1674 7e :3 0 43
:3 0 2f :2 0 a92
1309 130c 7e :3 0
176 :2 0 9 :3 0
2f :2 0 a95 130e
1312 a9a 130f 1314
:3 0 43 :3 0 7e
:3 0 9 :3 0 2f
:2 0 a9d 1317 131a
f0 :2 0 7e :3 0
43 :3 0 2f :2 0
aa0 131d 1320 aa3
131c 1322 :3 0 1316
1323 0 1329 6c
:3 0 2c :2 0 1325
1326 0 1329 132
:3 0 aa6 132a 1315
1329 0 1674 7e
:3 0 9 :3 0 2f
:2 0 aa9 132b 132e
a2 :2 0 2f :2 0
aae 1330 1332 :3 0
43 :3 0 2f :2 0
1334 1335 0 1392
6c :3 0 2c :2 0
1337 1338 0 1392
cb :3 0 22 :3 0
d6 :3 0 8d :3 0
3e :4 0 177 1
:8 0 1345 10 :3 0
96 :3 0 1340 1341
0 97 :3 0 1342
1343 0 1345 ab1
138f 98 :3 0 10
:3 0 96 :3 0 1348
1349 0 97 :3 0
134a 134b 0 1385
71 :3 0 72 :3 0
134d 134e 0 71
:3 0 84 :3 0 1350
1351 0 99 :2 0
2 :4 0 178 :2 0
86 :2 0 2c :2 0
ab4 1356 1358 :3 0
ab7 1352 135a 134f
135c 135b :2 0 74
:3 0 87 :3 0 135e
135f 0 76 :4 0
179 :4 0 79 :2 0
7a :3 0 abb 1363
1365 :3 0 79 :2 0
9c :4 0 abe 1367
1369 :3 0 79 :2 0
9d :4 0 ac1 136b
136d :3 0 79 :2 0
97 :3 0 ac4 136f
1371 :3 0 79 :2 0
9e :4 0 ac7 1373
1375 :3 0 79 :2 0
9f :3 0 a0 :3 0
2c :2 0 a1 :2 0
aca 1378 137c ace
1377 137e :3 0 ad1
1360 1380 :2 0 1382
ad4 1383 135d 1382
0 1384 ad6 0
1385 ad8 1388 :3 0
1388 0 1388 1387
1385 1386 :6 0 138a
2c :3 0 adb 138c
add 138b 138a :2 0
138d adf :2 0 138f
0 138f 138e 1345
138d :6 0 1392 1
:3 0 132 :3 0 ae1
1393 1333 1392 0
1674 7e :3 0 43
:3 0 2f :2 0 ae5
1394 1397 7e :3 0
e8 :2 0 9 :3 0
2f :2 0 ae8 1399
139d aed 139a 139f
:3 0 43 :3 0 7e
:3 0 43 :3 0 2f
:2 0 af0 13a2 13a5
f0 :2 0 7e :3 0
9 :3 0 2f :2 0
af3 13a8 13ab af6
13a7 13ad :3 0 13a1
13ae 0 1671 32
:4 0 13b0 13b1 0
1671 6a :3 0 89
:4 0 13b3 13b4 0
1671 7e :3 0 38
:3 0 2f :2 0 af9
13b6 13b9 a2 :2 0
2c :2 0 afe 13bb
13bd :3 0 6a :3 0
17a :4 0 79 :2 0
17b :4 0 b01 13c1
13c3 :3 0 79 :2 0
1f :3 0 b04 13c5
13c7 :3 0 79 :2 0
17c :4 0 b07 13c9
13cb :3 0 79 :2 0
22 :3 0 b0a 13cd
13cf :3 0 79 :2 0
17d :4 0 b0d 13d1
13d3 :3 0 79 :2 0
17e :4 0 b10 13d5
13d7 :3 0 79 :2 0
82 :3 0 7e :3 0
43 :3 0 2f :2 0
b13 13db 13de b16
13da 13e0 b18 13d9
13e2 :3 0 13bf 13e3
0 13ea 17f :3 0
6e :3 0 6a :3 0
13e6 13e7 0 13e8
:2 0 13ea b1b 1417
6a :3 0 17a :4 0
79 :2 0 17b :4 0
b1e 13ed 13ef :3 0
79 :2 0 3f :3 0
b21 13f1 13f3 :3 0
79 :2 0 17c :4 0
b24 13f5 13f7 :3 0
79 :2 0 22 :3 0
b27 13f9 13fb :3 0
79 :2 0 17d :4 0
b2a 13fd 13ff :3 0
79 :2 0 17e :4 0
b2d 1401 1403 :3 0
79 :2 0 82 :3 0
7e :3 0 43 :3 0
2f :2 0 b30 1407
140a b33 1406 140c
b35 1405 140e :3 0
13eb 140f 0 1416
17f :3 0 6f :3 0
6a :3 0 1412 1413
0 1414 :2 0 1416
b38 1418 13be 13ea
0 1419 0 1416
0 1419 b3b 0
1671 180 :3 0 7e
:3 0 38 :3 0 2f
:2 0 b3e 141b 141e
a2 :2 0 2c :2 0
b43 1420 1422 :3 0
6e :3 0 32 :4 0
1427 :2 0 143a 1424
1425 :3 0 6e :3 0
110 :3 0 1428 1429
:3 0 10 :3 0 96
:3 0 142b 142c 0
2f :2 0 142d 142e
0 1430 b46 1437
10 :3 0 96 :3 0
1431 1432 0 111
:2 0 1433 1434 0
1436 b48 1438 142a
1430 0 1439 0
1436 0 1439 b4a
0 143a b4d 1452
6f :3 0 32 :4 0
143e :2 0 1451 143b
143c :3 0 6f :3 0
110 :3 0 143f 1440
:3 0 10 :3 0 96
:3 0 1442 1443 0
2f :2 0 1444 1445
0 1447 b50 144e
10 :3 0 96 :3 0
1448 1449 0 111
:2 0 144a 144b 0
144d b52 144f 1441
1447 0 1450 0
144d 0 1450 b54
0 1451 b57 1453
1423 143a 0 1454
0 1451 0 1454
b5a 0 1464 10
:3 0 96 :3 0 1455
1456 0 10 :3 0
e9 :2 0 11a :3 0
1458 145a 0 b5f
1459 145c :3 0 145d
:2 0 181 :8 0 1461
b62 1462 145e 1461
0 1463 b64 0
1464 b66 1466 180
:4 0 1464 :4 0 1671
7e :3 0 38 :3 0
2f :2 0 b69 1467
146a a2 :2 0 2c
:2 0 b6e 146c 146e
:3 0 182 :3 0 6e
:4 0 1473 :2 0 1479
1471 0 10 :3 0
96 :3 0 1474 1475
0 97 :3 0 1476
1477 0 1479 b71
14c3 98 :3 0 10
:3 0 96 :3 0 147c
147d 0 97 :3 0
147e 147f 0 14b9
71 :3 0 72 :3 0
1481 1482 0 71
:3 0 84 :3 0 1484
1485 0 99 :2 0
2 :4 0 183 :2 0
86 :2 0 2c :2 0
b74 148a 148c :3 0
b77 1486 148e 1483
1490 148f :2 0 74
:3 0 87 :3 0 1492
1493 0 76 :4 0
184 :4 0 79 :2 0
7a :3 0 b7b 1497
1499 :3 0 79 :2 0
9c :4 0 b7e 149b
149d :3 0 79 :2 0
9d :4 0 b81 149f
14a1 :3 0 79 :2 0
97 :3 0 b84 14a3
14a5 :3 0 79 :2 0
9e :4 0 b87 14a7
14a9 :3 0 79 :2 0
9f :3 0 a0 :3 0
2c :2 0 a1 :2 0
b8a 14ac 14b0 b8e
14ab 14b2 :3 0 b91
1494 14b4 :2 0 14b6
b94 14b7 1491 14b6
0 14b8 b96 0
14b9 b98 14bc :3 0
14bc 0 14bc 14bb
14b9 14ba :6 0 14be
2f :3 0 b9b 14c0
b9d 14bf 14be :2 0
14c1 b9f :2 0 14c3
0 14c3 14c2 1479
14c1 :6 0 14c5 1
:3 0 ba1 151c 182
:3 0 6f :4 0 14c9
:2 0 14cf 14c7 0
10 :3 0 96 :3 0
14ca 14cb 0 97
:3 0 14cc 14cd 0
14cf ba3 1519 98
:3 0 10 :3 0 96
:3 0 14d2 14d3 0
97 :3 0 14d4 14d5
0 150f 71 :3 0
72 :3 0 14d7 14d8
0 71 :3 0 84
:3 0 14da 14db 0
99 :2 0 2 :4 0
185 :2 0 86 :2 0
2c :2 0 ba6 14e0
14e2 :3 0 ba9 14dc
14e4 14d9 14e6 14e5
:2 0 74 :3 0 87
:3 0 14e8 14e9 0
76 :4 0 186 :4 0
79 :2 0 7a :3 0
bad 14ed 14ef :3 0
79 :2 0 9c :4 0
bb0 14f1 14f3 :3 0
79 :2 0 9d :4 0
bb3 14f5 14f7 :3 0
79 :2 0 97 :3 0
bb6 14f9 14fb :3 0
79 :2 0 9e :4 0
bb9 14fd 14ff :3 0
79 :2 0 9f :3 0
a0 :3 0 2c :2 0
a1 :2 0 bbc 1502
1506 bc0 1501 1508
:3 0 bc3 14ea 150a
:2 0 150c bc6 150d
14e7 150c 0 150e
bc8 0 150f bca
1512 :3 0 1512 0
1512 1511 150f 1510
:6 0 1514 31 :3 0
bcd 1516 bcf 1515
1514 :2 0 1517 bd1
:2 0 1519 0 1519
1518 14cf 1517 :6 0
151b 1 :3 0 bd3
151d 146f 14c5 0
151e 0 151b 0
151e bd5 0 1671
32 :3 0 187 :2 0
bd8 1520 1521 :3 0
1522 :2 0 7e :3 0
38 :3 0 2f :2 0
bda 1524 1527 a2
:2 0 2c :2 0 bdf
1529 152b :3 0 71
:3 0 72 :3 0 152d
152e 0 71 :3 0
84 :3 0 1530 1531
0 13 :2 0 2
:4 0 188 :2 0 86
:2 0 2c :2 0 be2
1536 1538 :3 0 be5
1532 153a 152f 153c
153b :2 0 74 :3 0
87 :3 0 153e 153f
0 76 :4 0 189
:4 0 79 :2 0 7a
:3 0 be9 1543 1545
:3 0 79 :2 0 9c
:4 0 bec 1547 1549
:3 0 79 :2 0 dc
:4 0 bef 154b 154d
:3 0 79 :2 0 7e
:3 0 82 :3 0 dd
:3 0 de :3 0 1552
1553 0 bf2 1551
1555 81 :4 0 bf4
1550 1558 bf7 154f
155a :3 0 79 :2 0
df :4 0 bfa 155c
155e :3 0 79 :2 0
7c :4 0 bfd 1560
1562 :3 0 79 :2 0
1f :3 0 c00 1564
1566 :3 0 79 :2 0
7c :4 0 c03 1568
156a :3 0 c06 1540
156c :2 0 156e c09
156f 153d 156e 0
1570 c0b 0 159a
71 :3 0 72 :3 0
1571 1572 0 71
:3 0 84 :3 0 1574
1575 0 2c :2 0
2 :4 0 18a :2 0
86 :2 0 2c :2 0
c0d 157a 157c :3 0
c10 1576 157e 1573
1580 157f :2 0 74
:3 0 87 :3 0 1582
1583 0 76 :4 0
18b :4 0 79 :2 0
7a :3 0 c14 1587
1589 :3 0 c17 1584
158b :2 0 158d c1a
158e 1581 158d 0
158f c1c 0 159a
e2 :3 0 e3 :3 0
1590 1591 0 dd
:3 0 de :3 0 1593
1594 0 1f :3 0
e4 :3 0 c1e 1592
1598 :2 0 159a c22
1609 71 :3 0 72
:3 0 159b 159c 0
71 :3 0 84 :3 0
159e 159f 0 13
:2 0 2 :4 0 18c
:2 0 86 :2 0 2c
:2 0 c26 15a4 15a6
:3 0 c29 15a0 15a8
159d 15aa 15a9 :2 0
74 :3 0 87 :3 0
15ac 15ad 0 76
:4 0 18d :4 0 79
:2 0 7a :3 0 c2d
15b1 15b3 :3 0 79
:2 0 9c :4 0 c30
15b5 15b7 :3 0 79
:2 0 dc :4 0 c33
15b9 15bb :3 0 79
:2 0 7e :3 0 82
:3 0 dd :3 0 de
:3 0 15c0 15c1 0
c36 15bf 15c3 81
:4 0 c38 15be 15c6
c3b 15bd 15c8 :3 0
79 :2 0 df :4 0
c3e 15ca 15cc :3 0
79 :2 0 7c :4 0
c41 15ce 15d0 :3 0
79 :2 0 3f :3 0
c44 15d2 15d4 :3 0
79 :2 0 7c :4 0
c47 15d6 15d8 :3 0
c4a 15ae 15da :2 0
15dc c4d 15dd 15ab
15dc 0 15de c4f
0 1608 71 :3 0
72 :3 0 15df 15e0
0 71 :3 0 84
:3 0 15e2 15e3 0
2c :2 0 2 :4 0
18e :2 0 86 :2 0
2c :2 0 c51 15e8
15ea :3 0 c54 15e4
15ec 15e1 15ee 15ed
:2 0 74 :3 0 87
:3 0 15f0 15f1 0
76 :4 0 18f :4 0
79 :2 0 7a :3 0
c58 15f5 15f7 :3 0
c5b 15f2 15f9 :2 0
15fb c5e 15fc 15ef
15fb 0 15fd c60
0 1608 e2 :3 0
e3 :3 0 15fe 15ff
0 dd :3 0 de
:3 0 1601 1602 0
3f :3 0 e4 :3 0
c62 1600 1606 :2 0
1608 c66 160a 152c
159a 0 160b 0
1608 0 160b c6a
0 160c c6d 160d
1523 160c 0 160e
c6f 0 1671 e5
:3 0 f6 :3 0 b6
:3 0 9f :3 0 32
:3 0 e5 :3 0 f8
:3 0 22 :3 0 22
:3 0 100 :4 0 190
1 :8 0 161f 10
:3 0 96 :3 0 161a
161b 0 97 :3 0
161c 161d 0 161f
c71 1669 98 :3 0
10 :3 0 96 :3 0
1622 1623 0 97
:3 0 1624 1625 0
165f 71 :3 0 72
:3 0 1627 1628 0
71 :3 0 84 :3 0
162a 162b 0 99
:2 0 2 :4 0 191
:2 0 86 :2 0 2c
:2 0 c74 1630 1632
:3 0 c77 162c 1634
1629 1636 1635 :2 0
74 :3 0 87 :3 0
1638 1639 0 76
:4 0 192 :4 0 79
:2 0 7a :3 0 c7b
163d 163f :3 0 79
:2 0 9c :4 0 c7e
1641 1643 :3 0 79
:2 0 9d :4 0 c81
1645 1647 :3 0 79
:2 0 97 :3 0 c84
1649 164b :3 0 79
:2 0 9e :4 0 c87
164d 164f :3 0 79
:2 0 9f :3 0 a0
:3 0 2c :2 0 a1
:2 0 c8a 1652 1656
c8e 1651 1658 :3 0
c91 163a 165a :2 0
165c c94 165d 1637
165c 0 165e c96
0 165f c98 1662
:3 0 1662 0 1662
1661 165f 1660 :6 0
1664 33 :3 0 c9b
1666 c9d 1665 1664
:2 0 1667 c9f :2 0
1669 0 1669 1668
161f 1667 :6 0 1671
1 :3 0 43 :3 0
2f :2 0 166b 166c
0 1671 6c :3 0
2c :2 0 166e 166f
0 1671 ca1 1672
13a0 1671 0 1674
109d 1103 0 1674
cac 0 1676 132
:3 0 cb2 190d 7e
:3 0 b :3 0 2f
:2 0 cb4 1677 167a
7e :3 0 e9 :2 0
44 :3 0 2f :2 0
cb7 167c 1680 cbc
167d 1682 :3 0 7e
:3 0 46 :3 0 2f
:2 0 cbf 1684 1687
7e :3 0 a2 :2 0
41 :3 0 2f :2 0
cc2 1689 168d cc7
168a 168f :3 0 71
:3 0 72 :3 0 1691
1692 0 71 :3 0
84 :3 0 1694 1695
0 13 :2 0 2
:4 0 193 :2 0 86
:2 0 2c :2 0 cca
169a 169c :3 0 ccd
1696 169e 1693 16a0
169f :2 0 74 :3 0
87 :3 0 16a2 16a3
0 76 :4 0 194
:4 0 79 :2 0 7a
:3 0 cd1 16a7 16a9
:3 0 79 :2 0 9c
:4 0 cd4 16ab 16ad
:3 0 79 :2 0 dc
:4 0 cd7 16af 16b1
:3 0 79 :2 0 7e
:3 0 82 :3 0 10
:3 0 96 :3 0 16b6
16b7 0 cda 16b5
16b9 81 :4 0 cdc
16b4 16bc cdf 16b3
16be :3 0 79 :2 0
df :4 0 ce2 16c0
16c2 :3 0 79 :2 0
7c :4 0 ce5 16c4
16c6 :3 0 79 :2 0
1c :3 0 ce8 16c8
16ca :3 0 79 :2 0
7c :4 0 ceb 16cc
16ce :3 0 cee 16a4
16d0 :2 0 16d2 cf1
16d3 16a1 16d2 0
16d4 cf3 0 16fe
71 :3 0 72 :3 0
16d5 16d6 0 71
:3 0 84 :3 0 16d8
16d9 0 2c :2 0
2 :4 0 195 :2 0
86 :2 0 2c :2 0
cf5 16de 16e0 :3 0
cf8 16da 16e2 16d7
16e4 16e3 :2 0 74
:3 0 87 :3 0 16e6
16e7 0 76 :4 0
196 :4 0 79 :2 0
7a :3 0 cfc 16eb
16ed :3 0 cff 16e8
16ef :2 0 16f1 d02
16f2 16e5 16f1 0
16f3 d04 0 16fe
e2 :3 0 e3 :3 0
16f4 16f5 0 10
:3 0 96 :3 0 16f7
16f8 0 1c :3 0
e4 :3 0 d06 16f6
16fc :2 0 16fe d0a
16ff 1690 16fe 0
1700 d0e 0 190b
7e :3 0 b :3 0
2f :2 0 d10 1701
1704 a2 :2 0 2f
:2 0 d15 1706 1708
:3 0 44 :3 0 111
:2 0 170a 170b 0
170d d18 1787 7e
:3 0 b :3 0 2f
:2 0 d1a 170e 1711
176 :2 0 2c :2 0
d1f 1713 1715 :3 0
1716 :2 0 7e :3 0
b :3 0 2f :2 0
d22 1718 171b e8
:2 0 197 :2 0 d27
171d 171f :3 0 1720
:2 0 1717 1722 1721
:2 0 71 :3 0 72
:3 0 1724 1725 0
71 :3 0 84 :3 0
1727 1728 0 133
:2 0 2 :4 0 198
:2 0 86 :2 0 2c
:2 0 d2a 172d 172f
:3 0 d2d 1729 1731
1726 1733 1732 :2 0
74 :3 0 87 :3 0
1735 1736 0 76
:4 0 199 :4 0 79
:2 0 7a :3 0 d31
173a 173c :3 0 79
:2 0 9c :4 0 d34
173e 1740 :3 0 79
:2 0 dc :4 0 d37
1742 1744 :3 0 79
:2 0 7e :3 0 82
:3 0 dd :3 0 19a
:3 0 1749 174a 0
d3a 1748 174c 81
:4 0 d3c 1747 174f
d3f 1746 1751 :3 0
d42 1737 1753 :2 0
1755 d45 1756 1734
1755 0 1757 d47
0 1780 71 :3 0
72 :3 0 1758 1759
0 71 :3 0 84
:3 0 175b 175c 0
2c :2 0 2 :4 0
19b :2 0 86 :2 0
2c :2 0 d49 1761
1763 :3 0 d4c 175d
1765 175a 1767 1766
:2 0 74 :3 0 87
:3 0 1769 176a 0
76 :4 0 19c :4 0
79 :2 0 7a :3 0
d50 176e 1770 :3 0
d53 176b 1772 :2 0
1774 d56 1775 1768
1774 0 1776 d58
0 1780 e2 :3 0
139 :3 0 1777 1778
0 dd :3 0 19a
:3 0 177a 177b 0
e4 :3 0 d5a 1779
177e :2 0 1780 d5d
1781 1723 1780 0
1782 d61 0 1786
44 :3 0 b :3 0
1783 1784 0 1786
d63 1788 1709 170d
0 1789 0 1786
0 1789 d66 0
190b 1d :3 0 ef
:2 0 d69 178b 178c
:3 0 178d :2 0 ad
:3 0 60 :3 0 c4
:3 0 c5 :3 0 1d
:4 0 19d 1 :8 0
179a 10 :3 0 96
:3 0 1795 1796 0
97 :3 0 1797 1798
0 179a d6b 17e4
98 :3 0 10 :3 0
96 :3 0 179d 179e
0 97 :3 0 179f
17a0 0 17da 71
:3 0 72 :3 0 17a2
17a3 0 71 :3 0
84 :3 0 17a5 17a6
0 99 :2 0 2
:4 0 19e :2 0 86
:2 0 2c :2 0 d6e
17ab 17ad :3 0 d71
17a7 17af 17a4 17b1
17b0 :2 0 74 :3 0
87 :3 0 17b3 17b4
0 76 :4 0 19f
:4 0 79 :2 0 7a
:3 0 d75 17b8 17ba
:3 0 79 :2 0 9c
:4 0 d78 17bc 17be
:3 0 79 :2 0 9d
:4 0 d7b 17c0 17c2
:3 0 79 :2 0 97
:3 0 d7e 17c4 17c6
:3 0 79 :2 0 9e
:4 0 d81 17c8 17ca
:3 0 79 :2 0 9f
:3 0 a0 :3 0 2c
:2 0 a1 :2 0 d84
17cd 17d1 d88 17cc
17d3 :3 0 d8b 17b5
17d5 :2 0 17d7 d8e
17d8 17b2 17d7 0
17d9 d90 0 17da
d92 17dd :3 0 17dd
0 17dd 17dc 17da
17db :6 0 17df 35
:3 0 d95 17e1 d97
17e0 17df :2 0 17e2
d99 :2 0 17e4 0
17e4 17e3 179a 17e2
:6 0 1870 1 :3 0
10 :3 0 96 :3 0
17e6 17e7 0 10
:3 0 a2 :2 0 11a
:3 0 17e9 17eb 0
d9d 17ea 17ed :3 0
17ee :2 0 7e :3 0
44 :3 0 2f :2 0
da0 17f0 17f3 7e
:3 0 e8 :2 0 60
:3 0 2f :2 0 da3
17f5 17f9 da8 17f6
17fb :3 0 17fc :2 0
17ef 17fe 17fd :2 0
71 :3 0 72 :3 0
1800 1801 0 71
:3 0 84 :3 0 1803
1804 0 13 :2 0
2 :4 0 1a0 :2 0
86 :2 0 2c :2 0
dab 1809 180b :3 0
dae 1805 180d 1802
180f 180e :2 0 74
:3 0 87 :3 0 1811
1812 0 76 :4 0
1a1 :4 0 79 :2 0
7a :3 0 db2 1816
1818 :3 0 79 :2 0
9c :4 0 db5 181a
181c :3 0 79 :2 0
dc :4 0 db8 181e
1820 :3 0 79 :2 0
7e :3 0 82 :3 0
dd :3 0 1a2 :3 0
1825 1826 0 dbb
1824 1828 81 :4 0
dbd 1823 182b dc0
1822 182d :3 0 79
:2 0 df :4 0 dc3
182f 1831 :3 0 79
:2 0 7c :4 0 dc6
1833 1835 :3 0 79
:2 0 1d :3 0 dc9
1837 1839 :3 0 79
:2 0 7c :4 0 dcc
183b 183d :3 0 dcf
1813 183f :2 0 1841
dd2 1842 1810 1841
0 1843 dd4 0
186d 71 :3 0 72
:3 0 1844 1845 0
71 :3 0 84 :3 0
1847 1848 0 2c
:2 0 2 :4 0 1a3
:2 0 86 :2 0 2c
:2 0 dd6 184d 184f
:3 0 dd9 1849 1851
1846 1853 1852 :2 0
74 :3 0 87 :3 0
1855 1856 0 76
:4 0 1a4 :4 0 79
:2 0 7a :3 0 ddd
185a 185c :3 0 de0
1857 185e :2 0 1860
de3 1861 1854 1860
0 1862 de5 0
186d e2 :3 0 e3
:3 0 1863 1864 0
dd :3 0 1a2 :3 0
1866 1867 0 1d
:3 0 e4 :3 0 de7
1865 186b :2 0 186d
deb 186e 17ff 186d
0 186f def 0
1870 df1 1871 178e
1870 0 1872 df4
0 190b 43 :3 0
2f :2 0 1873 1874
0 190b 6c :3 0
16d :2 0 1876 1877
0 190b 7e :3 0
50 :3 0 2f :2 0
df6 1879 187c 176
:2 0 1a5 :2 0 dfb
187e 1880 :3 0 50
:3 0 2c :2 0 1882
1883 0 1885 dfe
1886 1881 1885 0
1887 e00 0 190b
c4 :3 0 1a6 :3 0
ad :3 0 44 :3 0
a8 :3 0 aa :3 0
a7 :3 0 ab :3 0
c3 :3 0 f9 :3 0
1a7 :3 0 c3 :3 0
dd :3 0 1a8 :3 0
dd :3 0 1a9 :3 0
c5 :3 0 1c :4 0
1aa 1 :8 0 18b0
110 :4 0 189b :3 0
e4 :3 0 a2 :2 0
e04 189e 189f :3 0
10 :3 0 96 :3 0
18a1 18a2 0 2f
:2 0 18a3 18a4 0
18a6 e07 18ad 10
:3 0 96 :3 0 18a7
18a8 0 111 :2 0
18a9 18aa 0 18ac
e09 18ae 18a0 18a6
0 18af 0 18ac
0 18af e0b 0
18b0 e0e 18fa 98
:3 0 10 :3 0 96
:3 0 18b3 18b4 0
97 :3 0 18b5 18b6
0 18f0 71 :3 0
72 :3 0 18b8 18b9
0 71 :3 0 84
:3 0 18bb 18bc 0
99 :2 0 2 :4 0
1ab :2 0 86 :2 0
2c :2 0 e11 18c1
18c3 :3 0 e14 18bd
18c5 18ba 18c7 18c6
:2 0 74 :3 0 87
:3 0 18c9 18ca 0
76 :4 0 1ac :4 0
79 :2 0 7a :3 0
e18 18ce 18d0 :3 0
79 :2 0 9c :4 0
e1b 18d2 18d4 :3 0
79 :2 0 9d :4 0
e1e 18d6 18d8 :3 0
79 :2 0 97 :3 0
e21 18da 18dc :3 0
79 :2 0 9e :4 0
e24 18de 18e0 :3 0
79 :2 0 9f :3 0
a0 :3 0 2c :2 0
a1 :2 0 e27 18e3
18e7 e2b 18e2 18e9
:3 0 e2e 18cb 18eb
:2 0 18ed e31 18ee
18c8 18ed 0 18ef
e33 0 18f0 e35
18f3 :3 0 18f3 0
18f3 18f2 18f0 18f1
:6 0 18f5 37 :3 0
e38 18f7 e3a 18f6
18f5 :2 0 18f8 e3c
:2 0 18fa 0 18fa
18f9 18b0 18f8 :6 0
190b 1 :3 0 7e
:3 0 42 :3 0 2f
:2 0 e3e 18fc 18ff
e9 :2 0 2f :2 0
e43 1901 1903 :3 0
42 :3 0 2f :2 0
1905 1906 0 1908
e46 1909 1904 1908
0 190a e48 0
190b e4a 190c 1683
190b 0 190e 1091
1676 0 190e e53
0 2247 6c :3 0
e8 :2 0 2f :2 0
e58 1910 1912 :3 0
31 :3 0 f0 :2 0
2c :2 0 e5b 1915
1917 :3 0 1914 1918
0 1bed 5f :3 0
166 :3 0 1f :3 0
3e :3 0 1c :3 0
27 :3 0 29 :3 0
61 :3 0 63 :3 0
31 :3 0 30 :3 0
2e :3 0 e5d 191b
1926 191a 1927 0
1bed 7e :3 0 49
:3 0 2f :2 0 e68
1929 192c e8 :2 0
2f :2 0 e6d 192e
1930 :3 0 1931 :2 0
33 :3 0 ef :2 0
e70 1934 1935 :3 0
1936 :2 0 1937 :2 0
1932 1939 1938 :2 0
60 :3 0 1ad :3 0
1f :3 0 3e :3 0
3f :3 0 1d :3 0
1c :3 0 33 :3 0
49 :3 0 2f :2 0
e72 193c 1945 193b
1946 0 1948 e7b
1949 193a 1948 0
194a e7d 0 1bed
1d :3 0 ef :2 0
e7f 194c 194d :3 0
194e :2 0 5f :3 0
1ae :3 0 1f :3 0
1c :3 0 16d :2 0
e81 1951 1955 1950
1956 0 1958 e85
1979 9f :3 0 2b
:3 0 2c :2 0 2c
:2 0 e87 1959 195d
a2 :2 0 16d :4 0
e8d 195f 1961 :3 0
5f :3 0 1ae :3 0
1f :3 0 1c :3 0
2f :2 0 e90 1964
1968 1963 1969 0
196b e94 1975 5f
:3 0 1ae :3 0 1f
:3 0 1c :3 0 2c
:2 0 e96 196d 1971
196c 1972 0 1974
e9a 1976 1962 196b
0 1977 0 1974
0 1977 e9c 0
1978 e9f 197a 194f
1958 0 197b 0
1978 0 197b ea1
0 1bed 33 :3 0
ef :2 0 ea4 197d
197e :3 0 197f :2 0
7e :3 0 42 :3 0
2f :2 0 ea6 1981
1984 e8 :2 0 2f
:2 0 eab 1986 1988
:3 0 42 :3 0 1af
:3 0 1a7 :3 0 198b
198c 0 7e :3 0
42 :3 0 2f :2 0
eae 198e 1991 dd
:3 0 1b0 :3 0 1993
1994 0 eb1 198d
1996 1997 :2 0 198a
1998 0 19f6 e5
:3 0 f6 :3 0 b6
:3 0 9f :3 0 33
:3 0 e5 :3 0 f8
:3 0 22 :3 0 22
:3 0 100 :4 0 1b1
1 :8 0 19aa 10
:3 0 96 :3 0 19a5
19a6 0 97 :3 0
19a7 19a8 0 19aa
eb4 19f4 98 :3 0
10 :3 0 96 :3 0
19ad 19ae 0 97
:3 0 19af 19b0 0
19ea 71 :3 0 72
:3 0 19b2 19b3 0
71 :3 0 84 :3 0
19b5 19b6 0 99
:2 0 2 :4 0 1b2
:2 0 86 :2 0 2c
:2 0 eb7 19bb 19bd
:3 0 eba 19b7 19bf
19b4 19c1 19c0 :2 0
74 :3 0 87 :3 0
19c3 19c4 0 76
:4 0 1b3 :4 0 79
:2 0 7a :3 0 ebe
19c8 19ca :3 0 79
:2 0 9c :4 0 ec1
19cc 19ce :3 0 79
:2 0 9d :4 0 ec4
19d0 19d2 :3 0 79
:2 0 97 :3 0 ec7
19d4 19d6 :3 0 79
:2 0 9e :4 0 eca
19d8 19da :3 0 79
:2 0 9f :3 0 a0
:3 0 2c :2 0 a1
:2 0 ecd 19dd 19e1
ed1 19dc 19e3 :3 0
ed4 19c5 19e5 :2 0
19e7 ed7 19e8 19c2
19e7 0 19e9 ed9
0 19ea edb 19ed
:3 0 19ed 0 19ed
19ec 19ea 19eb :6 0
19ef 39 :3 0 ede
19f1 ee0 19f0 19ef
:2 0 19f2 ee2 :2 0
19f4 0 19f4 19f3
19aa 19f2 :6 0 19f6
1 :3 0 ee4 1a54
e5 :3 0 f6 :3 0
b6 :3 0 9f :3 0
33 :3 0 e5 :3 0
f8 :3 0 22 :3 0
22 :3 0 100 :4 0
1b4 1 :8 0 1a07
10 :3 0 96 :3 0
1a02 1a03 0 97
:3 0 1a04 1a05 0
1a07 ee7 1a51 98
:3 0 10 :3 0 96
:3 0 1a0a 1a0b 0
97 :3 0 1a0c 1a0d
0 1a47 71 :3 0
72 :3 0 1a0f 1a10
0 71 :3 0 84
:3 0 1a12 1a13 0
99 :2 0 2 :4 0
1b5 :2 0 86 :2 0
2c :2 0 eea 1a18
1a1a :3 0 eed 1a14
1a1c 1a11 1a1e 1a1d
:2 0 74 :3 0 87
:3 0 1a20 1a21 0
76 :4 0 1b6 :4 0
79 :2 0 7a :3 0
ef1 1a25 1a27 :3 0
79 :2 0 9c :4 0
ef4 1a29 1a2b :3 0
79 :2 0 9d :4 0
ef7 1a2d 1a2f :3 0
79 :2 0 97 :3 0
efa 1a31 1a33 :3 0
79 :2 0 9e :4 0
efd 1a35 1a37 :3 0
79 :2 0 9f :3 0
a0 :3 0 2c :2 0
a1 :2 0 f00 1a3a
1a3e f04 1a39 1a40
:3 0 f07 1a22 1a42
:2 0 1a44 f0a 1a45
1a1f 1a44 0 1a46
f0c 0 1a47 f0e
1a4a :3 0 1a4a 0
1a4a 1a49 1a47 1a48
:6 0 1a4c 3b :3 0
f11 1a4e f13 1a4d
1a4c :2 0 1a4f f15
:2 0 1a51 0 1a51
1a50 1a07 1a4f :6 0
1a53 1 :3 0 f17
1a55 1989 19f6 0
1a56 0 1a53 0
1a56 f19 0 1a66
41 :3 0 7e :3 0
41 :3 0 2f :2 0
f1c 1a58 1a5b f0
:2 0 7e :3 0 46
:3 0 2f :2 0 f1f
1a5e 1a61 f22 1a5d
1a63 :3 0 1a57 1a64
0 1a66 f25 1a67
1980 1a66 0 1a68
f28 0 1bed 5e
:3 0 16d :2 0 1a69
1a6a 0 1bed 5f
:3 0 1b7 :3 0 1c
:3 0 22 :3 0 41
:3 0 5e :3 0 42
:3 0 40 :3 0 7e
:3 0 43 :3 0 2f
:2 0 f2a 1a74 1a77
7e :3 0 44 :3 0
2f :2 0 f2d 1a79
1a7c f30 1a6d 1a7e
1a6c 1a7f 0 1bed
7e :3 0 5f :3 0
2f :2 0 f39 1a81
1a84 e9 :2 0 2f
:2 0 f3e 1a86 1a88
:3 0 71 :3 0 72
:3 0 1a8a 1a8b 0
71 :3 0 84 :3 0
1a8d 1a8e 0 13
:2 0 2 :4 0 1b8
:2 0 86 :2 0 2c
:2 0 f41 1a93 1a95
:3 0 f44 1a8f 1a97
1a8c 1a99 1a98 :2 0
74 :3 0 87 :3 0
1a9b 1a9c 0 76
:4 0 1b9 :4 0 79
:2 0 7a :3 0 f48
1aa0 1aa2 :3 0 79
:2 0 9c :4 0 f4b
1aa4 1aa6 :3 0 79
:2 0 dc :4 0 f4e
1aa8 1aaa :3 0 79
:2 0 7e :3 0 82
:3 0 dd :3 0 1a2
:3 0 1aaf 1ab0 0
f51 1aae 1ab2 81
:4 0 f53 1aad 1ab5
f56 1aac 1ab7 :3 0
79 :2 0 df :4 0
f59 1ab9 1abb :3 0
79 :2 0 7c :4 0
f5c 1abd 1abf :3 0
79 :2 0 1c :3 0
f5f 1ac1 1ac3 :3 0
79 :2 0 7c :4 0
f62 1ac5 1ac7 :3 0
f65 1a9d 1ac9 :2 0
1acb f68 1acc 1a9a
1acb 0 1acd f6a
0 1af8 71 :3 0
72 :3 0 1ace 1acf
0 71 :3 0 84
:3 0 1ad1 1ad2 0
2c :2 0 2 :4 0
1ba :2 0 86 :2 0
2c :2 0 f6c 1ad7
1ad9 :3 0 f6f 1ad3
1adb 1ad0 1add 1adc
:2 0 74 :3 0 87
:3 0 1adf 1ae0 0
76 :4 0 1bb :4 0
79 :2 0 7a :3 0
f73 1ae4 1ae6 :3 0
f76 1ae1 1ae8 :2 0
1aea f79 1aeb 1ade
1aea 0 1aec f7b
0 1af8 e2 :3 0
e3 :3 0 1aed 1aee
0 dd :3 0 1a2
:3 0 1af0 1af1 0
1c :3 0 e4 :3 0
f7d 1aef 1af5 :2 0
1af8 132 :3 0 f81
1b78 6c :3 0 a2
:2 0 2c :2 0 f87
1afa 1afc :3 0 c4
:3 0 1a6 :3 0 c3
:3 0 f9 :3 0 1a7
:3 0 c3 :3 0 dd
:3 0 1a8 :3 0 dd
:3 0 1a9 :3 0 1bc
:3 0 7e :3 0 10c
:3 0 114 :3 0 1bd
:3 0 7e :3 0 10d
:3 0 115 :3 0 1be
:3 0 1bf :3 0 c5
:3 0 1c :4 0 1c0
1 :8 0 1b2a 110
:4 0 1b15 :3 0 e4
:3 0 a2 :2 0 f8c
1b18 1b19 :3 0 10
:3 0 96 :3 0 1b1b
1b1c 0 2f :2 0
1b1d 1b1e 0 1b20
f8f 1b27 10 :3 0
96 :3 0 1b21 1b22
0 111 :2 0 1b23
1b24 0 1b26 f91
1b28 1b1a 1b20 0
1b29 0 1b26 0
1b29 f93 0 1b2a
f96 1b74 98 :3 0
10 :3 0 96 :3 0
1b2d 1b2e 0 97
:3 0 1b2f 1b30 0
1b6a 71 :3 0 72
:3 0 1b32 1b33 0
71 :3 0 84 :3 0
1b35 1b36 0 99
:2 0 2 :4 0 1c1
:2 0 86 :2 0 2c
:2 0 f99 1b3b 1b3d
:3 0 f9c 1b37 1b3f
1b34 1b41 1b40 :2 0
74 :3 0 87 :3 0
1b43 1b44 0 76
:4 0 1c2 :4 0 79
:2 0 7a :3 0 fa0
1b48 1b4a :3 0 79
:2 0 9c :4 0 fa3
1b4c 1b4e :3 0 79
:2 0 9d :4 0 fa6
1b50 1b52 :3 0 79
:2 0 97 :3 0 fa9
1b54 1b56 :3 0 79
:2 0 9e :4 0 fac
1b58 1b5a :3 0 79
:2 0 9f :3 0 a0
:3 0 2c :2 0 a1
:2 0 faf 1b5d 1b61
fb3 1b5c 1b63 :3 0
fb6 1b45 1b65 :2 0
1b67 fb9 1b68 1b42
1b67 0 1b69 fbb
0 1b6a fbd 1b6d
:3 0 1b6d 0 1b6d
1b6c 1b6a 1b6b :6 0
1b6f 3d :3 0 fc0
1b71 fc2 1b70 1b6f
:2 0 1b72 fc4 :2 0
1b74 0 1b74 1b73
1b2a 1b72 :6 0 1b76
1 :3 0 fc6 1b77
1afd 1b76 0 1b79
1a89 1af8 0 1b79
fc8 0 1bed 60
:3 0 11b :3 0 1f
:3 0 fcb 1b7b 1b7d
1b7a 1b7e 0 1bed
71 :3 0 72 :3 0
1b80 1b81 0 71
:3 0 84 :3 0 1b83
1b84 0 13 :2 0
2 :4 0 1c3 :2 0
86 :2 0 2c :2 0
fcd 1b89 1b8b :3 0
fd0 1b85 1b8d 1b82
1b8f 1b8e :2 0 74
:3 0 87 :3 0 1b91
1b92 0 76 :4 0
1c4 :4 0 79 :2 0
7a :3 0 fd4 1b96
1b98 :3 0 79 :2 0
9c :4 0 fd7 1b9a
1b9c :3 0 79 :2 0
dc :4 0 fda 1b9e
1ba0 :3 0 79 :2 0
7e :3 0 82 :3 0
60 :3 0 fdd 1ba4
1ba6 81 :4 0 fdf
1ba3 1ba9 fe2 1ba2
1bab :3 0 79 :2 0
df :4 0 fe5 1bad
1baf :3 0 79 :2 0
7c :4 0 fe8 1bb1
1bb3 :3 0 79 :2 0
1c :3 0 feb 1bb5
1bb7 :3 0 79 :2 0
7c :4 0 fee 1bb9
1bbb :3 0 ff1 1b93
1bbd :2 0 1bbf ff4
1bc0 1b90 1bbf 0
1bc1 ff6 0 1bed
71 :3 0 72 :3 0
1bc2 1bc3 0 71
:3 0 84 :3 0 1bc5
1bc6 0 2c :2 0
2 :4 0 1c5 :2 0
86 :2 0 2c :2 0
ff8 1bcb 1bcd :3 0
ffb 1bc7 1bcf 1bc4
1bd1 1bd0 :2 0 74
:3 0 87 :3 0 1bd3
1bd4 0 76 :4 0
1c6 :4 0 79 :2 0
7a :3 0 fff 1bd8
1bda :3 0 1002 1bd5
1bdc :2 0 1bde 1005
1bdf 1bd2 1bde 0
1be0 1007 0 1bed
e2 :3 0 e3 :3 0
1be1 1be2 0 7e
:3 0 60 :3 0 2f
:2 0 1009 1be4 1be7
1c :3 0 e4 :3 0
100c 1be3 1beb :2 0
1bed 1010 1bee 1913
1bed 0 1bef 101d
0 2247 7e :3 0
d :3 0 2f :2 0
101f 1bf0 1bf3 7e
:3 0 e9 :2 0 46
:3 0 2f :2 0 1022
1bf5 1bf9 1027 1bf6
1bfb :3 0 11c :3 0
60 :3 0 100 :3 0
8d :3 0 13c :3 0
c5 :3 0 1c :3 0
c5 :3 0 8d :3 0
13d :3 0 dd :3 0
13e :4 0 1c7 1
:8 0 1c0f 10 :3 0
96 :3 0 1c0a 1c0b
0 97 :3 0 1c0c
1c0d 0 1c0f 102a
1c59 98 :3 0 10
:3 0 96 :3 0 1c12
1c13 0 97 :3 0
1c14 1c15 0 1c4f
71 :3 0 72 :3 0
1c17 1c18 0 71
:3 0 84 :3 0 1c1a
1c1b 0 99 :2 0
2 :4 0 1c8 :2 0
86 :2 0 2c :2 0
102d 1c20 1c22 :3 0
1030 1c1c 1c24 1c19
1c26 1c25 :2 0 74
:3 0 87 :3 0 1c28
1c29 0 76 :4 0
1c9 :4 0 79 :2 0
7a :3 0 1034 1c2d
1c2f :3 0 79 :2 0
9c :4 0 1037 1c31
1c33 :3 0 79 :2 0
9d :4 0 103a 1c35
1c37 :3 0 79 :2 0
97 :3 0 103d 1c39
1c3b :3 0 79 :2 0
9e :4 0 1040 1c3d
1c3f :3 0 79 :2 0
9f :3 0 a0 :3 0
2c :2 0 a1 :2 0
1043 1c42 1c46 1047
1c41 1c48 :3 0 104a
1c2a 1c4a :2 0 1c4c
104d 1c4d 1c27 1c4c
0 1c4e 104f 0
1c4f 1051 1c52 :3 0
1c52 0 1c52 1c51
1c4f 1c50 :6 0 1c54
3f :3 0 1054 1c56
1056 1c55 1c54 :2 0
1c57 1058 :2 0 1c59
0 1c59 1c58 1c0f
1c57 :6 0 2062 1
:3 0 7e :3 0 60
:3 0 2f :2 0 105a
1c5b 1c5e e8 :2 0
2f :2 0 105f 1c60
1c62 :3 0 71 :3 0
72 :3 0 1c64 1c65
0 71 :3 0 84
:3 0 1c67 1c68 0
13 :2 0 2 :4 0
1ca :2 0 86 :2 0
2c :2 0 1062 1c6d
1c6f :3 0 1065 1c69
1c71 1c66 1c73 1c72
:2 0 74 :3 0 87
:3 0 1c75 1c76 0
76 :4 0 1cb :4 0
79 :2 0 7a :3 0
1069 1c7a 1c7c :3 0
79 :2 0 9c :4 0
106c 1c7e 1c80 :3 0
79 :2 0 dc :4 0
106f 1c82 1c84 :3 0
79 :2 0 7e :3 0
82 :3 0 dd :3 0
144 :3 0 1c89 1c8a
0 1072 1c88 1c8c
81 :4 0 1074 1c87
1c8f 1077 1c86 1c91
:3 0 79 :2 0 df
:4 0 107a 1c93 1c95
:3 0 79 :2 0 7c
:4 0 107d 1c97 1c99
:3 0 79 :2 0 1c
:3 0 1080 1c9b 1c9d
:3 0 79 :2 0 7c
:4 0 1083 1c9f 1ca1
:3 0 1086 1c77 1ca3
:2 0 1ca5 1089 1ca6
1c74 1ca5 0 1ca7
108b 0 1cd1 71
:3 0 72 :3 0 1ca8
1ca9 0 71 :3 0
84 :3 0 1cab 1cac
0 2c :2 0 2
:4 0 1cc :2 0 86
:2 0 2c :2 0 108d
1cb1 1cb3 :3 0 1090
1cad 1cb5 1caa 1cb7
1cb6 :2 0 74 :3 0
87 :3 0 1cb9 1cba
0 76 :4 0 1cd
:4 0 79 :2 0 7a
:3 0 1094 1cbe 1cc0
:3 0 1097 1cbb 1cc2
:2 0 1cc4 109a 1cc5
1cb8 1cc4 0 1cc6
109c 0 1cd1 e2
:3 0 e3 :3 0 1cc7
1cc8 0 dd :3 0
144 :3 0 1cca 1ccb
0 1c :3 0 e4
:3 0 109e 1cc9 1ccf
:2 0 1cd1 10a2 1cd2
1c63 1cd1 0 1cd3
10a6 0 2062 47
:3 0 d :3 0 1cd4
1cd5 0 2062 54
:3 0 7e :3 0 41
:3 0 2f :2 0 10a8
1cd8 1cdb 1cd7 1cdc
0 2062 7e :3 0
47 :3 0 2f :2 0
10ab 1cde 1ce1 7e
:3 0 e8 :2 0 41
:3 0 2f :2 0 10ae
1ce3 1ce7 10b3 1ce4
1ce9 :3 0 31 :3 0
f0 :2 0 2c :2 0
10b6 1cec 1cee :3 0
1ceb 1cef 0 1fac
5f :3 0 166 :3 0
1f :3 0 3e :3 0
1c :3 0 27 :3 0
29 :3 0 61 :3 0
63 :3 0 31 :3 0
30 :3 0 2e :3 0
10b8 1cf2 1cfd 1cf1
1cfe 0 1fac 1d
:3 0 ef :2 0 10c3
1d01 1d02 :3 0 1d03
:2 0 5f :3 0 1ae
:3 0 1f :3 0 1c
:3 0 16d :2 0 10c5
1d06 1d0a 1d05 1d0b
0 1d0d 10c9 1d2e
9f :3 0 2b :3 0
2c :2 0 2c :2 0
10cb 1d0e 1d12 a2
:2 0 16d :4 0 10d1
1d14 1d16 :3 0 5f
:3 0 1ae :3 0 1f
:3 0 1c :3 0 2f
:2 0 10d4 1d19 1d1d
1d18 1d1e 0 1d20
10d8 1d2a 5f :3 0
1ae :3 0 1f :3 0
1c :3 0 2c :2 0
10da 1d22 1d26 1d21
1d27 0 1d29 10de
1d2b 1d17 1d20 0
1d2c 0 1d29 0
1d2c 10e0 0 1d2d
10e3 1d2f 1d04 1d0d
0 1d30 0 1d2d
0 1d30 10e5 0
1fac 4a :3 0 2f
:2 0 1d31 1d32 0
1fac 33 :3 0 ef
:2 0 10e8 1d35 1d36
:3 0 1d37 :2 0 7e
:3 0 42 :3 0 2f
:2 0 10ea 1d39 1d3c
e8 :2 0 2f :2 0
10ef 1d3e 1d40 :3 0
42 :3 0 1af :3 0
1a7 :3 0 1d43 1d44
0 7e :3 0 42
:3 0 2f :2 0 10f2
1d46 1d49 dd :3 0
1b0 :3 0 1d4b 1d4c
0 10f5 1d45 1d4e
1d4f :2 0 1d42 1d50
0 1dae e5 :3 0
f6 :3 0 b6 :3 0
9f :3 0 33 :3 0
e5 :3 0 f8 :3 0
22 :3 0 22 :3 0
100 :4 0 1ce 1
:8 0 1d62 10 :3 0
96 :3 0 1d5d 1d5e
0 97 :3 0 1d5f
1d60 0 1d62 10f8
1dac 98 :3 0 10
:3 0 96 :3 0 1d65
1d66 0 97 :3 0
1d67 1d68 0 1da2
71 :3 0 72 :3 0
1d6a 1d6b 0 71
:3 0 84 :3 0 1d6d
1d6e 0 99 :2 0
2 :4 0 1cf :2 0
86 :2 0 2c :2 0
10fb 1d73 1d75 :3 0
10fe 1d6f 1d77 1d6c
1d79 1d78 :2 0 74
:3 0 87 :3 0 1d7b
1d7c 0 76 :4 0
1d0 :4 0 79 :2 0
7a :3 0 1102 1d80
1d82 :3 0 79 :2 0
9c :4 0 1105 1d84
1d86 :3 0 79 :2 0
9d :4 0 1108 1d88
1d8a :3 0 79 :2 0
97 :3 0 110b 1d8c
1d8e :3 0 79 :2 0
9e :4 0 110e 1d90
1d92 :3 0 79 :2 0
9f :3 0 a0 :3 0
2c :2 0 a1 :2 0
1111 1d95 1d99 1115
1d94 1d9b :3 0 1118
1d7d 1d9d :2 0 1d9f
111b 1da0 1d7a 1d9f
0 1da1 111d 0
1da2 111f 1da5 :3 0
1da5 0 1da5 1da4
1da2 1da3 :6 0 1da7
41 :3 0 1122 1da9
1124 1da8 1da7 :2 0
1daa 1126 :2 0 1dac
0 1dac 1dab 1d62
1daa :6 0 1dae 1
:3 0 1128 1e0c e5
:3 0 f6 :3 0 b6
:3 0 9f :3 0 33
:3 0 e5 :3 0 f8
:3 0 22 :3 0 22
:3 0 100 :4 0 1d1
1 :8 0 1dbf 10
:3 0 96 :3 0 1dba
1dbb 0 97 :3 0
1dbc 1dbd 0 1dbf
112b 1e09 98 :3 0
10 :3 0 96 :3 0
1dc2 1dc3 0 97
:3 0 1dc4 1dc5 0
1dff 71 :3 0 72
:3 0 1dc7 1dc8 0
71 :3 0 84 :3 0
1dca 1dcb 0 99
:2 0 2 :4 0 1d2
:2 0 86 :2 0 2c
:2 0 112e 1dd0 1dd2
:3 0 1131 1dcc 1dd4
1dc9 1dd6 1dd5 :2 0
74 :3 0 87 :3 0
1dd8 1dd9 0 76
:4 0 1d3 :4 0 79
:2 0 7a :3 0 1135
1ddd 1ddf :3 0 79
:2 0 9c :4 0 1138
1de1 1de3 :3 0 79
:2 0 9d :4 0 113b
1de5 1de7 :3 0 79
:2 0 97 :3 0 113e
1de9 1deb :3 0 79
:2 0 9e :4 0 1141
1ded 1def :3 0 79
:2 0 9f :3 0 a0
:3 0 2c :2 0 a1
:2 0 1144 1df2 1df6
1148 1df1 1df8 :3 0
114b 1dda 1dfa :2 0
1dfc 114e 1dfd 1dd7
1dfc 0 1dfe 1150
0 1dff 1152 1e02
:3 0 1e02 0 1e02
1e01 1dff 1e00 :6 0
1e04 43 :3 0 1155
1e06 1157 1e05 1e04
:2 0 1e07 1159 :2 0
1e09 0 1e09 1e08
1dbf 1e07 :6 0 1e0b
1 :3 0 115b 1e0d
1d41 1dae 0 1e0e
0 1e0b 0 1e0e
115d 0 1e79 7e
:3 0 49 :3 0 2f
:2 0 1160 1e0f 1e12
e8 :2 0 2f :2 0
1165 1e14 1e16 :3 0
168 :3 0 169 :3 0
4a :3 0 167 :3 0
92 :3 0 1f :3 0
c5 :3 0 1c :3 0
f7 :3 0 b6 :3 0
9f :3 0 33 :4 0
1d4 1 :8 0 1e2a
10 :3 0 96 :3 0
1e25 1e26 0 97
:3 0 1e27 1e28 0
1e2a 1168 1e74 98
:3 0 10 :3 0 96
:3 0 1e2d 1e2e 0
97 :3 0 1e2f 1e30
0 1e6a 71 :3 0
72 :3 0 1e32 1e33
0 71 :3 0 84
:3 0 1e35 1e36 0
99 :2 0 2 :4 0
1d5 :2 0 86 :2 0
2c :2 0 116b 1e3b
1e3d :3 0 116e 1e37
1e3f 1e34 1e41 1e40
:2 0 74 :3 0 87
:3 0 1e43 1e44 0
76 :4 0 1d6 :4 0
79 :2 0 7a :3 0
1172 1e48 1e4a :3 0
79 :2 0 9c :4 0
1175 1e4c 1e4e :3 0
79 :2 0 9d :4 0
1178 1e50 1e52 :3 0
79 :2 0 97 :3 0
117b 1e54 1e56 :3 0
79 :2 0 9e :4 0
117e 1e58 1e5a :3 0
79 :2 0 9f :3 0
a0 :3 0 2c :2 0
a1 :2 0 1181 1e5d
1e61 1185 1e5c 1e63
:3 0 1188 1e45 1e65
:2 0 1e67 118b 1e68
1e42 1e67 0 1e69
118d 0 1e6a 118f
1e6d :3 0 1e6d 0
1e6d 1e6c 1e6a 1e6b
:6 0 1e6f 45 :3 0
1192 1e71 1194 1e70
1e6f :2 0 1e72 1196
:2 0 1e74 0 1e74
1e73 1e2a 1e72 :6 0
1e76 1 :3 0 1198
1e77 1e17 1e76 0
1e78 119a 0 1e79
119c 1e7a 1d38 1e79
0 1e7b 119f 0
1fac 41 :3 0 7e
:3 0 47 :3 0 2f
:2 0 11a1 1e7d 1e80
f0 :2 0 7e :3 0
46 :3 0 2f :2 0
11a4 1e83 1e86 11a7
1e82 1e88 :3 0 f0
:2 0 7e :3 0 4a
:3 0 2f :2 0 11aa
1e8b 1e8e 11ad 1e8a
1e90 :3 0 1e7c 1e91
0 1fac 45 :3 0
1d7 :2 0 1e93 1e94
0 1fac c4 :3 0
1a6 :3 0 c3 :3 0
f9 :3 0 1a7 :3 0
c3 :3 0 dd :3 0
1a8 :3 0 b3 :3 0
47 :3 0 af :3 0
47 :3 0 d3 :3 0
c1 :3 0 d4 :3 0
d5 :3 0 1d8 :3 0
c5 :3 0 1c :4 0
1d9 1 :8 0 1ebf
110 :4 0 1eaa :3 0
e4 :3 0 a2 :2 0
11b2 1ead 1eae :3 0
10 :3 0 96 :3 0
1eb0 1eb1 0 2f
:2 0 1eb2 1eb3 0
1eb5 11b5 1ebc 10
:3 0 96 :3 0 1eb6
1eb7 0 111 :2 0
1eb8 1eb9 0 1ebb
11b7 1ebd 1eaf 1eb5
0 1ebe 0 1ebb
0 1ebe 11b9 0
1ebf 11bc 1f09 98
:3 0 10 :3 0 96
:3 0 1ec2 1ec3 0
97 :3 0 1ec4 1ec5
0 1eff 71 :3 0
72 :3 0 1ec7 1ec8
0 71 :3 0 84
:3 0 1eca 1ecb 0
99 :2 0 2 :4 0
1da :2 0 86 :2 0
2c :2 0 11bf 1ed0
1ed2 :3 0 11c2 1ecc
1ed4 1ec9 1ed6 1ed5
:2 0 74 :3 0 87
:3 0 1ed8 1ed9 0
76 :4 0 1db :4 0
79 :2 0 7a :3 0
11c6 1edd 1edf :3 0
79 :2 0 9c :4 0
11c9 1ee1 1ee3 :3 0
79 :2 0 9d :4 0
11cc 1ee5 1ee7 :3 0
79 :2 0 97 :3 0
11cf 1ee9 1eeb :3 0
79 :2 0 9e :4 0
11d2 1eed 1eef :3 0
79 :2 0 9f :3 0
a0 :3 0 2c :2 0
a1 :2 0 11d5 1ef2
1ef6 11d9 1ef1 1ef8
:3 0 11dc 1eda 1efa
:2 0 1efc 11df 1efd
1ed7 1efc 0 1efe
11e1 0 1eff 11e3
1f02 :3 0 1f02 0
1f02 1f01 1eff 1f00
:6 0 1f04 47 :3 0
11e6 1f06 11e8 1f05
1f04 :2 0 1f07 11ea
:2 0 1f09 0 1f09
1f08 1ebf 1f07 :6 0
1fac 1 :3 0 10
:3 0 96 :3 0 1f0b
1f0c 0 10 :3 0
a2 :2 0 11a :3 0
1f0e 1f10 0 11ee
1f0f 1f12 :3 0 1f13
:2 0 5e :3 0 16d
:2 0 1f15 1f16 0
1fa2 60 :3 0 1b7
:3 0 1c :3 0 22
:3 0 41 :3 0 5e
:3 0 42 :3 0 40
:3 0 2f :2 0 7e
:3 0 44 :3 0 2f
:2 0 11f1 1f21 1f24
11f4 1f19 1f26 1f18
1f27 0 1fa2 7e
:3 0 60 :3 0 2f
:2 0 11fd 1f29 1f2c
e9 :2 0 2f :2 0
1202 1f2e 1f30 :3 0
71 :3 0 72 :3 0
1f32 1f33 0 71
:3 0 84 :3 0 1f35
1f36 0 13 :2 0
2 :4 0 1dc :2 0
86 :2 0 2c :2 0
1205 1f3b 1f3d :3 0
1208 1f37 1f3f 1f34
1f41 1f40 :2 0 74
:3 0 87 :3 0 1f43
1f44 0 76 :4 0
1dd :4 0 79 :2 0
7a :3 0 120c 1f48
1f4a :3 0 79 :2 0
9c :4 0 120f 1f4c
1f4e :3 0 79 :2 0
dc :4 0 1212 1f50
1f52 :3 0 79 :2 0
7e :3 0 82 :3 0
60 :3 0 1215 1f56
1f58 81 :4 0 1217
1f55 1f5b 121a 1f54
1f5d :3 0 79 :2 0
df :4 0 121d 1f5f
1f61 :3 0 79 :2 0
7c :4 0 1220 1f63
1f65 :3 0 79 :2 0
1c :3 0 1223 1f67
1f69 :3 0 79 :2 0
7c :4 0 1226 1f6b
1f6d :3 0 1229 1f45
1f6f :2 0 1f71 122c
1f72 1f42 1f71 0
1f73 122e 0 1f9f
71 :3 0 72 :3 0
1f74 1f75 0 71
:3 0 84 :3 0 1f77
1f78 0 2c :2 0
2 :4 0 1de :2 0
86 :2 0 2c :2 0
1230 1f7d 1f7f :3 0
1233 1f79 1f81 1f76
1f83 1f82 :2 0 74
:3 0 87 :3 0 1f85
1f86 0 76 :4 0
1df :4 0 79 :2 0
7a :3 0 1237 1f8a
1f8c :3 0 123a 1f87
1f8e :2 0 1f90 123d
1f91 1f84 1f90 0
1f92 123f 0 1f9f
e2 :3 0 e3 :3 0
1f93 1f94 0 7e
:3 0 60 :3 0 2f
:2 0 1241 1f96 1f99
1c :3 0 e4 :3 0
1244 1f95 1f9d :2 0
1f9f 1248 1fa0 1f31
1f9f 0 1fa1 124c
0 1fa2 124e 1fa3
1f14 1fa2 0 1fa4
1252 0 1fac 41
:3 0 7e :3 0 47
:3 0 2f :2 0 1254
1fa6 1fa9 1fa5 1faa
0 1fac 1257 1fd0
45 :3 0 1e0 :3 0
7e :3 0 1e1 :3 0
47 :3 0 1262 1fb0
1fb2 2f :2 0 1264
1faf 1fb5 1e2 :2 0
7e :3 0 1e1 :3 0
41 :3 0 1267 1fb9
1fbb 2f :2 0 1269
1fb8 1fbe 126c 1fb7
1fc0 :3 0 1fc1 :2 0
1e3 :2 0 1e4 :2 0
126f 1fc3 1fc5 :3 0
1fc6 :2 0 86 :2 0
1e5 :2 0 1272 1fc8
1fca :3 0 1275 1fae
1fcc 1fad 1fcd 0
1fcf 1277 1fd1 1cea
1fac 0 1fd2 0
1fcf 0 1fd2 1279
0 2062 60 :3 0
1e6 :3 0 1f :3 0
3e :3 0 3f :3 0
1c :3 0 33 :3 0
2b :3 0 41 :3 0
47 :3 0 54 :3 0
46 :3 0 45 :3 0
61 :3 0 64 :3 0
63 :3 0 65 :3 0
66 :3 0 68 :3 0
67 :3 0 69 :3 0
30 :3 0 2e :3 0
49 :3 0 40 :3 0
7e :3 0 4c :3 0
2f :2 0 127c 1fec
1fef 127f 1fd4 1ff1
1fd3 1ff2 0 2062
71 :3 0 72 :3 0
1ff4 1ff5 0 71
:3 0 84 :3 0 1ff7
1ff8 0 13 :2 0
2 :4 0 1e7 :2 0
86 :2 0 2c :2 0
1298 1ffd 1fff :3 0
129b 1ff9 2001 1ff6
2003 2002 :2 0 74
:3 0 87 :3 0 2005
2006 0 76 :4 0
1e8 :4 0 79 :2 0
7a :3 0 129f 200a
200c :3 0 79 :2 0
9c :4 0 12a2 200e
2010 :3 0 79 :2 0
dc :4 0 12a5 2012
2014 :3 0 79 :2 0
7e :3 0 82 :3 0
60 :3 0 12a8 2018
201a 81 :4 0 12aa
2017 201d 12ad 2016
201f :3 0 79 :2 0
df :4 0 12b0 2021
2023 :3 0 79 :2 0
7c :4 0 12b3 2025
2027 :3 0 79 :2 0
1c :3 0 12b6 2029
202b :3 0 79 :2 0
7c :4 0 12b9 202d
202f :3 0 12bc 2007
2031 :2 0 2033 12bf
2034 2004 2033 0
2035 12c1 0 2062
71 :3 0 72 :3 0
2036 2037 0 71
:3 0 84 :3 0 2039
203a 0 2c :2 0
2 :4 0 1e9 :2 0
86 :2 0 2c :2 0
12c3 203f 2041 :3 0
12c6 203b 2043 2038
2045 2044 :2 0 74
:3 0 87 :3 0 2047
2048 0 76 :4 0
1ea :4 0 79 :2 0
7a :3 0 12ca 204c
204e :3 0 12cd 2049
2050 :2 0 2052 12d0
2053 2046 2052 0
2054 12d2 0 2062
e2 :3 0 e3 :3 0
2055 2056 0 7e
:3 0 60 :3 0 2f
:2 0 12d4 2058 205b
1c :3 0 e4 :3 0
12d7 2057 205f :2 0
2062 132 :3 0 12db
21d2 7e :3 0 c
:3 0 2f :2 0 12e5
2063 2066 7e :3 0
e9 :2 0 45 :3 0
2f :2 0 12e8 2068
206c 12ed 2069 206e
:3 0 7e :3 0 46
:3 0 2f :2 0 12f0
2070 2073 e8 :2 0
2f :2 0 12f5 2075
2077 :3 0 2078 :2 0
7e :3 0 c :3 0
2f :2 0 12f8 207a
207d a2 :2 0 2f
:2 0 12fd 207f 2081
:3 0 2082 :2 0 2079
2084 2083 :2 0 71
:3 0 72 :3 0 2086
2087 0 71 :3 0
84 :3 0 2089 208a
0 13 :2 0 2
:4 0 1eb :2 0 86
:2 0 2c :2 0 1300
208f 2091 :3 0 1303
208b 2093 2088 2095
2094 :2 0 74 :3 0
87 :3 0 2097 2098
0 76 :4 0 1ec
:4 0 79 :2 0 7a
:3 0 1307 209c 209e
:3 0 79 :2 0 9c
:4 0 130a 20a0 20a2
:3 0 79 :2 0 dc
:4 0 130d 20a4 20a6
:3 0 79 :2 0 7e
:3 0 82 :3 0 10
:3 0 96 :3 0 20ab
20ac 0 1310 20aa
20ae 81 :4 0 1312
20a9 20b1 1315 20a8
20b3 :3 0 79 :2 0
df :4 0 1318 20b5
20b7 :3 0 79 :2 0
7c :4 0 131b 20b9
20bb :3 0 79 :2 0
1c :3 0 131e 20bd
20bf :3 0 79 :2 0
7c :4 0 1321 20c1
20c3 :3 0 1324 2099
20c5 :2 0 20c7 1327
20c8 2096 20c7 0
20c9 1329 0 20f3
71 :3 0 72 :3 0
20ca 20cb 0 71
:3 0 84 :3 0 20cd
20ce 0 2c :2 0
2 :4 0 1ed :2 0
86 :2 0 2c :2 0
132b 20d3 20d5 :3 0
132e 20cf 20d7 20cc
20d9 20d8 :2 0 74
:3 0 87 :3 0 20db
20dc 0 76 :4 0
1ee :4 0 79 :2 0
7a :3 0 1332 20e0
20e2 :3 0 1335 20dd
20e4 :2 0 20e6 1338
20e7 20da 20e6 0
20e8 133a 0 20f3
e2 :3 0 e3 :3 0
20e9 20ea 0 10
:3 0 96 :3 0 20ec
20ed 0 1c :3 0
e4 :3 0 133c 20eb
20f1 :2 0 20f3 1340
20f4 2085 20f3 0
20f5 1344 0 21d0
c4 :3 0 c1 :3 0
c :3 0 c3 :3 0
f9 :3 0 1a7 :3 0
c3 :3 0 dd :3 0
1ef :3 0 c5 :3 0
1c :4 0 1f0 1
:8 0 2117 110 :4 0
2102 :3 0 e4 :3 0
a2 :2 0 1348 2105
2106 :3 0 10 :3 0
96 :3 0 2108 2109
0 2f :2 0 210a
210b 0 210d 134b
2114 10 :3 0 96
:3 0 210e 210f 0
111 :2 0 2110 2111
0 2113 134d 2115
2107 210d 0 2116
0 2113 0 2116
134f 0 2117 1352
2161 98 :3 0 10
:3 0 96 :3 0 211a
211b 0 97 :3 0
211c 211d 0 2157
71 :3 0 72 :3 0
211f 2120 0 71
:3 0 84 :3 0 2122
2123 0 99 :2 0
2 :4 0 1f1 :2 0
86 :2 0 2c :2 0
1355 2128 212a :3 0
1358 2124 212c 2121
212e 212d :2 0 74
:3 0 87 :3 0 2130
2131 0 76 :4 0
1f2 :4 0 79 :2 0
7a :3 0 135c 2135
2137 :3 0 79 :2 0
9c :4 0 135f 2139
213b :3 0 79 :2 0
9d :4 0 1362 213d
213f :3 0 79 :2 0
97 :3 0 1365 2141
2143 :3 0 79 :2 0
9e :4 0 1368 2145
2147 :3 0 79 :2 0
9f :3 0 a0 :3 0
2c :2 0 a1 :2 0
136b 214a 214e 136f
2149 2150 :3 0 1372
2132 2152 :2 0 2154
1375 2155 212f 2154
0 2156 1377 0
2157 1379 215a :3 0
215a 0 215a 2159
2157 2158 :6 0 215c
49 :3 0 137c 215e
137e 215d 215c :2 0
215f 1380 :2 0 2161
0 2161 2160 2117
215f :6 0 21d0 1
:3 0 d6 :3 0 c3
:3 0 f9 :3 0 1a7
:3 0 c3 :3 0 dd
:3 0 1ef :3 0 92
:3 0 1f :3 0 8d
:3 0 3e :4 0 1f3
1 :8 0 2184 110
:4 0 216f :3 0 e4
:3 0 a2 :2 0 1384
2172 2173 :3 0 10
:3 0 96 :3 0 2175
2176 0 2f :2 0
2177 2178 0 217a
1387 2181 10 :3 0
96 :3 0 217b 217c
0 111 :2 0 217d
217e 0 2180 1389
2182 2174 217a 0
2183 0 2180 0
2183 138b 0 2184
138e 21ce 98 :3 0
10 :3 0 96 :3 0
2187 2188 0 97
:3 0 2189 218a 0
21c4 71 :3 0 72
:3 0 218c 218d 0
71 :3 0 84 :3 0
218f 2190 0 99
:2 0 2 :4 0 1f4
:2 0 86 :2 0 2c
:2 0 1391 2195 2197
:3 0 1394 2191 2199
218e 219b 219a :2 0
74 :3 0 87 :3 0
219d 219e 0 76
:4 0 1f5 :4 0 79
:2 0 7a :3 0 1398
21a2 21a4 :3 0 79
:2 0 9c :4 0 139b
21a6 21a8 :3 0 79
:2 0 9d :4 0 139e
21aa 21ac :3 0 79
:2 0 97 :3 0 13a1
21ae 21b0 :3 0 79
:2 0 9e :4 0 13a4
21b2 21b4 :3 0 79
:2 0 9f :3 0 a0
:3 0 2c :2 0 a1
:2 0 13a7 21b7 21bb
13ab 21b6 21bd :3 0
13ae 219f 21bf :2 0
21c1 13b1 21c2 219c
21c1 0 21c3 13b3
0 21c4 13b5 21c7
:3 0 21c7 0 21c7
21c6 21c4 21c5 :6 0
21c9 4b :3 0 13b8
21cb 13ba 21ca 21c9
:2 0 21cc 13bc :2 0
21ce 0 21ce 21cd
2184 21cc :6 0 21d0
1 :3 0 13be 21d1
206f 21d0 0 21d3
1bfc 2062 0 21d3
13c2 0 2247 60
:3 0 11b :3 0 1f
:3 0 13c5 21d5 21d7
21d4 21d8 0 2247
71 :3 0 72 :3 0
21da 21db 0 71
:3 0 84 :3 0 21dd
21de 0 13 :2 0
2 :4 0 1f6 :2 0
86 :2 0 2c :2 0
13c7 21e3 21e5 :3 0
13ca 21df 21e7 21dc
21e9 21e8 :2 0 74
:3 0 87 :3 0 21eb
21ec 0 76 :4 0
1f7 :4 0 79 :2 0
7a :3 0 13ce 21f0
21f2 :3 0 79 :2 0
9c :4 0 13d1 21f4
21f6 :3 0 79 :2 0
dc :4 0 13d4 21f8
21fa :3 0 79 :2 0
7e :3 0 82 :3 0
60 :3 0 13d7 21fe
2200 81 :4 0 13d9
21fd 2203 13dc 21fc
2205 :3 0 79 :2 0
df :4 0 13df 2207
2209 :3 0 79 :2 0
7c :4 0 13e2 220b
220d :3 0 79 :2 0
1c :3 0 13e5 220f
2211 :3 0 79 :2 0
7c :4 0 13e8 2213
2215 :3 0 13eb 21ed
2217 :2 0 2219 13ee
221a 21ea 2219 0
221b 13f0 0 2247
71 :3 0 72 :3 0
221c 221d 0 71
:3 0 84 :3 0 221f
2220 0 2c :2 0
2 :4 0 1f8 :2 0
86 :2 0 2c :2 0
13f2 2225 2227 :3 0
13f5 2221 2229 221e
222b 222a :2 0 74
:3 0 87 :3 0 222d
222e 0 76 :4 0
1f9 :4 0 79 :2 0
7a :3 0 13f9 2232
2234 :3 0 13fc 222f
2236 :2 0 2238 13ff
2239 222c 2238 0
223a 1401 0 2247
e2 :3 0 e3 :3 0
223b 223c 0 7e
:3 0 60 :3 0 2f
:2 0 1403 223e 2241
1c :3 0 e4 :3 0
1406 223d 2245 :2 0
2247 140a 2248 f5b
2247 0 23bb 8a
:3 0 1fa :3 0 8a
:3 0 8c :3 0 8a
:3 0 8d :3 0 8a
:3 0 8e :3 0 8a
:3 0 8f :3 0 8a
:3 0 90 :3 0 8a
:3 0 91 :3 0 8a
:3 0 92 :3 0 8a
:3 0 93 :3 0 12
:3 0 37 :3 0 14
:3 0 35 :3 0 38
:3 0 3d :3 0 15
:3 0 1f :3 0 3c
:3 0 94 :3 0 8a
:3 0 8a :3 0 8b
:3 0 1a :4 0 1fb
1 :8 0 226f 10
:3 0 96 :3 0 226a
226b 0 97 :3 0
226c 226d 0 226f
1419 22b9 98 :3 0
10 :3 0 96 :3 0
2272 2273 0 97
:3 0 2274 2275 0
22af 71 :3 0 72
:3 0 2277 2278 0
71 :3 0 84 :3 0
227a 227b 0 99
:2 0 2 :4 0 1fc
:2 0 86 :2 0 2c
:2 0 141c 2280 2282
:3 0 141f 227c 2284
2279 2286 2285 :2 0
74 :3 0 87 :3 0
2288 2289 0 76
:4 0 1fd :4 0 79
:2 0 7a :3 0 1423
228d 228f :3 0 79
:2 0 9c :4 0 1426
2291 2293 :3 0 79
:2 0 9d :4 0 1429
2295 2297 :3 0 79
:2 0 97 :3 0 142c
2299 229b :3 0 79
:2 0 9e :4 0 142f
229d 229f :3 0 79
:2 0 9f :3 0 a0
:3 0 2c :2 0 a1
:2 0 1432 22a2 22a6
1436 22a1 22a8 :3 0
1439 228a 22aa :2 0
22ac 143c 22ad 2287
22ac 0 22ae 143e
0 22af 1440 22b2
:3 0 22b2 0 22b2
22b1 22af 22b0 :6 0
22b4 4d :3 0 1443
22b6 1445 22b5 22b4
:2 0 22b7 1447 :2 0
22b9 0 22b9 22b8
226f 22b7 :6 0 23b8
1 :3 0 10 :3 0
96 :3 0 22bb 22bc
0 10 :3 0 a2
:2 0 11a :3 0 22be
22c0 0 144b 22bf
22c2 :3 0 22c3 :2 0
1fe :2 0 144e 22c5
22c6 :3 0 71 :3 0
72 :3 0 22c8 22c9
0 71 :3 0 84
:3 0 22cb 22cc 0
13 :2 0 2 :4 0
1ff :2 0 86 :2 0
2c :2 0 1450 22d1
22d3 :3 0 1453 22cd
22d5 22ca 22d7 22d6
:2 0 74 :3 0 87
:3 0 22d9 22da 0
76 :4 0 200 :4 0
79 :2 0 7a :3 0
1457 22de 22e0 :3 0
79 :2 0 9c :4 0
145a 22e2 22e4 :3 0
79 :2 0 dc :4 0
145d 22e6 22e8 :3 0
79 :2 0 7e :3 0
82 :3 0 dd :3 0
de :3 0 22ed 22ee
0 1460 22ec 22f0
81 :4 0 1462 22eb
22f3 1465 22ea 22f5
:3 0 79 :2 0 df
:4 0 1468 22f7 22f9
:3 0 79 :2 0 7c
:4 0 146b 22fb 22fd
:3 0 79 :2 0 1a
:3 0 146e 22ff 2301
:3 0 79 :2 0 7c
:4 0 1471 2303 2305
:3 0 1474 22db 2307
:2 0 2309 1477 230a
22d8 2309 0 230b
1479 0 2335 71
:3 0 72 :3 0 230c
230d 0 71 :3 0
84 :3 0 230f 2310
0 2c :2 0 2
:4 0 201 :2 0 86
:2 0 2c :2 0 147b
2315 2317 :3 0 147e
2311 2319 230e 231b
231a :2 0 74 :3 0
87 :3 0 231d 231e
0 76 :4 0 202
:4 0 79 :2 0 7a
:3 0 1482 2322 2324
:3 0 1485 231f 2326
:2 0 2328 1488 2329
231c 2328 0 232a
148a 0 2335 e2
:3 0 e3 :3 0 232b
232c 0 dd :3 0
de :3 0 232e 232f
0 1a :3 0 e4
:3 0 148c 232d 2333
:2 0 2335 1490 2336
22c7 2335 0 2337
1494 0 23b8 e5
:3 0 165 :3 0 2338
2339 0 1b :3 0
12 :3 0 1496 233a
233d a2 :2 0 2f
:2 0 149b 233f 2341
:3 0 10 :3 0 96
:3 0 2343 2344 0
2f :2 0 2345 2346
0 23b5 71 :3 0
72 :3 0 2348 2349
0 71 :3 0 84
:3 0 234b 234c 0
13 :2 0 2 :4 0
203 :2 0 86 :2 0
2c :2 0 149e 2351
2353 :3 0 14a1 234d
2355 234a 2357 2356
:2 0 74 :3 0 87
:3 0 2359 235a 0
76 :4 0 204 :4 0
79 :2 0 7a :3 0
14a5 235e 2360 :3 0
79 :2 0 9c :4 0
14a8 2362 2364 :3 0
79 :2 0 dc :4 0
14ab 2366 2368 :3 0
79 :2 0 7e :3 0
82 :3 0 10 :3 0
96 :3 0 236d 236e
0 14ae 236c 2370
81 :4 0 14b0 236b
2373 14b3 236a 2375
:3 0 79 :2 0 df
:4 0 14b6 2377 2379
:3 0 79 :2 0 7c
:4 0 14b9 237b 237d
:3 0 79 :2 0 1a
:3 0 14bc 237f 2381
:3 0 79 :2 0 7c
:4 0 14bf 2383 2385
:3 0 14c2 235b 2387
:2 0 2389 14c5 238a
2358 2389 0 238b
14c7 0 23b5 71
:3 0 72 :3 0 238c
238d 0 71 :3 0
84 :3 0 238f 2390
0 2c :2 0 2
:4 0 205 :2 0 86
:2 0 2c :2 0 14c9
2395 2397 :3 0 14cc
2391 2399 238e 239b
239a :2 0 74 :3 0
87 :3 0 239d 239e
0 76 :4 0 206
:4 0 79 :2 0 7a
:3 0 14d0 23a2 23a4
:3 0 14d3 239f 23a6
:2 0 23a8 14d6 23a9
239c 23a8 0 23aa
14d8 0 23b5 e2
:3 0 e3 :3 0 23ab
23ac 0 10 :3 0
96 :3 0 23ae 23af
0 1a :3 0 e4
:3 0 14da 23ad 23b3
:2 0 23b5 14de 23b6
2342 23b5 0 23b7
14e3 0 23b8 14e5
23ba 457 f4f 0
23bb 0 23b8 0
23bb 14e9 0 23bc
14ed 23bd 3a9 23bc
0 23be 14f0 0
2426 1c :3 0 3
:3 0 23bf 23c0 0
2426 1b :3 0 5
:3 0 23c2 23c3 0
2426 40 :3 0 e
:3 0 23c5 23c6 0
2426 3c :3 0 dd
:3 0 207 :3 0 23c9
23ca 0 23c8 23cb
0 2426 10 :3 0
96 :3 0 23cd 23ce
0 208 :3 0 3c
:3 0 1c :3 0 1b
:3 0 40 :3 0 14f2
23d0 23d5 23cf 23d6
0 2426 71 :3 0
72 :3 0 23d8 23d9
0 71 :3 0 84
:3 0 23db 23dc 0
172 :2 0 2 :4 0
209 :2 0 86 :2 0
2c :2 0 14f7 23e1
23e3 :3 0 14fa 23dd
23e5 23da 23e7 23e6
:2 0 74 :3 0 87
:3 0 23e9 23ea 0
76 :4 0 20a :4 0
79 :2 0 7a :3 0
14fe 23ee 23f0 :3 0
79 :2 0 9c :4 0
1501 23f2 23f4 :3 0
79 :2 0 dc :4 0
1504 23f6 23f8 :3 0
79 :2 0 7e :3 0
82 :3 0 10 :3 0
96 :3 0 23fd 23fe
0 1507 23fc 2400
81 :4 0 1509 23fb
2403 150c 23fa 2405
:3 0 79 :2 0 df
:4 0 150f 2407 2409
:3 0 79 :2 0 7c
:4 0 1512 240b 240d
:3 0 79 :2 0 1c
:3 0 1515 240f 2411
:3 0 79 :2 0 7c
:4 0 1518 2413 2415
:3 0 151b 23eb 2417
:2 0 2419 151e 241a
23e8 2419 0 241b
1520 0 2426 e2
:3 0 175 :3 0 241c
241d 0 10 :3 0
96 :3 0 241f 2420
0 1c :3 0 e4
:3 0 1522 241e 2424
:2 0 2426 1526 24c7
10 :3 0 20b :2 0
4 2427 2428 0
71 :3 0 72 :3 0
242a 242b 0 71
:3 0 84 :3 0 242d
242e 0 99 :2 0
2 :4 0 20c :2 0
86 :2 0 2c :2 0
1537 2433 2435 :3 0
153a 242f 2437 242c
2439 2438 :2 0 74
:3 0 87 :3 0 243b
243c 0 76 :4 0
20d :4 0 79 :2 0
7a :3 0 153e 2440
2442 :3 0 1541 243d
2444 :2 0 245d 74
:3 0 87 :3 0 2446
2447 0 76 :4 0
20e :4 0 79 :2 0
10 :3 0 20f :3 0
244c 244d 0 1544
244b 244f :3 0 79
:2 0 df :4 0 1547
2451 2453 :3 0 79
:2 0 10 :3 0 210
:3 0 2456 2457 0
154a 2455 2459 :3 0
154d 2448 245b :2 0
245d 1550 245e 243a
245d 0 245f 1553
0 246f 17f :3 0
70 :3 0 10 :3 0
20f :3 0 211 :3 0
10 :3 0 210 :3 0
212 :3 0 100 :4 0
213 1 :a 0 246b
:2 0 246f 2461 2469
:2 0 f :3 0 70
:3 0 246d :2 0 246f
1555 2471 1559 2470
246f :2 0 24c5 98
:3 0 10 :3 0 96
:3 0 2474 2475 0
97 :3 0 2476 2477
0 24bd 71 :3 0
72 :3 0 2479 247a
0 71 :3 0 84
:3 0 247c 247d 0
99 :2 0 2 :4 0
214 :2 0 86 :2 0
2c :2 0 155b 2482
2484 :3 0 155e 247e
2486 247b 2488 2487
:2 0 74 :3 0 87
:3 0 248a 248b 0
76 :4 0 215 :4 0
79 :2 0 7a :3 0
1562 248f 2491 :3 0
1565 248c 2493 :2 0
24ad 74 :3 0 87
:3 0 2495 2496 0
76 :4 0 9d :4 0
79 :2 0 97 :3 0
1568 249a 249c :3 0
79 :2 0 9e :4 0
156b 249e 24a0 :3 0
79 :2 0 9f :3 0
a0 :3 0 2c :2 0
a1 :2 0 156e 24a3
24a7 1572 24a2 24a9
:3 0 1575 2497 24ab
:2 0 24ad 1578 24ae
2489 24ad 0 24af
157b 0 24bd 17f
:3 0 70 :3 0 211
:3 0 10 :3 0 210
:3 0 212 :3 0 100
:4 0 216 1 :a 0
24b9 :2 0 24bd 24b1
24b7 :2 0 f :3 0
70 :3 0 24bb :2 0
24bd 157d 24c0 :3 0
24c0 0 24c0 24bf
24bd 24be :6 0 24c2
1 :3 0 1582 24c4
1584 24c3 24c2 :2 0
24c5 1586 :2 0 24c7
1589 24c7 24c6 2426
24c5 :6 0 24c8 :2 0
2 2c 24c7 24cb
:3 0 24ca 24c8 24cc
:8 0 
15e1
4
:3 0 1 3 1
7 1 b 1
f 1 13 1
17 1 1b 1
1f 1 23 9
6 a e 12
16 1a 1e 22
26 1 30 1
2e 1 37 1
35 1 3e 1
3c 1 45 1
43 1 4c 1
4a 1 53 1
51 1 5a 1
58 1 61 1
5f 1 68 1
66 1 6f 1
6d 1 76 1
74 1 7d 1
7b 1 84 1
82 1 89 1
8e 1 93 1
98 1 9d 1
a2 1 a7 1
ac 1 b1 1
b8 1 b6 1
bf 1 bd 1
c4 1 ca 1
d0 1 d6 1
db 1 e0 1
e6 1 ec 1
f2 1 f8 1
fe 1 104 1
10a 1 110 1
116 1 11e 1
11c 1 125 1
123 1 12c 1
12a 1 131 1
137 1 13d 1
143 1 149 1
14f 1 155 1
15b 1 161 1
167 1 16d 1
173 1 179 1
17f 1 185 1
18b 1 191 1
197 1 19d 1
1a3 1 1a9 1
1af 1 1b5 1
1bb 1 1c3 1
1c1 1 1ca 1
1c8 1 1cf 1
1d7 1 1d5 1
1dc 1 1e2 1
1e8 1 1ee 1
1f4 1 1fa 1
200 1 206 1
20c 1 212 1
218 1 220 1
21e 1 225 1
22a 1 22f 1
236 1 23d 1
24a 1 256 2
259 25b 2 25e
260 2 262 264
2 266 268 2
26a 26c 2 26e
270 2 272 274
2 276 278 2
27a 27c 2 282
284 2 286 288
2 28a 28b 2
28d 28e 2 27e
290 2 292 294
2 29a 29c 2
29e 2a0 2 2a2
2a3 2 2a5 2a6
2 296 2a8 2
2aa 2ac 1 2b2
2 2b4 2b5 2
2ae 2b7 2 2b9
2bb 1 2c1 2
2c3 2c4 2 2bd
2c6 2 2c8 2ca
1 2d0 2 2d2
2d3 2 2cc 2d5
2 2d7 2d9 1
2df 2 2e1 2e2
2 2db 2e4 2
2e6 2e8 2 2ea
2ec 2 2ee 2f0
2 2f2 2f4 2
2f6 2f8 4 252
258 25d 2fa 1
2fc 1 2fe 2
308 30a 3 306
307 30c 2 315
317 2 314 319
1 31b 1 31d
2 34e 353 2
364 366 3 362
363 368 2 371
373 2 375 377
2 379 37b 2
37d 37f 2 381
383 3 388 389
38a 2 385 38c
2 370 38e 1
390 1 392 2
35b 393 1 397
1 356 1 39b
1 3a6 2 3a2
3a6 2 3fc 401
2 412 414 3
410 411 416 2
41f 421 2 423
425 2 427 429
2 42b 42d 2
42f 431 3 436
437 438 2 433
43a 2 41e 43c
1 43e 1 440
2 409 441 1
445 1 404 1
449 1 454 2
450 454 2 478
47d 2 48e 490
3 48c 48d 492
2 49b 49d 2
49f 4a1 2 4a3
4a5 2 4a7 4a9
2 4ab 4ad 3
4b2 4b3 4b4 2
4af 4b6 2 49a
4b8 1 4ba 1
4bc 2 485 4bd
1 4c1 1 480
1 4c5 1 4d0
2 4cc 4d0 2
4dc 4de 3 4da
4db 4e0 2 4e9
4eb 2 4ed 4ef
2 4f1 4f3 1
4fb 2 4fd 4fe
2 4f5 500 2
502 504 2 506
508 2 50a 50c
2 50e 510 2
4e8 512 1 514
1 516 2 520
522 3 51e 51f
524 2 52d 52f
2 52c 531 1
533 1 535 3
53c 53d 53e 3
517 536 540 1
542 3 54d 54e
54f 1 553 2
551 553 3 55a
55b 55c 1 560
2 55e 560 2
56e 570 3 56c
56d 572 2 57b
57d 2 57f 581
2 583 585 1
58d 2 58f 590
2 587 592 2
594 596 2 598
59a 2 59c 59e
2 5a0 5a2 2
57a 5a4 1 5a6
1 5a8 2 5b2
5b4 3 5b0 5b1
5b6 2 5bf 5c1
2 5be 5c3 1
5c5 1 5c7 3
5ce 5cf 5d0 3
5a9 5c8 5d2 1
5d4 1 5d6 2
5dd 5de 2 5e3
5e4 2 5e0 5e6
2 5ec 5ed 1
5ef 2 5e9 5ef
2 5fd 5ff 3
5fb 5fc 601 2
60a 60c 2 60e
610 2 612 614
1 61c 2 61e
61f 2 616 621
2 623 625 2
627 629 2 62b
62d 2 62f 631
2 609 633 1
635 1 637 2
641 643 3 63f
640 645 2 64e
650 2 64d 652
1 654 1 656
3 65d 65e 65f
3 638 657 661
1 663 3 668
669 66a 1 66e
2 66c 66e 3
675 676 677 1
67b 2 679 67b
2 682 683 1
687 2 685 687
3 68d 68e 68f
1 693 2 691
693 2 6a6 6ab
2 6bc 6be 3
6ba 6bb 6c0 2
6c9 6cb 2 6cd
6cf 2 6d1 6d3
2 6d5 6d7 2
6d9 6db 3 6e0
6e1 6e2 2 6dd
6e4 2 6c8 6e6
1 6e8 1 6ea
2 6b3 6eb 1
6ef 1 6ae 1
6f3 1 6fe 2
6fa 6fe 2 70b
710 2 721 723
3 71f 720 725
2 72e 730 2
732 734 2 736
738 2 73a 73c
2 73e 740 3
745 746 747 2
742 749 2 72d
74b 1 74d 1
74f 2 718 750
1 754 1 713
1 758 1 75b
1 75e 3 763
764 765 1 769
2 767 769 1
76e 1 770 3
6f6 75f 771 2
783 788 2 799
79b 3 797 798
79d 2 7a6 7a8
2 7aa 7ac 2
7ae 7b0 2 7b2
7b4 2 7b6 7b8
3 7bd 7be 7bf
2 7ba 7c1 2
7a5 7c3 1 7c5
1 7c7 2 790
7c8 1 7cc 1
78b 1 7d0 1
7db 2 7d7 7db
2 7e8 7ed 2
7fe 800 3 7fc
7fd 802 2 80b
80d 2 80f 811
2 813 815 2
817 819 2 81b
81d 3 822 823
824 2 81f 826
2 80a 828 1
82a 1 82c 2
7f5 82d 1 831
1 7f0 1 835
1 838 1 83b
3 7d3 83c 83f
2 841 842 2
845 846 1 84c
2 848 84c 1
85b 2 85a 85b
1 863 1 869
2 86b 86c 2
858 86d 2 87e
880 3 87c 87d
882 2 88b 88d
2 88f 891 2
893 895 2 897
899 2 89b 89d
3 8a2 8a3 8a4
2 89f 8a6 2
88a 8a8 1 8aa
1 8ac 2 875
8ad 1 8b1 1
870 1 8b5 1
8b8 1 8c7 2
8c6 8c7 1 8cf
1 8d5 2 8d7
8d8 2 8c4 8d9
2 8ea 8ec 3
8e8 8e9 8ee 2
8f7 8f9 2 8fb
8fd 2 8ff 901
2 903 905 2
907 909 3 90e
90f 910 2 90b
912 2 8f6 914
1 916 1 918
2 8e1 919 1
91d 1 8dc 1
921 1 924 2
927 928 1 930
2 92c 930 1
936 1 939 1
93b 3 843 929
93c 2 947 94c
2 95d 95f 3
95b 95c 961 2
96a 96c 2 96e
970 2 972 974
2 976 978 2
97a 97c 3 981
982 983 2 97e
985 2 969 987
1 989 1 98b
2 954 98c 1
990 1 94f 1
994 2 99a 99b
1 99f 2 99d
99f 2 9aa 9ac
3 9a8 9a9 9ae
2 9b7 9b9 2
9bb 9bd 2 9bf
9c1 1 9c9 2
9cb 9cc 2 9c3
9ce 2 9d0 9d2
2 9d4 9d6 2
9d8 9da 2 9dc
9de 2 9b6 9e0
1 9e2 1 9e4
2 9ee 9f0 3
9ec 9ed 9f2 2
9fb 9fd 2 9fa
9ff 1 a01 1
a03 3 a0a a0b
a0c 3 9e5 a04
a0e 1 a10 3
a15 a16 a17 1
a1b 2 a19 a1b
2 a2e a33 2
a44 a46 3 a42
a43 a48 2 a51
a53 2 a55 a57
2 a59 a5b 2
a5d a5f 2 a61
a63 3 a68 a69
a6a 2 a65 a6c
2 a50 a6e 1
a70 1 a72 2
a3b a73 1 a77
1 a36 1 a7b
1 a86 2 a82
a86 2 a93 a98
2 aa9 aab 3
aa7 aa8 aad 2
ab6 ab8 2 aba
abc 2 abe ac0
2 ac2 ac4 2
ac6 ac8 3 acd
ace acf 2 aca
ad1 2 ab5 ad3
1 ad5 1 ad7
2 aa0 ad8 1
adc 1 a9b 1
ae0 1 ae3 1
ae6 2 a7e ae7
2 af9 afe 2
b0f b11 3 b0d
b0e b13 2 b1c
b1e 2 b20 b22
2 b24 b26 2
b28 b2a 2 b2c
b2e 3 b33 b34
b35 2 b30 b37
2 b1b b39 1
b3b 1 b3d 2
b06 b3e 1 b42
1 b01 1 b46
1 b51 2 b4d
b51 2 b5e b63
2 b74 b76 3
b72 b73 b78 2
b81 b83 2 b85
b87 2 b89 b8b
2 b8d b8f 2
b91 b93 3 b98
b99 b9a 2 b95
b9c 2 b80 b9e
1 ba0 1 ba2
2 b6b ba3 1
ba7 1 b66 1
bab 1 bae 1
bb1 2 b49 bb2
2 bb4 bb5 2
bc2 bc3 a bb9
bba bbb bbc bbd
bbe bbf bc0 bc5
bc6 2 bcb bcc
1 bd0 2 bce
bd0 1 bd5 1
bd8 2 be2 be4
3 be0 be1 be6
2 bef bf1 2
bf3 bf5 2 bf7
bf9 1 bff 2
c01 c02 2 bfb
c04 2 c06 c08
2 c0a c0c 2
c0e c10 2 c12
c14 2 bee c16
1 c18 1 c1a
2 c24 c26 3
c22 c23 c28 2
c31 c33 2 c30
c35 1 c37 1
c39 2 c3f c40
3 c42 c43 c44
3 c1b c3a c46
2 c48 c49 5
997 a11 bb6 bc9
c4a 2 c4c c4d
1 c4e 2 c52
c53 2 c58 c59
1 c5b 2 c55
c5b 2 c60 c61
1 c65 2 c63
c65 2 c6f c70
2 c75 c76 1
c78 2 c72 c78
2 c83 c85 3
c81 c82 c87 2
c90 c92 2 c94
c96 2 c98 c9a
1 ca2 2 ca4
ca5 2 c9c ca7
2 c8f ca9 1
cab 1 cad 2
cb7 cb9 3 cb5
cb6 cbb 2 cc4
cc6 2 cc3 cc8
1 cca 1 ccc
2 cd3 cd4 3
cae ccd cd6 2
cda cdb 2 ce0
ce1 1 ce3 2
cdd ce3 1 ce8
2 ceb cea 2
d08 d0d 2 d1e
d20 3 d1c d1d
d22 2 d2b d2d
2 d2f d31 2
d33 d35 2 d37
d39 2 d3b d3d
3 d42 d43 d44
2 d3f d46 2
d2a d48 1 d4a
1 d4c 2 d15
d4d 1 d51 1
d10 1 d55 2
d5b d5c 1 d60
2 d5e d60 2
d6b d6d 3 d69
d6a d6f 2 d78
d7a 2 d7c d7e
2 d80 d82 1
d8a 2 d8c d8d
2 d84 d8f 2
d91 d93 2 d95
d97 2 d99 d9b
2 d9d d9f 2
d77 da1 1 da3
1 da5 2 daf
db1 3 dad dae
db3 2 dbc dbe
2 dbb dc0 1
dc2 1 dc4 3
dcb dcc dcd 3
da6 dc5 dcf 1
dd1 2 def df4
2 e05 e07 3
e03 e04 e09 2
e12 e14 2 e16
e18 2 e1a e1c
2 e1e e20 2
e22 e24 3 e29
e2a e2b 2 e26
e2d 2 e11 e2f
1 e31 1 e33
2 dfc e34 1
e38 1 df7 1
e3c 2 e42 e43
1 e47 2 e45
e47 2 e52 e54
3 e50 e51 e56
2 e5f e61 2
e63 e65 2 e67
e69 1 e71 2
e73 e74 2 e6b
e76 2 e78 e7a
2 e7c e7e 2
e80 e82 2 e84
e86 2 e5e e88
1 e8a 1 e8c
2 e96 e98 3
e94 e95 e9a 2
ea3 ea5 2 ea2
ea7 1 ea9 1
eab 3 eb2 eb3
eb4 3 e8d eac
eb6 1 eb8 2
ec4 ec5 5 ebf
ec0 ec1 ec2 ec7
9 c6d cec cef
d58 dd2 e3f eb9
ebc eca 2 ecd
ecc 2 ed0 ed1
1 ed5 2 ed3
ed5 1 eda 1
edd 1 edf 2
ee9 eeb 3 ee7
ee8 eed 2 ef6
ef8 2 efa efc
2 efe f00 1
f06 2 f08 f09
2 f02 f0b 2
f0d f0f 2 f11
f13 2 f15 f17
2 f19 f1b 2
ef5 f1d 1 f1f
1 f21 2 f2b
f2d 3 f29 f2a
f2f 2 f38 f3a
2 f37 f3c 1
f3e 1 f40 2
f46 f47 3 f49
f4a f4b b 4c8
543 546 549 5d5
664 ece ee0 f22
f41 f4d 1 f50
1 f55 3 f65
f66 f67 1 f6b
2 f69 f6b 3
f72 f73 f74 1
f78 2 f76 f78
2 f86 f88 3
f84 f85 f8a 2
f93 f95 2 f97
f99 2 f9b f9d
1 fa5 2 fa7
fa8 2 f9f faa
2 fac fae 2
fb0 fb2 2 fb4
fb6 2 fb8 fba
2 f92 fbc 1
fbe 1 fc0 2
fca fcc 3 fc8
fc9 fce 2 fd7
fd9 2 fd6 fdb
1 fdd 1 fdf
3 fe6 fe7 fe8
3 fc1 fe0 fea
1 fec 2 ff9
ffe 2 100f 1011
3 100d 100e 1013
2 101c 101e 2
1020 1022 2 1024
1026 2 1028 102a
2 102c 102e 3
1033 1034 1035 2
1030 1037 2 101b
1039 1 103b 1
103d 2 1006 103e
1 1042 1 1001
1 1046 3 104c
104d 104e 1 1052
2 1050 1052 1
1057 1 105b 2
105d 105e 3 1069
106a 106b 1 106f
2 106d 106f 3
1076 1077 1078 1
107c 2 107a 107c
2 1083 1084 2
1089 108a 1 108c
2 1086 108c 3
1095 1096 1097 1
109b 2 1099 109b
2 10a7 10ac 2
10bd 10bf 3 10bb
10bc 10c1 2 10ca
10cc 2 10ce 10d0
2 10d2 10d4 2
10d6 10d8 2 10da
10dc 3 10e1 10e2
10e3 2 10de 10e5
2 10c9 10e7 1
10e9 1 10eb 2
10b4 10ec 1 10f0
1 10af 1 10f4
4 10f7 10fb 10fe
1101 3 1107 1108
1109 1 110d 2
110b 110d 2 111a
111f 2 1130 1132
3 112e 112f 1134
2 113d 113f 2
1141 1143 2 1145
1147 2 1149 114b
2 114d 114f 3
1154 1155 1156 2
1151 1158 2 113c
115a 1 115c 1
115e 2 1127 115f
1 1163 1 1122
1 1167 2 1170
1171 1 1177 a
117d 117e 117f 1180
1181 1182 1183 1184
1185 1186 2 118b
118c 1 1190 2
118e 1190 1 1194
1 11aa 2 11a9
11aa 1 11b2 1
11b8 2 11ba 11bb
2 11a7 11bc 2
11cd 11cf 3 11cb
11cc 11d1 2 11da
11dc 2 11de 11e0
2 11e2 11e4 2
11e6 11e8 2 11ea
11ec 3 11f1 11f2
11f3 2 11ee 11f5
2 11d9 11f7 1
11f9 1 11fb 2
11c4 11fc 1 1200
1 11bf 1 1204
1 1207 1 120a
3 120d 120e 120f
1 1213 2 1211
1213 1 1218 1
121c 2 121e 121f
10 1223 1224 1225
1226 1227 1228 1229
122a 122b 122c 122d
122e 122f 1230 1231
1232 2 1249 124e
2 125f 1261 3
125d 125e 1263 2
126c 126e 2 1270
1272 2 1274 1276
2 1278 127a 2
127c 127e 3 1283
1284 1285 2 1280
1287 2 126b 1289
1 128b 1 128d
2 1256 128e 1
1292 1 1251 1
1296 a 12a0 12a1
12a2 12a3 12a4 12a5
12a6 12a7 12a8 12a9
1 12af 2 12c0
12c2 3 12be 12bf
12c4 2 12cd 12cf
2 12d1 12d3 2
12d5 12d7 1 12df
2 12e1 12e2 2
12d9 12e4 2 12e6
12e8 2 12ea 12ec
2 12ee 12f0 2
12f2 12f4 2 12cc
12f6 1 12f8 1
12fa 3 1301 1302
1303 e 116a 1174
117a 1189 120b 1220
1235 1299 129d 12ac
12b2 12b7 12fb 1305
2 130a 130b 2
1310 1311 1 1313
2 130d 1313 2
1318 1319 2 131e
131f 2 131b 1321
2 1324 1327 2
132c 132d 1 1331
2 132f 1331 2
133f 1344 2 1355
1357 3 1353 1354
1359 2 1362 1364
2 1366 1368 2
136a 136c 2 136e
1370 2 1372 1374
3 1379 137a 137b
2 1376 137d 2
1361 137f 1 1381
1 1383 2 134c
1384 1 1388 1
1347 1 138c 3
1336 1339 138f 2
1395 1396 2 139b
139c 1 139e 2
1398 139e 2 13a3
13a4 2 13a9 13aa
2 13a6 13ac 2
13b7 13b8 1 13bc
2 13ba 13bc 2
13c0 13c2 2 13c4
13c6 2 13c8 13ca
2 13cc 13ce 2
13d0 13d2 2 13d4
13d6 2 13dc 13dd
1 13df 2 13d8
13e1 2 13e4 13e9
2 13ec 13ee 2
13f0 13f2 2 13f4
13f6 2 13f8 13fa
2 13fc 13fe 2
1400 1402 2 1408
1409 1 140b 2
1404 140d 2 1410
1415 2 1417 1418
2 141c 141d 1
1421 2 141f 1421
1 142f 1 1435
2 1437 1438 2
1426 1439 1 1446
1 144c 2 144e
144f 2 143d 1450
2 1452 1453 1
145b 2 1457 145b
1 1460 1 1462
2 1454 1463 2
1468 1469 1 146d
2 146b 146d 2
1472 1478 2 1489
148b 3 1487 1488
148d 2 1496 1498
2 149a 149c 2
149e 14a0 2 14a2
14a4 2 14a6 14a8
3 14ad 14ae 14af
2 14aa 14b1 2
1495 14b3 1 14b5
1 14b7 2 1480
14b8 1 14bc 1
147b 1 14c0 1
14c3 2 14c8 14ce
2 14df 14e1 3
14dd 14de 14e3 2
14ec 14ee 2 14f0
14f2 2 14f4 14f6
2 14f8 14fa 2
14fc 14fe 3 1503
1504 1505 2 1500
1507 2 14eb 1509
1 150b 1 150d
2 14d6 150e 1
1512 1 14d1 1
1516 1 1519 2
151c 151d 1 151f
2 1525 1526 1
152a 2 1528 152a
2 1535 1537 3
1533 1534 1539 2
1542 1544 2 1546
1548 2 154a 154c
1 1554 2 1556
1557 2 154e 1559
2 155b 155d 2
155f 1561 2 1563
1565 2 1567 1569
2 1541 156b 1
156d 1 156f 2
1579 157b 3 1577
1578 157d 2 1586
1588 2 1585 158a
1 158c 1 158e
3 1595 1596 1597
3 1570 158f 1599
2 15a3 15a5 3
15a1 15a2 15a7 2
15b0 15b2 2 15b4
15b6 2 15b8 15ba
1 15c2 2 15c4
15c5 2 15bc 15c7
2 15c9 15cb 2
15cd 15cf 2 15d1
15d3 2 15d5 15d7
2 15af 15d9 1
15db 1 15dd 2
15e7 15e9 3 15e5
15e6 15eb 2 15f4
15f6 2 15f3 15f8
1 15fa 1 15fc
3 1603 1604 1605
3 15de 15fd 1607
2 1609 160a 1
160b 1 160d 2
1619 161e 2 162f
1631 3 162d 162e
1633 2 163c 163e
2 1640 1642 2
1644 1646 2 1648
164a 2 164c 164e
3 1653 1654 1655
2 1650 1657 2
163b 1659 1 165b
1 165d 2 1626
165e 1 1662 1
1621 1 1666 a
13af 13b2 13b5 1419
1466 151e 160e 1669
166d 1670 5 1673
1308 132a 1393 1672
1 1674 2 1678
1679 2 167e 167f
1 1681 2 167b
1681 2 1685 1686
2 168b 168c 1
168e 2 1688 168e
2 1699 169b 3
1697 1698 169d 2
16a6 16a8 2 16aa
16ac 2 16ae 16b0
1 16b8 2 16ba
16bb 2 16b2 16bd
2 16bf 16c1 2
16c3 16c5 2 16c7
16c9 2 16cb 16cd
2 16a5 16cf 1
16d1 1 16d3 2
16dd 16df 3 16db
16dc 16e1 2 16ea
16ec 2 16e9 16ee
1 16f0 1 16f2
3 16f9 16fa 16fb
3 16d4 16f3 16fd
1 16ff 2 1702
1703 1 1707 2
1705 1707 1 170c
2 170f 1710 1
1714 2 1712 1714
2 1719 171a 1
171e 2 171c 171e
2 172c 172e 3
172a 172b 1730 2
1739 173b 2 173d
173f 2 1741 1743
1 174b 2 174d
174e 2 1745 1750
2 1738 1752 1
1754 1 1756 2
1760 1762 3 175e
175f 1764 2 176d
176f 2 176c 1771
1 1773 1 1775
2 177c 177d 3
1757 1776 177f 1
1781 2 1782 1785
2 1787 1788 1
178a 2 1794 1799
2 17aa 17ac 3
17a8 17a9 17ae 2
17b7 17b9 2 17bb
17bd 2 17bf 17c1
2 17c3 17c5 2
17c7 17c9 3 17ce
17cf 17d0 2 17cb
17d2 2 17b6 17d4
1 17d6 1 17d8
2 17a1 17d9 1
17dd 1 179c 1
17e1 1 17ec 2
17e8 17ec 2 17f1
17f2 2 17f7 17f8
1 17fa 2 17f4
17fa 2 1808 180a
3 1806 1807 180c
2 1815 1817 2
1819 181b 2 181d
181f 1 1827 2
1829 182a 2 1821
182c 2 182e 1830
2 1832 1834 2
1836 1838 2 183a
183c 2 1814 183e
1 1840 1 1842
2 184c 184e 3
184a 184b 1850 2
1859 185b 2 1858
185d 1 185f 1
1861 3 1868 1869
186a 3 1843 1862
186c 1 186e 2
17e4 186f 1 1871
2 187a 187b 1
187f 2 187d 187f
1 1884 1 1886
1 189d 2 189c
189d 1 18a5 1
18ab 2 18ad 18ae
2 189a 18af 2
18c0 18c2 3 18be
18bf 18c4 2 18cd
18cf 2 18d1 18d3
2 18d5 18d7 2
18d9 18db 2 18dd
18df 3 18e4 18e5
18e6 2 18e1 18e8
2 18cc 18ea 1
18ec 1 18ee 2
18b7 18ef 1 18f3
1 18b2 1 18f7
2 18fd 18fe 1
1902 2 1900 1902
1 1907 1 1909
8 1700 1789 1872
1875 1878 1887 18fa
190a 2 190d 190c
1 1911 2 190f
1911 1 1916 a
191c 191d 191e 191f
1920 1921 1922 1923
1924 1925 2 192a
192b 1 192f 2
192d 192f 1 1933
8 193d 193e 193f
1940 1941 1942 1943
1944 1 1947 1
1949 1 194b 3
1952 1953 1954 1
1957 3 195a 195b
195c 1 1960 2
195e 1960 3 1965
1966 1967 1 196a
3 196e 196f 1970
1 1973 2 1975
1976 1 1977 2
1979 197a 1 197c
2 1982 1983 1
1987 2 1985 1987
2 198f 1990 2
1992 1995 2 19a4
19a9 2 19ba 19bc
3 19b8 19b9 19be
2 19c7 19c9 2
19cb 19cd 2 19cf
19d1 2 19d3 19d5
2 19d7 19d9 3
19de 19df 19e0 2
19db 19e2 2 19c6
19e4 1 19e6 1
19e8 2 19b1 19e9
1 19ed 1 19ac
1 19f1 2 1999
19f4 2 1a01 1a06
2 1a17 1a19 3
1a15 1a16 1a1b 2
1a24 1a26 2 1a28
1a2a 2 1a2c 1a2e
2 1a30 1a32 2
1a34 1a36 3 1a3b
1a3c 1a3d 2 1a38
1a3f 2 1a23 1a41
1 1a43 1 1a45
2 1a0e 1a46 1
1a4a 1 1a09 1
1a4e 1 1a51 2
1a54 1a55 2 1a59
1a5a 2 1a5f 1a60
2 1a5c 1a62 2
1a56 1a65 1 1a67
2 1a75 1a76 2
1a7a 1a7b 8 1a6e
1a6f 1a70 1a71 1a72
1a73 1a78 1a7d 2
1a82 1a83 1 1a87
2 1a85 1a87 2
1a92 1a94 3 1a90
1a91 1a96 2 1a9f
1aa1 2 1aa3 1aa5
2 1aa7 1aa9 1
1ab1 2 1ab3 1ab4
2 1aab 1ab6 2
1ab8 1aba 2 1abc
1abe 2 1ac0 1ac2
2 1ac4 1ac6 2
1a9e 1ac8 1 1aca
1 1acc 2 1ad6
1ad8 3 1ad4 1ad5
1ada 2 1ae3 1ae5
2 1ae2 1ae7 1
1ae9 1 1aeb 3
1af2 1af3 1af4 3
1acd 1aec 1af6 1
1afb 2 1af9 1afb
1 1b17 2 1b16
1b17 1 1b1f 1
1b25 2 1b27 1b28
2 1b14 1b29 2
1b3a 1b3c 3 1b38
1b39 1b3e 2 1b47
1b49 2 1b4b 1b4d
2 1b4f 1b51 2
1b53 1b55 2 1b57
1b59 3 1b5e 1b5f
1b60 2 1b5b 1b62
2 1b46 1b64 1
1b66 1 1b68 2
1b31 1b69 1 1b6d
1 1b2c 1 1b71
1 1b74 2 1b78
1b77 1 1b7c 2
1b88 1b8a 3 1b86
1b87 1b8c 2 1b95
1b97 2 1b99 1b9b
2 1b9d 1b9f 1
1ba5 2 1ba7 1ba8
2 1ba1 1baa 2
1bac 1bae 2 1bb0
1bb2 2 1bb4 1bb6
2 1bb8 1bba 2
1b94 1bbc 1 1bbe
1 1bc0 2 1bca
1bcc 3 1bc8 1bc9
1bce 2 1bd7 1bd9
2 1bd6 1bdb 1
1bdd 1 1bdf 2
1be5 1be6 3 1be8
1be9 1bea c 1919
1928 194a 197b 1a68
1a6b 1a80 1b79 1b7f
1bc1 1be0 1bec 1
1bee 2 1bf1 1bf2
2 1bf7 1bf8 1
1bfa 2 1bf4 1bfa
2 1c09 1c0e 2
1c1f 1c21 3 1c1d
1c1e 1c23 2 1c2c
1c2e 2 1c30 1c32
2 1c34 1c36 2
1c38 1c3a 2 1c3c
1c3e 3 1c43 1c44
1c45 2 1c40 1c47
2 1c2b 1c49 1
1c4b 1 1c4d 2
1c16 1c4e 1 1c52
1 1c11 1 1c56
2 1c5c 1c5d 1
1c61 2 1c5f 1c61
2 1c6c 1c6e 3
1c6a 1c6b 1c70 2
1c79 1c7b 2 1c7d
1c7f 2 1c81 1c83
1 1c8b 2 1c8d
1c8e 2 1c85 1c90
2 1c92 1c94 2
1c96 1c98 2 1c9a
1c9c 2 1c9e 1ca0
2 1c78 1ca2 1
1ca4 1 1ca6 2
1cb0 1cb2 3 1cae
1caf 1cb4 2 1cbd
1cbf 2 1cbc 1cc1
1 1cc3 1 1cc5
3 1ccc 1ccd 1cce
3 1ca7 1cc6 1cd0
1 1cd2 2 1cd9
1cda 2 1cdf 1ce0
2 1ce5 1ce6 1
1ce8 2 1ce2 1ce8
1 1ced a 1cf3
1cf4 1cf5 1cf6 1cf7
1cf8 1cf9 1cfa 1cfb
1cfc 1 1d00 3
1d07 1d08 1d09 1
1d0c 3 1d0f 1d10
1d11 1 1d15 2
1d13 1d15 3 1d1a
1d1b 1d1c 1 1d1f
3 1d23 1d24 1d25
1 1d28 2 1d2a
1d2b 1 1d2c 2
1d2e 1d2f 1 1d34
2 1d3a 1d3b 1
1d3f 2 1d3d 1d3f
2 1d47 1d48 2
1d4a 1d4d 2 1d5c
1d61 2 1d72 1d74
3 1d70 1d71 1d76
2 1d7f 1d81 2
1d83 1d85 2 1d87
1d89 2 1d8b 1d8d
2 1d8f 1d91 3
1d96 1d97 1d98 2
1d93 1d9a 2 1d7e
1d9c 1 1d9e 1
1da0 2 1d69 1da1
1 1da5 1 1d64
1 1da9 2 1d51
1dac 2 1db9 1dbe
2 1dcf 1dd1 3
1dcd 1dce 1dd3 2
1ddc 1dde 2 1de0
1de2 2 1de4 1de6
2 1de8 1dea 2
1dec 1dee 3 1df3
1df4 1df5 2 1df0
1df7 2 1ddb 1df9
1 1dfb 1 1dfd
2 1dc6 1dfe 1
1e02 1 1dc1 1
1e06 1 1e09 2
1e0c 1e0d 2 1e10
1e11 1 1e15 2
1e13 1e15 2 1e24
1e29 2 1e3a 1e3c
3 1e38 1e39 1e3e
2 1e47 1e49 2
1e4b 1e4d 2 1e4f
1e51 2 1e53 1e55
2 1e57 1e59 3
1e5e 1e5f 1e60 2
1e5b 1e62 2 1e46
1e64 1 1e66 1
1e68 2 1e31 1e69
1 1e6d 1 1e2c
1 1e71 1 1e74
1 1e77 2 1e0e
1e78 1 1e7a 2
1e7e 1e7f 2 1e84
1e85 2 1e81 1e87
2 1e8c 1e8d 2
1e89 1e8f 1 1eac
2 1eab 1eac 1
1eb4 1 1eba 2
1ebc 1ebd 2 1ea9
1ebe 2 1ecf 1ed1
3 1ecd 1ece 1ed3
2 1edc 1ede 2
1ee0 1ee2 2 1ee4
1ee6 2 1ee8 1eea
2 1eec 1eee 3
1ef3 1ef4 1ef5 2
1ef0 1ef7 2 1edb
1ef9 1 1efb 1
1efd 2 1ec6 1efe
1 1f02 1 1ec1
1 1f06 1 1f11
2 1f0d 1f11 2
1f22 1f23 8 1f1a
1f1b 1f1c 1f1d 1f1e
1f1f 1f20 1f25 2
1f2a 1f2b 1 1f2f
2 1f2d 1f2f 2
1f3a 1f3c 3 1f38
1f39 1f3e 2 1f47
1f49 2 1f4b 1f4d
2 1f4f 1f51 1
1f57 2 1f59 1f5a
2 1f53 1f5c 2
1f5e 1f60 2 1f62
1f64 2 1f66 1f68
2 1f6a 1f6c 2
1f46 1f6e 1 1f70
1 1f72 2 1f7c
1f7e 3 1f7a 1f7b
1f80 2 1f89 1f8b
2 1f88 1f8d 1
1f8f 1 1f91 2
1f97 1f98 3 1f9a
1f9b 1f9c 3 1f73
1f92 1f9e 1 1fa0
3 1f17 1f28 1fa1
1 1fa3 2 1fa7
1fa8 a 1cf0 1cff
1d30 1d33 1e7b 1e92
1e95 1f09 1fa4 1fab
1 1fb1 2 1fb3
1fb4 1 1fba 2
1fbc 1fbd 2 1fb6
1fbf 2 1fc2 1fc4
2 1fc7 1fc9 1
1fcb 1 1fce 2
1fd0 1fd1 2 1fed
1fee 18 1fd5 1fd6
1fd7 1fd8 1fd9 1fda
1fdb 1fdc 1fdd 1fde
1fdf 1fe0 1fe1 1fe2
1fe3 1fe4 1fe5 1fe6
1fe7 1fe8 1fe9 1fea
1feb 1ff0 2 1ffc
1ffe 3 1ffa 1ffb
2000 2 2009 200b
2 200d 200f 2
2011 2013 1 2019
2 201b 201c 2
2015 201e 2 2020
2022 2 2024 2026
2 2028 202a 2
202c 202e 2 2008
2030 1 2032 1
2034 2 203e 2040
3 203c 203d 2042
2 204b 204d 2
204a 204f 1 2051
1 2053 2 2059
205a 3 205c 205d
205e 9 1c59 1cd3
1cd6 1cdd 1fd2 1ff3
2035 2054 2060 2
2064 2065 2 206a
206b 1 206d 2
2067 206d 2 2071
2072 1 2076 2
2074 2076 2 207b
207c 1 2080 2
207e 2080 2 208e
2090 3 208c 208d
2092 2 209b 209d
2 209f 20a1 2
20a3 20a5 1 20ad
2 20af 20b0 2
20a7 20b2 2 20b4
20b6 2 20b8 20ba
2 20bc 20be 2
20c0 20c2 2 209a
20c4 1 20c6 1
20c8 2 20d2 20d4
3 20d0 20d1 20d6
2 20df 20e1 2
20de 20e3 1 20e5
1 20e7 3 20ee
20ef 20f0 3 20c9
20e8 20f2 1 20f4
1 2104 2 2103
2104 1 210c 1
2112 2 2114 2115
2 2101 2116 2
2127 2129 3 2125
2126 212b 2 2134
2136 2 2138 213a
2 213c 213e 2
2140 2142 2 2144
2146 3 214b 214c
214d 2 2148 214f
2 2133 2151 1
2153 1 2155 2
211e 2156 1 215a
1 2119 1 215e
1 2171 2 2170
2171 1 2179 1
217f 2 2181 2182
2 216e 2183 2
2194 2196 3 2192
2193 2198 2 21a1
21a3 2 21a5 21a7
2 21a9 21ab 2
21ad 21af 2 21b1
21b3 3 21b8 21b9
21ba 2 21b5 21bc
2 21a0 21be 1
21c0 1 21c2 2
218b 21c3 1 21c7
1 2186 1 21cb
3 20f5 2161 21ce
2 21d2 21d1 1
21d6 2 21e2 21e4
3 21e0 21e1 21e6
2 21ef 21f1 2
21f3 21f5 2 21f7
21f9 1 21ff 2
2201 2202 2 21fb
2204 2 2206 2208
2 220a 220c 2
220e 2210 2 2212
2214 2 21ee 2216
1 2218 1 221a
2 2224 2226 3
2222 2223 2228 2
2231 2233 2 2230
2235 1 2237 1
2239 2 223f 2240
3 2242 2243 2244
e f5e f61 fed
1049 105f 1062 1065
190e 1bef 21d3 21d9
221b 223a 2246 2
2269 226e 2 227f
2281 3 227d 227e
2283 2 228c 228e
2 2290 2292 2
2294 2296 2 2298
229a 2 229c 229e
3 22a3 22a4 22a5
2 22a0 22a7 2
228b 22a9 1 22ab
1 22ad 2 2276
22ae 1 22b2 1
2271 1 22b6 1
22c1 2 22bd 22c1
1 22c4 2 22d0
22d2 3 22ce 22cf
22d4 2 22dd 22df
2 22e1 22e3 2
22e5 22e7 1 22ef
2 22f1 22f2 2
22e9 22f4 2 22f6
22f8 2 22fa 22fc
2 22fe 2300 2
2302 2304 2 22dc
2306 1 2308 1
230a 2 2314 2316
3 2312 2313 2318
2 2321 2323 2
2320 2325 1 2327
1 2329 3 2330
2331 2332 3 230b
232a 2334 1 2336
2 233b 233c 1
2340 2 233e 2340
2 2350 2352 3
234e 234f 2354 2
235d 235f 2 2361
2363 2 2365 2367
1 236f 2 2371
2372 2 2369 2374
2 2376 2378 2
237a 237c 2 237e
2380 2 2382 2384
2 235c 2386 1
2388 1 238a 2
2394 2396 3 2392
2393 2398 2 23a1
23a3 2 23a0 23a5
1 23a7 1 23a9
3 23b0 23b1 23b2
4 2347 238b 23aa
23b4 1 23b6 3
22b9 2337 23b7 3
23b9 2248 23ba 2
44c 23bb 1 23bd
4 23d1 23d2 23d3
23d4 2 23e0 23e2
3 23de 23df 23e4
2 23ed 23ef 2
23f1 23f3 2 23f5
23f7 1 23ff 2
2401 2402 2 23f9
2404 2 2406 2408
2 240a 240c 2
240e 2410 2 2412
2414 2 23ec 2416
1 2418 1 241a
3 2421 2422 2423
10 2ff 31e 321
324 327 32a 32d
39e 23be 23c1 23c4
23c7 23cc 23d7 241b
2425 2 2432 2434
3 2430 2431 2436
2 243f 2441 2
243e 2443 2 244a
244e 2 2450 2452
2 2454 2458 2
2449 245a 2 2445
245c 1 245e 3
245f 246a 246e 1
2429 2 2481 2483
3 247f 2480 2485
2 248e 2490 2
248d 2492 2 2499
249b 2 249d 249f
3 24a4 24a5 24a6
2 24a1 24a8 2
2498 24aa 2 2494
24ac 1 24ae 4
2478 24af 24b8 24bc
1 24c0 1 2473
2 2471 24c4 57
33 3a 41 48
4f 56 5d 64
6b 72 79 80
87 8c 91 96
9b a0 a5 aa
af b4 bb c2
c8 ce d4 d9
de e4 ea f0
f6 fc 102 108
10e 114 11a 121
128 12f 135 13b
141 147 14d 153
159 15f 165 16b
171 177 17d 183
189 18f 195 19b
1a1 1a7 1ad 1b3
1b9 1bf 1c6 1cd
1d3 1da 1e0 1e6
1ec 1f2 1f8 1fe
204 20a 210 216
21c 223 228 22d
234 23b 242 
1
4
0 
24cb
0
1
50
4f
61
0 1 2 1 4 1 6 1
8 1 a 1 c 1 e 1
10 1 12 1 14 1 16 1
18 1 1a 1 1c 1 1e 1
20 1 22 1 24 1 26 1
28 1 2a 1 2c 1 1 2f
1 31 1 33 1 35 1 37
1 39 1 3b 1 3d 1 3f
1 41 1 43 1 45 1 47
1 49 1 4b 1 4d 1 0

1a3 1 0
43 1 0
1cf 1 0
ec 1 0
218 1 0
9d 1 0
13d 1 0
1e8 1 0
f 1 0
fe 1 0
191 1 0
22a 1 0
93 1 0
1b5 1 0
d0 1 0
1d5 1 0
155 1 0
1a9 1 0
161 1 0
13 1 0
23 1 0
7 1 0
bd 1 0
98 1 0
1f4 1 0
22f 1 0
1c8 1 0
10a 1 0
21e 1 0
1fa 1 0
3c 1 0
1bb 1 0
104 1 0
d6 1 0
1e2 1 0
167 1 0
143 1 0
17f 1 0
19d 1 0
db 1 0
131 1 0
a2 1 0
66 1 0
149 1 0
f8 1 0
8e 1 0
206 1 0
116 1 0
c4 1 0
58 1 0
2e 1 0
18b 1 0
74 1 0
225 1 0
236 1 0
1af 1 0
ac 1 0
1dc 1 0
e6 1 0
212 1 0
35 1 0
3 1 0
ca 1 0
f2 1 0
11c 1 0
89 1 0
14f 1 0
197 1 0
15b 1 0
179 1 0
b6 1 0
82 1 0
b1 1 0
200 1 0
16d 1 0
110 1 0
123 1 0
7b 1 0
173 1 0
b 1 0
6d 1 0
5f 1 0
17 1 0
e0 1 0
1b 1 0
1ee 1 0
a7 1 0
1f 1 0
51 1 0
185 1 0
12a 1 0
2 0 1
1c1 1 0
4a 1 0
137 1 0
20c 1 0
23d 1 0
0

/
SHOW ERRORS FUNCTION SP_U_PARTICIPANT;
ALTER FUNCTION SP_U_PARTICIPANT COMPILE DEBUG;
/******************************************************************************************************************
update resource assignments SECURITY
assign_id:      RES_ASSIGNMENT_ID or TSK_ASSIGNMENT_ID
security_id:    SECURITY_ID in TMT_GLOBAL_SECURITY
*******************************************************************************************************************/
Prompt == FUNCTION SP_U_CRI_SECURITY ==
CREATE OR REPLACE FUNCTION SP_U_CRI_SECURITY wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
71
2 :e:
1FUNCTION:
1SP_U_CRI_SECURITY:
1ASSIGN_ID:
1VARCHAR2:
1SECURITY_ID001:
1P_PLANNED_START:
1TIMESTAMP:
1P_PLANNED_FINISH:
1P_DELAY:
1PLS_INTEGER:
1P_UNITS:
1P_WORK_PERCENT:
1P_ACTUAL:
1RES_ID001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1A_ELEMENT_ID:
132:
1A_PARTICIPANT_ID:
1255:
1A_PARTICIPANT_NAME:
1A_SECURITY_NAME:
1H_FULL_NAME:
1A_RES_ASSIGNMENT_ID:
1A_SECURITY_ID:
1A_TEMP_ID:
1H_CREATED_BY:
1H_PROJECT_ID:
1A_ASSIGNMENT_COUNT:
10:
1A_ELEMENT_TYPE:
1H_RESPONSIBLE:
1A_PARTICIPANT:
1A_RESOURCE_TYPE:
1A_SECURITY_VALUE:
1H_PARTICIPANT:
1H_UPDATE:
1H_TABLE_TYPE:
1H_ASSIGN_STRING:
18192:
1H_TEMP_RES_TYPE:
11:
1H_TEMP_PARTICIPANT:
1H_TEMP_SECURITY_ID:
1H_WBS_SECURITY_ID:
1H_TEMP_BITFLAG:
1H_TEMP_SC_STATE:
1H_TRANSFED_CRI:
1H_CRI_TABLE:
1H_CRI_ELEMENT_TYPE:
1H_REC_USER:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_U_CRI_SECURITY(:
1':
1, :
1COALESCE:
1NULLIF:
1'':
1NULL:
1TO_CHAR:
1);:
1CHECK_TRACE:
160:
1+:
1FPUT:
1               ENTER:: SP_U_CRI_SECURITY(61) :: cplan.sql(16861) :: :
1:
1PMO_CNST:
1SC_TABLE_CRI:
1SC_STATE:
1FC_U_ASSIGNED_SECURITY:
14:
176:
1       RETURN_STATUS:: SP_U_CRI_SECURITY(77) :: cplan.sql(16877) :: :
1 :
1STATE:: :
1 ID:: :
1PMODEFINES:
1PMO_RETURN_STATUS:
1TRUE:
1RETURN_ERROR_EXCEPTION:
116:
183:
1           EXCEPTION:: SP_U_CRI_SECURITY(84) :: cplan.sql(16884) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1ID:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
1OTHERS:
1SQLCODE:
195:
1           EXCEPTION:: SP_U_CRI_SECURITY(96) :: cplan.sql(16896) :: :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
2e4
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
1c 51 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 51 a5 1c 81 b0 a3
:2 a0 6b 1c 81 b0 :2 a0 6b :2 a0
6b 6e a5 b a 10 :2 a0 6b
6e :2 a0 6b 6e a5 b 6e 7e
a0 b4 2e 6e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :2 a0 6e 7e
a0 b4 2e 7e 6e b4 2e 6e
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e :2 a0 6e 7e a0
b4 2e 7e 6e b4 2e 6e a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
:3 a0 a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e :3 a0 a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e :3 a0 a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c a0 6e
d :2 a0 d :2 a0 d :2 a0 d :3 a0
6b d :2 a0 6b :5 a0 a5 b d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b :2 a0 a5 57 b7 :2 a0 6b :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 :2 a0
6b :2 6e 7e :2 a0 6b b4 2e 7e
6e b4 2e 7e :2 a0 6b b4 2e
a5 57 b7 19 3c :9 a0 12a e9
dd :2 a0 65 b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c :7 a0 12a e9 dd :2 a0
65 b7 a4 b1 11 4f b7 a6
9 a4 b1 11 68 4f 1d 17
b5 
2e4
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 5e
5a 30 66 6f 6b 59 77 84
80 56 8c 95 91 7f 9d aa
a6 7c b2 bb b7 a5 c3 a2
c8 cc d0 d4 d7 db f8 e3
e7 ea eb f3 e2 115 103 df
107 108 110 102 132 120 ff 124
125 12d 11f 14f 13d 11c 141 142
14a 13c 16c 15a 139 15e 15f 167
159 189 177 156 17b 17c 184 176
1a6 194 173 198 199 1a1 193 1c3
1b1 190 1b5 1b6 1be 1b0 1e0 1ce
1ad 1d2 1d3 1db 1cd 1fd 1eb 1ca
1ef 1f0 1f8 1ea 219 208 20c 1e7
214 207 235 224 228 204 230 223
251 240 244 220 24c 23f 26d 25c
260 23c 268 25b 289 278 27c 258
284 277 2a5 294 298 274 2a0 293
2c1 2b0 2b4 290 2bc 2af 2dd 2cc
2d0 2ac 2d8 2cb 2f9 2e8 2ec 2c8
2f4 2e7 316 304 2e4 308 309 311
303 333 321 300 325 326 32e 320
34f 33e 342 31d 34a 33d 36c 35a
33a 35e 35f 367 359 389 377 356
37b 37c 384 376 3a5 394 398 373
3a0 393 3c1 3b0 3b4 390 3bc 3af
3dd 3cc 3d0 3ac 3d8 3cb 3f9 3e8
3ec 3c8 3f4 3e7 415 404 408 3e4
410 403 432 420 400 424 425 42d
41f 452 43d 441 41c 445 44d 43c
459 45d 439 461 465 469 46c 471
472 1 474 479 47d 481 484 489
48d 491 494 499 49a 49c 4a1 4a4
4a8 4a9 4ae 4b3 4b6 4bb 4bc 4c1
4c4 4c8 4c9 4ce 4d1 4d6 4d7 4dc
4df 4e4 4e5 4ea 4ed 4f2 4f3 4f8
4fb 4ff 500 505 508 50d 50e 513
516 51b 51c 521 524 528 52c 531
534 538 539 53e 541 546 547 54c
551 552 554 559 55a 55c 55d 562
565 56a 56b 570 573 577 57b 580
583 587 588 58d 590 595 596 59b
5a0 5a1 5a3 5a8 5a9 5ab 5ac 5b1
5b4 5b9 5ba 5bf 5c2 5c6 5ca 5ce
5cf 5d1 5d6 5d7 5d9 5da 5df 5e2
5e7 5e8 5ed 5f0 5f4 5f8 5fc 5fd
5ff 604 605 607 608 60d 610 615
616 61b 61e 622 626 62a 62b 62d
632 633 635 636 63b 63e 643 644
649 64c 650 654 658 659 65b 660
661 663 664 669 66c 671 672 677
67a 67f 680 685 688 68c 68d 692
695 69a 69b 6a0 6a3 6a8 6a9 6ae
6af 6b4 6b6 6ba 6bd 6c1 6c5 6c8
6cc 6d0 6d3 6d6 6db 6de 6e1 6e4
6e5 6ea 6eb 1 6ed 6f2 6f6 6fa
6fd 702 707 70a 70e 70f 714 715
71a 71c 720 723 727 72c 730 734
738 73c 740 744 748 74c 750 754
758 75c 760 763 767 76b 76f 772
776 77a 77e 782 786 787 789 78d
791 795 798 79c 7a0 7a3 7a6 7ab
7ae 7b1 7b4 7b5 7ba 7bb 1 7bd
7c2 7c6 7ca 7cd 7d2 7d7 7da 7de
7df 7e4 7e7 7ec 7ed 7f2 7f5 7fa
7fb 800 803 807 80b 80f 813 816
817 819 81e 81f 821 822 827 82a
82f 830 835 838 83d 83e 843 846
84a 84b 850 853 858 859 85e 85f
864 866 86a 86d 871 875 878 87c
880 883 887 88b 88c 891 893 897
89b 89e 8a2 8a6 8a9 8ad 8b1 8b4
8b7 8bc 8bf 8c2 8c5 8c6 8cb 8cc
1 8ce 8d3 8d7 8db 8de 8e3 8e8
8eb 8ef 8f0 8f5 8f6 8fb 8ff 903
906 90b 910 913 917 91b 91e 91f
924 927 92c 92d 932 935 939 93d
940 941 946 947 94c 94e 952 955
959 95d 961 965 969 96d 971 975
979 985 98a 98e 992 996 99a 99c
99d 9a2 1 9a6 9aa 9ae 9b1 9b5
9b9 9bd 9c1 9c4 9c8 9cc 9cf 9d2
9d7 9da 9dd 9e0 9e1 9e6 9e7 1
9e9 9ee 9f2 9f6 9f9 9fe a03 a06
a0a a0b a10 a11 a16 a1a a1e a21
a26 a2b a2e a32 a33 a38 a3b a40
a41 a46 a49 a4d a51 a54 a57 a58
a5a a5b a60 a61 a66 a68 a6c a6f
a73 a77 a7b a7f a83 a87 a8b a97
a9c aa0 aa4 aa8 aac aae ab2 ab4
ac0 ac2 ac4 ac5 aca ace ad0 adc
ae0 ae2 ae3 aec 
2e4
2
0 1 a 6 10 :3 6 15 :3 6
16 :3 6 17 :3 6 e :3 6 e :3 6
15 :3 6 f :3 6 10 :2 6 1 3
a 13 a :2 1 4 11 1a 19
:2 11 :2 4 15 1e 1d :2 15 :2 4 17
20 1f :2 17 :2 4 14 1d 1c :2 14
:2 4 10 19 18 :2 10 :2 4 18 21
20 :2 18 :2 4 12 1b 1a :2 12 :2 4
e 17 16 :2 e :2 4 11 1a 19
:2 11 :2 4 11 1a 19 :2 11 :2 4 :2 17
26 17 :2 4 :2 13 22 13 :2 4 :2 12
21 12 :2 4 :2 12 21 12 :2 4 :2 14
23 14 :2 4 :2 15 24 15 :2 4 :2 12
21 12 :2 4 :2 d 1c d :2 4 :2 11
20 11 :2 4 14 1d 1c :2 14 :2 4
14 1d 1c :2 14 :2 4 :2 17 26 17
:2 4 17 20 1f :2 17 :2 4 16 1f
1e :2 16 :2 4 :2 13 22 13 :2 4 :2 14
23 14 :2 4 :2 13 22 13 :2 4 :2 10
1f 10 :2 4 :2 17 26 17 :2 4 f
18 17 :2 f :2 4 e 17 :3 e 4
7 :2 11 23 :2 2d 3a :2 23 :3 7 :2 d
19 25 :2 2f 43 :2 25 59 5f 62
:2 59 70 8b 8 :2 70 d 10 :2 70
1a 1d :2 70 b e :2 70 13 16
:2 70 1b 1e :2 70 2d 30 :2 70 b
e :2 70 13 16 1f 26 2b 2e
:2 26 3e 41 :2 26 46 :2 1f 4f :2 16
:2 70 b e :2 70 13 16 1f 26
2b 2e :2 26 3f 42 :2 26 47 :2 1f
50 :2 16 :2 70 b e :2 70 13 16
1f 27 :2 1f 31 :2 16 :2 70 b e
:2 70 13 16 1f 27 :2 1f 31 :2 16
:2 70 b e :2 70 13 16 1f 27
:2 1f 38 :2 16 :2 70 b e :2 70 13
16 1f 27 :2 1f 32 :2 16 :2 70 b
e :2 70 13 16 :2 70 1b 1e :2 70
28 2b :2 70 30 33 :2 70 :2 7 4f
:2 4 7 :2 11 23 :2 2d 39 3c 51
53 54 :2 51 :2 23 :3 7 :2 d 12 1e
62 65 :2 1e :2 7 57 :3 4 14 :2 4
11 :2 4 15 :2 4 12 :2 4 14 :2 1d
:2 4 :2 d 19 30 3e 49 58 :2 19
4 7 :2 11 23 :2 2d 39 3c 51
53 54 :2 51 :2 23 :3 7 :2 d 12 1e
62 65 :2 1e 72 75 :2 1e 79 7c
:2 1e 86 89 92 9a :2 a3 :2 92 ae
:2 89 :2 1e b6 b9 :2 1e c1 c4 :2 1e
c9 cc :2 1e d6 d9 :2 1e :2 7 57
:3 4 :2 f 21 :2 2a 34 3f :2 4 1
9 12 9 a :2 14 26 :2 30 3c
40 55 57 58 :2 55 :2 26 :3 a :2 10
15 21 65 68 :2 21 :3 a :2 10 15
39 5c 5f :2 68 :2 39 76 79 :2 39
81 84 :2 8d :2 39 :2 a 5b :3 7 c
15 1e 2c a 13 1e f e
7 e 7 e 7 29 :2 4 :2 9
7 :2 10 1c :2 7 :2 11 23 :2 2d 39
3d 52 54 55 :2 52 :2 23 :3 7 :2 d
12 1e 62 65 :2 1e :3 7 :2 d 12
36 42 45 :2 36 4d 50 :2 36 5c
5f 66 6f 72 :2 5f :2 36 :2 7 58
:2 4 7 c 1b a 13 1e f
e 7 e 7 e 7 :2 4 :4 10
:2 4 :8 1 
2e4
4
0 :2 1 :4 3 :4 4
:4 5 :4 6 :4 7 :4 8
:4 9 :4 a :4 b 2
:4 c :2 1 :7 e :7 f
:7 10 :7 11 :7 12 :7 13
:7 14 :7 15 :7 16 :7 17
:6 18 :6 19 :6 1a :6 1b
:6 1c :6 1d :6 1e :6 1f
:6 20 :7 21 :7 22 :6 23
:7 24 :7 25 :6 26 :6 27
:6 28 :6 29 :6 2a :7 2b
:7 2d :b 2f :11 30 31
:2 30 :2 31 :2 30 :2 31
:2 30 :2 32 :2 30 :2 32
:2 30 :2 32 :2 30 :2 32
:2 30 :2 33 :2 30 :12 33
:2 30 :2 34 :2 30 :12 34
:2 30 :2 35 :2 30 :9 35
:2 30 :2 36 :2 30 :9 36
:2 30 :2 37 :2 30 :9 37
:2 30 :2 38 :2 30 :9 38
:2 30 :2 39 :2 30 :2 39
:2 30 :2 39 :2 30 :2 39
:2 30 :2 39 :4 30 :3 2f
:11 3c :b 3d :3 3c :3 42
:3 45 :3 46 :3 47 :5 49
:b 4a :11 4c :30 4d :3 4c
:a 4f 2e :3 52 :11 53
:b 54 :17 55 :3 53 :2 57
:3 58 :3 59 5a 58
57 58 :3 5b :3 52
:2 5c :5 5e :11 5f :b 60
:18 61 :3 5f :2 63 64
:3 65 66 64 63
64 :3 67 :2 5d :6 5c
51 :7 1 
aee
4
:3 0 1 :3 0 2
:a 0 2df 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
56 0 7 4
:3 0 5 :7 0 9
8 :3 0 7 :3 0
6 :7 0 d c
:3 0 d 7c 0
b 7 :3 0 8
:7 0 11 10 :3 0
a :3 0 9 :7 0
15 14 :3 0 11
a2 0 f a
:3 0 b :7 0 19
18 :3 0 a :3 0
c :7 0 1d 1c
:3 0 15 :2 0 13
a :3 0 d :7 0
21 20 :3 0 4
:3 0 e :7 0 25
24 :3 0 f :3 0
10 :3 0 11 :2 0
4 29 2a 0
27 2b 0 2df
2 2c :2 0 15
:2 0 21 4 :3 0
13 :2 0 1f 2f
31 :6 0 34 32
0 2dd 0 12
:6 0 15 :2 0 25
4 :3 0 23 36
38 :6 0 3b 39
0 2dd 0 14
:6 0 13 :2 0 29
4 :3 0 27 3d
3f :6 0 42 40
0 2dd 0 16
:6 0 15 :2 0 2d
4 :3 0 2b 44
46 :6 0 49 47
0 2dd 0 17
:6 0 13 :2 0 31
4 :3 0 2f 4b
4d :6 0 50 4e
0 2dd 0 18
:6 0 13 :2 0 35
4 :3 0 33 52
54 :6 0 57 55
0 2dd 0 19
:6 0 13 :2 0 39
4 :3 0 37 59
5b :6 0 5e 5c
0 2dd 0 1a
:6 0 13 :2 0 3d
4 :3 0 3b 60
62 :6 0 65 63
0 2dd 0 1b
:6 0 13 :2 0 41
4 :3 0 3f 67
69 :6 0 6c 6a
0 2dd 0 1c
:6 0 1f :2 0 45
4 :3 0 43 6e
70 :6 0 73 71
0 2dd 0 1d
:6 0 1f :2 0 47
a :3 0 75 :7 0
79 76 77 2dd
0 1e :6 0 1f
:2 0 49 a :3 0
7b :7 0 7f 7c
7d 2dd 0 20
:6 0 1f :2 0 4b
a :3 0 81 :7 0
85 82 83 2dd
0 21 :6 0 1f
:2 0 4d a :3 0
87 :7 0 8b 88
89 2dd 0 22
:6 0 1f :2 0 4f
a :3 0 8d :7 0
91 8e 8f 2dd
0 23 :6 0 1f
:2 0 51 a :3 0
93 :7 0 97 94
95 2dd 0 24
:6 0 1f :2 0 53
a :3 0 99 :7 0
9d 9a 9b 2dd
0 25 :6 0 1f
:2 0 55 a :3 0
9f :7 0 a3 a0
a1 2dd 0 26
:6 0 29 :2 0 57
a :3 0 a5 :7 0
a9 a6 a7 2dd
0 27 :6 0 2b
:2 0 5b 4 :3 0
59 ab ad :6 0
b0 ae 0 2dd
0 28 :6 0 1f
:2 0 5f 4 :3 0
5d b2 b4 :6 0
b7 b5 0 2dd
0 2a :6 0 13
:2 0 61 a :3 0
b9 :7 0 bd ba
bb 2dd 0 2c
:6 0 13 :2 0 65
4 :3 0 63 bf
c1 :6 0 c4 c2
0 2dd 0 2d
:6 0 1f :2 0 69
4 :3 0 67 c6
c8 :6 0 cb c9
0 2dd 0 2e
:6 0 1f :2 0 6b
a :3 0 cd :7 0
d1 ce cf 2dd
0 2f :6 0 1f
:2 0 6d a :3 0
d3 :7 0 d7 d4
d5 2dd 0 30
:6 0 1f :2 0 6f
a :3 0 d9 :7 0
dd da db 2dd
0 31 :6 0 1f
:2 0 71 a :3 0
df :7 0 e3 e0
e1 2dd 0 32
:6 0 13 :2 0 73
a :3 0 e5 :7 0
e9 e6 e7 2dd
0 33 :6 0 f2
f3 0 77 4
:3 0 75 eb ed
:6 0 f0 ee 0
2dd 0 34 :6 0
f8 f9 0 79
10 :3 0 11 :2 0
4 f4 :7 0 f7
f5 0 2dd 0
35 :6 0 36 :3 0
37 :3 0 36 :3 0
38 :3 0 fb fc
0 2 :4 0 7b
fd ff fa 101
100 :2 0 39 :3 0
3a :3 0 103 104
0 3b :4 0 36
:3 0 3c :3 0 107
108 0 2 :4 0
7d 109 10b 3d
:4 0 3e :2 0 3f
:3 0 7f 10e 110
:3 0 40 :4 0 3e
:2 0 41 :4 0 82
113 115 :3 0 3e
:2 0 3 :3 0 85
117 119 :3 0 3e
:2 0 41 :4 0 88
11b 11d :3 0 3e
:2 0 42 :4 0 8b
11f 121 :3 0 3e
:2 0 41 :4 0 8e
123 125 :3 0 3e
:2 0 5 :3 0 91
127 129 :3 0 3e
:2 0 41 :4 0 94
12b 12d :3 0 3e
:2 0 42 :4 0 97
12f 131 :3 0 3e
:2 0 43 :3 0 44
:3 0 41 :4 0 3e
:2 0 6 :3 0 9a
137 139 :3 0 3e
:2 0 41 :4 0 9d
13b 13d :3 0 45
:4 0 a0 135 140
46 :4 0 a3 134
143 a6 133 145
:3 0 3e :2 0 42
:4 0 a9 147 149
:3 0 3e :2 0 43
:3 0 44 :3 0 41
:4 0 3e :2 0 8
:3 0 ac 14f 151
:3 0 3e :2 0 41
:4 0 af 153 155
:3 0 45 :4 0 b2
14d 158 46 :4 0
b5 14c 15b b8
14b 15d :3 0 3e
:2 0 42 :4 0 bb
15f 161 :3 0 3e
:2 0 43 :3 0 47
:3 0 9 :3 0 be
165 167 46 :4 0
c0 164 16a c3
163 16c :3 0 3e
:2 0 42 :4 0 c6
16e 170 :3 0 3e
:2 0 43 :3 0 47
:3 0 b :3 0 c9
174 176 46 :4 0
cb 173 179 ce
172 17b :3 0 3e
:2 0 42 :4 0 d1
17d 17f :3 0 3e
:2 0 43 :3 0 47
:3 0 c :3 0 d4
183 185 46 :4 0
d6 182 188 d9
181 18a :3 0 3e
:2 0 42 :4 0 dc
18c 18e :3 0 3e
:2 0 43 :3 0 47
:3 0 d :3 0 df
192 194 46 :4 0
e1 191 197 e4
190 199 :3 0 3e
:2 0 42 :4 0 e7
19b 19d :3 0 3e
:2 0 41 :4 0 ea
19f 1a1 :3 0 3e
:2 0 e :3 0 ed
1a3 1a5 :3 0 3e
:2 0 41 :4 0 f0
1a7 1a9 :3 0 3e
:2 0 48 :4 0 f3
1ab 1ad :3 0 f6
105 1af :2 0 1b1
fb 1b2 102 1b1
0 1b3 fd 0
23d 36 :3 0 37
:3 0 1b4 1b5 0
36 :3 0 49 :3 0
1b7 1b8 0 2b
:2 0 2 :4 0 4a
:2 0 4b :2 0 2b
:2 0 ff 1bd 1bf
:3 0 102 1b9 1c1
1b6 1c3 1c2 :2 0
39 :3 0 4c :3 0
1c5 1c6 0 3b
:4 0 4d :4 0 3e
:2 0 3f :3 0 106
1ca 1cc :3 0 109
1c7 1ce :2 0 1d0
10c 1d1 1c4 1d0
0 1d2 10e 0
23d 1c :3 0 4e
:4 0 1d3 1d4 0
23d 1b :3 0 3
:3 0 1d6 1d7 0
23d 1a :3 0 5
:3 0 1d9 1da 0
23d 34 :3 0 e
:3 0 1dc 1dd 0
23d 27 :3 0 4f
:3 0 50 :3 0 1e0
1e1 0 1df 1e2
0 23d 10 :3 0
51 :3 0 1e4 1e5
0 52 :3 0 27
:3 0 1b :3 0 1a
:3 0 34 :3 0 110
1e7 1ec 1e6 1ed
0 23d 36 :3 0
37 :3 0 1ef 1f0
0 36 :3 0 49
:3 0 1f2 1f3 0
53 :2 0 2 :4 0
54 :2 0 4b :2 0
2b :2 0 115 1f8
1fa :3 0 118 1f4
1fc 1f1 1fe 1fd
:2 0 39 :3 0 4c
:3 0 200 201 0
3b :4 0 55 :4 0
3e :2 0 3f :3 0
11c 205 207 :3 0
3e :2 0 56 :4 0
11f 209 20b :3 0
3e :2 0 57 :4 0
122 20d 20f :3 0
3e :2 0 43 :3 0
47 :3 0 10 :3 0
51 :3 0 214 215
0 125 213 217
46 :4 0 127 212
21a 12a 211 21c
:3 0 3e :2 0 58
:4 0 12d 21e 220
:3 0 3e :2 0 41
:4 0 130 222 224
:3 0 3e :2 0 1b
:3 0 133 226 228
:3 0 3e :2 0 41
:4 0 136 22a 22c
:3 0 139 202 22e
:2 0 230 13c 231
1ff 230 0 232
13e 0 23d 59
:3 0 5a :3 0 233
234 0 10 :3 0
51 :3 0 236 237
0 1b :3 0 5b
:3 0 140 235 23b
:2 0 23d 144 2de
10 :3 0 5c :2 0
4 23e 23f 0
36 :3 0 37 :3 0
241 242 0 36
:3 0 49 :3 0 244
245 0 5d :2 0
2 :4 0 5e :2 0
4b :2 0 2b :2 0
14f 24a 24c :3 0
152 246 24e 243
250 24f :2 0 39
:3 0 4c :3 0 252
253 0 3b :4 0
5f :4 0 3e :2 0
3f :3 0 156 257
259 :3 0 159 254
25b :2 0 274 39
:3 0 4c :3 0 25d
25e 0 3b :4 0
60 :4 0 3e :2 0
10 :3 0 61 :3 0
263 264 0 15c
262 266 :3 0 3e
:2 0 58 :4 0 15f
268 26a :3 0 3e
:2 0 10 :3 0 62
:3 0 26d 26e 0
162 26c 270 :3 0
165 25f 272 :2 0
274 168 275 251
274 0 276 16b
0 286 63 :3 0
35 :3 0 10 :3 0
61 :3 0 64 :3 0
10 :3 0 62 :3 0
65 :3 0 66 :4 0
67 1 :a 0 282
:2 0 286 278 280
:2 0 f :3 0 35
:3 0 284 :2 0 286
16d 288 171 287
286 :2 0 2dc 68
:3 0 10 :3 0 51
:3 0 28b 28c 0
69 :3 0 28d 28e
0 2d4 36 :3 0
37 :3 0 290 291
0 36 :3 0 49
:3 0 293 294 0
5d :2 0 2 :4 0
6a :2 0 4b :2 0
2b :2 0 173 299
29b :3 0 176 295
29d 292 29f 29e
:2 0 39 :3 0 4c
:3 0 2a1 2a2 0
3b :4 0 6b :4 0
3e :2 0 3f :3 0
17a 2a6 2a8 :3 0
17d 2a3 2aa :2 0
2c4 39 :3 0 4c
:3 0 2ac 2ad 0
3b :4 0 6c :4 0
3e :2 0 69 :3 0
180 2b1 2b3 :3 0
3e :2 0 6d :4 0
183 2b5 2b7 :3 0
3e :2 0 6e :3 0
6f :3 0 2b :2 0
70 :2 0 186 2ba
2be 18a 2b9 2c0
:3 0 18d 2ae 2c2
:2 0 2c4 190 2c5
2a0 2c4 0 2c6
193 0 2d4 63
:3 0 35 :3 0 64
:3 0 10 :3 0 62
:3 0 65 :3 0 66
:4 0 71 1 :a 0
2d0 :2 0 2d4 2c8
2ce :2 0 f :3 0
35 :3 0 2d2 :2 0
2d4 195 2d7 :3 0
2d7 0 2d7 2d6
2d4 2d5 :6 0 2d9
1 :3 0 19a 2db
19c 2da 2d9 :2 0
2dc 19e :2 0 2de
1a1 2de 2dd 23d
2dc :6 0 2df :2 0
2 2c 2de 2e2
:3 0 2e1 2df 2e3
:8 0 
1c1
4
:3 0 1 3 1
7 1 b 1
f 1 13 1
17 1 1b 1
1f 1 23 9
6 a e 12
16 1a 1e 22
26 1 30 1
2e 1 37 1
35 1 3e 1
3c 1 45 1
43 1 4c 1
4a 1 53 1
51 1 5a 1
58 1 61 1
5f 1 68 1
66 1 6f 1
6d 1 74 1
7a 1 80 1
86 1 8c 1
92 1 98 1
9e 1 a4 1
ac 1 aa 1
b3 1 b1 1
b8 1 c0 1
be 1 c7 1
c5 1 cc 1
d2 1 d8 1
de 1 e4 1
ec 1 ea 1
f1 1 fe 1
10a 2 10d 10f
2 112 114 2
116 118 2 11a
11c 2 11e 120
2 122 124 2
126 128 2 12a
12c 2 12e 130
2 136 138 2
13a 13c 2 13e
13f 2 141 142
2 132 144 2
146 148 2 14e
150 2 152 154
2 156 157 2
159 15a 2 14a
15c 2 15e 160
1 166 2 168
169 2 162 16b
2 16d 16f 1
175 2 177 178
2 171 17a 2
17c 17e 1 184
2 186 187 2
180 189 2 18b
18d 1 193 2
195 196 2 18f
198 2 19a 19c
2 19e 1a0 2
1a2 1a4 2 1a6
1a8 2 1aa 1ac
4 106 10c 111
1ae 1 1b0 1
1b2 2 1bc 1be
3 1ba 1bb 1c0
2 1c9 1cb 2
1c8 1cd 1 1cf
1 1d1 4 1e8
1e9 1ea 1eb 2
1f7 1f9 3 1f5
1f6 1fb 2 204
206 2 208 20a
2 20c 20e 1
216 2 218 219
2 210 21b 2
21d 21f 2 221
223 2 225 227
2 229 22b 2
203 22d 1 22f
1 231 3 238
239 23a a 1b3
1d2 1d5 1d8 1db
1de 1e3 1ee 232
23c 2 249 24b
3 247 248 24d
2 256 258 2
255 25a 2 261
265 2 267 269
2 26b 26f 2
260 271 2 25c
273 1 275 3
276 281 285 1
240 2 298 29a
3 296 297 29c
2 2a5 2a7 2
2a4 2a9 2 2b0
2b2 2 2b4 2b6
3 2bb 2bc 2bd
2 2b8 2bf 2
2af 2c1 2 2ab
2c3 1 2c5 4
28f 2c6 2cf 2d3
1 2d7 1 28a
2 288 2db 1f
33 3a 41 48
4f 56 5d 64
6b 72 78 7e
84 8a 90 96
9c a2 a8 af
b6 bc c3 ca
d0 d6 dc e2
e8 ef f6 
1
4
0 
2e2
0
1
14
2
29
0 1 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 
3c 1 0
b8 1 0
80 1 0
f 1 0
92 1 0
be 1 0
13 1 0
23 1 0
7 1 0
b1 1 0
9e 1 0
35 1 0
98 1 0
d2 1 0
c5 1 0
e4 1 0
5f 1 0
8c 1 0
d8 1 0
51 1 0
66 1 0
cc 1 0
7a 1 0
2e 1 0
3 1 0
86 1 0
de 1 0
2 0 1
a4 1 0
6d 1 0
b 1 0
58 1 0
17 1 0
74 1 0
1b 1 0
1f 1 0
4a 1 0
ea 1 0
aa 1 0
43 1 0
f1 1 0
0

/
SHOW ERRORS FUNCTION SP_U_CRI_SECURITY;
ALTER FUNCTION SP_U_CRI_SECURITY COMPILE DEBUG;
/****************************************************************************************
 id = TSK_ASSIGN_ID
 bitflag:
        1 = Copy Schedule to Baseline (includes budgets)
        2 = Copy Planned to Schedule
        3 = Copy Proposed to Schedule
        4 = Copy Forecast to Schedule (includes budgets)
        5 = Copy Forecast  Scheduled to Planned
        6 = Move Planned to Schedule
        7 = Append Planned to Schedule
 bussiness rules:
    1. Do not copy date for completed tasks (MILESTONE_PERCENT = 100)
    2. If the task has ACTUAL do not change ETC, WORK_TODATE, SD, FD
    3. When copy Forecast Date to ..., ETC is Forecast Effort, and clear Forcast dates after copy
    4. If both Forcast dates exists ignor forcast start, consider only forcast finish and ETC
    5. Calculated Forecast Start should not be in the past (is >= NOW)
    6. When copy Forcast to and assignments exists forcast rollup wins, and clear Forcast dates after copy
    7. Actual Finish date does not rollup from Assignments to Task
    8. When copy Planned to Schedule clear Planned Dates, Duration  Effort
****************************************************************************************/
Prompt == FUNCTION SP_COMMIT_ASSIGN ==
CREATE OR REPLACE FUNCTION SP_COMMIT_ASSIGN wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
192
2 :e:
1FUNCTION:
1SP_COMMIT_ASSIGN:
1ID001:
1VARCHAR2:
1BITFLAG001:
1PLS_INTEGER:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_BITID:
1RAW:
136:
1PMO_CNST:
1SC_ZERO_BIT:
1H_BITID1:
1H_PROJECT_ID:
132:
1H_DAYOFYEAR:
1DATE:
1H_RES_ID:
1H_TASK_ID:
1H_ID:
1H_TSK_ASSIGNMENT_ID:
1H_PRJ_ASSIGNMENT_ID:
1H_START_DATE:
1TIMESTAMP:
1H_FINISH_DATE:
1H_SCHED_WORK:
10:
1H_BILLABLE:
1H_TOTAL:
1H_DAY_MIN:
1H_BITFLAG:
1H_MIN_PER_DAY:
1H_CHANGE_FLAG:
1H_TYPE_ID:
1H_FROM_PRJ:
1H_TSK_PRJ:
1H_WORK:
1H_TEMP_VAR:
1H_TEMP_SC_STATE:
1H_REG_COST:
1NUMBER:
10.00:
1H_REG_SALE:
1STMT:
17999:
1CURSOR:
1C270:
1TA:
1TSK_ASSIGNMENT_ID:
1RESOURCE_ID:
1TASK_ASSIGNMENTS:
1JOIN:
1TMT_WBS:
1W:
1PROJECT_ID:
1ELEMENT_ID:
1TASK_ID:
1BIT_FLAG:
1RESOURCE_TYPE:
1PROJECT_ASSIGNMENT_ID:
1SELECT TA.TSK_ASSIGNMENT_ID, TA.RESOURCE_ID:n         FROM TASK_ASSIGNMENTS T+
1A JOIN TMT_WBS W:n         ON W.PROJECT_ID = TA.PROJECT_ID AND W.ELEMENT_ID =+
1 TA.TASK_ID:n         WHERE W.PROJECT_ID = h_project_id AND TA.BIT_FLAG = '0'+
1:n         AND TA.RESOURCE_TYPE = '0' AND TA.PROJECT_ASSIGNMENT_ID IS Null:
1CMM1:
1C27:
1DAY_YEAR:
1SCHED_MIN:
1BIT_SCHED:
1TASK_DAY_OF_YEAR:
1SELECT DAY_YEAR, SCHED_MIN, BIT_SCHED FROM TASK_DAY_OF_YEAR:n         WHERE P+
1ROJECT_ID = h_project_id AND TSK_ASSIGNMENT_ID = h_id AND BIT_FLAG = '0':
1C54:
1SELECT TASK_ID, TSK_ASSIGNMENT_ID:n         FROM TASK_ASSIGNMENTS:n         W+
1HERE BIT_FLAG = '0' AND PROJECT_ASSIGNMENT_ID = h_id:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_COMMIT_ASSIGN(:
1':
1, :
1COALESCE:
1TO_CHAR:
1NULL:
1);:
1CHECK_TRACE:
11:
162:
1+:
1FPUT:
1               ENTER:: SP_COMMIT_ASSIGN(63) :: cplan.sql(16996) :: :
1MINUTE_PER_DAY:
1SELECT COALESCE(MINUTE_PER_DAY, 480) INTO h_min_per_day FROM TMT_WBS WHERE EL+
1EMENT_ID = h_id:
1SC_STATE:
1SQLCODE:
1OTHERS:
116:
179:
1           EXCEPTION:: SP_COMMIT_ASSIGN(80) :: cplan.sql(17013) :: :
1 :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1=:
1SC_SQL_NO_DATA:
1MILESTONE_PERCENT:
1SELECT PROJECT_ID, CASE WHEN PROJECT_ID = TASK_ID THEN 1 ELSE 0 END, CASE WHE+
1N PROJECT_ASSIGNMENT_ID IS NuLL THEN 0 ELSE 1 END:n         INTO h_project_id+
1,h_tsk_prj,h_from_prj:n         FROM TASK_ASSIGNMENTS WHERE MILESTONE_PERCENT+
1 < 10000 AND RESOURCE_TYPE='0' AND TSK_ASSIGNMENT_ID = h_id:
196:
1           EXCEPTION:: SP_COMMIT_ASSIGN(97) :: cplan.sql(17030) :: :
18:
1103:
1      RETURN_INVALID:: SP_COMMIT_ASSIGN(104) :: cplan.sql(17037) :: :
1STATE:: :
1RECORD_NOT_FOUND:
1106:
1                EXIT:: SP_COMMIT_ASSIGN(107) :: cplan.sql(17040) :: :
1PMODEFINES:
1PMO_RETURN_INVALID_SP:
1TRUE:
1ELSIF:
1111:
1        RETURN_ERROR:: SP_COMMIT_ASSIGN(112) :: cplan.sql(17045) :: :
1PROJECT_ASSIGNMENT_EXISTS:
1 ID:: :
1114:
1                EXIT:: SP_COMMIT_ASSIGN(115) :: cplan.sql(17048) :: :
1PMO_RETURN_ERROR_SP:
1SELECT COALESCE(MINUTE_PER_DAY, 480) INTO h_min_per_day FROM TMT_WBS WHERE EL+
1EMENT_ID = h_project_id:
1127:
1           EXCEPTION:: SP_COMMIT_ASSIGN(128) :: cplan.sql(17061) :: :
1SELECT TSK_ASSIGNMENT_ID, RESOURCE_ID, TASK_ID, C_EFFORT FROM TASK_ASSIGNMENT+
1S :
1WHERE TSK_ASSIGNMENT_ID = ':
1' AND MILESTONE_PERCENT < 10000 AND RESOURCE_TYPE='0' AND BIT_FLAG = '0' :
13:
1TYPE_ID:
1SC_PROPOSAL:
1SC_PROJECT:
1SCHED_START:
1PLANNED_START:
1SCHED_FINISH:
1PLANNED_FINISH:
1SCHED_DURATION:
1PLANNED_DURATION:
1SCHED_EFFORT:
1PLANNED_EFFORT:
1FORECAST_START:
1FORECAST_FINISH:
1FORECAST_EFFORT:
1ETC:
1FORECAST_DURATION:
1SC_TASK:
1SC_TASK_TYPE1:
1SC_TASK_TYPE2:
1SC_TASK_TYPE3:
1SC_MILESTONE:
1SC_PERSONAL_TASK:
1SC_ACTIVE_ADM_TASK:
1SC_INACTIVE_ADM_TASK:
1SC_WBS_CHANGE_REQUEST_TASK:
1SC_WBS_ACTION_ITEM_TASK:
1SC_WBS_RISK_TASK:
1SC_WBS_ISSUE_TASK:
1SC_WBS_REQUIREMENT_TASK:
1SC_WBS_DEFECT_TASK:
1SC_WBS_SERVICE_REQUEST_TASK:
1ASSIGN_COUNT:
1WORK_TODATE:
1UPDATE TMT_WBS SET:n            TYPE_ID         = CASE WHEN TYPE_ID = PMO_CNS+
1T.SC_PROPOSAL THEN PMO_CNST.SC_PROJECT ELSE TYPE_ID END,:n            SCHED_S+
1TART     = COALESCE(PLANNED_START, SCHED_START),:n            SCHED_FINISH   +
1 = COALESCE(PLANNED_FINISH, SCHED_FINISH),:n            SCHED_DURATION  = CAS+
1E WHEN PLANNED_DURATION = 0 THEN SCHED_DURATION ELSE PLANNED_DURATION END,:n +
1           SCHED_EFFORT    = PLANNED_EFFORT,:n            PLANNED_START   = N+
1ull,:n            PLANNED_FINISH  = Null,:n            PLANNED_DURATION = 0,+
1:n            FORECAST_START  = Null,:n            FORECAST_FINISH = Null,:n +
1           FORECAST_EFFORT = PLANNED_EFFORT,:n            ETC             = P+
1LANNED_EFFORT,:n            FORECAST_DURATION = 0:n            WHERE PROJECT_+
1ID = h_project_id AND TYPE_ID IN (PMO_CNST.SC_TASK,PMO_CNST.SC_TASK_TYPE1,PMO+
1_CNST.SC_TASK_TYPE2,PMO_CNST.SC_TASK_TYPE3,PMO_CNST.SC_MILESTONE,PMO_CNST.SC_+
1PERSONAL_TASK,PMO_CNST.SC_ACTIVE_ADM_TASK,PMO_CNST.SC_INACTIVE_ADM_TASK,PMO_C+
1NST.SC_WBS_CHANGE_REQUEST_TASK,PMO_CNST.SC_WBS_ACTION_ITEM_TASK,PMO_CNST.SC_W+
1BS_RISK_TASK,PMO_CNST.SC_WBS_ISSUE_TASK,PMO_CNST.SC_WBS_REQUIREMENT_TASK,PMO_+
1CNST.SC_WBS_DEFECT_TASK,PMO_CNST.SC_WBS_SERVICE_REQUEST_TASK) AND ASSIGN_COUN+
1T = 0 AND WORK_TODATE = 0 AND SCHED_EFFORT = 0:
1FOUND:
1100:
1167:
1           EXCEPTION:: SP_COMMIT_ASSIGN(168) :: cplan.sql(17101) :: :
1OPEN:
1LOOP:
1!=:
1SC_SQL_SUCCESS:
1EXIT:
1SCHED_WORK:
1PLANNED_WORK:
1BAK_START_DT:
1BAK_FINISH_DT:
1BAK_WORK:
1SCHED_LABOR_COST:
1PLANNED_LABOR_COST:
1SCHED_LABOR_REVENUE:
1PLANNED_LABOR_REVENUE:
1FORECAST_LABOR_COST:
1BILLABLE:
1REGULAR_COST:
1ACTUAL_LABOR_COST:
1FORECAST_LABOR_REVENUE:
1REGULAR_RATE:
1ACTUAL_LABOR_REVENUE:
1UPDATE TASK_ASSIGNMENTS SET:n               BIT_FLAG = '2',:n               S+
1CHED_START = COALESCE(PLANNED_START, SCHED_START),:n               SCHED_FINI+
1SH = COALESCE(PLANNED_FINISH, SCHED_FINISH),:n               SCHED_DURATION =+
1 CASE WHEN PLANNED_DURATION > 0 THEN PLANNED_DURATION ELSE SCHED_DURATION END+
1,:n               SCHED_WORK = PLANNED_WORK,:n               ETC = PLANNED_WO+
1RK,:n               BAK_START_DT = COALESCE(PLANNED_START, SCHED_START),:n   +
1            BAK_FINISH_DT = COALESCE(PLANNED_FINISH, SCHED_FINISH),:n        +
1       BAK_WORK = PLANNED_WORK,:n               SCHED_LABOR_COST = CASE WHEN +
1PLANNED_LABOR_COST > 0.00 THEN PLANNED_LABOR_COST ELSE SCHED_LABOR_COST END,+
1:n               SCHED_LABOR_REVENUE = CASE WHEN PLANNED_LABOR_REVENUE > 0.00+
1 THEN PLANNED_LABOR_REVENUE ELSE SCHED_LABOR_REVENUE END,:n               FOR+
1ECAST_LABOR_COST = CASE WHEN BILLABLE = 0 THEN 0.00 ELSE ((ETC+PLANNED_WORK/6+
10.00) * REGULAR_COST) + ACTUAL_LABOR_COST END,:n               FORECAST_LABOR+
1_REVENUE = CASE WHEN BILLABLE = 0 THEN 0.00 ELSE ((ETC+PLANNED_WORK/60.00) * +
1REGULAR_RATE) + ACTUAL_LABOR_REVENUE END,:n               PLANNED_START = Nul+
1l, PLANNED_FINISH = Null, PLANNED_DURATION = 0, PLANNED_WORK = 0,:n          +
1     FORECAST_START = Null, FORECAST_FINISH = Null, FORECAST_DURATION = 0:n  +
1             WHERE TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
1213:
1           EXCEPTION:: SP_COMMIT_ASSIGN(214) :: cplan.sql(17147) :: :
1UPDATE TASK_DAY_OF_YEAR SET BIT_FLAG = '2':n               WHERE PROJECT_ID =+
1 h_project_id AND TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
1231:
1           EXCEPTION:: SP_COMMIT_ASSIGN(232) :: cplan.sql(17165) :: :
1CLOSE:
1246:
1           EXCEPTION:: SP_COMMIT_ASSIGN(247) :: cplan.sql(17180) :: :
1ROLLUP_BITS:
1SC_ASSIGNMENT_BIT:
1UPDATE TMT_WBS SET ROLLUP_BITS = PMO_CNST.SC_ASSIGNMENT_BIT:n         WHERE P+
1ROJECT_ID = h_project_id AND ASSIGN_COUNT > 0 AND WORK_TODATE = 0 AND SCHED_E+
1FFORT = 0:
1265:
1           EXCEPTION:: SP_COMMIT_ASSIGN(266) :: cplan.sql(17199) :: :
12:
1SELECT TSK_ASSIGNMENT_ID, RESOURCE_ID, TASK_ID, C_EFFORT FROM TASK_ASSIGNMENT+
1S WHERE PROJECT_ID = TASK_ID AND :
1PROJECT_ID = ':
1BUDGETS:
1B:
1ESTIMATED_BASELINE3:
1ESTIMATED_BASELINE2:
1ESTIMATED_BASELINE1:
1ESTIMATED_BUDGET:
1BUDGET_BASELINE3:
1BUDGET_BASELINE2:
1BUDGET_BASELINE1:
1BUDGET:
1UPDATE BUDGETS B SET:n               B.ESTIMATED_BASELINE3 = B.ESTIMATED_BASE+
1LINE2,:n               B.ESTIMATED_BASELINE2 = B.ESTIMATED_BASELINE1,:n      +
1         B.ESTIMATED_BASELINE1 = B.ESTIMATED_BUDGET,:n               B.BUDGET+
1_BASELINE3 = B.BUDGET_BASELINE2,:n               B.BUDGET_BASELINE2 = B.BUDGE+
1T_BASELINE1,:n               B.BUDGET_BASELINE1 = B.BUDGET:n               WH+
1ERE PROJECT_ID = h_project_id AND ELEMENT_ID = h_task_id:
1323:
1           EXCEPTION:: SP_COMMIT_ASSIGN(324) :: cplan.sql(17257) :: :
1BASELINE3_START:
1BASELINE2_START:
1BASELINE3_FINISH:
1BASELINE2_FINISH:
1BASELINE3_DURATION:
1BASELINE2_DURATION:
1BASELINE3_WORK:
1BASELINE2_WORK:
1BASELINE3_LABOR_COST:
1BASELINE2_LABOR_COST:
1BASELINE3_LABOR_REVENUE:
1BASELINE2_LABOR_REVENUE:
1BASELINE1_START:
1BASELINE1_FINISH:
1BASELINE1_DURATION:
1BASELINE1_WORK:
1BASELINE1_LABOR_COST:
1BASELINE1_LABOR_REVENUE:
1UNRESOLVED_START:
1UNRESOLVED_FINISH:
1UNRESOLVED_DURATION:
1B_REGULAR_COST:
1B_REGULAR_RATE:
1B_SPECIAL_COST:
1SPECIAL_COST:
1B_SPECIAL_RATE:
1SPECIAL_RATE:
1UPDATE TASK_ASSIGNMENTS TA SET:n               TA.BASELINE3_START = TA.BASELI+
1NE2_START, TA.BASELINE3_FINISH = TA.BASELINE2_FINISH, TA.BASELINE3_DURATION =+
1 TA.BASELINE2_DURATION, TA.BASELINE3_WORK = TA.BASELINE2_WORK,:n             +
1  TA.BASELINE3_LABOR_COST = TA.BASELINE2_LABOR_COST, TA.BASELINE3_LABOR_REVEN+
1UE = TA.BASELINE2_LABOR_REVENUE,:n               TA.BASELINE2_START = TA.BASE+
1LINE1_START, TA.BASELINE2_FINISH = TA.BASELINE1_FINISH, TA.BASELINE2_DURATION+
1 = TA.BASELINE1_DURATION, TA.BASELINE2_WORK = TA.BASELINE1_WORK,:n           +
1    TA.BASELINE2_LABOR_COST = TA.BASELINE1_LABOR_COST, TA.BASELINE2_LABOR_REV+
1ENUE = TA.BASELINE1_LABOR_REVENUE,:n               TA.BASELINE1_START = TA.UN+
1RESOLVED_START, TA.BASELINE1_FINISH = TA.UNRESOLVED_FINISH, TA.BASELINE1_DURA+
1TION = TA.UNRESOLVED_DURATION, TA.BASELINE1_WORK = TA.SCHED_WORK + TA.PLANNED+
1_WORK,:n               TA.BASELINE1_LABOR_COST = TA.SCHED_LABOR_COST + TA.PLA+
1NNED_LABOR_COST, TA.BASELINE1_LABOR_REVENUE = TA.SCHED_LABOR_REVENUE + TA.PLA+
1NNED_LABOR_REVENUE,:n               TA.B_REGULAR_COST = TA.REGULAR_COST, TA.B+
1_REGULAR_RATE = TA.REGULAR_RATE, TA.B_SPECIAL_COST = TA.SPECIAL_COST, TA.B_SP+
1ECIAL_RATE = TA.SPECIAL_RATE:n               WHERE TSK_ASSIGNMENT_ID = h_id:
1349:
1           EXCEPTION:: SP_COMMIT_ASSIGN(350) :: cplan.sql(17283) :: :
1PROJECT_ASSIGNMENTS:
1ESTIMATED_BASELINE3_START:
1ESTIMATED_BASELINE2_START:
1ESTIMATED_BASELINE1_START:
1ESTIMATED_SCHED_START:
1ESTIMATED_PLANNED_START:
1ESTIMATED_BASELINE3_FINISH:
1ESTIMATED_BASELINE2_FINISH:
1ESTIMATED_BASELINE1_FINISH:
1ESTIMATED_SCHED_FINISH:
1ESTIMATED_PLANNED_FINISH:
1ESTIMATED_BASELINE3_EFFORT:
1ESTIMATED_BASELINE2_EFFORT:
1ESTIMATED_BASELINE1_EFFORT:
1ESTIMATED_SCHED_EFFORT:
1ESTIMATED_PLANNED_EFFORT:
1ESTIMATED_BASELINE3_COST:
1ESTIMATED_BASELINE2_COST:
1ESTIMATED_BASELINE1_COST:
1ESTIMATED_SCHED_COST:
1ESTIMATED_PLANNED_COST:
1ESTIMATED_BASELINE3_REVENUE:
1ESTIMATED_BASELINE2_REVENUE:
1ESTIMATED_BASELINE1_REVENUE:
1ESTIMATED_SCHED_REVENUE:
1ESTIMATED_PLANNED_REVENUE:
1BASELINE_START:
1BASELINE_FINISH:
1BASELINE_DURATION:
1BASELINE_WORK:
1BASELINE_LABOR_COST:
1BASELINE_LABOR_REVENUE:
1UPDATE PROJECT_ASSIGNMENTS SET:n               ESTIMATED_BASELINE3_START = ES+
1TIMATED_BASELINE2_START,:n               ESTIMATED_BASELINE2_START = ESTIMATE+
1D_BASELINE1_START,:n               ESTIMATED_BASELINE1_START = CASE WHEN ESTI+
1MATED_SCHED_START IS NOT NULL THEN ESTIMATED_SCHED_START ELSE ESTIMATED_PLANN+
1ED_START END,:n               ESTIMATED_BASELINE3_FINISH = ESTIMATED_BASELINE+
12_FINISH,:n               ESTIMATED_BASELINE2_FINISH = ESTIMATED_BASELINE1_FI+
1NISH,:n               ESTIMATED_BASELINE1_FINISH = CASE WHEN ESTIMATED_SCHED_+
1FINISH IS NOT NULL THEN ESTIMATED_SCHED_FINISH ELSE ESTIMATED_PLANNED_FINISH +
1END,:n               ESTIMATED_BASELINE3_EFFORT = ESTIMATED_BASELINE2_EFFORT,+
1:n               ESTIMATED_BASELINE2_EFFORT = ESTIMATED_BASELINE1_EFFORT,:n  +
1             ESTIMATED_BASELINE1_EFFORT = CASE WHEN ESTIMATED_SCHED_EFFORT > +
10 THEN ESTIMATED_SCHED_EFFORT ELSE ESTIMATED_PLANNED_EFFORT END,:n           +
1    ESTIMATED_BASELINE3_COST = ESTIMATED_BASELINE2_COST,:n               ESTI+
1MATED_BASELINE2_COST = ESTIMATED_BASELINE1_COST,:n               ESTIMATED_BA+
1SELINE1_COST = CASE WHEN ESTIMATED_SCHED_COST > 0.00 THEN ESTIMATED_SCHED_COS+
1T ELSE ESTIMATED_PLANNED_COST END,:n               ESTIMATED_BASELINE3_REVENU+
1E = ESTIMATED_BASELINE2_REVENUE,:n               ESTIMATED_BASELINE2_REVENUE +
1= ESTIMATED_BASELINE1_REVENUE,:n               ESTIMATED_BASELINE1_REVENUE = +
1CASE WHEN ESTIMATED_SCHED_REVENUE > 0.00 THEN ESTIMATED_SCHED_REVENUE ELSE ES+
1TIMATED_PLANNED_REVENUE END,:n               BASELINE_START = UNRESOLVED_STAR+
1T,:n               BASELINE_FINISH = UNRESOLVED_FINISH,:n               BASEL+
1INE_DURATION = UNRESOLVED_DURATION,:n               BASELINE_WORK = SCHED_WOR+
1K + PLANNED_WORK,:n               BASELINE_LABOR_COST = SCHED_LABOR_COST + PL+
1ANNED_LABOR_COST,:n               BASELINE_LABOR_REVENUE = SCHED_LABOR_REVENU+
1E + PLANNED_LABOR_REVENUE:n               WHERE PROJECT_ID = h_project_id:
1388:
1           EXCEPTION:: SP_COMMIT_ASSIGN(389) :: cplan.sql(17322) :: :
1SELECT PLANNED_WORK INTO h_day_min FROM TASK_ASSIGNMENTS WHERE BIT_FLAG = '0'+
1 AND TSK_ASSIGNMENT_ID = h_id:
1407:
1           EXCEPTION:: SP_COMMIT_ASSIGN(408) :: cplan.sql(17341) :: :
1IS NULL:
1CASEEND0000:
1C_EFFORT:
1SELECT TSK_ASSIGNMENT_ID, CASE WHEN C_EFFORT = 0 THEN 0 ELSE C_EFFORT + h_wor+
1k END:n               INTO h_prj_assignment_id, h_work:n               FROM T+
1ASK_ASSIGNMENTS WHERE BIT_FLAG = '2' AND TASK_ID = h_project_id AND RESOURCE_+
1ID = h_res_id:
1426:
1           EXCEPTION:: SP_COMMIT_ASSIGN(427) :: cplan.sql(17360) :: :
1IS NOT NULL:
1DELETE FROM TASK_ASSIGNMENTS WHERE TSK_ASSIGNMENT_ID = h_id:
1449:
1           EXCEPTION:: SP_COMMIT_ASSIGN(450) :: cplan.sql(17383) :: :
1EFFORT_WEEK:
1DELETE FROM EFFORT_WEEK WHERE TSK_ASSIGNMENT_ID = h_id:
1466:
1           EXCEPTION:: SP_COMMIT_ASSIGN(467) :: cplan.sql(17400) :: :
1RESOURCE_ASSIGN_ROLES:
1RES_ASSIGNMENT_ID:
1DELETE FROM RESOURCE_ASSIGN_ROLES WHERE RES_ASSIGNMENT_ID = h_id:
1483:
1           EXCEPTION:: SP_COMMIT_ASSIGN(484) :: cplan.sql(17417) :: :
1RESOURCE_ASSIGN_SKILLS:
1DELETE FROM RESOURCE_ASSIGN_SKILLS WHERE RES_ASSIGNMENT_ID = h_id:
1           EXCEPTION:: SP_COMMIT_ASSIGN(501) :: cplan.sql(17434) :: :
1UTL_RAW:
1BIT_OR:
1UPDATE TASK_DAY_OF_YEAR SET SCHED_MIN = SCHED_MIN + h_day_min,:n             +
1        BIT_SCHED = UTL_RAW.BIT_OR(BIT_SCHED, h_bitID):n                     +
1WHERE PROJECT_ID = h_project_id AND TSK_ASSIGNMENT_ID = h_prj_assignment_id A+
1ND DAY_YEAR = h_dayofyear:
1547:
1           EXCEPTION:: SP_COMMIT_ASSIGN(548) :: cplan.sql(17481) :: :
1DELETE FROM TASK_DAY_OF_YEAR WHERE PROJECT_ID = h_project_id AND TSK_ASSIGNME+
1NT_ID = h_id AND DAY_YEAR = h_dayofyear:
1566:
1           EXCEPTION:: SP_COMMIT_ASSIGN(567) :: cplan.sql(17500) :: :
1UPDATE TASK_DAY_OF_YEAR SET TSK_ASSIGNMENT_ID = h_prj_assignment_id WHERE PRO+
1JECT_ID = h_project_id AND TSK_ASSIGNMENT_ID = h_id AND DAY_YEAR = h_dayofyea+
1r:
1583:
1           EXCEPTION:: SP_COMMIT_ASSIGN(584) :: cplan.sql(17517) :: :
1601:
1           EXCEPTION:: SP_COMMIT_ASSIGN(602) :: cplan.sql(17535) :: :
1615:
1           EXCEPTION:: SP_COMMIT_ASSIGN(616) :: cplan.sql(17549) :: :
1PARENT_ID:
1UPDATE TASK_DAY_OF_YEAR SET BIT_FLAG = '2', PARENT_ID = h_prj_assignment_id:n+
1               WHERE PROJECT_ID = h_project_id AND PARENT_ID = h_id:
1633:
1           EXCEPTION:: SP_COMMIT_ASSIGN(634) :: cplan.sql(17567) :: :
1SD:
1SC_SS:
1FD:
1SC_SF:
1UPDATE TASK_ASSIGNMENTS SET:n                  BIT_FLAG = '2',:n             +
1     SD = PMO_CNST.SC_SS, FD = PMO_CNST.SC_SF,:n                  SCHED_START+
1 = PLANNED_START,:n                  SCHED_FINISH = PLANNED_FINISH,:n        +
1          SCHED_DURATION = PLANNED_DURATION,:n                  SCHED_WORK = +
1PLANNED_WORK,:n                  BAK_START_DT = PLANNED_START,:n             +
1     BAK_FINISH_DT = PLANNED_FINISH,:n                  BAK_WORK = PLANNED_WO+
1RK,:n                  SCHED_LABOR_COST = CASE WHEN PLANNED_LABOR_COST > 0.00+
1 THEN PLANNED_LABOR_COST ELSE SCHED_LABOR_COST END,:n                  SCHED_+
1LABOR_REVENUE = CASE WHEN PLANNED_LABOR_REVENUE > 0.00 THEN PLANNED_LABOR_REV+
1ENUE ELSE SCHED_LABOR_REVENUE END,:n                  ETC = PLANNED_WORK,:n  +
1                FORECAST_LABOR_COST = ((ETC+PLANNED_WORK/60.00) * REGULAR_COS+
1T) + ACTUAL_LABOR_COST,:n                  FORECAST_LABOR_REVENUE = CASE WHEN+
1 BILLABLE = 0 THEN 0.00 ELSE ((ETC+PLANNED_WORK/60.00) * REGULAR_RATE) + ACTU+
1AL_LABOR_REVENUE END,:n                  PLANNED_START = NuLL, PLANNED_FINISH+
1 = NuLL, PLANNED_DURATION = 0, PLANNED_WORK = 0,:n                  FORECAST_+
1START = NuLL, FORECAST_FINISH = NuLL, FORECAST_DURATION = 0,:n               +
1   PROJECT_ASSIGNMENT_ID = NuLL:n                  WHERE TSK_ASSIGNMENT_ID = +
1h_id AND SCHED_WORK = 0 AND PLANNED_WORK > 0:
1669:
1           EXCEPTION:: SP_COMMIT_ASSIGN(670) :: cplan.sql(17603) :: :
1U_ASSIGN_STRING:
1UPDATE TASK_ASSIGNMENTS SET:n                     BIT_FLAG = '2',:n          +
1           SD = PMO_CNST.SC_SS,:n                     FD = PMO_CNST.SC_SF,:n +
1                    SCHED_START = PLANNED_START,:n                     SCHED_+
1FINISH = PLANNED_FINISH,:n                     SCHED_DURATION = PLANNED_DURAT+
1ION,:n                     SCHED_WORK = PLANNED_WORK,:n                     B+
1AK_START_DT = PLANNED_START,:n                     BAK_FINISH_DT = PLANNED_FI+
1NISH,:n                     BAK_WORK = PLANNED_WORK,:n                     SC+
1HED_LABOR_COST = CASE WHEN PLANNED_LABOR_COST > 0.00 THEN PLANNED_LABOR_COST +
1ELSE SCHED_LABOR_COST END,:n                     SCHED_LABOR_REVENUE = CASE W+
1HEN PLANNED_LABOR_REVENUE > 0.00 THEN PLANNED_LABOR_REVENUE ELSE SCHED_LABOR_+
1REVENUE END,:n                     ETC = PLANNED_WORK,:n                     +
1FORECAST_LABOR_COST = ((ETC+PLANNED_WORK/60.00) * REGULAR_COST) + ACTUAL_LABO+
1R_COST,:n                     FORECAST_LABOR_REVENUE = CASE WHEN BILLABLE = 0+
1 THEN 0.00 ELSE ((ETC+PLANNED_WORK/60.00) * REGULAR_RATE) + ACTUAL_LABOR_REVE+
1NUE END,:n                     PLANNED_START = NuLL, PLANNED_FINISH = NuLL, P+
1LANNED_DURATION = 0, PLANNED_WORK = 0,:n                     FORECAST_START =+
1 NuLL, FORECAST_FINISH = NuLL, FORECAST_DURATION = 0,:n                     P+
1ROJECT_ASSIGNMENT_ID = h_prj_assignment_id:n                     WHERE TSK_AS+
1SIGNMENT_ID = h_tsk_assignment_id:
1726:
1           EXCEPTION:: SP_COMMIT_ASSIGN(727) :: cplan.sql(17660) :: :
1UPDATE TMT_WBS SET ROLLUP_BITS = PMO_CNST.SC_ASSIGNMENT_BIT WHERE ELEMENT_ID +
1= h_task_id:
1745:
1           EXCEPTION:: SP_COMMIT_ASSIGN(746) :: cplan.sql(17679) :: :
1759:
1           EXCEPTION:: SP_COMMIT_ASSIGN(760) :: cplan.sql(17693) :: :
1>:
1UPDATE TASK_ASSIGNMENTS SET C_EFFORT = h_work WHERE TSK_ASSIGNMENT_ID = h_prj+
1_assignment_id:
1777:
1           EXCEPTION:: SP_COMMIT_ASSIGN(778) :: cplan.sql(17711) :: :
1BEST:
1SELECT PROJECT_ASSIGNMENT_ID, BEST, SCHED_START, SCHED_FINISH, BILLABLE, REGU+
1LAR_COST, REGULAR_RATE:n                  INTO h_prj_assignment_id, h_sched_w+
1ork, h_start_date, h_finish_date, h_billable, h_reg_cost, h_reg_sale:n       +
1           FROM TASK_ASSIGNMENTS WHERE TSK_ASSIGNMENT_ID   = h_prj_assignment+
1_id:
1797:
1           EXCEPTION:: SP_COMMIT_ASSIGN(798) :: cplan.sql(17731) :: :
1UPDATE PROJECT_ASSIGNMENTS SET:n                     ESTIMATED_PLANNED_START +
1= NuLL,:n                     ESTIMATED_PLANNED_FINISH = NuLL,:n             +
1        ESTIMATED_PLANNED_EFFORT = 0,:n                     ESTIMATED_PLANNED+
1_COST = 0.00,:n                     ESTIMATED_PLANNED_REVENUE = 0.00,:n      +
1               ESTIMATED_SCHED_START = h_start_date,:n                     ES+
1TIMATED_SCHED_FINISH = h_finish_date,:n                     ESTIMATED_SCHED_E+
1FFORT = h_sched_work,:n                     ESTIMATED_SCHED_COST = (h_sched_w+
1ork / 60.0) * h_reg_cost,:n                     ESTIMATED_SCHED_REVENUE = 0.0+
10:n                     WHERE PROJECT_ID = h_project_id AND RESOURCE_ID = h_r+
1es_id:
1827:
1           EXCEPTION:: SP_COMMIT_ASSIGN(828) :: cplan.sql(17761) :: :
1UPDATE PROJECT_ASSIGNMENTS SET:n                     ESTIMATED_PLANNED_START +
1= NuLL,:n                     ESTIMATED_PLANNED_FINISH = NuLL,:n             +
1        ESTIMATED_PLANNED_EFFORT = 0,:n                     ESTIMATED_PLANNED+
1_COST = 0.00,:n                     ESTIMATED_PLANNED_REVENUE = 0.00,:n      +
1               ESTIMATED_SCHED_START = h_start_date,:n                     ES+
1TIMATED_SCHED_FINISH = h_finish_date,:n                     ESTIMATED_SCHED_E+
1FFORT = h_sched_work,:n                     ESTIMATED_SCHED_COST = (h_sched_w+
1ork / 60.0) * h_reg_cost,:n                     ESTIMATED_SCHED_REVENUE = (h_+
1sched_work / 60.0) * h_reg_sale:n                     WHERE PROJECT_ID = h_pr+
1oject_id AND RESOURCE_ID = h_res_id:
1855:
1           EXCEPTION:: SP_COMMIT_ASSIGN(856) :: cplan.sql(17789) :: :
1882:
1           EXCEPTION:: SP_COMMIT_ASSIGN(883) :: cplan.sql(17816) :: :
1898:
1           EXCEPTION:: SP_COMMIT_ASSIGN(899) :: cplan.sql(17832) :: :
1FC_ROLLUP:
1SC_NS:
1SC_NF:
1SELECT CASE WHEN (SD <> PMO_CNST.SC_NS) AND (FD <> PMO_CNST.SC_NF) AND (TYPE_+
1ID = PMO_CNST.SC_PROPOSAL) THEN 1 ELSE 0 END:n      INTO h_change_flag:n     +
1 FROM TMT_WBS WHERE ELEMENT_ID = h_project_id:
1916:
1           EXCEPTION:: SP_COMMIT_ASSIGN(917) :: cplan.sql(17850) :: :
1FC_CHANGE_PROJ_TYPE:
1RESOURCE_ASSIGNMENTS:
1ELEMENT_TYPE:
1UPDATE RESOURCE_ASSIGNMENTS SET:n      ELEMENT_TYPE  = (SELECT TYPE_ID FROM T+
1MT_WBS WHERE ELEMENT_ID = h_project_id):n      WHERE ELEMENT_ID = h_project_i+
1d:
1940:
1           EXCEPTION:: SP_COMMIT_ASSIGN(941) :: cplan.sql(17874) :: :
14:
1950:
1       RETURN_STATUS:: SP_COMMIT_ASSIGN(951) :: cplan.sql(17884) :: :
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
1957:
1           EXCEPTION:: SP_COMMIT_ASSIGN(958) :: cplan.sql(17891) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1ERROR:
1ID:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
1969:
1           EXCEPTION:: SP_COMMIT_ASSIGN(970) :: cplan.sql(17903) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
14b0
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d b4 :3 a0 6b 2c 6a
a3 a0 51 a5 1c :2 a0 6b 81
b0 a3 a0 51 a5 1c :2 a0 6b
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 1c 81 b0 a3 a0
1c 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 51
a5 1c 81 b0 a0 f4 b4 bf
c8 :1a a0 12a bd b7 11 a4 b1
a3 :2 a0 6b 1c 81 b0 a0 f4
b4 bf c8 :9 a0 12a bd b7 11
a4 b1 a0 f4 b4 bf c8 :6 a0
12a bd b7 11 a4 b1 a3 :2 a0
6b 1c 81 b0 :2 a0 6b :2 a0 6b
6e a5 b a 10 :2 a0 6b 6e
:2 a0 6b 6e a5 b 6e 7e a0
b4 2e 6e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :3 a0 a5 b 6e
a5 b b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 d :2 a0 d :6 a0 12a :2 a0 6b
a0 d b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
6b a0 7e a0 6b b4 2e 5a
:c a0 12a :2 a0 6b a0 d b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 6b a0 7e a0
6b b4 2e 5a :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :4 a0 6b a5 b 6e
a5 b b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
a0 a5 57 a0 b7 :2 a0 51 a5
b 7e 51 b4 2e 5a :2 a0 51
a5 b 7e 51 b4 2e 5a a
10 :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b :2 a0 a5 57
b7 :2 19 3c :6 a0 12a :2 a0 6b a0
d b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f a0 6e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e d b7 :2 a0 d
:2 a0 51 a5 b 7e 51 b4 2e
:44 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 e9 dd b3 :4 a0 e9 d3
5 :2 a0 f :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c :2 a0
6b a0 7e a0 6b b4 2e 5a
a0 2b b7 19 3c :39 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :6 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
a0 47 :2 a0 e9 c1 :2 a0 6b a0
d b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 19
3c :9 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f a0 51 d a0 51 d
a0 6e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e d b7
:2 19 3c :3 a0 11c 11d :6 a0 e9 d3
5 :2 a0 f :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c :2 a0
6b a0 7e a0 6b b4 2e 5a
a0 2b b7 19 3c a0 51 :1e a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:62 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :3a a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 a6 9 51 :6 a0 12a
:2 a0 6b a0 d b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6b a0 7e a0 6b b4
2e 5a a0 7e b4 2e :2 5a 52
10 a0 3b b7 19 3c :c a0 12a
:2 a0 6b a0 d b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6b a0 7e a0 6b b4
2e 5a a0 7e b4 2e :2 5a a
10 :2 a0 51 a5 b 7e 51 b4
2e a0 51 d b7 :3 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :3 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :3 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:3 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f a0 51 d b7 :2 19 3c b7
:2 a0 d a0 51 d b7 :2 19 3c
a0 51 d :2 a0 e9 dd b3 :5 a0
e9 d3 5 :2 a0 f :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c :2 a0 6b a0 7e a0 6b b4
2e 5a a0 2b b7 19 3c :2 a0
51 a5 b 7e 51 b4 2e :f a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 6b a0 7e a0 6b b4 2e
5a :7 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 :9 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 :2 19 3c a0
b7 :2 a0 51 a5 b 7e 51 b4
2e :9 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 :2 19 3c b7 a0 47
:2 a0 e9 c1 :2 a0 6b a0 d b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :8 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 51 a5
b 7e 51 b4 2e :37 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 51
a5 b 7e 51 b4 2e a0 51
d :5 a0 :2 51 a5 b d b7 19
3c b7 :2 a0 e9 dd b3 :4 a0 e9
d3 5 :2 a0 f :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
:2 a0 6b a0 7e a0 6b b4 2e
5a a0 2b b7 19 3c :36 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :6 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 a0 47 :2 a0 e9 c1 :2 a0 6b
a0 d b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
51 a5 b 7e 51 b4 2e 5a
:2 a0 51 a5 b 7e 51 b4 2e
5a a 10 :5 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 19 3c a0
51 d :5 a0 :2 51 a5 b d :11 a0
12a :2 a0 6b a0 d b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 51 a5 b 7e 51
b4 2e :14 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 :16 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 :2 19 3c
b7 :2 19 3c 93 4f b0 46 b7
a6 9 4f b7 9 a4 14 :6 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 a0 47 :2 a0 e9 c1 :2 a0 6b
a0 d b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :3 a0
a5 b d :d a0 12a :2 a0 6b a0
d b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 51
a5 b 7e 51 b4 2e :3 a0 6b
d :2 a0 6b :4 a0 a5 b d b7
19 3c :8 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 6b 7e 51 b4
2e :2 a0 6b 51 d b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b :2 a0 a5 57 b7 :2 a0 6b :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 :2 a0
6b :2 6e 7e :2 a0 6b b4 2e 7e
6e b4 2e 7e :2 a0 6b b4 2e
a5 57 b7 19 3c :9 a0 12a e9
dd :2 a0 65 b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c :7 a0 12a e9 dd :2 a0
65 b7 a4 b1 11 4f b7 a6
9 a4 b1 11 68 4f 1d 17
b5 
14b0
2
0 3 7 23 1f 1e 2b 38
34 1b 40 33 45 49 4d 30
51 55 7d 5d 61 64 65 6d
71 75 78 5c a5 88 59 8c
8d 95 99 9d a0 87 c2 b0
84 b4 b5 bd af de cd d1
d9 ac fa e5 e9 ec ed f5
cc 117 105 c9 109 10a 112 104
134 122 101 126 127 12f 121 151
13f 11e 143 144 14c 13e 16e 15c
13b 160 161 169 15b 18a 179 17d
185 158 1a2 191 195 19d 178 1be
1ad 1b1 175 1b9 1ac 1da 1c9 1cd
1a9 1d5 1c8 1f6 1e5 1e9 1c5 1f1
1e4 212 201 205 1e1 20d 200 22e
21d 221 1fd 229 21c 24a 239 23d
219 245 238 266 255 259 235 261
254 282 271 275 251 27d 270 29e
28d 291 26d 299 28c 2ba 2a9 2ad
289 2b5 2a8 2d6 2c5 2c9 2a5 2d1
2c4 2f2 2e1 2e5 2c1 2ed 2e0 30e
2fd 301 2dd 309 2fc 32a 319 31d
2f9 325 318 346 335 339 315 341
334 363 351 331 355 356 35e 350
36a 36e 34d 37f 382 386 38a 38e
392 396 39a 39e 3a2 3a6 3aa 3ae
3b2 3b6 3ba 3be 3c2 3c6 3ca 3ce
3d2 3d6 3da 3de 3e2 3e6 3ea 3ee
3fa 3ff 401 40d 411 42f 417 41b
41f 422 42a 416 436 43a 413 44b
44e 452 456 45a 45e 462 466 46a
46e 472 476 482 487 489 495 499
49b 49f 4b0 4b1 4b4 4b8 4bc 4c0
4c4 4c8 4cc 4d0 4dc 4e1 4e3 4ef
4f3 511 4f9 4fd 501 504 50c 4f8
518 51c 4f5 520 524 528 52b 530
531 1 533 538 53c 540 543 548
54c 550 553 558 559 55b 560 563
567 568 56d 572 575 57a 57b 580
583 587 588 58d 590 595 596 59b
59e 5a3 5a4 5a9 5ac 5b0 5b4 5b8
5b9 5bb 5c0 5c1 5c3 5c4 5c9 5cc
5d1 5d2 5d7 5d8 5dd 5df 5e3 5e6
5ea 5ee 5f1 5f5 5f9 5fc 5ff 604
607 60a 60d 60e 613 614 1 616
61b 61f 623 626 62b 630 633 637
638 63d 63e 643 645 649 64c 650
654 658 65c 660 664 668 66c 670
674 678 67c 688 68c 690 693 697
69b 69d 1 6a1 6a5 6a9 6ac 6b0
6b4 6b8 6bc 6bf 6c3 6c7 6ca 6cd
6d2 6d5 6d8 6db 6dc 6e1 6e2 1
6e4 6e9 6ed 6f1 6f4 6f9 6fe 701
705 706 70b 70e 713 714 719 71c
721 722 727 72a 72e 72f 734 737
73c 73d 742 745 749 74d 750 753
754 756 757 75c 75d 762 764 768
76b 76d 771 773 77f 781 783 784
789 78d 78f 79b 79d 7a1 7a5 7a8
7ac 7af 7b3 7b6 7b7 7bc 7bf 7c3
7c7 7cb 7cf 7d3 7d7 7db 7df 7e3
7e7 7eb 7ef 7fb 7ff 803 806 80a
80e 810 1 814 818 81c 81f 823
827 82b 82f 832 836 83a 83d 840
845 848 84b 84e 84f 854 855 1
857 85c 860 864 867 86c 871 874
878 879 87e 881 886 887 88c 88f
894 895 89a 89d 8a1 8a2 8a7 8aa
8af 8b0 8b5 8b8 8bc 8c0 8c3 8c6
8c7 8c9 8ca 8cf 8d0 8d5 8d7 8db
8de 8e0 8e4 8e6 8f2 8f4 8f6 8f7
8fc 900 902 90e 910 914 918 91b
91f 922 926 929 92a 92f 932 936
93a 93d 941 945 948 94b 950 953
956 959 95a 95f 960 1 962 967
96b 96f 972 977 97c 97f 983 984
989 98c 991 992 997 99a 99f 9a0
9a5 9a8 9ac 9b0 9b4 9b8 9bb 9bc
9be 9c3 9c4 9c6 9c7 9cc 9cd 9d2
9d4 9d8 9db 9df 9e3 9e6 9ea 9ee
9f1 9f4 9f9 9fc 9ff a02 a03 a08
a09 1 a0b a10 a14 a18 a1b a20
a25 a28 a2c a2d a32 a33 a38 a3a
a3e a41 a45 a49 a4c a50 a54 a57
a5b a5c a61 a65 a67 a6b a6f a72
a73 a75 a78 a7b a7c a81 a84 a88
a8c a8f a90 a92 a95 a98 a99 a9e
1 aa1 aa6 aaa aae ab1 ab5 ab9
abc abf ac4 ac7 aca acd ace ad3
ad4 1 ad6 adb adf ae3 ae6 aeb
af0 af3 af7 af8 afd b00 b05 b06
b0b b0e b13 b14 b19 b1c b20 b24
b28 b2c b2f b30 b32 b37 b38 b3a
b3b b40 b43 b48 b49 b4e b51 b56
b57 b5c b5f b63 b64 b69 b6c b71
b72 b77 b78 b7d b7f b83 b86 b8a
b8e b91 b95 b99 b9c b9f ba4 ba7
baa bad bae bb3 bb4 1 bb6 bbb
bbf bc3 bc6 bcb bd0 bd3 bd7 bd8
bdd bde be3 be5 be9 bec bf0 bf4
bf7 bfb bff c02 c06 c0a c0b c10
c12 c16 c1a c1d c21 c25 c29 c2d
c31 c35 c41 c45 c49 c4c c50 c54
c56 1 c5a c5e c62 c65 c69 c6d
c71 c75 c78 c7c c80 c83 c86 c8b
c8e c91 c94 c95 c9a c9b 1 c9d
ca2 ca6 caa cad cb2 cb7 cba cbe
cbf cc4 cc7 ccc ccd cd2 cd5 cda
cdb ce0 ce3 ce7 ce8 ced cf0 cf5
cf6 cfb cfe d02 d06 d09 d0c d0d
d0f d10 d15 d16 d1b d1d d21 d24
d26 d2a d2c d38 d3a d3c d3d d42
d46 d48 d54 d56 d5a d5f d62 d67
d68 d6d d70 d74 d75 d7a d7d d82
d83 d88 d8c d8e d92 d96 d9a d9e
da2 da5 da6 da8 dab dae daf db4
db8 dbc dc0 dc4 dc8 dcc dd0 dd4
dd8 ddc de0 de4 de8 dec df0 df4
df8 dfc e00 e04 e08 e0c e10 e14
e18 e1c e20 e24 e28 e2c e30 e34
e38 e3c e40 e44 e48 e4c e50 e54
e58 e5c e60 e64 e68 e6c e70 e74
e78 e7c e80 e84 e88 e8c e90 e94
e98 e9c ea0 ea4 ea8 eac eb0 eb4
eb8 ebc ec0 ec4 ed0 ed4 ed9 edd
ee0 ee1 ee6 eea eee ef1 ef4 ef8
efa efe f02 f05 f08 f0c f0e f12
f16 f19 f1b 1 f1f f23 f27 f2a
f2e f32 f36 f3a f3d f41 f45 f48
f4b f50 f53 f56 f59 f5a f5f f60
1 f62 f67 f6b f6f f72 f77 f7c
f7f f83 f84 f89 f8c f91 f92 f97
f9a f9f fa0 fa5 fa8 fac fad fb2
fb5 fba fbb fc0 fc3 fc7 fcb fce
fd1 fd2 fd4 fd5 fda fdb fe0 fe2
fe6 fe9 feb fef ff1 ffd fff 1001
1002 1007 100b 100d 1019 101b 101f 1023
1028 102c 102d 1031 1035 1039 103d 1042
1047 104b 104f 1053 1058 105c 1060 1063
1066 106a 106c 1070 1074 1077 107a 107e
1080 1084 1088 108b 108f 1093 1096 109a
109d 10a1 10a4 10a5 10aa 10ad 10b1 10b7
10b9 10bd 10c0 10c4 10c8 10cc 10d0 10d4
10d8 10dc 10e0 10e4 10e8 10ec 10f0 10f4
10f8 10fc 1100 1104 1108 110c 1110 1114
1118 111c 1120 1124 1128 112c 1130 1134
1138 113c 1140 1144 1148 114c 1150 1154
1158 115c 1160 1164 1168 116c 1170 1174
1178 117c 1180 1184 1188 118c 1190 1194
1198 119c 11a0 11a4 11b0 11b4 11b9 11bd
11c0 11c1 11c6 11ca 11ce 11d1 11d4 11d8
11da 11de 11e2 11e5 11e8 11ec 11ee 11f2
11f6 11f9 11fb 1 11ff 1203 1207 120a
120e 1212 1216 121a 121d 1221 1225 1228
122b 1230 1233 1236 1239 123a 123f 1240
1 1242 1247 124b 124f 1252 1257 125c
125f 1263 1264 1269 126c 1271 1272 1277
127a 127f 1280 1285 1288 128c 128d 1292
1295 129a 129b 12a0 12a3 12a7 12ab 12ae
12b1 12b2 12b4 12b5 12ba 12bb 12c0 12c2
12c6 12c9 12cb 12cf 12d1 12dd 12df 12e1
12e2 12e7 12eb 12ed 12f9 12fb 12ff 1303
1307 130b 130f 1313 131f 1323 1328 132c
132f 1330 1335 1339 133d 1340 1343 1347
1349 134d 1351 1354 1357 135b 135d 1361
1365 1368 136a 1 136e 1372 1376 1379
137d 1381 1385 1389 138c 1390 1394 1397
139a 139f 13a2 13a5 13a8 13a9 13ae 13af
1 13b1 13b6 13ba 13be 13c1 13c6 13cb
13ce 13d2 13d3 13d8 13db 13e0 13e1 13e6
13e9 13ee 13ef 13f4 13f7 13fb 13fc 1401
1404 1409 140a 140f 1412 1416 141a 141d
1420 1421 1423 1424 1429 142a 142f 1431
1435 1438 143a 143e 1440 144c 144e 1450
1451 1456 145a 145c 1468 146a 146c 1470
1477 147b 147f 1484 1486 148a 148e 1491
1495 1499 149b 1 149f 14a3 14a7 14aa
14ae 14b2 14b6 14ba 14bd 14c1 14c5 14c8
14cb 14d0 14d3 14d6 14d9 14da 14df 14e0
1 14e2 14e7 14eb 14ef 14f2 14f7 14fc
14ff 1503 1504 1509 150c 1511 1512 1517
151a 151f 1520 1525 1528 152c 152d 1532
1535 153a 153b 1540 1543 1547 154b 154e
1551 1552 1554 1555 155a 155b 1560 1562
1566 1569 156b 156f 1571 157d 157f 1581
1582 1587 158b 158d 1599 159b 159d 15a1
15a4 15a8 15ac 15b0 15b4 15b8 15bc 15c0
15c4 15c8 15d4 15d8 15dd 15e1 15e4 15e5
15ea 15ee 15f2 15f5 15f8 15fc 15fe 1602
1606 1609 160c 1610 1612 1616 161a 161d
161f 1 1623 1627 162b 162e 1632 1636
163a 163e 1641 1645 1649 164c 164f 1654
1657 165a 165d 165e 1663 1664 1 1666
166b 166f 1673 1676 167b 1680 1683 1687
1688 168d 1690 1695 1696 169b 169e 16a3
16a4 16a9 16ac 16b0 16b1 16b6 16b9 16be
16bf 16c4 16c7 16cb 16cf 16d2 16d5 16d6
16d8 16d9 16de 16df 16e4 16e6 16ea 16ed
16ef 16f3 16f5 1701 1703 1705 1706 170b
170f 1711 171d 171f 1723 1726 172a 172e
1731 1735 1739 173e 1741 1746 1747 174c
174f 1753 1754 1759 175c 1761 1762 1767
176b 176d 1771 1775 1778 177c 1780 1784
1787 178b 178f 1793 1797 179b 179f 17a3
17a8 17ad 17b1 17b5 17b9 17be 17c2 17c6
17c9 17cc 17d0 17d2 17d6 17da 17dd 17e0
17e4 17e6 17ea 17ee 17f1 17f5 17f9 17fc
1800 1803 1807 180a 180b 1810 1813 1817
181d 181f 1823 1826 182a 182d 1831 1835
1839 183d 1841 1845 1849 184d 1851 1855
1859 185d 1861 1865 1869 186d 1871 1875
1879 187d 1881 1885 1889 188d 1891 1895
1899 189d 18a1 18a5 18b1 18b5 18ba 18be
18c1 18c2 18c7 18cb 18cf 18d2 18d5 18d9
18db 18df 18e3 18e6 18e9 18ed 18ef 18f3
18f7 18fa 18fc 1 1900 1904 1908 190b
190f 1913 1917 191b 191e 1922 1926 1929
192c 1931 1934 1937 193a 193b 1940 1941
1 1943 1948 194c 1950 1953 1958 195d
1960 1964 1965 196a 196d 1972 1973 1978
197b 1980 1981 1986 1989 198d 198e 1993
1996 199b 199c 19a1 19a4 19a8 19ac 19af
19b2 19b3 19b5 19b6 19bb 19bc 19c1 19c3
19c7 19ca 19cc 19d0 19d2 19de 19e0 19e2
19e3 19e8 19ec 19ee 19fa 19fc 1a00 1a04
1a08 1a0c 1a10 1a14 1a18 1a1c 1a20 1a24
1a28 1a2c 1a30 1a34 1a38 1a3c 1a40 1a44
1a48 1a4c 1a50 1a54 1a58 1a5c 1a60 1a64
1a68 1a6c 1a70 1a74 1a78 1a7c 1a80 1a84
1a88 1a8c 1a90 1a94 1a98 1a9c 1aa0 1aa4
1aa8 1aac 1ab0 1ab4 1ab8 1abc 1ac0 1ac4
1ac8 1acc 1ad0 1ad4 1ad8 1adc 1ae0 1ae4
1ae8 1aec 1af0 1af4 1af8 1afc 1b00 1b04
1b08 1b0c 1b10 1b14 1b18 1b1c 1b20 1b24
1b28 1b2c 1b30 1b34 1b38 1b3c 1b40 1b44
1b48 1b4c 1b50 1b54 1b58 1b5c 1b60 1b64
1b68 1b6c 1b70 1b74 1b78 1b7c 1b80 1b84
1b90 1b94 1b99 1b9d 1ba0 1ba1 1ba6 1baa
1bae 1bb1 1bb4 1bb8 1bba 1bbe 1bc2 1bc5
1bc8 1bcc 1bce 1bd2 1bd6 1bd9 1bdb 1
1bdf 1be3 1be7 1bea 1bee 1bf2 1bf6 1bfa
1bfd 1c01 1c05 1c08 1c0b 1c10 1c13 1c16
1c19 1c1a 1c1f 1c20 1 1c22 1c27 1c2b
1c2f 1c32 1c37 1c3c 1c3f 1c43 1c44 1c49
1c4c 1c51 1c52 1c57 1c5a 1c5f 1c60 1c65
1c68 1c6c 1c6d 1c72 1c75 1c7a 1c7b 1c80
1c83 1c87 1c8b 1c8e 1c91 1c92 1c94 1c95
1c9a 1c9b 1ca0 1ca2 1ca6 1ca9 1cab 1caf
1cb1 1cbd 1cbf 1cc1 1cc2 1cc7 1ccb 1ccd
1cd9 1cdb 1cdf 1ce3 1ce7 1ceb 1cef 1cf3
1cf7 1cfb 1cff 1d03 1d07 1d0b 1d0f 1d13
1d17 1d1b 1d1f 1d23 1d27 1d2b 1d2f 1d33
1d37 1d3b 1d3f 1d43 1d47 1d4b 1d4f 1d53
1d57 1d5b 1d5f 1d63 1d67 1d6b 1d6f 1d73
1d77 1d7b 1d7f 1d83 1d87 1d8b 1d8f 1d93
1d97 1d9b 1d9f 1da3 1da7 1dab 1daf 1db3
1db7 1dbb 1dbf 1dc3 1dcf 1dd3 1dd8 1ddc
1ddf 1de0 1de5 1de9 1ded 1df0 1df3 1df7
1df9 1dfd 1e01 1e04 1e07 1e0b 1e0d 1e11
1e15 1e18 1e1a 1 1e1e 1e22 1e26 1e29
1e2d 1e31 1e35 1e39 1e3c 1e40 1e44 1e47
1e4a 1e4f 1e52 1e55 1e58 1e59 1e5e 1e5f
1 1e61 1e66 1e6a 1e6e 1e71 1e76 1e7b
1e7e 1e82 1e83 1e88 1e8b 1e90 1e91 1e96
1e99 1e9e 1e9f 1ea4 1ea7 1eab 1eac 1eb1
1eb4 1eb9 1eba 1ebf 1ec2 1ec6 1eca 1ecd
1ed0 1ed1 1ed3 1ed4 1ed9 1eda 1edf 1ee1
1ee5 1ee8 1eea 1eee 1ef0 1efc 1efe 1f00
1f01 1f06 1f0a 1f0c 1f18 1f1a 1f1c 1f1d
1f22 1f25 1f29 1f2d 1f31 1f35 1f39 1f3d
1f49 1f4d 1f51 1f54 1f58 1f5c 1f5e 1
1f62 1f66 1f6a 1f6d 1f71 1f75 1f79 1f7d
1f80 1f84 1f88 1f8b 1f8e 1f93 1f96 1f99
1f9c 1f9d 1fa2 1fa3 1 1fa5 1faa 1fae
1fb2 1fb5 1fba 1fbf 1fc2 1fc6 1fc7 1fcc
1fcf 1fd4 1fd5 1fda 1fdd 1fe2 1fe3 1fe8
1feb 1fef 1ff0 1ff5 1ff8 1ffd 1ffe 2003
2006 200a 200e 2011 2014 2015 2017 2018
201d 201e 2023 2025 2029 202c 202e 2032
2034 2040 2042 2044 2045 204a 204e 2050
205c 205e 2062 2066 2069 206d 2070 2074
2077 2078 207d 2080 2084 2087 2088 208d
2090 1 2093 2098 209c 20a2 20a4 20a8
20ab 20af 20b3 20b7 20bb 20bf 20c3 20c7
20cb 20cf 20d3 20d7 20db 20e7 20eb 20ef
20f2 20f6 20fa 20fc 1 2100 2104 2108
210b 210f 2113 2117 211b 211e 2122 2126
2129 212c 2131 2134 2137 213a 213b 2140
2141 1 2143 2148 214c 2150 2153 2158
215d 2160 2164 2165 216a 216d 2172 2173
2178 217b 2180 2181 2186 2189 218d 218e
2193 2196 219b 219c 21a1 21a4 21a8 21ac
21af 21b2 21b3 21b5 21b6 21bb 21bc 21c1
21c3 21c7 21ca 21cc 21d0 21d2 21de 21e0
21e2 21e3 21e8 21ec 21ee 21fa 21fc 2200
2204 2207 220b 220e 2212 2215 2216 221b
221e 2222 2225 2226 222b 222e 1 2231
2236 223a 223e 2241 2242 2244 2247 224a
224b 2250 2254 2257 225b 225d 2261 2265
2269 2275 2279 227e 2282 2285 2286 228b
228f 2293 2296 2299 229d 229f 22a3 22a7
22aa 22ad 22b1 22b3 22b7 22bb 22be 22c0
1 22c4 22c8 22cc 22cf 22d3 22d7 22db
22df 22e2 22e6 22ea 22ed 22f0 22f5 22f8
22fb 22fe 22ff 2304 2305 1 2307 230c
2310 2314 2317 231c 2321 2324 2328 2329
232e 2331 2336 2337 233c 233f 2344 2345
234a 234d 2351 2352 2357 235a 235f 2360
2365 2368 236c 2370 2373 2376 2377 2379
237a 237f 2380 2385 2387 238b 238e 2390
2394 2396 23a2 23a4 23a6 23a7 23ac 23b0
23b2 23be 23c0 23c4 23c8 23cc 23d8 23dc
23e1 23e5 23e8 23e9 23ee 23f2 23f6 23f9
23fc 2400 2402 2406 240a 240d 2410 2414
2416 241a 241e 2421 2423 1 2427 242b
242f 2432 2436 243a 243e 2442 2445 2449
244d 2450 2453 2458 245b 245e 2461 2462
2467 2468 1 246a 246f 2473 2477 247a
247f 2484 2487 248b 248c 2491 2494 2499
249a 249f 24a2 24a7 24a8 24ad 24b0 24b4
24b5 24ba 24bd 24c2 24c3 24c8 24cb 24cf
24d3 24d6 24d9 24da 24dc 24dd 24e2 24e3
24e8 24ea 24ee 24f1 24f3 24f7 24f9 2505
2507 2509 250a 250f 2513 2515 2521 2523
2527 252b 252f 253b 253f 2544 2548 254b
254c 2551 2555 2559 255c 255f 2563 2565
2569 256d 2570 2573 2577 2579 257d 2581
2584 2586 1 258a 258e 2592 2595 2599
259d 25a1 25a5 25a8 25ac 25b0 25b3 25b6
25bb 25be 25c1 25c4 25c5 25ca 25cb 1
25cd 25d2 25d6 25da 25dd 25e2 25e7 25ea
25ee 25ef 25f4 25f7 25fc 25fd 2602 2605
260a 260b 2610 2613 2617 2618 261d 2620
2625 2626 262b 262e 2632 2636 2639 263c
263d 263f 2640 2645 2646 264b 264d 2651
2654 2656 265a 265c 2668 266a 266c 266d
2672 2676 2678 2684 2686 268a 268e 2692
269e 26a2 26a7 26ab 26ae 26af 26b4 26b8
26bc 26bf 26c2 26c6 26c8 26cc 26d0 26d3
26d6 26da 26dc 26e0 26e4 26e7 26e9 1
26ed 26f1 26f5 26f8 26fc 2700 2704 2708
270b 270f 2713 2716 2719 271e 2721 2724
2727 2728 272d 272e 1 2730 2735 2739
273d 2740 2745 274a 274d 2751 2752 2757
275a 275f 2760 2765 2768 276d 276e 2773
2776 277a 277b 2780 2783 2788 2789 278e
2791 2795 2799 279c 279f 27a0 27a2 27a3
27a8 27a9 27ae 27b0 27b4 27b7 27b9 27bd
27bf 27cb 27cd 27cf 27d0 27d5 27d9 27db
27e7 27e9 27ed 27f0 27f4 27f6 27fa 27fe
2801 2803 2807 280b 280f 2813 2816 281a
281c 2820 2824 2827 282b 282e 2832 2836
283a 283f 2843 2844 2848 284c 2850 2854
2858 285d 2862 2866 286a 286e 2873 2877
287b 287e 2881 2885 2887 288b 288f 2892
2895 2899 289b 289f 28a3 28a6 28aa 28ae
28b1 28b5 28b8 28bc 28bf 28c0 28c5 28c8
28cc 28d2 28d4 28d8 28db 28df 28e3 28e6
28e7 28e9 28ec 28ef 28f0 28f5 28f9 28fd
2901 2905 2909 290d 2911 2915 2919 291d
2921 2925 2929 292d 2931 293d 2941 2946
294a 294d 294e 2953 2957 295b 295e 2961
2965 2967 296b 296f 2972 2975 2979 297b
297f 2983 2986 2988 1 298c 2990 2994
2997 299b 299f 29a3 29a7 29aa 29ae 29b2
29b5 29b8 29bd 29c0 29c3 29c6 29c7 29cc
29cd 1 29cf 29d4 29d8 29dc 29df 29e4
29e9 29ec 29f0 29f1 29f6 29f9 29fe 29ff
2a04 2a07 2a0c 2a0d 2a12 2a15 2a19 2a1a
2a1f 2a22 2a27 2a28 2a2d 2a30 2a34 2a38
2a3b 2a3e 2a3f 2a41 2a42 2a47 2a48 2a4d
2a4f 2a53 2a56 2a58 2a5c 2a5e 2a6a 2a6c
2a6e 2a6f 2a74 2a78 2a7a 2a86 2a88 2a8c
2a90 2a93 2a97 2a9a 2a9e 2aa1 2aa2 2aa7
2aaa 2aae 2ab2 2ab6 2aba 2abe 2ac2 2ac6
2ad2 2ad6 2adb 2adf 2ae2 2ae3 2ae8 2aec
2af0 2af3 2af6 2afa 2afc 2b00 2b04 2b07
2b0a 2b0e 2b10 2b14 2b18 2b1b 2b1d 1
2b21 2b25 2b29 2b2c 2b30 2b34 2b38 2b3c
2b3f 2b43 2b47 2b4a 2b4d 2b52 2b55 2b58
2b5b 2b5c 2b61 2b62 1 2b64 2b69 2b6d
2b71 2b74 2b79 2b7e 2b81 2b85 2b86 2b8b
2b8e 2b93 2b94 2b99 2b9c 2ba1 2ba2 2ba7
2baa 2bae 2baf 2bb4 2bb7 2bbc 2bbd 2bc2
2bc5 2bc9 2bcd 2bd0 2bd3 2bd4 2bd6 2bd7
2bdc 2bdd 2be2 2be4 2be8 2beb 2bed 2bf1
2bf3 2bff 2c01 2c03 2c04 2c09 2c0d 2c0f
2c1b 2c1d 2c1f 2c23 2c27 2c2b 2c2f 2c33
2c37 2c3b 2c3f 2c43 2c4f 2c53 2c58 2c5c
2c5f 2c60 2c65 2c69 2c6d 2c70 2c73 2c77
2c79 2c7d 2c81 2c84 2c87 2c8b 2c8d 2c91
2c95 2c98 2c9a 1 2c9e 2ca2 2ca6 2ca9
2cad 2cb1 2cb5 2cb9 2cbc 2cc0 2cc4 2cc7
2cca 2ccf 2cd2 2cd5 2cd8 2cd9 2cde 2cdf
1 2ce1 2ce6 2cea 2cee 2cf1 2cf6 2cfb
2cfe 2d02 2d03 2d08 2d0b 2d10 2d11 2d16
2d19 2d1e 2d1f 2d24 2d27 2d2b 2d2c 2d31
2d34 2d39 2d3a 2d3f 2d42 2d46 2d4a 2d4d
2d50 2d51 2d53 2d54 2d59 2d5a 2d5f 2d61
2d65 2d68 2d6a 2d6e 2d70 2d7c 2d7e 2d80
2d81 2d86 2d8a 2d8c 2d98 2d9a 2d9c 2da0
2da4 2da7 2dab 2dad 2db1 2db5 2db8 2db9
2dbb 2dbe 2dc1 2dc2 2dc7 2dcb 2dcf 2dd3
2dd7 2ddb 2ddf 2de3 2de7 2deb 2df7 2dfb
2e00 2e04 2e07 2e08 2e0d 2e11 2e15 2e18
2e1b 2e1f 2e21 2e25 2e29 2e2c 2e2f 2e33
2e35 2e39 2e3d 2e40 2e42 1 2e46 2e4a
2e4e 2e51 2e55 2e59 2e5d 2e61 2e64 2e68
2e6c 2e6f 2e72 2e77 2e7a 2e7d 2e80 2e81
2e86 2e87 1 2e89 2e8e 2e92 2e96 2e99
2e9e 2ea3 2ea6 2eaa 2eab 2eb0 2eb3 2eb8
2eb9 2ebe 2ec1 2ec6 2ec7 2ecc 2ecf 2ed3
2ed4 2ed9 2edc 2ee1 2ee2 2ee7 2eea 2eee
2ef2 2ef5 2ef8 2ef9 2efb 2efc 2f01 2f02
2f07 2f09 2f0d 2f10 2f12 2f16 2f18 2f24
2f26 2f28 2f29 2f2e 2f32 2f34 2f40 2f42
2f44 2f48 2f4c 2f4f 2f51 2f55 2f5c 2f60
2f64 2f69 2f6b 2f6f 2f73 2f76 2f7a 2f7e
2f80 1 2f84 2f88 2f8c 2f8f 2f93 2f97
2f9b 2f9f 2fa2 2fa6 2faa 2fad 2fb0 2fb5
2fb8 2fbb 2fbe 2fbf 2fc4 2fc5 1 2fc7
2fcc 2fd0 2fd4 2fd7 2fdc 2fe1 2fe4 2fe8
2fe9 2fee 2ff1 2ff6 2ff7 2ffc 2fff 3004
3005 300a 300d 3011 3012 3017 301a 301f
3020 3025 3028 302c 3030 3033 3036 3037
3039 303a 303f 3040 3045 3047 304b 304e
3050 3054 3056 3062 3064 3066 3067 306c
3070 3072 307e 3080 3084 3088 308c 3090
3094 3098 309c 30a0 30ac 30b0 30b5 30b9
30bc 30bd 30c2 30c6 30ca 30cd 30d0 30d4
30d6 30da 30de 30e1 30e4 30e8 30ea 30ee
30f2 30f5 30f7 1 30fb 30ff 3103 3106
310a 310e 3112 3116 3119 311d 3121 3124
3127 312c 312f 3132 3135 3136 313b 313c
1 313e 3143 3147 314b 314e 3153 3158
315b 315f 3160 3165 3168 316d 316e 3173
3176 317b 317c 3181 3184 3188 3189 318e
3191 3196 3197 319c 319f 31a3 31a7 31aa
31ad 31ae 31b0 31b1 31b6 31b7 31bc 31be
31c2 31c5 31c7 31cb 31cd 31d9 31db 31dd
31de 31e3 31e7 31e9 31f5 31f7 31fb 31ff
3202 3203 3205 3208 320b 320c 3211 3215
3219 321d 3221 3225 3229 322d 3231 3235
3239 323d 3241 3245 3249 324d 3251 3255
3259 325d 3261 3265 3269 326d 3271 3275
3279 327d 3281 3285 3289 328d 3291 3295
3299 329d 32a1 32a5 32a9 32ad 32b1 32b5
32b9 32bd 32c1 32c5 32c9 32cd 32d1 32d5
32d9 32dd 32e1 32e5 32e9 32ed 32f9 32fd
3302 3306 3309 330a 330f 3313 3317 331a
331d 3321 3323 3327 332b 332e 3331 3335
3337 333b 333f 3342 3344 1 3348 334c
3350 3353 3357 335b 335f 3363 3366 336a
336e 3371 3374 3379 337c 337f 3382 3383
3388 3389 1 338b 3390 3394 3398 339b
33a0 33a5 33a8 33ac 33ad 33b2 33b5 33ba
33bb 33c0 33c3 33c8 33c9 33ce 33d1 33d5
33d6 33db 33de 33e3 33e4 33e9 33ec 33f0
33f4 33f7 33fa 33fb 33fd 33fe 3403 3404
3409 340b 340f 3412 3414 3418 341a 3426
3428 342a 342b 3430 3434 3436 3442 3444
3448 344c 344f 3450 3452 3455 3458 3459
345e 3462 3465 3469 346d 3471 3475 3479
347d 3480 3483 3484 3486 348a 348c 3490
3493 3495 3499 349d 34a2 34a6 34a7 34ab
34af 34b3 34b7 34bc 34c1 34c5 34c9 34cd
34d2 34d6 34da 34dd 34e0 34e4 34e6 34ea
34ee 34f1 34f4 34f8 34fa 34fe 3502 3505
3509 350d 3510 3514 3517 351b 351e 351f
3524 3527 352b 3531 3533 3537 353a 353e
3542 3546 354a 354e 3552 3556 355a 355e
3562 3566 356a 356e 3572 3576 357a 357e
3582 3586 358a 358e 3592 3596 359a 359e
35a2 35a6 35aa 35ae 35b2 35b6 35ba 35be
35c2 35c6 35ca 35ce 35d2 35d6 35da 35de
35e2 35e6 35ea 35ee 35f2 35f6 35fa 35fe
3602 3606 360a 360e 3612 361e 3622 3627
362b 362e 362f 3634 3638 363c 363f 3642
3646 3648 364c 3650 3653 3656 365a 365c
3660 3664 3667 3669 1 366d 3671 3675
3678 367c 3680 3684 3688 368b 368f 3693
3696 3699 369e 36a1 36a4 36a7 36a8 36ad
36ae 1 36b0 36b5 36b9 36bd 36c0 36c5
36ca 36cd 36d1 36d2 36d7 36da 36df 36e0
36e5 36e8 36ed 36ee 36f3 36f6 36fa 36fb
3700 3703 3708 3709 370e 3711 3715 3719
371c 371f 3720 3722 3723 3728 3729 372e
3730 3734 3737 3739 373d 373f 374b 374d
374f 3750 3755 3759 375b 3767 3769 376d
3771 3775 3779 377d 3781 378d 3791 3796
379a 379d 379e 37a3 37a7 37ab 37ae 37b1
37b5 37b7 37bb 37bf 37c2 37c5 37c9 37cb
37cf 37d3 37d6 37d8 1 37dc 37e0 37e4
37e7 37eb 37ef 37f3 37f7 37fa 37fe 3802
3805 3808 380d 3810 3813 3816 3817 381c
381d 1 381f 3824 3828 382c 382f 3834
3839 383c 3840 3841 3846 3849 384e 384f
3854 3857 385c 385d 3862 3865 3869 386a
386f 3872 3877 3878 387d 3880 3884 3888
388b 388e 388f 3891 3892 3897 3898 389d
389f 38a3 38a6 38a8 38ac 38ae 38ba 38bc
38be 38bf 38c4 38c8 38ca 38d6 38d8 38da
38de 38e5 38e9 38ed 38f2 38f4 38f8 38fc
38ff 3903 3907 3909 1 390d 3911 3915
3918 391c 3920 3924 3928 392b 392f 3933
3936 3939 393e 3941 3944 3947 3948 394d
394e 1 3950 3955 3959 395d 3960 3965
396a 396d 3971 3972 3977 397a 397f 3980
3985 3988 398d 398e 3993 3996 399a 399b
39a0 39a3 39a8 39a9 39ae 39b1 39b5 39b9
39bc 39bf 39c0 39c2 39c3 39c8 39c9 39ce
39d0 39d4 39d7 39d9 39dd 39df 39eb 39ed
39ef 39f0 39f5 39f9 39fb 3a07 3a09 3a0d
3a11 3a14 3a15 3a17 3a1a 3a1d 3a1e 3a23
3a26 3a2a 3a2e 3a31 3a32 3a34 3a37 3a3a
3a3b 3a40 1 3a43 3a48 3a4c 3a50 3a54
3a58 3a5c 3a68 3a6c 3a71 3a75 3a78 3a79
3a7e 3a82 3a86 3a89 3a8c 3a90 3a92 3a96
3a9a 3a9d 3aa0 3aa4 3aa6 3aaa 3aae 3ab1
3ab3 1 3ab7 3abb 3abf 3ac2 3ac6 3aca
3ace 3ad2 3ad5 3ad9 3add 3ae0 3ae3 3ae8
3aeb 3aee 3af1 3af2 3af7 3af8 1 3afa
3aff 3b03 3b07 3b0a 3b0f 3b14 3b17 3b1b
3b1c 3b21 3b24 3b29 3b2a 3b2f 3b32 3b37
3b38 3b3d 3b40 3b44 3b45 3b4a 3b4d 3b52
3b53 3b58 3b5b 3b5f 3b63 3b66 3b69 3b6a
3b6c 3b6d 3b72 3b73 3b78 3b7a 3b7e 3b81
3b83 3b87 3b89 3b95 3b97 3b99 3b9a 3b9f
3ba3 3ba5 3bb1 3bb3 3bb5 3bb9 3bbc 3bc0
3bc3 3bc7 3bcb 3bcf 3bd3 3bd7 3bdb 3bde
3be1 3be2 3be4 3be8 3bec 3bf0 3bf4 3bf8
3bfc 3c00 3c04 3c08 3c0c 3c10 3c14 3c18
3c1c 3c20 3c24 3c28 3c2c 3c38 3c3c 3c40
3c43 3c47 3c4b 3c4d 1 3c51 3c55 3c59
3c5c 3c60 3c64 3c68 3c6c 3c6f 3c73 3c77
3c7a 3c7d 3c82 3c85 3c88 3c8b 3c8c 3c91
3c92 1 3c94 3c99 3c9d 3ca1 3ca4 3ca9
3cae 3cb1 3cb5 3cb6 3cbb 3cbe 3cc3 3cc4
3cc9 3ccc 3cd1 3cd2 3cd7 3cda 3cde 3cdf
3ce4 3ce7 3cec 3ced 3cf2 3cf5 3cf9 3cfd
3d00 3d03 3d04 3d06 3d07 3d0c 3d0d 3d12
3d14 3d18 3d1b 3d1d 3d21 3d23 3d2f 3d31
3d33 3d34 3d39 3d3d 3d3f 3d4b 3d4d 3d51
3d55 3d58 3d59 3d5b 3d5e 3d61 3d62 3d67
3d6b 3d6f 3d73 3d77 3d7b 3d7f 3d83 3d87
3d8b 3d8f 3d93 3d97 3d9b 3d9f 3da3 3da7
3dab 3daf 3db3 3db7 3dc3 3dc7 3dcc 3dd0
3dd3 3dd4 3dd9 3ddd 3de1 3de4 3de7 3deb
3ded 3df1 3df5 3df8 3dfb 3dff 3e01 3e05
3e09 3e0c 3e0e 1 3e12 3e16 3e1a 3e1d
3e21 3e25 3e29 3e2d 3e30 3e34 3e38 3e3b
3e3e 3e43 3e46 3e49 3e4c 3e4d 3e52 3e53
1 3e55 3e5a 3e5e 3e62 3e65 3e6a 3e6f
3e72 3e76 3e77 3e7c 3e7f 3e84 3e85 3e8a
3e8d 3e92 3e93 3e98 3e9b 3e9f 3ea0 3ea5
3ea8 3ead 3eae 3eb3 3eb6 3eba 3ebe 3ec1
3ec4 3ec5 3ec7 3ec8 3ecd 3ece 3ed3 3ed5
3ed9 3edc 3ede 3ee2 3ee4 3ef0 3ef2 3ef4
3ef5 3efa 3efe 3f00 3f0c 3f0e 3f10 3f14
3f18 3f1c 3f20 3f24 3f28 3f2c 3f30 3f34
3f38 3f3c 3f40 3f44 3f48 3f4c 3f50 3f54
3f58 3f5c 3f60 3f64 3f68 3f74 3f78 3f7d
3f81 3f84 3f85 3f8a 3f8e 3f92 3f95 3f98
3f9c 3f9e 3fa2 3fa6 3fa9 3fac 3fb0 3fb2
3fb6 3fba 3fbd 3fbf 1 3fc3 3fc7 3fcb
3fce 3fd2 3fd6 3fda 3fde 3fe1 3fe5 3fe9
3fec 3fef 3ff4 3ff7 3ffa 3ffd 3ffe 4003
4004 1 4006 400b 400f 4013 4016 401b
4020 4023 4027 4028 402d 4030 4035 4036
403b 403e 4043 4044 4049 404c 4050 4051
4056 4059 405e 405f 4064 4067 406b 406f
4072 4075 4076 4078 4079 407e 407f 4084
4086 408a 408d 408f 4093 4095 40a1 40a3
40a5 40a6 40ab 40af 40b1 40bd 40bf 40c1
40c5 40c9 40cc 40ce 40d2 40d6 40d9 40e1
40e3 40e4 40e7 40e9 40ea 40ef 40f1 40f3
40f8 40fc 4101 4105 4109 410d 4111 4115
4119 4125 4129 412e 4132 4135 4136 413b
413f 4143 4146 4149 414d 414f 4153 4157
415a 415d 4161 4163 4167 416b 416e 4170
1 4174 4178 417c 417f 4183 4187 418b
418f 4192 4196 419a 419d 41a0 41a5 41a8
41ab 41ae 41af 41b4 41b5 1 41b7 41bc
41c0 41c4 41c7 41cc 41d1 41d4 41d8 41d9
41de 41e1 41e6 41e7 41ec 41ef 41f4 41f5
41fa 41fd 4201 4202 4207 420a 420f 4210
4215 4218 421c 4220 4223 4226 4227 4229
422a 422f 4230 4235 4237 423b 423e 4240
4244 4246 4252 4254 4256 4257 425c 4260
4262 426e 4270 4272 4276 427d 4281 4285
428a 428c 4290 4294 4297 429b 429f 42a1
1 42a5 42a9 42ad 42b0 42b4 42b8 42bc
42c0 42c3 42c7 42cb 42ce 42d1 42d6 42d9
42dc 42df 42e0 42e5 42e6 1 42e8 42ed
42f1 42f5 42f8 42fd 4302 4305 4309 430a
430f 4312 4317 4318 431d 4320 4325 4326
432b 432e 4332 4333 4338 433b 4340 4341
4346 4349 434d 4351 4354 4357 4358 435a
435b 4360 4361 4366 4368 436c 436f 4371
4375 4377 4383 4385 4387 4388 438d 4391
4393 439f 43a1 43a5 43a9 43ad 43ae 43b0
43b4 43b8 43bc 43c0 43c4 43c8 43cc 43d0
43d4 43d8 43dc 43e0 43e4 43e8 43f4 43f8
43fc 43ff 4403 4407 4409 1 440d 4411
4415 4418 441c 4420 4424 4428 442b 442f
4433 4436 4439 443e 4441 4444 4447 4448
444d 444e 1 4450 4455 4459 445d 4460
4465 446a 446d 4471 4472 4477 447a 447f
4480 4485 4488 448d 448e 4493 4496 449a
449b 44a0 44a3 44a8 44a9 44ae 44b1 44b5
44b9 44bc 44bf 44c0 44c2 44c3 44c8 44c9
44ce 44d0 44d4 44d7 44d9 44dd 44df 44eb
44ed 44ef 44f0 44f5 44f9 44fb 4507 4509
450d 4511 4514 4515 4517 451a 451d 451e
4523 4527 452b 452f 4532 4536 453a 453e
4541 4545 4549 454d 4551 4552 4554 4558
455a 455e 4561 4565 4569 456d 4571 4575
4579 457d 4581 458d 4591 4596 459a 459d
459e 45a3 45a7 45ab 45ae 45b1 45b5 45b7
45bb 45bf 45c2 45c5 45c9 45cb 45cf 45d3
45d6 45d8 1 45dc 45e0 45e4 45e7 45eb
45ef 45f3 45f7 45fa 45fe 4602 4605 4608
460d 4610 4613 4616 4617 461c 461d 1
461f 4624 4628 462c 462f 4634 4639 463c
4640 4641 4646 4649 464e 464f 4654 4657
465c 465d 4662 4665 4669 466a 466f 4672
4677 4678 467d 4680 4684 4688 468b 468e
468f 4691 4692 4697 4698 469d 469f 46a3
46a6 46a8 46ac 46ae 46ba 46bc 46be 46bf
46c4 46c8 46ca 46d6 46d8 46dc 46e0 46e3
46e6 46e9 46ea 46ef 46f3 46f7 46fa 46fd
4701 4703 4707 470a 470e 4712 4715 4719
471d 4720 4723 4728 472b 472e 4731 4732
4737 4738 1 473a 473f 4743 4747 474a
474f 4754 4757 475b 475c 4761 4764 4769
476a 476f 4772 4777 4778 477d 4780 4784
4788 478c 4790 4793 4794 4796 479b 479c
479e 479f 47a4 47a7 47ac 47ad 47b2 47b5
47ba 47bb 47c0 47c3 47c7 47c8 47cd 47d0
47d5 47d6 47db 47dc 47e1 47e3 47e7 47ea
47ee 47f2 47f5 47f9 47fd 4800 4804 4808
4809 480e 4810 4814 4818 481b 481f 4823
4826 482a 482e 4831 4834 4839 483c 483f
4842 4843 4848 4849 1 484b 4850 4854
4858 485b 4860 4865 4868 486c 486d 4872
4873 4878 487c 4880 4883 4888 488d 4890
4894 4898 489b 489c 48a1 48a4 48a9 48aa
48af 48b2 48b6 48ba 48bd 48be 48c3 48c4
48c9 48cb 48cf 48d2 48d6 48da 48de 48e2
48e6 48ea 48ee 48f2 48f6 4902 4907 490b
490f 4913 4917 4919 491a 491f 1 4923
4927 492b 492e 4932 4936 493a 493e 4941
4945 4949 494c 494f 4954 4957 495a 495d
495e 4963 4964 1 4966 496b 496f 4973
4976 497b 4980 4983 4987 4988 498d 498e
4993 4997 499b 499e 49a3 49a8 49ab 49af
49b0 49b5 49b8 49bd 49be 49c3 49c6 49ca
49ce 49d1 49d4 49d5 49d7 49d8 49dd 49de
49e3 49e5 49e9 49ec 49f0 49f4 49f8 49fc
4a00 4a04 4a08 4a14 4a19 4a1d 4a21 4a25
4a29 4a2b 4a2f 4a31 4a3d 4a3f 4a41 4a42
4a47 4a4b 4a4d 4a59 4a5d 4a5f 4a60 4a69 
14b0
2
0 1 a 6 c :3 6 11 :2 6
1 3 a 13 a :2 1 4 c
10 f c 20 :2 29 c :2 4 d
11 10 d 21 :2 2a d :2 4 11
1a 19 :2 11 :2 4 :3 10 :2 4 d 16
15 :2 d :2 4 e 17 16 :2 e :2 4
9 12 11 :2 9 :2 4 18 21 20
:2 18 :2 4 18 21 20 :2 18 :2 4 :3 11
:2 4 :3 12 :2 4 :2 11 20 11 :2 4 :2 f
1e f :2 4 :2 c 1b c :2 4 :2 e
1d e :2 4 :2 e 1d e :2 4 :2 12
21 12 :2 4 :2 12 21 12 :2 4 :2 e
1d e :2 4 :2 f 1e f :2 4 :2 e
1d e :2 4 :2 b 1a b :2 4 :2 f
1e f :2 4 :2 14 23 14 :2 4 :2 f
19 f :2 4 :2 f 19 f :2 4 9
12 11 :2 9 4 7 e 0 :2 7
11 14 27 2a f 20 23 28
30 d f 1c 1f 2e 30 3d
40 10 12 1f 30 33 e 11
29 2c a :6 7 c 15 :3 c :2 7
e 0 :2 7 11 1b 26 35 10
1d 2e 42 4b a :6 7 e 0
:2 7 11 1a f 10 23 3b a
:5 7 4 e 17 :3 e 4 7 :2 11
23 :2 2d 3a :2 23 :3 7 :2 d 19 25
:2 2f 43 :2 25 58 5e 61 :2 58 6f
89 8 :2 6f d 10 :2 6f 16 19
:2 6f b e :2 6f 13 16 1f 27
:2 1f 34 :2 16 :2 6f 3c 3f :2 6f :2 7
4e :2 4 7 :2 11 23 :2 2d 39 3c
50 52 53 :2 50 :2 23 :3 7 :2 d 12
1e 61 64 :2 1e :2 7 56 :3 4 11
:2 4 c 4 e 17 31 44 52
5f :2 7 :2 10 1c 7 4 :2 c a
:2 13 1f a d :2 17 29 :2 33 3f
43 57 59 5a :2 57 :2 29 :3 d :2 13
18 24 67 6a :2 24 77 7a :2 24
7e 81 :2 24 8d 90 :2 24 98 9b
:2 24 a7 aa b1 ba bd :2 aa :2 24
:2 d 5d :2 a :2 7 :4 13 :2 7 4 :3 1
8 :2 11 1c 1a :2 25 :2 1a 7 11
27 34 59 f 1c 26 f 26
44 5a 6e :2 a :2 13 1f a 7
:2 f d :2 16 22 d 10 :2 1a 2c
:2 36 42 46 5a 5c 5d :2 5a :2 2c
:3 10 :2 16 1b 27 6a 6d :2 27 7a
7d :2 27 81 84 :2 27 90 93 :2 27
9b 9e :2 27 aa ad b4 bd c0
:2 ad :2 27 :2 10 60 :2 d :2 a :4 16 :2 a
7 :3 35 b :2 14 1f 1d :2 28 :2 1d
a d :2 17 29 :2 33 3f 42 56
59 5a :2 56 :2 29 :3 d :2 13 18 24
68 6b :2 24 78 7b :2 24 7f 82
:2 24 8c 8f 98 a0 :2 a9 :2 98 bc
:2 8f :2 24 :2 d 5d :2 a d :2 17 29
:2 33 3f 42 56 59 5a :2 56 :2 29
:3 d :2 13 18 24 68 6b :2 24 :2 d
5d :3 a :2 15 2b :2 34 46 :2 a 7
38 e 17 22 :2 e 25 27 :2 25
d 2f 38 44 :2 2f 47 49 :2 47
2e :3 d :2 17 29 :2 33 3f 43 57
5a 5b :2 57 :2 29 :3 d :2 13 18 24
68 6b :2 24 78 7b :2 24 7f 82
:2 24 8c 8f 98 a0 :2 a9 :2 98 c5
:2 8f :2 24 cd d0 :2 24 d8 db :2 24
e0 e3 :2 24 e8 eb :2 24 :2 d 5e
:2 a d :2 17 29 :2 33 3f 42 56
59 5a :2 56 :2 29 :3 d :2 13 18 24
68 6b :2 24 :2 d 5d :3 a :2 15 29
:2 32 4d 53 :2 a 4c 38 :2 7 11
1a 34 47 55 62 :2 a :2 13 1f
a 7 :2 f d :2 16 22 d 10
:2 1a 2c :2 36 42 46 5a 5d 5e
:2 5a :2 2c :3 10 :2 16 1b 27 6b 6e
:2 27 7b 7e :2 27 82 85 :2 27 91
94 :2 27 9c 9f :2 27 ab ae b5
be c1 :2 ae :2 27 :2 10 61 :2 d :2 a
:4 16 :2 a 7 :3 35 7 f e 11
:2 f 30 33 :2 f 13 16 :2 f 7
35 7 17 7 a 13 1e :2 a
21 23 :2 21 14 d 29 33 3c
4d 56 66 d 1f 28 37 d
1f 28 38 d 29 43 57 d
1f :6 d 1f d 1f d 13 20
31 3d 46 4e 57 65 6e 7c
85 93 9c a9 b2 c3 cc df
e8 fd 106 121 12a 142 14b 15c
165 177 180 198 1a1 1b4 1bd 1de
1f3 207 d 14 10 1c :3 1a 10
:2 19 25 10 21 10 :2 19 25 10
:4 d a :2 12 10 :2 19 25 10 13
:2 1d 2f :2 39 45 49 5d 60 61
:2 5d :2 2f :3 13 :2 19 1e 2a 6e 71
:2 2a 7e 81 :2 2a 85 88 :2 2a 94
97 :2 2a 9f a2 :2 2a ae b1 b8
c1 c4 :2 b1 :2 2a :2 13 64 :2 10 :2 d
:4 19 :2 d a :3 25 a f :4 a 13
1d 32 :3 d 10 15 :2 10 :2 19 25
10 1b 10 :2 19 25 10 :4 d 11
:2 1a 26 23 :2 2f :2 23 :3 10 3f :2 d
17 :2 10 1e 27 36 10 1f 28
38 10 2b 45 5b 10 1d 10
16 10 1f 28 37 10 20 29
39 10 1b 10 2d 4c 64 10
30 52 6d 10 30 4e 52 68
78 10 33 51 55 6b 7b 10
26 3d 53 10 27 3f 16 2a
10 17 13 1f :3 1d 13 :2 1c 28
13 24 13 :2 1c 28 13 :4 10 d
:2 15 13 :2 1c 28 13 16 :2 20 32
:2 3c 48 4c 60 63 64 :2 60 :2 32
:3 16 :2 1c 21 2d 71 74 :2 2d 81
84 :2 2d 88 8b :2 2d 97 9a :2 2d
a2 a5 :2 2d b1 b4 bb c4 c7
:2 b4 :2 2d :2 16 67 :2 13 :2 10 :4 1c :2 10
d :3 a 17 2c 16 23 34 48
10 17 13 1f :3 1d 13 :2 1c 28
13 24 13 :2 1c 28 13 :4 10 d
:2 15 13 :2 1c 28 13 16 :2 20 32
:2 3c 48 4c 60 63 64 :2 60 :2 32
:3 16 :2 1c 21 2d 71 74 :2 2d 81
84 :2 2d 88 8b :2 2d 97 9a :2 2d
a2 a5 :2 2d b1 b4 bb c4 c7
:2 b4 :2 2d :2 16 67 :2 13 :2 10 :4 1c :2 10
d :4 a e 25 d 13 :3 d :2 16
22 d a :2 12 10 :2 19 25 10
13 :2 1d 2f :2 39 45 49 5d 60
61 :2 5d :2 2f :3 13 :2 19 1e 2a 6e
71 :2 2a 7e 81 :2 2a 85 88 :2 2a
94 97 :2 2a 9f a2 :2 2a ae b1
b8 c1 c4 :2 b1 :2 2a :2 13 64 :2 10
:2 d :4 19 :2 d a :4 25 :2 7 11 1d
2b 34 10 1d 2e 43 57 a
11 d 19 :3 17 d :2 16 22 d
1e d :2 16 22 d :4 a 7 :2 f
d :2 16 22 d 10 :2 1a 2c :2 36
42 46 5a 5d 5e :2 5a :2 2c :3 10
:2 16 1b 27 6b 6e :2 27 7b 7e
:2 27 82 85 :2 27 91 94 :2 27 9c
9f :2 27 ab ae b5 be c1 :2 ae
:2 27 :2 10 61 :2 d :2 a :4 16 :2 a 7
:3 4 7 14 :2 7 14 :2 7 d e
11 :2 d 23 26 :2 d 13 16 :2 d
7 :5 4 9 :2 12 :2 4 d 17 1d
27 32 :3 7 a f :2 a :2 13 1f
a 15 a :2 13 1f a :4 7 b
:2 14 20 1d :2 29 :2 1d :3 a 39 :2 7
c f 17 1f 10 12 28 2a
10 12 28 2a 10 12 28 2a
10 12 25 27 10 12 25 27
10 12 25 27 16 23 34 41
10 17 13 1f :3 1d 13 :2 1c 28
13 24 13 :2 1c 28 13 :4 10 d
:2 15 13 :2 1c 28 13 16 :2 20 32
:2 3c 48 4c 60 63 64 :2 60 :2 32
:3 16 :2 1c 21 2d 71 74 :2 2d 81
84 :2 2d 88 8b :2 2d 97 9a :2 2d
a2 a5 :2 2d b1 b4 bb c4 c7
:2 b4 :2 2d :2 16 67 :2 13 :2 10 :4 1c :2 10
d :3 11 17 28 10 13 25 28
39 3c 4f 52 64 67 7c 7f
93 96 a7 aa 10 13 2a 2d
43 46 60 63 10 13 25 28
39 3c 4f 52 64 67 7c 7f
93 96 a7 aa 10 13 2a 2d
43 46 60 63 10 13 25 28
3a 3d 50 53 66 69 7e 81
96 99 aa ad ba bd 10 13
2a 2d 40 43 57 5a 74 77
8d 90 10 13 24 27 35 38
49 4c 5a 5d 6e 71 7f 82
93 96 16 2a 10 17 13 1f
:3 1d 13 :2 1c 28 13 24 13 :2 1c
28 13 :4 10 d :2 15 13 :2 1c 28
13 16 :2 20 32 :2 3c 48 4c 60
63 64 :2 60 :2 32 :3 16 :2 1c 21 2d
71 74 :2 2d 81 84 :2 2d 88 8b
:2 2d 97 9a :2 2d a2 a5 :2 2d b1
b4 bb c4 c7 :2 b4 :2 2d :2 16 67
:2 13 :2 10 :4 1c :2 10 d :3 11 17 10
2c 10 2c 10 36 5d 78 10
2d 10 2d 10 37 5f 7b 10
2d 10 2d 10 37 57 73 10
2b 10 2b 10 35 56 70 10
2e 10 2e 10 38 5c 79 10
21 10 22 10 24 10 20 2d
10 26 39 10 29 3f 16 23
10 17 13 1f :3 1d 13 :2 1c 28
13 24 13 :2 1c 28 13 :4 10 d
:2 15 13 :2 1c 28 13 16 :2 20 32
:2 3c 48 4c 60 63 64 :2 60 :2 32
:3 16 :2 1c 21 2d 71 74 :2 2d 81
84 :2 2d 88 8b :2 2d 97 9a :2 2d
a2 a5 :2 2d b1 b4 bb c4 c7
:2 b4 :2 2d :2 16 67 :2 13 :2 10 :4 1c :2 10
d :4 11 :2 a f 17 29 38 4f
62 76 :2 10 :2 19 25 10 d :2 15
13 :2 1c 28 13 16 :2 20 32 :2 3c
48 4c 60 63 64 :2 60 :2 32 :3 16
:2 1c 21 2d 71 74 :2 2d 81 84
:2 2d 88 8b :2 2d 97 9a :2 2d a2
a5 :2 2d b1 b4 bb c4 c7 :2 b4
:2 2d :2 16 67 :2 13 :2 10 :4 1c :2 10 d
:4 11 :2 1a 26 23 :2 2f :2 23 10 :4 44
43 42 :2 10 15 10 58 :2 d 17
34 4d 58 15 2a 15 2c 3f
49 5a 68 :2 10 :2 19 25 10 d
:2 15 13 :2 1c 28 13 16 :2 20 32
:2 3c 48 4c 60 63 64 :2 60 :2 32
:3 16 :2 1c 21 2d 71 74 :2 2d 81
84 :2 2d 88 8b :2 2d 97 9a :2 2d
a2 a5 :2 2d b1 b4 bb c4 c7
:2 b4 :2 2d :2 16 67 :2 13 :2 10 :4 1c :2 10
d :4 11 :2 1a 25 23 :2 2e :2 23 10
:4 44 43 42 :2 10 13 1c 27 :2 13
2a 2c :2 2a 13 1e 13 2e 22
39 4d 16 1d 19 25 :3 23 19
:2 22 2e 19 2a 19 :2 22 2e 19
:4 16 13 :2 1b 19 :2 22 2e 19 1c
:2 26 38 :2 42 4e 52 66 69 6a
:2 66 :2 38 :3 1c :2 22 27 33 77 7a
:2 33 87 8a :2 33 8e 91 :2 33 9d
a0 :2 33 a8 ab :2 33 b7 ba c1
ca cd :2 ba :2 33 :2 1c 6d :2 19 :2 16
:4 22 :2 16 13 :3 10 22 34 48 16
1d 19 25 :3 23 19 :2 22 2e 19
2a 19 :2 22 2e 19 :4 16 13 :2 1b
19 :2 22 2e 19 1c :2 26 38 :2 42
4e 52 66 69 6a :2 66 :2 38 :3 1c
:2 22 27 33 77 7a :2 33 87 8a
:2 33 8e 91 :2 33 9d a0 :2 33 a8
ab :2 33 b7 ba c1 ca cd :2 ba
:2 33 :2 1c 6d :2 19 :2 16 :4 22 :2 16 13
:3 10 22 3e 52 16 1d 19 25
:3 23 19 :2 22 2e 19 2a 19 :2 22
2e 19 :4 16 13 :2 1b 19 :2 22 2e
19 1c :2 26 38 :2 42 4e 52 66
69 6a :2 66 :2 38 :3 1c :2 22 27 33
77 7a :2 33 87 8a :2 33 8e 91
:2 33 9d a0 :2 33 a8 ab :2 33 b7
ba c1 ca cd :2 ba :2 33 :2 1c 6d
:2 19 :2 16 :4 22 :2 16 13 :3 10 22 3f
53 16 1d 19 25 :3 23 19 :2 22
2e 19 2a 19 :2 22 2e 19 :4 16
13 :2 1b 19 :2 22 2e 19 1c :2 26
38 :2 42 4e 52 66 69 6a :2 66
:2 38 :3 1c :2 22 27 33 77 7a :2 33
87 8a :2 33 8e 91 :2 33 9d a0
:2 33 a8 ab :2 33 b7 ba c1 ca
cd :2 ba :2 33 :2 1c 6d :2 19 :2 16 :4 22
:2 16 13 :3 10 13 1e 13 :4 10 66
10 27 :2 10 1b 10 :5 d 1a :2 d
12 :4 d 16 1f 2c 37 :3 10 13
17 :2 13 :2 1c 28 13 1d 13 :2 1c
28 13 :4 10 14 :2 1d 29 26 :2 32
:2 26 :3 13 42 :2 10 13 1c 25 :2 13
28 2a :2 28 1d 32 3e 4a 16
22 2a 31 3c 1c 29 3a 4e
66 71 16 1d 19 25 :3 23 19
:2 22 2e 19 2a 19 :2 22 2e 19
:4 16 13 :2 1b 19 :2 22 2e 19 1c
:2 26 38 :2 42 4e 52 66 69 6a
:2 66 :2 38 :3 1c :2 22 27 33 77 7a
:2 33 87 8a :2 33 8e 91 :2 33 9d
a0 :2 33 a8 ab :2 33 b7 ba c1
ca cd :2 ba :2 33 :2 1c 6d :2 19 :2 16
:4 22 :2 16 13 :3 2c 17 :2 20 2b 29
:2 34 :2 29 16 25 3c 49 5a 6e
77 82 19 20 1c 28 :3 26 1c
:2 25 31 1c 2d 1c :2 25 31 1c
:4 19 16 :2 1e 1c :2 25 31 1c 1f
:2 29 3b :2 45 51 55 69 6c 6d
:2 69 :2 3b :3 1f :2 25 2a 36 7a 7d
:2 36 8a 8d :2 36 91 94 :2 36 a0
a3 :2 36 ab ae :2 36 ba bd c4
cd d0 :2 bd :2 36 :2 1f 70 :2 1c :2 19
:4 25 :2 19 16 :4 44 20 35 49 63
70 81 95 9e a9 19 20 1c
28 :3 26 1c :2 25 31 1c 2d 1c
:2 25 31 1c :4 19 16 :2 1e 1c :2 25
31 1c 1f :2 29 3b :2 45 51 55
69 6c 6d :2 69 :2 3b :3 1f :2 25 2a
36 7a 7d :2 36 8a 8d :2 36 91
94 :2 36 a0 a3 :2 36 ab ae :2 36
ba bd c4 cd d0 :2 bd :2 36 :2 1f
70 :2 1c :2 19 :4 25 :2 19 16 :7 13 10
2c 16 1f 28 :2 16 2b 2d :2 2b
1d 32 46 60 6d 7e 92 9b
a6 16 1d 19 25 :3 23 19 :2 22
2e 19 2a 19 :2 22 2e 19 :4 16
13 :2 1b 19 :2 22 2e 19 1c :2 26
38 :2 42 4e 52 66 69 6a :2 66
:2 38 :3 1c :2 22 27 33 77 7a :2 33
87 8a :2 33 8e 91 :2 33 9d a0
:2 33 a8 ab :2 33 b7 ba c1 ca
cd :2 ba :2 33 :2 1c 6d :2 19 :2 16 :4 22
:2 16 13 :4 2f 2c :2 10 d :2 11 10
16 :3 10 :2 19 25 10 d :2 15 13
:2 1c 28 13 16 :2 20 32 :2 3c 48
4c 60 63 64 :2 60 :2 32 :3 16 :2 1c
21 2d 71 74 :2 2d 81 84 :2 2d
88 8b :2 2d 97 9a :2 2d a2 a5
:2 2d b1 b4 bb c4 c7 :2 b4 :2 2d
:2 16 67 :2 13 :2 10 :4 1c :2 10 d :3 11
17 2c 3c 48 16 23 34 40
10 17 13 1f :3 1d 13 :2 1c 28
13 24 13 :2 1c 28 13 :4 10 d
:2 15 13 :2 1c 28 13 16 :2 20 32
:2 3c 48 4c 60 63 64 :2 60 :2 32
:3 16 :2 1c 21 2d 71 74 :2 2d 81
84 :2 2d 88 8b :2 2d 97 9a :2 2d
a2 a5 :2 2d b1 b4 bb c4 c7
:2 b4 :2 2d :2 16 67 :2 13 :2 10 :4 1c :2 10
d :3 11 10 19 24 :2 10 27 29
:2 27 1a :2 13 18 21 28 2d 36
13 21 13 22 13 24 13 20
13 22 13 23 13 1e 13 30
4f 67 13 33 55 70 13 19
13 2b 2f 45 55 13 36 54
58 6e 7e 13 29 40 56 13
2a 42 13 19 2d 36 49 13
1a 16 22 :3 20 16 :2 1f 2b 16
27 16 :2 1f 2b 16 :4 13 10 :2 18
16 :2 1f 2b 16 19 :2 23 35 :2 3f
4b 4f 63 66 67 :2 63 :2 35 :3 19
:2 1f 24 30 74 77 :2 30 84 87
:2 30 8b 8e :2 30 9a 9d :2 30 a5
a8 :2 30 b4 b7 be c7 ca :2 b7
:2 30 :2 19 6a :2 16 :2 13 :4 1f :2 13 10
:3 2b 13 1c 25 :2 13 28 2a :2 28
13 21 :2 13 26 36 44 59 65
68 :2 26 13 2c :2 10 2b 10 15
:4 10 19 22 2d :3 13 16 1a :2 16
:2 1f 2b 16 20 16 :2 1f 2b 16
:4 13 17 :2 20 2c 29 :2 35 :2 29 :3 16
45 :2 13 1d :2 16 1b 24 16 1b
24 16 24 16 25 16 27 16
23 16 25 16 26 16 21 16
33 52 6a 16 36 58 73 16
1c 16 2e 32 48 58 16 39
57 5b 71 81 16 2c 43 59
16 2d 45 16 2e 1c 30 16
1d 19 25 :3 23 19 :2 22 2e 19
2a 19 :2 22 2e 19 :4 16 13 :2 1b
19 :2 22 2e 19 1c :2 26 38 :2 42
4e 52 66 69 6a :2 66 :2 38 :3 1c
:2 22 27 33 77 7a :2 33 87 8a
:2 33 8e 91 :2 33 9d a0 :2 33 a8
ab :2 33 b7 ba c1 ca cd :2 ba
:2 33 :2 1c 6d :2 19 :2 16 :4 22 :2 16 13
:3 10 1d 29 37 40 58 65 16
1d 19 25 :3 23 19 :2 22 2e 19
2a 19 :2 22 2e 19 :4 16 13 :2 1b
19 :2 22 2e 19 1c :2 26 38 :2 42
4e 52 66 69 6a :2 66 :2 38 :3 1c
:2 22 27 33 77 7a :2 33 87 8a
:2 33 8e 91 :2 33 9d a0 :2 33 a8
ab :2 33 b7 ba c1 ca cd :2 ba
:2 33 :2 1c 6d :2 19 :2 16 :4 22 :2 16 13
:4 10 14 d 13 19 :3 13 :2 1c 28
13 10 :2 18 16 :2 1f 2b 16 19
:2 23 35 :2 3f 4b 4f 63 66 67
:2 63 :2 35 :3 19 :2 1f 24 30 74 77
:2 30 84 87 :2 30 8b 8e :2 30 9a
9d :2 30 a5 a8 :2 30 b4 b7 be
c7 ca :2 b7 :2 30 :2 19 6a :2 16 :2 13
:4 1f :2 13 10 :3 d 14 1d 28 :2 14
2b 2d :2 2b 13 35 3e 46 :2 35
49 4b :2 49 34 :2 13 1d 32 3d
4a 5e 16 1d 19 25 :3 23 19
:2 22 2e 19 2a 19 :2 22 2e 19
:4 16 13 :2 1b 19 :2 22 2e 19 1c
:2 26 38 :2 42 4e 52 66 69 6a
:2 66 :2 38 :3 1c :2 22 27 33 77 7a
:2 33 87 8a :2 33 8e 91 :2 33 9d
a0 :2 33 a8 ab :2 33 b7 ba c1
ca cd :2 ba :2 33 :2 1c 6d :2 19 :2 16
:4 22 :2 16 13 :4 4e :3 10 1e :2 10 23
33 41 56 62 65 :2 23 10 1a
31 37 44 52 5c 6a 18 2d
3b 49 58 64 70 18 2f 45
:2 13 :2 1c 28 13 10 :2 18 16 :2 1f
2b 16 19 :2 23 35 :2 3f 4b 4f
63 66 67 :2 63 :2 35 :3 19 :2 1f 24
30 74 77 :2 30 84 87 :2 30 8b
8e :2 30 9a 9d :2 30 a5 a8 :2 30
b4 b7 be c7 ca :2 b7 :2 30 :2 19
6a :2 16 :2 13 :4 1f :2 13 10 :3 d 13
1c 28 :2 13 2b 2d :2 2b 1d :6 16
2e 16 2f 16 2f 16 2e 45
16 1c 29 3a 48 16 1d 19
25 :3 23 19 :2 22 2e 19 2a 19
:2 22 2e 19 :4 16 13 :2 1b 19 :2 22
2e 19 1c :2 26 38 :2 42 4e 52
66 69 6a :2 66 :2 38 :3 1c :2 22 27
33 77 7a :2 33 87 8a :2 33 8e
91 :2 33 9d a0 :2 33 a8 ab :2 33
b7 ba c1 ca cd :2 ba :2 33 :2 1c
6d :2 19 :2 16 :4 22 :2 16 13 :4 2f 1d
:6 16 2e 16 2f 16 2f 16 2e
45 16 31 48 1c 29 3a 48
16 1d 19 25 :3 23 19 :2 22 2e
19 2a 19 :2 22 2e 19 :4 16 13
:2 1b 19 :2 22 2e 19 1c :2 26 38
:2 42 4e 52 66 69 6a :2 66 :2 38
:3 1c :2 22 27 33 77 7a :2 33 87
8a :2 33 8e 91 :2 33 9d a0 :2 33
a8 ab :2 33 b7 ba c1 ca cd
:2 ba :2 33 :2 1c 6d :2 19 :2 16 :4 22 :2 16
13 :7 10 :4 d f d :3 11 :2 a d
a :3 7 11 1d 2b 34 4c 59
a 11 d 19 :3 17 d :2 16 22
d 1e d :2 16 22 d :4 a 7
:2 f d :2 16 22 d 10 :2 1a 2c
:2 36 42 46 5a 5d 5e :2 5a :2 2c
:3 10 :2 16 1b 27 6b 6e :2 27 7b
7e :2 27 82 85 :2 27 91 94 :2 27
9c 9f :2 27 ab ae b5 be c1
:2 ae :2 27 :2 10 61 :2 d :2 a :4 16 :2 a
7 :4 4 8 1 7 d :3 7 :2 10
1c 7 4 :2 c a :2 13 1f a
d :2 17 29 :2 33 3f 43 57 5a
5b :2 57 :2 29 :3 d :2 13 18 24 68
6b :2 24 78 7b :2 24 7f 82 :2 24
8e 91 :2 24 99 9c :2 24 a8 ab
b2 bb be :2 ab :2 24 :2 d 5e :2 a
:2 7 :4 13 :2 7 4 :3 1 4 17 21
:2 17 4 19 1f 28 34 3a 43
4f 59 62 :2 c 1a 27 :2 7 :2 10
1c 7 4 :2 c a :2 13 1f a
d :2 17 29 :2 33 3f 43 57 5a
5b :2 57 :2 29 :3 d :2 13 18 24 68
6b :2 24 78 7b :2 24 7f 82 :2 24
8e 91 :2 24 99 9c :2 24 a8 ab
b2 bb be :2 ab :2 24 :2 d 5e :2 a
:2 7 :4 13 :2 7 4 :3 1 7 10 1f
:2 7 22 24 :2 22 7 14 :2 1d :2 7
:2 10 1c 30 3e 4d :2 1c 7 26
:2 4 e 7 1f 2c 3a 47 d
1a 7 e a 16 :3 14 a :2 13
1f a 1b a :2 13 1f a :4 7
4 :2 c a :2 13 1f a d :2 17
29 :2 33 3f 43 57 5a 5b :2 57
:2 29 :3 d :2 13 18 24 68 6b :2 24
78 7b :2 24 7f 82 :2 24 8e 91
:2 24 99 9c :2 24 a8 ab b2 bb
be :2 ab :2 24 :2 d 5e :2 a :2 7 :4 13
:2 7 4 :3 1 7 :2 10 19 1b :2 19
7 :2 10 1c 7 1f :2 4 7 :2 11
23 :2 2d 39 3c 50 53 54 :2 50
:2 23 :3 7 :2 d 12 1e 62 65 :2 1e
72 75 :2 1e 79 7c :2 1e 86 89
92 9a :2 a3 :2 92 ae :2 89 :2 1e b6
b9 :2 1e c1 c4 :2 1e c9 cc :2 1e
d2 d5 :2 1e :2 7 57 :3 4 :2 f 21
:2 2a 34 3b :2 4 1 9 12 9
a :2 14 26 :2 30 3c 40 54 57
58 :2 54 :2 26 :3 a :2 10 15 21 65
68 :2 21 :3 a :2 10 15 39 5c 5f
:2 68 :2 39 76 79 :2 39 81 84 :2 8d
:2 39 :2 a 5b :3 7 c 15 1e 2c
a 13 1e f e 7 e 7
e 7 29 :2 4 :2 9 7 :2 10 1c
:2 7 :2 11 23 :2 2d 39 3d 51 54
55 :2 51 :2 23 :3 7 :2 d 12 1e 62
65 :2 1e :3 7 :2 d 12 36 42 45
:2 36 4d 50 :2 36 5c 5f 66 6f
72 :2 5f :2 36 :2 7 58 :2 4 7 c
1b a 13 1e f e 7 e
7 e 7 :2 4 :4 10 :2 4 :8 1 
14b0
4
0 :2 1 :4 3 :4 4
2 :4 5 :2 1 :a 7
:a 8 :7 9 :5 a :7 b
:7 c :7 d :7 e :7 f
:5 10 :5 11 :6 12 :6 13
:6 14 :6 15 :6 16 :6 17
:6 18 :6 19 :6 1a :6 1b
:6 1c :6 1d :6 1e :6 1f
:6 20 :7 21 :2 23 0
:2 23 :4 24 :5 25 :8 26
:5 27 :4 28 24 :5 23
:7 2b :2 2d 0 :2 2d
:4 2e :5 2f 2e :5 2d
:2 31 0 :2 31 :2 32
33 :3 34 32 :5 31
:7 36 :b 38 :11 39 3a
:2 39 :2 3a :2 39 :2 3a
:2 39 :2 3b :2 39 :9 3b
:2 39 :2 3b :4 39 :3 38
:11 3e :b 3f :3 3e :3 45
:3 46 :7 49 :5 4a 48
:2 4c :5 4e :11 4f :24 50
:3 4f :2 4d :6 4c 4b
:3 37 :a 56 :4 58 :3 59
:5 5a 58 :5 5b 57
:2 5d :5 5f :11 60 :24 61
:3 60 :2 5e :6 5d 5c
:3 56 :a 66 :11 67 :20 68
:3 67 :11 6a :b 6b :3 6a
:9 6d 6e 66 :16 6e
:11 6f :30 70 :3 6f :11 72
:b 73 :3 72 :a 75 6e
:3 66 :7 79 :5 7a 78
:2 7c :5 7e :11 7f :24 80
:3 7f :2 7d :6 7c 7b
:3 56 :2 85 :2 86 :2 85
:2 86 :2 85 :2 87 :3 85
56 :3 89 :9 8c 8f
:7 90 :4 91 :4 92 :4 93
:2 94 95 96 97
98 99 :2 9a :2 9b
9c :24 9d 8f :6 9e
:5 9f 9e :5 a1 a0
:3 9e 8e :2 a4 :5 a6
:11 a7 :24 a8 :3 a7 :2 a5
:6 a4 a3 :3 8c :5 ad
af :6 b0 :3 b1 :5 b2
b1 :5 b4 b3 :3 b1
:a b6 :2 b7 :3 b6 bb
bc :4 bd :4 be :4 bf
:2 c0 :2 c1 :4 c2 :4 c3
:2 c4 :4 c5 :4 c6 :6 c7
:6 c8 :4 c9 :3 ca :2 cb
bb :6 cc :5 cd cc
:5 cf ce :3 cc ba
:2 d2 :5 d4 :11 d5 :24 d6
:3 d5 :2 d3 :6 d2 d1
:3 af :2 dc :4 dd dc
:6 de :5 df de :5 e1
e0 :3 de db :2 e4
:5 e6 :11 e7 :24 e8 :3 e7
:2 e5 :6 e4 e3 :4 af
ec 8c :4 f0 :5 f1
ef :2 f3 :5 f5 :11 f6
:24 f7 :3 f6 :2 f4 :6 f3
f2 :6 8c :4 fe :5 ff
fe :6 100 :5 101 100
:5 103 102 :3 100 fd
:2 106 :5 108 :11 109 :24 10a
:3 109 :2 107 :6 106 105
:3 88 :3 10f :3 110 112
113 :2 114 :2 113 :2 114
:2 113 :2 115 :2 113 112
88 :3 56 :5 11c 11e
:8 11f :3 120 :5 121 120
:5 123 122 :3 120 :a 126
:2 127 :3 126 12b 12d
:2 132 :4 133 :4 134 :4 135
:4 136 :4 137 :4 138 :4 139
132 :6 13a :5 13b 13a
:5 13d 13c :3 13a 131
:2 140 :5 142 :11 143 :24 144
:3 143 :2 141 :6 140 13f
:3 12d :2 14b :10 14c :8 14d
:10 14e :8 14f :12 150 :c 151
:10 152 :2 153 14b :6 154
:5 155 154 :5 157 156
:3 154 14a :2 15a :5 15c
:11 15d :24 15e :3 15d :2 15b
:6 15a 159 :3 12d 164
:2 165 :2 166 :4 167 :2 168
:2 169 :4 16a :2 16b :2 16c
:4 16d :2 16e :2 16f :4 170
:2 171 :2 172 :4 173 :2 174
:2 175 :2 176 :3 177 :3 178
:3 179 :2 17a 164 :6 17b
:5 17c 17b :5 17e 17d
:3 17b 163 :2 181 :5 183
:11 184 :24 185 :3 184 :2 182
:6 181 180 :6 12d 18c
:7 191 :5 192 190 :2 194
:5 196 :11 197 :24 198 :3 197
:2 195 :6 194 193 :3 18c
:12 19d :2 19e :3 19d :4 1a2
:2 1a3 :6 1a4 1a2 :5 1a5
1a1 :2 1a7 :5 1a9 :11 1aa
:24 1ab :3 1aa :2 1a8 :6 1a7
1a6 :3 18c :12 1b1 :9 1b2
:3 1b3 1b2 :4 1b7 :6 1b8
:5 1b9 1b8 :5 1bb 1ba
:3 1b8 1b6 :2 1be :5 1c0
:11 1c1 :24 1c2 :3 1c1 :2 1bf
:6 1be 1bd :3 1b4 :4 1c8
:6 1c9 :5 1ca 1c9 :5 1cc
1cb :3 1c9 1c7 :2 1cf
:5 1d1 :11 1d2 :24 1d3 :3 1d2
:2 1d0 :6 1cf 1ce :3 1b4
:4 1d9 :6 1da :5 1db 1da
:5 1dd 1dc :3 1da 1d8
:2 1e0 :5 1e2 :11 1e3 :24 1e4
:3 1e3 :2 1e1 :6 1e0 1df
:3 1b4 :4 1ea :6 1eb :5 1ec
1eb :5 1ee 1ed :3 1eb
1e9 :2 1f1 :5 1f3 :11 1f4
:24 1f5 :3 1f4 :2 1f2 :6 1f1
1f0 :3 1b4 :3 1fa 1b4
:3 1b2 1b1 :3 1fd :3 1fe
1fc :3 1b1 :3 201 :5 206
208 :7 209 :3 20a :5 20b
20a :5 20d 20c :3 20a
:a 210 :2 211 :3 210 :9 215
:4 217 :5 218 :6 219 217
:6 21a :5 21b 21a :5 21d
21c :3 21a 216 :2 220
:5 222 :11 223 :24 224 :3 223
:2 221 :6 220 21f :3 215
:a 22a :8 22c :6 22d :5 22e
22d :5 230 22f :3 22d
22b :2 233 :5 235 :11 236
:24 237 :3 236 :2 234 :6 233
232 :4 22a :a 23d :6 23e
:5 23f 23e :5 241 240
:3 23e 23c :2 244 :5 246
:11 247 :24 248 :3 247 :2 245
:6 244 243 :4 23b :3 22a
24d 215 :9 24d :a 24f
:6 250 :5 251 250 :5 253
252 :3 250 24e :2 256
:5 258 :11 259 :24 25a :3 259
:2 257 :6 256 255 :4 24d
:3 215 208 25f 18c
:4 261 :5 262 260 :2 264
:5 266 :11 267 :24 268 :3 267
:2 265 :6 264 263 :3 18c
:4 26e :4 26f 26e :6 270
:5 271 270 :5 273 272
:3 270 26d :2 276 :5 278
:11 279 :24 27a :3 279 :2 277
:6 276 275 :3 18c :9 27f
281 282 :6 283 :2 284
:2 285 :2 286 :2 287 :2 288
:2 289 :2 28a :4 28b :4 28c
:2 28d :5 28e :6 28f :4 290
:3 291 292 :4 293 281
:6 294 :5 295 294 :5 297
296 :3 294 280 :2 29a
:5 29c :11 29d :24 29e :3 29d
:2 29b :6 29a 299 :3 27f
:9 2a3 :3 2a5 :a 2a6 :3 2a3
27f :5 2ab 2ad :6 2ae
:3 2af :5 2b0 2af :5 2b2
2b1 :3 2af :a 2b4 :2 2b5
:3 2b4 2b9 2ba :3 2bb
:3 2bc :2 2bd :2 2be :2 2bf
:2 2c0 :2 2c1 :2 2c2 :2 2c3
:4 2c4 :4 2c5 :2 2c6 :5 2c7
:6 2c8 :4 2c9 :3 2ca :2 2cb
:2 2cc 2b9 :6 2cd :5 2ce
2cd :5 2d0 2cf :3 2cd
2b8 :2 2d3 :5 2d5 :11 2d6
:24 2d7 :3 2d6 :2 2d4 :6 2d3
2d2 :3 2ad :7 2df :6 2e0
:5 2e1 2e0 :5 2e3 2e2
:3 2e0 2de :2 2e6 :5 2e8
:11 2e9 :24 2ea :3 2e9 :2 2e7
:6 2e6 2e5 :4 2ad 2ee
2a8 :4 2f1 :5 2f2 2f0
:2 2f4 :5 2f6 :11 2f7 :24 2f8
:3 2f7 :2 2f5 :6 2f4 2f3
:3 2a8 :16 2fd :6 2ff :6 300
:5 301 300 :5 303 302
:3 300 2fe :2 306 :5 308
:11 309 :24 30a :3 309 :2 307
:6 306 305 :6 2fd :3 311
:a 312 :7 315 :7 316 :3 317
315 :5 318 314 :2 31a
:5 31c :11 31d :24 31e :3 31d
:2 31b :6 31a 319 :3 2a8
:9 324 326 327 328
329 32a 32b :2 32c
:2 32d :2 32e :3 32f 330
:4 331 326 :6 332 :5 333
332 :5 335 334 :3 332
325 :2 338 :5 33a :11 33b
:24 33c :3 33b :2 339 :6 338
337 :4 324 342 343
344 345 346 347
:2 348 :2 349 :2 34a :3 34b
:3 34c :4 34d 342 :6 34e
:5 34f 34e :5 351 350
:3 34e 341 :2 354 :5 356
:11 357 :24 358 :3 357 :2 355
:6 354 353 :4 340 :3 324
2a8 :3 27f 360 361
:5 18c 363 362 :3 12b
:7 368 :6 369 :5 36a 369
:5 36c 36b :3 369 367
:2 36f :5 371 :11 372 :24 373
:3 372 :2 370 :6 36f 36e
:4 11e 378 37 :4 37c
:5 37d 37b :2 37f :5 381
:11 382 :24 383 :3 382 :2 380
:6 37f 37e :3 37 :6 388
:9 38c 38d :3 38e 38c
:5 38f 38b :2 391 :5 393
:11 394 :24 395 :3 394 :2 392
:6 391 390 :3 37 :9 39a
:5 39b :a 39c :3 39a 3a0
:5 3a1 :2 3a2 3a0 :6 3a3
:5 3a4 3a3 :5 3a6 3a5
:3 3a3 39f :2 3a9 :5 3ab
:11 3ac :24 3ad :3 3ac :2 3aa
:6 3a9 3a8 :3 37 :7 3b2
:5 3b3 :3 3b2 :11 3b6 :30 3b7
:3 3b6 :a 3b9 37 :3 3bc
:11 3bd :b 3be :17 3bf :3 3bd
:2 3c1 :3 3c2 :3 3c3 3c4
3c2 3c1 3c2 :3 3c5
:3 3bc :2 3c6 :5 3c8 :11 3c9
:b 3ca :18 3cb :3 3c9 :2 3cd
3ce :3 3cf 3d0 3ce
3cd 3ce :3 3d1 :2 3c7
:6 3c6 3bb :7 1 
4a6b
4
:3 0 1 :3 0 2
:a 0 14ab 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 d
e 0 7 6
:3 0 5 :7 0 9
8 :3 0 7 :3 0
8 :3 0 9 :2 0
4 b f 0
14ab 2 10 :2 0
c :2 0 c b
:3 0 c :2 0 a
13 15 2 :5 0
d :3 0 e :3 0
17 18 0 1b
16 19 14a9 0
a :6 0 11 :2 0
10 b :3 0 e
1d 1f 2 :5 0
d :3 0 e :3 0
21 22 0 25
20 23 14a9 0
f :6 0 16 c9
0 14 4 :3 0
12 27 29 :6 0
2c 2a 0 14a9
0 10 :6 0 11
:2 0 1a 13 :3 0
2e :7 0 31 2f
0 14a9 0 12
:6 0 4 :3 0 11
:2 0 18 33 35
:6 0 38 36 0
14a9 0 14 :6 0
11 :2 0 1e 4
:3 0 1c 3a 3c
:6 0 3f 3d 0
14a9 0 15 :6 0
11 :2 0 22 4
:3 0 20 41 43
:6 0 46 44 0
14a9 0 16 :6 0
11 :2 0 26 4
:3 0 24 48 4a
:6 0 4d 4b 0
14a9 0 17 :6 0
2c 175 0 2a
4 :3 0 28 4f
51 :6 0 54 52
0 14a9 0 18
:6 0 1d :2 0 2e
1a :3 0 56 :7 0
59 57 0 14a9
0 19 :6 0 1a
:3 0 5b :7 0 5e
5c 0 14a9 0
1b :6 0 1d :2 0
30 6 :3 0 60
:7 0 64 61 62
14a9 0 1c :6 0
1d :2 0 32 6
:3 0 66 :7 0 6a
67 68 14a9 0
1e :6 0 1d :2 0
34 6 :3 0 6c
:7 0 70 6d 6e
14a9 0 1f :6 0
1d :2 0 36 6
:3 0 72 :7 0 76
73 74 14a9 0
20 :6 0 1d :2 0
38 6 :3 0 78
:7 0 7c 79 7a
14a9 0 21 :6 0
1d :2 0 3a 6
:3 0 7e :7 0 82
7f 80 14a9 0
22 :6 0 1d :2 0
3c 6 :3 0 84
:7 0 88 85 86
14a9 0 23 :6 0
1d :2 0 3e 6
:3 0 8a :7 0 8e
8b 8c 14a9 0
24 :6 0 1d :2 0
40 6 :3 0 90
:7 0 94 91 92
14a9 0 25 :6 0
1d :2 0 42 6
:3 0 96 :7 0 9a
97 98 14a9 0
26 :6 0 1d :2 0
44 6 :3 0 9c
:7 0 a0 9d 9e
14a9 0 27 :6 0
1d :2 0 46 6
:3 0 a2 :7 0 a6
a3 a4 14a9 0
28 :6 0 2c :2 0
48 6 :3 0 a8
:7 0 ac a9 aa
14a9 0 29 :6 0
2c :2 0 4a 2b
:3 0 ae :7 0 b2
af b0 14a9 0
2a :6 0 2f :2 0
4c 2b :3 0 b4
:7 0 b8 b5 b6
14a9 0 2d :9 0
50 4 :3 0 4e
ba bc :6 0 bf
bd 0 14a9 0
2e :6 0 30 :3 0
31 :a 0 2 e0
:4 0 c1 c4 0
c2 :3 0 32 :3 0
33 :3 0 32 :3 0
34 :3 0 35 :3 0
32 :3 0 36 :3 0
37 :3 0 38 :3 0
38 :3 0 39 :3 0
32 :3 0 39 :3 0
38 :3 0 3a :3 0
32 :3 0 3b :3 0
38 :3 0 39 :3 0
10 :3 0 32 :3 0
3c :3 0 32 :3 0
3d :3 0 32 :3 0
3e :4 0 3f 1
:8 0 e1 c1 c4
e2 0 14a9 52
e2 e4 e1 e3
:6 0 e0 :7 0 e2
:3 0 54 8 :3 0
9 :2 0 4 e6
e7 0 e8 :7 0
eb e9 0 14a9
0 40 :6 0 30
:3 0 41 :a 0 3
fb :4 0 ed f0
0 ee :3 0 42
:3 0 43 :3 0 44
:3 0 45 :3 0 39
:3 0 10 :3 0 33
:3 0 16 :3 0 3c
:4 0 46 1 :8 0
fc ed f0 fd
0 14a9 56 fd
ff fc fe :6 0
fb :7 0 fd 30
:3 0 47 :a 0 4
10c :5 0 101 104
0 102 :3 0 3b
:3 0 33 :3 0 35
:3 0 3c :3 0 3e
:3 0 16 :4 0 48
1 :8 0 10d 101
104 10e 0 14a9
58 10e 110 10d
10f :6 0 10c :7 0
10e 118 119 0
5a 8 :3 0 9
:2 0 4 112 113
0 114 :7 0 117
115 0 14a9 0
49 :6 0 4a :3 0
4b :3 0 4a :3 0
4c :3 0 11b 11c
0 2 :4 0 5c
11d 11f 11a 121
120 :2 0 4d :3 0
4e :3 0 123 124
0 4f :4 0 4a
:3 0 50 :3 0 127
128 0 2 :4 0
5e 129 12b 51
:4 0 52 :2 0 53
:3 0 60 12e 130
:3 0 54 :4 0 52
:2 0 55 :4 0 63
133 135 :3 0 52
:2 0 3 :3 0 66
137 139 :3 0 52
:2 0 55 :4 0 69
13b 13d :3 0 52
:2 0 56 :4 0 6c
13f 141 :3 0 52
:2 0 57 :3 0 58
:3 0 5 :3 0 6f
145 147 59 :4 0
71 144 14a 74
143 14c :3 0 52
:2 0 5a :4 0 77
14e 150 :3 0 7a
125 152 :2 0 154
7f 155 122 154
0 156 81 0
1409 4a :3 0 4b
:3 0 157 158 0
4a :3 0 5b :3 0
15a 15b 0 5c
:2 0 2 :4 0 5d
:2 0 5e :2 0 5c
:2 0 83 160 162
:3 0 86 15c 164
159 166 165 :2 0
4d :3 0 5f :3 0
168 169 0 4f
:4 0 60 :4 0 52
:2 0 53 :3 0 8a
16d 16f :3 0 8d
16a 171 :2 0 173
90 174 167 173
0 175 92 0
1409 21 :3 0 5
:3 0 176 177 0
1409 16 :3 0 3
:3 0 179 17a 0
1409 57 :3 0 61
:3 0 22 :3 0 37
:3 0 3a :3 0 16
:4 0 62 1 :8 0
188 8 :3 0 63
:3 0 183 184 0
64 :3 0 185 186
0 188 94 1d2
65 :3 0 8 :3 0
63 :3 0 18b 18c
0 64 :3 0 18d
18e 0 1c8 4a
:3 0 4b :3 0 190
191 0 4a :3 0
5b :3 0 193 194
0 66 :2 0 2
:4 0 67 :2 0 5e
:2 0 5c :2 0 97
199 19b :3 0 9a
195 19d 192 19f
19e :2 0 4d :3 0
5f :3 0 1a1 1a2
0 4f :4 0 68
:4 0 52 :2 0 53
:3 0 9e 1a6 1a8
:3 0 52 :2 0 69
:4 0 a1 1aa 1ac
:3 0 52 :2 0 6a
:4 0 a4 1ae 1b0
:3 0 52 :2 0 64
:3 0 a7 1b2 1b4
:3 0 52 :2 0 6b
:4 0 aa 1b6 1b8
:3 0 52 :2 0 6c
:3 0 6d :3 0 5c
:2 0 6e :2 0 ad
1bb 1bf b1 1ba
1c1 :3 0 b4 1a3
1c3 :2 0 1c5 b7
1c6 1a0 1c5 0
1c7 b9 0 1c8
bb 1cb :3 0 1cb
0 1cb 1ca 1c8
1c9 :6 0 1cd 5
:3 0 be 1cf c0
1ce 1cd :2 0 1d0
c2 :2 0 1d2 0
1d2 1d1 188 1d0
:6 0 1409 1 :3 0
8 :3 0 63 :3 0
1d4 1d5 0 8
:3 0 6f :2 0 70
:3 0 1d7 1d9 0
c6 1d8 1db :3 0
1dc :2 0 39 :3 0
39 :3 0 3b :3 0
3e :3 0 10 :3 0
26 :3 0 25 :3 0
35 :3 0 71 :3 0
3d :3 0 33 :3 0
16 :4 0 72 1
:8 0 1f0 8 :3 0
63 :3 0 1eb 1ec
0 64 :3 0 1ed
1ee 0 1f0 c9
23a 65 :3 0 8
:3 0 63 :3 0 1f3
1f4 0 64 :3 0
1f5 1f6 0 230
4a :3 0 4b :3 0
1f8 1f9 0 4a
:3 0 5b :3 0 1fb
1fc 0 66 :2 0
2 :4 0 73 :2 0
5e :2 0 5c :2 0
cc 201 203 :3 0
cf 1fd 205 1fa
207 206 :2 0 4d
:3 0 5f :3 0 209
20a 0 4f :4 0
74 :4 0 52 :2 0
53 :3 0 d3 20e
210 :3 0 52 :2 0
69 :4 0 d6 212
214 :3 0 52 :2 0
6a :4 0 d9 216
218 :3 0 52 :2 0
64 :3 0 dc 21a
21c :3 0 52 :2 0
6b :4 0 df 21e
220 :3 0 52 :2 0
6c :3 0 6d :3 0
5c :2 0 6e :2 0
e2 223 227 e6
222 229 :3 0 e9
20b 22b :2 0 22d
ec 22e 208 22d
0 22f ee 0
230 f0 233 :3 0
233 0 233 232
230 231 :6 0 235
7 :3 0 f3 237
f5 236 235 :2 0
238 f7 :2 0 23a
0 23a 239 1f0
238 :6 0 392 1
:3 0 8 :3 0 63
:3 0 23c 23d 0
8 :3 0 6f :2 0
70 :3 0 23f 241
0 fb 240 243
:3 0 244 :2 0 4a
:3 0 4b :3 0 246
247 0 4a :3 0
5b :3 0 249 24a
0 75 :2 0 2
:4 0 76 :2 0 5e
:2 0 5c :2 0 fe
24f 251 :3 0 101
24b 253 248 255
254 :2 0 4d :3 0
5f :3 0 257 258
0 4f :4 0 77
:4 0 52 :2 0 53
:3 0 105 25c 25e
:3 0 52 :2 0 69
:4 0 108 260 262
:3 0 52 :2 0 78
:4 0 10b 264 266
:3 0 52 :2 0 57
:3 0 58 :3 0 d
:3 0 79 :3 0 26b
26c 0 10e 26a
26e 59 :4 0 110
269 271 113 268
273 :3 0 116 259
275 :2 0 277 119
278 256 277 0
279 11b 0 2a3
4a :3 0 4b :3 0
27a 27b 0 4a
:3 0 5b :3 0 27d
27e 0 5c :2 0
2 :4 0 7a :2 0
5e :2 0 5c :2 0
11d 283 285 :3 0
120 27f 287 27c
289 288 :2 0 4d
:3 0 5f :3 0 28b
28c 0 4f :4 0
7b :4 0 52 :2 0
53 :3 0 124 290
292 :3 0 127 28d
294 :2 0 296 12a
297 28a 296 0
298 12c 0 2a3
7c :3 0 7d :3 0
299 29a 0 d
:3 0 79 :3 0 29c
29d 0 7e :3 0
12e 29b 2a0 :2 0
2a3 7f :3 0 131
329 57 :3 0 26
:3 0 1d :2 0 135
2a4 2a7 6f :2 0
1d :2 0 13a 2a9
2ab :3 0 2ac :2 0
57 :3 0 25 :3 0
1d :2 0 13d 2ae
2b1 6f :2 0 5c
:2 0 142 2b3 2b5
:3 0 2b6 :2 0 2ad
2b8 2b7 :2 0 4a
:3 0 4b :3 0 2ba
2bb 0 4a :3 0
5b :3 0 2bd 2be
0 11 :2 0 2
:4 0 80 :2 0 5e
:2 0 5c :2 0 145
2c3 2c5 :3 0 148
2bf 2c7 2bc 2c9
2c8 :2 0 4d :3 0
5f :3 0 2cb 2cc
0 4f :4 0 81
:4 0 52 :2 0 53
:3 0 14c 2d0 2d2
:3 0 52 :2 0 69
:4 0 14f 2d4 2d6
:3 0 52 :2 0 78
:4 0 152 2d8 2da
:3 0 52 :2 0 57
:3 0 58 :3 0 d
:3 0 82 :3 0 2df
2e0 0 155 2de
2e2 59 :4 0 157
2dd 2e5 15a 2dc
2e7 :3 0 52 :2 0
83 :4 0 15d 2e9
2eb :3 0 52 :2 0
55 :4 0 160 2ed
2ef :3 0 52 :2 0
16 :3 0 163 2f1
2f3 :3 0 52 :2 0
55 :4 0 166 2f5
2f7 :3 0 169 2cd
2f9 :2 0 2fb 16c
2fc 2ca 2fb 0
2fd 16e 0 327
4a :3 0 4b :3 0
2fe 2ff 0 4a
:3 0 5b :3 0 301
302 0 5c :2 0
2 :4 0 84 :2 0
5e :2 0 5c :2 0
170 307 309 :3 0
173 303 30b 300
30d 30c :2 0 4d
:3 0 5f :3 0 30f
310 0 4f :4 0
85 :4 0 52 :2 0
53 :3 0 177 314
316 :3 0 17a 311
318 :2 0 31a 17d
31b 30e 31a 0
31c 17f 0 327
7c :3 0 86 :3 0
31d 31e 0 d
:3 0 82 :3 0 320
321 0 16 :3 0
7e :3 0 181 31f
325 :2 0 327 185
328 2b9 327 0
32a 245 2a3 0
32a 189 0 392
57 :3 0 61 :3 0
22 :3 0 37 :3 0
3a :3 0 10 :4 0
87 1 :8 0 337
8 :3 0 63 :3 0
332 333 0 64
:3 0 334 335 0
337 18c 381 65
:3 0 8 :3 0 63
:3 0 33a 33b 0
64 :3 0 33c 33d
0 377 4a :3 0
4b :3 0 33f 340
0 4a :3 0 5b
:3 0 342 343 0
66 :2 0 2 :4 0
88 :2 0 5e :2 0
5c :2 0 18f 348
34a :3 0 192 344
34c 341 34e 34d
:2 0 4d :3 0 5f
:3 0 350 351 0
4f :4 0 89 :4 0
52 :2 0 53 :3 0
196 355 357 :3 0
52 :2 0 69 :4 0
199 359 35b :3 0
52 :2 0 6a :4 0
19c 35d 35f :3 0
52 :2 0 64 :3 0
19f 361 363 :3 0
52 :2 0 6b :4 0
1a2 365 367 :3 0
52 :2 0 6c :3 0
6d :3 0 5c :2 0
6e :2 0 1a5 36a
36e 1a9 369 370
:3 0 1ac 352 372
:2 0 374 1af 375
34f 374 0 376
1b1 0 377 1b3
37a :3 0 37a 0
37a 379 377 378
:6 0 37c 9 :3 0
1b6 37e 1b8 37d
37c :2 0 37f 1ba
:2 0 381 0 381
380 337 37f :6 0
392 1 :3 0 2e
:3 0 8a :4 0 52
:2 0 8b :4 0 1bc
385 387 :3 0 52
:2 0 16 :3 0 1bf
389 38b :3 0 52
:2 0 8c :4 0 1c2
38d 38f :3 0 383
390 0 392 1c5
651 10 :3 0 16
:3 0 393 394 0
650 57 :3 0 21
:3 0 1d :2 0 1ca
396 399 6f :2 0
8d :2 0 1cf 39b
39d :3 0 37 :3 0
8e :3 0 8e :3 0
d :3 0 8f :3 0
d :3 0 90 :3 0
8e :3 0 91 :3 0
57 :3 0 92 :3 0
91 :3 0 93 :3 0
57 :3 0 94 :3 0
93 :3 0 95 :3 0
96 :3 0 95 :3 0
96 :3 0 97 :3 0
98 :3 0 92 :3 0
94 :3 0 96 :3 0
99 :3 0 9a :3 0
9b :3 0 98 :3 0
9c :3 0 98 :3 0
9d :3 0 39 :3 0
10 :3 0 8e :3 0
d :3 0 9e :3 0
d :3 0 9f :3 0
d :3 0 a0 :3 0
d :3 0 a1 :3 0
d :3 0 a2 :3 0
d :3 0 a3 :3 0
d :3 0 a4 :3 0
d :3 0 a5 :3 0
d :3 0 a6 :3 0
d :3 0 a7 :3 0
d :3 0 a8 :3 0
d :3 0 a9 :3 0
d :3 0 aa :3 0
d :3 0 ab :3 0
d :3 0 ac :3 0
ad :3 0 ae :3 0
97 :4 0 af 1
:8 0 3f9 b0 :4 0
3e4 :3 0 7e :3 0
6f :2 0 1d4 3e7
3e8 :3 0 8 :3 0
63 :3 0 3ea 3eb
0 1d :2 0 3ec
3ed 0 3ef 1d7
3f6 8 :3 0 63
:3 0 3f0 3f1 0
b1 :2 0 3f2 3f3
0 3f5 1d9 3f7
3e9 3ef 0 3f8
0 3f5 0 3f8
1db 0 3f9 1de
443 65 :3 0 8
:3 0 63 :3 0 3fc
3fd 0 64 :3 0
3fe 3ff 0 439
4a :3 0 4b :3 0
401 402 0 4a
:3 0 5b :3 0 404
405 0 66 :2 0
2 :4 0 b2 :2 0
5e :2 0 5c :2 0
1e1 40a 40c :3 0
1e4 406 40e 403
410 40f :2 0 4d
:3 0 5f :3 0 412
413 0 4f :4 0
b3 :4 0 52 :2 0
53 :3 0 1e8 417
419 :3 0 52 :2 0
69 :4 0 1eb 41b
41d :3 0 52 :2 0
6a :4 0 1ee 41f
421 :3 0 52 :2 0
64 :3 0 1f1 423
425 :3 0 52 :2 0
6b :4 0 1f4 427
429 :3 0 52 :2 0
6c :3 0 6d :3 0
5c :2 0 6e :2 0
1f7 42c 430 1fb
42b 432 :3 0 1fe
414 434 :2 0 436
201 437 411 436
0 438 203 0
439 205 43c :3 0
43c 0 43c 43b
439 43a :6 0 43e
b :3 0 208 440
20a 43f 43e :2 0
441 20c :2 0 443
0 443 442 3f9
441 :6 0 5cd 1
:3 0 b4 :3 0 31
:4 0 448 :2 0 5cd
446 449 :3 0 b5
:3 0 31 :3 0 17
:3 0 14 :4 0 44f
:2 0 575 44b 450
:3 0 20e :3 0 31
:3 0 b0 :3 0 451
452 :3 0 8 :3 0
63 :3 0 454 455
0 1d :2 0 456
457 0 459 211
460 8 :3 0 63
:3 0 45a 45b 0
b1 :2 0 45c 45d
0 45f 213 461
453 459 0 462
0 45f 0 462
215 0 575 8
:3 0 63 :3 0 463
464 0 8 :3 0
b6 :2 0 b7 :3 0
466 468 0 21a
467 46a :3 0 46b
:2 0 b8 :8 0 46f
21d 470 46c 46f
0 471 21f 0
575 35 :3 0 3c
:3 0 91 :3 0 57
:3 0 92 :3 0 91
:3 0 93 :3 0 57
:3 0 94 :3 0 93
:3 0 95 :3 0 96
:3 0 96 :3 0 95
:3 0 b9 :3 0 ba
:3 0 9c :3 0 ba
:3 0 bb :3 0 57
:3 0 92 :3 0 91
:3 0 bc :3 0 57
:3 0 94 :3 0 93
:3 0 bd :3 0 ba
:3 0 be :3 0 bf
:3 0 bf :3 0 be
:3 0 c0 :3 0 c1
:3 0 c1 :3 0 c0
:3 0 c2 :3 0 c3
:3 0 9c :3 0 ba
:3 0 c4 :3 0 c5
:3 0 c6 :3 0 c3
:3 0 9c :3 0 ba
:3 0 c7 :3 0 c8
:3 0 92 :3 0 94
:3 0 96 :3 0 ba
:3 0 99 :3 0 9a
:3 0 9d :3 0 33
:3 0 17 :4 0 c9
1 :8 0 4c1 b0
:4 0 4ac :3 0 7e
:3 0 6f :2 0 223
4af 4b0 :3 0 8
:3 0 63 :3 0 4b2
4b3 0 1d :2 0
4b4 4b5 0 4b7
226 4be 8 :3 0
63 :3 0 4b8 4b9
0 b1 :2 0 4ba
4bb 0 4bd 228
4bf 4b1 4b7 0
4c0 0 4bd 0
4c0 22a 0 4c1
22d 50b 65 :3 0
8 :3 0 63 :3 0
4c4 4c5 0 64
:3 0 4c6 4c7 0
501 4a :3 0 4b
:3 0 4c9 4ca 0
4a :3 0 5b :3 0
4cc 4cd 0 66
:2 0 2 :4 0 ca
:2 0 5e :2 0 5c
:2 0 230 4d2 4d4
:3 0 233 4ce 4d6
4cb 4d8 4d7 :2 0
4d :3 0 5f :3 0
4da 4db 0 4f
:4 0 cb :4 0 52
:2 0 53 :3 0 237
4df 4e1 :3 0 52
:2 0 69 :4 0 23a
4e3 4e5 :3 0 52
:2 0 6a :4 0 23d
4e7 4e9 :3 0 52
:2 0 64 :3 0 240
4eb 4ed :3 0 52
:2 0 6b :4 0 243
4ef 4f1 :3 0 52
:2 0 6c :3 0 6d
:3 0 5c :2 0 6e
:2 0 246 4f4 4f8
24a 4f3 4fa :3 0
24d 4dc 4fc :2 0
4fe 250 4ff 4d9
4fe 0 500 252
0 501 254 504
:3 0 504 0 504
503 501 502 :6 0
506 e :3 0 257
508 259 507 506
:2 0 509 25b :2 0
50b 0 50b 50a
4c1 509 :6 0 575
d :3 0 45 :3 0
3c :3 0 39 :3 0
10 :3 0 33 :3 0
17 :4 0 cc 1
:8 0 529 b0 :4 0
514 :3 0 7e :3 0
6f :2 0 25f 517
518 :3 0 8 :3 0
63 :3 0 51a 51b
0 1d :2 0 51c
51d 0 51f 262
526 8 :3 0 63
:3 0 520 521 0
b1 :2 0 522 523
0 525 264 527
519 51f 0 528
0 525 0 528
266 0 529 269
573 65 :3 0 8
:3 0 63 :3 0 52c
52d 0 64 :3 0
52e 52f 0 569
4a :3 0 4b :3 0
531 532 0 4a
:3 0 5b :3 0 534
535 0 66 :2 0
2 :4 0 cd :2 0
5e :2 0 5c :2 0
26c 53a 53c :3 0
26f 536 53e 533
540 53f :2 0 4d
:3 0 5f :3 0 542
543 0 4f :4 0
ce :4 0 52 :2 0
53 :3 0 273 547
549 :3 0 52 :2 0
69 :4 0 276 54b
54d :3 0 52 :2 0
6a :4 0 279 54f
551 :3 0 52 :2 0
64 :3 0 27c 553
555 :3 0 52 :2 0
6b :4 0 27f 557
559 :3 0 52 :2 0
6c :3 0 6d :3 0
5c :2 0 6e :2 0
282 55c 560 286
55b 562 :3 0 289
544 564 :2 0 566
28c 567 541 566
0 568 28e 0
569 290 56c :3 0
56c 0 56c 56b
569 56a :6 0 56e
10 :3 0 293 570
295 56f 56e :2 0
571 297 :2 0 573
0 573 572 529
571 :6 0 575 d
:3 0 299 577 b5
:4 0 575 :4 0 5cd
cf :3 0 31 :4 0
57b :2 0 581 579
0 8 :3 0 63
:3 0 57c 57d 0
64 :3 0 57e 57f
0 581 29f 5cb
65 :3 0 8 :3 0
63 :3 0 584 585
0 64 :3 0 586
587 0 5c1 4a
:3 0 4b :3 0 589
58a 0 4a :3 0
5b :3 0 58c 58d
0 66 :2 0 2
:4 0 d0 :2 0 5e
:2 0 5c :2 0 2a2
592 594 :3 0 2a5
58e 596 58b 598
597 :2 0 4d :3 0
5f :3 0 59a 59b
0 4f :4 0 d1
:4 0 52 :2 0 53
:3 0 2a9 59f 5a1
:3 0 52 :2 0 69
:4 0 2ac 5a3 5a5
:3 0 52 :2 0 6a
:4 0 2af 5a7 5a9
:3 0 52 :2 0 64
:3 0 2b2 5ab 5ad
:3 0 52 :2 0 6b
:4 0 2b5 5af 5b1
:3 0 52 :2 0 6c
:3 0 6d :3 0 5c
:2 0 6e :2 0 2b8
5b4 5b8 2bc 5b3
5ba :3 0 2bf 59c
5bc :2 0 5be 2c2
5bf 599 5be 0
5c0 2c4 0 5c1
2c6 5c4 :3 0 5c4
0 5c4 5c3 5c1
5c2 :6 0 5c6 12
:3 0 2c9 5c8 2cb
5c7 5c6 :2 0 5c9
2cd :2 0 5cb 0
5cb 5ca 581 5c9
:6 0 5cd 1 :3 0
2cf 5ce 39e 5cd
0 5cf 2d4 0
650 37 :3 0 d2
:3 0 d :3 0 d3
:3 0 39 :3 0 10
:3 0 ad :3 0 ae
:3 0 97 :4 0 d4
1 :8 0 5ef b0
:4 0 5da :3 0 7e
:3 0 6f :2 0 2d8
5dd 5de :3 0 8
:3 0 63 :3 0 5e0
5e1 0 1d :2 0
5e2 5e3 0 5e5
2db 5ec 8 :3 0
63 :3 0 5e6 5e7
0 b1 :2 0 5e8
5e9 0 5eb 2dd
5ed 5df 5e5 0
5ee 0 5eb 0
5ee 2df 0 5ef
2e2 639 65 :3 0
8 :3 0 63 :3 0
5f2 5f3 0 64
:3 0 5f4 5f5 0
62f 4a :3 0 4b
:3 0 5f7 5f8 0
4a :3 0 5b :3 0
5fa 5fb 0 66
:2 0 2 :4 0 d5
:2 0 5e :2 0 5c
:2 0 2e5 600 602
:3 0 2e8 5fc 604
5f9 606 605 :2 0
4d :3 0 5f :3 0
608 609 0 4f
:4 0 d6 :4 0 52
:2 0 53 :3 0 2ec
60d 60f :3 0 52
:2 0 69 :4 0 2ef
611 613 :3 0 52
:2 0 6a :4 0 2f2
615 617 :3 0 52
:2 0 64 :3 0 2f5
619 61b :3 0 52
:2 0 6b :4 0 2f8
61d 61f :3 0 52
:2 0 6c :3 0 6d
:3 0 5c :2 0 6e
:2 0 2fb 622 626
2ff 621 628 :3 0
302 60a 62a :2 0
62c 305 62d 607
62c 0 62e 307
0 62f 309 632
:3 0 632 0 632
631 62f 630 :6 0
634 14 :3 0 30c
636 30e 635 634
:2 0 637 310 :2 0
639 0 639 638
5ef 637 :6 0 650
1 :3 0 26 :3 0
5c :2 0 63b 63c
0 650 21 :3 0
d7 :2 0 63e 63f
0 650 2e :3 0
d8 :4 0 52 :2 0
d9 :4 0 312 643
645 :3 0 52 :2 0
16 :3 0 315 647
649 :3 0 52 :2 0
8c :4 0 318 64b
64d :3 0 641 64e
0 650 31b 652
1dd 392 0 653
0 650 0 653
322 0 1409 b4
:3 0 40 :3 0 2e
:3 0 655 656 0
657 :2 0 1409 b5
:3 0 40 :3 0 16
:3 0 14 :3 0 15
:3 0 27 :4 0 660
:2 0 126a 65a 661
:3 0 325 :3 0 40
:3 0 b0 :3 0 662
663 :3 0 8 :3 0
63 :3 0 665 666
0 1d :2 0 667
668 0 66a 32a
671 8 :3 0 63
:3 0 66b 66c 0
b1 :2 0 66d 66e
0 670 32c 672
664 66a 0 673
0 670 0 673
32e 0 126a 8
:3 0 63 :3 0 674
675 0 8 :3 0
b6 :2 0 b7 :3 0
677 679 0 333
678 67b :3 0 67c
:2 0 b8 :8 0 680
336 681 67d 680
0 682 338 0
126a 21 :3 0 5c
:2 0 da :3 0 db
:3 0 db :3 0 dc
:3 0 db :3 0 dd
:3 0 db :3 0 dd
:3 0 db :3 0 de
:3 0 db :3 0 de
:3 0 db :3 0 df
:3 0 db :3 0 e0
:3 0 db :3 0 e1
:3 0 db :3 0 e1
:3 0 db :3 0 e2
:3 0 db :3 0 e2
:3 0 db :3 0 e3
:3 0 39 :3 0 10
:3 0 3a :3 0 15
:4 0 e4 1 :8 0
6b9 b0 :4 0 6a4
:3 0 7e :3 0 6f
:2 0 33c 6a7 6a8
:3 0 8 :3 0 63
:3 0 6aa 6ab 0
1d :2 0 6ac 6ad
0 6af 33f 6b6
8 :3 0 63 :3 0
6b0 6b1 0 b1
:2 0 6b2 6b3 0
6b5 341 6b7 6a9
6af 0 6b8 0
6b5 0 6b8 343
0 6b9 346 703
65 :3 0 8 :3 0
63 :3 0 6bc 6bd
0 64 :3 0 6be
6bf 0 6f9 4a
:3 0 4b :3 0 6c1
6c2 0 4a :3 0
5b :3 0 6c4 6c5
0 66 :2 0 2
:4 0 e5 :2 0 5e
:2 0 5c :2 0 349
6ca 6cc :3 0 34c
6c6 6ce 6c3 6d0
6cf :2 0 4d :3 0
5f :3 0 6d2 6d3
0 4f :4 0 e6
:4 0 52 :2 0 53
:3 0 350 6d7 6d9
:3 0 52 :2 0 69
:4 0 353 6db 6dd
:3 0 52 :2 0 6a
:4 0 356 6df 6e1
:3 0 52 :2 0 64
:3 0 359 6e3 6e5
:3 0 52 :2 0 6b
:4 0 35c 6e7 6e9
:3 0 52 :2 0 6c
:3 0 6d :3 0 5c
:2 0 6e :2 0 35f
6ec 6f0 363 6eb
6f2 :3 0 366 6d4
6f4 :2 0 6f6 369
6f7 6d1 6f6 0
6f8 36b 0 6f9
36d 6fc :3 0 6fc
0 6fc 6fb 6f9
6fa :6 0 6fe 17
:3 0 370 700 372
6ff 6fe :2 0 701
374 :2 0 703 0
703 702 6b9 701
:6 0 865 16 :3 0
35 :3 0 32 :3 0
32 :3 0 e7 :3 0
32 :3 0 e8 :3 0
32 :3 0 e9 :3 0
32 :3 0 ea :3 0
32 :3 0 eb :3 0
32 :3 0 ec :3 0
32 :3 0 ed :3 0
32 :3 0 ee :3 0
32 :3 0 ef :3 0
32 :3 0 f0 :3 0
32 :3 0 f1 :3 0
32 :3 0 f2 :3 0
32 :3 0 e8 :3 0
32 :3 0 f3 :3 0
32 :3 0 ea :3 0
32 :3 0 f4 :3 0
32 :3 0 ec :3 0
32 :3 0 f5 :3 0
32 :3 0 ee :3 0
32 :3 0 f6 :3 0
32 :3 0 f0 :3 0
32 :3 0 f7 :3 0
32 :3 0 f2 :3 0
32 :3 0 f8 :3 0
32 :3 0 f3 :3 0
32 :3 0 f9 :3 0
32 :3 0 f4 :3 0
32 :3 0 fa :3 0
32 :3 0 f5 :3 0
32 :3 0 fb :3 0
32 :3 0 f6 :3 0
32 :3 0 b9 :3 0
32 :3 0 ba :3 0
32 :3 0 f7 :3 0
32 :3 0 be :3 0
32 :3 0 bf :3 0
32 :3 0 f8 :3 0
32 :3 0 c0 :3 0
32 :3 0 c1 :3 0
32 :3 0 fc :3 0
32 :3 0 c4 :3 0
32 :3 0 fd :3 0
32 :3 0 c7 :3 0
32 :3 0 fe :3 0
32 :3 0 ff :3 0
32 :3 0 100 :3 0
32 :3 0 101 :3 0
33 :3 0 16 :4 0
102 1 :8 0 77d
b0 :4 0 768 :3 0
7e :3 0 6f :2 0
378 76b 76c :3 0
8 :3 0 63 :3 0
76e 76f 0 1d
:2 0 770 771 0
773 37b 77a 8
:3 0 63 :3 0 774
775 0 b1 :2 0
776 777 0 779
37d 77b 76d 773
0 77c 0 779
0 77c 37f 0
77d 382 7c7 65
:3 0 8 :3 0 63
:3 0 780 781 0
64 :3 0 782 783
0 7bd 4a :3 0
4b :3 0 785 786
0 4a :3 0 5b
:3 0 788 789 0
66 :2 0 2 :4 0
103 :2 0 5e :2 0
5c :2 0 385 78e
790 :3 0 388 78a
792 787 794 793
:2 0 4d :3 0 5f
:3 0 796 797 0
4f :4 0 104 :4 0
52 :2 0 53 :3 0
38c 79b 79d :3 0
52 :2 0 69 :4 0
38f 79f 7a1 :3 0
52 :2 0 6a :4 0
392 7a3 7a5 :3 0
52 :2 0 64 :3 0
395 7a7 7a9 :3 0
52 :2 0 6b :4 0
398 7ab 7ad :3 0
52 :2 0 6c :3 0
6d :3 0 5c :2 0
6e :2 0 39b 7b0
7b4 39f 7af 7b6
:3 0 3a2 798 7b8
:2 0 7ba 3a5 7bb
795 7ba 0 7bc
3a7 0 7bd 3a9
7c0 :3 0 7c0 0
7c0 7bf 7bd 7be
:6 0 7c2 19 :3 0
3ac 7c4 3ae 7c3
7c2 :2 0 7c5 3b0
:2 0 7c7 0 7c7
7c6 77d 7c5 :6 0
865 16 :3 0 105
:3 0 106 :3 0 107
:3 0 107 :3 0 108
:3 0 108 :3 0 109
:3 0 109 :3 0 10a
:3 0 10b :3 0 10c
:3 0 10c :3 0 10d
:3 0 10d :3 0 10e
:3 0 10e :3 0 10f
:3 0 110 :3 0 111
:3 0 111 :3 0 112
:3 0 112 :3 0 113
:3 0 113 :3 0 114
:3 0 115 :3 0 116
:3 0 116 :3 0 117
:3 0 117 :3 0 118
:3 0 118 :3 0 119
:3 0 11a :3 0 11b
:3 0 11b :3 0 11c
:3 0 11c :3 0 11d
:3 0 11d :3 0 11e
:3 0 11f :3 0 f9
:3 0 120 :3 0 fa
:3 0 121 :3 0 fb
:3 0 122 :3 0 b9
:3 0 ba :3 0 123
:3 0 be :3 0 bf
:3 0 124 :3 0 c0
:3 0 c1 :3 0 39
:3 0 10 :4 0 125
1 :8 0 819 b0
:4 0 804 :3 0 7e
:3 0 6f :2 0 3b4
807 808 :3 0 8
:3 0 63 :3 0 80a
80b 0 1d :2 0
80c 80d 0 80f
3b7 816 8 :3 0
63 :3 0 810 811
0 b1 :2 0 812
813 0 815 3b9
817 809 80f 0
818 0 815 0
818 3bb 0 819
3be 863 65 :3 0
8 :3 0 63 :3 0
81c 81d 0 64
:3 0 81e 81f 0
859 4a :3 0 4b
:3 0 821 822 0
4a :3 0 5b :3 0
824 825 0 66
:2 0 2 :4 0 126
:2 0 5e :2 0 5c
:2 0 3c1 82a 82c
:3 0 3c4 826 82e
823 830 82f :2 0
4d :3 0 5f :3 0
832 833 0 4f
:4 0 127 :4 0 52
:2 0 53 :3 0 3c8
837 839 :3 0 52
:2 0 69 :4 0 3cb
83b 83d :3 0 52
:2 0 6a :4 0 3ce
83f 841 :3 0 52
:2 0 64 :3 0 3d1
843 845 :3 0 52
:2 0 6b :4 0 3d4
847 849 :3 0 52
:2 0 6c :3 0 6d
:3 0 5c :2 0 6e
:2 0 3d7 84c 850
3db 84b 852 :3 0
3de 834 854 :2 0
856 3e1 857 831
856 0 858 3e3
0 859 3e5 85c
:3 0 85c 0 85c
85b 859 85a :6 0
85e 1b :3 0 3e8
860 3ea 85f 85e
:2 0 861 3ec :2 0
863 0 863 862
819 861 :6 0 865
16 :3 0 3ee 867
3f2 866 865 :2 0
1200 d7 :2 0 ba
:3 0 20 :3 0 35
:3 0 3c :3 0 33
:3 0 16 :4 0 128
1 :8 0 875 8
:3 0 63 :3 0 870
871 0 64 :3 0
872 873 0 875
3f4 8bf 65 :3 0
8 :3 0 63 :3 0
878 879 0 64
:3 0 87a 87b 0
8b5 4a :3 0 4b
:3 0 87d 87e 0
4a :3 0 5b :3 0
880 881 0 66
:2 0 2 :4 0 129
:2 0 5e :2 0 5c
:2 0 3f7 886 888
:3 0 3fa 882 88a
87f 88c 88b :2 0
4d :3 0 5f :3 0
88e 88f 0 4f
:4 0 12a :4 0 52
:2 0 53 :3 0 3fe
893 895 :3 0 52
:2 0 69 :4 0 401
897 899 :3 0 52
:2 0 6a :4 0 404
89b 89d :3 0 52
:2 0 64 :3 0 407
89f 8a1 :3 0 52
:2 0 6b :4 0 40a
8a3 8a5 :3 0 52
:2 0 6c :3 0 6d
:3 0 5c :2 0 6e
:2 0 40d 8a8 8ac
411 8a7 8ae :3 0
414 890 8b0 :2 0
8b2 417 8b3 88d
8b2 0 8b4 419
0 8b5 41b 8b8
:3 0 8b8 0 8b8
8b7 8b5 8b6 :6 0
8ba 1d :3 0 41e
8bc 420 8bb 8ba
:2 0 8bd 422 :2 0
8bf 0 8bf 8be
875 8bd :6 0 11fa
16 :3 0 8 :3 0
63 :3 0 8c1 8c2
0 8 :3 0 b6
:2 0 b7 :3 0 8c4
8c6 0 426 8c5
8c8 :3 0 8c9 :2 0
20 :3 0 12b :2 0
429 8cc 8cd :3 0
8ce :2 0 8cf :2 0
8ca 8d1 8d0 :2 0
12c :3 0 8d3 :4 0
8d5 42b 8d6 8d2
8d5 0 8d7 42d
0 11fa 33 :3 0
12d :3 0 12d :3 0
27 :3 0 18 :3 0
27 :3 0 35 :3 0
3c :3 0 3b :3 0
10 :3 0 34 :3 0
14 :4 0 12e 1
:8 0 8ea 8 :3 0
63 :3 0 8e5 8e6
0 64 :3 0 8e7
8e8 0 8ea 42f
934 65 :3 0 8
:3 0 63 :3 0 8ed
8ee 0 64 :3 0
8ef 8f0 0 92a
4a :3 0 4b :3 0
8f2 8f3 0 4a
:3 0 5b :3 0 8f5
8f6 0 66 :2 0
2 :4 0 12f :2 0
5e :2 0 5c :2 0
432 8fb 8fd :3 0
435 8f7 8ff 8f4
901 900 :2 0 4d
:3 0 5f :3 0 903
904 0 4f :4 0
130 :4 0 52 :2 0
53 :3 0 439 908
90a :3 0 52 :2 0
69 :4 0 43c 90c
90e :3 0 52 :2 0
6a :4 0 43f 910
912 :3 0 52 :2 0
64 :3 0 442 914
916 :3 0 52 :2 0
6b :4 0 445 918
91a :3 0 52 :2 0
6c :3 0 6d :3 0
5c :2 0 6e :2 0
448 91d 921 44c
91c 923 :3 0 44f
905 925 :2 0 927
452 928 902 927
0 929 454 0
92a 456 92d :3 0
92d 0 92d 92c
92a 92b :6 0 92f
1f :3 0 459 931
45b 930 92f :2 0
932 45d :2 0 934
0 934 933 8ea
932 :6 0 11fa 16
:3 0 8 :3 0 63
:3 0 936 937 0
8 :3 0 6f :2 0
b7 :3 0 939 93b
0 461 93a 93d
:3 0 93e :2 0 18
:3 0 131 :2 0 464
941 942 :3 0 943
:2 0 944 :2 0 93f
946 945 :2 0 57
:3 0 26 :3 0 1d
:2 0 466 948 94b
6f :2 0 1d :2 0
46b 94d 94f :3 0
1f :3 0 d7 :2 0
951 952 0 954
46e aed 35 :3 0
33 :3 0 16 :4 0
132 1 :8 0 96e
b0 :4 0 959 :3 0
7e :3 0 6f :2 0
472 95c 95d :3 0
8 :3 0 63 :3 0
95f 960 0 1d
:2 0 961 962 0
964 475 96b 8
:3 0 63 :3 0 965
966 0 b1 :2 0
967 968 0 96a
477 96c 95e 964
0 96d 0 96a
0 96d 479 0
96e 47c 9b8 65
:3 0 8 :3 0 63
:3 0 971 972 0
64 :3 0 973 974
0 9ae 4a :3 0
4b :3 0 976 977
0 4a :3 0 5b
:3 0 979 97a 0
66 :2 0 2 :4 0
133 :2 0 5e :2 0
5c :2 0 47f 97f
981 :3 0 482 97b
983 978 985 984
:2 0 4d :3 0 5f
:3 0 987 988 0
4f :4 0 134 :4 0
52 :2 0 53 :3 0
486 98c 98e :3 0
52 :2 0 69 :4 0
489 990 992 :3 0
52 :2 0 6a :4 0
48c 994 996 :3 0
52 :2 0 64 :3 0
48f 998 99a :3 0
52 :2 0 6b :4 0
492 99c 99e :3 0
52 :2 0 6c :3 0
6d :3 0 5c :2 0
6e :2 0 495 9a1
9a5 499 9a0 9a7
:3 0 49c 989 9a9
:2 0 9ab 49f 9ac
986 9ab 0 9ad
4a1 0 9ae 4a3
9b1 :3 0 9b1 0
9b1 9b0 9ae 9af
:6 0 9b3 21 :3 0
4a6 9b5 4a8 9b4
9b3 :2 0 9b6 4aa
:2 0 9b8 0 9b8
9b7 96e 9b6 :6 0
aec 16 :3 0 135
:3 0 33 :3 0 16
:4 0 136 1 :8 0
9d3 b0 :4 0 9be
:3 0 7e :3 0 6f
:2 0 4ae 9c1 9c2
:3 0 8 :3 0 63
:3 0 9c4 9c5 0
1d :2 0 9c6 9c7
0 9c9 4b1 9d0
8 :3 0 63 :3 0
9ca 9cb 0 b1
:2 0 9cc 9cd 0
9cf 4b3 9d1 9c3
9c9 0 9d2 0
9cf 0 9d2 4b5
0 9d3 4b8 a1d
65 :3 0 8 :3 0
63 :3 0 9d6 9d7
0 64 :3 0 9d8
9d9 0 a13 4a
:3 0 4b :3 0 9db
9dc 0 4a :3 0
5b :3 0 9de 9df
0 66 :2 0 2
:4 0 137 :2 0 5e
:2 0 5c :2 0 4bb
9e4 9e6 :3 0 4be
9e0 9e8 9dd 9ea
9e9 :2 0 4d :3 0
5f :3 0 9ec 9ed
0 4f :4 0 138
:4 0 52 :2 0 53
:3 0 4c2 9f1 9f3
:3 0 52 :2 0 69
:4 0 4c5 9f5 9f7
:3 0 52 :2 0 6a
:4 0 4c8 9f9 9fb
:3 0 52 :2 0 64
:3 0 4cb 9fd 9ff
:3 0 52 :2 0 6b
:4 0 4ce a01 a03
:3 0 52 :2 0 6c
:3 0 6d :3 0 5c
:2 0 6e :2 0 4d1
a06 a0a 4d5 a05
a0c :3 0 4d8 9ee
a0e :2 0 a10 4db
a11 9eb a10 0
a12 4dd 0 a13
4df a16 :3 0 a16
0 a16 a15 a13
a14 :6 0 a18 23
:3 0 4e2 a1a 4e4
a19 a18 :2 0 a1b
4e6 :2 0 a1d 0
a1d a1c 9d3 a1b
:6 0 aec 16 :3 0
139 :3 0 13a :3 0
16 :4 0 13b 1
:8 0 a38 b0 :4 0
a23 :3 0 7e :3 0
6f :2 0 4ea a26
a27 :3 0 8 :3 0
63 :3 0 a29 a2a
0 1d :2 0 a2b
a2c 0 a2e 4ed
a35 8 :3 0 63
:3 0 a2f a30 0
b1 :2 0 a31 a32
0 a34 4ef a36
a28 a2e 0 a37
0 a34 0 a37
4f1 0 a38 4f4
a82 65 :3 0 8
:3 0 63 :3 0 a3b
a3c 0 64 :3 0
a3d a3e 0 a78
4a :3 0 4b :3 0
a40 a41 0 4a
:3 0 5b :3 0 a43
a44 0 66 :2 0
2 :4 0 13c :2 0
5e :2 0 5c :2 0
4f7 a49 a4b :3 0
4fa a45 a4d a42
a4f a4e :2 0 4d
:3 0 5f :3 0 a51
a52 0 4f :4 0
13d :4 0 52 :2 0
53 :3 0 4fe a56
a58 :3 0 52 :2 0
69 :4 0 501 a5a
a5c :3 0 52 :2 0
6a :4 0 504 a5e
a60 :3 0 52 :2 0
64 :3 0 507 a62
a64 :3 0 52 :2 0
6b :4 0 50a a66
a68 :3 0 52 :2 0
6c :3 0 6d :3 0
5c :2 0 6e :2 0
50d a6b a6f 511
a6a a71 :3 0 514
a53 a73 :2 0 a75
517 a76 a50 a75
0 a77 519 0
a78 51b a7b :3 0
a7b 0 a7b a7a
a78 a79 :6 0 a7d
25 :3 0 51e a7f
520 a7e a7d :2 0
a80 522 :2 0 a82
0 a82 a81 a38
a80 :6 0 aec 16
:3 0 13e :3 0 13a
:3 0 16 :4 0 13f
1 :8 0 a9d b0
:4 0 a88 :3 0 7e
:3 0 6f :2 0 526
a8b a8c :3 0 8
:3 0 63 :3 0 a8e
a8f 0 1d :2 0
a90 a91 0 a93
529 a9a 8 :3 0
63 :3 0 a94 a95
0 b1 :2 0 a96
a97 0 a99 52b
a9b a8d a93 0
a9c 0 a99 0
a9c 52d 0 a9d
530 ae7 65 :3 0
8 :3 0 63 :3 0
aa0 aa1 0 64
:3 0 aa2 aa3 0
add 4a :3 0 4b
:3 0 aa5 aa6 0
4a :3 0 5b :3 0
aa8 aa9 0 66
:2 0 2 :4 0 6e
:2 0 5e :2 0 5c
:2 0 533 aae ab0
:3 0 536 aaa ab2
aa7 ab4 ab3 :2 0
4d :3 0 5f :3 0
ab6 ab7 0 4f
:4 0 140 :4 0 52
:2 0 53 :3 0 53a
abb abd :3 0 52
:2 0 69 :4 0 53d
abf ac1 :3 0 52
:2 0 6a :4 0 540
ac3 ac5 :3 0 52
:2 0 64 :3 0 543
ac7 ac9 :3 0 52
:2 0 6b :4 0 546
acb acd :3 0 52
:2 0 6c :3 0 6d
:3 0 5c :2 0 6e
:2 0 549 ad0 ad4
54d acf ad6 :3 0
550 ab8 ad8 :2 0
ada 553 adb ab5
ada 0 adc 555
0 add 557 ae0
:3 0 ae0 0 ae0
adf add ade :6 0
ae2 27 :3 0 55a
ae4 55c ae3 ae2
:2 0 ae5 55e :2 0
ae7 0 ae7 ae6
a9d ae5 :6 0 aec
16 :3 0 1f :3 0
5c :2 0 ae9 aea
0 aec 560 aee
950 954 0 aef
0 aec 0 aef
566 0 af0 569
af8 18 :3 0 16
:3 0 af1 af2 0
af7 1f :3 0 1d
:2 0 af4 af5 0
af7 56b af9 947
af0 0 afa 0
af7 0 afa 56e
0 11fa 20 :3 0
1d :2 0 afb afc
0 11fa b4 :3 0
41 :4 0 b01 :2 0
11fa aff b02 :3 0
b5 :3 0 41 :3 0
12 :3 0 20 :3 0
a :4 0 b09 :2 0
d03 b04 b0a :3 0
571 :3 0 41 :3 0
b0 :3 0 b0b b0c
:3 0 8 :3 0 63
:3 0 b0e b0f 0
1d :2 0 b10 b11
0 b13 575 b1a
8 :3 0 63 :3 0
b14 b15 0 b1
:2 0 b16 b17 0
b19 577 b1b b0d
b13 0 b1c 0
b19 0 b1c 579
0 d03 8 :3 0
63 :3 0 b1d b1e
0 8 :3 0 b6
:2 0 b7 :3 0 b20
b22 0 57e b21
b24 :3 0 b25 :2 0
b8 :8 0 b29 581
b2a b26 b29 0
b2b 583 0 d03
57 :3 0 1f :3 0
1d :2 0 585 b2c
b2f 6f :2 0 5c
:2 0 58a b31 b33
:3 0 45 :3 0 43
:3 0 43 :3 0 20
:3 0 44 :3 0 141
:3 0 142 :3 0 44
:3 0 a :3 0 39
:3 0 10 :3 0 33
:3 0 18 :3 0 42
:3 0 12 :4 0 143
1 :8 0 b5a b0
:4 0 b45 :3 0 7e
:3 0 6f :2 0 58f
b48 b49 :3 0 8
:3 0 63 :3 0 b4b
b4c 0 1d :2 0
b4d b4e 0 b50
592 b57 8 :3 0
63 :3 0 b51 b52
0 b1 :2 0 b53
b54 0 b56 594
b58 b4a b50 0
b59 0 b56 0
b59 596 0 b5a
599 ba4 65 :3 0
8 :3 0 63 :3 0
b5d b5e 0 64
:3 0 b5f b60 0
b9a 4a :3 0 4b
:3 0 b62 b63 0
4a :3 0 5b :3 0
b65 b66 0 66
:2 0 2 :4 0 144
:2 0 5e :2 0 5c
:2 0 59c b6b b6d
:3 0 59f b67 b6f
b64 b71 b70 :2 0
4d :3 0 5f :3 0
b73 b74 0 4f
:4 0 145 :4 0 52
:2 0 53 :3 0 5a3
b78 b7a :3 0 52
:2 0 69 :4 0 5a6
b7c b7e :3 0 52
:2 0 6a :4 0 5a9
b80 b82 :3 0 52
:2 0 64 :3 0 5ac
b84 b86 :3 0 52
:2 0 6b :4 0 5af
b88 b8a :3 0 52
:2 0 6c :3 0 6d
:3 0 5c :2 0 6e
:2 0 5b2 b8d b91
5b6 b8c b93 :3 0
5b9 b75 b95 :2 0
b97 5bc b98 b72
b97 0 b99 5be
0 b9a 5c0 b9d
:3 0 b9d 0 b9d
b9c b9a b9b :6 0
b9f 2a :3 0 5c3
ba1 5c5 ba0 b9f
:2 0 ba2 5c7 :2 0
ba4 0 ba4 ba3
b5a ba2 :6 0 c8a
29 :3 0 8 :3 0
63 :3 0 ba6 ba7
0 8 :3 0 6f
:2 0 b7 :3 0 ba9
bab 0 5cb baa
bad :3 0 bae :2 0
45 :3 0 39 :3 0
10 :3 0 33 :3 0
16 :3 0 42 :3 0
12 :4 0 146 1
:8 0 bcd b0 :4 0
bb8 :3 0 7e :3 0
6f :2 0 5d0 bbb
bbc :3 0 8 :3 0
63 :3 0 bbe bbf
0 1d :2 0 bc0
bc1 0 bc3 5d3
bca 8 :3 0 63
:3 0 bc4 bc5 0
b1 :2 0 bc6 bc7
0 bc9 5d5 bcb
bbd bc3 0 bcc
0 bc9 0 bcc
5d7 0 bcd 5da
c17 65 :3 0 8
:3 0 63 :3 0 bd0
bd1 0 64 :3 0
bd2 bd3 0 c0d
4a :3 0 4b :3 0
bd5 bd6 0 4a
:3 0 5b :3 0 bd8
bd9 0 66 :2 0
2 :4 0 147 :2 0
5e :2 0 5c :2 0
5dd bde be0 :3 0
5e0 bda be2 bd7
be4 be3 :2 0 4d
:3 0 5f :3 0 be6
be7 0 4f :4 0
148 :4 0 52 :2 0
53 :3 0 5e4 beb
bed :3 0 52 :2 0
69 :4 0 5e7 bef
bf1 :3 0 52 :2 0
6a :4 0 5ea bf3
bf5 :3 0 52 :2 0
64 :3 0 5ed bf7
bf9 :3 0 52 :2 0
6b :4 0 5f0 bfb
bfd :3 0 52 :2 0
6c :3 0 6d :3 0
5c :2 0 6e :2 0
5f3 c00 c04 5f7
bff c06 :3 0 5fa
be8 c08 :2 0 c0a
5fd c0b be5 c0a
0 c0c 5ff 0
c0d 601 c10 :3 0
c10 0 c10 c0f
c0d c0e :6 0 c12
2c :3 0 604 c14
606 c13 c12 :2 0
c15 608 :2 0 c17
0 c17 c16 bcd
c15 :6 0 c19 29
:3 0 60a c86 45
:3 0 33 :3 0 18
:3 0 39 :3 0 10
:3 0 33 :3 0 16
:3 0 42 :3 0 12
:4 0 149 1 :8 0
c39 b0 :4 0 c24
:3 0 7e :3 0 6f
:2 0 60e c27 c28
:3 0 8 :3 0 63
:3 0 c2a c2b 0
1d :2 0 c2c c2d
0 c2f 611 c36
8 :3 0 63 :3 0
c30 c31 0 b1
:2 0 c32 c33 0
c35 613 c37 c29
c2f 0 c38 0
c35 0 c38 615
0 c39 618 c83
65 :3 0 8 :3 0
63 :3 0 c3c c3d
0 64 :3 0 c3e
c3f 0 c79 4a
:3 0 4b :3 0 c41
c42 0 4a :3 0
5b :3 0 c44 c45
0 66 :2 0 2
:4 0 14a :2 0 5e
:2 0 5c :2 0 61b
c4a c4c :3 0 61e
c46 c4e c43 c50
c4f :2 0 4d :3 0
5f :3 0 c52 c53
0 4f :4 0 14b
:4 0 52 :2 0 53
:3 0 622 c57 c59
:3 0 52 :2 0 69
:4 0 625 c5b c5d
:3 0 52 :2 0 6a
:4 0 628 c5f c61
:3 0 52 :2 0 64
:3 0 62b c63 c65
:3 0 52 :2 0 6b
:4 0 62e c67 c69
:3 0 52 :2 0 6c
:3 0 6d :3 0 5c
:2 0 6e :2 0 631
c6c c70 635 c6b
c72 :3 0 638 c54
c74 :2 0 c76 63b
c77 c51 c76 0
c78 63d 0 c79
63f c7c :3 0 c7c
0 c7c c7b c79
c7a :6 0 c7e 2e
:3 0 642 c80 644
c7f c7e :2 0 c81
646 :2 0 c83 0
c83 c82 c39 c81
:6 0 c85 29 :3 0
648 c87 baf c19
0 c88 0 c85
0 c88 64a 0
c8a 7f :3 0 64d
d01 57 :3 0 1f
:3 0 1d :2 0 650
c8b c8e 6f :2 0
d7 :2 0 655 c90
c92 :3 0 45 :3 0
33 :3 0 18 :3 0
39 :3 0 10 :3 0
33 :3 0 16 :3 0
42 :3 0 12 :4 0
149 1 :8 0 cb3
b0 :4 0 c9e :3 0
7e :3 0 6f :2 0
65a ca1 ca2 :3 0
8 :3 0 63 :3 0
ca4 ca5 0 1d
:2 0 ca6 ca7 0
ca9 65d cb0 8
:3 0 63 :3 0 caa
cab 0 b1 :2 0
cac cad 0 caf
65f cb1 ca3 ca9
0 cb2 0 caf
0 cb2 661 0
cb3 664 cfd 65
:3 0 8 :3 0 63
:3 0 cb6 cb7 0
64 :3 0 cb8 cb9
0 cf3 4a :3 0
4b :3 0 cbb cbc
0 4a :3 0 5b
:3 0 cbe cbf 0
66 :2 0 2 :4 0
14c :2 0 5e :2 0
5c :2 0 667 cc4
cc6 :3 0 66a cc0
cc8 cbd cca cc9
:2 0 4d :3 0 5f
:3 0 ccc ccd 0
4f :4 0 14d :4 0
52 :2 0 53 :3 0
66e cd1 cd3 :3 0
52 :2 0 69 :4 0
671 cd5 cd7 :3 0
52 :2 0 6a :4 0
674 cd9 cdb :3 0
52 :2 0 64 :3 0
677 cdd cdf :3 0
52 :2 0 6b :4 0
67a ce1 ce3 :3 0
52 :2 0 6c :3 0
6d :3 0 5c :2 0
6e :2 0 67d ce6
cea 681 ce5 cec
:3 0 684 cce cee
:2 0 cf0 687 cf1
ccb cf0 0 cf2
689 0 cf3 68b
cf6 :3 0 cf6 0
cf6 cf5 cf3 cf4
:6 0 cf8 30 :3 0
68e cfa 690 cf9
cf8 :2 0 cfb 692
:2 0 cfd 0 cfd
cfc cb3 cfb :6 0
cff 29 :3 0 694
d00 c93 cff 0
d02 b34 c8a 0
d02 696 0 d03
699 d05 b5 :4 0
d03 :4 0 11fa cf
:3 0 41 :4 0 d09
:2 0 d0f d07 0
8 :3 0 63 :3 0
d0a d0b 0 64
:3 0 d0c d0d 0
d0f 69e d59 65
:3 0 8 :3 0 63
:3 0 d12 d13 0
64 :3 0 d14 d15
0 d4f 4a :3 0
4b :3 0 d17 d18
0 4a :3 0 5b
:3 0 d1a d1b 0
66 :2 0 2 :4 0
14e :2 0 5e :2 0
5c :2 0 6a1 d20
d22 :3 0 6a4 d1c
d24 d19 d26 d25
:2 0 4d :3 0 5f
:3 0 d28 d29 0
4f :4 0 14f :4 0
52 :2 0 53 :3 0
6a8 d2d d2f :3 0
52 :2 0 69 :4 0
6ab d31 d33 :3 0
52 :2 0 6a :4 0
6ae d35 d37 :3 0
52 :2 0 64 :3 0
6b1 d39 d3b :3 0
52 :2 0 6b :4 0
6b4 d3d d3f :3 0
52 :2 0 6c :3 0
6d :3 0 5c :2 0
6e :2 0 6b7 d42
d46 6bb d41 d48
:3 0 6be d2a d4a
:2 0 d4c 6c1 d4d
d27 d4c 0 d4e
6c3 0 d4f 6c5
d52 :3 0 d52 0
d52 d51 d4f d50
:6 0 d54 32 :3 0
6c8 d56 6ca d55
d54 :2 0 d57 6cc
:2 0 d59 0 d59
d58 d0f d57 :6 0
11fa 16 :3 0 45
:3 0 3c :3 0 150
:3 0 18 :3 0 39
:3 0 10 :3 0 150
:3 0 16 :4 0 151
1 :8 0 d79 b0
:4 0 d64 :3 0 7e
:3 0 6f :2 0 6d0
d67 d68 :3 0 8
:3 0 63 :3 0 d6a
d6b 0 1d :2 0
d6c d6d 0 d6f
6d3 d76 8 :3 0
63 :3 0 d70 d71
0 b1 :2 0 d72
d73 0 d75 6d5
d77 d69 d6f 0
d78 0 d75 0
d78 6d7 0 d79
6da dc3 65 :3 0
8 :3 0 63 :3 0
d7c d7d 0 64
:3 0 d7e d7f 0
db9 4a :3 0 4b
:3 0 d81 d82 0
4a :3 0 5b :3 0
d84 d85 0 66
:2 0 2 :4 0 152
:2 0 5e :2 0 5c
:2 0 6dd d8a d8c
:3 0 6e0 d86 d8e
d83 d90 d8f :2 0
4d :3 0 5f :3 0
d92 d93 0 4f
:4 0 153 :4 0 52
:2 0 53 :3 0 6e4
d97 d99 :3 0 52
:2 0 69 :4 0 6e7
d9b d9d :3 0 52
:2 0 6a :4 0 6ea
d9f da1 :3 0 52
:2 0 64 :3 0 6ed
da3 da5 :3 0 52
:2 0 6b :4 0 6f0
da7 da9 :3 0 52
:2 0 6c :3 0 6d
:3 0 5c :2 0 6e
:2 0 6f3 dac db0
6f7 dab db2 :3 0
6fa d94 db4 :2 0
db6 6fd db7 d91
db6 0 db8 6ff
0 db9 701 dbc
:3 0 dbc 0 dbc
dbb db9 dba :6 0
dbe 34 :3 0 704
dc0 706 dbf dbe
:2 0 dc1 708 :2 0
dc3 0 dc3 dc2
d79 dc1 :6 0 11fa
16 :3 0 57 :3 0
26 :3 0 1d :2 0
70a dc5 dc8 6f
:2 0 1d :2 0 70f
dca dcc :3 0 35
:3 0 3c :3 0 154
:3 0 d :3 0 155
:3 0 156 :3 0 d
:3 0 157 :3 0 91
:3 0 92 :3 0 93
:3 0 94 :3 0 95
:3 0 96 :3 0 b9
:3 0 ba :3 0 bb
:3 0 92 :3 0 bc
:3 0 94 :3 0 bd
:3 0 ba :3 0 be
:3 0 bf :3 0 bf
:3 0 be :3 0 c0
:3 0 c1 :3 0 c1
:3 0 c0 :3 0 9c
:3 0 ba :3 0 c2
:3 0 9c :3 0 ba
:3 0 c4 :3 0 c5
:3 0 c6 :3 0 c3
:3 0 9c :3 0 ba
:3 0 c7 :3 0 c8
:3 0 92 :3 0 94
:3 0 96 :3 0 ba
:3 0 99 :3 0 9a
:3 0 9d :3 0 3e
:3 0 33 :3 0 16
:3 0 b9 :3 0 ba
:4 0 158 1 :8 0
e1b b0 :4 0 e06
:3 0 7e :3 0 6f
:2 0 714 e09 e0a
:3 0 8 :3 0 63
:3 0 e0c e0d 0
1d :2 0 e0e e0f
0 e11 717 e18
8 :3 0 63 :3 0
e12 e13 0 b1
:2 0 e14 e15 0
e17 719 e19 e0b
e11 0 e1a 0
e17 0 e1a 71b
0 e1b 71e e65
65 :3 0 8 :3 0
63 :3 0 e1e e1f
0 64 :3 0 e20
e21 0 e5b 4a
:3 0 4b :3 0 e23
e24 0 4a :3 0
5b :3 0 e26 e27
0 66 :2 0 2
:4 0 159 :2 0 5e
:2 0 5c :2 0 721
e2c e2e :3 0 724
e28 e30 e25 e32
e31 :2 0 4d :3 0
5f :3 0 e34 e35
0 4f :4 0 15a
:4 0 52 :2 0 53
:3 0 728 e39 e3b
:3 0 52 :2 0 69
:4 0 72b e3d e3f
:3 0 52 :2 0 6a
:4 0 72e e41 e43
:3 0 52 :2 0 64
:3 0 731 e45 e47
:3 0 52 :2 0 6b
:4 0 734 e49 e4b
:3 0 52 :2 0 6c
:3 0 6d :3 0 5c
:2 0 6e :2 0 737
e4e e52 73b e4d
e54 :3 0 73e e36
e56 :2 0 e58 741
e59 e33 e58 0
e5a 743 0 e5b
745 e5e :3 0 e5e
0 e5e e5d e5b
e5c :6 0 e60 36
:3 0 748 e62 74a
e61 e60 :2 0 e63
74c :2 0 e65 0
e65 e64 e1b e63
:6 0 e80 16 :3 0
57 :3 0 1f :3 0
1d :2 0 74e e67
e6a 6f :2 0 d7
:2 0 753 e6c e6e
:3 0 28 :3 0 8d
:2 0 e70 e71 0
e7d 29 :3 0 15b
:3 0 10 :3 0 18
:3 0 28 :3 0 1d
:2 0 1d :2 0 756
e74 e7a e73 e7b
0 e7d 75c e7e
e6f e7d 0 e7f
75f 0 e80 761
11f3 b4 :3 0 47
:4 0 e84 :2 0 11f2
e82 e85 :3 0 b5
:3 0 47 :3 0 15
:3 0 17 :4 0 e8b
:2 0 fae e87 e8c
:3 0 764 :3 0 47
:3 0 b0 :3 0 e8d
e8e :3 0 8 :3 0
63 :3 0 e90 e91
0 1d :2 0 e92
e93 0 e95 767
e9c 8 :3 0 63
:3 0 e96 e97 0
b1 :2 0 e98 e99
0 e9b 769 e9d
e8f e95 0 e9e
0 e9b 0 e9e
76b 0 fae 8
:3 0 63 :3 0 e9f
ea0 0 8 :3 0
b6 :2 0 b7 :3 0
ea2 ea4 0 770
ea3 ea6 :3 0 ea7
:2 0 b8 :8 0 eab
773 eac ea8 eab
0 ead 775 0
fae 35 :3 0 3c
:3 0 154 :3 0 d
:3 0 155 :3 0 156
:3 0 d :3 0 157
:3 0 91 :3 0 92
:3 0 93 :3 0 94
:3 0 95 :3 0 96
:3 0 b9 :3 0 ba
:3 0 bb :3 0 92
:3 0 bc :3 0 94
:3 0 bd :3 0 ba
:3 0 be :3 0 bf
:3 0 bf :3 0 be
:3 0 c0 :3 0 c1
:3 0 c1 :3 0 c0
:3 0 9c :3 0 ba
:3 0 c2 :3 0 9c
:3 0 ba :3 0 c4
:3 0 c5 :3 0 c6
:3 0 c3 :3 0 9c
:3 0 ba :3 0 c7
:3 0 c8 :3 0 92
:3 0 94 :3 0 96
:3 0 ba :3 0 99
:3 0 9a :3 0 9d
:3 0 3e :3 0 18
:3 0 33 :3 0 17
:4 0 15c 1 :8 0
efa b0 :4 0 ee5
:3 0 7e :3 0 6f
:2 0 779 ee8 ee9
:3 0 8 :3 0 63
:3 0 eeb eec 0
1d :2 0 eed eee
0 ef0 77c ef7
8 :3 0 63 :3 0
ef1 ef2 0 b1
:2 0 ef3 ef4 0
ef6 77e ef8 eea
ef0 0 ef9 0
ef6 0 ef9 780
0 efa 783 f44
65 :3 0 8 :3 0
63 :3 0 efd efe
0 64 :3 0 eff
f00 0 f3a 4a
:3 0 4b :3 0 f02
f03 0 4a :3 0
5b :3 0 f05 f06
0 66 :2 0 2
:4 0 15d :2 0 5e
:2 0 5c :2 0 786
f0b f0d :3 0 789
f07 f0f f04 f11
f10 :2 0 4d :3 0
5f :3 0 f13 f14
0 4f :4 0 15e
:4 0 52 :2 0 53
:3 0 78d f18 f1a
:3 0 52 :2 0 69
:4 0 790 f1c f1e
:3 0 52 :2 0 6a
:4 0 793 f20 f22
:3 0 52 :2 0 64
:3 0 796 f24 f26
:3 0 52 :2 0 6b
:4 0 799 f28 f2a
:3 0 52 :2 0 6c
:3 0 6d :3 0 5c
:2 0 6e :2 0 79c
f2d f31 7a0 f2c
f33 :3 0 7a3 f15
f35 :2 0 f37 7a6
f38 f12 f37 0
f39 7a8 0 f3a
7aa f3d :3 0 f3d
0 f3d f3c f3a
f3b :6 0 f3f 39
:3 0 7ad f41 7af
f40 f3f :2 0 f42
7b1 :2 0 f44 0
f44 f43 efa f42
:6 0 fae 38 :3 0
37 :3 0 d2 :3 0
d :3 0 d3 :3 0
3a :3 0 15 :4 0
15f 1 :8 0 f62
b0 :4 0 f4d :3 0
7e :3 0 6f :2 0
7b5 f50 f51 :3 0
8 :3 0 63 :3 0
f53 f54 0 1d
:2 0 f55 f56 0
f58 7b8 f5f 8
:3 0 63 :3 0 f59
f5a 0 b1 :2 0
f5b f5c 0 f5e
7ba f60 f52 f58
0 f61 0 f5e
0 f61 7bc 0
f62 7bf fac 65
:3 0 8 :3 0 63
:3 0 f65 f66 0
64 :3 0 f67 f68
0 fa2 4a :3 0
4b :3 0 f6a f6b
0 4a :3 0 5b
:3 0 f6d f6e 0
66 :2 0 2 :4 0
160 :2 0 5e :2 0
5c :2 0 7c2 f73
f75 :3 0 7c5 f6f
f77 f6c f79 f78
:2 0 4d :3 0 5f
:3 0 f7b f7c 0
4f :4 0 161 :4 0
52 :2 0 53 :3 0
7c9 f80 f82 :3 0
52 :2 0 69 :4 0
7cc f84 f86 :3 0
52 :2 0 6a :4 0
7cf f88 f8a :3 0
52 :2 0 64 :3 0
7d2 f8c f8e :3 0
52 :2 0 6b :4 0
7d5 f90 f92 :3 0
52 :2 0 6c :3 0
6d :3 0 5c :2 0
6e :2 0 7d8 f95
f99 7dc f94 f9b
:3 0 7df f7d f9d
:2 0 f9f 7e2 fa0
f7a f9f 0 fa1
7e4 0 fa2 7e6
fa5 :3 0 fa5 0
fa5 fa4 fa2 fa3
:6 0 fa7 3b :3 0
7e9 fa9 7eb fa8
fa7 :2 0 faa 7ed
:2 0 fac 0 fac
fab f62 faa :6 0
fae 38 :3 0 7ef
fb0 b5 :4 0 fae
:4 0 11f2 cf :3 0
47 :4 0 fb4 :2 0
fba fb2 0 8
:3 0 63 :3 0 fb5
fb6 0 64 :3 0
fb7 fb8 0 fba
7f5 1004 65 :3 0
8 :3 0 63 :3 0
fbd fbe 0 64
:3 0 fbf fc0 0
ffa 4a :3 0 4b
:3 0 fc2 fc3 0
4a :3 0 5b :3 0
fc5 fc6 0 66
:2 0 2 :4 0 162
:2 0 5e :2 0 5c
:2 0 7f8 fcb fcd
:3 0 7fb fc7 fcf
fc4 fd1 fd0 :2 0
4d :3 0 5f :3 0
fd3 fd4 0 4f
:4 0 163 :4 0 52
:2 0 53 :3 0 7ff
fd8 fda :3 0 52
:2 0 69 :4 0 802
fdc fde :3 0 52
:2 0 6a :4 0 805
fe0 fe2 :3 0 52
:2 0 64 :3 0 808
fe4 fe6 :3 0 52
:2 0 6b :4 0 80b
fe8 fea :3 0 52
:2 0 6c :3 0 6d
:3 0 5c :2 0 6e
:2 0 80e fed ff1
812 fec ff3 :3 0
815 fd5 ff5 :2 0
ff7 818 ff8 fd2
ff7 0 ff9 81a
0 ffa 81c ffd
:3 0 ffd 0 ffd
ffc ffa ffb :6 0
fff 3d :3 0 81f
1001 821 1000 fff
:2 0 1002 823 :2 0
1004 0 1004 1003
fba 1002 :6 0 11f2
16 :3 0 57 :3 0
26 :3 0 1d :2 0
825 1006 1009 6f
:2 0 5c :2 0 82a
100b 100d :3 0 100e
:2 0 57 :3 0 27
:3 0 1d :2 0 82d
1010 1013 164 :2 0
1d :2 0 832 1015
1017 :3 0 1018 :2 0
100f 101a 1019 :2 0
35 :3 0 12d :3 0
27 :3 0 33 :3 0
18 :4 0 165 1
:8 0 1037 b0 :4 0
1022 :3 0 7e :3 0
6f :2 0 837 1025
1026 :3 0 8 :3 0
63 :3 0 1028 1029
0 1d :2 0 102a
102b 0 102d 83a
1034 8 :3 0 63
:3 0 102e 102f 0
b1 :2 0 1030 1031
0 1033 83c 1035
1027 102d 0 1036
0 1033 0 1036
83e 0 1037 841
1081 65 :3 0 8
:3 0 63 :3 0 103a
103b 0 64 :3 0
103c 103d 0 1077
4a :3 0 4b :3 0
103f 1040 0 4a
:3 0 5b :3 0 1042
1043 0 66 :2 0
2 :4 0 166 :2 0
5e :2 0 5c :2 0
844 1048 104a :3 0
847 1044 104c 1041
104e 104d :2 0 4d
:3 0 5f :3 0 1050
1051 0 4f :4 0
167 :4 0 52 :2 0
53 :3 0 84b 1055
1057 :3 0 52 :2 0
69 :4 0 84e 1059
105b :3 0 52 :2 0
6a :4 0 851 105d
105f :3 0 52 :2 0
64 :3 0 854 1061
1063 :3 0 52 :2 0
6b :4 0 857 1065
1067 :3 0 52 :2 0
6c :3 0 6d :3 0
5c :2 0 6e :2 0
85a 106a 106e 85e
1069 1070 :3 0 861
1052 1072 :2 0 1074
864 1075 104f 1074
0 1076 866 0
1077 868 107a :3 0
107a 0 107a 1079
1077 1078 :6 0 107c
3f :3 0 86b 107e
86d 107d 107c :2 0
107f 86f :2 0 1081
0 1081 1080 1037
107f :6 0 1083 16
:3 0 871 1084 101b
1083 0 1085 873
0 11f2 28 :3 0
8d :2 0 1086 1087
0 11f2 29 :3 0
15b :3 0 10 :3 0
18 :3 0 28 :3 0
1d :2 0 1d :2 0
875 108a 1090 1089
1091 0 11f2 3e
:3 0 168 :3 0 91
:3 0 93 :3 0 c3
:3 0 c4 :3 0 c7
:3 0 18 :3 0 1c
:3 0 19 :3 0 1b
:3 0 1e :3 0 2a
:3 0 2d :3 0 35
:3 0 33 :3 0 18
:4 0 169 1 :8 0
10aa 8 :3 0 63
:3 0 10a5 10a6 0
64 :3 0 10a7 10a8
0 10aa 87b 10f4
65 :3 0 8 :3 0
63 :3 0 10ad 10ae
0 64 :3 0 10af
10b0 0 10ea 4a
:3 0 4b :3 0 10b2
10b3 0 4a :3 0
5b :3 0 10b5 10b6
0 66 :2 0 2
:4 0 16a :2 0 5e
:2 0 5c :2 0 87e
10bb 10bd :3 0 881
10b7 10bf 10b4 10c1
10c0 :2 0 4d :3 0
5f :3 0 10c3 10c4
0 4f :4 0 16b
:4 0 52 :2 0 53
:3 0 885 10c8 10ca
:3 0 52 :2 0 69
:4 0 888 10cc 10ce
:3 0 52 :2 0 6a
:4 0 88b 10d0 10d2
:3 0 52 :2 0 64
:3 0 88e 10d4 10d6
:3 0 52 :2 0 6b
:4 0 891 10d8 10da
:3 0 52 :2 0 6c
:3 0 6d :3 0 5c
:2 0 6e :2 0 894
10dd 10e1 898 10dc
10e3 :3 0 89b 10c5
10e5 :2 0 10e7 89e
10e8 10c2 10e7 0
10e9 8a0 0 10ea
8a2 10ed :3 0 10ed
0 10ed 10ec 10ea
10eb :6 0 10ef 41
:3 0 8a5 10f1 8a7
10f0 10ef :2 0 10f2
8a9 :2 0 10f4 0
10f4 10f3 10aa 10f2
:6 0 11f2 16 :3 0
57 :3 0 1e :3 0
1d :2 0 8ab 10f6
10f9 6f :2 0 1d
:2 0 8b0 10fb 10fd
:3 0 105 :3 0 10a
:3 0 10f :3 0 114
:3 0 119 :3 0 11e
:3 0 109 :3 0 19
:3 0 10e :3 0 1b
:3 0 113 :3 0 1c
:3 0 118 :3 0 1c
:3 0 2a :3 0 11d
:3 0 39 :3 0 10
:3 0 34 :3 0 14
:4 0 16c 1 :8 0
1129 b0 :4 0 1114
:3 0 7e :3 0 6f
:2 0 8b5 1117 1118
:3 0 8 :3 0 63
:3 0 111a 111b 0
1d :2 0 111c 111d
0 111f 8b8 1126
8 :3 0 63 :3 0
1120 1121 0 b1
:2 0 1122 1123 0
1125 8ba 1127 1119
111f 0 1128 0
1125 0 1128 8bc
0 1129 8bf 1173
65 :3 0 8 :3 0
63 :3 0 112c 112d
0 64 :3 0 112e
112f 0 1169 4a
:3 0 4b :3 0 1131
1132 0 4a :3 0
5b :3 0 1134 1135
0 66 :2 0 2
:4 0 16d :2 0 5e
:2 0 5c :2 0 8c2
113a 113c :3 0 8c5
1136 113e 1133 1140
113f :2 0 4d :3 0
5f :3 0 1142 1143
0 4f :4 0 16e
:4 0 52 :2 0 53
:3 0 8c9 1147 1149
:3 0 52 :2 0 69
:4 0 8cc 114b 114d
:3 0 52 :2 0 6a
:4 0 8cf 114f 1151
:3 0 52 :2 0 64
:3 0 8d2 1153 1155
:3 0 52 :2 0 6b
:4 0 8d5 1157 1159
:3 0 52 :2 0 6c
:3 0 6d :3 0 5c
:2 0 6e :2 0 8d8
115c 1160 8dc 115b
1162 :3 0 8df 1144
1164 :2 0 1166 8e2
1167 1141 1166 0
1168 8e4 0 1169
8e6 116c :3 0 116c
0 116c 116b 1169
116a :6 0 116e 43
:3 0 8e9 1170 8eb
116f 116e :2 0 1171
8ed :2 0 1173 0
1173 1172 1129 1171
:6 0 1175 16 :3 0
8ef 11ef 105 :3 0
10a :3 0 10f :3 0
114 :3 0 119 :3 0
11e :3 0 109 :3 0
19 :3 0 10e :3 0
1b :3 0 113 :3 0
1c :3 0 118 :3 0
1c :3 0 2a :3 0
11d :3 0 1c :3 0
2d :3 0 39 :3 0
10 :3 0 34 :3 0
14 :4 0 16f 1
:8 0 11a2 b0 :4 0
118d :3 0 7e :3 0
6f :2 0 8f3 1190
1191 :3 0 8 :3 0
63 :3 0 1193 1194
0 1d :2 0 1195
1196 0 1198 8f6
119f 8 :3 0 63
:3 0 1199 119a 0
b1 :2 0 119b 119c
0 119e 8f8 11a0
1192 1198 0 11a1
0 119e 0 11a1
8fa 0 11a2 8fd
11ec 65 :3 0 8
:3 0 63 :3 0 11a5
11a6 0 64 :3 0
11a7 11a8 0 11e2
4a :3 0 4b :3 0
11aa 11ab 0 4a
:3 0 5b :3 0 11ad
11ae 0 66 :2 0
2 :4 0 170 :2 0
5e :2 0 5c :2 0
900 11b3 11b5 :3 0
903 11af 11b7 11ac
11b9 11b8 :2 0 4d
:3 0 5f :3 0 11bb
11bc 0 4f :4 0
171 :4 0 52 :2 0
53 :3 0 907 11c0
11c2 :3 0 52 :2 0
69 :4 0 90a 11c4
11c6 :3 0 52 :2 0
6a :4 0 90d 11c8
11ca :3 0 52 :2 0
64 :3 0 910 11cc
11ce :3 0 52 :2 0
6b :4 0 913 11d0
11d2 :3 0 52 :2 0
6c :3 0 6d :3 0
5c :2 0 6e :2 0
916 11d5 11d9 91a
11d4 11db :3 0 91d
11bd 11dd :2 0 11df
920 11e0 11ba 11df
0 11e1 922 0
11e2 924 11e5 :3 0
11e5 0 11e5 11e4
11e2 11e3 :6 0 11e7
45 :3 0 927 11e9
929 11e8 11e7 :2 0
11ea 92b :2 0 11ec
0 11ec 11eb 11a2
11ea :6 0 11ee 16
:3 0 92d 11f0 10fe
1175 0 11f1 0
11ee 0 11f1 92f
0 11f2 932 11f4
dcd e80 0 11f5
0 11f2 0 11f5
93b 0 11fa 12c
:5 0 11f8 47 0
11f9 93e 11f8 11f7
11fa 940 11fc 94c
11fb 11fa :2 0 1200
0 11fe 94e 11ff
0 11fe :2 0 1200
950 :2 0 1201 683
1200 0 126a 0
37 :3 0 d2 :3 0
d :3 0 d3 :3 0
3a :3 0 15 :4 0
15f 1 :8 0 121e
b0 :4 0 1209 :3 0
7e :3 0 6f :2 0
956 120c 120d :3 0
8 :3 0 63 :3 0
120f 1210 0 1d
:2 0 1211 1212 0
1214 959 121b 8
:3 0 63 :3 0 1215
1216 0 b1 :2 0
1217 1218 0 121a
95b 121c 120e 1214
0 121d 0 121a
0 121d 95d 0
121e 960 1268 65
:3 0 8 :3 0 63
:3 0 1221 1222 0
64 :3 0 1223 1224
0 125e 4a :3 0
4b :3 0 1226 1227
0 4a :3 0 5b
:3 0 1229 122a 0
66 :2 0 2 :4 0
172 :2 0 5e :2 0
5c :2 0 963 122f
1231 :3 0 966 122b
1233 1228 1235 1234
:2 0 4d :3 0 5f
:3 0 1237 1238 0
4f :4 0 173 :4 0
52 :2 0 53 :3 0
96a 123c 123e :3 0
52 :2 0 69 :4 0
96d 1240 1242 :3 0
52 :2 0 6a :4 0
970 1244 1246 :3 0
52 :2 0 64 :3 0
973 1248 124a :3 0
52 :2 0 6b :4 0
976 124c 124e :3 0
52 :2 0 6c :3 0
6d :3 0 5c :2 0
6e :2 0 979 1251
1255 97d 1250 1257
:3 0 980 1239 1259
:2 0 125b 983 125c
1236 125b 0 125d
985 0 125e 987
1261 :3 0 1261 0
1261 1260 125e 125f
:6 0 1263 47 :3 0
98a 1265 98c 1264
1263 :2 0 1266 98e
:2 0 1268 0 1268
1267 121e 1266 :6 0
126a 16 :3 0 990
126c b5 :4 0 126a
:4 0 1409 cf :3 0
40 :4 0 1270 :2 0
1276 126e 0 8
:3 0 63 :3 0 1271
1272 0 64 :3 0
1273 1274 0 1276
996 12c0 65 :3 0
8 :3 0 63 :3 0
1279 127a 0 64
:3 0 127b 127c 0
12b6 4a :3 0 4b
:3 0 127e 127f 0
4a :3 0 5b :3 0
1281 1282 0 66
:2 0 2 :4 0 174
:2 0 5e :2 0 5c
:2 0 999 1287 1289
:3 0 99c 1283 128b
1280 128d 128c :2 0
4d :3 0 5f :3 0
128f 1290 0 4f
:4 0 175 :4 0 52
:2 0 53 :3 0 9a0
1294 1296 :3 0 52
:2 0 69 :4 0 9a3
1298 129a :3 0 52
:2 0 6a :4 0 9a6
129c 129e :3 0 52
:2 0 64 :3 0 9a9
12a0 12a2 :3 0 52
:2 0 6b :4 0 9ac
12a4 12a6 :3 0 52
:2 0 6c :3 0 6d
:3 0 5c :2 0 6e
:2 0 9af 12a9 12ad
9b3 12a8 12af :3 0
9b6 1291 12b1 :2 0
12b3 9b9 12b4 128e
12b3 0 12b5 9bb
0 12b6 9bd 12b9
:3 0 12b9 0 12b9
12b8 12b6 12b7 :6 0
12bb 49 :3 0 9c0
12bd 9c2 12bc 12bb
:2 0 12be 9c4 :2 0
12c0 0 12c0 12bf
1276 12be :6 0 1409
1 :3 0 29 :3 0
176 :3 0 10 :3 0
9c6 12c3 12c5 12c2
12c6 0 1409 154
:3 0 d :3 0 177
:3 0 156 :3 0 d
:3 0 178 :3 0 8e
:3 0 d :3 0 8f
:3 0 23 :3 0 37
:3 0 3a :3 0 10
:4 0 179 1 :8 0
12db 8 :3 0 63
:3 0 12d6 12d7 0
64 :3 0 12d8 12d9
0 12db 9c8 1325
65 :3 0 8 :3 0
63 :3 0 12de 12df
0 64 :3 0 12e0
12e1 0 131b 4a
:3 0 4b :3 0 12e3
12e4 0 4a :3 0
5b :3 0 12e6 12e7
0 66 :2 0 2
:4 0 17a :2 0 5e
:2 0 5c :2 0 9cb
12ec 12ee :3 0 9ce
12e8 12f0 12e5 12f2
12f1 :2 0 4d :3 0
5f :3 0 12f4 12f5
0 4f :4 0 17b
:4 0 52 :2 0 53
:3 0 9d2 12f9 12fb
:3 0 52 :2 0 69
:4 0 9d5 12fd 12ff
:3 0 52 :2 0 6a
:4 0 9d8 1301 1303
:3 0 52 :2 0 64
:3 0 9db 1305 1307
:3 0 52 :2 0 6b
:4 0 9de 1309 130b
:3 0 52 :2 0 6c
:3 0 6d :3 0 5c
:2 0 6e :2 0 9e1
130e 1312 9e5 130d
1314 :3 0 9e8 12f6
1316 :2 0 1318 9eb
1319 12f3 1318 0
131a 9ed 0 131b
9ef 131e :3 0 131e
0 131e 131d 131b
131c :6 0 1320 4b
:3 0 9f2 1322 9f4
1321 1320 :2 0 1323
9f6 :2 0 1325 0
1325 1324 12db 1323
:6 0 1409 1 :3 0
57 :3 0 23 :3 0
1d :2 0 9f8 1327
132a 6f :2 0 5c
:2 0 9fd 132c 132e
:3 0 24 :3 0 d
:3 0 8f :3 0 1331
1332 0 1330 1333
0 133f 8 :3 0
63 :3 0 1335 1336
0 17c :3 0 10
:3 0 23 :3 0 24
:3 0 a00 1338 133c
1337 133d 0 133f
a04 1340 132f 133f
0 1341 a07 0
1409 17d :3 0 17e
:3 0 8e :3 0 37
:3 0 3a :3 0 10
:3 0 3a :3 0 10
:4 0 17f 1 :8 0
1360 b0 :4 0 134b
:3 0 7e :3 0 6f
:2 0 a0b 134e 134f
:3 0 8 :3 0 63
:3 0 1351 1352 0
1d :2 0 1353 1354
0 1356 a0e 135d
8 :3 0 63 :3 0
1357 1358 0 b1
:2 0 1359 135a 0
135c a10 135e 1350
1356 0 135f 0
135c 0 135f a12
0 1360 a15 13aa
65 :3 0 8 :3 0
63 :3 0 1363 1364
0 64 :3 0 1365
1366 0 13a0 4a
:3 0 4b :3 0 1368
1369 0 4a :3 0
5b :3 0 136b 136c
0 66 :2 0 2
:4 0 180 :2 0 5e
:2 0 5c :2 0 a18
1371 1373 :3 0 a1b
136d 1375 136a 1377
1376 :2 0 4d :3 0
5f :3 0 1379 137a
0 4f :4 0 181
:4 0 52 :2 0 53
:3 0 a1f 137e 1380
:3 0 52 :2 0 69
:4 0 a22 1382 1384
:3 0 52 :2 0 6a
:4 0 a25 1386 1388
:3 0 52 :2 0 64
:3 0 a28 138a 138c
:3 0 52 :2 0 6b
:4 0 a2b 138e 1390
:3 0 52 :2 0 6c
:3 0 6d :3 0 5c
:2 0 6e :2 0 a2e
1393 1397 a32 1392
1399 :3 0 a35 137b
139b :2 0 139d a38
139e 1378 139d 0
139f a3a 0 13a0
a3c 13a3 :3 0 13a3
0 13a3 13a2 13a0
13a1 :6 0 13a5 4d
:3 0 a3f 13a7 a41
13a6 13a5 :2 0 13a8
a43 :2 0 13aa 0
13aa 13a9 1360 13a8
:6 0 1409 1 :3 0
8 :3 0 63 :3 0
13ac 13ad 0 6f
:2 0 b1 :2 0 a47
13af 13b1 :3 0 8
:3 0 63 :3 0 13b3
13b4 0 1d :2 0
13b5 13b6 0 13b8
a4a 13b9 13b2 13b8
0 13ba a4c 0
1409 4a :3 0 4b
:3 0 13bb 13bc 0
4a :3 0 5b :3 0
13be 13bf 0 182
:2 0 2 :4 0 183
:2 0 5e :2 0 5c
:2 0 a4e 13c4 13c6
:3 0 a51 13c0 13c8
13bd 13ca 13c9 :2 0
4d :3 0 5f :3 0
13cc 13cd 0 4f
:4 0 184 :4 0 52
:2 0 53 :3 0 a55
13d1 13d3 :3 0 52
:2 0 69 :4 0 a58
13d5 13d7 :3 0 52
:2 0 78 :4 0 a5b
13d9 13db :3 0 52
:2 0 57 :3 0 58
:3 0 8 :3 0 63
:3 0 13e0 13e1 0
a5e 13df 13e3 59
:4 0 a60 13de 13e6
a63 13dd 13e8 :3 0
52 :2 0 83 :4 0
a66 13ea 13ec :3 0
52 :2 0 55 :4 0
a69 13ee 13f0 :3 0
52 :2 0 3 :3 0
a6c 13f2 13f4 :3 0
52 :2 0 55 :4 0
a6f 13f6 13f8 :3 0
a72 13ce 13fa :2 0
13fc a75 13fd 13cb
13fc 0 13fe a77
0 1409 7c :3 0
185 :3 0 13ff 1400
0 8 :3 0 63
:3 0 1402 1403 0
3 :3 0 7e :3 0
a79 1401 1407 :2 0
1409 a7d 14aa 8
:3 0 186 :2 0 4
140a 140b 0 4a
:3 0 4b :3 0 140d
140e 0 4a :3 0
5b :3 0 1410 1411
0 66 :2 0 2
:4 0 187 :2 0 5e
:2 0 5c :2 0 a8e
1416 1418 :3 0 a91
1412 141a 140f 141c
141b :2 0 4d :3 0
5f :3 0 141e 141f
0 4f :4 0 188
:4 0 52 :2 0 53
:3 0 a95 1423 1425
:3 0 a98 1420 1427
:2 0 1440 4d :3 0
5f :3 0 1429 142a
0 4f :4 0 189
:4 0 52 :2 0 8
:3 0 18a :3 0 142f
1430 0 a9b 142e
1432 :3 0 52 :2 0
83 :4 0 a9e 1434
1436 :3 0 52 :2 0
8 :3 0 18b :3 0
1439 143a 0 aa1
1438 143c :3 0 aa4
142b 143e :2 0 1440
aa7 1441 141d 1440
0 1442 aaa 0
1452 b4 :3 0 49
:3 0 8 :3 0 18a
:3 0 18c :3 0 8
:3 0 18b :3 0 18d
:3 0 18e :4 0 18f
1 :a 0 144e :2 0
1452 1444 144c :2 0
7 :3 0 49 :3 0
1450 :2 0 1452 aac
1454 ab0 1453 1452
:2 0 14a8 65 :3 0
8 :3 0 63 :3 0
1457 1458 0 64
:3 0 1459 145a 0
14a0 4a :3 0 4b
:3 0 145c 145d 0
4a :3 0 5b :3 0
145f 1460 0 66
:2 0 2 :4 0 190
:2 0 5e :2 0 5c
:2 0 ab2 1465 1467
:3 0 ab5 1461 1469
145e 146b 146a :2 0
4d :3 0 5f :3 0
146d 146e 0 4f
:4 0 191 :4 0 52
:2 0 53 :3 0 ab9
1472 1474 :3 0 abc
146f 1476 :2 0 1490
4d :3 0 5f :3 0
1478 1479 0 4f
:4 0 6a :4 0 52
:2 0 64 :3 0 abf
147d 147f :3 0 52
:2 0 6b :4 0 ac2
1481 1483 :3 0 52
:2 0 6c :3 0 6d
:3 0 5c :2 0 6e
:2 0 ac5 1486 148a
ac9 1485 148c :3 0
acc 147a 148e :2 0
1490 acf 1491 146c
1490 0 1492 ad2
0 14a0 b4 :3 0
49 :3 0 18c :3 0
8 :3 0 18b :3 0
18d :3 0 18e :4 0
192 1 :a 0 149c
:2 0 14a0 1494 149a
:2 0 7 :3 0 49
:3 0 149e :2 0 14a0
ad4 14a3 :3 0 14a3
0 14a3 14a2 14a0
14a1 :6 0 14a5 1
:3 0 ad9 14a7 adb
14a6 14a5 :2 0 14a8
add :2 0 14aa ae0
14aa 14a9 1409 14a8
:6 0 14ab :2 0 2
10 14aa 14ae :3 0
14ad 14ab 14af :8 0

b01
4
:3 0 1 3 1
7 2 6 a
1 14 1 12
1 1e 1 1c
1 28 1 26
1 2d 1 34
1 32 1 3b
1 39 1 42
1 40 1 49
1 47 1 50
1 4e 1 55
1 5a 1 5f
1 65 1 6b
1 71 1 77
1 7d 1 83
1 89 1 8f
1 95 1 9b
1 a1 1 a7
1 ad 1 b3
1 bb 1 b9
1 df 1 e5
1 fa 1 10b
1 111 1 11e
1 12a 2 12d
12f 2 132 134
2 136 138 2
13a 13c 2 13e
140 1 146 2
148 149 2 142
14b 2 14d 14f
4 126 12c 131
151 1 153 1
155 2 15f 161
3 15d 15e 163
2 16c 16e 2
16b 170 1 172
1 174 2 182
187 2 198 19a
3 196 197 19c
2 1a5 1a7 2
1a9 1ab 2 1ad
1af 2 1b1 1b3
2 1b5 1b7 3
1bc 1bd 1be 2
1b9 1c0 2 1a4
1c2 1 1c4 1
1c6 2 18f 1c7
1 1cb 1 18a
1 1cf 1 1da
2 1d6 1da 2
1ea 1ef 2 200
202 3 1fe 1ff
204 2 20d 20f
2 211 213 2
215 217 2 219
21b 2 21d 21f
3 224 225 226
2 221 228 2
20c 22a 1 22c
1 22e 2 1f7
22f 1 233 1
1f2 1 237 1
242 2 23e 242
2 24e 250 3
24c 24d 252 2
25b 25d 2 25f
261 2 263 265
1 26d 2 26f
270 2 267 272
2 25a 274 1
276 1 278 2
282 284 3 280
281 286 2 28f
291 2 28e 293
1 295 1 297
2 29e 29f 3
279 298 2a1 2
2a5 2a6 1 2aa
2 2a8 2aa 2
2af 2b0 1 2b4
2 2b2 2b4 2
2c2 2c4 3 2c0
2c1 2c6 2 2cf
2d1 2 2d3 2d5
2 2d7 2d9 1
2e1 2 2e3 2e4
2 2db 2e6 2
2e8 2ea 2 2ec
2ee 2 2f0 2f2
2 2f4 2f6 2
2ce 2f8 1 2fa
1 2fc 2 306
308 3 304 305
30a 2 313 315
2 312 317 1
319 1 31b 3
322 323 324 3
2fd 31c 326 2
329 328 2 331
336 2 347 349
3 345 346 34b
2 354 356 2
358 35a 2 35c
35e 2 360 362
2 364 366 3
36b 36c 36d 2
368 36f 2 353
371 1 373 1
375 2 33e 376
1 37a 1 339
1 37e 2 384
386 2 388 38a
2 38c 38e 4
23a 32a 381 391
2 397 398 1
39c 2 39a 39c
1 3e6 2 3e5
3e6 1 3ee 1
3f4 2 3f6 3f7
2 3e3 3f8 2
409 40b 3 407
408 40d 2 416
418 2 41a 41c
2 41e 420 2
422 424 2 426
428 3 42d 42e
42f 2 42a 431
2 415 433 1
435 1 437 2
400 438 1 43c
1 3fb 1 440
2 44c 44d 1
458 1 45e 2
460 461 1 469
2 465 469 1
46e 1 470 1
4ae 2 4ad 4ae
1 4b6 1 4bc
2 4be 4bf 2
4ab 4c0 2 4d1
4d3 3 4cf 4d0
4d5 2 4de 4e0
2 4e2 4e4 2
4e6 4e8 2 4ea
4ec 2 4ee 4f0
3 4f5 4f6 4f7
2 4f2 4f9 2
4dd 4fb 1 4fd
1 4ff 2 4c8
500 1 504 1
4c3 1 508 1
516 2 515 516
1 51e 1 524
2 526 527 2
513 528 2 539
53b 3 537 538
53d 2 546 548
2 54a 54c 2
54e 550 2 552
554 2 556 558
3 55d 55e 55f
2 55a 561 2
545 563 1 565
1 567 2 530
568 1 56c 1
52b 1 570 5
44e 462 471 50b
573 2 57a 580
2 591 593 3
58f 590 595 2
59e 5a0 2 5a2
5a4 2 5a6 5a8
2 5aa 5ac 2
5ae 5b0 3 5b5
5b6 5b7 2 5b2
5b9 2 59d 5bb
1 5bd 1 5bf
2 588 5c0 1
5c4 1 583 1
5c8 4 443 447
577 5cb 1 5ce
1 5dc 2 5db
5dc 1 5e4 1
5ea 2 5ec 5ed
2 5d9 5ee 2
5ff 601 3 5fd
5fe 603 2 60c
60e 2 610 612
2 614 616 2
618 61a 2 61c
61e 3 623 624
625 2 620 627
2 60b 629 1
62b 1 62d 2
5f6 62e 1 632
1 5f1 1 636
2 642 644 2
646 648 2 64a
64c 6 395 5cf
639 63d 640 64f
2 651 652 4
65b 65c 65d 65e
1 669 1 66f
2 671 672 1
67a 2 676 67a
1 67f 1 681
1 6a6 2 6a5
6a6 1 6ae 1
6b4 2 6b6 6b7
2 6a3 6b8 2
6c9 6cb 3 6c7
6c8 6cd 2 6d6
6d8 2 6da 6dc
2 6de 6e0 2
6e2 6e4 2 6e6
6e8 3 6ed 6ee
6ef 2 6ea 6f1
2 6d5 6f3 1
6f5 1 6f7 2
6c0 6f8 1 6fc
1 6bb 1 700
1 76a 2 769
76a 1 772 1
778 2 77a 77b
2 767 77c 2
78d 78f 3 78b
78c 791 2 79a
79c 2 79e 7a0
2 7a2 7a4 2
7a6 7a8 2 7aa
7ac 3 7b1 7b2
7b3 2 7ae 7b5
2 799 7b7 1
7b9 1 7bb 2
784 7bc 1 7c0
1 77f 1 7c4
1 806 2 805
806 1 80e 1
814 2 816 817
2 803 818 2
829 82b 3 827
828 82d 2 836
838 2 83a 83c
2 83e 840 2
842 844 2 846
848 3 84d 84e
84f 2 84a 851
2 835 853 1
855 1 857 2
820 858 1 85c
1 81b 1 860
3 703 7c7 863
1 684 2 86f
874 2 885 887
3 883 884 889
2 892 894 2
896 898 2 89a
89c 2 89e 8a0
2 8a2 8a4 3
8a9 8aa 8ab 2
8a6 8ad 2 891
8af 1 8b1 1
8b3 2 87c 8b4
1 8b8 1 877
1 8bc 1 8c7
2 8c3 8c7 1
8cb 1 8d4 1
8d6 2 8e4 8e9
2 8fa 8fc 3
8f8 8f9 8fe 2
907 909 2 90b
90d 2 90f 911
2 913 915 2
917 919 3 91e
91f 920 2 91b
922 2 906 924
1 926 1 928
2 8f1 929 1
92d 1 8ec 1
931 1 93c 2
938 93c 1 940
2 949 94a 1
94e 2 94c 94e
1 953 1 95b
2 95a 95b 1
963 1 969 2
96b 96c 2 958
96d 2 97e 980
3 97c 97d 982
2 98b 98d 2
98f 991 2 993
995 2 997 999
2 99b 99d 3
9a2 9a3 9a4 2
99f 9a6 2 98a
9a8 1 9aa 1
9ac 2 975 9ad
1 9b1 1 970
1 9b5 1 9c0
2 9bf 9c0 1
9c8 1 9ce 2
9d0 9d1 2 9bd
9d2 2 9e3 9e5
3 9e1 9e2 9e7
2 9f0 9f2 2
9f4 9f6 2 9f8
9fa 2 9fc 9fe
2 a00 a02 3
a07 a08 a09 2
a04 a0b 2 9ef
a0d 1 a0f 1
a11 2 9da a12
1 a16 1 9d5
1 a1a 1 a25
2 a24 a25 1
a2d 1 a33 2
a35 a36 2 a22
a37 2 a48 a4a
3 a46 a47 a4c
2 a55 a57 2
a59 a5b 2 a5d
a5f 2 a61 a63
2 a65 a67 3
a6c a6d a6e 2
a69 a70 2 a54
a72 1 a74 1
a76 2 a3f a77
1 a7b 1 a3a
1 a7f 1 a8a
2 a89 a8a 1
a92 1 a98 2
a9a a9b 2 a87
a9c 2 aad aaf
3 aab aac ab1
2 aba abc 2
abe ac0 2 ac2
ac4 2 ac6 ac8
2 aca acc 3
ad1 ad2 ad3 2
ace ad5 2 ab9
ad7 1 ad9 1
adb 2 aa4 adc
1 ae0 1 a9f
1 ae4 5 9b8
a1d a82 ae7 aeb
2 aed aee 1
aef 2 af3 af6
2 af8 af9 3
b05 b06 b07 1
b12 1 b18 2
b1a b1b 1 b23
2 b1f b23 1
b28 1 b2a 2
b2d b2e 1 b32
2 b30 b32 1
b47 2 b46 b47
1 b4f 1 b55
2 b57 b58 2
b44 b59 2 b6a
b6c 3 b68 b69
b6e 2 b77 b79
2 b7b b7d 2
b7f b81 2 b83
b85 2 b87 b89
3 b8e b8f b90
2 b8b b92 2
b76 b94 1 b96
1 b98 2 b61
b99 1 b9d 1
b5c 1 ba1 1
bac 2 ba8 bac
1 bba 2 bb9
bba 1 bc2 1
bc8 2 bca bcb
2 bb7 bcc 2
bdd bdf 3 bdb
bdc be1 2 bea
bec 2 bee bf0
2 bf2 bf4 2
bf6 bf8 2 bfa
bfc 3 c01 c02
c03 2 bfe c05
2 be9 c07 1
c09 1 c0b 2
bd4 c0c 1 c10
1 bcf 1 c14
1 c17 1 c26
2 c25 c26 1
c2e 1 c34 2
c36 c37 2 c23
c38 2 c49 c4b
3 c47 c48 c4d
2 c56 c58 2
c5a c5c 2 c5e
c60 2 c62 c64
2 c66 c68 3
c6d c6e c6f 2
c6a c71 2 c55
c73 1 c75 1
c77 2 c40 c78
1 c7c 1 c3b
1 c80 1 c83
2 c86 c87 2
ba4 c88 2 c8c
c8d 1 c91 2
c8f c91 1 ca0
2 c9f ca0 1
ca8 1 cae 2
cb0 cb1 2 c9d
cb2 2 cc3 cc5
3 cc1 cc2 cc7
2 cd0 cd2 2
cd4 cd6 2 cd8
cda 2 cdc cde
2 ce0 ce2 3
ce7 ce8 ce9 2
ce4 ceb 2 ccf
ced 1 cef 1
cf1 2 cba cf2
1 cf6 1 cb5
1 cfa 1 cfd
2 d01 d00 4
b08 b1c b2b d02
2 d08 d0e 2
d1f d21 3 d1d
d1e d23 2 d2c
d2e 2 d30 d32
2 d34 d36 2
d38 d3a 2 d3c
d3e 3 d43 d44
d45 2 d40 d47
2 d2b d49 1
d4b 1 d4d 2
d16 d4e 1 d52
1 d11 1 d56
1 d66 2 d65
d66 1 d6e 1
d74 2 d76 d77
2 d63 d78 2
d89 d8b 3 d87
d88 d8d 2 d96
d98 2 d9a d9c
2 d9e da0 2
da2 da4 2 da6
da8 3 dad dae
daf 2 daa db1
2 d95 db3 1
db5 1 db7 2
d80 db8 1 dbc
1 d7b 1 dc0
2 dc6 dc7 1
dcb 2 dc9 dcb
1 e08 2 e07
e08 1 e10 1
e16 2 e18 e19
2 e05 e1a 2
e2b e2d 3 e29
e2a e2f 2 e38
e3a 2 e3c e3e
2 e40 e42 2
e44 e46 2 e48
e4a 3 e4f e50
e51 2 e4c e53
2 e37 e55 1
e57 1 e59 2
e22 e5a 1 e5e
1 e1d 1 e62
2 e68 e69 1
e6d 2 e6b e6d
5 e75 e76 e77
e78 e79 2 e72
e7c 1 e7e 2
e65 e7f 2 e88
e89 1 e94 1
e9a 2 e9c e9d
1 ea5 2 ea1
ea5 1 eaa 1
eac 1 ee7 2
ee6 ee7 1 eef
1 ef5 2 ef7
ef8 2 ee4 ef9
2 f0a f0c 3
f08 f09 f0e 2
f17 f19 2 f1b
f1d 2 f1f f21
2 f23 f25 2
f27 f29 3 f2e
f2f f30 2 f2b
f32 2 f16 f34
1 f36 1 f38
2 f01 f39 1
f3d 1 efc 1
f41 1 f4f 2
f4e f4f 1 f57
1 f5d 2 f5f
f60 2 f4c f61
2 f72 f74 3
f70 f71 f76 2
f7f f81 2 f83
f85 2 f87 f89
2 f8b f8d 2
f8f f91 3 f96
f97 f98 2 f93
f9a 2 f7e f9c
1 f9e 1 fa0
2 f69 fa1 1
fa5 1 f64 1
fa9 5 e8a e9e
ead f44 fac 2
fb3 fb9 2 fca
fcc 3 fc8 fc9
fce 2 fd7 fd9
2 fdb fdd 2
fdf fe1 2 fe3
fe5 2 fe7 fe9
3 fee fef ff0
2 feb ff2 2
fd6 ff4 1 ff6
1 ff8 2 fc1
ff9 1 ffd 1
fbc 1 1001 2
1007 1008 1 100c
2 100a 100c 2
1011 1012 1 1016
2 1014 1016 1
1024 2 1023 1024
1 102c 1 1032
2 1034 1035 2
1021 1036 2 1047
1049 3 1045 1046
104b 2 1054 1056
2 1058 105a 2
105c 105e 2 1060
1062 2 1064 1066
3 106b 106c 106d
2 1068 106f 2
1053 1071 1 1073
1 1075 2 103e
1076 1 107a 1
1039 1 107e 1
1081 1 1084 5
108b 108c 108d 108e
108f 2 10a4 10a9
2 10ba 10bc 3
10b8 10b9 10be 2
10c7 10c9 2 10cb
10cd 2 10cf 10d1
2 10d3 10d5 2
10d7 10d9 3 10de
10df 10e0 2 10db
10e2 2 10c6 10e4
1 10e6 1 10e8
2 10b1 10e9 1
10ed 1 10ac 1
10f1 2 10f7 10f8
1 10fc 2 10fa
10fc 1 1116 2
1115 1116 1 111e
1 1124 2 1126
1127 2 1113 1128
2 1139 113b 3
1137 1138 113d 2
1146 1148 2 114a
114c 2 114e 1150
2 1152 1154 2
1156 1158 3 115d
115e 115f 2 115a
1161 2 1145 1163
1 1165 1 1167
2 1130 1168 1
116c 1 112b 1
1170 1 1173 1
118f 2 118e 118f
1 1197 1 119d
2 119f 11a0 2
118c 11a1 2 11b2
11b4 3 11b0 11b1
11b6 2 11bf 11c1
2 11c3 11c5 2
11c7 11c9 2 11cb
11cd 2 11cf 11d1
3 11d6 11d7 11d8
2 11d3 11da 2
11be 11dc 1 11de
1 11e0 2 11a9
11e1 1 11e5 1
11a4 1 11e9 1
11ec 2 11ef 11f0
8 e83 fb0 1004
1085 1088 1092 10f4
11f1 2 11f3 11f4
1 11f6 b 8bf
8d7 934 afa afd
b00 d05 d59 dc3
11f5 11f9 1 868
1 11fd 3 867
11fc 11ff 1 120b
2 120a 120b 1
1213 1 1219 2
121b 121c 2 1208
121d 2 122e 1230
3 122c 122d 1232
2 123b 123d 2
123f 1241 2 1243
1245 2 1247 1249
2 124b 124d 3
1252 1253 1254 2
124f 1256 2 123a
1258 1 125a 1
125c 2 1225 125d
1 1261 1 1220
1 1265 5 65f
673 682 1201 1268
2 126f 1275 2
1286 1288 3 1284
1285 128a 2 1293
1295 2 1297 1299
2 129b 129d 2
129f 12a1 2 12a3
12a5 3 12aa 12ab
12ac 2 12a7 12ae
2 1292 12b0 1
12b2 1 12b4 2
127d 12b5 1 12b9
1 1278 1 12bd
1 12c4 2 12d5
12da 2 12eb 12ed
3 12e9 12ea 12ef
2 12f8 12fa 2
12fc 12fe 2 1300
1302 2 1304 1306
2 1308 130a 3
130f 1310 1311 2
130c 1313 2 12f7
1315 1 1317 1
1319 2 12e2 131a
1 131e 1 12dd
1 1322 2 1328
1329 1 132d 2
132b 132d 3 1339
133a 133b 2 1334
133e 1 1340 1
134d 2 134c 134d
1 1355 1 135b
2 135d 135e 2
134a 135f 2 1370
1372 3 136e 136f
1374 2 137d 137f
2 1381 1383 2
1385 1387 2 1389
138b 2 138d 138f
3 1394 1395 1396
2 1391 1398 2
137c 139a 1 139c
1 139e 2 1367
139f 1 13a3 1
1362 1 13a7 1
13b0 2 13ae 13b0
1 13b7 1 13b9
2 13c3 13c5 3
13c1 13c2 13c7 2
13d0 13d2 2 13d4
13d6 2 13d8 13da
1 13e2 2 13e4
13e5 2 13dc 13e7
2 13e9 13eb 2
13ed 13ef 2 13f1
13f3 2 13f5 13f7
2 13cf 13f9 1
13fb 1 13fd 3
1404 1405 1406 10
156 175 178 17b
1d2 653 658 126c
12c0 12c7 1325 1341
13aa 13ba 13fe 1408
2 1415 1417 3
1413 1414 1419 2
1422 1424 2 1421
1426 2 142d 1431
2 1433 1435 2
1437 143b 2 142c
143d 2 1428 143f
1 1441 3 1442
144d 1451 1 140c
2 1464 1466 3
1462 1463 1468 2
1471 1473 2 1470
1475 2 147c 147e
2 1480 1482 3
1487 1488 1489 2
1484 148b 2 147b
148d 2 1477 148f
1 1491 4 145b
1492 149b 149f 1
14a3 1 1456 2
1454 14a7 20 1a
24 2b 30 37
3e 45 4c 53
58 5d 63 69
6f 75 7b 81
87 8d 93 99
9f a5 ab b1
b7 be e0 ea
fb 10c 116 
1
4
0 
14ae
0
1
50
4f
24
0 1 1 1 1 5 1 7
1 9 1 b 1 d e d
10 1 12 1 14 1 16 17
16 19 16 1b 16 1d 16 1f
16 21 16 23 16 25 16 27
16 29 2a 29 2c 29 2e 29
30 16 32 16 34 16 36 16
38 39 38 3b 16 3d 16 3f
16 41 16 43 16 45 16 47
1 49 1 4b 1 4d 1 0

2 0 1
83 1 0
a1 1 0
7d 1 0
5a 1 0
47 1 0
4e 1 0
ed 1 3
1c 1 0
101 1 4
b3 1 0
b9 1 0
12 1 0
71 1 0
2d 1 0
a7 1 0
95 1 0
89 1 0
e5 1 0
3 1 0
55 1 0
65 1 0
77 1 0
5f 1 0
6b 1 0
8f 1 0
40 1 0
39 1 0
9b 1 0
32 1 0
26 1 0
11f6 16 47
7 1 0
ad 1 0
c1 1 2
111 1 0
0

/
SHOW ERRORS FUNCTION SP_COMMIT_ASSIGN;
ALTER FUNCTION SP_COMMIT_ASSIGN COMPILE DEBUG;
/****************************************************************************************
Accept ETC and/or FORECAST_START, Assign level
  Bitflag =
    1 - ETC
    2 - FORECAST_START
    3 - ETC + FORECAST_START
****************************************************************************************/
Prompt == FUNCTION SP_ACPT_ETC_ASSIGN ==
CREATE OR REPLACE FUNCTION SP_ACPT_ETC_ASSIGN wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
ab
2 :e:
1FUNCTION:
1SP_ACPT_ETC_ASSIGN:
1ID001:
1VARCHAR2:
1BITFLAG001:
1PLS_INTEGER:
1REC_USER001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_TSK_ASSIGNMENT_ID:
132:
1H_PRJ_ASSIGNMENT_ID:
1H_REC_USER:
1H_PROJECT_ID:
1H_TASK_ID:
1H_RES_ID:
1H_RES_TYPE:
11:
1H_TA_START_DT:
1TIMESTAMP:
1H_TA_FINISH_DT:
1H_START_DATE:
1H_FINISH_DATE:
1H_FINISH_D:
1DATE:
1H_LAST_SUBMITTED:
1H_WEEK_OF:
1H_BIT_FLAG:
1H_EFFORT:
10:
1H_CONTOUR:
1H_BITFLAG:
1H_REMAINING:
1H_TOTAL:
1H_CONSTR_DT:
1H_DAYOFYEAR:
1H_FINISH_TIME:
18:
1H_MINUTE:
1H_CONSTR_TYPE:
1H_FF_FLAG:
1H_ETC:
1H_SCHED_WORK:
1H_TEMP_VAR:
1H_TEMP_SC_STATE:
1H_REG_COST:
1NUMBER:
10.00:
1H_REG_SALE:
1H_SD:
1H_FD:
1H_BILLABLE:
1H_CAPITAL_EXPENSE:
1H_TPH_DELETE:
1H_MLST_PERCENT:
1H_PROJAFFECTED_START:
1H_WORK_TODATE:
1H_PASSED:
1H_NOT_EFFORT_PA:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_ACPT_ETC_ASSIGN(:
1':
1, :
1COALESCE:
1TO_CHAR:
1NULL:
1);:
1CHECK_TRACE:
160:
1+:
1FPUT:
1               ENTER:: SP_ACPT_ETC_ASSIGN(61) :: cplan.sql(17986) :: :
1PROJECT_ID:
1TASK_ID:
1PROJECT_ASSIGNMENT_ID:
1SCHED_WORK:
1PLANNED_WORK:
1FORECAST_START:
1FORECAST_FINISH:
1ETC:
1WORK_TODATE:
1C_CONTOUR:
1LAST_SUBMITTED:
1PLANNED_START:
1SCHED_START:
1PLANNED_FINISH:
1SCHED_FINISH:
1UNRESOLVED_START:
1UNRESOLVED_FINISH:
1BILLABLE:
1CAPITAL_EXPENSE:
1REGULAR_COST:
1REGULAR_RATE:
1BIT_FLAG:
1MILESTONE_PERCENT:
1RESOURCE_ID:
1RESOURCE_TYPE:
1TASK_ASSIGNMENTS:
1TSK_ASSIGNMENT_ID:
1SELECT:n      PROJECT_ID,:n      TASK_ID,:n      PROJECT_ASSIGNMENT_ID,:n    +
1  SCHED_WORK+PLANNED_WORK,:n      FORECAST_START,:n      FORECAST_FINISH,:n  +
1    CASE WHEN h_bitflag = 2 AND FORECAST_START IS NuLL THEN 0 ELSE ETC END,:n+
1      SCHED_WORK+PLANNED_WORK - WORK_TODATE,:n      ETC,:n      C_CONTOUR,:n +
1     LAST_SUBMITTED,:n      CASE WHEN FORECAST_FINISH IS NOT NuLL AND FORECAS+
1T_START IS NuLL AND FORECAST_FINISH BETWEEN COALESCE(PLANNED_START, SCHED_STA+
1RT) AND COALESCE(PLANNED_FINISH, SCHED_FINISH) THEN 1 ELSE 0 END,:n      UNRE+
1SOLVED_START,:n      UNRESOLVED_FINISH,:n      BILLABLE,:n      CAPITAL_EXPEN+
1SE,:n      REGULAR_COST,:n      REGULAR_RATE,:n      BIT_FLAG,:n      MILESTO+
1NE_PERCENT,:n      RESOURCE_ID,:n      RESOURCE_TYPE,:n      WORK_TODATE:n   +
1   INTO:n      h_project_id,:n      h_task_id,:n      h_prj_assignment_id,:n +
1     h_sched_work,:n      h_start_date,:n      h_finish_date,:n      h_effort+
1,:n      h_remaining,:n      h_etc,:n      h_contour,:n      h_last_submitted+
1,:n      h_FF_flag,:n      h_ta_start_DT,:n      h_ta_finish_DT,:n      h_bil+
1lable,:n      h_capital_expense,:n      h_reg_cost,:n      h_reg_sale,:n     +
1 h_bit_flag,:n      h_mlst_percent,:n      h_res_id,:n      h_res_type,:n    +
1  h_work_todate:n      FROM TASK_ASSIGNMENTS:n      WHERE TSK_ASSIGNMENT_ID =+
1 h_tsk_assignment_id:n      AND (((SCHED_WORK+PLANNED_WORK) > 0:n      AND (S+
1CHED_WORK+PLANNED_WORK - WORK_TODATE) <> ETC):n      OR FORECAST_START IS NOT+
1 NULL OR FORECAST_FINISH IS NOT NULL):
1SC_STATE:
1SQLCODE:
1OTHERS:
116:
1138:
1           EXCEPTION:: SP_ACPT_ETC_ASSIGN(139) :: cplan.sql(18064) :: :
1 :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1=:
1SC_SQL_NO_DATA:
1145:
1        RETURN_ERROR:: SP_ACPT_ETC_ASSIGN(146) :: cplan.sql(18071) :: :
1STATE:: :
1PMO_CNST:
1RECORD_NOT_FOUND:
1 ID:: :
1148:
1                EXIT:: SP_ACPT_ETC_ASSIGN(149) :: cplan.sql(18074) :: :
1PMODEFINES:
1PMO_RETURN_ERROR_SP:
1TRUE:
1FC_ACPT_EFFORT:
1>:
1200000:
1167:
1        RETURN_ERROR:: SP_ACPT_ETC_ASSIGN(168) :: cplan.sql(18093) :: :
1170:
1                EXIT:: SP_ACPT_ETC_ASSIGN(171) :: cplan.sql(18096) :: :
1!=:
1SELECT ETC INTO h_total:n            FROM TASK_ASSIGNMENTS:n            WHERE+
1 TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
1189:
1           EXCEPTION:: SP_ACPT_ETC_ASSIGN(190) :: cplan.sql(18115) :: :
1UPDATE TASK_ASSIGNMENTS:n               SET ETC  = h_etc:n               WHER+
1E TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
1FOUND:
1100:
1209:
1           EXCEPTION:: SP_ACPT_ETC_ASSIGN(210) :: cplan.sql(18135) :: :
1FC_ROLLUP:
14:
1220:
1       RETURN_STATUS:: SP_ACPT_ETC_ASSIGN(221) :: cplan.sql(18146) :: :
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
1227:
1           EXCEPTION:: SP_ACPT_ETC_ASSIGN(228) :: cplan.sql(18153) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1ID:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
1239:
1           EXCEPTION:: SP_ACPT_ETC_ASSIGN(240) :: cplan.sql(18165) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
517
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 1c
81 b0 a3 a0 1c 81 b0 a3
a0 1c 81 b0 a3 a0 1c 81
b0 a3 a0 1c 81 b0 a3 a0
1c 81 b0 a3 a0 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
81 b0 a3 a0 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 81
b0 a3 a0 1c 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 :2 a0 6b
1c 81 b0 :2 a0 6b :2 a0 6b 6e
a5 b a 10 :2 a0 6b 6e :2 a0
6b 6e a5 b 6e 7e a0 b4
2e 6e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
d :2 a0 d :2 a0 d a0 4d d
a0 4d d :46 a0 12a :2 a0 6b a0
d b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
a0 7e a0 6b b4 2e 5a :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b :2 a0 a5 57 b7 19
3c :1c a0 a5 b d :2 a0 51 a5
b 7e 51 b4 2e :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :3 a0 a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 51
a5 b :2 a0 a5 57 b7 a0 51
d :2 a0 51 a5 b 7e 51 b4
2e :5 a0 12a :2 a0 6b a0 d b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 51 a5 b
a0 7e a0 51 a5 b b4 2e
:5 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 19 3c b7 19 3c :3 a0
a5 b d b7 :2 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b :2 a0
a5 57 b7 :2 a0 6b :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 :2 a0 6b :2 6e
7e :2 a0 6b b4 2e 7e 6e b4
2e 7e :2 a0 6b b4 2e a5 57
b7 19 3c :9 a0 12a e9 dd :2 a0
65 b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c :7 a0 12a e9 dd :2 a0 65 b7
a4 b1 11 4f b7 a6 9 a4
b1 11 68 4f 1d 17 b5 
517
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 30
56 5a 5e 62 65 69 86 71
75 78 79 81 70 a3 91 6d
95 96 9e 90 c0 ae 8d b2
b3 bb ad dd cb aa cf d0
d8 ca fa e8 c7 ec ed f5
e7 117 105 e4 109 10a 112 104
134 122 101 126 127 12f 121 150
13f 143 14b 11e 168 157 15b 163
13e 184 173 177 17f 13b 19c 18b
18f 197 172 1b8 1a7 1ab 1b3 16f
1d0 1bf 1c3 1cb 1a6 1ec 1db 1df
1e7 1a3 208 1f3 1f7 1fa 1fb 203
1da 224 213 217 1d7 21f 212 240
22f 233 20f 23b 22e 25c 24b 24f
22b 257 24a 278 267 26b 247 273
266 294 283 287 263 28f 282 2b0
29f 2a3 2ab 27f 2c8 2b7 2bb 2c3
29e 2e5 2d3 29b 2d7 2d8 2e0 2d2
301 2f0 2f4 2cf 2fc 2ef 31d 30c
310 2ec 318 30b 339 328 32c 308
334 327 355 344 348 324 350 343
371 360 364 340 36c 35f 38d 37c
380 35c 388 37b 3a9 398 39c 378
3a4 397 3c5 3b4 3b8 394 3c0 3b3
3e1 3d0 3d4 3b0 3dc 3cf 3fd 3ec
3f0 3f8 3cc 415 404 408 410 3eb
431 420 424 3e8 42c 41f 44d 43c
440 41c 448 43b 469 458 45c 438
464 457 485 474 478 454 480 473
4a1 490 494 49c 470 4bc 4a8 4ac
4b4 4b7 48f 4d8 4c7 4cb 48c 4d3
4c6 4f4 4e3 4e7 4c3 4ef 4e2 514
4ff 503 4df 507 50f 4fe 51b 51f
4fb 523 527 52b 52e 533 534 1
536 53b 53f 543 546 54b 54f 553
556 55b 55c 55e 563 566 56a 56b
570 575 578 57d 57e 583 586 58a
58b 590 593 598 599 59e 5a1 5a6
5a7 5ac 5af 5b3 5b7 5bb 5bc 5be
5c3 5c4 5c6 5c7 5cc 5cf 5d4 5d5
5da 5dd 5e2 5e3 5e8 5eb 5ef 5f0
5f5 5f8 5fd 5fe 603 606 60b 60c
611 612 617 619 61d 620 624 628
62b 62f 633 636 639 63e 641 644
647 648 64d 64e 1 650 655 659
65d 660 665 66a 66d 671 672 677
678 67d 67f 683 686 68a 68e 692
696 69a 69e 6a2 6a6 6aa 6ae 6af
6b3 6b7 6b8 6bc 6c0 6c4 6c8 6cc
6d0 6d4 6d8 6dc 6e0 6e4 6e8 6ec
6f0 6f4 6f8 6fc 700 704 708 70c
710 714 718 71c 720 724 728 72c
730 734 738 73c 740 744 748 74c
750 754 758 75c 760 764 768 76c
770 774 778 77c 780 784 788 78c
790 794 798 79c 7a0 7a4 7a8 7ac
7b0 7b4 7b8 7bc 7c0 7c4 7c8 7cc
7d0 7d4 7e0 7e4 7e8 7eb 7ef 7f3
7f5 1 7f9 7fd 801 804 808 80c
810 814 817 81b 81f 822 825 82a
82d 830 833 834 839 83a 1 83c
841 845 849 84c 851 856 859 85d
85e 863 866 86b 86c 871 874 879
87a 87f 882 886 887 88c 88f 894
895 89a 89d 8a1 8a5 8a8 8ab 8ac
8ae 8af 8b4 8b5 8ba 8bc 8c0 8c3
8c5 8c9 8cb 8d7 8d9 8db 8dc 8e1
8e5 8e7 8f3 8f5 8f9 8fd 900 904
907 90b 90e 90f 914 917 91b 91f
922 926 92a 92d 930 935 938 93b
93e 93f 944 945 1 947 94c 950
954 957 95c 961 964 968 969 96e
971 976 977 97c 97f 984 985 98a
98d 991 995 999 99d 9a0 9a1 9a3
9a8 9a9 9ab 9ac 9b1 9b4 9b9 9ba
9bf 9c2 9c7 9c8 9cd 9d0 9d4 9d5
9da 9dd 9e2 9e3 9e8 9e9 9ee 9f0
9f4 9f7 9fb 9ff a02 a06 a0a a0d
a10 a15 a18 a1b a1e a1f a24 a25
1 a27 a2c a30 a34 a37 a3c a41
a44 a48 a49 a4e a4f a54 a56 a5a
a5d a61 a65 a68 a6c a70 a73 a77
a7b a7c a81 a83 a87 a8a a8e a92
a96 a9a a9e aa2 aa6 aaa aae ab2
ab6 aba abe ac2 ac6 aca ace ad2
ad6 ada ade ae2 ae6 aea aee af2
af6 afa afb afd b01 b05 b09 b0c
b0d b0f b12 b15 b16 b1b b1f b23
b26 b2a b2e b31 b34 b39 b3c b3f
b42 b43 b48 b49 1 b4b b50 b54
b58 b5b b60 b65 b68 b6c b6d b72
b75 b7a b7b b80 b83 b88 b89 b8e
b91 b95 b99 b9d b9e ba0 ba5 ba6
ba8 ba9 bae bb1 bb6 bb7 bbc bbf
bc4 bc5 bca bcd bd1 bd2 bd7 bda
bdf be0 be5 be6 beb bed bf1 bf4
bf8 bfc bff c03 c07 c0a c0d c12
c15 c18 c1b c1c c21 c22 1 c24
c29 c2d c31 c34 c39 c3e c41 c45
c46 c4b c4c c51 c53 c57 c5a c5e
c62 c65 c69 c6d c70 c71 c73 c77
c7b c7c c81 c83 c87 c8a c8e c92
c96 c99 c9a c9c c9f ca2 ca3 ca8
cac cb0 cb4 cb8 cbc cc8 ccc cd0
cd3 cd7 cdb cdd 1 ce1 ce5 ce9
cec cf0 cf4 cf8 cfc cff d03 d07
d0a d0d d12 d15 d18 d1b d1c d21
d22 1 d24 d29 d2d d31 d34 d39
d3e d41 d45 d46 d4b d4e d53 d54
d59 d5c d61 d62 d67 d6a d6e d6f
d74 d77 d7c d7d d82 d85 d89 d8d
d90 d93 d94 d96 d97 d9c d9d da2
da4 da8 dab dad db1 db3 dbf dc1
dc3 dc4 dc9 dcd dcf ddb ddd de1
de5 de8 de9 deb def df2 df6 df9
dfa dfc dfd e02 e06 e0a e0e e12
e16 e22 e26 e2b e2f e32 e33 e38
e3c e40 e43 e46 e4a e4c e50 e54
e57 e5a e5e e60 e64 e68 e6b e6d
1 e71 e75 e79 e7c e80 e84 e88
e8c e8f e93 e97 e9a e9d ea2 ea5
ea8 eab eac eb1 eb2 1 eb4 eb9
ebd ec1 ec4 ec9 ece ed1 ed5 ed6
edb ede ee3 ee4 ee9 eec ef1 ef2
ef7 efa efe eff f04 f07 f0c f0d
f12 f15 f19 f1d f20 f23 f24 f26
f27 f2c f2d f32 f34 f38 f3b f3d
f41 f43 f4f f51 f53 f54 f59 f5d
f5f f6b f6d f6f f73 f76 f78 f7c
f7f f83 f87 f8b f8c f8e f92 f94
f98 f9c f9f fa3 fa7 faa fae fb2
fb5 fb8 fbd fc0 fc3 fc6 fc7 fcc
fcd 1 fcf fd4 fd8 fdc fdf fe4
fe9 fec ff0 ff1 ff6 ff9 ffe fff
1004 1007 100c 100d 1012 1015 1019 101d
1021 1025 1028 1029 102b 1030 1031 1033
1034 1039 103c 1041 1042 1047 104a 104f
1050 1055 1058 105c 105d 1062 1065 106a
106b 1070 1071 1076 1078 107c 107f 1083
1087 108a 108e 1092 1095 1099 109d 109e
10a3 10a5 10a9 10ad 10b0 10b4 10b8 10bb
10bf 10c3 10c6 10c9 10ce 10d1 10d4 10d7
10d8 10dd 10de 1 10e0 10e5 10e9 10ed
10f0 10f5 10fa 10fd 1101 1102 1107 1108
110d 1111 1115 1118 111d 1122 1125 1129
112d 1130 1131 1136 1139 113e 113f 1144
1147 114b 114f 1152 1153 1158 1159 115e
1160 1164 1167 116b 116f 1173 1177 117b
117f 1183 1187 118b 1197 119c 11a0 11a4
11a8 11ac 11ae 11af 11b4 1 11b8 11bc
11c0 11c3 11c7 11cb 11cf 11d3 11d6 11da
11de 11e1 11e4 11e9 11ec 11ef 11f2 11f3
11f8 11f9 1 11fb 1200 1204 1208 120b
1210 1215 1218 121c 121d 1222 1223 1228
122c 1230 1233 1238 123d 1240 1244 1245
124a 124d 1252 1253 1258 125b 125f 1263
1266 1269 126a 126c 126d 1272 1273 1278
127a 127e 1281 1285 1289 128d 1291 1295
1299 129d 12a9 12ae 12b2 12b6 12ba 12be
12c0 12c4 12c6 12d2 12d4 12d6 12d7 12dc
12e0 12e2 12ee 12f2 12f4 12f5 12fe 
517
2
0 1 a 6 c :3 6 11 :3 6
12 :2 6 1 3 a 13 a :2 1
4 18 21 20 :2 18 :2 4 18 21
20 :2 18 :2 4 f 18 17 :2 f :2 4
11 1a 19 :2 11 :2 4 e 17 16
:2 e :2 4 d 16 15 :2 d :2 4 f
18 17 :2 f :2 4 :3 12 :2 4 :3 13 :2 4
:3 11 :2 4 :3 12 :2 4 :3 f :2 4 :3 15 :2 4
:3 e :2 4 f 18 17 :2 f :2 4 :2 d
1c d :2 4 :2 e 1d e :2 4 :2 e
1d e :2 4 :2 10 1f 10 :2 4 :2 c
1b c :2 4 :3 10 :2 4 :3 10 :2 4 12
1b 1a :2 12 :2 4 :2 d 1c d :2 4
:2 12 21 12 :2 4 :2 e 1d e :2 4
:2 a 19 a :2 4 :2 11 20 11 :2 4
:2 f 1e f :2 4 :2 14 23 14 :2 4
:2 f 19 f :2 4 :2 f 19 f :2 4
:3 9 :2 4 :3 9 :2 4 :2 f 1e f :2 4
:2 16 25 16 :2 4 :2 11 20 11 :2 4
:2 13 22 13 :2 4 :3 19 :2 4 :2 12 21
12 :2 4 :2 d 1c d :2 4 :2 14 23
14 :2 4 e 17 :3 e 4 7 :2 11
23 :2 2d 3a :2 23 :3 7 :2 d 19 25
:2 2f 43 :2 25 5a 60 63 :2 5a 71
8d 8 :2 71 d 10 :2 71 16 19
:2 71 b e :2 71 13 16 1f 27
:2 1f 34 :2 16 :2 71 b e :2 71 13
16 :2 71 1b 1e :2 71 2a 2d :2 71
32 35 :2 71 :2 7 50 :2 4 7 :2 11
23 :2 2d 39 3c 52 54 55 :2 52
:2 23 :3 7 :2 d 12 1e 63 66 :2 1e
:2 7 58 :3 4 11 :2 4 1b :2 4 12
:2 4 14 :2 4 15 4 :4 7 12 :2 7
11 23 46 7 12 21 :3 7 11
31 4c 64 6d 7c 8d 96 a6
:22 7 c d 21 e 19 c 17
26 36 a 28 fffa 7 :2 10 1c
7 4 :2 c a :2 13 1f a d
:2 17 29 :2 33 3f 43 59 5c 5d
:2 59 :2 29 :3 d :2 13 18 24 6a 6d
:2 24 7a 7d :2 24 81 84 :2 24 90
93 :2 24 9b 9e :2 24 aa ad b4
bd c0 :2 ad :2 24 :2 d 60 :2 a :2 7
:4 13 :2 7 4 :3 1 8 :2 11 1c 1a
:2 25 :2 1a 7 a :2 14 26 :2 30 3c
40 56 59 5a :2 56 :2 26 :3 a :2 10
15 21 67 6a :2 21 77 7a :2 21
7e 81 :2 21 8b 8e 97 9f :2 a8
:2 97 bb :2 8e :2 21 c3 c6 :2 21 ce
d1 :2 21 d6 d9 :2 21 ed f0 :2 21
:2 a 5d :2 7 a :2 14 26 :2 30 3c
3f 55 58 59 :2 55 :2 26 :3 a :2 10
15 21 67 6a :2 21 :2 a 5c :3 7
:2 12 26 :2 2f 41 f :2 7 35 :3 4
17 26 34 3f 54 25 33 41
50 5a 25 2c 37 49 54 25
35 41 54 25 31 3d 4d 57
25 34 3f :2 17 4 7 10 21
:2 7 24 26 :2 24 a :2 14 26 :2 30
3c 40 56 59 5a :2 56 :2 26 :3 a
:2 10 15 21 67 6a :2 21 77 7a
:2 21 7e 81 :2 21 8b 8e 97 9f
:2 97 b1 :2 8e :2 21 b9 bc :2 21 c4
c7 :2 21 cc cf :2 21 e3 e6 :2 21
:2 a 5d :2 7 a :2 14 26 :2 30 3c
3f 55 58 59 :2 55 :2 26 :3 a :2 10
15 21 67 6a :2 21 :2 a 5c :3 7
:2 12 26 2f 40 :2 26 44 f :2 7
2d 7 12 7 a 13 1e :2 a
21 24 :2 21 14 1d 12 13 27
:2 d :2 16 22 d a :2 12 10 :2 19
25 10 13 :2 1d 2f :2 39 45 49
5f 62 63 :2 5f :2 2f :3 13 :2 19 1e
2a 70 73 :2 2a 80 83 :2 2a 87
8a :2 2a 96 99 :2 2a a1 a4 :2 2a
b0 b3 ba c3 c6 :2 b3 :2 2a :2 13
66 :2 10 :2 d :4 19 :2 d a :3 26 d
16 1d :2 d 22 20 2b 34 :2 22
:2 20 17 14 1b 16 2a 10 17
13 1f :3 1d 13 :2 1c 28 13 24
13 :2 1c 28 13 :4 10 d :2 15 13
:2 1c 28 13 16 :2 20 32 :2 3c 48
4c 62 65 66 :2 62 :2 32 :3 16 :2 1c
21 2d 73 76 :2 2d 83 86 :2 2d
8a 8d :2 2d 99 9c :2 2d a4 a7
:2 2d b3 b6 bd c6 c9 :2 b6 :2 2d
:2 16 69 :2 13 :2 10 :4 1c :2 10 d :4 37
:2 a 26 :3 7 1a 24 :2 1a 7 :4 4
7 :2 11 23 :2 2d 39 3c 52 55
56 :2 52 :2 23 :3 7 :2 d 12 1e 64
67 :2 1e 74 77 :2 1e 7b 7e :2 1e
88 8b 94 9c :2 a5 :2 94 b0 :2 8b
:2 1e b8 bb :2 1e c3 c6 :2 1e cb
ce :2 1e d4 d7 :2 1e :2 7 59 :3 4
:2 f 21 :2 2a 34 3b :2 4 1 9
12 9 a :2 14 26 :2 30 3c 40
56 59 5a :2 56 :2 26 :3 a :2 10 15
21 67 6a :2 21 :3 a :2 10 15 39
5c 5f :2 68 :2 39 76 79 :2 39 81
84 :2 8d :2 39 :2 a 5d :3 7 c 15
1e 2c a 13 1e f e 7
e 7 e 7 29 :2 4 :2 9 7
:2 10 1c :2 7 :2 11 23 :2 2d 39 3d
53 56 57 :2 53 :2 23 :3 7 :2 d 12
1e 64 67 :2 1e :3 7 :2 d 12 36
42 45 :2 36 4d 50 :2 36 5c 5f
66 6f 72 :2 5f :2 36 :2 7 5a :2 4
7 c 1b a 13 1e f e
7 e 7 e 7 :2 4 :4 10 :2 4
:8 1 
517
4
0 :2 1 :4 3 :4 4
:4 5 2 :4 6 :2 1
:7 8 :7 9 :7 a :7 b
:7 c :7 d :7 e :5 f
:5 10 :5 11 :5 12 :5 13
:5 14 :5 15 :7 16 :6 17
:6 18 :6 19 :6 1a :6 1b
:5 1c :5 1d :7 1e :6 1f
:6 20 :6 21 :6 22 :6 23
:6 24 :6 25 :6 26 :6 27
:5 28 :5 29 :6 2a :6 2b
:6 2c :6 2d :5 2e :6 2f
:6 30 :6 31 :7 33 :b 35
:11 36 37 :2 36 :2 37
:2 36 :2 37 :2 36 :2 38
:2 36 :9 38 :2 36 :2 39
:2 36 :2 39 :2 36 :2 39
:2 36 :2 39 :2 36 :2 39
:4 36 :3 35 :11 3c :b 3d
:3 3c :3 44 :3 45 :3 46
:3 4a :3 4c 51 52
53 :2 54 55 56
:3 57 :3 58 59 5a
5b :9 5c 5d 5e
5f 60 61 62
63 64 65 66
67 69 6a 6b
6c 6d 6e 6f
70 71 72 73
74 75 76 77
78 79 7a 7b
7c 7d 7e 7f
80 :2 81 :2 82 :4 83
:2 84 51 :5 85 4f
:2 87 :5 89 :11 8a :24 8b
:3 8a :2 88 :6 87 86
:3 34 :a 90 :11 91 :30 92
:3 91 :11 94 :b 95 :3 94
:7 97 98 :2 97 :3 90
:6 9b :5 9c :5 9d :4 9e
:5 9f :3 a0 :3 9b :9 a4
:11 a7 :2e a8 :3 a7 :11 aa
:b ab :3 aa :9 ad ae
:2 ad a4 :3 b0 :9 b3
:2 b5 b6 :2 b7 b5
:5 b8 b4 :2 ba :5 bc
:11 bd :24 be :3 bd :2 bb
:6 ba b9 :3 b3 :d c3
c5 :2 c6 :2 c7 c5
:6 c8 :5 c9 c8 :5 cb
ca :3 c8 c4 :2 ce
:5 d0 :11 d1 :24 d2 :3 d1
:2 cf :6 ce cd :6 c3
:3 b3 :6 d9 af :3 a4
:11 dc :30 dd :3 dc :a df
34 :3 e2 :11 e3 :b e4
:17 e5 :3 e3 :2 e7 :3 e8
:3 e9 ea e8 e7
e8 :3 eb :3 e2 :2 ec
:5 ee :11 ef :b f0 :18 f1
:3 ef :2 f3 f4 :3 f5
f6 f4 f3 f4
:3 f7 :2 ed :6 ec e1
:7 1 
1300
4
:3 0 1 :3 0 2
:a 0 512 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
:2 0 7 6 :3 0
5 :7 0 9 8
:3 0 4 :3 0 7
:7 0 d c :3 0
8 :3 0 9 :3 0
a :2 0 4 11
12 0 f 13
0 512 2 14
:2 0 c :2 0 f
4 :3 0 c :2 0
d 17 19 :6 0
1c 1a 0 510
0 b :6 0 c
:2 0 13 4 :3 0
11 1e 20 :6 0
23 21 0 510
0 d :6 0 c
:2 0 17 4 :3 0
15 25 27 :6 0
2a 28 0 510
0 e :6 0 c
:2 0 1b 4 :3 0
19 2c 2e :6 0
31 2f 0 510
0 f :6 0 c
:2 0 1f 4 :3 0
1d 33 35 :6 0
38 36 0 510
0 10 :6 0 13
:2 0 23 4 :3 0
21 3a 3c :6 0
3f 3d 0 510
0 11 :6 0 29
13b 0 27 4
:3 0 25 41 43
:6 0 46 44 0
510 0 12 :6 0
2d 16f 0 2b
15 :3 0 48 :7 0
4b 49 0 510
0 14 :6 0 15
:3 0 4d :7 0 50
4e 0 510 0
16 :6 0 31 1a3
0 2f 15 :3 0
52 :7 0 55 53
0 510 0 17
:6 0 15 :3 0 57
:7 0 5a 58 0
510 0 18 :6 0
35 1d7 0 33
1a :3 0 5c :7 0
5f 5d 0 510
0 19 :6 0 1a
:3 0 61 :7 0 64
62 0 510 0
1b :6 0 1f :2 0
39 1a :3 0 66
:7 0 69 67 0
510 0 1c :6 0
4 :3 0 13 :2 0
37 6b 6d :6 0
70 6e 0 510
0 1d :6 0 1f
:2 0 3b 6 :3 0
72 :7 0 76 73
74 510 0 1e
:6 0 1f :2 0 3d
6 :3 0 78 :7 0
7c 79 7a 510
0 20 :6 0 1f
:2 0 3f 6 :3 0
7e :7 0 82 7f
80 510 0 21
:6 0 1f :2 0 41
6 :3 0 84 :7 0
88 85 86 510
0 22 :6 0 45
29b 0 43 6
:3 0 8a :7 0 8e
8b 8c 510 0
23 :6 0 27 :2 0
47 15 :3 0 90
:7 0 93 91 0
510 0 24 :6 0
1a :3 0 95 :7 0
98 96 0 510
0 25 :6 0 1f
:2 0 4b 4 :3 0
49 9a 9c :6 0
9f 9d 0 510
0 26 :6 0 1f
:2 0 4d 6 :3 0
a1 :7 0 a5 a2
a3 510 0 28
:6 0 1f :2 0 4f
6 :3 0 a7 :7 0
ab a8 a9 510
0 29 :6 0 1f
:2 0 51 6 :3 0
ad :7 0 b1 ae
af 510 0 2a
:6 0 1f :2 0 53
6 :3 0 b3 :7 0
b7 b4 b5 510
0 2b :6 0 1f
:2 0 55 6 :3 0
b9 :7 0 bd ba
bb 510 0 2c
:6 0 1f :2 0 57
6 :3 0 bf :7 0
c3 c0 c1 510
0 2d :6 0 31
:2 0 59 6 :3 0
c5 :7 0 c9 c6
c7 510 0 2e
:6 0 31 :2 0 5b
30 :3 0 cb :7 0
cf cc cd 510
0 2f :6 0 5f
3e8 0 5d 30
:3 0 d1 :7 0 d5
d2 d3 510 0
32 :6 0 1f :2 0
61 1a :3 0 d7
:7 0 da d8 0
510 0 33 :6 0
1a :3 0 dc :7 0
df dd 0 510
0 34 :6 0 1f
:2 0 63 6 :3 0
e1 :7 0 e5 e2
e3 510 0 35
:6 0 1f :2 0 65
6 :3 0 e7 :7 0
eb e8 e9 510
0 36 :6 0 1f
:2 0 67 6 :3 0
ed :7 0 f1 ee
ef 510 0 37
:6 0 6b 48c 0
69 6 :3 0 f3
:7 0 f7 f4 f5
510 0 38 :6 0
1f :2 0 6d 1a
:3 0 f9 :7 0 fc
fa 0 510 0
39 :6 0 6 :3 0
fe :7 0 1f :2 0
102 ff 100 510
0 3a :6 0 1f
:2 0 6f 6 :3 0
104 :7 0 108 105
106 510 0 3b
:6 0 110 111 0
71 6 :3 0 10a
:7 0 10e 10b 10c
510 0 3c :6 0
116 117 0 73
9 :3 0 a :2 0
4 112 :7 0 115
113 0 510 0
3d :6 0 3e :3 0
3f :3 0 3e :3 0
40 :3 0 119 11a
0 2 :4 0 75
11b 11d 118 11f
11e :2 0 41 :3 0
42 :3 0 121 122
0 43 :4 0 3e
:3 0 44 :3 0 125
126 0 2 :4 0
77 127 129 45
:4 0 46 :2 0 47
:3 0 79 12c 12e
:3 0 48 :4 0 46
:2 0 49 :4 0 7c
131 133 :3 0 46
:2 0 3 :3 0 7f
135 137 :3 0 46
:2 0 49 :4 0 82
139 13b :3 0 46
:2 0 4a :4 0 85
13d 13f :3 0 46
:2 0 4b :3 0 4c
:3 0 5 :3 0 88
143 145 4d :4 0
8a 142 148 8d
141 14a :3 0 46
:2 0 4a :4 0 90
14c 14e :3 0 46
:2 0 49 :4 0 93
150 152 :3 0 46
:2 0 7 :3 0 96
154 156 :3 0 46
:2 0 49 :4 0 99
158 15a :3 0 46
:2 0 4e :4 0 9c
15c 15e :3 0 9f
123 160 :2 0 162
a4 163 120 162
0 164 a6 0
470 3e :3 0 3f
:3 0 165 166 0
3e :3 0 4f :3 0
168 169 0 13
:2 0 2 :4 0 50
:2 0 51 :2 0 13
:2 0 a8 16e 170
:3 0 ab 16a 172
167 174 173 :2 0
41 :3 0 52 :3 0
176 177 0 43
:4 0 53 :4 0 46
:2 0 47 :3 0 af
17b 17d :3 0 b2
178 17f :2 0 181
b5 182 175 181
0 183 b7 0
470 21 :3 0 5
:3 0 184 185 0
470 b :3 0 3
:3 0 187 188 0
470 e :3 0 7
:3 0 18a 18b 0
470 17 :4 0 18d
18e 0 470 18
:4 0 190 191 0
470 54 :3 0 55
:3 0 56 :3 0 57
:3 0 58 :3 0 59
:3 0 5a :3 0 21
:3 0 59 :3 0 5b
:3 0 57 :3 0 58
:3 0 5c :3 0 5b
:3 0 5d :3 0 5e
:3 0 5a :3 0 59
:3 0 5a :3 0 4b
:3 0 5f :3 0 60
:3 0 4b :3 0 61
:3 0 62 :3 0 63
:3 0 64 :3 0 65
:3 0 66 :3 0 67
:3 0 68 :3 0 69
:3 0 6a :3 0 6b
:3 0 6c :3 0 5c
:3 0 f :3 0 10
:3 0 d :3 0 2c
:3 0 17 :3 0 18
:3 0 1e :3 0 22
:3 0 2b :3 0 20
:3 0 1b :3 0 2a
:3 0 14 :3 0 16
:3 0 35 :3 0 36
:3 0 2f :3 0 32
:3 0 1d :3 0 38
:3 0 11 :3 0 12
:3 0 3a :3 0 6d
:3 0 6e :3 0 b
:3 0 57 :3 0 58
:3 0 57 :3 0 58
:3 0 5c :3 0 5b
:3 0 59 :3 0 5a
:4 0 6f 1 :8 0
1df 9 :3 0 70
:3 0 1da 1db 0
71 :3 0 1dc 1dd
0 1df b9 229
72 :3 0 9 :3 0
70 :3 0 1e2 1e3
0 71 :3 0 1e4
1e5 0 21f 3e
:3 0 3f :3 0 1e7
1e8 0 3e :3 0
4f :3 0 1ea 1eb
0 73 :2 0 2
:4 0 74 :2 0 51
:2 0 13 :2 0 bc
1f0 1f2 :3 0 bf
1ec 1f4 1e9 1f6
1f5 :2 0 41 :3 0
52 :3 0 1f8 1f9
0 43 :4 0 75
:4 0 46 :2 0 47
:3 0 c3 1fd 1ff
:3 0 46 :2 0 76
:4 0 c6 201 203
:3 0 46 :2 0 77
:4 0 c9 205 207
:3 0 46 :2 0 71
:3 0 cc 209 20b
:3 0 46 :2 0 78
:4 0 cf 20d 20f
:3 0 46 :2 0 79
:3 0 7a :3 0 13
:2 0 7b :2 0 d2
212 216 d6 211
218 :3 0 d9 1fa
21a :2 0 21c dc
21d 1f7 21c 0
21e de 0 21f
e0 222 :3 0 222
0 222 221 21f
220 :6 0 224 2
:3 0 e3 226 e5
225 224 :2 0 227
e7 :2 0 229 0
229 228 1df 227
:6 0 470 1 :3 0
9 :3 0 70 :3 0
22b 22c 0 9
:3 0 7c :2 0 7d
:3 0 22e 230 0
eb 22f 232 :3 0
233 :2 0 3e :3 0
3f :3 0 235 236
0 3e :3 0 4f
:3 0 238 239 0
c :2 0 2 :4 0
7e :2 0 51 :2 0
13 :2 0 ee 23e
240 :3 0 f1 23a
242 237 244 243
:2 0 41 :3 0 52
:3 0 246 247 0
43 :4 0 7f :4 0
46 :2 0 47 :3 0
f5 24b 24d :3 0
46 :2 0 76 :4 0
f8 24f 251 :3 0
46 :2 0 80 :4 0
fb 253 255 :3 0
46 :2 0 4b :3 0
4c :3 0 81 :3 0
82 :3 0 25a 25b
0 fe 259 25d
4d :4 0 100 258
260 103 257 262
:3 0 46 :2 0 83
:4 0 106 264 266
:3 0 46 :2 0 49
:4 0 109 268 26a
:3 0 46 :2 0 b
:3 0 10c 26c 26e
:3 0 46 :2 0 49
:4 0 10f 270 272
:3 0 112 248 274
:2 0 276 115 277
245 276 0 278
117 0 2a2 3e
:3 0 3f :3 0 279
27a 0 3e :3 0
4f :3 0 27c 27d
0 13 :2 0 2
:4 0 84 :2 0 51
:2 0 13 :2 0 119
282 284 :3 0 11c
27e 286 27b 288
287 :2 0 41 :3 0
52 :3 0 28a 28b
0 43 :4 0 85
:4 0 46 :2 0 47
:3 0 120 28f 291
:3 0 123 28c 293
:2 0 295 126 296
289 295 0 297
128 0 2a2 86
:3 0 87 :3 0 298
299 0 81 :3 0
82 :3 0 29b 29c
0 b :3 0 88
:3 0 12a 29a 2a0
:2 0 2a2 12e 2a3
234 2a2 0 2a4
132 0 470 2e
:3 0 89 :3 0 f
:3 0 10 :3 0 b
:3 0 d :3 0 2c
:3 0 17 :3 0 18
:3 0 1e :3 0 22
:3 0 2b :3 0 20
:3 0 1b :3 0 2a
:3 0 14 :3 0 16
:3 0 35 :3 0 36
:3 0 2f :3 0 32
:3 0 1d :3 0 38
:3 0 11 :3 0 12
:3 0 3a :3 0 21
:3 0 e :3 0 134
2a6 2c1 2a5 2c2
0 470 4b :3 0
2e :3 0 1f :2 0
14f 2c4 2c7 8a
:2 0 8b :2 0 154
2c9 2cb :3 0 3e
:3 0 3f :3 0 2cd
2ce 0 3e :3 0
4f :3 0 2d0 2d1
0 c :2 0 2
:4 0 8c :2 0 51
:2 0 13 :2 0 157
2d6 2d8 :3 0 15a
2d2 2da 2cf 2dc
2db :2 0 41 :3 0
52 :3 0 2de 2df
0 43 :4 0 8d
:4 0 46 :2 0 47
:3 0 15e 2e3 2e5
:3 0 46 :2 0 76
:4 0 161 2e7 2e9
:3 0 46 :2 0 80
:4 0 164 2eb 2ed
:3 0 46 :2 0 4b
:3 0 4c :3 0 2e
:3 0 167 2f1 2f3
4d :4 0 169 2f0
2f6 16c 2ef 2f8
:3 0 46 :2 0 83
:4 0 16f 2fa 2fc
:3 0 46 :2 0 49
:4 0 172 2fe 300
:3 0 46 :2 0 b
:3 0 175 302 304
:3 0 46 :2 0 49
:4 0 178 306 308
:3 0 17b 2e0 30a
:2 0 30c 17e 30d
2dd 30c 0 30e
180 0 33a 3e
:3 0 3f :3 0 30f
310 0 3e :3 0
4f :3 0 312 313
0 13 :2 0 2
:4 0 8e :2 0 51
:2 0 13 :2 0 182
318 31a :3 0 185
314 31c 311 31e
31d :2 0 41 :3 0
52 :3 0 320 321
0 43 :4 0 8f
:4 0 46 :2 0 47
:3 0 189 325 327
:3 0 18c 322 329
:2 0 32b 18f 32c
31f 32b 0 32d
191 0 33a 86
:3 0 87 :3 0 32e
32f 0 4b :3 0
2e :3 0 1f :2 0
193 331 334 b
:3 0 88 :3 0 196
330 338 :2 0 33a
19a 41f 23 :3 0
1f :2 0 33b 33c
0 41e 4b :3 0
2a :3 0 1f :2 0
19e 33e 341 90
:2 0 13 :2 0 1a3
343 345 :3 0 5b
:3 0 23 :3 0 6d
:3 0 6e :3 0 b
:4 0 91 1 :8 0
352 9 :3 0 70
:3 0 34d 34e 0
71 :3 0 34f 350
0 352 1a6 39c
72 :3 0 9 :3 0
70 :3 0 355 356
0 71 :3 0 357
358 0 392 3e
:3 0 3f :3 0 35a
35b 0 3e :3 0
4f :3 0 35d 35e
0 73 :2 0 2
:4 0 92 :2 0 51
:2 0 13 :2 0 1a9
363 365 :3 0 1ac
35f 367 35c 369
368 :2 0 41 :3 0
52 :3 0 36b 36c
0 43 :4 0 93
:4 0 46 :2 0 47
:3 0 1b0 370 372
:3 0 46 :2 0 76
:4 0 1b3 374 376
:3 0 46 :2 0 77
:4 0 1b6 378 37a
:3 0 46 :2 0 71
:3 0 1b9 37c 37e
:3 0 46 :2 0 78
:4 0 1bc 380 382
:3 0 46 :2 0 79
:3 0 7a :3 0 13
:2 0 7b :2 0 1bf
385 389 1c3 384
38b :3 0 1c6 36d
38d :2 0 38f 1c9
390 36a 38f 0
391 1cb 0 392
1cd 395 :3 0 395
0 395 394 392
393 :6 0 397 4
:3 0 1d0 399 1d2
398 397 :2 0 39a
1d4 :2 0 39c 0
39c 39b 352 39a
:6 0 415 1 :3 0
4b :3 0 2b :3 0
1f :2 0 1d6 39e
3a1 4b :3 0 8a
:2 0 23 :3 0 1f
:2 0 1d9 3a3 3a7
1de 3a4 3a9 :3 0
6d :3 0 5b :3 0
2b :3 0 6e :3 0
b :4 0 94 1
:8 0 3c6 95 :4 0
3b1 :3 0 88 :3 0
7c :2 0 1e3 3b4
3b5 :3 0 9 :3 0
70 :3 0 3b7 3b8
0 1f :2 0 3b9
3ba 0 3bc 1e6
3c3 9 :3 0 70
:3 0 3bd 3be 0
96 :2 0 3bf 3c0
0 3c2 1e8 3c4
3b6 3bc 0 3c5
0 3c2 0 3c5
1ea 0 3c6 1ed
410 72 :3 0 9
:3 0 70 :3 0 3c9
3ca 0 71 :3 0
3cb 3cc 0 406
3e :3 0 3f :3 0
3ce 3cf 0 3e
:3 0 4f :3 0 3d1
3d2 0 73 :2 0
2 :4 0 97 :2 0
51 :2 0 13 :2 0
1f0 3d7 3d9 :3 0
1f3 3d3 3db 3d0
3dd 3dc :2 0 41
:3 0 52 :3 0 3df
3e0 0 43 :4 0
98 :4 0 46 :2 0
47 :3 0 1f7 3e4
3e6 :3 0 46 :2 0
76 :4 0 1fa 3e8
3ea :3 0 46 :2 0
77 :4 0 1fd 3ec
3ee :3 0 46 :2 0
71 :3 0 200 3f0
3f2 :3 0 46 :2 0
78 :4 0 203 3f4
3f6 :3 0 46 :2 0
79 :3 0 7a :3 0
13 :2 0 7b :2 0
206 3f9 3fd 20a
3f8 3ff :3 0 20d
3e1 401 :2 0 403
210 404 3de 403
0 405 212 0
406 214 409 :3 0
409 0 409 408
406 407 :6 0 40b
6 :3 0 217 40d
219 40c 40b :2 0
40e 21b :2 0 410
0 410 40f 3c6
40e :6 0 412 1
:3 0 21d 413 3aa
412 0 414 21f
0 415 221 416
346 415 0 417
224 0 41e 2e
:3 0 99 :3 0 f
:3 0 226 419 41b
418 41c 0 41e
228 420 2cc 33a
0 421 0 41e
0 421 22c 0
470 3e :3 0 3f
:3 0 422 423 0
3e :3 0 4f :3 0
425 426 0 9a
:2 0 2 :4 0 9b
:2 0 51 :2 0 13
:2 0 22f 42b 42d
:3 0 232 427 42f
424 431 430 :2 0
41 :3 0 52 :3 0
433 434 0 43
:4 0 9c :4 0 46
:2 0 47 :3 0 236
438 43a :3 0 46
:2 0 76 :4 0 239
43c 43e :3 0 46
:2 0 80 :4 0 23c
440 442 :3 0 46
:2 0 4b :3 0 4c
:3 0 9 :3 0 70
:3 0 447 448 0
23f 446 44a 4d
:4 0 241 445 44d
244 444 44f :3 0
46 :2 0 83 :4 0
247 451 453 :3 0
46 :2 0 49 :4 0
24a 455 457 :3 0
46 :2 0 3 :3 0
24d 459 45b :3 0
46 :2 0 49 :4 0
250 45d 45f :3 0
253 435 461 :2 0
463 256 464 432
463 0 465 258
0 470 86 :3 0
9d :3 0 466 467
0 9 :3 0 70
:3 0 469 46a 0
3 :3 0 88 :3 0
25a 468 46e :2 0
470 25e 511 9
:3 0 9e :2 0 4
471 472 0 3e
:3 0 3f :3 0 474
475 0 3e :3 0
4f :3 0 477 478
0 73 :2 0 2
:4 0 9f :2 0 51
:2 0 13 :2 0 26c
47d 47f :3 0 26f
479 481 476 483
482 :2 0 41 :3 0
52 :3 0 485 486
0 43 :4 0 a0
:4 0 46 :2 0 47
:3 0 273 48a 48c
:3 0 276 487 48e
:2 0 4a7 41 :3 0
52 :3 0 490 491
0 43 :4 0 a1
:4 0 46 :2 0 9
:3 0 a2 :3 0 496
497 0 279 495
499 :3 0 46 :2 0
83 :4 0 27c 49b
49d :3 0 46 :2 0
9 :3 0 a3 :3 0
4a0 4a1 0 27f
49f 4a3 :3 0 282
492 4a5 :2 0 4a7
285 4a8 484 4a7
0 4a9 288 0
4b9 a4 :3 0 3d
:3 0 9 :3 0 a2
:3 0 a5 :3 0 9
:3 0 a3 :3 0 a6
:3 0 a7 :4 0 a8
1 :a 0 4b5 :2 0
4b9 4ab 4b3 :2 0
8 :3 0 3d :3 0
4b7 :2 0 4b9 28a
4bb 28e 4ba 4b9
:2 0 50f 72 :3 0
9 :3 0 70 :3 0
4be 4bf 0 71
:3 0 4c0 4c1 0
507 3e :3 0 3f
:3 0 4c3 4c4 0
3e :3 0 4f :3 0
4c6 4c7 0 73
:2 0 2 :4 0 a9
:2 0 51 :2 0 13
:2 0 290 4cc 4ce
:3 0 293 4c8 4d0
4c5 4d2 4d1 :2 0
41 :3 0 52 :3 0
4d4 4d5 0 43
:4 0 aa :4 0 46
:2 0 47 :3 0 297
4d9 4db :3 0 29a
4d6 4dd :2 0 4f7
41 :3 0 52 :3 0
4df 4e0 0 43
:4 0 77 :4 0 46
:2 0 71 :3 0 29d
4e4 4e6 :3 0 46
:2 0 78 :4 0 2a0
4e8 4ea :3 0 46
:2 0 79 :3 0 7a
:3 0 13 :2 0 7b
:2 0 2a3 4ed 4f1
2a7 4ec 4f3 :3 0
2aa 4e1 4f5 :2 0
4f7 2ad 4f8 4d3
4f7 0 4f9 2b0
0 507 a4 :3 0
3d :3 0 a5 :3 0
9 :3 0 a3 :3 0
a6 :3 0 a7 :4 0
ab 1 :a 0 503
:2 0 507 4fb 501
:2 0 8 :3 0 3d
:3 0 505 :2 0 507
2b2 50a :3 0 50a
0 50a 509 507
508 :6 0 50c 1
:3 0 2b7 50e 2b9
50d 50c :2 0 50f
2bb :2 0 511 2be
511 510 470 50f
:6 0 512 :2 0 2
14 511 515 :3 0
514 512 516 :8 0

2ea
4
:3 0 1 3 1
7 1 b 3
6 a e 1
18 1 16 1
1f 1 1d 1
26 1 24 1
2d 1 2b 1
34 1 32 1
3b 1 39 1
42 1 40 1
47 1 4c 1
51 1 56 1
5b 1 60 1
65 1 6c 1
6a 1 71 1
77 1 7d 1
83 1 89 1
8f 1 94 1
9b 1 99 1
a0 1 a6 1
ac 1 b2 1
b8 1 be 1
c4 1 ca 1
d0 1 d6 1
db 1 e0 1
e6 1 ec 1
f2 1 f8 1
fd 1 103 1
109 1 10f 1
11c 1 128 2
12b 12d 2 130
132 2 134 136
2 138 13a 2
13c 13e 1 144
2 146 147 2
140 149 2 14b
14d 2 14f 151
2 153 155 2
157 159 2 15b
15d 4 124 12a
12f 15f 1 161
1 163 2 16d
16f 3 16b 16c
171 2 17a 17c
2 179 17e 1
180 1 182 2
1d9 1de 2 1ef
1f1 3 1ed 1ee
1f3 2 1fc 1fe
2 200 202 2
204 206 2 208
20a 2 20c 20e
3 213 214 215
2 210 217 2
1fb 219 1 21b
1 21d 2 1e6
21e 1 222 1
1e1 1 226 1
231 2 22d 231
2 23d 23f 3
23b 23c 241 2
24a 24c 2 24e
250 2 252 254
1 25c 2 25e
25f 2 256 261
2 263 265 2
267 269 2 26b
26d 2 26f 271
2 249 273 1
275 1 277 2
281 283 3 27f
280 285 2 28e
290 2 28d 292
1 294 1 296
3 29d 29e 29f
3 278 297 2a1
1 2a3 1a 2a7
2a8 2a9 2aa 2ab
2ac 2ad 2ae 2af
2b0 2b1 2b2 2b3
2b4 2b5 2b6 2b7
2b8 2b9 2ba 2bb
2bc 2bd 2be 2bf
2c0 2 2c5 2c6
1 2ca 2 2c8
2ca 2 2d5 2d7
3 2d3 2d4 2d9
2 2e2 2e4 2
2e6 2e8 2 2ea
2ec 1 2f2 2
2f4 2f5 2 2ee
2f7 2 2f9 2fb
2 2fd 2ff 2
301 303 2 305
307 2 2e1 309
1 30b 1 30d
2 317 319 3
315 316 31b 2
324 326 2 323
328 1 32a 1
32c 2 332 333
3 335 336 337
3 30e 32d 339
2 33f 340 1
344 2 342 344
2 34c 351 2
362 364 3 360
361 366 2 36f
371 2 373 375
2 377 379 2
37b 37d 2 37f
381 3 386 387
388 2 383 38a
2 36e 38c 1
38e 1 390 2
359 391 1 395
1 354 1 399
2 39f 3a0 2
3a5 3a6 1 3a8
2 3a2 3a8 1
3b3 2 3b2 3b3
1 3bb 1 3c1
2 3c3 3c4 2
3b0 3c5 2 3d6
3d8 3 3d4 3d5
3da 2 3e3 3e5
2 3e7 3e9 2
3eb 3ed 2 3ef
3f1 2 3f3 3f5
3 3fa 3fb 3fc
2 3f7 3fe 2
3e2 400 1 402
1 404 2 3cd
405 1 409 1
3c8 1 40d 1
410 1 413 2
39c 414 1 416
1 41a 3 33d
417 41d 2 41f
420 2 42a 42c
3 428 429 42e
2 437 439 2
43b 43d 2 43f
441 1 449 2
44b 44c 2 443
44e 2 450 452
2 454 456 2
458 45a 2 45c
45e 2 436 460
1 462 1 464
3 46b 46c 46d
d 164 183 186
189 18c 18f 192
229 2a4 2c3 421
465 46f 2 47c
47e 3 47a 47b
480 2 489 48b
2 488 48d 2
494 498 2 49a
49c 2 49e 4a2
2 493 4a4 2
48f 4a6 1 4a8
3 4a9 4b4 4b8
1 473 2 4cb
4cd 3 4c9 4ca
4cf 2 4d8 4da
2 4d7 4dc 2
4e3 4e5 2 4e7
4e9 3 4ee 4ef
4f0 2 4eb 4f2
2 4e2 4f4 2
4de 4f6 1 4f8
4 4c2 4f9 502
506 1 50a 1
4bd 2 4bb 50e
2b 1b 22 29
30 37 3e 45
4a 4f 54 59
5e 63 68 6f
75 7b 81 87
8d 92 97 9e
a4 aa b0 b6
bc c2 c8 ce
d4 d9 de e4
ea f0 f6 fb
101 107 10d 114

1
4
0 
515
0
1
14
8
2f
0 1 2 1 4 1 6 1
0 0 0 0 0 0 0 0
0 0 0 0 
b 1 0
2 0 1
83 1 0
be 1 0
f2 1 0
56 1 0
16 1 0
ec 1 0
1d 1 0
b2 1 0
a0 1 0
40 1 0
d0 1 0
94 1 0
c4 1 0
109 1 0
60 1 0
71 1 0
3 1 0
47 1 0
51 1 0
e0 1 0
7d 1 0
b8 1 0
99 1 0
db 1 0
89 1 0
e6 1 0
32 1 0
f8 1 0
4c 1 0
fd 1 0
6a 1 0
8f 1 0
65 1 0
39 1 0
2b 1 0
7 1 0
d6 1 0
ca 1 0
5b 1 0
24 1 0
77 1 0
ac 1 0
a6 1 0
10f 1 0
103 1 0
0

/
SHOW ERRORS FUNCTION SP_ACPT_ETC_ASSIGN;
ALTER FUNCTION SP_ACPT_ETC_ASSIGN COMPILE DEBUG;
/****************************************************************************************
Accept ETC and/or FORECAST_START, WBS level
  Bitflag =
    1 - ETC
    2 - FORECAST DATES
    3 - ETC + FORECAST DATES
****************************************************************************************/
Prompt == FUNCTION SP_ACPT_ETC_WBS ==
CREATE OR REPLACE FUNCTION SP_ACPT_ETC_WBS wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
ec
2 :e:
1FUNCTION:
1SP_ACPT_ETC_WBS:
1ID001:
1VARCHAR2:
1BITFLAG001:
1PLS_INTEGER:
1REC_USER001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_PRJ_ASSIGNMENT_ID:
132:
1H_PROJECT_ID:
1H_RANK:
1200:
1H_REC_USER:
1H_RES_ID:
1H_RES_TYPE:
11:
1H_TA_START_DT:
1TIMESTAMP:
1H_TA_FINISH_DT:
1H_START_DATE:
1H_FINISH_DATE:
1H_START_DT:
1H_FINISH_DT:
1H_FINISH_D:
1DATE:
1H_WEEK_OF:
1H_LAST_SUBMITTED:
1H_TASK_ID:
1H_TSK_ASSIGNMENT_ID:
1H_BIT_FLAG:
1H_BITFLAG:
10:
1H_CONTOUR:
1H_EFFORT:
1H_REMAINING:
1H_TOTAL:
1H_TYPE:
1H_PASSED:
1H_CONSTR_DT:
1H_DAYOFYEAR:
1H_FINISH_TIME:
18:
1H_MINUTE:
1H_CONSTR_TYPE:
1H_ETC:
1H_TEMP_VAR:
1H_TEMP_SC_STATE:
1H_SCHED_START:
1H_SCHED_FINISH:
1H_SCHED_WORK:
1H_WORK_TODATE:
1H_MLST_PERCENT:
1H_REG_COST:
1NUMBER:
10.00:
1H_REG_SALE:
1H_SD:
1H_FD:
1H_BILLABLE:
1H_CAPITAL_EXPENSE:
1H_TPH_DELETE:
1H_NOT_EFFORT_PA:
1H_FF_FLAG:
1NULL_RETURN:
1LONG:
1ORA_TEMP_SC_STATE:
1CURSOR:
1CAWTSK:
1PROJECT_ID:
1ELEMENT_ID:
1SCHED_EFFORT:
1PLANNED_EFFORT:
1FORECAST_START:
1COALESCE:
1PLANNED_START:
1SCHED_START:
1FORECAST_FINISH:
1PLANNED_FINISH:
1SCHED_FINISH:
1TMT_WBS:
1RANK:
1TYPE_ID:
1PMO_CNST:
1SC_TASK:
1SC_TASK_TYPE1:
1SC_TASK_TYPE2:
1SC_TASK_TYPE3:
1SC_MILESTONE:
1SC_PERSONAL_TASK:
1SC_ACTIVE_ADM_TASK:
1SC_INACTIVE_ADM_TASK:
1SC_WBS_CHANGE_REQUEST_TASK:
1SC_WBS_ACTION_ITEM_TASK:
1SC_WBS_RISK_TASK:
1SC_WBS_ISSUE_TASK:
1SC_WBS_REQUIREMENT_TASK:
1SC_WBS_DEFECT_TASK:
1SC_WBS_SERVICE_REQUEST_TASK:
1WORK_TODATE:
1ETC:
1SELECT PROJECT_ID, ELEMENT_ID, SCHED_EFFORT+PLANNED_EFFORT,:n         CASE WH+
1EN FORECAST_START IS NULL THEN COALESCE(PLANNED_START, SCHED_START) ELSE FORE+
1CAST_START END,:n         CASE WHEN FORECAST_FINISH IS NULL THEN COALESCE(PLA+
1NNED_FINISH, SCHED_FINISH) ELSE FORECAST_FINISH END:n         FROM TMT_WBS WH+
1ERE RANK LIKE h_rank AND TYPE_ID IN (PMO_CNST.SC_TASK,PMO_CNST.SC_TASK_TYPE1,+
1PMO_CNST.SC_TASK_TYPE2,PMO_CNST.SC_TASK_TYPE3,PMO_CNST.SC_MILESTONE,PMO_CNST.+
1SC_PERSONAL_TASK,PMO_CNST.SC_ACTIVE_ADM_TASK,PMO_CNST.SC_INACTIVE_ADM_TASK,PM+
1O_CNST.SC_WBS_CHANGE_REQUEST_TASK,PMO_CNST.SC_WBS_ACTION_ITEM_TASK,PMO_CNST.S+
1C_WBS_RISK_TASK,PMO_CNST.SC_WBS_ISSUE_TASK,PMO_CNST.SC_WBS_REQUIREMENT_TASK,P+
1MO_CNST.SC_WBS_DEFECT_TASK,PMO_CNST.SC_WBS_SERVICE_REQUEST_TASK):n         AN+
1D (((SCHED_EFFORT+PLANNED_EFFORT) > 0 AND ((SCHED_EFFORT+PLANNED_EFFORT-WORK_+
1TODATE) <> ETC)) OR:n         (FORECAST_START IS NOT NULL OR FORECAST_FINISH +
1IS NOT NULL)) ORDER BY COALESCE(PLANNED_START, SCHED_START):
1CAWASS:
1TSK_ASSIGNMENT_ID:
1PROJECT_ASSIGNMENT_ID:
1SCHED_WORK:
1PLANNED_WORK:
1C_CONTOUR:
1LAST_SUBMITTED:
1UNRESOLVED_START:
1UNRESOLVED_FINISH:
1BILLABLE:
1CAPITAL_EXPENSE:
1REGULAR_COST:
1REGULAR_RATE:
1BIT_FLAG:
1MILESTONE_PERCENT:
1RESOURCE_ID:
1RESOURCE_TYPE:
1TASK_ASSIGNMENTS:
1TASK_ID:
1SELECT:n         TSK_ASSIGNMENT_ID,:n         PROJECT_ASSIGNMENT_ID,:n       +
1  SCHED_WORK+PLANNED_WORK,:n         FORECAST_START,:n         FORECAST_FINIS+
1H,:n         CASE WHEN h_bitflag = 2 AND FORECAST_START IS NuLL THEN 0 ELSE E+
1TC END,:n         SCHED_WORK+PLANNED_WORK - WORK_TODATE,:n         ETC,:n    +
1     C_CONTOUR,:n         LAST_SUBMITTED,:n         CASE WHEN FORECAST_FINISH+
1 IS NOT NuLL AND FORECAST_START IS NuLL AND FORECAST_FINISH BETWEEN COALESCE(+
1PLANNED_START, SCHED_START) AND COALESCE(PLANNED_FINISH, SCHED_FINISH) THEN 1+
1 ELSE 0 END,:n         UNRESOLVED_START,:n         UNRESOLVED_FINISH,:n      +
1   BILLABLE,:n         CAPITAL_EXPENSE,:n         REGULAR_COST,:n         REG+
1ULAR_RATE,:n         BIT_FLAG,:n         MILESTONE_PERCENT,:n         RESOURC+
1E_ID,:n         RESOURCE_TYPE,:n         WORK_TODATE:n         FROM TASK_ASSI+
1GNMENTS:n         WHERE PROJECT_ID = h_project_id:n         AND TASK_ID = h_t+
1ask_id:n         AND (((SCHED_WORK+PLANNED_WORK) > 0:n         AND ((SCHED_WO+
1RK + PLANNED_WORK - WORK_TODATE) <> ETC)):n         OR (FORECAST_START IS NOT+
1 NULL OR FORECAST_FINISH IS NOT NULL)):
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_ACPT_ETC_WBS(:
1':
1, :
1TO_CHAR:
1NULL:
1);:
1CHECK_TRACE:
1106:
1+:
1FPUT:
1               ENTER:: SP_ACPT_ETC_WBS(107) :: cplan.sql(18294) :: :
1RTRIM:
1SELECT RTRIM(RANK), TYPE_ID INTO h_rank, h_type:n      FROM TMT_WBS WHERE ELE+
1MENT_ID = id001/*HOST(h_id)*/:
1SC_STATE:
1SQLCODE:
1OTHERS:
116:
1123:
1           EXCEPTION:: SP_ACPT_ETC_WBS(124) :: cplan.sql(18311) :: :
1 :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1=:
1SC_SQL_SUCCESS:
1IS NOT NULL:
1%:
1-:
1OPEN:
1LOOP:
1FOUND:
1100:
1!=:
1EXIT:
12:
1FC_ACPT_DURATION:
1FC_ACPT_EFFORT:
1ELSIF:
1CANNOT_ACCEPT_FROM_PROJECT_AFF:
1CLOSE:
1228:
1           EXCEPTION:: SP_ACPT_ETC_WBS(229) :: cplan.sql(18416) :: :
1>:
1CONSTRAINT_DT:
1CONSTRAINT_TYPE:
1SELECT CONSTRAINT_DT, CONSTRAINT_TYPE, FORECAST_START, FORECAST_FINISH:n     +
1             INTO h_constr_DT, h_constr_type, h_start_DT, h_finish_DT:n      +
1            FROM TMT_WBS WHERE PROJECT_ID = h_project_id AND ELEMENT_ID = h_t+
1ask_id:
1250:
1           EXCEPTION:: SP_ACPT_ETC_WBS(251) :: cplan.sql(18438) :: :
1TO_DATE:
1UPDATE TMT_WBS SET:n                        CONSTRAINT_DT =:n                +
1        CASE:n                        WHEN h_constr_type IN (1,2,3,4) AND TO_+
1DATE(SubStr(h_constr_DT, 1, 10)) < TO_DATE(SubStr(h_finish_DT, 1, 10)) THEN h+
1_finish_DT:n                        WHEN h_constr_type IN (0,5,6,7) THEN h_fi+
1nish_DT:n                        ELSE h_constr_DT:n                        EN+
1D,:n                        CONSTRAINT_TYPE =:n                        CASE:n+
1                        WHEN h_constr_type IN (1,2,3,4) AND TO_DATE(SubStr(h_+
1constr_DT, 1, 10)) < TO_DATE(SubStr(h_finish_DT, 1, 10)) THEN 2:n            +
1            WHEN h_constr_type IN (0,5,6,7) THEN 2:n                        E+
1LSE h_constr_type:n                        END:n                        WHERE+
1 PROJECT_ID = h_project_id AND ELEMENT_ID = h_task_id:
1TRUE:
1284:
1           EXCEPTION:: SP_ACPT_ETC_WBS(285) :: cplan.sql(18472) :: :
1UPDATE TMT_WBS SET CONSTRAINT_DT = h_finish_DT, CONSTRAINT_TYPE = 2:n        +
1                WHERE PROJECT_ID = h_project_id AND ELEMENT_ID = h_task_id:
1302:
1           EXCEPTION:: SP_ACPT_ETC_WBS(303) :: cplan.sql(18490) :: :
1IS NULL:
1UPDATE TMT_WBS SET:n                        CONSTRAINT_DT =:n                +
1        CASE:n                        WHEN h_constr_type IN (0,5,6,7) AND TO_+
1DATE(SubStr(h_constr_DT, 1, 10)) > TO_DATE(SubStr(h_start_DT, 1, 10)) THEN h_+
1start_DT:n                        WHEN h_constr_type IN (1,2,3,4) THEN h_star+
1t_DT:n                        ELSE h_constr_DT:n                        END,+
1:n                        CONSTRAINT_TYPE =:n                        CASE:n  +
1                      WHEN h_constr_type IN (0,5,6,7) AND TO_DATE(SubStr(h_co+
1nstr_DT, 1, 10)) > TO_DATE(SubStr(h_start_DT, 1, 10)) THEN 6:n               +
1         WHEN h_constr_type IN (1,2,3,4) THEN 6:n                        ELSE+
1 h_constr_type:n                        END:n                        WHERE PR+
1OJECT_ID = h_project_id AND ELEMENT_ID = h_task_id:
1335:
1           EXCEPTION:: SP_ACPT_ETC_WBS(336) :: cplan.sql(18523) :: :
1UPDATE TMT_WBS SET CONSTRAINT_DT = h_start_DT, CONSTRAINT_TYPE = 6:n         +
1               WHERE PROJECT_ID = h_project_id AND ELEMENT_ID = h_task_id:
1353:
1           EXCEPTION:: SP_ACPT_ETC_WBS(354) :: cplan.sql(18541) :: :
1372:
1           EXCEPTION:: SP_ACPT_ETC_WBS(373) :: cplan.sql(18560) :: :
1NLEN:
1LENGTH:
1NOT:
1MOD:
14:
1PMODEFINES:
1PMO_RETURN_ERROR_SP:
1INVALID_RANK_LIKE:
1ROLLUP_BITS:
1PMO_STPU:
1BIT_OR:
1SC_PROPOSED_BIT:
1UPDATE TMT_WBS SET ROLLUP_BITS = PMO_STPU.BIT_OR(ROLLUP_BITS,PMO_CNST.SC_PROP+
1OSED_BIT):n            WHERE PROJECT_ID = h_project_id AND RANK LIKE h_rank:
1407:
1           EXCEPTION:: SP_ACPT_ETC_WBS(408) :: cplan.sql(18595) :: :
1FC_ROLLUP:
1424:
1       RETURN_STATUS:: SP_ACPT_ETC_WBS(425) :: cplan.sql(18612) :: :
1STATE:: :
1 ID:: :
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
1431:
1           EXCEPTION:: SP_ACPT_ETC_WBS(432) :: cplan.sql(18619) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1ERROR:
1ID:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
1443:
1           EXCEPTION:: SP_ACPT_ETC_WBS(444) :: cplan.sql(18631) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
8df
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
1c 81 b0 a3 a0 1c 81 b0
a3 a0 1c 81 b0 a3 a0 1c
81 b0 a3 a0 1c 81 b0 a3
a0 1c 81 b0 a3 a0 1c 81
b0 a3 a0 1c 81 b0 a3 a0
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 81 b0 a3
a0 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 81 b0 a3 a0
1c 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 81 b0 a3 a0
1c 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 81 b0 a3 a0
1c 51 81 b0 a0 f4 b4 bf
c8 :3b a0 12a bd b7 11 a4 b1
a0 f4 b4 bf c8 :30 a0 12a bd
b7 11 a4 b1 a3 :2 a0 6b 1c
81 b0 :2 a0 6b :2 a0 6b 6e a5
b a 10 :2 a0 6b 6e :2 a0 6b
6e a5 b 6e 7e a0 b4 2e
6e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :3 a0 a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 d
:2 a0 d a0 51 d :8 a0 12a :2 a0
6b a0 d b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 6b a0 7e a0 6b b4 2e
5a a0 7e b4 2e :2 5a a 10
:3 a0 7e 6e b4 2e :2 51 a5 b
d a0 7e 51 b4 2e d :2 a0
e9 dd b3 :7 a0 e9 d3 5 :2 a0
f :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c :2 a0 6b a0
7e a0 6b b4 2e 5a a0 2b
b7 19 3c :2 a0 51 a5 b 7e
51 b4 2e :2 a0 51 a5 b 7e
51 b4 2e :3 a0 6b d :7 a0 a5
b d :2 a0 6b a0 d :3 a0 51
a5 b 7e 51 b4 2e d b7
19 3c b7 a0 4d d a0 4d
d :2 a0 e9 dd b3 :18 a0 e9 d3
5 :2 a0 f :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c :2 a0
6b a0 7e a0 6b b4 2e 5a
a0 2b b7 19 3c :1c a0 a5 b
d :2 a0 51 a5 b 7e 51 b4
2e :3 a0 51 a5 b 7e 51 b4
2e d a0 b7 :2 a0 51 a5 b
a0 7e a0 6b b4 2e :3 a0 51
a5 b 7e 51 b4 2e d b7
:2 19 3c b7 a0 47 :2 a0 e9 c1
:2 a0 6b a0 d b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 51 a5 b 7e 51 b4
2e 5a :2 a0 51 a5 b 7e 51
b4 2e 5a a 10 a0 4d d
a0 4d d :d a0 12a :2 a0 6b a0
d b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f a0 7e
b4 2e 5a a0 7e b4 2e 5a
:1b a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 :8 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 :2 19 3c a0 b7
a0 7e b4 2e :2 5a a0 7e b4
2e :2 5a a 10 a0 7e b4 2e
5a :1b a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 :8 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 :2 19 3c b7
:2 19 3c b7 19 3c b7 :2 19 3c
b7 a0 47 :2 a0 e9 c1 :2 a0 6b
a0 d b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
51 a5 b 7e 51 b4 2e 5a
:2 a0 51 a5 b :2 7e 51 b4 2e
b4 2e 5a a 10 a3 a0 1c
51 81 b0 a0 7e b4 2e 5a
:4 a0 a5 b 51 a5 b d 51
7e 51 b4 2e a0 7e 51 b4
2e a 10 :2 a0 7e 51 b4 2e
d b7 19 3c b7 19 3c a0
7e 51 b4 2e 7e b4 2e :2 a0
7e 51 b4 2e 5a 7e 51 b4
2e 52 10 :2 a0 6b :2 a0 6b :2 a0
a5 57 b7 19 3c b7 a4 b1
11 4f :b a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :3 a0 a5 b d b7
19 3c b7 19 3c :2 a0 51 a5
b 7e 51 b4 2e :2 a0 6b :2 a0
6b d a0 b7 :2 a0 51 a5 b
7e 51 b4 2e :2 a0 6b :2 a0 51
a5 b d b7 :2 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b :2 a0
a5 57 b7 :2 a0 6b :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 :2 a0 6b :2 6e
7e :2 a0 6b b4 2e 7e 6e b4
2e 7e :2 a0 6b b4 2e a5 57
b7 19 3c :9 a0 12a e9 dd :2 a0
65 b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c :7 a0 12a e9 dd :2 a0 65 b7
a4 b1 11 4f b7 a6 9 a4
b1 11 68 4f 1d 17 b5 
8df
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 30
56 5a 5e 62 65 69 86 71
75 78 79 81 70 a3 91 6d
95 96 9e 90 c0 ae 8d b2
b3 bb ad dd cb aa cf d0
d8 ca fa e8 c7 ec ed f5
e7 117 105 e4 109 10a 112 104
133 122 126 12e 101 14b 13a 13e
146 121 167 156 15a 162 11e 17f
16e 172 17a 155 19b 18a 18e 196
152 1b3 1a2 1a6 1ae 189 1cf 1be
1c2 1ca 186 1e7 1d6 1da 1e2 1bd
203 1f2 1f6 1fe 1ba 21f 20a 20e
211 212 21a 1f1 23c 22a 1ee 22e
22f 237 229 259 247 226 24b 24c
254 246 275 264 268 243 270 263
291 280 284 260 28c 27f 2ad 29c
2a0 27c 2a8 29b 2c9 2b8 2bc 298
2c4 2b7 2e5 2d4 2d8 2b4 2e0 2d3
301 2f0 2f4 2d0 2fc 2ef 31d 30c
310 2ec 318 30b 339 328 32c 334
308 351 340 344 34c 327 36e 35c
324 360 361 369 35b 38a 379 37d
358 385 378 3a6 395 399 375 3a1
394 3c2 3b1 3b5 391 3bd 3b0 3de
3cd 3d1 3ad 3d9 3cc 3fa 3e9 3ed
3c9 3f5 3e8 416 405 409 411 3e5
42e 41d 421 429 404 44a 439 43d
401 445 438 466 455 459 435 461
454 482 471 475 451 47d 470 49e
48d 491 46d 499 48c 4ba 4a9 4ad
489 4b5 4a8 4d6 4c5 4c9 4d1 4a5
4ee 4dd 4e1 4e9 4c4 50a 4f9 4fd
4c1 505 4f8 526 515 519 4f5 521
514 542 531 535 511 53d 530 55e
54d 551 52d 559 54c 57a 569 56d
549 575 568 596 585 589 591 565
5b1 59d 5a1 5a9 5ac 584 5b8 5bc
581 5cd 5d0 5d4 5d8 5dc 5e0 5e4
5e8 5ec 5f0 5f4 5f8 5fc 600 604
608 60c 610 614 618 61c 620 624
628 62c 630 634 638 63c 640 644
648 64c 650 654 658 65c 660 664
668 66c 670 674 678 67c 680 684
688 68c 690 694 698 69c 6a0 6a4
6a8 6ac 6b0 6b4 6b8 6bc 6c0 6cc
6d1 6d3 6df 6e3 6e5 6e9 6fa 6fb
6fe 702 706 70a 70e 712 716 71a
71e 722 726 72a 72e 732 736 73a
73e 742 746 74a 74e 752 756 75a
75e 762 766 76a 76e 772 776 77a
77e 782 786 78a 78e 792 796 79a
79e 7a2 7a6 7aa 7ae 7b2 7b6 7ba
7be 7c2 7ce 7d3 7d5 7e1 7e5 803
7eb 7ef 7f3 7f6 7fe 7ea 80a 80e
7e7 812 816 81a 81d 822 823 1
825 82a 82e 832 835 83a 83e 842
845 84a 84b 84d 852 855 859 85a
85f 864 867 86c 86d 872 875 879
87a 87f 882 887 888 88d 890 895
896 89b 89e 8a2 8a6 8aa 8ab 8ad
8b2 8b3 8b5 8b6 8bb 8be 8c3 8c4
8c9 8cc 8d1 8d2 8d7 8da 8de 8df
8e4 8e7 8ec 8ed 8f2 8f5 8fa 8fb
900 901 906 908 90c 90f 913 917
91a 91e 922 925 928 92d 930 933
936 937 93c 93d 1 93f 944 948
94c 94f 954 959 95c 960 961 966
967 96c 96e 972 975 979 97d 981
985 989 98d 991 994 998 99c 9a0
9a4 9a8 9ac 9b0 9b4 9b8 9c4 9c8
9cc 9cf 9d3 9d7 9d9 1 9dd 9e1
9e5 9e8 9ec 9f0 9f4 9f8 9fb 9ff
a03 a06 a09 a0e a11 a14 a17 a18
a1d a1e 1 a20 a25 a29 a2d a30
a35 a3a a3d a41 a42 a47 a4a a4f
a50 a55 a58 a5d a5e a63 a66 a6a
a6b a70 a73 a78 a79 a7e a81 a85
a89 a8c a8f a90 a92 a93 a98 a99
a9e aa0 aa4 aa7 aa9 aad aaf abb
abd abf ac0 ac5 ac9 acb ad7 ad9
add ae1 ae4 ae8 aeb aef af2 af3
af8 afb aff b02 b03 b08 b0b 1
b0e b13 b17 b1b b1f b22 b27 b28
b2d b30 b33 b34 b36 b3a b3e b41
b44 b45 b4a b4e b52 b56 b5b b5f
b60 b64 b68 b6c b70 b74 b78 b7c
b81 b86 b8a b8e b92 b97 b9b b9f
ba2 ba5 ba9 bab baf bb3 bb6 bb9
bbd bbf bc3 bc7 bca bce bd2 bd5
bd9 bdc be0 be3 be4 be9 bec bf0
bf6 bf8 bfc bff c03 c07 c0a c0b
c0d c10 c13 c14 c19 c1d c21 c24
c25 c27 c2a c2d c2e c33 c37 c3b
c3f c42 c46 c4a c4e c52 c56 c5a
c5e c62 c63 c65 c69 c6d c71 c74
c78 c7c c80 c84 c88 c8b c8c c8e
c91 c94 c95 c9a c9e ca0 ca4 ca7
ca9 cad cae cb2 cb6 cb7 cbb cbf
cc3 cc8 ccc ccd cd1 cd5 cd9 cdd
ce1 ce5 ce9 ced cf1 cf5 cf9 cfd
d01 d05 d09 d0d d11 d15 d19 d1d
d21 d25 d29 d2d d32 d37 d3b d3f
d43 d48 d4c d50 d53 d56 d5a d5c
d60 d64 d67 d6a d6e d70 d74 d78
d7b d7f d83 d86 d8a d8d d91 d94
d95 d9a d9d da1 da7 da9 dad db0
db4 db8 dbc dc0 dc4 dc8 dcc dd0
dd4 dd8 ddc de0 de4 de8 dec df0
df4 df8 dfc e00 e04 e08 e0c e10
e14 e18 e1c e20 e21 e23 e27 e2b
e2f e32 e33 e35 e38 e3b e3c e41
e45 e49 e4d e50 e51 e53 e56 e59
e5a e5f e63 e67 e69 e6d e71 e74
e75 e77 e7b e7e e82 e85 e86 e8b
e8f e93 e97 e9a e9b e9d ea0 ea3
ea4 ea9 ead eaf eb3 eb7 eba ebc
ec0 ec7 ecb ecf ed4 ed6 eda ede
ee1 ee5 ee9 eeb 1 eef ef3 ef7
efa efe f02 f06 f0a f0d f11 f15
f18 f1b f20 f23 f26 f29 f2a f2f
f30 1 f32 f37 f3b f3f f42 f47
f4c f4f f53 f54 f59 f5c f61 f62
f67 f6a f6f f70 f75 f78 f7c f7d
f82 f85 f8a f8b f90 f93 f97 f9b
f9e fa1 fa2 fa4 fa5 faa fab fb0
fb2 fb6 fb9 fbb fbf fc1 fcd fcf
fd1 fd2 fd7 fdb fdd fe9 feb fef
ff3 ff6 ff7 ff9 ffc fff 1000 1005
1008 100c 1010 1013 1014 1016 1019 101c
101d 1022 1 1025 102a 102e 102f 1033
1037 1038 103c 1040 1044 1048 104c 1050
1054 1058 105c 1060 1064 1068 106c 1070
107c 1080 1084 1087 108b 108f 1091 1
1095 1099 109d 10a0 10a4 10a8 10ac 10b0
10b3 10b7 10bb 10be 10c1 10c6 10c9 10cc
10cf 10d0 10d5 10d6 1 10d8 10dd 10e1
10e5 10e8 10ed 10f2 10f5 10f9 10fa 10ff
1102 1107 1108 110d 1110 1115 1116 111b
111e 1122 1123 1128 112b 1130 1131 1136
1139 113d 1141 1144 1147 1148 114a 114b
1150 1151 1156 1158 115c 115f 1161 1165
1167 1173 1175 1177 1178 117d 1181 1183
118f 1191 1195 1198 1199 119e 11a1 11a5
11a8 11a9 11ae 11b1 11b5 11b9 11bd 11c1
11c5 11c9 11cd 11d1 11d5 11d9 11dd 11e1
11e5 11e9 11ed 11f1 11f5 11f9 11fd 1201
1205 1209 120d 1211 1215 1219 121d 1229
122d 1232 1236 1239 123a 123f 1243 1247
124a 124d 1251 1253 1257 125b 125e 1261
1265 1267 126b 126f 1272 1274 1 1278
127c 1280 1283 1287 128b 128f 1293 1296
129a 129e 12a1 12a4 12a9 12ac 12af 12b2
12b3 12b8 12b9 1 12bb 12c0 12c4 12c8
12cb 12d0 12d5 12d8 12dc 12dd 12e2 12e5
12ea 12eb 12f0 12f3 12f8 12f9 12fe 1301
1305 1306 130b 130e 1313 1314 1319 131c
1320 1324 1327 132a 132b 132d 132e 1333
1334 1339 133b 133f 1342 1344 1348 134a
1356 1358 135a 135b 1360 1364 1366 1372
1374 1376 137a 137e 1382 1386 138a 138e
1392 1396 13a2 13a6 13ab 13af 13b2 13b3
13b8 13bc 13c0 13c3 13c6 13ca 13cc 13d0
13d4 13d7 13da 13de 13e0 13e4 13e8 13eb
13ed 1 13f1 13f5 13f9 13fc 1400 1404
1408 140c 140f 1413 1417 141a 141d 1422
1425 1428 142b 142c 1431 1432 1 1434
1439 143d 1441 1444 1449 144e 1451 1455
1456 145b 145e 1463 1464 1469 146c 1471
1472 1477 147a 147e 147f 1484 1487 148c
148d 1492 1495 1499 149d 14a0 14a3 14a4
14a6 14a7 14ac 14ad 14b2 14b4 14b8 14bb
14bd 14c1 14c3 14cf 14d1 14d3 14d4 14d9
14dd 14df 14eb 14ed 14ef 14f3 14f7 14fa
14fe 1500 1504 1507 1508 150d 1510 1513
1517 151a 151b 1520 1523 1 1526 152b
152f 1532 1533 1538 153b 153f 1543 1547
154b 154f 1553 1557 155b 155f 1563 1567
156b 156f 1573 1577 157b 157f 1583 1587
158b 158f 1593 1597 159b 159f 15a3 15a7
15b3 15b7 15bc 15c0 15c3 15c4 15c9 15cd
15d1 15d4 15d7 15db 15dd 15e1 15e5 15e8
15eb 15ef 15f1 15f5 15f9 15fc 15fe 1
1602 1606 160a 160d 1611 1615 1619 161d
1620 1624 1628 162b 162e 1633 1636 1639
163c 163d 1642 1643 1 1645 164a 164e
1652 1655 165a 165f 1662 1666 1667 166c
166f 1674 1675 167a 167d 1682 1683 1688
168b 168f 1690 1695 1698 169d 169e 16a3
16a6 16aa 16ae 16b1 16b4 16b5 16b7 16b8
16bd 16be 16c3 16c5 16c9 16cc 16ce 16d2
16d4 16e0 16e2 16e4 16e5 16ea 16ee 16f0
16fc 16fe 1700 1704 1708 170c 1710 1714
1718 171c 1720 172c 1730 1735 1739 173c
173d 1742 1746 174a 174d 1750 1754 1756
175a 175e 1761 1764 1768 176a 176e 1772
1775 1777 1 177b 177f 1783 1786 178a
178e 1792 1796 1799 179d 17a1 17a4 17a7
17ac 17af 17b2 17b5 17b6 17bb 17bc 1
17be 17c3 17c7 17cb 17ce 17d3 17d8 17db
17df 17e0 17e5 17e8 17ed 17ee 17f3 17f6
17fb 17fc 1801 1804 1808 1809 180e 1811
1816 1817 181c 181f 1823 1827 182a 182d
182e 1830 1831 1836 1837 183c 183e 1842
1845 1847 184b 184d 1859 185b 185d 185e
1863 1867 1869 1875 1877 1879 187d 1881
1884 1886 188a 188e 1891 1893 1897 189a
189c 18a0 18a4 18a7 18a9 18ad 18b4 18b8
18bc 18c1 18c3 18c7 18cb 18ce 18d2 18d6
18d8 1 18dc 18e0 18e4 18e7 18eb 18ef
18f3 18f7 18fa 18fe 1902 1905 1908 190d
1910 1913 1916 1917 191c 191d 1 191f
1924 1928 192c 192f 1934 1939 193c 1940
1941 1946 1949 194e 194f 1954 1957 195c
195d 1962 1965 1969 196a 196f 1972 1977
1978 197d 1980 1984 1988 198b 198e 198f
1991 1992 1997 1998 199d 199f 19a3 19a6
19a8 19ac 19ae 19ba 19bc 19be 19bf 19c4
19c8 19ca 19d6 19d8 19dc 19e0 19e3 19e4
19e6 19e9 19ec 19ed 19f2 19f5 19f9 19fd
1a00 1a01 1a03 1a06 1a09 1a0c 1a0d 1a12
1a13 1a18 1 1a1b 1a38 1a24 1a28 1a30
1a33 1a23 1a3f 1a20 1a43 1a44 1a49 1a4c
1a50 1a54 1a58 1a5c 1a5d 1a5f 1a62 1a63
1a65 1a69 1a6c 1a6f 1a72 1a73 1a78 1a7c
1a7f 1a82 1a83 1 1a88 1a8d 1a91 1a95
1a98 1a9b 1a9c 1aa1 1aa5 1aa7 1aab 1aae
1ab0 1ab4 1ab7 1abb 1abe 1ac1 1ac2 1ac7
1aca 1acb 1ad0 1ad4 1ad8 1adb 1ade 1adf
1ae4 1ae7 1aea 1aed 1aee 1 1af3 1af8
1afc 1b00 1b03 1b07 1b0b 1b0e 1b12 1b16
1b17 1b1c 1b1e 1b22 1b25 1b27 1b2b 1b2d
1b39 1b3b 1b3f 1b43 1b47 1b4b 1b4f 1b53
1b57 1b5b 1b5f 1b63 1b67 1b73 1b77 1b7c
1b80 1b83 1b84 1b89 1b8d 1b91 1b94 1b97
1b9b 1b9d 1ba1 1ba5 1ba8 1bab 1baf 1bb1
1bb5 1bb9 1bbc 1bbe 1 1bc2 1bc6 1bca
1bcd 1bd1 1bd5 1bd9 1bdd 1be0 1be4 1be8
1beb 1bee 1bf3 1bf6 1bf9 1bfc 1bfd 1c02
1c03 1 1c05 1c0a 1c0e 1c12 1c15 1c1a
1c1f 1c22 1c26 1c27 1c2c 1c2f 1c34 1c35
1c3a 1c3d 1c42 1c43 1c48 1c4b 1c4f 1c50
1c55 1c58 1c5d 1c5e 1c63 1c66 1c6a 1c6e
1c71 1c74 1c75 1c77 1c78 1c7d 1c7e 1c83
1c85 1c89 1c8c 1c8e 1c92 1c94 1ca0 1ca2
1ca4 1ca5 1caa 1cae 1cb0 1cbc 1cbe 1cc2
1cc6 1cca 1ccb 1ccd 1cd1 1cd3 1cd7 1cda
1cdc 1ce0 1ce3 1ce7 1ceb 1cee 1cef 1cf1
1cf4 1cf7 1cf8 1cfd 1d01 1d05 1d08 1d0c
1d10 1d13 1d17 1d1b 1d1d 1d21 1d25 1d28
1d29 1d2b 1d2e 1d31 1d32 1d37 1d3b 1d3f
1d42 1d46 1d4a 1d4d 1d4e 1d50 1d54 1d56
1d5a 1d5e 1d61 1d65 1d69 1d6c 1d70 1d74
1d77 1d7a 1d7f 1d82 1d85 1d88 1d89 1d8e
1d8f 1 1d91 1d96 1d9a 1d9e 1da1 1da6
1dab 1dae 1db2 1db3 1db8 1dbb 1dc0 1dc1
1dc6 1dc9 1dce 1dcf 1dd4 1dd7 1ddb 1ddf
1de3 1de7 1dea 1deb 1ded 1df2 1df3 1df5
1df6 1dfb 1dfe 1e03 1e04 1e09 1e0c 1e11
1e12 1e17 1e1a 1e1e 1e1f 1e24 1e27 1e2c
1e2d 1e32 1e33 1e38 1e3a 1e3e 1e41 1e45
1e49 1e4c 1e50 1e54 1e57 1e5b 1e5f 1e60
1e65 1e67 1e6b 1e6f 1e72 1e76 1e7a 1e7d
1e81 1e85 1e88 1e8b 1e90 1e93 1e96 1e99
1e9a 1e9f 1ea0 1 1ea2 1ea7 1eab 1eaf
1eb2 1eb7 1ebc 1ebf 1ec3 1ec4 1ec9 1eca
1ecf 1ed3 1ed7 1eda 1edf 1ee4 1ee7 1eeb
1eef 1ef2 1ef3 1ef8 1efb 1f00 1f01 1f06
1f09 1f0d 1f11 1f14 1f15 1f1a 1f1b 1f20
1f22 1f26 1f29 1f2d 1f31 1f35 1f39 1f3d
1f41 1f45 1f49 1f4d 1f59 1f5e 1f62 1f66
1f6a 1f6e 1f70 1f71 1f76 1 1f7a 1f7e
1f82 1f85 1f89 1f8d 1f91 1f95 1f98 1f9c
1fa0 1fa3 1fa6 1fab 1fae 1fb1 1fb4 1fb5
1fba 1fbb 1 1fbd 1fc2 1fc6 1fca 1fcd
1fd2 1fd7 1fda 1fde 1fdf 1fe4 1fe5 1fea
1fee 1ff2 1ff5 1ffa 1fff 2002 2006 2007
200c 200f 2014 2015 201a 201d 2021 2025
2028 202b 202c 202e 202f 2034 2035 203a
203c 2040 2043 2047 204b 204f 2053 2057
205b 205f 206b 2070 2074 2078 207c 2080
2082 2086 2088 2094 2096 2098 2099 209e
20a2 20a4 20b0 20b4 20b6 20b7 20c0 
8df
2
0 1 a 6 c :3 6 11 :3 6
12 :2 6 1 3 a 13 a :2 1
4 18 21 20 :2 18 :2 4 11 1a
19 :2 11 :2 4 b 14 13 :2 b :2 4
f 18 17 :2 f :2 4 d 16 15
:2 d :2 4 f 18 17 :2 f :2 4 :3 12
:2 4 :3 13 :2 4 :3 11 :2 4 :3 12 :2 4 :3 f
:2 4 :3 10 :2 4 :3 f :2 4 :3 e :2 4 :3 15
:2 4 e 17 16 :2 e :2 4 18 21
20 :2 18 :2 4 f 18 17 :2 f :2 4
:2 e 1d e :2 4 :2 e 1d e :2 4
:2 d 1c d :2 4 :2 10 1f 10 :2 4
:2 c 1b c :2 4 :2 b 1a b :2 4
:2 d 1c d :2 4 :3 10 :2 4 :3 10 :2 4
12 1b 1a :2 12 :2 4 :2 d 1c d
:2 4 :2 12 21 12 :2 4 :2 a 19 a
:2 4 :2 f 1e f :2 4 :2 14 23 14
:2 4 :3 12 :2 4 :3 13 :2 4 :2 11 20 11
:2 4 :2 12 21 12 :2 4 :2 13 22 13
:2 4 :2 f 19 f :2 4 :2 f 19 f
:2 4 :3 9 :2 4 :3 9 :2 4 :2 f 1e f
:2 4 :2 16 25 16 :2 4 :2 11 20 11
:2 4 :2 14 23 14 :2 4 :2 e 1d e
:2 4 :3 10 :2 4 :2 16 2e 16 4 7
e 0 :2 7 11 1d 29 36 14
30 39 48 5a 14 31 3a 4a
5d f 1d 27 32 3e 47 4f
58 66 6f 7d 86 94 9d aa
b3 c4 cd e0 e9 fe 107 122
12b 143 14c 15d 166 178 181 199
1a2 1b5 1be 11 1e 38 45 54
64 b 29 50 59 68 a :6 7
e 0 :2 7 :3 a 15 :2 a 14 26
49 a 15 24 :3 a 14 34 4f
67 70 7f 90 99 a9 :b a f
10 1d e 18 11 1c 10 1d
2c 3c e 2c fffa :5 7 4 e
17 :3 e 4 7 :2 11 23 :2 2d 3a
:2 23 :3 7 :2 d 19 25 :2 2f 43 :2 25
57 5d 60 :2 57 6e 87 8 :2 6e
d 10 :2 6e 16 19 :2 6e b e
:2 6e 13 16 1f 27 :2 1f 34 :2 16
:2 6e b e :2 6e 13 16 :2 6e 1b
1e :2 6e 2a 2d :2 6e 32 35 :2 6e
:2 7 4d :2 4 7 :2 11 23 :2 2d 39
3c 4f 52 53 :2 4f :2 23 :3 7 :2 d
12 1e 61 64 :2 1e :2 7 56 :3 4
11 :2 4 12 :2 4 17 4 e 14
1b 28 30 c 1a 27 :2 7 :2 10
1c 7 4 :2 c a :2 13 1f a
d :2 17 29 :2 33 3f 43 56 59
5a :2 56 :2 29 :3 d :2 13 18 24 67
6a :2 24 77 7a :2 24 7e 81 :2 24
8d 90 :2 24 98 9b :2 24 a7 aa
b1 ba bd :2 aa :2 24 :2 d 5d :2 a
:2 7 :4 13 :2 7 4 :3 1 8 :2 11 1c
1a :2 25 :2 1a 7 :4 3b 3a 39 :3 7
11 18 1f 22 :2 18 27 2a :2 11
:2 7 13 14 :2 13 :2 7 c :4 7 10
1c 2a 35 3f 4d :3 a d 14
:2 d :2 16 22 d 1a d :2 16 22
d :4 a e :2 17 23 20 :2 2c :2 20
:3 d 3c :2 a d 16 20 :2 d 23
25 :2 23 10 19 24 :2 10 27 29
:2 27 10 25 :2 2e :2 10 1f 30 3e
49 57 66 :2 1f :2 10 :2 19 25 :2 10
1c 25 2f :2 1c 32 34 :2 1c 10
2b :2 d 27 d 1d :2 d 1e :2 d
12 :4 d 16 :19 10 13 1a :2 13 :2 1c
28 13 20 13 :2 1c 28 13 :4 10
14 :2 1d 29 26 :2 32 :2 26 :3 13 42
:3 10 23 32 40 4b 60 25 33
41 50 5a 25 2c 37 49 54
25 35 41 54 25 31 3d 4d
57 25 34 3f :2 23 10 13 1c
2d :2 13 30 32 :2 30 13 1f 28
32 :2 1f 35 37 :2 1f 13 10 34
16 1f 30 :2 16 35 33 :2 3e :2 33
13 26 2f 40 :2 26 43 45 :2 26
13 5d 34 :2 10 d 11 a 10
16 :3 10 :2 19 25 10 d :2 15 13
:2 1c 28 13 16 :2 20 32 :2 3c 48
4c 5f 62 63 :2 5f :2 32 :3 16 :2 1c
21 2d 70 73 :2 2d 80 83 :2 2d
87 8a :2 2d 96 99 :2 2d a1 a4
:2 2d b0 b3 ba c3 c6 :2 b3 :2 2d
:2 16 66 :2 13 :2 10 :4 1c :2 10 d :3 a
11 1a 25 :2 11 28 2b :2 28 10
33 3c 46 :2 33 49 4b :2 49 32
:3 10 1e :2 10 1f 10 1a 29 3a
4a 18 25 34 40 18 26 33
44 51 :2 13 :2 1c 28 13 10 :2 18
16 :2 1f 2b 16 19 :2 23 35 :2 3f
4b 4f 62 65 66 :2 62 :2 35 :3 19
:2 1f 24 30 73 76 :2 30 83 86
:2 30 8a 8d :2 30 99 9c :2 30 a4
a7 :2 30 b3 b6 bd c6 c9 :2 b6
:2 30 :2 19 69 :2 16 :2 13 :4 1f :2 13 10
:3 4e :4 14 13 :4 17 16 20 19 1e
3d 45 4c 63 6b 72 8c 1e
3e 1e 19 1e 3d 45 4c 63
6b 72 :2 1e 1f 2c 3d 4a 19
20 1c 28 :3 26 1c :2 25 31 1c
2d 1c :2 25 31 1c :4 19 16 :2 1e
1c :2 25 31 1c 1f :2 29 3b :2 45
51 55 68 6b 6c :2 68 :2 3b :3 1f
:2 25 2a 36 79 7c :2 36 89 8c
:2 36 90 93 :2 36 9f a2 :2 36 aa
ad :2 36 b9 bc c3 cc cf :2 bc
:2 36 :2 1f 6f :2 1c :2 19 :4 25 :2 19 16
:4 30 20 2c 3c 49 1f 2c 3d
4a 19 20 1c 28 :3 26 1c :2 25
31 1c 2d 1c :2 25 31 1c :4 19
16 :2 1e 1c :2 25 31 1c 1f :2 29
3b :2 45 51 55 68 6b 6c :2 68
:2 3b :3 1f :2 25 2a 36 79 7c :2 36
89 8c :2 36 90 93 :2 36 9f a2
:2 36 aa ad :2 36 b9 bc c3 cc
cf :2 bc :2 36 :2 1f 6f :2 1c :2 19 :4 25
:2 19 16 :7 13 10 2d :4 18 17 16
:4 37 36 35 :2 16 :4 17 16 20 19
1e 3d 45 4c 63 6b 72 8b
1e 3e 1e 19 1e 3d 45 4c
63 6b 72 :2 1e 1f 2c 3d 4a
19 20 1c 28 :3 26 1c :2 25 31
1c 2d 1c :2 25 31 1c :4 19 16
:2 1e 1c :2 25 31 1c 1f :2 29 3b
:2 45 51 55 68 6b 6c :2 68 :2 3b
:3 1f :2 25 2a 36 79 7c :2 36 89
8c :2 36 90 93 :2 36 9f a2 :2 36
aa ad :2 36 b9 bc c3 cc cf
:2 bc :2 36 :2 1f 6f :2 1c :2 19 :4 25 :2 19
16 :4 30 20 2c 3c 48 1f 2c
3d 4a 19 20 1c 28 :3 26 1c
:2 25 31 1c 2d 1c :2 25 31 1c
:4 19 16 :2 1e 1c :2 25 31 1c 1f
:2 29 3b :2 45 51 55 68 6b 6c
:2 68 :2 3b :3 1f :2 25 2a 36 79 7c
:2 36 89 8c :2 36 90 93 :2 36 9f
a2 :2 36 aa ad :2 36 b9 bc c3
cc cf :2 bc :2 36 :2 1f 6f :2 1c :2 19
:4 25 :2 19 16 :7 13 4d 2d :2 10 4e
:2 d :4 a 7 b 50 a 10 :3 a
:2 13 1f a 7 :2 f d :2 16 22
d 10 :2 1a 2c :2 36 42 46 59
5c 5d :2 59 :2 2c :3 10 :2 16 1b 27
6a 6d :2 27 7a 7d :2 27 81 84
:2 27 90 93 :2 27 9b 9e :2 27 aa
ad b4 bd c0 :2 ad :2 27 :2 10 60
:2 d :2 a :4 16 :2 a 7 :3 50 b 14
1e :2 b 21 23 :2 21 a 2b 34
3e :2 2b 41 43 44 :2 43 :2 41 2a
:2 a b :2 10 1e 10 b :4 f e
c 14 1d 24 :2 1d 2d :2 14 c
f 11 14 :2 11 1a 1f 22 :2 1f
:2 f c 14 19 1b :2 14 c 24
:2 c 23 :2 b 12 17 1a :2 17 :3 e
20 :2 25 29 :2 20 1f 2c 2f :2 2c
:2 e c :2 17 2b :2 34 47 4f :2 c
31 :2 b :2 a :3 47 14 20 2e 37
3e 4a 53 13 20 31 3b d
14 10 1c :3 1a 10 :2 19 25 10
21 10 :2 19 25 10 :4 d a :2 12
10 :2 19 25 10 13 :2 1d 2f :2 39
45 49 5c 5f 60 :2 5c :2 2f :3 13
:2 19 1e 2a 6d 70 :2 2a 7d 80
:2 2a 84 87 :2 2a 93 96 :2 2a 9e
a1 :2 2a ad b0 b7 c0 c3 :2 b0
:2 2a :2 13 63 :2 10 :2 d :4 19 :2 d a
:3 47 a 1d 27 :2 1d a 47 :2 7
50 :2 4 7 10 21 :2 7 24 26
:2 24 7 :2 10 1c :2 25 7 4 28
a 13 24 :2 a 27 29 :2 27 7
:2 10 1c 25 36 :2 1c 7 2d 28
:2 4 7 :2 11 23 :2 2d 39 3c 4f
52 53 :2 4f :2 23 :3 7 :2 d 12 1e
61 64 :2 1e 71 74 :2 1e 78 7b
:2 1e 85 88 91 99 :2 a2 :2 91 ad
:2 88 :2 1e b5 b8 :2 1e c0 c3 :2 1e
c8 cb :2 1e d1 d4 :2 1e :2 7 56
:3 4 :2 f 21 :2 2a 34 3b :2 4 1
9 12 9 a :2 14 26 :2 30 3c
40 53 56 57 :2 53 :2 26 :3 a :2 10
15 21 64 67 :2 21 :3 a :2 10 15
39 5c 5f :2 68 :2 39 76 79 :2 39
81 84 :2 8d :2 39 :2 a 5a :3 7 c
15 1e 2c a 13 1e f e
7 e 7 e 7 29 :2 4 :2 9
7 :2 10 1c :2 7 :2 11 23 :2 2d 39
3d 50 53 54 :2 50 :2 23 :3 7 :2 d
12 1e 61 64 :2 1e :3 7 :2 d 12
36 42 45 :2 36 4d 50 :2 36 5c
5f 66 6f 72 :2 5f :2 36 :2 7 57
:2 4 7 c 1b a 13 1e f
e 7 e 7 e 7 :2 4 :4 10
:2 4 :8 1 
8df
4
0 :2 1 :4 3 :4 4
:4 5 2 :4 6 :2 1
:7 8 :7 9 :7 a :7 b
:7 c :7 d :5 e :5 f
:5 10 :5 11 :5 12 :5 13
:5 14 :5 15 :5 16 :7 17
:7 18 :7 19 :6 1a :6 1b
:6 1c :6 1d :6 1e :6 1f
:6 20 :5 21 :5 22 :7 23
:6 24 :6 25 :6 26 :6 27
:6 28 :5 29 :5 2a :6 2b
:6 2c :6 2d :6 2e :6 2f
:5 30 :5 31 :6 32 :6 33
:6 34 :6 35 :6 36 :5 37
:6 38 :2 3a 0 :2 3a
:4 3b :5 3c :5 3d :22 3e
:6 3f :5 40 3b :5 3a
:2 42 0 :2 42 44
45 :2 46 47 48
:3 49 :3 4a 4b 4c
4d :9 4e 4f 50
51 52 53 54
55 56 57 58
59 5a :2 5b :2 5c
:2 5d :4 5e :2 5f 44
:5 42 :7 61 :b 63 :11 64
65 :2 64 :2 65 :2 64
:2 65 :2 64 :2 66 :2 64
:9 66 :2 64 :2 67 :2 64
:2 67 :2 64 :2 67 :2 64
:2 67 :2 64 :2 67 :4 64
:3 63 :11 6a :b 6b :3 6a
:3 6f :3 70 :3 71 :5 74
:3 75 74 :5 76 73
:2 78 :5 7a :11 7b :24 7c
:3 7b :2 79 :6 78 77
:3 62 :12 81 :c 82 :6 83
:5 87 89 :9 8a :3 8b
:5 8c 8b :5 8e 8d
:3 8b :a 91 :2 92 :3 91
:9 97 :9 99 :5 9b :a 9c
:5 9d :b 9f :3 99 97
:3 a3 :3 a5 :5 a8 aa
ab ac ad ae
af b0 b1 b2
b3 b4 b5 b6
b7 b8 b9 ba
bb bc bd be
bf c0 c1 :3 ab
:3 c2 :5 c3 c2 :5 c5
c4 :3 c2 :a c8 :2 c9
:3 c8 :6 ce :5 cf :5 d0
:4 d1 :5 d2 :3 d3 :3 ce
:9 d5 :b d6 d7 d5
:b d7 :b d8 d7 :3 d5
aa da a1 :4 de
:5 df dd :2 e1 :5 e3
:11 e4 :24 e5 :3 e4 :2 e2
:6 e1 e0 :3 a1 :16 ed
:3 ee :3 ef :4 f2 :4 f3
:5 f4 f2 :5 f5 f1
:2 f7 :5 f9 :11 fa :24 fb
:3 fa :2 f8 :6 f7 f6
:3 ed :5 101 :5 103 105
106 :8 108 :2 109 10a
10c :7 10e 10f 110
:4 112 105 :6 113 :5 114
113 :5 116 115 :3 113
104 :2 119 :5 11b :11 11c
:24 11d :3 11c :2 11a :6 119
118 :4 103 :4 123 :4 124
123 :6 125 :5 126 125
:5 128 127 :3 125 122
:2 12b :5 12d :11 12e :24 12f
:3 12e :2 12c :6 12b 12a
:4 121 :3 103 134 101
:e 134 :5 136 138 139
:8 13b :2 13c 13d 13f
:7 141 142 143 :4 145
138 :6 146 :5 147 146
:5 149 148 :3 146 137
:2 14c :5 14e :11 14f :24 150
:3 14f :2 14d :6 14c 14b
:4 136 :4 156 :4 157 156
:6 158 :5 159 158 :5 15b
15a :3 158 155 :2 15e
:5 160 :11 161 :24 162 :3 161
:2 15f :6 15e 15d :4 154
:3 136 134 :3 101 :3 ed
a1 :3 97 89 16a
81 :4 16e :5 16f 16d
:2 171 :5 173 :11 174 :24 175
:3 174 :2 172 :6 171 170
:3 81 :19 17c :6 17e :5 180
:a 181 :c 182 :7 183 :3 182
:3 180 :15 186 :a 187 :3 186
:2 17f :3 17c :7 18c :4 18d
18c :6 18e :5 18f 18e
:5 191 190 :3 18e 18b
:2 194 :5 196 :11 197 :24 198
:3 197 :2 195 :6 194 193
:3 17c :6 19d :3 17c :3 81
:9 1a2 :7 1a3 1a4 1a2
:9 1a4 :9 1a5 1a4 :3 1a2
:11 1a8 :30 1a9 :3 1a8 :a 1ab
62 :3 1ae :11 1af :b 1b0
:17 1b1 :3 1af :2 1b3 :3 1b4
:3 1b5 1b6 1b4 1b3
1b4 :3 1b7 :3 1ae :2 1b8
:5 1ba :11 1bb :b 1bc :18 1bd
:3 1bb :2 1bf 1c0 :3 1c1
1c2 1c0 1bf 1c0
:3 1c3 :2 1b9 :6 1b8 1ad
:7 1 
20c2
4
:3 0 1 :3 0 2
:a 0 8da 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
:2 0 7 6 :3 0
5 :7 0 9 8
:3 0 4 :3 0 7
:7 0 d c :3 0
8 :3 0 9 :3 0
a :2 0 4 11
12 0 f 13
0 8da 2 14
:2 0 c :2 0 f
4 :3 0 c :2 0
d 17 19 :6 0
1c 1a 0 8d8
0 b :6 0 f
:2 0 13 4 :3 0
11 1e 20 :6 0
23 21 0 8d8
0 d :6 0 c
:2 0 17 4 :3 0
15 25 27 :6 0
2a 28 0 8d8
0 e :6 0 c
:2 0 1b 4 :3 0
19 2c 2e :6 0
31 2f 0 8d8
0 10 :6 0 13
:2 0 1f 4 :3 0
1d 33 35 :6 0
38 36 0 8d8
0 11 :6 0 25
11e 0 23 4
:3 0 21 3a 3c
:6 0 3f 3d 0
8d8 0 12 :6 0
29 152 0 27
15 :3 0 41 :7 0
44 42 0 8d8
0 14 :6 0 15
:3 0 46 :7 0 49
47 0 8d8 0
16 :6 0 2d 186
0 2b 15 :3 0
4b :7 0 4e 4c
0 8d8 0 17
:6 0 15 :3 0 50
:7 0 53 51 0
8d8 0 18 :6 0
31 1ba 0 2f
15 :3 0 55 :7 0
58 56 0 8d8
0 19 :6 0 15
:3 0 5a :7 0 5d
5b 0 8d8 0
1a :6 0 35 1ee
0 33 1c :3 0
5f :7 0 62 60
0 8d8 0 1b
:6 0 1c :3 0 64
:7 0 67 65 0
8d8 0 1d :6 0
c :2 0 39 1c
:3 0 69 :7 0 6c
6a 0 8d8 0
1e :6 0 4 :3 0
c :2 0 37 6e
70 :6 0 73 71
0 8d8 0 1f
:6 0 13 :2 0 3d
4 :3 0 3b 75
77 :6 0 7a 78
0 8d8 0 20
:6 0 23 :2 0 41
4 :3 0 3f 7c
7e :6 0 81 7f
0 8d8 0 21
:6 0 23 :2 0 43
6 :3 0 83 :7 0
87 84 85 8d8
0 22 :6 0 23
:2 0 45 6 :3 0
89 :7 0 8d 8a
8b 8d8 0 24
:6 0 23 :2 0 47
6 :3 0 8f :7 0
93 90 91 8d8
0 25 :6 0 23
:2 0 49 6 :3 0
95 :7 0 99 96
97 8d8 0 26
:6 0 23 :2 0 4b
6 :3 0 9b :7 0
9f 9c 9d 8d8
0 27 :6 0 23
:2 0 4d 6 :3 0
a1 :7 0 a5 a2
a3 8d8 0 28
:6 0 51 324 0
4f 6 :3 0 a7
:7 0 ab a8 a9
8d8 0 29 :6 0
2d :2 0 53 15
:3 0 ad :7 0 b0
ae 0 8d8 0
2a :6 0 1c :3 0
b2 :7 0 b5 b3
0 8d8 0 2b
:6 0 23 :2 0 57
4 :3 0 55 b7
b9 :6 0 bc ba
0 8d8 0 2c
:6 0 23 :2 0 59
6 :3 0 be :7 0
c2 bf c0 8d8
0 2e :6 0 23
:2 0 5b 6 :3 0
c4 :7 0 c8 c5
c6 8d8 0 2f
:6 0 23 :2 0 5d
6 :3 0 ca :7 0
ce cb cc 8d8
0 30 :6 0 23
:2 0 5f 6 :3 0
d0 :7 0 d4 d1
d2 8d8 0 31
:6 0 63 401 0
61 6 :3 0 d6
:7 0 da d7 d8
8d8 0 32 :6 0
23 :2 0 65 15
:3 0 dc :7 0 df
dd 0 8d8 0
33 :6 0 15 :3 0
e1 :7 0 e4 e2
0 8d8 0 34
:6 0 23 :2 0 67
6 :3 0 e6 :7 0
ea e7 e8 8d8
0 35 :6 0 23
:2 0 69 6 :3 0
ec :7 0 f0 ed
ee 8d8 0 36
:6 0 3a :2 0 6b
6 :3 0 f2 :7 0
f6 f3 f4 8d8
0 37 :6 0 3a
:2 0 6d 39 :3 0
f8 :7 0 fc f9
fa 8d8 0 38
:6 0 71 4c1 0
6f 39 :3 0 fe
:7 0 102 ff 100
8d8 0 3b :6 0
23 :2 0 73 1c
:3 0 104 :7 0 107
105 0 8d8 0
3c :6 0 1c :3 0
109 :7 0 10c 10a
0 8d8 0 3d
:6 0 23 :2 0 75
6 :3 0 10e :7 0
112 10f 110 8d8
0 3e :6 0 23
:2 0 77 6 :3 0
114 :7 0 118 115
116 8d8 0 3f
:6 0 23 :2 0 79
6 :3 0 11a :7 0
11e 11b 11c 8d8
0 40 :6 0 23
:2 0 7b 6 :3 0
120 :7 0 124 121
122 8d8 0 41
:6 0 7f 581 0
7d 6 :3 0 126
:7 0 12a 127 128
8d8 0 42 :9 0
81 44 :3 0 12c
:7 0 12f 12d 0
8d8 0 43 :6 0
6 :3 0 131 0
2 :5 0 23 :2 0
135 132 133 8d8
0 45 :6 0 46
:3 0 47 :a 0 2
177 :4 0 137 13a
0 138 :3 0 48
:3 0 49 :3 0 4a
:3 0 4b :3 0 4c
:3 0 4d :3 0 4e
:3 0 4f :3 0 4c
:3 0 50 :3 0 4d
:3 0 51 :3 0 52
:3 0 50 :3 0 53
:3 0 54 :3 0 e
:3 0 55 :3 0 56
:3 0 57 :3 0 56
:3 0 58 :3 0 56
:3 0 59 :3 0 56
:3 0 5a :3 0 56
:3 0 5b :3 0 56
:3 0 5c :3 0 56
:3 0 5d :3 0 56
:3 0 5e :3 0 56
:3 0 5f :3 0 56
:3 0 60 :3 0 56
:3 0 61 :3 0 56
:3 0 62 :3 0 56
:3 0 63 :3 0 56
:3 0 64 :3 0 56
:3 0 65 :3 0 4a
:3 0 4b :3 0 4a
:3 0 4b :3 0 66
:3 0 67 :3 0 4c
:3 0 50 :3 0 4d
:3 0 4e :3 0 4f
:4 0 68 1 :8 0
178 137 13a 179
0 8d8 83 179
17b 178 17a :6 0
177 :7 0 179 46
:3 0 69 :a 0 3
1b2 :5 0 17d 180
0 17e :3 0 6a
:3 0 6b :3 0 6c
:3 0 6d :3 0 4c
:3 0 50 :3 0 22
:3 0 4c :3 0 67
:3 0 6c :3 0 6d
:3 0 66 :3 0 67
:3 0 6e :3 0 6f
:3 0 50 :3 0 4c
:3 0 50 :3 0 4d
:3 0 4e :3 0 4f
:3 0 4d :3 0 51
:3 0 52 :3 0 70
:3 0 71 :3 0 72
:3 0 73 :3 0 74
:3 0 75 :3 0 76
:3 0 77 :3 0 78
:3 0 79 :3 0 66
:3 0 7a :3 0 48
:3 0 d :3 0 7b
:3 0 1f :3 0 6c
:3 0 6d :3 0 6c
:3 0 6d :3 0 66
:3 0 67 :3 0 4c
:3 0 50 :4 0 7c
1 :8 0 1b3 17d
180 1b4 0 8d8
85 1b4 1b6 1b3
1b5 :6 0 1b2 :7 0
1b4 1be 1bf 0
87 9 :3 0 a
:2 0 4 1b8 1b9
0 1ba :7 0 1bd
1bb 0 8d8 0
7d :6 0 7e :3 0
7f :3 0 7e :3 0
80 :3 0 1c1 1c2
0 2 :4 0 89
1c3 1c5 1c0 1c7
1c6 :2 0 81 :3 0
82 :3 0 1c9 1ca
0 83 :4 0 7e
:3 0 84 :3 0 1cd
1ce 0 2 :4 0
8b 1cf 1d1 85
:4 0 86 :2 0 87
:3 0 8d 1d4 1d6
:3 0 88 :4 0 86
:2 0 89 :4 0 90
1d9 1db :3 0 86
:2 0 3 :3 0 93
1dd 1df :3 0 86
:2 0 89 :4 0 96
1e1 1e3 :3 0 86
:2 0 8a :4 0 99
1e5 1e7 :3 0 86
:2 0 4d :3 0 8b
:3 0 5 :3 0 9c
1eb 1ed 8c :4 0
9e 1ea 1f0 a1
1e9 1f2 :3 0 86
:2 0 8a :4 0 a4
1f4 1f6 :3 0 86
:2 0 89 :4 0 a7
1f8 1fa :3 0 86
:2 0 7 :3 0 aa
1fc 1fe :3 0 86
:2 0 89 :4 0 ad
200 202 :3 0 86
:2 0 8d :4 0 b0
204 206 :3 0 b3
1cb 208 :2 0 20a
b8 20b 1c8 20a
0 20c ba 0
838 7e :3 0 7f
:3 0 20d 20e 0
7e :3 0 8e :3 0
210 211 0 13
:2 0 2 :4 0 8f
:2 0 90 :2 0 13
:2 0 bc 216 218
:3 0 bf 212 21a
20f 21c 21b :2 0
81 :3 0 91 :3 0
21e 21f 0 83
:4 0 92 :4 0 86
:2 0 87 :3 0 c3
223 225 :3 0 c6
220 227 :2 0 229
c9 22a 21d 229
0 22b cb 0
838 22 :3 0 5
:3 0 22c 22d 0
838 10 :3 0 7
:3 0 22f 230 0
838 41 :3 0 23
:2 0 232 233 0
838 93 :3 0 54
:3 0 55 :3 0 e
:3 0 28 :3 0 53
:3 0 49 :3 0 3
:4 0 94 1 :8 0
243 9 :3 0 95
:3 0 23e 23f 0
96 :3 0 240 241
0 243 cd 28d
97 :3 0 9 :3 0
95 :3 0 246 247
0 96 :3 0 248
249 0 283 7e
:3 0 7f :3 0 24b
24c 0 7e :3 0
8e :3 0 24e 24f
0 98 :2 0 2
:4 0 99 :2 0 90
:2 0 13 :2 0 d0
254 256 :3 0 d3
250 258 24d 25a
259 :2 0 81 :3 0
91 :3 0 25c 25d
0 83 :4 0 9a
:4 0 86 :2 0 87
:3 0 d7 261 263
:3 0 86 :2 0 9b
:4 0 da 265 267
:3 0 86 :2 0 9c
:4 0 dd 269 26b
:3 0 86 :2 0 96
:3 0 e0 26d 26f
:3 0 86 :2 0 9d
:4 0 e3 271 273
:3 0 86 :2 0 9e
:3 0 9f :3 0 13
:2 0 a0 :2 0 e6
276 27a ea 275
27c :3 0 ed 25e
27e :2 0 280 f0
281 25b 280 0
282 f2 0 283
f4 286 :3 0 286
0 286 285 283
284 :6 0 288 4
:3 0 f7 28a f9
289 288 :2 0 28b
fb :2 0 28d 0
28d 28c 243 28b
:6 0 838 1 :3 0
9 :3 0 95 :3 0
28f 290 0 9
:3 0 a1 :2 0 a2
:3 0 292 294 0
ff 293 296 :3 0
297 :2 0 28 :3 0
a3 :2 0 102 29a
29b :3 0 29c :2 0
29d :2 0 298 29f
29e :2 0 e :3 0
9e :3 0 e :3 0
86 :2 0 a4 :4 0
104 2a4 2a6 :3 0
13 :2 0 f :2 0
107 2a2 2aa 2a1
2ab 0 7bf 25
:3 0 a5 :2 0 13
:2 0 10b 2ae 2b0
:3 0 2ad 2b1 0
7bf a6 :3 0 47
:4 0 2b6 :2 0 7bf
2b4 2b7 :3 0 a7
:3 0 47 :3 0 d
:3 0 1f :3 0 25
:3 0 17 :3 0 18
:4 0 2c0 :2 0 683
2b9 2c1 :3 0 10d
:3 0 47 :3 0 a8
:3 0 2c2 2c3 :3 0
9 :3 0 95 :3 0
2c5 2c6 0 23
:2 0 2c7 2c8 0
2ca 113 2d1 9
:3 0 95 :3 0 2cb
2cc 0 a9 :2 0
2cd 2ce 0 2d0
115 2d2 2c4 2ca
0 2d3 0 2d0
0 2d3 117 0
683 9 :3 0 95
:3 0 2d4 2d5 0
9 :3 0 aa :2 0
a2 :3 0 2d7 2d9
0 11c 2d8 2db
:3 0 2dc :2 0 ab
:8 0 2e0 11f 2e1
2dd 2e0 0 2e2
121 0 683 4d
:3 0 25 :3 0 23
:2 0 123 2e3 2e6
a1 :2 0 23 :2 0
128 2e8 2ea :3 0
4d :3 0 22 :3 0
23 :2 0 12b 2ec
2ef a1 :2 0 ac
:2 0 130 2f1 2f3
:3 0 45 :3 0 9
:3 0 95 :3 0 2f6
2f7 0 2f5 2f8
0 314 43 :3 0
ad :3 0 d :3 0
1f :3 0 17 :3 0
18 :3 0 10 :3 0
133 2fb 301 2fa
302 0 314 9
:3 0 95 :3 0 304
305 0 45 :3 0
306 307 0 314
29 :3 0 4d :3 0
29 :3 0 23 :2 0
139 30a 30d 90
:2 0 13 :2 0 13c
30f 311 :3 0 309
312 0 314 13f
315 2f4 314 0
316 144 0 317
146 680 17 :4 0
318 319 0 67f
18 :4 0 31b 31c
0 67f a6 :3 0
69 :4 0 321 :2 0
67f 31f 322 :3 0
a7 :3 0 69 :3 0
20 :3 0 b :3 0
35 :3 0 17 :3 0
18 :3 0 25 :3 0
26 :3 0 30 :3 0
24 :3 0 1e :3 0
42 :3 0 14 :3 0
16 :3 0 3e :3 0
3f :3 0 38 :3 0
3b :3 0 21 :3 0
37 :3 0 11 :3 0
12 :3 0 36 :4 0
33c :2 0 3ae 324
33d :3 0 148 :3 0
69 :3 0 a8 :3 0
33e 33f :3 0 9
:3 0 95 :3 0 341
342 0 23 :2 0
343 344 0 346
15f 34d 9 :3 0
95 :3 0 347 348
0 a9 :2 0 349
34a 0 34c 161
34e 340 346 0
34f 0 34c 0
34f 163 0 3ae
9 :3 0 95 :3 0
350 351 0 9
:3 0 aa :2 0 a2
:3 0 353 355 0
168 354 357 :3 0
358 :2 0 ab :8 0
35c 16b 35d 359
35c 0 35e 16d
0 3ae 32 :3 0
ae :3 0 d :3 0
1f :3 0 20 :3 0
b :3 0 35 :3 0
17 :3 0 18 :3 0
25 :3 0 26 :3 0
30 :3 0 24 :3 0
1e :3 0 42 :3 0
14 :3 0 16 :3 0
3e :3 0 3f :3 0
38 :3 0 3b :3 0
21 :3 0 37 :3 0
11 :3 0 12 :3 0
36 :3 0 22 :3 0
10 :3 0 16f 360
37b 35f 37c 0
3ae 4d :3 0 32
:3 0 23 :2 0 18a
37e 381 a1 :2 0
23 :2 0 18f 383
385 :3 0 29 :3 0
4d :3 0 29 :3 0
23 :2 0 192 388
38b 90 :2 0 13
:2 0 195 38d 38f
:3 0 387 390 0
393 af :3 0 198
3ac 4d :3 0 32
:3 0 23 :2 0 19a
394 397 56 :3 0
a1 :2 0 b0 :3 0
399 39b 0 19f
39a 39d :3 0 41
:3 0 4d :3 0 41
:3 0 23 :2 0 1a2
3a0 3a3 90 :2 0
13 :2 0 1a5 3a5
3a7 :3 0 39f 3a8
0 3aa 1a8 3ab
39e 3aa 0 3ad
386 393 0 3ad
1aa 0 3ae 1ad
3b0 a7 :4 0 3ae
:4 0 67f b1 :3 0
69 :4 0 3b4 :2 0
3ba 3b2 0 9
:3 0 95 :3 0 3b5
3b6 0 96 :3 0
3b7 3b8 0 3ba
1b3 404 97 :3 0
9 :3 0 95 :3 0
3bd 3be 0 96
:3 0 3bf 3c0 0
3fa 7e :3 0 7f
:3 0 3c2 3c3 0
7e :3 0 8e :3 0
3c5 3c6 0 98
:2 0 2 :4 0 b2
:2 0 90 :2 0 13
:2 0 1b6 3cb 3cd
:3 0 1b9 3c7 3cf
3c4 3d1 3d0 :2 0
81 :3 0 91 :3 0
3d3 3d4 0 83
:4 0 b3 :4 0 86
:2 0 87 :3 0 1bd
3d8 3da :3 0 86
:2 0 9b :4 0 1c0
3dc 3de :3 0 86
:2 0 9c :4 0 1c3
3e0 3e2 :3 0 86
:2 0 96 :3 0 1c6
3e4 3e6 :3 0 86
:2 0 9d :4 0 1c9
3e8 3ea :3 0 86
:2 0 9e :3 0 9f
:3 0 13 :2 0 a0
:2 0 1cc 3ed 3f1
1d0 3ec 3f3 :3 0
1d3 3d5 3f5 :2 0
3f7 1d6 3f8 3d2
3f7 0 3f9 1d8
0 3fa 1da 3fd
:3 0 3fd 0 3fd
3fc 3fa 3fb :6 0
3ff 8 :3 0 1dd
401 1df 400 3ff
:2 0 402 1e1 :2 0
404 0 404 403
3ba 402 :6 0 67f
6 :3 0 4d :3 0
22 :3 0 23 :2 0
1e3 406 409 aa
:2 0 13 :2 0 1e8
40b 40d :3 0 40e
:2 0 4d :3 0 29
:3 0 23 :2 0 1eb
410 413 b4 :2 0
23 :2 0 1f0 415
417 :3 0 418 :2 0
40f 41a 419 :2 0
19 :4 0 41c 41d
0 67c 1a :4 0
41f 420 0 67c
b5 :3 0 b6 :3 0
4c :3 0 50 :3 0
2a :3 0 2f :3 0
19 :3 0 1a :3 0
53 :3 0 48 :3 0
d :3 0 49 :3 0
1f :4 0 b7 1
:8 0 435 9 :3 0
95 :3 0 430 431
0 96 :3 0 432
433 0 435 1f3
47f 97 :3 0 9
:3 0 95 :3 0 438
439 0 96 :3 0
43a 43b 0 475
7e :3 0 7f :3 0
43d 43e 0 7e
:3 0 8e :3 0 440
441 0 98 :2 0
2 :4 0 b8 :2 0
90 :2 0 13 :2 0
1f6 446 448 :3 0
1f9 442 44a 43f
44c 44b :2 0 81
:3 0 91 :3 0 44e
44f 0 83 :4 0
b9 :4 0 86 :2 0
87 :3 0 1fd 453
455 :3 0 86 :2 0
9b :4 0 200 457
459 :3 0 86 :2 0
9c :4 0 203 45b
45d :3 0 86 :2 0
96 :3 0 206 45f
461 :3 0 86 :2 0
9d :4 0 209 463
465 :3 0 86 :2 0
9e :3 0 9f :3 0
13 :2 0 a0 :2 0
20c 468 46c 210
467 46e :3 0 213
450 470 :2 0 472
216 473 44d 472
0 474 218 0
475 21a 478 :3 0
478 0 478 477
475 476 :6 0 47a
a :3 0 21d 47c
21f 47b 47a :2 0
47d 221 :2 0 47f
0 47f 47e 435
47d :6 0 67c 6
:3 0 1a :3 0 a3
:2 0 223 482 483
:3 0 484 :2 0 2a
:3 0 a3 :2 0 225
487 488 :3 0 489
:2 0 53 :3 0 b5
:3 0 2f :3 0 ba
:3 0 9e :3 0 2a
:3 0 ba :3 0 9e
:3 0 1a :3 0 1a
:3 0 2f :3 0 1a
:3 0 2a :3 0 b6
:3 0 2f :3 0 ba
:3 0 9e :3 0 2a
:3 0 ba :3 0 9e
:3 0 1a :3 0 2f
:3 0 2f :3 0 48
:3 0 d :3 0 49
:3 0 1f :4 0 bb
1 :8 0 4bc a8
:4 0 4a7 :3 0 bc
:3 0 a1 :2 0 229
4aa 4ab :3 0 9
:3 0 95 :3 0 4ad
4ae 0 23 :2 0
4af 4b0 0 4b2
22c 4b9 9 :3 0
95 :3 0 4b3 4b4
0 a9 :2 0 4b5
4b6 0 4b8 22e
4ba 4ac 4b2 0
4bb 0 4b8 0
4bb 230 0 4bc
233 506 97 :3 0
9 :3 0 95 :3 0
4bf 4c0 0 96
:3 0 4c1 4c2 0
4fc 7e :3 0 7f
:3 0 4c4 4c5 0
7e :3 0 8e :3 0
4c7 4c8 0 98
:2 0 2 :4 0 bd
:2 0 90 :2 0 13
:2 0 236 4cd 4cf
:3 0 239 4c9 4d1
4c6 4d3 4d2 :2 0
81 :3 0 91 :3 0
4d5 4d6 0 83
:4 0 be :4 0 86
:2 0 87 :3 0 23d
4da 4dc :3 0 86
:2 0 9b :4 0 240
4de 4e0 :3 0 86
:2 0 9c :4 0 243
4e2 4e4 :3 0 86
:2 0 96 :3 0 246
4e6 4e8 :3 0 86
:2 0 9d :4 0 249
4ea 4ec :3 0 86
:2 0 9e :3 0 9f
:3 0 13 :2 0 a0
:2 0 24c 4ef 4f3
250 4ee 4f5 :3 0
253 4d7 4f7 :2 0
4f9 256 4fa 4d4
4f9 0 4fb 258
0 4fc 25a 4ff
:3 0 4ff 0 4ff
4fe 4fc 4fd :6 0
501 c :3 0 25d
503 25f 502 501
:2 0 504 261 :2 0
506 0 506 505
4bc 504 :6 0 508
6 :3 0 263 574
53 :3 0 b5 :3 0
1a :3 0 b6 :3 0
48 :3 0 d :3 0
49 :3 0 1f :4 0
bf 1 :8 0 527
a8 :4 0 512 :3 0
bc :3 0 a1 :2 0
267 515 516 :3 0
9 :3 0 95 :3 0
518 519 0 23
:2 0 51a 51b 0
51d 26a 524 9
:3 0 95 :3 0 51e
51f 0 a9 :2 0
520 521 0 523
26c 525 517 51d
0 526 0 523
0 526 26e 0
527 271 571 97
:3 0 9 :3 0 95
:3 0 52a 52b 0
96 :3 0 52c 52d
0 567 7e :3 0
7f :3 0 52f 530
0 7e :3 0 8e
:3 0 532 533 0
98 :2 0 2 :4 0
c0 :2 0 90 :2 0
13 :2 0 274 538
53a :3 0 277 534
53c 531 53e 53d
:2 0 81 :3 0 91
:3 0 540 541 0
83 :4 0 c1 :4 0
86 :2 0 87 :3 0
27b 545 547 :3 0
86 :2 0 9b :4 0
27e 549 54b :3 0
86 :2 0 9c :4 0
281 54d 54f :3 0
86 :2 0 96 :3 0
284 551 553 :3 0
86 :2 0 9d :4 0
287 555 557 :3 0
86 :2 0 9e :3 0
9f :3 0 13 :2 0
a0 :2 0 28a 55a
55e 28e 559 560
:3 0 291 542 562
:2 0 564 294 565
53f 564 0 566
296 0 567 298
56a :3 0 56a 0
56a 569 567 568
:6 0 56c e :3 0
29b 56e 29d 56d
56c :2 0 56f 29f
:2 0 571 0 571
570 527 56f :6 0
573 6 :3 0 2a1
575 48a 508 0
576 0 573 0
576 2a3 0 578
af :3 0 2a6 67a
19 :3 0 a3 :2 0
2a8 57a 57b :3 0
57c :2 0 57d :2 0
1a :3 0 c2 :2 0
2aa 580 581 :3 0
582 :2 0 583 :2 0
57e 585 584 :2 0
2a :3 0 a3 :2 0
2ac 588 589 :3 0
58a :2 0 53 :3 0
b5 :3 0 2f :3 0
ba :3 0 9e :3 0
2a :3 0 ba :3 0
9e :3 0 19 :3 0
19 :3 0 2f :3 0
19 :3 0 2a :3 0
b6 :3 0 2f :3 0
ba :3 0 9e :3 0
2a :3 0 ba :3 0
9e :3 0 19 :3 0
2f :3 0 2f :3 0
48 :3 0 d :3 0
49 :3 0 1f :4 0
c3 1 :8 0 5bd
a8 :4 0 5a8 :3 0
bc :3 0 a1 :2 0
2b0 5ab 5ac :3 0
9 :3 0 95 :3 0
5ae 5af 0 23
:2 0 5b0 5b1 0
5b3 2b3 5ba 9
:3 0 95 :3 0 5b4
5b5 0 a9 :2 0
5b6 5b7 0 5b9
2b5 5bb 5ad 5b3
0 5bc 0 5b9
0 5bc 2b7 0
5bd 2ba 607 97
:3 0 9 :3 0 95
:3 0 5c0 5c1 0
96 :3 0 5c2 5c3
0 5fd 7e :3 0
7f :3 0 5c5 5c6
0 7e :3 0 8e
:3 0 5c8 5c9 0
98 :2 0 2 :4 0
c4 :2 0 90 :2 0
13 :2 0 2bd 5ce
5d0 :3 0 2c0 5ca
5d2 5c7 5d4 5d3
:2 0 81 :3 0 91
:3 0 5d6 5d7 0
83 :4 0 c5 :4 0
86 :2 0 87 :3 0
2c4 5db 5dd :3 0
86 :2 0 9b :4 0
2c7 5df 5e1 :3 0
86 :2 0 9c :4 0
2ca 5e3 5e5 :3 0
86 :2 0 96 :3 0
2cd 5e7 5e9 :3 0
86 :2 0 9d :4 0
2d0 5eb 5ed :3 0
86 :2 0 9e :3 0
9f :3 0 13 :2 0
a0 :2 0 2d3 5f0
5f4 2d7 5ef 5f6
:3 0 2da 5d8 5f8
:2 0 5fa 2dd 5fb
5d5 5fa 0 5fc
2df 0 5fd 2e1
600 :3 0 600 0
600 5ff 5fd 5fe
:6 0 602 10 :3 0
2e4 604 2e6 603
602 :2 0 605 2e8
:2 0 607 0 607
606 5bd 605 :6 0
609 6 :3 0 2ea
675 53 :3 0 b5
:3 0 19 :3 0 b6
:3 0 48 :3 0 d
:3 0 49 :3 0 1f
:4 0 c6 1 :8 0
628 a8 :4 0 613
:3 0 bc :3 0 a1
:2 0 2ee 616 617
:3 0 9 :3 0 95
:3 0 619 61a 0
23 :2 0 61b 61c
0 61e 2f1 625
9 :3 0 95 :3 0
61f 620 0 a9
:2 0 621 622 0
624 2f3 626 618
61e 0 627 0
624 0 627 2f5
0 628 2f8 672
97 :3 0 9 :3 0
95 :3 0 62b 62c
0 96 :3 0 62d
62e 0 668 7e
:3 0 7f :3 0 630
631 0 7e :3 0
8e :3 0 633 634
0 98 :2 0 2
:4 0 c7 :2 0 90
:2 0 13 :2 0 2fb
639 63b :3 0 2fe
635 63d 632 63f
63e :2 0 81 :3 0
91 :3 0 641 642
0 83 :4 0 c8
:4 0 86 :2 0 87
:3 0 302 646 648
:3 0 86 :2 0 9b
:4 0 305 64a 64c
:3 0 86 :2 0 9c
:4 0 308 64e 650
:3 0 86 :2 0 96
:3 0 30b 652 654
:3 0 86 :2 0 9d
:4 0 30e 656 658
:3 0 86 :2 0 9e
:3 0 9f :3 0 13
:2 0 a0 :2 0 311
65b 65f 315 65a
661 :3 0 318 643
663 :2 0 665 31b
666 640 665 0
667 31d 0 668
31f 66b :3 0 66b
0 66b 66a 668
669 :6 0 66d 12
:3 0 322 66f 324
66e 66d :2 0 670
326 :2 0 672 0
672 671 628 670
:6 0 674 6 :3 0
328 676 58b 609
0 677 0 674
0 677 32a 0
678 32d 679 586
678 0 67b 485
578 0 67b 32f
0 67c 332 67d
41b 67c 0 67e
337 0 67f 339
681 2eb 317 0
682 0 67f 0
682 340 0 683
343 685 a7 :4 0
683 :4 0 7bf b1
:3 0 47 :4 0 689
:2 0 68f 687 0
9 :3 0 95 :3 0
68a 68b 0 96
:3 0 68c 68d 0
68f 348 6d9 97
:3 0 9 :3 0 95
:3 0 692 693 0
96 :3 0 694 695
0 6cf 7e :3 0
7f :3 0 697 698
0 7e :3 0 8e
:3 0 69a 69b 0
98 :2 0 2 :4 0
c9 :2 0 90 :2 0
13 :2 0 34b 6a0
6a2 :3 0 34e 69c
6a4 699 6a6 6a5
:2 0 81 :3 0 91
:3 0 6a8 6a9 0
83 :4 0 ca :4 0
86 :2 0 87 :3 0
352 6ad 6af :3 0
86 :2 0 9b :4 0
355 6b1 6b3 :3 0
86 :2 0 9c :4 0
358 6b5 6b7 :3 0
86 :2 0 96 :3 0
35b 6b9 6bb :3 0
86 :2 0 9d :4 0
35e 6bd 6bf :3 0
86 :2 0 9e :3 0
9f :3 0 13 :2 0
a0 :2 0 361 6c2
6c6 365 6c1 6c8
:3 0 368 6aa 6ca
:2 0 6cc 36b 6cd
6a7 6cc 0 6ce
36d 0 6cf 36f
6d2 :3 0 6d2 0
6d2 6d1 6cf 6d0
:6 0 6d4 14 :3 0
372 6d6 374 6d5
6d4 :2 0 6d7 376
:2 0 6d9 0 6d9
6d8 68f 6d7 :6 0
7bf 1 :3 0 4d
:3 0 29 :3 0 23
:2 0 378 6db 6de
b4 :2 0 23 :2 0
37d 6e0 6e2 :3 0
6e3 :2 0 4d :3 0
25 :3 0 23 :2 0
380 6e5 6e8 b4
:2 0 a5 :2 0 13
:2 0 383 6eb 6ed
:3 0 387 6ea 6ef
:3 0 6f0 :2 0 6e4
6f2 6f1 :2 0 a3
:2 0 38a 6 :3 0
6f5 :7 0 23 :2 0
6f9 6f6 6f7 746
0 cb :6 0 e
:3 0 38c 6fb 6fc
:3 0 6fd :2 0 cb
:3 0 4d :3 0 cc
:3 0 e :3 0 38e
701 703 23 :2 0
390 700 706 6ff
707 0 71f 13
:2 0 aa :2 0 23
:2 0 395 70a 70c
:3 0 cb :3 0 aa
:2 0 23 :2 0 39a
70f 711 :3 0 70d
713 712 :2 0 cb
:3 0 cb :3 0 a5
:2 0 13 :2 0 39d
717 719 :3 0 715
71a 0 71c 3a0
71d 714 71c 0
71e 3a2 0 71f
3a4 720 6fe 71f
0 721 3a7 0
744 cb :3 0 aa
:2 0 23 :2 0 3ab
723 725 :3 0 cd
:2 0 3ae 727 728
:3 0 cb :3 0 ce
:3 0 ce :2 0 cf
:2 0 3b0 72c 72e
:3 0 72f :2 0 aa
:2 0 23 :2 0 3b5
731 733 :3 0 729
735 734 :2 0 d0
:3 0 d1 :3 0 737
738 0 56 :3 0
d2 :3 0 73a 73b
0 e :3 0 bc
:3 0 3b8 739 73f
:2 0 741 3bc 742
736 741 0 743
3be 0 744 3c0
747 :3 0 747 3c3
747 746 744 745
:6 0 7bc 1 :3 0
53 :3 0 d3 :3 0
d4 :3 0 d5 :3 0
d3 :3 0 56 :3 0
d6 :3 0 48 :3 0
d :3 0 54 :3 0
e :4 0 d7 1
:8 0 76a a8 :4 0
755 :3 0 bc :3 0
a1 :2 0 3c7 758
759 :3 0 9 :3 0
95 :3 0 75b 75c
0 23 :2 0 75d
75e 0 760 3ca
767 9 :3 0 95
:3 0 761 762 0
a9 :2 0 763 764
0 766 3cc 768
75a 760 0 769
0 766 0 769
3ce 0 76a 3d1
7b4 97 :3 0 9
:3 0 95 :3 0 76d
76e 0 96 :3 0
76f 770 0 7aa
7e :3 0 7f :3 0
772 773 0 7e
:3 0 8e :3 0 775
776 0 98 :2 0
2 :4 0 d8 :2 0
90 :2 0 13 :2 0
3d4 77b 77d :3 0
3d7 777 77f 774
781 780 :2 0 81
:3 0 91 :3 0 783
784 0 83 :4 0
d9 :4 0 86 :2 0
87 :3 0 3db 788
78a :3 0 86 :2 0
9b :4 0 3de 78c
78e :3 0 86 :2 0
9c :4 0 3e1 790
792 :3 0 86 :2 0
96 :3 0 3e4 794
796 :3 0 86 :2 0
9d :4 0 3e7 798
79a :3 0 86 :2 0
9e :3 0 9f :3 0
13 :2 0 a0 :2 0
3ea 79d 7a1 3ee
79c 7a3 :3 0 3f1
785 7a5 :2 0 7a7
3f4 7a8 782 7a7
0 7a9 3f6 0
7aa 3f8 7ad :3 0
7ad 0 7ad 7ac
7aa 7ab :6 0 7af
17 :3 0 3fb 7b1
3fd 7b0 7af :2 0
7b2 3ff :2 0 7b4
0 7b4 7b3 76a
7b2 :6 0 7bc 1
:3 0 32 :3 0 da
:3 0 d :3 0 401
7b7 7b9 7b6 7ba
0 7bc 403 7bd
6f3 7bc 0 7be
407 0 7bf 409
7c0 2a0 7bf 0
7c1 410 0 838
4d :3 0 41 :3 0
23 :2 0 412 7c2
7c5 b4 :2 0 23
:2 0 417 7c7 7c9
:3 0 9 :3 0 95
:3 0 7cb 7cc 0
56 :3 0 b0 :3 0
7ce 7cf 0 7cd
7d0 0 7d3 af
:3 0 41a 7e8 4d
:3 0 32 :3 0 23
:2 0 41c 7d4 7d7
b4 :2 0 a9 :2 0
421 7d9 7db :3 0
9 :3 0 95 :3 0
7dd 7de 0 4d
:3 0 32 :3 0 23
:2 0 424 7e0 7e3
7df 7e4 0 7e6
427 7e7 7dc 7e6
0 7e9 7ca 7d3
0 7e9 429 0
838 7e :3 0 7f
:3 0 7ea 7eb 0
7e :3 0 8e :3 0
7ed 7ee 0 cf
:2 0 2 :4 0 db
:2 0 90 :2 0 13
:2 0 42c 7f3 7f5
:3 0 42f 7ef 7f7
7ec 7f9 7f8 :2 0
81 :3 0 91 :3 0
7fb 7fc 0 83
:4 0 dc :4 0 86
:2 0 87 :3 0 433
800 802 :3 0 86
:2 0 9b :4 0 436
804 806 :3 0 86
:2 0 dd :4 0 439
808 80a :3 0 86
:2 0 4d :3 0 8b
:3 0 9 :3 0 95
:3 0 80f 810 0
43c 80e 812 8c
:4 0 43e 80d 815
441 80c 817 :3 0
86 :2 0 de :4 0
444 819 81b :3 0
86 :2 0 89 :4 0
447 81d 81f :3 0
86 :2 0 3 :3 0
44a 821 823 :3 0
86 :2 0 89 :4 0
44d 825 827 :3 0
450 7fd 829 :2 0
82b 453 82c 7fa
82b 0 82d 455
0 838 d0 :3 0
df :3 0 82e 82f
0 9 :3 0 95
:3 0 831 832 0
3 :3 0 bc :3 0
457 830 836 :2 0
838 45b 8d9 9
:3 0 e0 :2 0 4
839 83a 0 7e
:3 0 7f :3 0 83c
83d 0 7e :3 0
8e :3 0 83f 840
0 98 :2 0 2
:4 0 e1 :2 0 90
:2 0 13 :2 0 466
845 847 :3 0 469
841 849 83e 84b
84a :2 0 81 :3 0
91 :3 0 84d 84e
0 83 :4 0 e2
:4 0 86 :2 0 87
:3 0 46d 852 854
:3 0 470 84f 856
:2 0 86f 81 :3 0
91 :3 0 858 859
0 83 :4 0 e3
:4 0 86 :2 0 9
:3 0 e4 :3 0 85e
85f 0 473 85d
861 :3 0 86 :2 0
de :4 0 476 863
865 :3 0 86 :2 0
9 :3 0 e5 :3 0
868 869 0 479
867 86b :3 0 47c
85a 86d :2 0 86f
47f 870 84c 86f
0 871 482 0
881 a6 :3 0 7d
:3 0 9 :3 0 e4
:3 0 e6 :3 0 9
:3 0 e5 :3 0 e7
:3 0 e8 :4 0 e9
1 :a 0 87d :2 0
881 873 87b :2 0
8 :3 0 7d :3 0
87f :2 0 881 484
883 488 882 881
:2 0 8d7 97 :3 0
9 :3 0 95 :3 0
886 887 0 96
:3 0 888 889 0
8cf 7e :3 0 7f
:3 0 88b 88c 0
7e :3 0 8e :3 0
88e 88f 0 98
:2 0 2 :4 0 ea
:2 0 90 :2 0 13
:2 0 48a 894 896
:3 0 48d 890 898
88d 89a 899 :2 0
81 :3 0 91 :3 0
89c 89d 0 83
:4 0 eb :4 0 86
:2 0 87 :3 0 491
8a1 8a3 :3 0 494
89e 8a5 :2 0 8bf
81 :3 0 91 :3 0
8a7 8a8 0 83
:4 0 9c :4 0 86
:2 0 96 :3 0 497
8ac 8ae :3 0 86
:2 0 9d :4 0 49a
8b0 8b2 :3 0 86
:2 0 9e :3 0 9f
:3 0 13 :2 0 a0
:2 0 49d 8b5 8b9
4a1 8b4 8bb :3 0
4a4 8a9 8bd :2 0
8bf 4a7 8c0 89b
8bf 0 8c1 4aa
0 8cf a6 :3 0
7d :3 0 e6 :3 0
9 :3 0 e5 :3 0
e7 :3 0 e8 :4 0
ec 1 :a 0 8cb
:2 0 8cf 8c3 8c9
:2 0 8 :3 0 7d
:3 0 8cd :2 0 8cf
4ac 8d2 :3 0 8d2
0 8d2 8d1 8cf
8d0 :6 0 8d4 1
:3 0 4b1 8d6 4b3
8d5 8d4 :2 0 8d7
4b5 :2 0 8d9 4b8
8d9 8d8 838 8d7
:6 0 8da :2 0 2
14 8d9 8dd :3 0
8dc 8da 8de :8 0

4ed
4
:3 0 1 3 1
7 1 b 3
6 a e 1
18 1 16 1
1f 1 1d 1
26 1 24 1
2d 1 2b 1
34 1 32 1
3b 1 39 1
40 1 45 1
4a 1 4f 1
54 1 59 1
5e 1 63 1
68 1 6f 1
6d 1 76 1
74 1 7d 1
7b 1 82 1
88 1 8e 1
94 1 9a 1
a0 1 a6 1
ac 1 b1 1
b8 1 b6 1
bd 1 c3 1
c9 1 cf 1
d5 1 db 1
e0 1 e5 1
eb 1 f1 1
f7 1 fd 1
103 1 108 1
10d 1 113 1
119 1 11f 1
125 1 12b 1
130 1 176 1
1b1 1 1b7 1
1c4 1 1d0 2
1d3 1d5 2 1d8
1da 2 1dc 1de
2 1e0 1e2 2
1e4 1e6 1 1ec
2 1ee 1ef 2
1e8 1f1 2 1f3
1f5 2 1f7 1f9
2 1fb 1fd 2
1ff 201 2 203
205 4 1cc 1d2
1d7 207 1 209
1 20b 2 215
217 3 213 214
219 2 222 224
2 221 226 1
228 1 22a 2
23d 242 2 253
255 3 251 252
257 2 260 262
2 264 266 2
268 26a 2 26c
26e 2 270 272
3 277 278 279
2 274 27b 2
25f 27d 1 27f
1 281 2 24a
282 1 286 1
245 1 28a 1
295 2 291 295
1 299 2 2a3
2a5 3 2a7 2a8
2a9 1 2af 5
2ba 2bb 2bc 2bd
2be 1 2c9 1
2cf 2 2d1 2d2
1 2da 2 2d6
2da 1 2df 1
2e1 2 2e4 2e5
1 2e9 2 2e7
2e9 2 2ed 2ee
1 2f2 2 2f0
2f2 5 2fc 2fd
2fe 2ff 300 2
30b 30c 2 30e
310 4 2f9 303
308 313 1 315
1 316 16 325
326 327 328 329
32a 32b 32c 32d
32e 32f 330 331
332 333 334 335
336 337 338 339
33a 1 345 1
34b 2 34d 34e
1 356 2 352
356 1 35b 1
35d 1a 361 362
363 364 365 366
367 368 369 36a
36b 36c 36d 36e
36f 370 371 372
373 374 375 376
377 378 379 37a
2 37f 380 1
384 2 382 384
2 389 38a 2
38c 38e 1 391
2 395 396 1
39c 2 398 39c
2 3a1 3a2 2
3a4 3a6 1 3a9
2 3ac 3ab 5
33b 34f 35e 37d
3ad 2 3b3 3b9
2 3ca 3cc 3
3c8 3c9 3ce 2
3d7 3d9 2 3db
3dd 2 3df 3e1
2 3e3 3e5 2
3e7 3e9 3 3ee
3ef 3f0 2 3eb
3f2 2 3d6 3f4
1 3f6 1 3f8
2 3c1 3f9 1
3fd 1 3bc 1
401 2 407 408
1 40c 2 40a
40c 2 411 412
1 416 2 414
416 2 42f 434
2 445 447 3
443 444 449 2
452 454 2 456
458 2 45a 45c
2 45e 460 2
462 464 3 469
46a 46b 2 466
46d 2 451 46f
1 471 1 473
2 43c 474 1
478 1 437 1
47c 1 481 1
486 1 4a9 2
4a8 4a9 1 4b1
1 4b7 2 4b9
4ba 2 4a6 4bb
2 4cc 4ce 3
4ca 4cb 4d0 2
4d9 4db 2 4dd
4df 2 4e1 4e3
2 4e5 4e7 2
4e9 4eb 3 4f0
4f1 4f2 2 4ed
4f4 2 4d8 4f6
1 4f8 1 4fa
2 4c3 4fb 1
4ff 1 4be 1
503 1 506 1
514 2 513 514
1 51c 1 522
2 524 525 2
511 526 2 537
539 3 535 536
53b 2 544 546
2 548 54a 2
54c 54e 2 550
552 2 554 556
3 55b 55c 55d
2 558 55f 2
543 561 1 563
1 565 2 52e
566 1 56a 1
529 1 56e 1
571 2 574 575
1 576 1 579
1 57f 1 587
1 5aa 2 5a9
5aa 1 5b2 1
5b8 2 5ba 5bb
2 5a7 5bc 2
5cd 5cf 3 5cb
5cc 5d1 2 5da
5dc 2 5de 5e0
2 5e2 5e4 2
5e6 5e8 2 5ea
5ec 3 5f1 5f2
5f3 2 5ee 5f5
2 5d9 5f7 1
5f9 1 5fb 2
5c4 5fc 1 600
1 5bf 1 604
1 607 1 615
2 614 615 1
61d 1 623 2
625 626 2 612
627 2 638 63a
3 636 637 63c
2 645 647 2
649 64b 2 64d
64f 2 651 653
2 655 657 3
65c 65d 65e 2
659 660 2 644
662 1 664 1
666 2 62f 667
1 66b 1 62a
1 66f 1 672
2 675 676 1
677 2 67a 679
4 41e 421 47f
67b 1 67d 6
31a 31d 320 3b0
404 67e 2 680
681 4 2bf 2d3
2e2 682 2 688
68e 2 69f 6a1
3 69d 69e 6a3
2 6ac 6ae 2
6b0 6b2 2 6b4
6b6 2 6b8 6ba
2 6bc 6be 3
6c3 6c4 6c5 2
6c0 6c7 2 6ab
6c9 1 6cb 1
6cd 2 696 6ce
1 6d2 1 691
1 6d6 2 6dc
6dd 1 6e1 2
6df 6e1 2 6e6
6e7 1 6ec 1
6ee 2 6e9 6ee
1 6f4 1 6fa
1 702 2 704
705 1 70b 2
709 70b 1 710
2 70e 710 2
716 718 1 71b
1 71d 2 708
71e 1 720 1
724 2 722 724
1 726 2 72a
72d 1 732 2
730 732 3 73c
73d 73e 1 740
1 742 2 721
743 1 6f8 1
757 2 756 757
1 75f 1 765
2 767 768 2
754 769 2 77a
77c 3 778 779
77e 2 787 789
2 78b 78d 2
78f 791 2 793
795 2 797 799
3 79e 79f 7a0
2 79b 7a2 2
786 7a4 1 7a6
1 7a8 2 771
7a9 1 7ad 1
76c 1 7b1 1
7b8 3 747 7b4
7bb 1 7bd 6
2ac 2b2 2b5 685
6d9 7be 1 7c0
2 7c3 7c4 1
7c8 2 7c6 7c8
1 7d1 2 7d5
7d6 1 7da 2
7d8 7da 2 7e1
7e2 1 7e5 2
7e8 7e7 2 7f2
7f4 3 7f0 7f1
7f6 2 7ff 801
2 803 805 2
807 809 1 811
2 813 814 2
80b 816 2 818
81a 2 81c 81e
2 820 822 2
824 826 2 7fe
828 1 82a 1
82c 3 833 834
835 a 20c 22b
22e 231 234 28d
7c1 7e9 82d 837
2 844 846 3
842 843 848 2
851 853 2 850
855 2 85c 860
2 862 864 2
866 86a 2 85b
86c 2 857 86e
1 870 3 871
87c 880 1 83b
2 893 895 3
891 892 897 2
8a0 8a2 2 89f
8a4 2 8ab 8ad
2 8af 8b1 3
8b6 8b7 8b8 2
8b3 8ba 2 8aa
8bc 2 8a6 8be
1 8c0 4 88a
8c1 8ca 8ce 1
8d2 1 885 2
883 8d6 34 1b
22 29 30 37
3e 43 48 4d
52 57 5c 61
66 6b 72 79
80 86 8c 92
98 9e a4 aa
af b4 bb c1
c7 cd d3 d9
de e3 e9 ef
f5 fb 101 106
10b 111 117 11d
123 129 12e 134
177 1b2 1bc 
1
4
0 
8dd
0
1
28
19
39
0 1 1 1 4 1 6 6
8 6 a 6 c 6 e 6
10 6 12 1 14 1 1 17
1 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0

b 1 0
2 0 1
e0 1 0
94 1 0
cf 1 0
f1 1 0
4f 1 0
74 1 0
119 1 0
16 1 0
c9 1 0
bd 1 0
39 1 0
db 1 0
fd 1 0
12b 1 0
b1 1 0
d5 1 0
6f4 16 0
11f 1 0
68 1 0
8e 1 0
54 1 0
3 1 0
40 1 0
4a 1 0
137 1 2
10d 1 0
82 1 0
e5 1 0
b6 1 0
108 1 0
59 1 0
9a 1 0
113 1 0
6d 1 0
24 1 0
45 1 0
130 1 0
eb 1 0
7b 1 0
ac 1 0
63 1 0
a0 1 0
32 1 0
1d 1 0
17d 1 3
7 1 0
103 1 0
f7 1 0
5e 1 0
2b 1 0
88 1 0
125 1 0
c3 1 0
1b7 1 0
a6 1 0
0

/
SHOW ERRORS FUNCTION SP_ACPT_ETC_WBS;
ALTER FUNCTION SP_ACPT_ETC_WBS COMPILE DEBUG;
/****************************************************************************************
Reject ETC and/or FORECAST_START, WBS level
  Bitflag =
    1 - ETC
    2 - FORECAST_START
    3 - ETC + FORECAST_START
****************************************************************************************/
Prompt == FUNCTION SP_RJCT_ETC_ASSIGN ==
CREATE OR REPLACE FUNCTION SP_RJCT_ETC_ASSIGN wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
a2
2 :e:
1FUNCTION:
1SP_RJCT_ETC_ASSIGN:
1ID001:
1VARCHAR2:
1BITFLAG001:
1PLS_INTEGER:
1REC_USER001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_TSK_ASSIGNMENT_ID:
132:
1H_PROJECT_ID:
1H_TASK_ID:
1H_START_DATE:
1TIMESTAMP:
1H_BIT_FLAG:
11:
1H_BITFLAG:
10:
1H_TEMP_SC_STATE:
1H_STEPS_EXIST:
1H_SCHED_WORK:
1H_WORK_TODATE:
1H_MLST_PERCENT:
1I_PERCENT_COMPLETE:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_RJCT_ETC_ASSIGN(:
1':
1, :
1COALESCE:
1TO_CHAR:
1NULL:
1);:
1CHECK_TRACE:
130:
1+:
1FPUT:
1               ENTER:: SP_RJCT_ETC_ASSIGN(31) :: cplan.sql(18684) :: :
1PROJECT_ID:
1TASK_ID:
1BIT_FLAG:
1SCHED_WORK:
1PLANNED_WORK:
1WORK_TODATE:
1MILESTONE_PERCENT:
1TASK_ASSIGNMENTS:
1TSK_ASSIGNMENT_ID:
1SELECT PROJECT_ID, TASK_ID, BIT_FLAG, SCHED_WORK+PLANNED_WORK, WORK_TODATE, M+
1ILESTONE_PERCENT:n      INTO h_project_id, h_task_id, h_bit_flag, h_sched_wor+
1k, h_work_todate, h_mlst_percent:n      FROM TASK_ASSIGNMENTS WHERE TSK_ASSIG+
1NMENT_ID = h_tsk_assignment_id:
1SC_STATE:
1SQLCODE:
1OTHERS:
116:
147:
1           EXCEPTION:: SP_RJCT_ETC_ASSIGN(48) :: cplan.sql(18701) :: :
1 :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1=:
12:
1ETC:
1UPDATE TASK_ASSIGNMENTS SET ETC = SCHED_WORK - WORK_TODATE--, MILESTONE_PERCE+
1NT = (WORK_TODATE * 10000) / SCHED_WORK:n            WHERE TSK_ASSIGNMENT_ID +
1= h_tsk_assignment_id:
1FOUND:
1TRUE:
1100:
167:
1           EXCEPTION:: SP_RJCT_ETC_ASSIGN(68) :: cplan.sql(18721) :: :
1ACTIVITIES:
1ETC_MODIFIED:
1ELEMENT_ID:
1TYPE_ID:
1PMO_CNST:
1SC_TIMESHEET_ACTIVITY:
1UPDATE ACTIVITIES:n            SET ETC_MODIFIED = 'N':n            WHERE TSK_+
1ASSIGNMENT_ID = h_tsk_assignment_id:n            AND TSK_ASSIGNMENT_ID <> ELE+
1MENT_ID:n            AND TYPE_ID = PMO_CNST.SC_TIMESHEET_ACTIVITY:
188:
1           EXCEPTION:: SP_RJCT_ETC_ASSIGN(89) :: cplan.sql(18742) :: :
1UPDATE TASK_ASSIGNMENTS SET ETC = PLANNED_WORK, WORK_TODATE = 0, MILESTONE_PE+
1RCENT = 0:n            WHERE TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
1106:
1           EXCEPTION:: SP_RJCT_ETC_ASSIGN(107) :: cplan.sql(18760) :: :
1TMT_WBS:
1ROLLUP_BITS:
1PMO_STPU:
1BIT_OR:
1SC_SCHED_BIT:
1UPDATE TMT_WBS SET ROLLUP_BITS = PMO_STPU.BIT_OR(ROLLUP_BITS, PMO_CNST.SC_SCH+
1ED_BIT) WHERE ELEMENT_ID = h_task_id:
1124:
1           EXCEPTION:: SP_RJCT_ETC_ASSIGN(125) :: cplan.sql(18778) :: :
1FORECAST_START:
1FORECAST_FINISH:
1FORECAST_DURATION:
1UPDATE TASK_ASSIGNMENTS SET FORECAST_START = NuLL, FORECAST_FINISH = NuLL, FO+
1RECAST_DURATION = 0:n            WHERE TSK_ASSIGNMENT_ID = h_tsk_assignment_i+
1d:
1143:
1           EXCEPTION:: SP_RJCT_ETC_ASSIGN(144) :: cplan.sql(18797) :: :
1160:
1           EXCEPTION:: SP_RJCT_ETC_ASSIGN(161) :: cplan.sql(18814) :: :
1UPDATE TASK_ASSIGNMENTS SET FORECAST_START = NuLL, FORECAST_FINISH = NuLL, FO+
1RECAST_DURATION = 0,:n               ETC = SCHED_WORK - WORK_TODATE--, MILEST+
1ONE_PERCENT = (WORK_TODATE * 10000) / SCHED_WORK:n               WHERE TSK_AS+
1SIGNMENT_ID = h_tsk_assignment_id:
1180:
1           EXCEPTION:: SP_RJCT_ETC_ASSIGN(181) :: cplan.sql(18834) :: :
1UPDATE ACTIVITIES:n               SET ETC_MODIFIED = 'N':n               WHER+
1E TSK_ASSIGNMENT_ID = h_tsk_assignment_id:n               AND TSK_ASSIGNMENT_+
1ID <> ELEMENT_ID:n               AND TYPE_ID = PMO_CNST.SC_TIMESHEET_ACTIVITY:
1201:
1           EXCEPTION:: SP_RJCT_ETC_ASSIGN(202) :: cplan.sql(18855) :: :
1UPDATE TASK_ASSIGNMENTS SET FORECAST_START = NuLL, FORECAST_FINISH = NuLL, FO+
1RECAST_DURATION = 0,:n               ETC = PLANNED_WORK, WORK_TODATE = 0, MIL+
1ESTONE_PERCENT = 0:n               WHERE TSK_ASSIGNMENT_ID = h_tsk_assignment+
1_id:
1220:
1           EXCEPTION:: SP_RJCT_ETC_ASSIGN(221) :: cplan.sql(18874) :: :
1238:
1           EXCEPTION:: SP_RJCT_ETC_ASSIGN(239) :: cplan.sql(18892) :: :
1BITAND:
1>:
1TRUNC:
1TO_NUMBER:
1/:
1*:
110000.00:
1-:
1<:
1SC_PERCENT_COMPLETE_BIT:
1ACTUAL_FINISH:
1SCHED_FINISH:
1UPDATE TASK_ASSIGNMENTS SET:n            ROLLUP_BITS = PMO_STPU.BIT_OR(ROLLUP+
1_BITS,PMO_CNST.SC_PERCENT_COMPLETE_BIT),:n            ACTUAL_FINISH = CASE:n +
1           WHEN ACTUAL_FINISH IS NULL AND ETC = 0 THEN SCHED_FINISH:n        +
1    ELSE ACTUAL_FINISH:n            END:n            WHERE TSK_ASSIGNMENT_ID +
1= h_tsk_assignment_id:
1268:
1           EXCEPTION:: SP_RJCT_ETC_ASSIGN(269) :: cplan.sql(18922) :: :
1UPDATE TASK_ASSIGNMENTS SET:n         ACTUAL_FINISH = CASE:n         WHEN ACT+
1UAL_FINISH IS NULL AND ETC = 0 THEN SCHED_FINISH:n         ELSE ACTUAL_FINISH+
1:n         END:n         WHERE TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
1291:
1           EXCEPTION:: SP_RJCT_ETC_ASSIGN(292) :: cplan.sql(18945) :: :
1SC_SQL_SUCCESS:
1!=:
1FC_FIX_SUMMARY_TS:
1FC_ROLLUP:
14:
1306:
1       RETURN_STATUS:: SP_RJCT_ETC_ASSIGN(307) :: cplan.sql(18960) :: :
1STATE:: :
1 ID:: :
1PMODEFINES:
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
1313:
1           EXCEPTION:: SP_RJCT_ETC_ASSIGN(314) :: cplan.sql(18967) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1ID:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
1325:
1           EXCEPTION:: SP_RJCT_ETC_ASSIGN(326) :: cplan.sql(18979) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
7ec
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 81 b0 a3 :2 a0
6b 1c 81 b0 :2 a0 6b :2 a0 6b
6e a5 b a 10 :2 a0 6b 6e
:2 a0 6b 6e a5 b 6e 7e a0
b4 2e 6e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :3 a0 a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 d :2 a0 d :10 a0 12a :2 a0 6b
a0 d b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
51 a5 b 7e 51 b4 2e :2 a0
:2 51 a5 b 7e 6e b4 2e :6 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:9 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 :7 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 :2 19 3c :9 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
:2 a0 51 a5 b 7e 51 b4 2e
:6 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :9 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 :2 a0 :2 51 a5 b 7e
6e b4 2e :9 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :9 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 :a a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
:2 19 3c :9 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 :2 19 3c b7 :2 19
3c :3 a0 51 a5 b 51 a5 b
5a 7e 51 b4 2e 5a :2 a0 51
a5 b 7e 51 b4 2e 5a a
10 :5 a0 a5 b 51 a5 b 7e
:3 a0 a5 b 51 a5 b b4 2e
5a 7e 51 b4 2e 5a 7e :2 a0
51 a5 b b4 2e a5 b d
a0 7e 51 b4 2e 5a a0 :2 7e
51 b4 2e b4 2e 52 10 :e a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 19 3c b7 :8 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 :2 19 3c
:2 a0 6b a0 7e a0 6b b4 2e
5a :2 a0 51 a5 b 7e 51 b4
2e 5a a 10 :4 a0 a5 b d
b7 19 3c :3 a0 a5 b d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
:2 a0 a5 57 b7 :2 a0 6b :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 :2 a0 6b
:2 6e 7e :2 a0 6b b4 2e 7e 6e
b4 2e 7e :2 a0 6b b4 2e a5
57 b7 19 3c :9 a0 12a e9 dd
:2 a0 65 b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c :7 a0 12a e9 dd :2 a0 65
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 68 4f 1d 17 b5 
7ec
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 30
56 5a 5e 62 65 69 86 71
75 78 79 81 70 a3 91 6d
95 96 9e 90 c0 ae 8d b2
b3 bb ad dc cb cf d7 aa
f8 e3 e7 ea eb f3 ca 114
103 107 c7 10f 102 130 11f 123
ff 12b 11e 14c 13b 13f 11b 147
13a 168 157 15b 137 163 156 184
173 177 153 17f 172 1a0 18f 193
16f 19b 18e 1bc 1ab 1af 1b7 18b
1db 1c3 1c7 1cb 1ce 1d6 1aa 1e2
1e6 1a7 1ea 1ee 1f2 1f5 1fa 1fb
1 1fd 202 206 20a 20d 212 216
21a 21d 222 223 225 22a 22d 231
232 237 23c 23f 244 245 24a 24d
251 252 257 25a 25f 260 265 268
26d 26e 273 276 27a 27e 282 283
285 28a 28b 28d 28e 293 296 29b
29c 2a1 2a4 2a9 2aa 2af 2b2 2b6
2b7 2bc 2bf 2c4 2c5 2ca 2cd 2d2
2d3 2d8 2d9 2de 2e0 2e4 2e7 2eb
2ef 2f2 2f6 2fa 2fd 300 305 308
30b 30e 30f 314 315 1 317 31c
320 324 327 32c 331 334 338 339
33e 33f 344 346 34a 34d 351 355
359 35d 361 365 369 36d 371 375
379 37d 381 385 389 38d 391 395
399 39d 3a1 3a5 3b1 3b5 3b9 3bc
3c0 3c4 3c6 1 3ca 3ce 3d2 3d5
3d9 3dd 3e1 3e5 3e8 3ec 3f0 3f3
3f6 3fb 3fe 401 404 405 40a 40b
1 40d 412 416 41a 41d 422 427
42a 42e 42f 434 437 43c 43d 442
445 44a 44b 450 453 457 458 45d
460 465 466 46b 46e 472 476 479
47c 47d 47f 480 485 486 48b 48d
491 494 496 49a 49c 4a8 4aa 4ac
4ad 4b2 4b6 4b8 4c4 4c6 4ca 4ce
4d1 4d2 4d4 4d7 4da 4db 4e0 4e4
4e8 4eb 4ee 4ef 4f1 4f4 4f9 4fa
4ff 503 507 50b 50f 513 517 523
527 52c 530 533 534 539 53d 541
544 547 54b 54d 551 555 558 55b
55f 561 565 569 56c 56e 1 572
576 57a 57d 581 585 589 58d 590
594 598 59b 59e 5a3 5a6 5a9 5ac
5ad 5b2 5b3 1 5b5 5ba 5be 5c2
5c5 5ca 5cf 5d2 5d6 5d7 5dc 5df
5e4 5e5 5ea 5ed 5f2 5f3 5f8 5fb
5ff 600 605 608 60d 60e 613 616
61a 61e 621 624 625 627 628 62d
62e 633 635 639 63c 63e 642 644
650 652 654 655 65a 65e 660 66c
66e 672 676 67a 67e 682 686 68a
68e 692 69e 6a2 6a7 6ab 6ae 6af
6b4 6b8 6bc 6bf 6c2 6c6 6c8 6cc
6d0 6d3 6d6 6da 6dc 6e0 6e4 6e7
6e9 1 6ed 6f1 6f5 6f8 6fc 700
704 708 70b 70f 713 716 719 71e
721 724 727 728 72d 72e 1 730
735 739 73d 740 745 74a 74d 751
752 757 75a 75f 760 765 768 76d
76e 773 776 77a 77b 780 783 788
789 78e 791 795 799 79c 79f 7a0
7a2 7a3 7a8 7a9 7ae 7b0 7b4 7b7
7b9 7bd 7bf 7cb 7cd 7cf 7d0 7d5
7d9 7db 7e7 7e9 7eb 7ef 7f3 7f7
7fb 7ff 803 807 813 817 81c 820
823 824 829 82d 831 834 837 83b
83d 841 845 848 84b 84f 851 855
859 85c 85e 1 862 866 86a 86d
871 875 879 87d 880 884 888 88b
88e 893 896 899 89c 89d 8a2 8a3
1 8a5 8aa 8ae 8b2 8b5 8ba 8bf
8c2 8c6 8c7 8cc 8cf 8d4 8d5 8da
8dd 8e2 8e3 8e8 8eb 8ef 8f0 8f5
8f8 8fd 8fe 903 906 90a 90e 911
914 915 917 918 91d 91e 923 925
929 92c 92e 932 934 940 942 944
945 94a 94e 950 95c 95e 960 964
968 96b 96f 973 977 97b 97f 983
987 98b 98f 99b 99f 9a4 9a8 9ab
9ac 9b1 9b5 9b9 9bc 9bf 9c3 9c5
9c9 9cd 9d0 9d3 9d7 9d9 9dd 9e1
9e4 9e6 1 9ea 9ee 9f2 9f5 9f9
9fd a01 a05 a08 a0c a10 a13 a16
a1b a1e a21 a24 a25 a2a a2b 1
a2d a32 a36 a3a a3d a42 a47 a4a
a4e a4f a54 a57 a5c a5d a62 a65
a6a a6b a70 a73 a77 a78 a7d a80
a85 a86 a8b a8e a92 a96 a99 a9c
a9d a9f aa0 aa5 aa6 aab aad ab1
ab4 ab6 aba abc ac8 aca acc acd
ad2 ad6 ad8 ae4 ae6 ae8 aec af0
af3 af4 af6 af9 afc afd b02 b06
b0a b0e b12 b16 b1a b26 b2a b2f
b33 b36 b37 b3c b40 b44 b47 b4a
b4e b50 b54 b58 b5b b5e b62 b64
b68 b6c b6f b71 1 b75 b79 b7d
b80 b84 b88 b8c b90 b93 b97 b9b
b9e ba1 ba6 ba9 bac baf bb0 bb5
bb6 1 bb8 bbd bc1 bc5 bc8 bcd
bd2 bd5 bd9 bda bdf be2 be7 be8
bed bf0 bf5 bf6 bfb bfe c02 c03
c08 c0b c10 c11 c16 c19 c1d c21
c24 c27 c28 c2a c2b c30 c31 c36
c38 c3c c3f c41 c45 c47 c53 c55
c57 c58 c5d c61 c63 c6f c71 c75
c79 c7d c81 c85 c89 c8d c91 c95
ca1 ca5 caa cae cb1 cb2 cb7 cbb
cbf cc2 cc5 cc9 ccb ccf cd3 cd6
cd9 cdd cdf ce3 ce7 cea cec 1
cf0 cf4 cf8 cfb cff d03 d07 d0b
d0e d12 d16 d19 d1c d21 d24 d27
d2a d2b d30 d31 1 d33 d38 d3c
d40 d43 d48 d4d d50 d54 d55 d5a
d5d d62 d63 d68 d6b d70 d71 d76
d79 d7d d7e d83 d86 d8b d8c d91
d94 d98 d9c d9f da2 da3 da5 da6
dab dac db1 db3 db7 dba dbc dc0
dc2 dce dd0 dd2 dd3 dd8 ddc dde
dea dec dee df2 df6 df9 dfc dfd
dff e02 e07 e08 e0d e11 e15 e19
e1d e21 e25 e29 e2d e31 e3d e41
e46 e4a e4d e4e e53 e57 e5b e5e
e61 e65 e67 e6b e6f e72 e75 e79
e7b e7f e83 e86 e88 1 e8c e90
e94 e97 e9b e9f ea3 ea7 eaa eae
eb2 eb5 eb8 ebd ec0 ec3 ec6 ec7
ecc ecd 1 ecf ed4 ed8 edc edf
ee4 ee9 eec ef0 ef1 ef6 ef9 efe
eff f04 f07 f0c f0d f12 f15 f19
f1a f1f f22 f27 f28 f2d f30 f34
f38 f3b f3e f3f f41 f42 f47 f48
f4d f4f f53 f56 f58 f5c f5e f6a
f6c f6e f6f f74 f78 f7a f86 f88
f8c f90 f94 f98 f9c fa0 fa4 fa8
fac fb8 fbc fc1 fc5 fc8 fc9 fce
fd2 fd6 fd9 fdc fe0 fe2 fe6 fea
fed ff0 ff4 ff6 ffa ffe 1001 1003
1 1007 100b 100f 1012 1016 101a 101e
1022 1025 1029 102d 1030 1033 1038 103b
103e 1041 1042 1047 1048 1 104a 104f
1053 1057 105a 105f 1064 1067 106b 106c
1071 1074 1079 107a 107f 1082 1087 1088
108d 1090 1094 1095 109a 109d 10a2 10a3
10a8 10ab 10af 10b3 10b6 10b9 10ba 10bc
10bd 10c2 10c3 10c8 10ca 10ce 10d1 10d3
10d7 10d9 10e5 10e7 10e9 10ea 10ef 10f3
10f5 1101 1103 1105 1109 110d 1111 1115
1119 111d 1121 1125 1129 112d 1139 113d
1142 1146 1149 114a 114f 1153 1157 115a
115d 1161 1163 1167 116b 116e 1171 1175
1177 117b 117f 1182 1184 1 1188 118c
1190 1193 1197 119b 119f 11a3 11a6 11aa
11ae 11b1 11b4 11b9 11bc 11bf 11c2 11c3
11c8 11c9 1 11cb 11d0 11d4 11d8 11db
11e0 11e5 11e8 11ec 11ed 11f2 11f5 11fa
11fb 1200 1203 1208 1209 120e 1211 1215
1216 121b 121e 1223 1224 1229 122c 1230
1234 1237 123a 123b 123d 123e 1243 1244
1249 124b 124f 1252 1254 1258 125a 1266
1268 126a 126b 1270 1274 1276 1282 1284
1286 128a 128e 1291 1295 1299 129d 12a1
12a5 12a9 12ad 12b1 12b5 12c1 12c5 12ca
12ce 12d1 12d2 12d7 12db 12df 12e2 12e5
12e9 12eb 12ef 12f3 12f6 12f9 12fd 12ff
1303 1307 130a 130c 1 1310 1314 1318
131b 131f 1323 1327 132b 132e 1332 1336
1339 133c 1341 1344 1347 134a 134b 1350
1351 1 1353 1358 135c 1360 1363 1368
136d 1370 1374 1375 137a 137d 1382 1383
1388 138b 1390 1391 1396 1399 139d 139e
13a3 13a6 13ab 13ac 13b1 13b4 13b8 13bc
13bf 13c2 13c3 13c5 13c6 13cb 13cc 13d1
13d3 13d7 13da 13dc 13e0 13e2 13ee 13f0
13f2 13f3 13f8 13fc 13fe 140a 140c 140e
1412 1416 1419 141b 141f 1423 1426 142a
142e 1432 1435 1436 1438 143b 143c 143e
1441 1444 1447 1448 144d 1450 1454 1458
145b 145c 145e 1461 1464 1465 146a 1
146d 1472 1476 147a 147e 1482 1486 1487
1489 148c 148d 148f 1492 1496 149a 149e
149f 14a1 14a4 14a5 14a7 14a8 14ad 14b0
14b3 14b6 14b7 14bc 14bf 14c2 14c6 14ca
14cd 14ce 14d0 14d1 14d6 14d7 14d9 14dd
14e1 14e4 14e7 14e8 14ed 14f0 14f4 14f7
14fa 14fd 14fe 1503 1504 1 1509 150e
1512 1516 151a 151e 1522 1526 152a 152e
1532 1536 153a 153e 1542 1546 1552 1556
155b 155f 1562 1563 1568 156c 1570 1573
1576 157a 157c 1580 1584 1587 158a 158e
1590 1594 1598 159b 159d 1 15a1 15a5
15a9 15ac 15b0 15b4 15b8 15bc 15bf 15c3
15c7 15ca 15cd 15d2 15d5 15d8 15db 15dc
15e1 15e2 1 15e4 15e9 15ed 15f1 15f4
15f9 15fe 1601 1605 1606 160b 160e 1613
1614 1619 161c 1621 1622 1627 162a 162e
162f 1634 1637 163c 163d 1642 1645 1649
164d 1650 1653 1654 1656 1657 165c 165d
1662 1664 1668 166b 166d 1671 1673 167f
1681 1683 1684 1689 168d 168f 169b 169d
169f 16a3 16a6 16a8 16ac 16b0 16b4 16b8
16bc 16c0 16c4 16c8 16d4 16d8 16dd 16e1
16e4 16e5 16ea 16ee 16f2 16f5 16f8 16fc
16fe 1702 1706 1709 170c 1710 1712 1716
171a 171d 171f 1 1723 1727 172b 172e
1732 1736 173a 173e 1741 1745 1749 174c
174f 1754 1757 175a 175d 175e 1763 1764
1 1766 176b 176f 1773 1776 177b 1780
1783 1787 1788 178d 1790 1795 1796 179b
179e 17a3 17a4 17a9 17ac 17b0 17b1 17b6
17b9 17be 17bf 17c4 17c7 17cb 17cf 17d2
17d5 17d6 17d8 17d9 17de 17df 17e4 17e6
17ea 17ed 17ef 17f3 17f5 1801 1803 1805
1806 180b 180f 1811 181d 181f 1821 1825
1829 182c 1830 1834 1837 183b 183e 1842
1845 1846 184b 184e 1852 1856 1859 185a
185c 185f 1862 1863 1868 1 186b 1870
1874 1878 187c 1880 1881 1883 1887 1889
188d 1890 1894 1898 189c 189d 189f 18a3
18a7 18ab 18ae 18b2 18b6 18b9 18bc 18c1
18c4 18c7 18ca 18cb 18d0 18d1 1 18d3
18d8 18dc 18e0 18e3 18e8 18ed 18f0 18f4
18f5 18fa 18fd 1902 1903 1908 190b 1910
1911 1916 1919 191d 1921 1925 1929 192c
192d 192f 1934 1935 1937 1938 193d 1940
1945 1946 194b 194e 1953 1954 1959 195c
1960 1961 1966 1969 196e 196f 1974 1975
197a 197c 1980 1983 1987 198b 198e 1992
1996 1999 199d 19a1 19a2 19a7 19a9 19ad
19b1 19b4 19b8 19bc 19bf 19c3 19c7 19ca
19cd 19d2 19d5 19d8 19db 19dc 19e1 19e2
1 19e4 19e9 19ed 19f1 19f4 19f9 19fe
1a01 1a05 1a06 1a0b 1a0c 1a11 1a15 1a19
1a1c 1a21 1a26 1a29 1a2d 1a31 1a34 1a35
1a3a 1a3d 1a42 1a43 1a48 1a4b 1a4f 1a53
1a56 1a57 1a5c 1a5d 1a62 1a64 1a68 1a6b
1a6f 1a73 1a77 1a7b 1a7f 1a83 1a87 1a8b
1a8f 1a9b 1aa0 1aa4 1aa8 1aac 1ab0 1ab2
1ab3 1ab8 1 1abc 1ac0 1ac4 1ac7 1acb
1acf 1ad3 1ad7 1ada 1ade 1ae2 1ae5 1ae8
1aed 1af0 1af3 1af6 1af7 1afc 1afd 1
1aff 1b04 1b08 1b0c 1b0f 1b14 1b19 1b1c
1b20 1b21 1b26 1b27 1b2c 1b30 1b34 1b37
1b3c 1b41 1b44 1b48 1b49 1b4e 1b51 1b56
1b57 1b5c 1b5f 1b63 1b67 1b6a 1b6d 1b6e
1b70 1b71 1b76 1b77 1b7c 1b7e 1b82 1b85
1b89 1b8d 1b91 1b95 1b99 1b9d 1ba1 1bad
1bb2 1bb6 1bba 1bbe 1bc2 1bc4 1bc8 1bca
1bd6 1bd8 1bda 1bdb 1be0 1be4 1be6 1bf2
1bf6 1bf8 1bf9 1c02 
7ec
2
0 1 a 6 c :3 6 11 :3 6
12 :2 6 1 3 a 13 a :2 1
4 18 21 20 :2 18 :2 4 11 1a
19 :2 11 :2 4 e 17 16 :2 e :2 4
:3 11 :2 4 f 18 17 :2 f :2 4 :2 e
1d e :2 4 :2 14 23 14 :2 4 :2 12
21 12 :2 4 :2 11 20 11 :2 4 :2 12
21 12 :2 4 :2 13 22 13 :2 4 :3 17
:2 4 e 17 :3 e 4 7 :2 11 23
:2 2d 3a :2 23 :3 7 :2 d 19 25 :2 2f
43 :2 25 5a 60 63 :2 5a 71 8d
8 :2 71 d 10 :2 71 16 19 :2 71
b e :2 71 13 16 1f 27 :2 1f
34 :2 16 :2 71 b e :2 71 13 16
:2 71 1b 1e :2 71 2a 2d :2 71 32
35 :2 71 :2 7 50 :2 4 7 :2 11 23
:2 2d 39 3c 52 54 55 :2 52 :2 23
:3 7 :2 d 12 1e 63 66 :2 1e :2 7
58 :3 4 11 :2 4 1b 4 e 1a
23 2d 38 46 53 c 1a 25
31 3f 4e c 23 37 :2 7 :2 10
1c 7 4 :2 c a :2 13 1f a
d :2 17 29 :2 33 3f 43 59 5b
5c :2 59 :2 29 :3 d :2 13 18 24 69
6c :2 24 79 7c :2 24 80 83 :2 24
8f 92 :2 24 9a 9d :2 24 a9 ac
b3 bc bf :2 ac :2 24 :2 d 5f :2 a
:2 7 :4 13 :2 7 4 :3 1 7 10 1b
:2 7 1e 20 :2 1e a 11 1d 20
:2 a 23 25 :2 23 14 29 2f 3c
13 27 d 14 10 1c :3 1a 10
:2 19 25 10 21 10 :2 19 25 10
:4 d a :2 12 10 :2 19 25 10 13
:2 1d 2f :2 39 45 49 5f 61 62
:2 5f :2 2f :3 13 :2 19 1e 2a 6f 72
:2 2a 7f 82 :2 2a 86 89 :2 2a 95
98 :2 2a a0 a3 :2 2a af b2 b9
c2 c5 :2 b2 :2 2a :2 13 65 :2 10 :2 d
:4 19 :2 d a :3 29 14 11 13 27
11 26 11 1b 24 d 14 10
1c :3 1a 10 :2 19 25 10 21 10
:2 19 25 10 :4 d a :2 12 10 :2 19
25 10 13 :2 1d 2f :2 39 45 49
5f 61 62 :2 5f :2 2f :3 13 :2 19 1e
2a 6f 72 :2 2a 7f 82 :2 2a 86
89 :2 2a 95 98 :2 2a a0 a3 :2 2a
af b2 b9 c2 c5 :2 b2 :2 2a :2 13
65 :2 10 :2 d :4 19 :2 d a :4 29 14
29 2f 3d 4e 13 27 d 14
10 1c :3 1a 10 :2 19 25 10 21
10 :2 19 25 10 :4 d a :2 12 10
:2 19 25 10 13 :2 1d 2f :2 39 45
49 5f 62 63 :2 5f :2 2f :3 13 :2 19
1e 2a 70 73 :2 2a 80 83 :2 2a
87 8a :2 2a 96 99 :2 2a a1 a4
:2 2a b0 b3 ba c3 c6 :2 b3 :2 2a
:2 13 66 :2 10 :2 d :4 19 :2 d a :7 7
11 1d 2b 34 3b 48 51 65
72 a 11 d 19 :3 17 d :2 16
22 d 1e d :2 16 22 d :4 a
7 :2 f d :2 16 22 d 10 :2 1a
2c :2 36 42 46 5c 5f 60 :2 5c
:2 2c :3 10 :2 16 1b 27 6d 70 :2 27
7d 80 :2 27 84 87 :2 27 93 96
:2 27 9e a1 :2 27 ad b0 b7 c0
c3 :2 b0 :2 27 :2 10 63 :2 d :2 a :4 16
:2 a 7 :4 22 a 13 1e :2 a 21
23 :2 21 14 29 40 58 13 27
d 14 10 1c :3 1a 10 :2 19 25
10 21 10 :2 19 25 10 :4 d a
:2 12 10 :2 19 25 10 13 :2 1d 2f
:2 39 45 49 5f 62 63 :2 5f :2 2f
:3 13 :2 19 1e 2a 70 73 :2 2a 80
83 :2 2a 87 8a :2 2a 96 99 :2 2a
a1 a4 :2 2a b0 b3 ba c3 c6
:2 b3 :2 2a :2 13 66 :2 10 :2 d :4 19 :2 d
a :3 25 14 20 2e 37 3e 4b
54 68 75 d 14 10 1c :3 1a
10 :2 19 25 10 21 10 :2 19 25
10 :4 d a :2 12 10 :2 19 25 10
13 :2 1d 2f :2 39 45 49 5f 62
63 :2 5f :2 2f :3 13 :2 19 1e 2a 70
73 :2 2a 80 83 :2 2a 87 8a :2 2a
96 99 :2 2a a1 a4 :2 2a b0 b3
ba c3 c6 :2 b3 :2 2a :2 13 66 :2 10
:2 d :4 19 :2 d a :4 25 d 14 20
23 :2 d 26 28 :2 26 17 2c 43
5b 10 16 23 16 2a 10 17
13 1f :3 1d 13 :2 1c 28 13 24
13 :2 1c 28 13 :4 10 d :2 15 13
:2 1c 28 13 16 :2 20 32 :2 3c 48
4c 62 65 66 :2 62 :2 32 :3 16 :2 1c
21 2d 73 76 :2 2d 83 86 :2 2d
8a 8d :2 2d 99 9c :2 2d a4 a7
:2 2d b3 b6 bd c6 c9 :2 b6 :2 2d
:2 16 69 :2 13 :2 10 :4 1c :2 10 d :3 2c
17 14 16 2a 14 29 14 1e
27 10 17 13 1f :3 1d 13 :2 1c
28 13 24 13 :2 1c 28 13 :4 10
d :2 15 13 :2 1c 28 13 16 :2 20
32 :2 3c 48 4c 62 65 66 :2 62
:2 32 :3 16 :2 1c 21 2d 73 76 :2 2d
83 86 :2 2d 8a 8d :2 2d 99 9c
:2 2d a4 a7 :2 2d b3 b6 bd c6
c9 :2 b6 :2 2d :2 16 69 :2 13 :2 10 :4 1c
:2 10 d :4 2c 17 2c 43 5b 10
16 24 35 16 2a 10 17 13
1f :3 1d 13 :2 1c 28 13 24 13
:2 1c 28 13 :4 10 d :2 15 13 :2 1c
28 13 16 :2 20 32 :2 3c 48 4c
62 65 66 :2 62 :2 32 :3 16 :2 1c 21
2d 73 76 :2 2d 83 86 :2 2d 8a
8d :2 2d 99 9c :2 2d a4 a7 :2 2d
b3 b6 bd c6 c9 :2 b6 :2 2d :2 16
69 :2 13 :2 10 :4 1c :2 10 d :7 a 14
20 2e 37 3e 4b 54 68 75
d 14 10 1c :3 1a 10 :2 19 25
10 21 10 :2 19 25 10 :4 d a
:2 12 10 :2 19 25 10 13 :2 1d 2f
:2 39 45 49 5f 62 63 :2 5f :2 2f
:3 13 :2 19 1e 2a 70 73 :2 2a 80
83 :2 2a 87 8a :2 2a 96 99 :2 2a
a1 a4 :2 2a b0 b3 ba c3 c6
:2 b3 :2 2a :2 13 66 :2 10 :2 d :4 19 :2 d
a :7 7 :4 4 9 10 19 24 :2 10
28 :2 9 8 2c 2e :2 2c 7 36
3f 4f :2 36 52 54 :2 52 35 :3 7
1d 25 2e 38 :2 2e 48 :2 25 4b
4d 28 32 :2 28 41 :2 4d :2 25 24
45 47 :2 24 23 51 53 28 38
:2 53 :2 23 :2 1d 7 b 1e 20 :2 1e
a 26 39 3b 3c :2 3b :2 39 :2 a
14 d 1b 24 2b 37 40 d
12 2c 39 12 13 27 d 14
10 1c :3 1a 10 :2 19 25 10 21
10 :2 19 25 10 :4 d a :2 12 10
:2 19 25 10 13 :2 1d 2f :2 39 45
49 5f 62 63 :2 5f :2 2f :3 13 :2 19
1e 2a 70 73 :2 2a 80 83 :2 2a
87 8a :2 2a 96 99 :2 2a a1 a4
:2 2a b0 b3 ba c3 c6 :2 b3 :2 2a
:2 13 66 :2 10 :2 d :4 19 :2 d a :4 3e
:2 7 57 11 a f 29 36 f
10 24 a 11 d 19 :3 17 d
:2 16 22 d 1e d :2 16 22 d
:4 a 7 :2 f d :2 16 22 d 10
:2 1a 2c :2 36 42 46 5c 5f 60
:2 5c :2 2c :3 10 :2 16 1b 27 6d 70
:2 27 7d 80 :2 27 84 87 :2 27 93
96 :2 27 9e a1 :2 27 ad b0 b7
c0 c3 :2 b0 :2 27 :2 10 63 :2 d :2 a
:4 16 :2 a 7 :7 4 8 :2 11 1c 1a
:2 25 :2 1a 7 3a 43 4e :2 3a 51
54 :2 51 39 :3 7 1a 2c 3a :2 1a
7 57 :3 4 17 21 :2 17 4 7
:2 11 23 :2 2d 39 3c 52 55 56
:2 52 :2 23 :3 7 :2 d 12 1e 64 67
:2 1e 74 77 :2 1e 7b 7e :2 1e 88
8b 94 9c :2 a5 :2 94 b0 :2 8b :2 1e
b8 bb :2 1e c3 c6 :2 1e cb ce
:2 1e d4 d7 :2 1e :2 7 59 :3 4 :2 f
21 :2 2a 34 3b :2 4 1 9 12
9 a :2 14 26 :2 30 3c 40 56
59 5a :2 56 :2 26 :3 a :2 10 15 21
67 6a :2 21 :3 a :2 10 15 39 5c
5f :2 68 :2 39 76 79 :2 39 81 84
:2 8d :2 39 :2 a 5d :3 7 c 15 1e
2c a 13 1e f e 7 e
7 e 7 29 :2 4 :2 9 7 :2 10
1c :2 7 :2 11 23 :2 2d 39 3d 53
56 57 :2 53 :2 23 :3 7 :2 d 12 1e
64 67 :2 1e :3 7 :2 d 12 36 42
45 :2 36 4d 50 :2 36 5c 5f 66
6f 72 :2 5f :2 36 :2 7 5a :2 4 7
c 1b a 13 1e f e 7
e 7 e 7 :2 4 :4 10 :2 4 :8 1

7ec
4
0 :2 1 :4 3 :4 4
:4 5 2 :4 6 :2 1
:7 8 :7 9 :7 a :5 b
:7 c :6 d :6 e :6 f
:6 10 :6 11 :6 12 :5 13
:7 15 :b 17 :11 18 19
:2 18 :2 19 :2 18 :2 19
:2 18 :2 1a :2 18 :9 1a
:2 18 :2 1b :2 18 :2 1b
:2 18 :2 1b :2 18 :2 1b
:2 18 :2 1b :4 18 :3 17
:11 1e :b 1f :3 1e :3 23
:3 24 :7 27 :6 28 :3 29
27 :5 2a 26 :2 2c
:5 2e :11 2f :24 30 :3 2f
:2 2d :6 2c 2b :3 16
:9 35 :a 36 :4 38 :2 39
38 :6 3a :5 3b 3a
:5 3d 3c :3 3a 37
:2 40 :5 42 :11 43 :24 44
:3 43 :2 41 :6 40 3f
:3 36 4a 4b :2 4c
:2 4d :3 4e 4a :6 4f
:5 50 4f :5 52 51
:3 4f 49 :2 55 :5 57
:11 58 :24 59 :3 58 :2 56
:6 55 54 :4 36 :5 5f
:2 60 5f :6 61 :5 62
61 :5 64 63 :3 61
5e :2 67 :5 69 :11 6a
:24 6b :3 6a :2 68 :6 67
66 :4 5d :3 36 :a 72
:6 73 :5 74 73 :5 76
75 :3 73 71 :2 79
:5 7b :11 7c :24 7d :3 7c
:2 7a :6 79 78 :4 35
:9 82 :4 84 :2 85 84
:6 86 :5 87 86 :5 89
88 :3 86 83 :2 8c
:5 8e :11 8f :24 90 :3 8f
:2 8d :6 8c 8b :3 82
:a 96 :6 97 :5 98 97
:5 9a 99 :3 97 95
:2 9d :5 9f :11 a0 :24 a1
:3 a0 :2 9e :6 9d 9c
:4 82 :a a6 :4 a8 :3 a9
:2 aa a8 :6 ab :5 ac
ab :5 ae ad :3 ab
a7 :2 b1 :5 b3 :11 b4
:24 b5 :3 b4 :2 b2 :6 b1
b0 :3 a6 bb bc
:2 bd :2 be :3 bf bb
:6 c0 :5 c1 c0 :5 c3
c2 :3 c0 ba :2 c6
:5 c8 :11 c9 :24 ca :3 c9
:2 c7 :6 c6 c5 :4 a6
:4 d0 :4 d1 :2 d2 d0
:6 d3 :5 d4 d3 :5 d6
d5 :3 d3 cf :2 d9
:5 db :11 dc :24 dd :3 dc
:2 da :6 d9 d8 :4 ce
:3 a6 :a e4 :6 e5 :5 e6
e5 :5 e8 e7 :3 e5
e3 :2 eb :5 ed :11 ee
:24 ef :3 ee :2 ec :6 eb
ea :4 a5 :3 82 81
:3 35 :1b f6 :c f7 :5 f8
:5 f7 :2 f8 :3 f7 :2 f8
:2 f9 :2 f8 :5 f7 :10 fa
fc :6 fd fe :3 ff
100 :2 102 fc :6 103
:5 104 103 :5 106 105
:3 103 fb :2 109 :5 10b
:11 10c :24 10d :3 10c :2 10a
:6 109 108 :6 fa f6
114 115 :3 116 117
:2 119 114 :6 11a :5 11b
11a :5 11d 11c :3 11a
113 :2 120 :5 122 :11 123
:24 124 :3 123 :2 121 :6 120
11f :4 112 :3 f6 :16 12a
:7 12c :3 12a :6 12f :11 132
:30 133 :3 132 :a 135 16
:3 138 :11 139 :b 13a :17 13b
:3 139 :2 13d :3 13e :3 13f
140 13e 13d 13e
:3 141 :3 138 :2 142 :5 144
:11 145 :b 146 :18 147 :3 145
:2 149 14a :3 14b 14c
14a 149 14a :3 14d
:2 143 :6 142 137 :7 1

1c04
4
:3 0 1 :3 0 2
:a 0 7e7 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
:2 0 7 6 :3 0
5 :7 0 9 8
:3 0 4 :3 0 7
:7 0 d c :3 0
8 :3 0 9 :3 0
a :2 0 4 11
12 0 f 13
0 7e7 2 14
:2 0 c :2 0 f
4 :3 0 c :2 0
d 17 19 :6 0
1c 1a 0 7e5
0 b :6 0 c
:2 0 13 4 :3 0
11 1e 20 :6 0
23 21 0 7e5
0 d :6 0 19
c7 0 17 4
:3 0 15 25 27
:6 0 2a 28 0
7e5 0 e :6 0
14 :2 0 1d 10
:3 0 2c :7 0 2f
2d 0 7e5 0
f :6 0 4 :3 0
12 :2 0 1b 31
33 :6 0 36 34
0 7e5 0 11
:6 0 14 :2 0 1f
6 :3 0 38 :7 0
3c 39 3a 7e5
0 13 :6 0 14
:2 0 21 6 :3 0
3e :7 0 42 3f
40 7e5 0 15
:6 0 14 :2 0 23
6 :3 0 44 :7 0
48 45 46 7e5
0 16 :6 0 14
:2 0 25 6 :3 0
4a :7 0 4e 4b
4c 7e5 0 17
:6 0 14 :2 0 27
6 :3 0 50 :7 0
54 51 52 7e5
0 18 :6 0 2b
1a7 0 29 6
:3 0 56 :7 0 5a
57 58 7e5 0
19 :6 0 67 68
0 2d 6 :3 0
5c :7 0 5f 5d
0 7e5 0 1a
:6 0 9 :3 0 a
:2 0 4 61 62
0 63 :7 0 66
64 0 7e5 0
1b :6 0 1c :3 0
1d :3 0 1c :3 0
1e :3 0 6a 6b
0 2 :4 0 2f
6c 6e 69 70
6f :2 0 1f :3 0
20 :3 0 72 73
0 21 :4 0 1c
:3 0 22 :3 0 76
77 0 2 :4 0
31 78 7a 23
:4 0 24 :2 0 25
:3 0 33 7d 7f
:3 0 26 :4 0 24
:2 0 27 :4 0 36
82 84 :3 0 24
:2 0 3 :3 0 39
86 88 :3 0 24
:2 0 27 :4 0 3c
8a 8c :3 0 24
:2 0 28 :4 0 3f
8e 90 :3 0 24
:2 0 29 :3 0 2a
:3 0 5 :3 0 42
94 96 2b :4 0
44 93 99 47
92 9b :3 0 24
:2 0 28 :4 0 4a
9d 9f :3 0 24
:2 0 27 :4 0 4d
a1 a3 :3 0 24
:2 0 7 :3 0 50
a5 a7 :3 0 24
:2 0 27 :4 0 53
a9 ab :3 0 24
:2 0 2c :4 0 56
ad af :3 0 59
74 b1 :2 0 b3
5e b4 71 b3
0 b5 60 0
745 1c :3 0 1d
:3 0 b6 b7 0
1c :3 0 2d :3 0
b9 ba 0 12
:2 0 2 :4 0 2e
:2 0 2f :2 0 12
:2 0 62 bf c1
:3 0 65 bb c3
b8 c5 c4 :2 0
1f :3 0 30 :3 0
c7 c8 0 21
:4 0 31 :4 0 24
:2 0 25 :3 0 69
cc ce :3 0 6c
c9 d0 :2 0 d2
6f d3 c6 d2
0 d4 71 0
745 13 :3 0 5
:3 0 d5 d6 0
745 b :3 0 3
:3 0 d8 d9 0
745 32 :3 0 33
:3 0 34 :3 0 35
:3 0 36 :3 0 37
:3 0 38 :3 0 d
:3 0 e :3 0 11
:3 0 17 :3 0 18
:3 0 19 :3 0 39
:3 0 3a :3 0 b
:4 0 3b 1 :8 0
f1 9 :3 0 3c
:3 0 ec ed 0
3d :3 0 ee ef
0 f1 73 13b
3e :3 0 9 :3 0
3c :3 0 f4 f5
0 3d :3 0 f6
f7 0 131 1c
:3 0 1d :3 0 f9
fa 0 1c :3 0
2d :3 0 fc fd
0 3f :2 0 2
:4 0 40 :2 0 2f
:2 0 12 :2 0 76
102 104 :3 0 79
fe 106 fb 108
107 :2 0 1f :3 0
30 :3 0 10a 10b
0 21 :4 0 41
:4 0 24 :2 0 25
:3 0 7d 10f 111
:3 0 24 :2 0 42
:4 0 80 113 115
:3 0 24 :2 0 43
:4 0 83 117 119
:3 0 24 :2 0 3d
:3 0 86 11b 11d
:3 0 24 :2 0 44
:4 0 89 11f 121
:3 0 24 :2 0 45
:3 0 46 :3 0 12
:2 0 47 :2 0 8c
124 128 90 123
12a :3 0 93 10c
12c :2 0 12e 96
12f 109 12e 0
130 98 0 131
9a 134 :3 0 134
0 134 133 131
132 :6 0 136 2
:3 0 9d 138 9f
137 136 :2 0 139
a1 :2 0 13b 0
13b 13a f1 139
:6 0 745 1 :3 0
29 :3 0 13 :3 0
14 :2 0 a3 13d
140 48 :2 0 12
:2 0 a8 142 144
:3 0 45 :3 0 11
:3 0 12 :2 0 12
:2 0 ab 146 14a
48 :2 0 49 :4 0
b1 14c 14e :3 0
39 :3 0 4a :3 0
35 :3 0 37 :3 0
3a :3 0 b :4 0
4b 1 :8 0 16c
4c :4 0 157 :3 0
4d :3 0 48 :2 0
b6 15a 15b :3 0
9 :3 0 3c :3 0
15d 15e 0 14
:2 0 15f 160 0
162 b9 169 9
:3 0 3c :3 0 163
164 0 4e :2 0
165 166 0 168
bb 16a 15c 162
0 16b 0 168
0 16b bd 0
16c c0 1b6 3e
:3 0 9 :3 0 3c
:3 0 16f 170 0
3d :3 0 171 172
0 1ac 1c :3 0
1d :3 0 174 175
0 1c :3 0 2d
:3 0 177 178 0
3f :2 0 2 :4 0
4f :2 0 2f :2 0
12 :2 0 c3 17d
17f :3 0 c6 179
181 176 183 182
:2 0 1f :3 0 30
:3 0 185 186 0
21 :4 0 50 :4 0
24 :2 0 25 :3 0
ca 18a 18c :3 0
24 :2 0 42 :4 0
cd 18e 190 :3 0
24 :2 0 43 :4 0
d0 192 194 :3 0
24 :2 0 3d :3 0
d3 196 198 :3 0
24 :2 0 44 :4 0
d6 19a 19c :3 0
24 :2 0 45 :3 0
46 :3 0 12 :2 0
47 :2 0 d9 19f
1a3 dd 19e 1a5
:3 0 e0 187 1a7
:2 0 1a9 e3 1aa
184 1a9 0 1ab
e5 0 1ac e7
1af :3 0 1af 0
1af 1ae 1ac 1ad
:6 0 1b1 4 :3 0
ea 1b3 ec 1b2
1b1 :2 0 1b4 ee
:2 0 1b6 0 1b6
1b5 16c 1b4 :6 0
223 1 :3 0 51
:3 0 52 :3 0 3a
:3 0 b :3 0 3a
:3 0 53 :3 0 54
:3 0 55 :3 0 56
:4 0 57 1 :8 0
1d7 4c :4 0 1c2
:3 0 4d :3 0 48
:2 0 f2 1c5 1c6
:3 0 9 :3 0 3c
:3 0 1c8 1c9 0
14 :2 0 1ca 1cb
0 1cd f5 1d4
9 :3 0 3c :3 0
1ce 1cf 0 4e
:2 0 1d0 1d1 0
1d3 f7 1d5 1c7
1cd 0 1d6 0
1d3 0 1d6 f9
0 1d7 fc 221
3e :3 0 9 :3 0
3c :3 0 1da 1db
0 3d :3 0 1dc
1dd 0 217 1c
:3 0 1d :3 0 1df
1e0 0 1c :3 0
2d :3 0 1e2 1e3
0 3f :2 0 2
:4 0 58 :2 0 2f
:2 0 12 :2 0 ff
1e8 1ea :3 0 102
1e4 1ec 1e1 1ee
1ed :2 0 1f :3 0
30 :3 0 1f0 1f1
0 21 :4 0 59
:4 0 24 :2 0 25
:3 0 106 1f5 1f7
:3 0 24 :2 0 42
:4 0 109 1f9 1fb
:3 0 24 :2 0 43
:4 0 10c 1fd 1ff
:3 0 24 :2 0 3d
:3 0 10f 201 203
:3 0 24 :2 0 44
:4 0 112 205 207
:3 0 24 :2 0 45
:3 0 46 :3 0 12
:2 0 47 :2 0 115
20a 20e 119 209
210 :3 0 11c 1f2
212 :2 0 214 11f
215 1ef 214 0
216 121 0 217
123 21a :3 0 21a
0 21a 219 217
218 :6 0 21c 6
:3 0 126 21e 128
21d 21c :2 0 21f
12a :2 0 221 0
221 220 1d7 21f
:6 0 223 1 :3 0
12c 28e 39 :3 0
4a :3 0 36 :3 0
37 :3 0 38 :3 0
3a :3 0 b :4 0
5a 1 :8 0 241
4c :4 0 22c :3 0
4d :3 0 48 :2 0
131 22f 230 :3 0
9 :3 0 3c :3 0
232 233 0 14
:2 0 234 235 0
237 134 23e 9
:3 0 3c :3 0 238
239 0 4e :2 0
23a 23b 0 23d
136 23f 231 237
0 240 0 23d
0 240 138 0
241 13b 28b 3e
:3 0 9 :3 0 3c
:3 0 244 245 0
3d :3 0 246 247
0 281 1c :3 0
1d :3 0 249 24a
0 1c :3 0 2d
:3 0 24c 24d 0
3f :2 0 2 :4 0
5b :2 0 2f :2 0
12 :2 0 13e 252
254 :3 0 141 24e
256 24b 258 257
:2 0 1f :3 0 30
:3 0 25a 25b 0
21 :4 0 5c :4 0
24 :2 0 25 :3 0
145 25f 261 :3 0
24 :2 0 42 :4 0
148 263 265 :3 0
24 :2 0 43 :4 0
14b 267 269 :3 0
24 :2 0 3d :3 0
14e 26b 26d :3 0
24 :2 0 44 :4 0
151 26f 271 :3 0
24 :2 0 45 :3 0
46 :3 0 12 :2 0
47 :2 0 154 274
278 158 273 27a
:3 0 15b 25c 27c
:2 0 27e 15e 27f
259 27e 0 280
160 0 281 162
284 :3 0 284 0
284 283 281 282
:6 0 286 8 :3 0
165 288 167 287
286 :2 0 289 169
:2 0 28b 0 28b
28a 241 289 :6 0
28d 1 :3 0 16b
28f 14f 223 0
290 0 28d 0
290 16d 0 2fc
5d :3 0 5e :3 0
5f :3 0 60 :3 0
5e :3 0 55 :3 0
61 :3 0 53 :3 0
e :4 0 62 1
:8 0 2b0 4c :4 0
29b :3 0 4d :3 0
48 :2 0 172 29e
29f :3 0 9 :3 0
3c :3 0 2a1 2a2
0 14 :2 0 2a3
2a4 0 2a6 175
2ad 9 :3 0 3c
:3 0 2a7 2a8 0
4e :2 0 2a9 2aa
0 2ac 177 2ae
2a0 2a6 0 2af
0 2ac 0 2af
179 0 2b0 17c
2fa 3e :3 0 9
:3 0 3c :3 0 2b3
2b4 0 3d :3 0
2b5 2b6 0 2f0
1c :3 0 1d :3 0
2b8 2b9 0 1c
:3 0 2d :3 0 2bb
2bc 0 3f :2 0
2 :4 0 63 :2 0
2f :2 0 12 :2 0
17f 2c1 2c3 :3 0
182 2bd 2c5 2ba
2c7 2c6 :2 0 1f
:3 0 30 :3 0 2c9
2ca 0 21 :4 0
64 :4 0 24 :2 0
25 :3 0 186 2ce
2d0 :3 0 24 :2 0
42 :4 0 189 2d2
2d4 :3 0 24 :2 0
43 :4 0 18c 2d6
2d8 :3 0 24 :2 0
3d :3 0 18f 2da
2dc :3 0 24 :2 0
44 :4 0 192 2de
2e0 :3 0 24 :2 0
45 :3 0 46 :3 0
12 :2 0 47 :2 0
195 2e3 2e7 199
2e2 2e9 :3 0 19c
2cb 2eb :2 0 2ed
19f 2ee 2c8 2ed
0 2ef 1a1 0
2f0 1a3 2f3 :3 0
2f3 0 2f3 2f2
2f0 2f1 :6 0 2f5
a :3 0 1a6 2f7
1a8 2f6 2f5 :2 0
2f8 1aa :2 0 2fa
0 2fa 2f9 2b0
2f8 :6 0 2fc 1
:3 0 1ac 59b 29
:3 0 13 :3 0 14
:2 0 1af 2fd 300
48 :2 0 49 :2 0
1b4 302 304 :3 0
39 :3 0 65 :3 0
66 :3 0 67 :3 0
3a :3 0 b :4 0
68 1 :8 0 322
4c :4 0 30d :3 0
4d :3 0 48 :2 0
1b9 310 311 :3 0
9 :3 0 3c :3 0
313 314 0 14
:2 0 315 316 0
318 1bc 31f 9
:3 0 3c :3 0 319
31a 0 4e :2 0
31b 31c 0 31e
1be 320 312 318
0 321 0 31e
0 321 1c0 0
322 1c3 36c 3e
:3 0 9 :3 0 3c
:3 0 325 326 0
3d :3 0 327 328
0 362 1c :3 0
1d :3 0 32a 32b
0 1c :3 0 2d
:3 0 32d 32e 0
3f :2 0 2 :4 0
69 :2 0 2f :2 0
12 :2 0 1c6 333
335 :3 0 1c9 32f
337 32c 339 338
:2 0 1f :3 0 30
:3 0 33b 33c 0
21 :4 0 6a :4 0
24 :2 0 25 :3 0
1cd 340 342 :3 0
24 :2 0 42 :4 0
1d0 344 346 :3 0
24 :2 0 43 :4 0
1d3 348 34a :3 0
24 :2 0 3d :3 0
1d6 34c 34e :3 0
24 :2 0 44 :4 0
1d9 350 352 :3 0
24 :2 0 45 :3 0
46 :3 0 12 :2 0
47 :2 0 1dc 355
359 1e0 354 35b
:3 0 1e3 33d 35d
:2 0 35f 1e6 360
33a 35f 0 361
1e8 0 362 1ea
365 :3 0 365 0
365 364 362 363
:6 0 367 c :3 0
1ed 369 1ef 368
367 :2 0 36a 1f1
:2 0 36c 0 36c
36b 322 36a :6 0
3d9 1 :3 0 5d
:3 0 5e :3 0 5f
:3 0 60 :3 0 5e
:3 0 55 :3 0 61
:3 0 53 :3 0 e
:4 0 62 1 :8 0
38d 4c :4 0 378
:3 0 4d :3 0 48
:2 0 1f5 37b 37c
:3 0 9 :3 0 3c
:3 0 37e 37f 0
14 :2 0 380 381
0 383 1f8 38a
9 :3 0 3c :3 0
384 385 0 4e
:2 0 386 387 0
389 1fa 38b 37d
383 0 38c 0
389 0 38c 1fc
0 38d 1ff 3d7
3e :3 0 9 :3 0
3c :3 0 390 391
0 3d :3 0 392
393 0 3cd 1c
:3 0 1d :3 0 395
396 0 1c :3 0
2d :3 0 398 399
0 3f :2 0 2
:4 0 6b :2 0 2f
:2 0 12 :2 0 202
39e 3a0 :3 0 205
39a 3a2 397 3a4
3a3 :2 0 1f :3 0
30 :3 0 3a6 3a7
0 21 :4 0 6c
:4 0 24 :2 0 25
:3 0 209 3ab 3ad
:3 0 24 :2 0 42
:4 0 20c 3af 3b1
:3 0 24 :2 0 43
:4 0 20f 3b3 3b5
:3 0 24 :2 0 3d
:3 0 212 3b7 3b9
:3 0 24 :2 0 44
:4 0 215 3bb 3bd
:3 0 24 :2 0 45
:3 0 46 :3 0 12
:2 0 47 :2 0 218
3c0 3c4 21c 3bf
3c6 :3 0 21f 3a8
3c8 :2 0 3ca 222
3cb 3a5 3ca 0
3cc 224 0 3cd
226 3d0 :3 0 3d0
0 3d0 3cf 3cd
3ce :6 0 3d2 e
:3 0 229 3d4 22b
3d3 3d2 :2 0 3d5
22d :2 0 3d7 0
3d7 3d6 38d 3d5
:6 0 3d9 1 :3 0
22f 597 45 :3 0
11 :3 0 12 :2 0
12 :2 0 232 3da
3de 48 :2 0 49
:4 0 238 3e0 3e2
:3 0 39 :3 0 65
:3 0 66 :3 0 67
:3 0 4a :3 0 35
:3 0 37 :3 0 3a
:3 0 b :4 0 6d
1 :8 0 403 4c
:4 0 3ee :3 0 4d
:3 0 48 :2 0 23d
3f1 3f2 :3 0 9
:3 0 3c :3 0 3f4
3f5 0 14 :2 0
3f6 3f7 0 3f9
240 400 9 :3 0
3c :3 0 3fa 3fb
0 4e :2 0 3fc
3fd 0 3ff 242
401 3f3 3f9 0
402 0 3ff 0
402 244 0 403
247 44d 3e :3 0
9 :3 0 3c :3 0
406 407 0 3d
:3 0 408 409 0
443 1c :3 0 1d
:3 0 40b 40c 0
1c :3 0 2d :3 0
40e 40f 0 3f
:2 0 2 :4 0 6e
:2 0 2f :2 0 12
:2 0 24a 414 416
:3 0 24d 410 418
40d 41a 419 :2 0
1f :3 0 30 :3 0
41c 41d 0 21
:4 0 6f :4 0 24
:2 0 25 :3 0 251
421 423 :3 0 24
:2 0 42 :4 0 254
425 427 :3 0 24
:2 0 43 :4 0 257
429 42b :3 0 24
:2 0 3d :3 0 25a
42d 42f :3 0 24
:2 0 44 :4 0 25d
431 433 :3 0 24
:2 0 45 :3 0 46
:3 0 12 :2 0 47
:2 0 260 436 43a
264 435 43c :3 0
267 41e 43e :2 0
440 26a 441 41b
440 0 442 26c
0 443 26e 446
:3 0 446 0 446
445 443 444 :6 0
448 10 :3 0 271
44a 273 449 448
:2 0 44b 275 :2 0
44d 0 44d 44c
403 44b :6 0 4ba
1 :3 0 51 :3 0
52 :3 0 3a :3 0
b :3 0 3a :3 0
53 :3 0 54 :3 0
55 :3 0 56 :4 0
70 1 :8 0 46e
4c :4 0 459 :3 0
4d :3 0 48 :2 0
279 45c 45d :3 0
9 :3 0 3c :3 0
45f 460 0 14
:2 0 461 462 0
464 27c 46b 9
:3 0 3c :3 0 465
466 0 4e :2 0
467 468 0 46a
27e 46c 45e 464
0 46d 0 46a
0 46d 280 0
46e 283 4b8 3e
:3 0 9 :3 0 3c
:3 0 471 472 0
3d :3 0 473 474
0 4ae 1c :3 0
1d :3 0 476 477
0 1c :3 0 2d
:3 0 479 47a 0
3f :2 0 2 :4 0
71 :2 0 2f :2 0
12 :2 0 286 47f
481 :3 0 289 47b
483 478 485 484
:2 0 1f :3 0 30
:3 0 487 488 0
21 :4 0 72 :4 0
24 :2 0 25 :3 0
28d 48c 48e :3 0
24 :2 0 42 :4 0
290 490 492 :3 0
24 :2 0 43 :4 0
293 494 496 :3 0
24 :2 0 3d :3 0
296 498 49a :3 0
24 :2 0 44 :4 0
299 49c 49e :3 0
24 :2 0 45 :3 0
46 :3 0 12 :2 0
47 :2 0 29c 4a1
4a5 2a0 4a0 4a7
:3 0 2a3 489 4a9
:2 0 4ab 2a6 4ac
486 4ab 0 4ad
2a8 0 4ae 2aa
4b1 :3 0 4b1 0
4b1 4b0 4ae 4af
:6 0 4b3 12 :3 0
2ad 4b5 2af 4b4
4b3 :2 0 4b6 2b1
:2 0 4b8 0 4b8
4b7 46e 4b6 :6 0
4ba 1 :3 0 2b3
528 39 :3 0 65
:3 0 66 :3 0 67
:3 0 4a :3 0 36
:3 0 37 :3 0 38
:3 0 3a :3 0 b
:4 0 73 1 :8 0
4db 4c :4 0 4c6
:3 0 4d :3 0 48
:2 0 2b8 4c9 4ca
:3 0 9 :3 0 3c
:3 0 4cc 4cd 0
14 :2 0 4ce 4cf
0 4d1 2bb 4d8
9 :3 0 3c :3 0
4d2 4d3 0 4e
:2 0 4d4 4d5 0
4d7 2bd 4d9 4cb
4d1 0 4da 0
4d7 0 4da 2bf
0 4db 2c2 525
3e :3 0 9 :3 0
3c :3 0 4de 4df
0 3d :3 0 4e0
4e1 0 51b 1c
:3 0 1d :3 0 4e3
4e4 0 1c :3 0
2d :3 0 4e6 4e7
0 3f :2 0 2
:4 0 74 :2 0 2f
:2 0 12 :2 0 2c5
4ec 4ee :3 0 2c8
4e8 4f0 4e5 4f2
4f1 :2 0 1f :3 0
30 :3 0 4f4 4f5
0 21 :4 0 75
:4 0 24 :2 0 25
:3 0 2cc 4f9 4fb
:3 0 24 :2 0 42
:4 0 2cf 4fd 4ff
:3 0 24 :2 0 43
:4 0 2d2 501 503
:3 0 24 :2 0 3d
:3 0 2d5 505 507
:3 0 24 :2 0 44
:4 0 2d8 509 50b
:3 0 24 :2 0 45
:3 0 46 :3 0 12
:2 0 47 :2 0 2db
50e 512 2df 50d
514 :3 0 2e2 4f6
516 :2 0 518 2e5
519 4f3 518 0
51a 2e7 0 51b
2e9 51e :3 0 51e
0 51e 51d 51b
51c :6 0 520 14
:3 0 2ec 522 2ee
521 520 :2 0 523
2f0 :2 0 525 0
525 524 4db 523
:6 0 527 1 :3 0
2f2 529 3e3 4ba
0 52a 0 527
0 52a 2f4 0
596 5d :3 0 5e
:3 0 5f :3 0 60
:3 0 5e :3 0 55
:3 0 61 :3 0 53
:3 0 e :4 0 62
1 :8 0 54a 4c
:4 0 535 :3 0 4d
:3 0 48 :2 0 2f9
538 539 :3 0 9
:3 0 3c :3 0 53b
53c 0 14 :2 0
53d 53e 0 540
2fc 547 9 :3 0
3c :3 0 541 542
0 4e :2 0 543
544 0 546 2fe
548 53a 540 0
549 0 546 0
549 300 0 54a
303 594 3e :3 0
9 :3 0 3c :3 0
54d 54e 0 3d
:3 0 54f 550 0
58a 1c :3 0 1d
:3 0 552 553 0
1c :3 0 2d :3 0
555 556 0 3f
:2 0 2 :4 0 76
:2 0 2f :2 0 12
:2 0 306 55b 55d
:3 0 309 557 55f
554 561 560 :2 0
1f :3 0 30 :3 0
563 564 0 21
:4 0 77 :4 0 24
:2 0 25 :3 0 30d
568 56a :3 0 24
:2 0 42 :4 0 310
56c 56e :3 0 24
:2 0 43 :4 0 313
570 572 :3 0 24
:2 0 3d :3 0 316
574 576 :3 0 24
:2 0 44 :4 0 319
578 57a :3 0 24
:2 0 45 :3 0 46
:3 0 12 :2 0 47
:2 0 31c 57d 581
320 57c 583 :3 0
323 565 585 :2 0
587 326 588 562
587 0 589 328
0 58a 32a 58d
:3 0 58d 0 58d
58c 58a 58b :6 0
58f 16 :3 0 32d
591 32f 590 58f
:2 0 592 331 :2 0
594 0 594 593
54a 592 :6 0 596
1 :3 0 333 598
305 3d9 0 599
0 596 0 599
336 0 59a 339
59c 145 2fc 0
59d 0 59a 0
59d 33b 0 745
78 :3 0 29 :3 0
13 :3 0 14 :2 0
33e 59f 5a2 12
:2 0 341 59e 5a5
5a6 :2 0 48 :2 0
12 :2 0 346 5a8
5aa :3 0 5ab :2 0
29 :3 0 19 :3 0
14 :2 0 349 5ad
5b0 79 :2 0 14
:2 0 34e 5b2 5b4
:3 0 5b5 :2 0 5ac
5b7 5b6 :2 0 1a
:3 0 7a :3 0 29
:3 0 7b :3 0 18
:3 0 351 5bc 5be
14 :2 0 353 5bb
5c1 7c :2 0 29
:3 0 7b :3 0 17
:3 0 356 5c5 5c7
14 :2 0 358 5c4
5ca 35b 5c3 5cc
:3 0 5cd :2 0 7d
:2 0 7e :2 0 35e
5cf 5d1 :3 0 5d2
:2 0 7f :2 0 29
:3 0 19 :3 0 14
:2 0 361 5d5 5d8
364 5d4 5da :3 0
367 5ba 5dc 5b9
5dd 0 662 1a
:3 0 79 :2 0 12
:2 0 36b 5e0 5e2
:3 0 5e3 :2 0 1a
:3 0 80 :2 0 7f
:2 0 12 :2 0 36e
5e7 5e9 :3 0 372
5e6 5eb :3 0 5e4
5ed 5ec :2 0 39
:3 0 5e :3 0 5f
:3 0 60 :3 0 5e
:3 0 55 :3 0 81
:3 0 82 :3 0 82
:3 0 4a :3 0 83
:3 0 82 :3 0 3a
:3 0 b :4 0 84
1 :8 0 613 4c
:4 0 5fe :3 0 4d
:3 0 48 :2 0 377
601 602 :3 0 9
:3 0 3c :3 0 604
605 0 14 :2 0
606 607 0 609
37a 610 9 :3 0
3c :3 0 60a 60b
0 4e :2 0 60c
60d 0 60f 37c
611 603 609 0
612 0 60f 0
612 37e 0 613
381 65d 3e :3 0
9 :3 0 3c :3 0
616 617 0 3d
:3 0 618 619 0
653 1c :3 0 1d
:3 0 61b 61c 0
1c :3 0 2d :3 0
61e 61f 0 3f
:2 0 2 :4 0 85
:2 0 2f :2 0 12
:2 0 384 624 626
:3 0 387 620 628
61d 62a 629 :2 0
1f :3 0 30 :3 0
62c 62d 0 21
:4 0 86 :4 0 24
:2 0 25 :3 0 38b
631 633 :3 0 24
:2 0 42 :4 0 38e
635 637 :3 0 24
:2 0 43 :4 0 391
639 63b :3 0 24
:2 0 3d :3 0 394
63d 63f :3 0 24
:2 0 44 :4 0 397
641 643 :3 0 24
:2 0 45 :3 0 46
:3 0 12 :2 0 47
:2 0 39a 646 64a
39e 645 64c :3 0
3a1 62e 64e :2 0
650 3a4 651 62b
650 0 652 3a6
0 653 3a8 656
:3 0 656 0 656
655 653 654 :6 0
658 18 :3 0 3ab
65a 3ad 659 658
:2 0 65b 3af :2 0
65d 0 65d 65c
613 65b :6 0 65f
1 :3 0 3b1 660
5ee 65f 0 661
3b3 0 662 3b5
6ce 39 :3 0 82
:3 0 82 :3 0 4a
:3 0 83 :3 0 82
:3 0 3a :3 0 b
:4 0 87 1 :8 0
681 4c :4 0 66c
:3 0 4d :3 0 48
:2 0 3ba 66f 670
:3 0 9 :3 0 3c
:3 0 672 673 0
14 :2 0 674 675
0 677 3bd 67e
9 :3 0 3c :3 0
678 679 0 4e
:2 0 67a 67b 0
67d 3bf 67f 671
677 0 680 0
67d 0 680 3c1
0 681 3c4 6cb
3e :3 0 9 :3 0
3c :3 0 684 685
0 3d :3 0 686
687 0 6c1 1c
:3 0 1d :3 0 689
68a 0 1c :3 0
2d :3 0 68c 68d
0 3f :2 0 2
:4 0 88 :2 0 2f
:2 0 12 :2 0 3c7
692 694 :3 0 3ca
68e 696 68b 698
697 :2 0 1f :3 0
30 :3 0 69a 69b
0 21 :4 0 89
:4 0 24 :2 0 25
:3 0 3ce 69f 6a1
:3 0 24 :2 0 42
:4 0 3d1 6a3 6a5
:3 0 24 :2 0 43
:4 0 3d4 6a7 6a9
:3 0 24 :2 0 3d
:3 0 3d7 6ab 6ad
:3 0 24 :2 0 44
:4 0 3da 6af 6b1
:3 0 24 :2 0 45
:3 0 46 :3 0 12
:2 0 47 :2 0 3dd
6b4 6b8 3e1 6b3
6ba :3 0 3e4 69c
6bc :2 0 6be 3e7
6bf 699 6be 0
6c0 3e9 0 6c1
3eb 6c4 :3 0 6c4
0 6c4 6c3 6c1
6c2 :6 0 6c6 1a
:3 0 3ee 6c8 3f0
6c7 6c6 :2 0 6c9
3f2 :2 0 6cb 0
6cb 6ca 681 6c9
:6 0 6cd 1 :3 0
3f4 6cf 5b8 662
0 6d0 0 6cd
0 6d0 3f6 0
745 9 :3 0 3c
:3 0 6d1 6d2 0
9 :3 0 48 :2 0
8a :3 0 6d4 6d6
0 3fb 6d5 6d8
:3 0 6d9 :2 0 29
:3 0 13 :3 0 14
:2 0 3fe 6db 6de
8b :2 0 49 :2 0
403 6e0 6e2 :3 0
6e3 :2 0 6da 6e5
6e4 :2 0 15 :3 0
8c :3 0 d :3 0
b :3 0 406 6e8
6eb 6e7 6ec 0
6ee 409 6ef 6e6
6ee 0 6f0 40b
0 745 15 :3 0
8d :3 0 d :3 0
40d 6f2 6f4 6f1
6f5 0 745 1c
:3 0 1d :3 0 6f7
6f8 0 1c :3 0
2d :3 0 6fa 6fb
0 8e :2 0 2
:4 0 8f :2 0 2f
:2 0 12 :2 0 40f
700 702 :3 0 412
6fc 704 6f9 706
705 :2 0 1f :3 0
30 :3 0 708 709
0 21 :4 0 90
:4 0 24 :2 0 25
:3 0 416 70d 70f
:3 0 24 :2 0 42
:4 0 419 711 713
:3 0 24 :2 0 91
:4 0 41c 715 717
:3 0 24 :2 0 29
:3 0 2a :3 0 9
:3 0 3c :3 0 71c
71d 0 41f 71b
71f 2b :4 0 421
71a 722 424 719
724 :3 0 24 :2 0
92 :4 0 427 726
728 :3 0 24 :2 0
27 :4 0 42a 72a
72c :3 0 24 :2 0
3 :3 0 42d 72e
730 :3 0 24 :2 0
27 :4 0 430 732
734 :3 0 433 70a
736 :2 0 738 436
739 707 738 0
73a 438 0 745
93 :3 0 94 :3 0
73b 73c 0 9
:3 0 3c :3 0 73e
73f 0 3 :3 0
4d :3 0 43a 73d
743 :2 0 745 43e
7e6 9 :3 0 95
:2 0 4 746 747
0 1c :3 0 1d
:3 0 749 74a 0
1c :3 0 2d :3 0
74c 74d 0 3f
:2 0 2 :4 0 96
:2 0 2f :2 0 12
:2 0 44a 752 754
:3 0 44d 74e 756
74b 758 757 :2 0
1f :3 0 30 :3 0
75a 75b 0 21
:4 0 97 :4 0 24
:2 0 25 :3 0 451
75f 761 :3 0 454
75c 763 :2 0 77c
1f :3 0 30 :3 0
765 766 0 21
:4 0 98 :4 0 24
:2 0 9 :3 0 99
:3 0 76b 76c 0
457 76a 76e :3 0
24 :2 0 92 :4 0
45a 770 772 :3 0
24 :2 0 9 :3 0
9a :3 0 775 776
0 45d 774 778
:3 0 460 767 77a
:2 0 77c 463 77d
759 77c 0 77e
466 0 78e 9b
:3 0 1b :3 0 9
:3 0 99 :3 0 9c
:3 0 9 :3 0 9a
:3 0 9d :3 0 9e
:4 0 9f 1 :a 0
78a :2 0 78e 780
788 :2 0 8 :3 0
1b :3 0 78c :2 0
78e 468 790 46c
78f 78e :2 0 7e4
3e :3 0 9 :3 0
3c :3 0 793 794
0 3d :3 0 795
796 0 7dc 1c
:3 0 1d :3 0 798
799 0 1c :3 0
2d :3 0 79b 79c
0 3f :2 0 2
:4 0 a0 :2 0 2f
:2 0 12 :2 0 46e
7a1 7a3 :3 0 471
79d 7a5 79a 7a7
7a6 :2 0 1f :3 0
30 :3 0 7a9 7aa
0 21 :4 0 a1
:4 0 24 :2 0 25
:3 0 475 7ae 7b0
:3 0 478 7ab 7b2
:2 0 7cc 1f :3 0
30 :3 0 7b4 7b5
0 21 :4 0 43
:4 0 24 :2 0 3d
:3 0 47b 7b9 7bb
:3 0 24 :2 0 44
:4 0 47e 7bd 7bf
:3 0 24 :2 0 45
:3 0 46 :3 0 12
:2 0 47 :2 0 481
7c2 7c6 485 7c1
7c8 :3 0 488 7b6
7ca :2 0 7cc 48b
7cd 7a8 7cc 0
7ce 48e 0 7dc
9b :3 0 1b :3 0
9c :3 0 9 :3 0
9a :3 0 9d :3 0
9e :4 0 a2 1
:a 0 7d8 :2 0 7dc
7d0 7d6 :2 0 8
:3 0 1b :3 0 7da
:2 0 7dc 490 7df
:3 0 7df 0 7df
7de 7dc 7dd :6 0
7e1 1 :3 0 495
7e3 497 7e2 7e1
:2 0 7e4 499 :2 0
7e6 49c 7e6 7e5
745 7e4 :6 0 7e7
:2 0 2 14 7e6
7ea :3 0 7e9 7e7
7eb :8 0 
4aa
4
:3 0 1 3 1
7 1 b 3
6 a e 1
18 1 16 1
1f 1 1d 1
26 1 24 1
2b 1 32 1
30 1 37 1
3d 1 43 1
49 1 4f 1
55 1 5b 1
60 1 6d 1
79 2 7c 7e
2 81 83 2
85 87 2 89
8b 2 8d 8f
1 95 2 97
98 2 91 9a
2 9c 9e 2
a0 a2 2 a4
a6 2 a8 aa
2 ac ae 4
75 7b 80 b0
1 b2 1 b4
2 be c0 3
bc bd c2 2
cb cd 2 ca
cf 1 d1 1
d3 2 eb f0
2 101 103 3
ff 100 105 2
10e 110 2 112
114 2 116 118
2 11a 11c 2
11e 120 3 125
126 127 2 122
129 2 10d 12b
1 12d 1 12f
2 f8 130 1
134 1 f3 1
138 2 13e 13f
1 143 2 141
143 3 147 148
149 1 14d 2
14b 14d 1 159
2 158 159 1
161 1 167 2
169 16a 2 156
16b 2 17c 17e
3 17a 17b 180
2 189 18b 2
18d 18f 2 191
193 2 195 197
2 199 19b 3
1a0 1a1 1a2 2
19d 1a4 2 188
1a6 1 1a8 1
1aa 2 173 1ab
1 1af 1 16e
1 1b3 1 1c4
2 1c3 1c4 1
1cc 1 1d2 2
1d4 1d5 2 1c1
1d6 2 1e7 1e9
3 1e5 1e6 1eb
2 1f4 1f6 2
1f8 1fa 2 1fc
1fe 2 200 202
2 204 206 3
20b 20c 20d 2
208 20f 2 1f3
211 1 213 1
215 2 1de 216
1 21a 1 1d9
1 21e 2 1b6
221 1 22e 2
22d 22e 1 236
1 23c 2 23e
23f 2 22b 240
2 251 253 3
24f 250 255 2
25e 260 2 262
264 2 266 268
2 26a 26c 2
26e 270 3 275
276 277 2 272
279 2 25d 27b
1 27d 1 27f
2 248 280 1
284 1 243 1
288 1 28b 2
28e 28f 1 29d
2 29c 29d 1
2a5 1 2ab 2
2ad 2ae 2 29a
2af 2 2c0 2c2
3 2be 2bf 2c4
2 2cd 2cf 2
2d1 2d3 2 2d5
2d7 2 2d9 2db
2 2dd 2df 3
2e4 2e5 2e6 2
2e1 2e8 2 2cc
2ea 1 2ec 1
2ee 2 2b7 2ef
1 2f3 1 2b2
1 2f7 2 290
2fa 2 2fe 2ff
1 303 2 301
303 1 30f 2
30e 30f 1 317
1 31d 2 31f
320 2 30c 321
2 332 334 3
330 331 336 2
33f 341 2 343
345 2 347 349
2 34b 34d 2
34f 351 3 356
357 358 2 353
35a 2 33e 35c
1 35e 1 360
2 329 361 1
365 1 324 1
369 1 37a 2
379 37a 1 382
1 388 2 38a
38b 2 377 38c
2 39d 39f 3
39b 39c 3a1 2
3aa 3ac 2 3ae
3b0 2 3b2 3b4
2 3b6 3b8 2
3ba 3bc 3 3c1
3c2 3c3 2 3be
3c5 2 3a9 3c7
1 3c9 1 3cb
2 394 3cc 1
3d0 1 38f 1
3d4 2 36c 3d7
3 3db 3dc 3dd
1 3e1 2 3df
3e1 1 3f0 2
3ef 3f0 1 3f8
1 3fe 2 400
401 2 3ed 402
2 413 415 3
411 412 417 2
420 422 2 424
426 2 428 42a
2 42c 42e 2
430 432 3 437
438 439 2 434
43b 2 41f 43d
1 43f 1 441
2 40a 442 1
446 1 405 1
44a 1 45b 2
45a 45b 1 463
1 469 2 46b
46c 2 458 46d
2 47e 480 3
47c 47d 482 2
48b 48d 2 48f
491 2 493 495
2 497 499 2
49b 49d 3 4a2
4a3 4a4 2 49f
4a6 2 48a 4a8
1 4aa 1 4ac
2 475 4ad 1
4b1 1 470 1
4b5 2 44d 4b8
1 4c8 2 4c7
4c8 1 4d0 1
4d6 2 4d8 4d9
2 4c5 4da 2
4eb 4ed 3 4e9
4ea 4ef 2 4f8
4fa 2 4fc 4fe
2 500 502 2
504 506 2 508
50a 3 50f 510
511 2 50c 513
2 4f7 515 1
517 1 519 2
4e2 51a 1 51e
1 4dd 1 522
1 525 2 528
529 1 537 2
536 537 1 53f
1 545 2 547
548 2 534 549
2 55a 55c 3
558 559 55e 2
567 569 2 56b
56d 2 56f 571
2 573 575 2
577 579 3 57e
57f 580 2 57b
582 2 566 584
1 586 1 588
2 551 589 1
58d 1 54c 1
591 2 52a 594
2 597 598 1
599 2 59b 59c
2 5a0 5a1 2
5a3 5a4 1 5a9
2 5a7 5a9 2
5ae 5af 1 5b3
2 5b1 5b3 1
5bd 2 5bf 5c0
1 5c6 2 5c8
5c9 2 5c2 5cb
2 5ce 5d0 2
5d6 5d7 2 5d3
5d9 1 5db 1
5e1 2 5df 5e1
1 5e8 1 5ea
2 5e5 5ea 1
600 2 5ff 600
1 608 1 60e
2 610 611 2
5fd 612 2 623
625 3 621 622
627 2 630 632
2 634 636 2
638 63a 2 63c
63e 2 640 642
3 647 648 649
2 644 64b 2
62f 64d 1 64f
1 651 2 61a
652 1 656 1
615 1 65a 1
65d 1 660 2
5de 661 1 66e
2 66d 66e 1
676 1 67c 2
67e 67f 2 66b
680 2 691 693
3 68f 690 695
2 69e 6a0 2
6a2 6a4 2 6a6
6a8 2 6aa 6ac
2 6ae 6b0 3
6b5 6b6 6b7 2
6b2 6b9 2 69d
6bb 1 6bd 1
6bf 2 688 6c0
1 6c4 1 683
1 6c8 1 6cb
2 6ce 6cf 1
6d7 2 6d3 6d7
2 6dc 6dd 1
6e1 2 6df 6e1
2 6e9 6ea 1
6ed 1 6ef 1
6f3 2 6ff 701
3 6fd 6fe 703
2 70c 70e 2
710 712 2 714
716 1 71e 2
720 721 2 718
723 2 725 727
2 729 72b 2
72d 72f 2 731
733 2 70b 735
1 737 1 739
3 740 741 742
b b5 d4 d7
da 13b 59d 6d0
6f0 6f6 73a 744
2 751 753 3
74f 750 755 2
75e 760 2 75d
762 2 769 76d
2 76f 771 2
773 777 2 768
779 2 764 77b
1 77d 3 77e
789 78d 1 748
2 7a0 7a2 3
79e 79f 7a4 2
7ad 7af 2 7ac
7b1 2 7b8 7ba
2 7bc 7be 3
7c3 7c4 7c5 2
7c0 7c7 2 7b7
7c9 2 7b3 7cb
1 7cd 4 797
7ce 7d7 7db 1
7df 1 792 2
790 7e3 d 1b
22 29 2e 35
3b 41 47 4d
53 59 5e 65

1
4
0 
7ea
0
1
28
1c
11
0 1 2 1 4 1 6 1
8 1 a 1 c 1 e 1
10 1 12 1 14 1 16 1
18 1 1a 1 0 0 0 0
0 0 0 0 0 0 0 0

b 1 0
55 1 0
16 1 0
2 0 1
3d 1 0
3 1 0
2b 1 0
37 1 0
49 1 0
24 1 0
4f 1 0
30 1 0
43 1 0
1d 1 0
7 1 0
5b 1 0
60 1 0
0

/
SHOW ERRORS FUNCTION SP_RJCT_ETC_ASSIGN;
ALTER FUNCTION SP_RJCT_ETC_ASSIGN COMPILE DEBUG;
/****************************************************************************************
Reject ETC and/or FORECAST_START, WBS level
  Bitflag =
    1 - ETC
    2 - FORECAST_START
    3 - ETC + FORECAST_START
****************************************************************************************/
Prompt == FUNCTION SP_RJCT_ETC_WBS ==
CREATE OR REPLACE FUNCTION SP_RJCT_ETC_WBS wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
ea
2 :e:
1FUNCTION:
1SP_RJCT_ETC_WBS:
1ID001:
1VARCHAR2:
1BITFLAG001:
1PLS_INTEGER:
1REC_USER001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_FINISH_DATE:
1TIMESTAMP:
1H_PROJECT_ID:
132:
1H_RANK:
1200:
1H_START_DATE:
1H_TASK_ID:
1H_TSK_ASSIGNMENT_ID:
1H_BIT_FLAG:
11:
1H_BITFLAG:
10:
1H_EFFORT:
1H_TYPE:
1H_START_D:
1DATE:
1H_TEMP_SC_STATE:
1H_TEMP_VAR:
1H_TEMP_SC_NODATA:
1H_STEPS_EXIST:
1H_SCHED_WORK:
1H_WORK_TODATE:
1H_MLST_PERCENT:
1H_TEMP_SC_STATE_ALERT:
1H_ALERT_ID:
1H_REC_USER:
1H_CALLTYPE:
1H_TABLE_TYPE:
1I_STEPS_EXIST:
1I_PERCENT_COMPLETE:
1CURSOR:
1CAWTSKR:
1ELEMENT_ID:
1SCHED_EFFORT:
1PLANNED_EFFORT:
1FORECAST_START:
1SCHED_START:
1FORECAST_FINISH:
1SCHED_FINISH:
1TMT_WBS:
1PROJECT_ID:
1RANK:
1TYPE_ID:
1PMO_CNST:
1SC_TASK:
1SC_TASK_TYPE1:
1SC_TASK_TYPE2:
1SC_TASK_TYPE3:
1SC_MILESTONE:
1SC_PERSONAL_TASK:
1SC_ACTIVE_ADM_TASK:
1SC_INACTIVE_ADM_TASK:
1SC_WBS_CHANGE_REQUEST_TASK:
1SC_WBS_ACTION_ITEM_TASK:
1SC_WBS_RISK_TASK:
1SC_WBS_ISSUE_TASK:
1SC_WBS_REQUIREMENT_TASK:
1SC_WBS_DEFECT_TASK:
1SC_WBS_SERVICE_REQUEST_TASK:
1WORK_TODATE:
1ETC:
1SELECT ELEMENT_ID, SCHED_EFFORT+PLANNED_EFFORT,:n         CASE WHEN FORECAST_+
1START IS NULL THEN SCHED_START ELSE FORECAST_START END,:n         CASE WHEN F+
1ORECAST_FINISH IS NULL THEN SCHED_FINISH ELSE FORECAST_FINISH END:n         F+
1ROM TMT_WBS:n         WHERE PROJECT_ID = h_project_id AND RANK LIKE h_rank AN+
1D TYPE_ID IN (PMO_CNST.SC_TASK,PMO_CNST.SC_TASK_TYPE1,PMO_CNST.SC_TASK_TYPE2,+
1PMO_CNST.SC_TASK_TYPE3,PMO_CNST.SC_MILESTONE,PMO_CNST.SC_PERSONAL_TASK,PMO_CN+
1ST.SC_ACTIVE_ADM_TASK,PMO_CNST.SC_INACTIVE_ADM_TASK,PMO_CNST.SC_WBS_CHANGE_RE+
1QUEST_TASK,PMO_CNST.SC_WBS_ACTION_ITEM_TASK,PMO_CNST.SC_WBS_RISK_TASK,PMO_CNS+
1T.SC_WBS_ISSUE_TASK,PMO_CNST.SC_WBS_REQUIREMENT_TASK,PMO_CNST.SC_WBS_DEFECT_T+
1ASK,PMO_CNST.SC_WBS_SERVICE_REQUEST_TASK):n         AND (((SCHED_EFFORT+PLANN+
1ED_EFFORT) > 0 AND ((SCHED_EFFORT+PLANNED_EFFORT-WORK_TODATE) <> ETC)):n     +
1    OR (FORECAST_START IS NOT NULL OR FORECAST_FINISH IS NOT NULL)):
1CAWASSR:
1TSK_ASSIGNMENT_ID:
1BIT_FLAG:
1BEST:
1SCHED_WORK:
1PLANNED_WORK:
1MILESTONE_PERCENT:
1TASK_ASSIGNMENTS:
1TASK_ID:
1SELECT TSK_ASSIGNMENT_ID, BIT_FLAG, BEST, SCHED_WORK+PLANNED_WORK, WORK_TODAT+
1E, MILESTONE_PERCENT:n         FROM TASK_ASSIGNMENTS:n         WHERE PROJECT_+
1ID = h_project_id:n         AND TASK_ID = h_task_id:n         AND (((SCHED_WO+
1RK+PLANNED_WORK) > 0 AND ((SCHED_WORK+PLANNED_WORK-WORK_TODATE) <> ETC)):n   +
1      OR (FORECAST_START IS NOT NULL OR FORECAST_FINISH IS NOT NULL)):
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_RJCT_ETC_WBS(:
1':
1, :
1COALESCE:
1TO_CHAR:
1NULL:
1);:
1CHECK_TRACE:
160:
1+:
1FPUT:
1               ENTER:: SP_RJCT_ETC_WBS(61) :: cplan.sql(19062) :: :
13:
1SCETCFORCASTREJECTED:
1RTRIM:
1SELECT PROJECT_ID, RTRIM(RANK), TYPE_ID:n      INTO h_project_id, h_rank, h_t+
1ype:n      FROM TMT_WBS WHERE ELEMENT_ID = id001:
1SC_STATE:
1SQLCODE:
1OTHERS:
116:
183:
1           EXCEPTION:: SP_RJCT_ETC_WBS(84) :: cplan.sql(19085) :: :
1 :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1=:
1SC_SQL_SUCCESS:
1IS NOT NULL:
1%:
1-:
1START_FINISH_DATE:
1SELECT START_FINISH_DATE INTO h_start_D FROM TMT_WBS WHERE ELEMENT_ID = h_pro+
1ject_id:
1101:
1           EXCEPTION:: SP_RJCT_ETC_WBS(102) :: cplan.sql(19103) :: :
1OPEN:
1LOOP:
1FOUND:
1100:
1!=:
1EXIT:
12:
1FORECAST_DURATION:
1UPDATE TMT_WBS SET:n                  FORECAST_START = NULL,:n               +
1   FORECAST_FINISH = NULL,:n                  FORECAST_DURATION = 0:n        +
1          WHERE PROJECT_ID = h_project_id AND ELEMENT_ID = h_task_id:
1TRUE:
1141:
1           EXCEPTION:: SP_RJCT_ETC_WBS(142) :: cplan.sql(19143) :: :
1FC_ISSUE_ALERT:
1CONTINUE0000:
1ACTIVITIES:
1ETC_MODIFIED:
1SC_TIMESHEET_ACTIVITY:
1UPDATE ACTIVITIES:n                        SET ETC_MODIFIED = 'N':n          +
1              WHERE TSK_ASSIGNMENT_ID = h_tsk_assignment_id:n                +
1        AND TSK_ASSIGNMENT_ID <> ELEMENT_ID:n                        AND TYPE+
1_ID = PMO_CNST.SC_TIMESHEET_ACTIVITY:
1190:
1           EXCEPTION:: SP_RJCT_ETC_WBS(191) :: cplan.sql(19192) :: :
1PROPOSED_START:
1PROPOSED_FINISH:
1PROPOSED_WORK:
1BAK_START_DT:
1BAK_FINISH_DT:
1BAK_WORK:
1BAK_ASSIGN_STRING:
1ASSIGN_STRING:
1ACTUAL_FINISH:
1UPDATE TASK_ASSIGNMENTS SET:n                           PROPOSED_START      =+
1 SCHED_START,:n                           PROPOSED_FINISH     = SCHED_FINISH,+
1:n                           PROPOSED_WORK       = SCHED_WORK,:n             +
1              BAK_START_DT        = SCHED_START,:n                           +
1BAK_FINISH_DT       = SCHED_FINISH,:n                           BAK_WORK     +
1       = SCHED_WORK,:n                           BAK_ASSIGN_STRING   = ASSIGN+
1_STRING,:n                           BEST                = SCHED_WORK,:n     +
1                      ETC                 = SCHED_WORK - WORK_TODATE,:n      +
1                     ACTUAL_FINISH       = NULL:n                           W+
1HERE TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
1219:
1           EXCEPTION:: SP_RJCT_ETC_WBS(220) :: cplan.sql(19221) :: :
1UPDATE TASK_ASSIGNMENTS SET:n                           SCHED_WORK	= SCHED_WO+
1RK,:n                           ETC			= SCHED_WORK - WORK_TODATE:n           +
1                WHERE TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
1247:
1           EXCEPTION:: SP_RJCT_ETC_WBS(248) :: cplan.sql(19249) :: :
1ACTUAL_DURATION:
1UPDATE TASK_ASSIGNMENTS SET:n                        ETC					= PLANNED_WORK, +
1:n                        MILESTONE_PERCENT	= 0 ,:n                        AC+
1TUAL_FINISH		= NULL, :n                        ACTUAL_DURATION		= 0:n        +
1                WHERE TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
1270:
1           EXCEPTION:: SP_RJCT_ETC_WBS(271) :: cplan.sql(19272) :: :
1UPDATE TASK_ASSIGNMENTS SET:n                        FORECAST_START = NULL,:n+
1                        FORECAST_FINISH = NULL,:n                        FORE+
1CAST_DURATION = 0:n                        WHERE TSK_ASSIGNMENT_ID = h_tsk_as+
1signment_id:
1295:
1           EXCEPTION:: SP_RJCT_ETC_WBS(296) :: cplan.sql(19297) :: :
1UPDATE ACTIVITIES:n                           SET ETC_MODIFIED = 'N':n       +
1                    WHERE TSK_ASSIGNMENT_ID = h_tsk_assignment_id:n          +
1                 AND TSK_ASSIGNMENT_ID <> ELEMENT_ID:n                       +
1    AND TYPE_ID = PMO_CNST.SC_TIMESHEET_ACTIVITY:
1318:
1           EXCEPTION:: SP_RJCT_ETC_WBS(319) :: cplan.sql(19320) :: :
1UPDATE TASK_ASSIGNMENTS SET:n                           FORECAST_START = NULL+
1,:n                           FORECAST_FINISH = NULL,:n                      +
1     FORECAST_DURATION = 0,:n                           SCHED_WORK = CASE WHE+
1N PROPOSED_WORK > WORK_TODATE THEN PROPOSED_WORK ELSE SCHED_WORK END,:n      +
1                     ETC = CASE WHEN PROPOSED_WORK > WORK_TODATE THEN PROPOSE+
1D_WORK - WORK_TODATE ELSE 0 END/*,:n                           MILESTONE_PERC+
1ENT = (WORK_TODATE * 10000) / SCHED_WORK*/:n                           WHERE +
1TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
1342:
1           EXCEPTION:: SP_RJCT_ETC_WBS(343) :: cplan.sql(19344) :: :
1UPDATE TASK_ASSIGNMENTS SET:n                           FORECAST_START = NULL+
1,:n                           FORECAST_FINISH = NULL,:n                      +
1     FORECAST_DURATION = 0,:n                           ETC = PLANNED_WORK, M+
1ILESTONE_PERCENT = 0:n                           WHERE TSK_ASSIGNMENT_ID = h_+
1tsk_assignment_id:
1364:
1           EXCEPTION:: SP_RJCT_ETC_WBS(365) :: cplan.sql(19366) :: :
1SC_SQL_NO_DATA:
1BITAND:
1>:
1TRUNC:
1TO_NUMBER:
1/:
1*:
110000.00:
1<:
1ROLLUP_BITS:
1PMO_STPU:
1BIT_OR:
1SC_PERCENT_COMPLETE_BIT:
1UPDATE TASK_ASSIGNMENTS SET:n                           ROLLUP_BITS = PMO_STP+
1U.BIT_OR(ROLLUP_BITS,PMO_CNST.SC_PERCENT_COMPLETE_BIT),:n                    +
1       ACTUAL_FINISH = CASE:n                           WHEN ACTUAL_FINISH IS+
1 NULL AND ETC = 0 THEN SCHED_FINISH:n                           ELSE ACTUAL_F+
1INISH:n                           END:n                           WHERE TSK_A+
1SSIGNMENT_ID = h_tsk_assignment_id:
1406:
1           EXCEPTION:: SP_RJCT_ETC_WBS(407) :: cplan.sql(19408) :: :
1UPDATE TASK_ASSIGNMENTS SET:n                           ACTUAL_FINISH = CASE +
1WHEN (ACTUAL_FINISH IS NULL) AND ETC = 0 THEN SCHED_FINISH ELSE ACTUAL_FINISH+
1 END:n                           WHERE TSK_ASSIGNMENT_ID = h_tsk_assignment_i+
1d:
1425:
1           EXCEPTION:: SP_RJCT_ETC_WBS(426) :: cplan.sql(19427) :: :
1FC_FIX_SUMMARY_TS:
1CLOSE:
1448:
1           EXCEPTION:: SP_RJCT_ETC_WBS(449) :: cplan.sql(19450) :: :
1CONSTRAINT_TYPE:
1TO_DATE:
1CONSTRAINT_DT:
1UPDATE TMT_WBS SET:n            CONSTRAINT_TYPE =:n            CASE:n        +
1    WHEN TO_DATE(SubStr(SCHED_START, 1, 10)) <> TO_DATE(SubStr(h_start_D, 1, +
110)) THEN 6:n            ELSE 0:n            END,:n            CONSTRAINT_DT +
1=:n            CASE:n            WHEN TO_DATE(SubStr(SCHED_START, 1, 10)) <> +
1TO_DATE(SubStr(h_start_D, 1, 10)) THEN SCHED_START:n            ELSE NULL:n  +
1          END:n            WHERE PROJECT_ID = h_project_id AND ELEMENT_ID = h+
1_task_id:
1478:
1           EXCEPTION:: SP_RJCT_ETC_WBS(479) :: cplan.sql(19480) :: :
1495:
1           EXCEPTION:: SP_RJCT_ETC_WBS(496) :: cplan.sql(19497) :: :
1FC_ROLLUP:
14:
1507:
1       RETURN_STATUS:: SP_RJCT_ETC_WBS(508) :: cplan.sql(19509) :: :
1STATE:: :
1 ID:: :
1PMODEFINES:
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
1514:
1           EXCEPTION:: SP_RJCT_ETC_WBS(515) :: cplan.sql(19516) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1ERROR:
1ID:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
1526:
1           EXCEPTION:: SP_RJCT_ETC_WBS(527) :: cplan.sql(19528) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
ab3
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 81 b0 a0 f4 b4
bf c8 :35 a0 12a bd b7 11 a4
b1 a0 f4 b4 bf c8 :14 a0 12a
bd b7 11 a4 b1 a3 :2 a0 6b
1c 81 b0 :2 a0 6b :2 a0 6b 6e
a5 b a 10 :2 a0 6b 6e :2 a0
6b 6e a5 b 6e 7e a0 b4
2e 6e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
d :2 a0 d a0 51 d a0 6e
d :a a0 12a :2 a0 6b a0 d b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 6b a0 7e
a0 6b b4 2e 5a a0 7e b4
2e :2 5a a 10 :3 a0 7e 6e b4
2e :2 51 a5 b d a0 7e 51
b4 2e d :5 a0 12a :2 a0 6b a0
d b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 e9
dd b3 :6 a0 e9 d3 5 :2 a0 f
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c :2 a0 6b a0 7e
a0 6b b4 2e 5a a0 2b b7
19 3c :2 a0 51 a5 b 7e 51
b4 2e :2 a0 51 a5 b 7e 51
b4 2e :8 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f a0 51 d :8 a0 51
a5 b a5 b d b7 a0 3b
b7 :2 19 3c b7 :2 a0 e9 dd b3
:8 a0 e9 d3 5 :2 a0 f :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c :2 a0 6b a0 7e a0 6b
b4 2e 5a a0 2b b7 19 3c
a0 51 d :2 a0 51 a5 b 7e
51 b4 2e :2 a0 :2 51 a5 b 7e
6e b4 2e :9 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 51 a5 b
:2 7e 51 b4 2e b4 2e :17 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
:8 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 :2 19 3c b7 :8 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 :2 19
3c b7 :2 a0 51 a5 b 7e 51
b4 2e :6 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 :2 a0 :2 51 a5 b
7e 6e b4 2e :9 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :10 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 :9 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 :2 19 3c b7 :2 19 3c b7 :2 19
3c :2 a0 6b a0 7e a0 6b b4
2e 5a a0 51 d b7 19 3c
a0 51 d :8 a0 51 a5 b a5
b d :2 a0 51 a5 b 7e 51
b4 2e :3 a0 51 a5 b 51 a5
b 5a 7e 51 b4 2e 5a :2 a0
51 a5 b 7e 51 b4 2e 5a
a 10 :5 a0 a5 b 51 a5 b
7e :3 a0 a5 b 51 a5 b b4
2e 5a 7e 51 b4 2e 5a 7e
:2 a0 51 a5 b b4 2e a5 b
d a0 7e 51 b4 2e 5a a0
:2 7e 51 b4 2e b4 2e 52 10
:e a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 :8 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 :2 19 3c :4 a0 a5
b d b7 19 3c b7 19 3c
b7 a0 47 :2 a0 e9 c1 :2 a0 6b
a0 d b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
:2 19 3c :14 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f 93 4f b0 46 b7
a0 47 :2 a0 e9 c1 :2 a0 6b a0
d b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 51
a5 b :2 7e 51 b4 2e b4 2e
:3 a0 a5 b d b7 19 3c b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b :2 a0 a5 57 b7 :2 a0
6b :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 :2 a0 6b :2 6e 7e :2 a0 6b b4
2e 7e 6e b4 2e 7e :2 a0 6b
b4 2e a5 57 b7 19 3c :9 a0
12a e9 dd :2 a0 65 b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c :7 a0 12a e9
dd :2 a0 65 b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 68 4f
1d 17 b5 
ab3
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 30
56 5a 5e 62 65 69 82 71
75 7d 70 9f 8d 6d 91 92
9a 8c bc aa 89 ae af b7
a9 d8 c7 cb d3 a6 f4 df
e3 e6 e7 ef c6 111 ff c3
103 104 10c fe 12e 11c fb 120
121 129 11b 14a 139 13d 118 145
138 166 155 159 135 161 154 182
171 175 151 17d 170 19e 18d 191
199 16d 1b9 1a5 1a9 1b1 1b4 18c
1d5 1c4 1c8 189 1d0 1c3 1f1 1e0
1e4 1c0 1ec 1df 20d 1fc 200 1dc
208 1fb 229 218 21c 1f8 224 217
245 234 238 214 240 233 261 250
254 230 25c 24f 27d 26c 270 24c
278 26b 29a 288 268 28c 28d 295
287 2b7 2a5 284 2a9 2aa 2b2 2a4
2d3 2c2 2c6 2a1 2ce 2c1 2ef 2de
2e2 2be 2ea 2dd 30b 2fa 2fe 2da
306 2f9 327 316 31a 322 2f6 312
32e 33f 340 343 347 34b 34f 353
357 35b 35f 363 367 36b 36f 373
377 37b 37f 383 387 38b 38f 393
397 39b 39f 3a3 3a7 3ab 3af 3b3
3b7 3bb 3bf 3c3 3c7 3cb 3cf 3d3
3d7 3db 3df 3e3 3e7 3eb 3ef 3f3
3f7 3fb 3ff 403 407 40b 40f 413
417 41b 427 42c 42e 43a 43e 440
444 455 456 459 45d 461 465 469
46d 471 475 479 47d 481 485 489
48d 491 495 499 49d 4a1 4a5 4a9
4ad 4b9 4be 4c0 4cc 4d0 4ee 4d6
4da 4de 4e1 4e9 4d5 4f5 4f9 4d2
4fd 501 505 508 50d 50e 1 510
515 519 51d 520 525 529 52d 530
535 536 538 53d 540 544 545 54a
54f 552 557 558 55d 560 564 565
56a 56d 572 573 578 57b 580 581
586 589 58d 591 595 596 598 59d
59e 5a0 5a1 5a6 5a9 5ae 5af 5b4
5b7 5bc 5bd 5c2 5c5 5c9 5ca 5cf
5d2 5d7 5d8 5dd 5e0 5e5 5e6 5eb
5ec 5f1 5f3 5f7 5fa 5fe 602 605
609 60d 610 613 618 61b 61e 621
622 627 628 1 62a 62f 633 637
63a 63f 644 647 64b 64c 651 652
657 659 65d 660 664 668 66c 670
674 678 67c 67f 683 687 68c 690
694 698 69c 6a0 6a4 6a8 6ac 6b0
6b4 6b8 6c4 6c8 6cc 6cf 6d3 6d7
6d9 1 6dd 6e1 6e5 6e8 6ec 6f0
6f4 6f8 6fb 6ff 703 706 709 70e
711 714 717 718 71d 71e 1 720
725 729 72d 730 735 73a 73d 741
742 747 74a 74f 750 755 758 75d
75e 763 766 76a 76b 770 773 778
779 77e 781 785 789 78c 78f 790
792 793 798 799 79e 7a0 7a4 7a7
7a9 7ad 7af 7bb 7bd 7bf 7c0 7c5
7c9 7cb 7d7 7d9 7dd 7e1 7e4 7e8
7eb 7ef 7f2 7f3 7f8 7fb 7ff 802
803 808 80b 1 80e 813 817 81b
81f 822 827 828 82d 830 833 834
836 83a 83e 841 844 845 84a 84e
852 856 85a 85e 862 86e 872 876
879 87d 881 883 1 887 88b 88f
892 896 89a 89e 8a2 8a5 8a9 8ad
8b0 8b3 8b8 8bb 8be 8c1 8c2 8c7
8c8 1 8ca 8cf 8d3 8d7 8da 8df
8e4 8e7 8eb 8ec 8f1 8f4 8f9 8fa
8ff 902 907 908 90d 910 914 915
91a 91d 922 923 928 92b 92f 933
936 939 93a 93c 93d 942 943 948
94a 94e 951 953 957 959 965 967
969 96a 96f 973 975 981 983 987
98b 990 994 995 999 99d 9a1 9a5
9a9 9ad 9b2 9b7 9bb 9bf 9c3 9c8
9cc 9d0 9d3 9d6 9da 9dc 9e0 9e4
9e7 9ea 9ee 9f0 9f4 9f8 9fb 9ff
a03 a06 a0a a0d a11 a14 a15 a1a
a1d a21 a27 a29 a2d a30 a34 a38
a3b a3c a3e a41 a44 a45 a4a a4e
a52 a55 a56 a58 a5b a5e a5f a64
a68 a6c a70 a74 a78 a7c a80 a84
a90 a94 a99 a9d aa0 aa1 aa6 aaa
aae ab1 ab4 ab8 aba abe ac2 ac5
ac8 acc ace ad2 ad6 ad9 adb 1
adf ae3 ae7 aea aee af2 af6 afa
afd b01 b05 b08 b0b b10 b13 b16
b19 b1a b1f b20 1 b22 b27 b2b
b2f b32 b37 b3c b3f b43 b44 b49
b4c b51 b52 b57 b5a b5f b60 b65
b68 b6c b6d b72 b75 b7a b7b b80
b83 b87 b8b b8e b91 b92 b94 b95
b9a b9b ba0 ba2 ba6 ba9 bab baf
bb1 bbd bbf bc1 bc2 bc7 bcb bcd
bd9 bdb bdf be2 be6 bea bee bf2
bf6 bfa bfe c02 c06 c09 c0a c0c
c0d c0f c13 c15 c19 c1f c21 c25
c29 c2c c2e c32 c36 c3b c3f c40
c44 c48 c4c c50 c54 c58 c5c c60
c65 c6a c6e c72 c76 c7b c7f c83
c86 c89 c8d c8f c93 c97 c9a c9d
ca1 ca3 ca7 cab cae cb2 cb6 cb9
cbd cc0 cc4 cc7 cc8 ccd cd0 cd4
cda cdc ce0 ce3 ce7 cea cee cf2
cf6 cf9 cfa cfc cff d02 d03 d08
d0c d10 d13 d16 d17 d19 d1c d21
d22 d27 d2b d2f d33 d37 d3b d3f
d43 d47 d4b d57 d5b d60 d64 d67
d68 d6d d71 d75 d78 d7b d7f d81
d85 d89 d8c d8f d93 d95 d99 d9d
da0 da2 1 da6 daa dae db1 db5
db9 dbd dc1 dc4 dc8 dcc dcf dd2
dd7 dda ddd de0 de1 de6 de7 1
de9 dee df2 df6 df9 dfe e03 e06
e0a e0b e10 e13 e18 e19 e1e e21
e26 e27 e2c e2f e33 e34 e39 e3c
e41 e42 e47 e4a e4e e52 e55 e58
e59 e5b e5c e61 e62 e67 e69 e6d
e70 e72 e76 e78 e84 e86 e88 e89
e8e e92 e94 ea0 ea2 ea6 eaa ead
eae eb0 eb3 eb6 eb9 eba ebf ec0
ec5 ec9 ecd ed1 ed5 ed9 edd ee1
ee5 ee9 eed ef1 ef5 ef9 efd f01
f05 f09 f0d f11 f15 f19 f1d f21
f2d f31 f36 f3a f3d f3e f43 f47
f4b f4e f51 f55 f57 f5b f5f f62
f65 f69 f6b f6f f73 f76 f78 1
f7c f80 f84 f87 f8b f8f f93 f97
f9a f9e fa2 fa5 fa8 fad fb0 fb3
fb6 fb7 fbc fbd 1 fbf fc4 fc8
fcc fcf fd4 fd9 fdc fe0 fe1 fe6
fe9 fee fef ff4 ff7 ffc ffd 1002
1005 1009 100a 100f 1012 1017 1018 101d
1020 1024 1028 102b 102e 102f 1031 1032
1037 1038 103d 103f 1043 1046 1048 104c
104e 105a 105c 105e 105f 1064 1068 106a
1076 1078 107a 107e 1082 1086 108a 108e
1092 1096 109a 10a6 10aa 10af 10b3 10b6
10b7 10bc 10c0 10c4 10c7 10ca 10ce 10d0
10d4 10d8 10db 10de 10e2 10e4 10e8 10ec
10ef 10f1 1 10f5 10f9 10fd 1100 1104
1108 110c 1110 1113 1117 111b 111e 1121
1126 1129 112c 112f 1130 1135 1136 1
1138 113d 1141 1145 1148 114d 1152 1155
1159 115a 115f 1162 1167 1168 116d 1170
1175 1176 117b 117e 1182 1183 1188 118b
1190 1191 1196 1199 119d 11a1 11a4 11a7
11a8 11aa 11ab 11b0 11b1 11b6 11b8 11bc
11bf 11c1 11c5 11c7 11d3 11d5 11d7 11d8
11dd 11e1 11e3 11ef 11f1 11f3 11f7 11fb
11fe 1200 1204 1208 120c 1210 1214 1218
121c 1220 122c 1230 1235 1239 123c 123d
1242 1246 124a 124d 1250 1254 1256 125a
125e 1261 1264 1268 126a 126e 1272 1275
1277 1 127b 127f 1283 1286 128a 128e
1292 1296 1299 129d 12a1 12a4 12a7 12ac
12af 12b2 12b5 12b6 12bb 12bc 1 12be
12c3 12c7 12cb 12ce 12d3 12d8 12db 12df
12e0 12e5 12e8 12ed 12ee 12f3 12f6 12fb
12fc 1301 1304 1308 1309 130e 1311 1316
1317 131c 131f 1323 1327 132a 132d 132e
1330 1331 1336 1337 133c 133e 1342 1345
1347 134b 134d 1359 135b 135d 135e 1363
1367 1369 1375 1377 1379 137d 1381 1384
1386 138a 138e 1391 1392 1394 1397 139a
139b 13a0 13a4 13a8 13ac 13b0 13b4 13b8
13c4 13c8 13cd 13d1 13d4 13d5 13da 13de
13e2 13e5 13e8 13ec 13ee 13f2 13f6 13f9
13fc 1400 1402 1406 140a 140d 140f 1
1413 1417 141b 141e 1422 1426 142a 142e
1431 1435 1439 143c 143f 1444 1447 144a
144d 144e 1453 1454 1 1456 145b 145f
1463 1466 146b 1470 1473 1477 1478 147d
1480 1485 1486 148b 148e 1493 1494 1499
149c 14a0 14a1 14a6 14a9 14ae 14af 14b4
14b7 14bb 14bf 14c2 14c5 14c6 14c8 14c9
14ce 14cf 14d4 14d6 14da 14dd 14df 14e3
14e5 14f1 14f3 14f5 14f6 14fb 14ff 1501
150d 150f 1511 1515 1519 151c 151f 1520
1522 1525 152a 152b 1530 1534 1538 153c
1540 1544 1548 154c 1550 1554 1560 1564
1569 156d 1570 1571 1576 157a 157e 1581
1584 1588 158a 158e 1592 1595 1598 159c
159e 15a2 15a6 15a9 15ab 1 15af 15b3
15b7 15ba 15be 15c2 15c6 15ca 15cd 15d1
15d5 15d8 15db 15e0 15e3 15e6 15e9 15ea
15ef 15f0 1 15f2 15f7 15fb 15ff 1602
1607 160c 160f 1613 1614 1619 161c 1621
1622 1627 162a 162f 1630 1635 1638 163c
163d 1642 1645 164a 164b 1650 1653 1657
165b 165e 1661 1662 1664 1665 166a 166b
1670 1672 1676 1679 167b 167f 1681 168d
168f 1691 1692 1697 169b 169d 16a9 16ab
16af 16b3 16b7 16bb 16bf 16c3 16c7 16cb
16cf 16d3 16d7 16db 16df 16e3 16e7 16eb
16f7 16fb 1700 1704 1707 1708 170d 1711
1715 1718 171b 171f 1721 1725 1729 172c
172f 1733 1735 1739 173d 1740 1742 1
1746 174a 174e 1751 1755 1759 175d 1761
1764 1768 176c 176f 1772 1777 177a 177d
1780 1781 1786 1787 1 1789 178e 1792
1796 1799 179e 17a3 17a6 17aa 17ab 17b0
17b3 17b8 17b9 17be 17c1 17c6 17c7 17cc
17cf 17d3 17d4 17d9 17dc 17e1 17e2 17e7
17ea 17ee 17f2 17f5 17f8 17f9 17fb 17fc
1801 1802 1807 1809 180d 1810 1812 1816
1818 1824 1826 1828 1829 182e 1832 1834
1840 1842 1844 1848 184c 1850 1854 1858
185c 1860 1864 1868 1874 1878 187d 1881
1884 1885 188a 188e 1892 1895 1898 189c
189e 18a2 18a6 18a9 18ac 18b0 18b2 18b6
18ba 18bd 18bf 1 18c3 18c7 18cb 18ce
18d2 18d6 18da 18de 18e1 18e5 18e9 18ec
18ef 18f4 18f7 18fa 18fd 18fe 1903 1904
1 1906 190b 190f 1913 1916 191b 1920
1923 1927 1928 192d 1930 1935 1936 193b
193e 1943 1944 1949 194c 1950 1951 1956
1959 195e 195f 1964 1967 196b 196f 1972
1975 1976 1978 1979 197e 197f 1984 1986
198a 198d 198f 1993 1995 19a1 19a3 19a5
19a6 19ab 19af 19b1 19bd 19bf 19c1 19c5
19c9 19cc 19ce 19d2 19d6 19d9 19db 19df
19e3 19e6 19ea 19ee 19f1 19f5 19f8 19fc
19ff 1a00 1a05 1a08 1a0c 1a0f 1a13 1a15
1a19 1a1c 1a20 1a23 1a27 1a2b 1a2f 1a33
1a37 1a3b 1a3f 1a43 1a47 1a4a 1a4b 1a4d
1a4e 1a50 1a54 1a58 1a5c 1a5f 1a60 1a62
1a65 1a68 1a69 1a6e 1a72 1a76 1a7a 1a7d
1a7e 1a80 1a83 1a84 1a86 1a89 1a8c 1a8f
1a90 1a95 1a98 1a9c 1aa0 1aa3 1aa4 1aa6
1aa9 1aac 1aad 1ab2 1 1ab5 1aba 1abe
1ac2 1ac6 1aca 1ace 1acf 1ad1 1ad4 1ad5
1ad7 1ada 1ade 1ae2 1ae6 1ae7 1ae9 1aec
1aed 1aef 1af0 1af5 1af8 1afb 1afe 1aff
1b04 1b07 1b0a 1b0e 1b12 1b15 1b16 1b18
1b19 1b1e 1b1f 1b21 1b25 1b29 1b2c 1b2f
1b30 1b35 1b38 1b3c 1b3f 1b42 1b45 1b46
1b4b 1b4c 1 1b51 1b56 1b5a 1b5e 1b62
1b66 1b6a 1b6e 1b72 1b76 1b7a 1b7e 1b82
1b86 1b8a 1b8e 1b9a 1b9e 1ba3 1ba7 1baa
1bab 1bb0 1bb4 1bb8 1bbb 1bbe 1bc2 1bc4
1bc8 1bcc 1bcf 1bd2 1bd6 1bd8 1bdc 1be0
1be3 1be5 1 1be9 1bed 1bf1 1bf4 1bf8
1bfc 1c00 1c04 1c07 1c0b 1c0f 1c12 1c15
1c1a 1c1d 1c20 1c23 1c24 1c29 1c2a 1
1c2c 1c31 1c35 1c39 1c3c 1c41 1c46 1c49
1c4d 1c4e 1c53 1c56 1c5b 1c5c 1c61 1c64
1c69 1c6a 1c6f 1c72 1c76 1c77 1c7c 1c7f
1c84 1c85 1c8a 1c8d 1c91 1c95 1c98 1c9b
1c9c 1c9e 1c9f 1ca4 1ca5 1caa 1cac 1cb0
1cb3 1cb5 1cb9 1cbb 1cc7 1cc9 1ccb 1ccc
1cd1 1cd5 1cd7 1ce3 1ce5 1ce7 1ceb 1cef
1cf3 1cf7 1cfb 1cff 1d03 1d07 1d13 1d17
1d1c 1d20 1d23 1d24 1d29 1d2d 1d31 1d34
1d37 1d3b 1d3d 1d41 1d45 1d48 1d4b 1d4f
1d51 1d55 1d59 1d5c 1d5e 1 1d62 1d66
1d6a 1d6d 1d71 1d75 1d79 1d7d 1d80 1d84
1d88 1d8b 1d8e 1d93 1d96 1d99 1d9c 1d9d
1da2 1da3 1 1da5 1daa 1dae 1db2 1db5
1dba 1dbf 1dc2 1dc6 1dc7 1dcc 1dcf 1dd4
1dd5 1dda 1ddd 1de2 1de3 1de8 1deb 1def
1df0 1df5 1df8 1dfd 1dfe 1e03 1e06 1e0a
1e0e 1e11 1e14 1e15 1e17 1e18 1e1d 1e1e
1e23 1e25 1e29 1e2c 1e2e 1e32 1e34 1e40
1e42 1e44 1e45 1e4a 1e4e 1e50 1e5c 1e5e
1e60 1e64 1e68 1e6b 1e6f 1e73 1e77 1e7b
1e7c 1e7e 1e82 1e84 1e88 1e8b 1e8d 1e91
1e94 1e96 1e9a 1ea1 1ea5 1ea9 1eae 1eb0
1eb4 1eb8 1ebb 1ebf 1ec3 1ec5 1 1ec9
1ecd 1ed1 1ed4 1ed8 1edc 1ee0 1ee4 1ee7
1eeb 1eef 1ef2 1ef5 1efa 1efd 1f00 1f03
1f04 1f09 1f0a 1 1f0c 1f11 1f15 1f19
1f1c 1f21 1f26 1f29 1f2d 1f2e 1f33 1f36
1f3b 1f3c 1f41 1f44 1f49 1f4a 1f4f 1f52
1f56 1f57 1f5c 1f5f 1f64 1f65 1f6a 1f6d
1f71 1f75 1f78 1f7b 1f7c 1f7e 1f7f 1f84
1f85 1f8a 1f8c 1f90 1f93 1f95 1f99 1f9b
1fa7 1fa9 1fab 1fac 1fb1 1fb5 1fb7 1fc3
1fc5 1fc7 1fcb 1fcf 1fd2 1fd6 1fda 1fde
1fe2 1fe6 1fea 1fee 1ff2 1ff6 1ffa 1ffe
2002 2006 200a 200e 2012 2016 201a 201e
2022 202e 2032 2037 203b 203e 203f 2044
2048 204c 204f 2052 2056 2058 205c 2060
2063 2066 206a 206c 2070 2074 2077 2079
1 207d 2081 2085 2088 208c 2090 2094
2098 209b 209f 20a3 20a6 20a9 20ae 20b1
20b4 20b7 20b8 20bd 20be 1 20c0 20c5
20c9 20cd 20d0 20d5 20da 20dd 20e1 20e2
20e7 20ea 20ef 20f0 20f5 20f8 20fd 20fe
2103 2106 210a 210b 2110 2113 2118 2119
211e 2121 2125 2129 212c 212f 2130 2132
2133 2138 2139 213e 2140 2144 2147 2149
214d 214f 215b 215d 215f 2160 2165 2169
216b 2177 2179 2181 2183 2184 2187 2189
218d 2194 2198 219c 21a1 21a3 21a7 21ab
21ae 21b2 21b6 21b8 1 21bc 21c0 21c4
21c7 21cb 21cf 21d3 21d7 21da 21de 21e2
21e5 21e8 21ed 21f0 21f3 21f6 21f7 21fc
21fd 1 21ff 2204 2208 220c 220f 2214
2219 221c 2220 2221 2226 2229 222e 222f
2234 2237 223c 223d 2242 2245 2249 224a
224f 2252 2257 2258 225d 2260 2264 2268
226b 226e 226f 2271 2272 2277 2278 227d
227f 2283 2286 2288 228c 228e 229a 229c
229e 229f 22a4 22a8 22aa 22b6 22b8 22bc
22c0 22c3 22c4 22c6 22c9 22cc 22cf 22d0
22d5 22d6 22db 22df 22e3 22e7 22e8 22ea
22ee 22f0 22f4 22f7 22f9 22fd 2300 2304
2308 230b 230f 2313 2316 2319 231e 2321
2324 2327 2328 232d 232e 1 2330 2335
2339 233d 2340 2345 234a 234d 2351 2352
2357 235a 235f 2360 2365 2368 236d 236e
2373 2376 237a 237e 2382 2386 2389 238a
238c 2391 2392 2394 2395 239a 239d 23a2
23a3 23a8 23ab 23b0 23b1 23b6 23b9 23bd
23be 23c3 23c6 23cb 23cc 23d1 23d2 23d7
23d9 23dd 23e0 23e4 23e8 23eb 23ef 23f3
23f6 23fa 23fe 23ff 2404 2406 240a 240e
2411 2415 2419 241c 2420 2424 2427 242a
242f 2432 2435 2438 2439 243e 243f 1
2441 2446 244a 244e 2451 2456 245b 245e
2462 2463 2468 2469 246e 2472 2476 2479
247e 2483 2486 248a 248e 2491 2492 2497
249a 249f 24a0 24a5 24a8 24ac 24b0 24b3
24b4 24b9 24ba 24bf 24c1 24c5 24c8 24cc
24d0 24d4 24d8 24dc 24e0 24e4 24e8 24ec
24f8 24fd 2501 2505 2509 250d 250f 2510
2515 1 2519 251d 2521 2524 2528 252c
2530 2534 2537 253b 253f 2542 2545 254a
254d 2550 2553 2554 2559 255a 1 255c
2561 2565 2569 256c 2571 2576 2579 257d
257e 2583 2584 2589 258d 2591 2594 2599
259e 25a1 25a5 25a6 25ab 25ae 25b3 25b4
25b9 25bc 25c0 25c4 25c7 25ca 25cb 25cd
25ce 25d3 25d4 25d9 25db 25df 25e2 25e6
25ea 25ee 25f2 25f6 25fa 25fe 260a 260f
2613 2617 261b 261f 2621 2625 2627 2633
2635 2637 2638 263d 2641 2643 264f 2653
2655 2656 265f 
ab3
2
0 1 a 6 c :3 6 11 :3 6
12 :2 6 1 3 a 13 a :2 1
4 :3 12 :2 4 11 1a 19 :2 11 :2 4
b 14 13 :2 b :2 4 :3 11 :2 4 e
17 16 :2 e :2 4 18 21 20 :2 18
:2 4 f 18 17 :2 f :2 4 :2 e 1d
e :2 4 :2 d 1c d :2 4 :2 b 1a
b :2 4 :3 e :2 4 :2 14 23 14 :2 4
:2 f 1e f :2 4 :2 15 24 15 :2 4
:2 12 21 12 :2 4 :2 11 20 11 :2 4
:2 12 21 12 :2 4 :2 13 22 13 :2 4
:2 1a 29 1a :2 4 f 18 17 :2 f
:2 4 f 18 17 :2 f :2 4 :2 f 1e
f :2 4 :2 11 20 11 :2 4 :2 12 2a
12 :2 4 :3 17 4 7 e 0 :2 7
11 1d 2a 14 30 41 14 31
43 f 10 1d 2e 38 43 4f
58 60 69 77 80 8e 97 a5
ae bb c4 d5 de f1 fa 10f
118 133 13c 154 15d 16e 177 189
192 1aa 1b3 1c6 1cf 11 1e 38
45 54 64 e 2c a :6 7 e
0 :2 7 11 24 2e 34 3f 4d
5a f 10 1d e 18 11 1c
34 3f 4c 5c e 2c a :5 7
4 e 17 :3 e 4 7 :2 11 23
:2 2d 3a :2 23 :3 7 :2 d 19 25 :2 2f
43 :2 25 57 5d 60 :2 57 6e 87
8 :2 6e d 10 :2 6e 16 19 :2 6e
b e :2 6e 13 16 1f 27 :2 1f
34 :2 16 :2 6e b e :2 6e 13 16
:2 6e 1b 1e :2 6e 2a 2d :2 6e 32
35 :2 6e :2 7 4d :2 4 7 :2 11 23
:2 2d 39 3c 4f 51 52 :2 4f :2 23
:3 7 :2 d 12 1e 60 63 :2 1e :2 7
55 :3 4 11 :2 4 12 :2 4 12 :2 4
12 4 e 1a 20 27 c 1a
22 c 1a 27 :2 7 :2 10 1c 7
4 :2 c a :2 13 1f a d :2 17
29 :2 33 3f 43 56 58 59 :2 56
:2 29 :3 d :2 13 18 24 66 69 :2 24
76 79 :2 24 7d 80 :2 24 8c 8f
:2 24 97 9a :2 24 a6 a9 b0 b9
bc :2 a9 :2 24 :2 d 5c :2 a :2 7 :4 13
:2 7 4 :3 1 8 :2 11 1c 1a :2 25
:2 1a 7 :4 3b 3a 39 :3 7 11 18
1f 22 :2 18 27 2a :2 11 :2 7 13
14 :2 13 7 11 28 37 45 52
:2 a :2 13 1f a 7 :2 f d :2 16
22 d 10 :2 1a 2c :2 36 42 46
59 5c 5d :2 59 :2 2c :3 10 :2 16 1b
27 6a 6d :2 27 7a 7d :2 27 81
84 :2 27 90 93 :2 27 9b 9e :2 27
aa ad b4 bd c0 :2 ad :2 27 :2 10
60 :2 d :2 a :4 16 :2 a 7 :3 50 7
c :4 7 10 1d 28 32 40 :3 a
d 15 :2 d :2 16 22 d 1b d
:2 16 22 d :4 a e :2 17 23 20
:2 2c :2 20 :3 d 3c :2 a d 16 20
:2 d 23 25 :2 23 10 19 24 :2 10
27 29 :2 27 1a :3 13 19 26 37
44 13 1a 16 22 :3 20 16 :2 1f
2b 16 27 16 :2 1f 2b 16 :4 13
10 :2 18 16 :2 1f 2b 16 19 :2 23
35 :2 3f 4b 4f 62 65 66 :2 62
:2 35 :3 19 :2 1f 24 30 73 76 :2 30
83 86 :2 30 8a 8d :2 30 99 9c
:2 30 a4 a7 :2 30 b3 b6 bd c6
c9 :2 b6 :2 30 :2 19 69 :2 16 :2 13 :4 1f
:2 13 10 :3 2b 10 20 :2 10 29 38
44 4f 5b 67 29 37 :2 67 :2 29
10 2b 15 10 :4 d 27 d 12
:4 d 16 23 38 44 50 5e 6d
:3 10 13 1b :2 13 :2 1c 28 13 21
13 :2 1c 28 13 :4 10 14 :2 1d 29
26 :2 32 :2 26 :3 13 42 :3 10 24 10
13 1c 27 :2 13 2a 2c :2 2a 16
1d 29 2c :2 16 2f 31 :2 2f 20
1d 1f 33 1d 32 1d 27 30
19 20 1c 28 :3 26 1c :2 25 31
1c 2d 1c :2 25 31 1c :4 19 16
:2 1e 1c :2 25 31 1c 1f :2 29 3b
:2 45 51 55 68 6b 6c :2 68 :2 3b
:3 1f :2 25 2a 36 79 7c :2 36 89
8c :2 36 90 93 :2 36 9f a2 :2 36
aa ad :2 36 b9 bc c3 cc cf
:2 bc :2 36 :2 1f 6f :2 1c :2 19 :4 25 :2 19
16 :3 35 19 22 2e :2 19 31 33
34 :2 33 :2 31 23 1c 32 1c 32
1c 32 1c 32 1c 32 1c 32
1c 32 1c 32 1c 32 3f 1c
22 36 1c 23 1f 2b :3 29 1f
:2 28 34 1f 30 1f :2 28 34 1f
:4 1c 19 :2 21 1f :2 28 34 1f 22
:2 2c 3e :2 48 54 58 6b 6e 6f
:2 6b :2 3e :3 22 :2 28 2d 39 7c 7f
:2 39 8c 8f :2 39 93 96 :2 39 a2
a5 :2 39 ad b0 :2 39 bc bf c6
cf d2 :2 bf :2 39 :2 22 72 :2 1f :2 1c
:4 28 :2 1c 19 :4 36 23 1c 29 1c
24 31 22 36 1c 23 1f 2b
:3 29 1f :2 28 34 1f 30 1f :2 28
34 1f :4 1c 19 :2 21 1f :2 28 34
1f 22 :2 2c 3e :2 48 54 58 6b
6e 6f :2 6b :2 3e :3 22 :2 28 2d 39
7c 7f :2 39 8c 8f :2 39 93 96
:2 39 a2 a5 :2 39 ad b0 :2 39 bc
bf c6 cf d2 :2 bf :2 39 :2 22 72
:2 1f :2 1c :4 28 :2 1c 19 :7 16 35 20
19 23 :3 19 1f 33 19 20 1c
28 :3 26 1c :2 25 31 1c 2d 1c
:2 25 31 1c :4 19 16 :2 1e 1c :2 25
31 1c 1f :2 29 3b :2 45 51 55
68 6b 6c :2 68 :2 3b :3 1f :2 25 2a
36 79 7c :2 36 89 8c :2 36 90
93 :2 36 9f a2 :2 36 aa ad :2 36
b9 bc c3 cc cf :2 bc :2 36 :2 1f
6f :2 1c :2 19 :4 25 :2 19 16 :7 13 2e
16 1f 2a :2 16 2d 2f :2 2d 20
:3 19 1f 33 19 20 1c 28 :3 26
1c :2 25 31 1c 2d 1c :2 25 31
1c :4 19 16 :2 1e 1c :2 25 31 1c
1f :2 29 3b :2 45 51 55 68 6b
6c :2 68 :2 3b :3 1f :2 25 2a 36 79
7c :2 36 89 8c :2 36 90 93 :2 36
9f a2 :2 36 aa ad :2 36 b9 bc
c3 cc cf :2 bc :2 36 :2 1f 6f :2 1c
:2 19 :4 25 :2 19 16 :4 31 19 20 2c
2f :2 19 32 34 :2 32 23 20 22
36 20 35 20 2a 33 1c 23
1f 2b :3 29 1f :2 28 34 1f 30
1f :2 28 34 1f :4 1c 19 :2 21 1f
:2 28 34 1f 22 :2 2c 3e :2 48 54
58 6b 6e 6f :2 6b :2 3e :3 22 :2 28
2d 39 7c 7f :2 39 8c 8f :2 39
93 96 :2 39 a2 a5 :2 39 ad b0
:2 39 bc bf c6 cf d2 :2 bf :2 39
:2 22 72 :2 1f :2 1c :4 28 :2 1c 19 :3 38
23 :4 1c 33 43 54 67 1c 2c
3c 4d 5d 22 36 1c 23 1f
2b :3 29 1f :2 28 34 1f 30 1f
:2 28 34 1f :4 1c 19 :2 21 1f :2 28
34 1f 22 :2 2c 3e :2 48 54 58
6b 6e 6f :2 6b :2 3e :3 22 :2 28 2d
39 7c 7f :2 39 8c 8f :2 39 93
96 :2 39 a2 a5 :2 39 ad b0 :2 39
bc bf c6 cf d2 :2 bf :2 39 :2 22
72 :2 1f :2 1c :4 28 :2 1c 19 :4 38 23
:4 1c 22 30 22 36 1c 23 1f
2b :3 29 1f :2 28 34 1f 30 1f
:2 28 34 1f :4 1c 19 :2 21 1f :2 28
34 1f 22 :2 2c 3e :2 48 54 58
6b 6e 6f :2 6b :2 3e :3 22 :2 28 2d
39 7c 7f :2 39 8c 8f :2 39 93
96 :2 39 a2 a5 :2 39 ad b0 :2 39
bc bf c6 cf d2 :2 bf :2 39 :2 22
72 :2 1f :2 1c :4 28 :2 1c 19 :7 16 :4 13
:4 10 14 :2 1d 28 26 :2 31 :2 26 :2 13
27 13 41 :3 10 20 :2 10 29 38
44 59 65 2b 34 42 :2 2b :2 29
10 13 1c 2e :2 13 31 33 :2 31
18 1f 28 33 :2 1f 37 :2 18 17
3b 3d :2 3b 16 45 4e 5e :2 45
61 63 :2 61 44 :3 16 2c 34 3d
47 :2 3d 57 :2 34 5a 5c 28 32
:2 28 41 :2 5c :2 34 33 45 47 :2 33
32 51 53 28 38 :2 53 :2 32 :2 2c
16 1a 2d 2f :2 2d 19 35 48
4a 4b :2 4a :2 48 :2 19 23 1c 2a
33 3a 46 4f 1c 21 3b 48
21 22 36 1c 23 1f 2b :3 29
1f :2 28 34 1f 30 1f :2 28 34
1f :4 1c 19 :2 21 1f :2 28 34 1f
22 :2 2c 3e :2 48 54 58 6b 6e
6f :2 6b :2 3e :3 22 :2 28 2d 39 7c
7f :2 39 8c 8f :2 39 93 96 :2 39
a2 a5 :2 39 ad b0 :2 39 bc bf
c6 cf d2 :2 bf :2 39 :2 22 72 :2 1f
:2 1c :4 28 :2 1c 19 :4 4d 23 1c 37
52 5f 71 22 36 1c 23 1f
2b :3 29 1f :2 28 34 1f 30 1f
:2 28 34 1f :4 1c 19 :2 21 1f :2 28
34 1f 22 :2 2c 3e :2 48 54 58
6b 6e 6f :2 6b :2 3e :3 22 :2 28 2d
39 7c 7f :2 39 8c 8f :2 39 93
96 :2 39 a2 a5 :2 39 ad b0 :2 39
bc bf c6 cf d2 :2 bf :2 39 :2 22
72 :2 1f :2 1c :4 28 :2 1c 19 :8 16 29
3b 49 :2 29 16 66 :2 13 35 :2 10
d 11 a 10 16 :3 10 :2 19 25
10 d :2 15 13 :2 1c 28 13 16
:2 20 32 :2 3c 48 4c 5f 62 63
:2 5f :2 32 :3 16 :2 1c 21 2d 70 73
:2 2d 80 83 :2 2d 87 8a :2 2d 96
99 :2 2d a1 a4 :2 2d b0 b3 ba
c3 c6 :2 b3 :2 2d :2 16 66 :2 13 :2 10
:4 1c :2 10 d :7 a 14 d 12 1a
21 39 41 48 d 12 1a 21
39 41 48 60 13 20 31 3e
d 14 10 1c :3 1a 10 :2 19 25
10 21 10 :2 19 25 10 :4 d a
:2 12 10 :2 19 25 10 13 :2 1d 2f
:2 39 45 49 5c 5f 60 :2 5c :2 2f
:3 13 :2 19 1e 2a 6d 70 :2 2a 7d
80 :2 2a 84 87 :2 2a 93 96 :2 2a
9e a1 :2 2a ad b0 b7 c0 c3
:2 b0 :2 2a :2 13 63 :2 10 :2 d :4 19 :2 d
a :3 7 c a :3 7 b 50 a
10 :3 a :2 13 1f a 7 :2 f d
:2 16 22 d 10 :2 1a 2c :2 36 42
46 59 5c 5d :2 59 :2 2c :3 10 :2 16
1b 27 6a 6d :2 27 7a 7d :2 27
81 84 :2 27 90 93 :2 27 9b 9e
:2 27 aa ad b4 bd c0 :2 ad :2 27
:2 10 60 :2 d :2 a :4 16 :2 a 7 :3 50
a 13 1d :2 a 20 22 23 :2 22
:2 20 a 1d 27 :2 1d a 25 :2 7
50 :2 4 7 :2 11 23 :2 2d 39 3c
4f 52 53 :2 4f :2 23 :3 7 :2 d 12
1e 61 64 :2 1e 71 74 :2 1e 78
7b :2 1e 85 88 91 99 :2 a2 :2 91
ad :2 88 :2 1e b5 b8 :2 1e c0 c3
:2 1e c8 cb :2 1e d1 d4 :2 1e :2 7
56 :3 4 :2 f 21 :2 2a 34 3b :2 4
1 9 12 9 a :2 14 26 :2 30
3c 40 53 56 57 :2 53 :2 26 :3 a
:2 10 15 21 64 67 :2 21 :3 a :2 10
15 39 5c 5f :2 68 :2 39 76 79
:2 39 81 84 :2 8d :2 39 :2 a 5a :3 7
c 15 1e 2c a 13 1e f
e 7 e 7 e 7 29 :2 4
:2 9 7 :2 10 1c :2 7 :2 11 23 :2 2d
39 3d 50 53 54 :2 50 :2 23 :3 7
:2 d 12 1e 61 64 :2 1e :3 7 :2 d
12 36 42 45 :2 36 4d 50 :2 36
5c 5f 66 6f 72 :2 5f :2 36 :2 7
57 :2 4 7 c 1b a 13 1e
f e 7 e 7 e 7 :2 4
:4 10 :2 4 :8 1 
ab3
4
0 :2 1 :4 3 :4 4
:4 5 2 :4 6 :2 1
:5 8 :7 9 :7 a :5 b
:7 c :7 d :7 e :6 f
:6 10 :6 11 :5 12 :6 13
:6 14 :6 15 :6 16 :6 17
:6 18 :6 19 :6 1a :7 1b
:7 1c :6 1d :6 1e :6 1f
:5 20 :2 22 0 :2 22
:3 23 :3 24 :3 25 26
:23 27 :6 28 :2 29 23
:5 22 :2 2b 0 :2 2b
:7 2c 2d :2 2e :2 2f
:6 30 :2 31 2c :5 2b
:7 33 :b 35 :11 36 37
:2 36 :2 37 :2 36 :2 37
:2 36 :2 38 :2 36 :9 38
:2 36 :2 39 :2 36 :2 39
:2 36 :2 39 :2 36 :2 39
:2 36 :2 39 :4 36 :3 35
:11 3c :b 3d :3 3c :3 43
:3 46 :3 47 :3 48 :4 4b
:3 4c :3 4d 4b :5 4e
4a :2 50 :5 52 :11 53
:24 54 :3 53 :2 51 :6 50
4f :3 34 :12 5a :c 5b
:6 5c :6 5f :5 60 5e
:2 62 :5 64 :11 65 :24 66
:3 65 :2 63 :6 62 61
:3 5a :5 6b 6d :8 6e
:3 6f :5 70 6f :5 72
71 :3 6f :a 75 :2 76
:3 75 :9 7a :9 7c 7f
80 81 82 :4 83
7f :6 84 :5 85 84
:5 87 86 :3 84 7e
:2 8a :5 8c :11 8d :24 8e
:3 8d :2 8b :6 8a 89
:3 7c :3 94 :7 95 :2 96
:5 95 7c :2 98 97
:3 7c 7a :5 9d 9f
:a a0 :3 a1 :5 a2 a1
:5 a4 a3 :3 a1 :a a7
:2 a8 :3 a7 :3 ac :9 ad
:a ae b0 b1 :2 b2
:2 b3 :3 b4 b0 :6 b5
:5 b6 b5 :5 b8 b7
:3 b5 af :2 bb :5 bd
:11 be :24 bf :3 be :2 bc
:6 bb ba :3 ae :c c4
c6 :2 c7 :2 c8 :2 c9
:2 ca :2 cb :2 cc :2 cd
:2 ce :3 cf d0 :2 d1
c6 :6 d2 :5 d3 d2
:5 d5 d4 :3 d2 c5
:2 d8 :5 da :11 db :24 dc
:3 db :2 d9 :6 d8 d7
:4 c4 ea :2 eb :3 ec
:2 ed ea :6 ee :5 ef
ee :5 f1 f0 :3 ee
e9 :2 f4 :5 f6 :11 f7
:24 f8 :3 f7 :2 f5 :6 f4
f3 :4 e0 :3 c4 ae
ff :2 100 101 102
103 :2 104 ff :6 105
:5 106 105 :5 108 107
:3 105 fe :2 10b :5 10d
:11 10e :24 10f :3 10e :2 10c
:6 10b 10a :4 fd :3 ae
ad :9 116 119 11a
11b 11c :2 11d 119
:6 11e :5 11f 11e :5 121
120 :3 11e 118 :2 124
:5 126 :11 127 :24 128 :3 127
:2 125 :6 124 123 :4 116
:a 12e 130 131 :2 132
:2 133 :3 134 130 :6 135
:5 136 135 :5 138 137
:3 135 12f :2 13b :5 13d
:11 13e :24 13f :3 13e :2 13c
:6 13b 13a :3 12e 145
146 147 148 :5 149
:5 14a :2 14c 145 :6 14d
:5 14e 14d :5 150 14f
:3 14d 144 :2 153 :5 155
:11 156 :24 157 :3 156 :2 154
:6 153 152 :4 12e 15d
15e 15f 160 :3 161
:2 162 15d :6 163 :5 164
163 :5 166 165 :3 163
15c :2 169 :5 16b :11 16c
:24 16d :3 16c :2 16a :6 169
168 :4 15b :3 12e 12c
:3 116 115 :3 ad :a 175
:3 176 :3 175 :3 17a :6 17b
:5 17c :3 17b :9 17f :1b 180
:c 181 :5 182 :5 181 :2 182
:3 181 :2 182 :2 183 :2 182
:5 181 :10 184 186 :6 187
188 :3 189 18a :2 18c
186 :6 18d :5 18e 18d
:5 190 18f :3 18d 185
:2 193 :5 195 :11 196 :24 197
:3 196 :2 194 :6 193 192
:4 184 19d :5 19e :2 19f
19d :6 1a0 :5 1a1 1a0
:5 1a3 1a2 :3 1a0 19c
:2 1a6 :5 1a8 :11 1a9 :24 1aa
:3 1a9 :2 1a7 :6 1a6 1a5
:4 19b :3 184 :7 1b3 :3 180
:3 17f 9f 1b6 9a
:4 1ba :5 1bb 1b9 :2 1bd
:5 1bf :11 1c0 :24 1c1 :3 1c0
:2 1be :6 1bd 1bc :4 9a
:3 7a 1c9 1ca :6 1cc
1cf :7 1d1 :4 1d4 1c9
:6 1d5 :5 1d6 1d5 :5 1d8
1d7 :3 1d5 1c8 :2 1db
:5 1dd :11 1de :24 1df :3 1de
:2 1dc :6 1db 1da :3 6d
1e3 1e4 :3 6d 1e5
5a :4 1e9 :5 1ea 1e8
:2 1ec :5 1ee :11 1ef :24 1f0
:3 1ef :2 1ed :6 1ec 1eb
:3 5a :c 1f5 :6 1f6 :3 1f5
:3 5a :11 1fb :30 1fc :3 1fb
:a 1fe 34 :3 201 :11 202
:b 203 :17 204 :3 202 :2 206
:3 207 :3 208 209 207
206 207 :3 20a :3 201
:2 20b :5 20d :11 20e :b 20f
:18 210 :3 20e :2 212 213
:3 214 215 213 212
213 :3 216 :2 20c :6 20b
200 :7 1 
2661
4
:3 0 1 :3 0 2
:a 0 aae 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
:2 0 7 6 :3 0
5 :7 0 9 8
:3 0 4 :3 0 7
:7 0 d c :3 0
8 :3 0 9 :3 0
a :2 0 4 11
12 0 f 13
0 aae 2 14
:2 0 e :2 0 d
c :3 0 17 :7 0
1a 18 0 aac
0 b :6 0 10
:2 0 11 4 :3 0
f 1c 1e :6 0
21 1f 0 aac
0 d :6 0 17
c3 0 15 4
:3 0 13 23 25
:6 0 28 26 0
aac 0 f :6 0
e :2 0 1b c
:3 0 2a :7 0 2d
2b 0 aac 0
11 :6 0 4 :3 0
e :2 0 19 2f
31 :6 0 34 32
0 aac 0 12
:6 0 15 :2 0 1f
4 :3 0 1d 36
38 :6 0 3b 39
0 aac 0 13
:6 0 17 :2 0 23
4 :3 0 21 3d
3f :6 0 42 40
0 aac 0 14
:6 0 17 :2 0 25
6 :3 0 44 :7 0
48 45 46 aac
0 16 :6 0 17
:2 0 27 6 :3 0
4a :7 0 4e 4b
4c aac 0 18
:6 0 2b 189 0
29 6 :3 0 50
:7 0 54 51 52
aac 0 19 :6 0
17 :2 0 2d 1b
:3 0 56 :7 0 59
57 0 aac 0
1a :6 0 6 :3 0
5b :7 0 17 :2 0
5f 5c 5d aac
0 1c :6 0 17
:2 0 2f 6 :3 0
61 :7 0 65 62
63 aac 0 1d
:6 0 17 :2 0 31
6 :3 0 67 :7 0
6b 68 69 aac
0 1e :6 0 17
:2 0 33 6 :3 0
6d :7 0 71 6e
6f aac 0 1f
:6 0 17 :2 0 35
6 :3 0 73 :7 0
77 74 75 aac
0 20 :6 0 17
:2 0 37 6 :3 0
79 :7 0 7d 7a
7b aac 0 21
:6 0 17 :2 0 39
6 :3 0 7f :7 0
83 80 81 aac
0 22 :6 0 e
:2 0 3b 6 :3 0
85 :7 0 89 86
87 aac 0 23
:6 0 e :2 0 3f
4 :3 0 3d 8b
8d :6 0 90 8e
0 aac 0 24
:6 0 17 :2 0 43
4 :3 0 41 92
94 :6 0 97 95
0 aac 0 25
:6 0 17 :2 0 45
6 :3 0 99 :7 0
9d 9a 9b aac
0 26 :6 0 17
:2 0 47 6 :3 0
9f :7 0 a3 a0
a1 aac 0 27
:6 0 4b 312 0
49 6 :3 0 a5
0 2 :5 0 a9
a6 a7 aac 0
28 :6 0 2a :3 0
6 :3 0 ab :7 0
ae ac 0 aac
0 29 :6 0 2b
:a 0 2 ea :5 0
b0 b3 0 b1
:3 0 2c :3 0 2d
:3 0 2e :3 0 2f
:3 0 30 :3 0 2f
:3 0 31 :3 0 32
:3 0 31 :3 0 33
:3 0 34 :3 0 d
:3 0 35 :3 0 f
:3 0 36 :3 0 37
:3 0 38 :3 0 37
:3 0 39 :3 0 37
:3 0 3a :3 0 37
:3 0 3b :3 0 37
:3 0 3c :3 0 37
:3 0 3d :3 0 37
:3 0 3e :3 0 37
:3 0 3f :3 0 37
:3 0 40 :3 0 37
:3 0 41 :3 0 37
:3 0 42 :3 0 37
:3 0 43 :3 0 37
:3 0 44 :3 0 37
:3 0 45 :3 0 37
:3 0 46 :3 0 2d
:3 0 2e :3 0 2d
:3 0 2e :3 0 47
:3 0 48 :3 0 2f
:3 0 31 :4 0 49
1 :8 0 eb b0
b3 ec 0 aac
4d ec ee eb
ed :6 0 ea :7 0
ec 2a :3 0 4a
:a 0 3 109 :5 0
f0 f3 0 f1
:3 0 4b :3 0 4c
:3 0 4d :3 0 4e
:3 0 4f :3 0 47
:3 0 50 :3 0 51
:3 0 34 :3 0 d
:3 0 52 :3 0 12
:3 0 4e :3 0 4f
:3 0 4e :3 0 4f
:3 0 47 :3 0 48
:3 0 2f :3 0 31
:4 0 53 1 :8 0
10a f0 f3 10b
0 aac 4f 10b
10d 10a 10c :6 0
109 :7 0 10b 115
116 0 51 9
:3 0 a :2 0 4
10f 110 0 111
:7 0 114 112 0
aac 0 54 :6 0
55 :3 0 56 :3 0
55 :3 0 57 :3 0
118 119 0 2
:4 0 53 11a 11c
117 11e 11d :2 0
58 :3 0 59 :3 0
120 121 0 5a
:4 0 55 :3 0 5b
:3 0 124 125 0
2 :4 0 55 126
128 5c :4 0 5d
:2 0 5e :3 0 57
12b 12d :3 0 5f
:4 0 5d :2 0 60
:4 0 5a 130 132
:3 0 5d :2 0 3
:3 0 5d 134 136
:3 0 5d :2 0 60
:4 0 60 138 13a
:3 0 5d :2 0 61
:4 0 63 13c 13e
:3 0 5d :2 0 62
:3 0 63 :3 0 5
:3 0 66 142 144
64 :4 0 68 141
147 6b 140 149
:3 0 5d :2 0 61
:4 0 6e 14b 14d
:3 0 5d :2 0 60
:4 0 71 14f 151
:3 0 5d :2 0 7
:3 0 74 153 155
:3 0 5d :2 0 60
:4 0 77 157 159
:3 0 5d :2 0 65
:4 0 7a 15b 15d
:3 0 7d 122 15f
:2 0 161 82 162
11f 161 0 163
84 0 a0c 55
:3 0 56 :3 0 164
165 0 55 :3 0
66 :3 0 167 168
0 15 :2 0 2
:4 0 67 :2 0 68
:2 0 15 :2 0 86
16d 16f :3 0 89
169 171 166 173
172 :2 0 58 :3 0
69 :3 0 175 176
0 5a :4 0 6a
:4 0 5d :2 0 5e
:3 0 8d 17a 17c
:3 0 90 177 17e
:2 0 180 93 181
174 180 0 182
95 0 a0c 16
:3 0 5 :3 0 183
184 0 a0c 25
:3 0 7 :3 0 186
187 0 a0c 26
:3 0 6b :2 0 189
18a 0 a0c 24
:3 0 6c :4 0 18c
18d 0 a0c 34
:3 0 6d :3 0 35
:3 0 36 :3 0 d
:3 0 f :3 0 19
:3 0 33 :3 0 2c
:3 0 3 :4 0 6e
1 :8 0 19f 9
:3 0 6f :3 0 19a
19b 0 70 :3 0
19c 19d 0 19f
97 1e9 71 :3 0
9 :3 0 6f :3 0
1a2 1a3 0 70
:3 0 1a4 1a5 0
1df 55 :3 0 56
:3 0 1a7 1a8 0
55 :3 0 66 :3 0
1aa 1ab 0 72
:2 0 2 :4 0 73
:2 0 68 :2 0 15
:2 0 9a 1b0 1b2
:3 0 9d 1ac 1b4
1a9 1b6 1b5 :2 0
58 :3 0 69 :3 0
1b8 1b9 0 5a
:4 0 74 :4 0 5d
:2 0 5e :3 0 a1
1bd 1bf :3 0 5d
:2 0 75 :4 0 a4
1c1 1c3 :3 0 5d
:2 0 76 :4 0 a7
1c5 1c7 :3 0 5d
:2 0 70 :3 0 aa
1c9 1cb :3 0 5d
:2 0 77 :4 0 ad
1cd 1cf :3 0 5d
:2 0 78 :3 0 79
:3 0 15 :2 0 7a
:2 0 b0 1d2 1d6
b4 1d1 1d8 :3 0
b7 1ba 1da :2 0
1dc ba 1dd 1b7
1dc 0 1de bc
0 1df be 1e2
:3 0 1e2 0 1e2
1e1 1df 1e0 :6 0
1e4 4 :3 0 c1
1e6 c3 1e5 1e4
:2 0 1e7 c5 :2 0
1e9 0 1e9 1e8
19f 1e7 :6 0 a0c
1 :3 0 9 :3 0
6f :3 0 1eb 1ec
0 9 :3 0 7b
:2 0 7c :3 0 1ee
1f0 0 c9 1ef
1f2 :3 0 1f3 :2 0
19 :3 0 7d :2 0
cc 1f6 1f7 :3 0
1f8 :2 0 1f9 :2 0
1f4 1fb 1fa :2 0
f :3 0 78 :3 0
f :3 0 5d :2 0
7e :4 0 ce 200
202 :3 0 15 :2 0
10 :2 0 d1 1fe
206 1fd 207 0
9bb 18 :3 0 7f
:2 0 15 :2 0 d5
20a 20c :3 0 209
20d 0 9bb 80
:3 0 1a :3 0 33
:3 0 2c :3 0 d
:4 0 81 1 :8 0
21a 9 :3 0 6f
:3 0 215 216 0
70 :3 0 217 218
0 21a d7 264
71 :3 0 9 :3 0
6f :3 0 21d 21e
0 70 :3 0 21f
220 0 25a 55
:3 0 56 :3 0 222
223 0 55 :3 0
66 :3 0 225 226
0 72 :2 0 2
:4 0 82 :2 0 68
:2 0 15 :2 0 da
22b 22d :3 0 dd
227 22f 224 231
230 :2 0 58 :3 0
69 :3 0 233 234
0 5a :4 0 83
:4 0 5d :2 0 5e
:3 0 e1 238 23a
:3 0 5d :2 0 75
:4 0 e4 23c 23e
:3 0 5d :2 0 76
:4 0 e7 240 242
:3 0 5d :2 0 70
:3 0 ea 244 246
:3 0 5d :2 0 77
:4 0 ed 248 24a
:3 0 5d :2 0 78
:3 0 79 :3 0 15
:2 0 7a :2 0 f0
24d 251 f4 24c
253 :3 0 f7 235
255 :2 0 257 fa
258 232 257 0
259 fc 0 25a
fe 25d :3 0 25d
0 25d 25c 25a
25b :6 0 25f 6
:3 0 101 261 103
260 25f :2 0 262
105 :2 0 264 0
264 263 21a 262
:6 0 9bb 1 :3 0
84 :3 0 2b :4 0
269 :2 0 9bb 267
26a :3 0 85 :3 0
2b :3 0 12 :3 0
18 :3 0 11 :3 0
b :4 0 272 :2 0
94e 26c 273 :3 0
107 :3 0 2b :3 0
86 :3 0 274 275
:3 0 9 :3 0 6f
:3 0 277 278 0
17 :2 0 279 27a
0 27c 10c 283
9 :3 0 6f :3 0
27d 27e 0 87
:2 0 27f 280 0
282 10e 284 276
27c 0 285 0
282 0 285 110
0 94e 9 :3 0
6f :3 0 286 287
0 9 :3 0 88
:2 0 7c :3 0 289
28b 0 115 28a
28d :3 0 28e :2 0
89 :8 0 292 118
293 28f 292 0
294 11a 0 94e
62 :3 0 18 :3 0
17 :2 0 11c 295
298 7b :2 0 17
:2 0 121 29a 29c
:3 0 62 :3 0 16
:3 0 17 :2 0 124
29e 2a1 7b :2 0
8a :2 0 129 2a3
2a5 :3 0 33 :3 0
2f :3 0 31 :3 0
8b :3 0 34 :3 0
d :3 0 2c :3 0
12 :4 0 8c 1
:8 0 2c5 86 :4 0
2b0 :3 0 8d :3 0
7b :2 0 12e 2b3
2b4 :3 0 9 :3 0
6f :3 0 2b6 2b7
0 17 :2 0 2b8
2b9 0 2bb 131
2c2 9 :3 0 6f
:3 0 2bc 2bd 0
87 :2 0 2be 2bf
0 2c1 133 2c3
2b5 2bb 0 2c4
0 2c1 0 2c4
135 0 2c5 138
30f 71 :3 0 9
:3 0 6f :3 0 2c8
2c9 0 70 :3 0
2ca 2cb 0 305
55 :3 0 56 :3 0
2cd 2ce 0 55
:3 0 66 :3 0 2d0
2d1 0 72 :2 0
2 :4 0 8e :2 0
68 :2 0 15 :2 0
13b 2d6 2d8 :3 0
13e 2d2 2da 2cf
2dc 2db :2 0 58
:3 0 69 :3 0 2de
2df 0 5a :4 0
8f :4 0 5d :2 0
5e :3 0 142 2e3
2e5 :3 0 5d :2 0
75 :4 0 145 2e7
2e9 :3 0 5d :2 0
76 :4 0 148 2eb
2ed :3 0 5d :2 0
70 :3 0 14b 2ef
2f1 :3 0 5d :2 0
77 :4 0 14e 2f3
2f5 :3 0 5d :2 0
78 :3 0 79 :3 0
15 :2 0 7a :2 0
151 2f8 2fc 155
2f7 2fe :3 0 158
2e0 300 :2 0 302
15b 303 2dd 302
0 304 15d 0
305 15f 308 :3 0
308 0 308 307
305 306 :6 0 30a
9 :3 0 162 30c
164 30b 30a :2 0
30d 166 :2 0 30f
0 30f 30e 2c5
30d :6 0 322 8
:3 0 27 :3 0 15
:2 0 311 312 0
322 23 :3 0 90
:3 0 24 :3 0 12
:3 0 25 :3 0 26
:3 0 62 :3 0 27
:3 0 17 :2 0 168
31a 31d 16b 315
31f 314 320 0
322 171 326 91
:3 0 323 :4 0 325
175 327 2a6 322
0 328 0 325
0 328 177 0
329 17a 8d1 84
:3 0 4a :4 0 32d
:2 0 8d0 32b 32e
:3 0 85 :3 0 4a
:3 0 13 :3 0 14
:3 0 1d :3 0 20
:3 0 21 :3 0 22
:4 0 338 :2 0 878
330 339 :3 0 17c
:3 0 4a :3 0 86
:3 0 33a 33b :3 0
9 :3 0 6f :3 0
33d 33e 0 17
:2 0 33f 340 0
342 183 349 9
:3 0 6f :3 0 343
344 0 87 :2 0
345 346 0 348
185 34a 33c 342
0 34b 0 348
0 34b 187 0
878 9 :3 0 6f
:3 0 34c 34d 0
9 :3 0 88 :2 0
7c :3 0 34f 351
0 18c 350 353
:3 0 354 :2 0 89
:8 0 358 18f 359
355 358 0 35a
191 0 878 1e
:3 0 17 :2 0 35b
35c 0 878 62
:3 0 16 :3 0 17
:2 0 193 35e 361
7b :2 0 15 :2 0
198 363 365 :3 0
78 :3 0 14 :3 0
15 :2 0 15 :2 0
19b 367 36b 7b
:2 0 8a :4 0 1a1
36d 36f :3 0 92
:3 0 93 :3 0 4b
:3 0 13 :3 0 4b
:3 0 2c :3 0 36
:3 0 37 :3 0 94
:4 0 95 1 :8 0
390 86 :4 0 37b
:3 0 8d :3 0 7b
:2 0 1a6 37e 37f
:3 0 9 :3 0 6f
:3 0 381 382 0
17 :2 0 383 384
0 386 1a9 38d
9 :3 0 6f :3 0
387 388 0 87
:2 0 389 38a 0
38c 1ab 38e 380
386 0 38f 0
38c 0 38f 1ad
0 390 1b0 3da
71 :3 0 9 :3 0
6f :3 0 393 394
0 70 :3 0 395
396 0 3d0 55
:3 0 56 :3 0 398
399 0 55 :3 0
66 :3 0 39b 39c
0 72 :2 0 2
:4 0 96 :2 0 68
:2 0 15 :2 0 1b3
3a1 3a3 :3 0 1b6
39d 3a5 39a 3a7
3a6 :2 0 58 :3 0
69 :3 0 3a9 3aa
0 5a :4 0 97
:4 0 5d :2 0 5e
:3 0 1ba 3ae 3b0
:3 0 5d :2 0 75
:4 0 1bd 3b2 3b4
:3 0 5d :2 0 76
:4 0 1c0 3b6 3b8
:3 0 5d :2 0 70
:3 0 1c3 3ba 3bc
:3 0 5d :2 0 77
:4 0 1c6 3be 3c0
:3 0 5d :2 0 78
:3 0 79 :3 0 15
:2 0 7a :2 0 1c9
3c3 3c7 1cd 3c2
3c9 :3 0 1d0 3ab
3cb :2 0 3cd 1d3
3ce 3a8 3cd 0
3cf 1d5 0 3d0
1d7 3d3 :3 0 3d3
0 3d3 3d2 3d0
3d1 :6 0 3d5 c
:3 0 1da 3d7 1dc
3d6 3d5 :2 0 3d8
1de :2 0 3da 0
3da 3d9 390 3d8
:6 0 4d0 b :3 0
62 :3 0 1d :3 0
17 :2 0 1e0 3dc
3df 7b :2 0 7f
:2 0 15 :2 0 1e3
3e2 3e4 :3 0 1e7
3e1 3e6 :3 0 51
:3 0 98 :3 0 30
:3 0 99 :3 0 32
:3 0 9a :3 0 4e
:3 0 9b :3 0 30
:3 0 9c :3 0 32
:3 0 9d :3 0 4e
:3 0 9e :3 0 9f
:3 0 4d :3 0 4e
:3 0 48 :3 0 4e
:3 0 47 :3 0 a0
:3 0 4b :3 0 13
:4 0 a1 1 :8 0
415 86 :4 0 400
:3 0 8d :3 0 7b
:2 0 1ec 403 404
:3 0 9 :3 0 6f
:3 0 406 407 0
17 :2 0 408 409
0 40b 1ef 412
9 :3 0 6f :3 0
40c 40d 0 87
:2 0 40e 40f 0
411 1f1 413 405
40b 0 414 0
411 0 414 1f3
0 415 1f6 45f
71 :3 0 9 :3 0
6f :3 0 418 419
0 70 :3 0 41a
41b 0 455 55
:3 0 56 :3 0 41d
41e 0 55 :3 0
66 :3 0 420 421
0 72 :2 0 2
:4 0 a2 :2 0 68
:2 0 15 :2 0 1f9
426 428 :3 0 1fc
422 42a 41f 42c
42b :2 0 58 :3 0
69 :3 0 42e 42f
0 5a :4 0 a3
:4 0 5d :2 0 5e
:3 0 200 433 435
:3 0 5d :2 0 75
:4 0 203 437 439
:3 0 5d :2 0 76
:4 0 206 43b 43d
:3 0 5d :2 0 70
:3 0 209 43f 441
:3 0 5d :2 0 77
:4 0 20c 443 445
:3 0 5d :2 0 78
:3 0 79 :3 0 15
:2 0 7a :2 0 20f
448 44c 213 447
44e :3 0 216 430
450 :2 0 452 219
453 42d 452 0
454 21b 0 455
21d 458 :3 0 458
0 458 457 455
456 :6 0 45a e
:3 0 220 45c 222
45b 45a :2 0 45d
224 :2 0 45f 0
45f 45e 415 45d
:6 0 461 b :3 0
226 4cd 51 :3 0
4e :3 0 4e :3 0
48 :3 0 4e :3 0
47 :3 0 4b :3 0
13 :4 0 a4 1
:8 0 480 86 :4 0
46b :3 0 8d :3 0
7b :2 0 22a 46e
46f :3 0 9 :3 0
6f :3 0 471 472
0 17 :2 0 473
474 0 476 22d
47d 9 :3 0 6f
:3 0 477 478 0
87 :2 0 479 47a
0 47c 22f 47e
470 476 0 47f
0 47c 0 47f
231 0 480 234
4ca 71 :3 0 9
:3 0 6f :3 0 483
484 0 70 :3 0
485 486 0 4c0
55 :3 0 56 :3 0
488 489 0 55
:3 0 66 :3 0 48b
48c 0 72 :2 0
2 :4 0 a5 :2 0
68 :2 0 15 :2 0
237 491 493 :3 0
23a 48d 495 48a
497 496 :2 0 58
:3 0 69 :3 0 499
49a 0 5a :4 0
a6 :4 0 5d :2 0
5e :3 0 23e 49e
4a0 :3 0 5d :2 0
75 :4 0 241 4a2
4a4 :3 0 5d :2 0
76 :4 0 244 4a6
4a8 :3 0 5d :2 0
70 :3 0 247 4aa
4ac :3 0 5d :2 0
77 :4 0 24a 4ae
4b0 :3 0 5d :2 0
78 :3 0 79 :3 0
15 :2 0 7a :2 0
24d 4b3 4b7 251
4b2 4b9 :3 0 254
49b 4bb :2 0 4bd
257 4be 498 4bd
0 4bf 259 0
4c0 25b 4c3 :3 0
4c3 0 4c3 4c2
4c0 4c1 :6 0 4c5
10 :3 0 25e 4c7
260 4c6 4c5 :2 0
4c8 262 :2 0 4ca
0 4ca 4c9 480
4c8 :6 0 4cc b
:3 0 264 4ce 3e7
461 0 4cf 0
4cc 0 4cf 266
0 4d0 269 53c
51 :3 0 48 :3 0
4f :3 0 50 :3 0
a0 :3 0 a7 :3 0
4b :3 0 13 :4 0
a8 1 :8 0 4ef
86 :4 0 4da :3 0
8d :3 0 7b :2 0
26e 4dd 4de :3 0
9 :3 0 6f :3 0
4e0 4e1 0 17
:2 0 4e2 4e3 0
4e5 271 4ec 9
:3 0 6f :3 0 4e6
4e7 0 87 :2 0
4e8 4e9 0 4eb
273 4ed 4df 4e5
0 4ee 0 4eb
0 4ee 275 0
4ef 278 539 71
:3 0 9 :3 0 6f
:3 0 4f2 4f3 0
70 :3 0 4f4 4f5
0 52f 55 :3 0
56 :3 0 4f7 4f8
0 55 :3 0 66
:3 0 4fa 4fb 0
72 :2 0 2 :4 0
a9 :2 0 68 :2 0
15 :2 0 27b 500
502 :3 0 27e 4fc
504 4f9 506 505
:2 0 58 :3 0 69
:3 0 508 509 0
5a :4 0 aa :4 0
5d :2 0 5e :3 0
282 50d 50f :3 0
5d :2 0 75 :4 0
285 511 513 :3 0
5d :2 0 76 :4 0
288 515 517 :3 0
5d :2 0 70 :3 0
28b 519 51b :3 0
5d :2 0 77 :4 0
28e 51d 51f :3 0
5d :2 0 78 :3 0
79 :3 0 15 :2 0
7a :2 0 291 522
526 295 521 528
:3 0 298 50a 52a
:2 0 52c 29b 52d
507 52c 0 52e
29d 0 52f 29f
532 :3 0 532 0
532 531 52f 530
:6 0 534 12 :3 0
2a2 536 2a4 535
534 :2 0 537 2a6
:2 0 539 0 539
538 4ef 537 :6 0
53b b :3 0 2a8
53d 370 4d0 0
53e 0 53b 0
53e 2aa 0 53f
2ad 70e 62 :3 0
16 :3 0 17 :2 0
2af 540 543 7b
:2 0 8a :2 0 2b4
545 547 :3 0 51
:3 0 2f :3 0 31
:3 0 8b :3 0 4b
:3 0 13 :4 0 ab
1 :8 0 565 86
:4 0 550 :3 0 8d
:3 0 7b :2 0 2b9
553 554 :3 0 9
:3 0 6f :3 0 556
557 0 17 :2 0
558 559 0 55b
2bc 562 9 :3 0
6f :3 0 55c 55d
0 87 :2 0 55e
55f 0 561 2be
563 555 55b 0
564 0 561 0
564 2c0 0 565
2c3 5af 71 :3 0
9 :3 0 6f :3 0
568 569 0 70
:3 0 56a 56b 0
5a5 55 :3 0 56
:3 0 56d 56e 0
55 :3 0 66 :3 0
570 571 0 72
:2 0 2 :4 0 ac
:2 0 68 :2 0 15
:2 0 2c6 576 578
:3 0 2c9 572 57a
56f 57c 57b :2 0
58 :3 0 69 :3 0
57e 57f 0 5a
:4 0 ad :4 0 5d
:2 0 5e :3 0 2cd
583 585 :3 0 5d
:2 0 75 :4 0 2d0
587 589 :3 0 5d
:2 0 76 :4 0 2d3
58b 58d :3 0 5d
:2 0 70 :3 0 2d6
58f 591 :3 0 5d
:2 0 77 :4 0 2d9
593 595 :3 0 5d
:2 0 78 :3 0 79
:3 0 15 :2 0 7a
:2 0 2dc 598 59c
2e0 597 59e :3 0
2e3 580 5a0 :2 0
5a2 2e6 5a3 57d
5a2 0 5a4 2e8
0 5a5 2ea 5a8
:3 0 5a8 0 5a8
5a7 5a5 5a6 :6 0
5aa 14 :3 0 2ed
5ac 2ef 5ab 5aa
:2 0 5ad 2f1 :2 0
5af 0 5af 5ae
565 5ad :6 0 5b1
b :3 0 2f3 70a
78 :3 0 14 :3 0
15 :2 0 15 :2 0
2f5 5b2 5b6 7b
:2 0 8a :4 0 2fb
5b8 5ba :3 0 92
:3 0 93 :3 0 4b
:3 0 13 :3 0 4b
:3 0 2c :3 0 36
:3 0 37 :3 0 94
:4 0 ae 1 :8 0
5db 86 :4 0 5c6
:3 0 8d :3 0 7b
:2 0 300 5c9 5ca
:3 0 9 :3 0 6f
:3 0 5cc 5cd 0
17 :2 0 5ce 5cf
0 5d1 303 5d8
9 :3 0 6f :3 0
5d2 5d3 0 87
:2 0 5d4 5d5 0
5d7 305 5d9 5cb
5d1 0 5da 0
5d7 0 5da 307
0 5db 30a 625
71 :3 0 9 :3 0
6f :3 0 5de 5df
0 70 :3 0 5e0
5e1 0 61b 55
:3 0 56 :3 0 5e3
5e4 0 55 :3 0
66 :3 0 5e6 5e7
0 72 :2 0 2
:4 0 af :2 0 68
:2 0 15 :2 0 30d
5ec 5ee :3 0 310
5e8 5f0 5e5 5f2
5f1 :2 0 58 :3 0
69 :3 0 5f4 5f5
0 5a :4 0 b0
:4 0 5d :2 0 5e
:3 0 314 5f9 5fb
:3 0 5d :2 0 75
:4 0 317 5fd 5ff
:3 0 5d :2 0 76
:4 0 31a 601 603
:3 0 5d :2 0 70
:3 0 31d 605 607
:3 0 5d :2 0 77
:4 0 320 609 60b
:3 0 5d :2 0 78
:3 0 79 :3 0 15
:2 0 7a :2 0 323
60e 612 327 60d
614 :3 0 32a 5f6
616 :2 0 618 32d
619 5f3 618 0
61a 32f 0 61b
331 61e :3 0 61e
0 61e 61d 61b
61c :6 0 620 16
:3 0 334 622 336
621 620 :2 0 623
338 :2 0 625 0
625 624 5db 623
:6 0 699 b :3 0
51 :3 0 2f :3 0
31 :3 0 8b :3 0
4e :3 0 9a :3 0
47 :3 0 9a :3 0
4e :3 0 48 :3 0
9a :3 0 47 :3 0
9a :3 0 47 :3 0
4b :3 0 13 :4 0
b1 1 :8 0 64d
86 :4 0 638 :3 0
8d :3 0 7b :2 0
33c 63b 63c :3 0
9 :3 0 6f :3 0
63e 63f 0 17
:2 0 640 641 0
643 33f 64a 9
:3 0 6f :3 0 644
645 0 87 :2 0
646 647 0 649
341 64b 63d 643
0 64c 0 649
0 64c 343 0
64d 346 697 71
:3 0 9 :3 0 6f
:3 0 650 651 0
70 :3 0 652 653
0 68d 55 :3 0
56 :3 0 655 656
0 55 :3 0 66
:3 0 658 659 0
72 :2 0 2 :4 0
b2 :2 0 68 :2 0
15 :2 0 349 65e
660 :3 0 34c 65a
662 657 664 663
:2 0 58 :3 0 69
:3 0 666 667 0
5a :4 0 b3 :4 0
5d :2 0 5e :3 0
350 66b 66d :3 0
5d :2 0 75 :4 0
353 66f 671 :3 0
5d :2 0 76 :4 0
356 673 675 :3 0
5d :2 0 70 :3 0
359 677 679 :3 0
5d :2 0 77 :4 0
35c 67b 67d :3 0
5d :2 0 78 :3 0
79 :3 0 15 :2 0
7a :2 0 35f 680
684 363 67f 686
:3 0 366 668 688
:2 0 68a 369 68b
665 68a 0 68c
36b 0 68d 36d
690 :3 0 690 0
690 68f 68d 68e
:6 0 692 18 :3 0
370 694 372 693
692 :2 0 695 374
:2 0 697 0 697
696 64d 695 :6 0
699 b :3 0 376
706 51 :3 0 2f
:3 0 31 :3 0 8b
:3 0 48 :3 0 4f
:3 0 50 :3 0 4b
:3 0 13 :4 0 b4
1 :8 0 6b9 86
:4 0 6a4 :3 0 8d
:3 0 7b :2 0 37b
6a7 6a8 :3 0 9
:3 0 6f :3 0 6aa
6ab 0 17 :2 0
6ac 6ad 0 6af
37e 6b6 9 :3 0
6f :3 0 6b0 6b1
0 87 :2 0 6b2
6b3 0 6b5 380
6b7 6a9 6af 0
6b8 0 6b5 0
6b8 382 0 6b9
385 703 71 :3 0
9 :3 0 6f :3 0
6bc 6bd 0 70
:3 0 6be 6bf 0
6f9 55 :3 0 56
:3 0 6c1 6c2 0
55 :3 0 66 :3 0
6c4 6c5 0 72
:2 0 2 :4 0 b5
:2 0 68 :2 0 15
:2 0 388 6ca 6cc
:3 0 38b 6c6 6ce
6c3 6d0 6cf :2 0
58 :3 0 69 :3 0
6d2 6d3 0 5a
:4 0 b6 :4 0 5d
:2 0 5e :3 0 38f
6d7 6d9 :3 0 5d
:2 0 75 :4 0 392
6db 6dd :3 0 5d
:2 0 76 :4 0 395
6df 6e1 :3 0 5d
:2 0 70 :3 0 398
6e3 6e5 :3 0 5d
:2 0 77 :4 0 39b
6e7 6e9 :3 0 5d
:2 0 78 :3 0 79
:3 0 15 :2 0 7a
:2 0 39e 6ec 6f0
3a2 6eb 6f2 :3 0
3a5 6d4 6f4 :2 0
6f6 3a8 6f7 6d1
6f6 0 6f8 3aa
0 6f9 3ac 6fc
:3 0 6fc 0 6fc
6fb 6f9 6fa :6 0
6fe 1a :3 0 3af
700 3b1 6ff 6fe
:2 0 701 3b3 :2 0
703 0 703 702
6b9 701 :6 0 705
b :3 0 3b5 707
5bb 699 0 708
0 705 0 708
3b7 0 709 3ba
70b 548 5b1 0
70c 0 709 0
70c 3bc 0 70d
3bf 70f 366 53f
0 710 0 70d
0 710 3c1 0
878 9 :3 0 6f
:3 0 711 712 0
9 :3 0 7b :2 0
b7 :3 0 714 716
0 3c6 715 718
:3 0 719 :2 0 1e
:3 0 15 :2 0 71b
71c 0 71e 3c9
71f 71a 71e 0
720 3cb 0 878
27 :3 0 17 :2 0
721 722 0 878
23 :3 0 90 :3 0
24 :3 0 13 :3 0
25 :3 0 26 :3 0
62 :3 0 27 :3 0
17 :2 0 3cd 72a
72d 3d0 725 72f
724 730 0 878
62 :3 0 1e :3 0
17 :2 0 3d6 732
735 7b :2 0 17
:2 0 3db 737 739
:3 0 b8 :3 0 62
:3 0 16 :3 0 17
:2 0 3de 73c 73f
15 :2 0 3e1 73b
742 743 :2 0 7b
:2 0 15 :2 0 3e6
745 747 :3 0 748
:2 0 62 :3 0 22
:3 0 17 :2 0 3e9
74a 74d b9 :2 0
17 :2 0 3ee 74f
751 :3 0 752 :2 0
749 754 753 :2 0
29 :3 0 ba :3 0
62 :3 0 bb :3 0
21 :3 0 3f1 759
75b 17 :2 0 3f3
758 75e bc :2 0
62 :3 0 bb :3 0
20 :3 0 3f6 762
764 17 :2 0 3f8
761 767 3fb 760
769 :3 0 76a :2 0
bd :2 0 be :2 0
3fe 76c 76e :3 0
76f :2 0 7f :2 0
62 :3 0 22 :3 0
17 :2 0 401 772
775 404 771 777
:3 0 407 757 779
756 77a 0 872
29 :3 0 b9 :2 0
15 :2 0 40b 77d
77f :3 0 780 :2 0
29 :3 0 bf :2 0
7f :2 0 15 :2 0
40e 784 786 :3 0
412 783 788 :3 0
781 78a 789 :2 0
51 :3 0 c0 :3 0
c1 :3 0 c2 :3 0
c0 :3 0 37 :3 0
c3 :3 0 a0 :3 0
a0 :3 0 48 :3 0
32 :3 0 a0 :3 0
4b :3 0 13 :4 0
c4 1 :8 0 7b0
86 :4 0 79b :3 0
8d :3 0 7b :2 0
417 79e 79f :3 0
9 :3 0 6f :3 0
7a1 7a2 0 17
:2 0 7a3 7a4 0
7a6 41a 7ad 9
:3 0 6f :3 0 7a7
7a8 0 87 :2 0
7a9 7aa 0 7ac
41c 7ae 7a0 7a6
0 7af 0 7ac
0 7af 41e 0
7b0 421 7fa 71
:3 0 9 :3 0 6f
:3 0 7b3 7b4 0
70 :3 0 7b5 7b6
0 7f0 55 :3 0
56 :3 0 7b8 7b9
0 55 :3 0 66
:3 0 7bb 7bc 0
72 :2 0 2 :4 0
c5 :2 0 68 :2 0
15 :2 0 424 7c1
7c3 :3 0 427 7bd
7c5 7ba 7c7 7c6
:2 0 58 :3 0 69
:3 0 7c9 7ca 0
5a :4 0 c6 :4 0
5d :2 0 5e :3 0
42b 7ce 7d0 :3 0
5d :2 0 75 :4 0
42e 7d2 7d4 :3 0
5d :2 0 76 :4 0
431 7d6 7d8 :3 0
5d :2 0 70 :3 0
434 7da 7dc :3 0
5d :2 0 77 :4 0
437 7de 7e0 :3 0
5d :2 0 78 :3 0
79 :3 0 15 :2 0
7a :2 0 43a 7e3
7e7 43e 7e2 7e9
:3 0 441 7cb 7eb
:2 0 7ed 444 7ee
7c8 7ed 0 7ef
446 0 7f0 448
7f3 :3 0 7f3 0
7f3 7f2 7f0 7f1
:6 0 7f5 1c :3 0
44b 7f7 44d 7f6
7f5 :2 0 7f8 44f
:2 0 7fa 0 7fa
7f9 7b0 7f8 :6 0
7fc b :3 0 451
868 51 :3 0 a0
:3 0 a0 :3 0 48
:3 0 32 :3 0 a0
:3 0 4b :3 0 13
:4 0 c7 1 :8 0
81b 86 :4 0 806
:3 0 8d :3 0 7b
:2 0 455 809 80a
:3 0 9 :3 0 6f
:3 0 80c 80d 0
17 :2 0 80e 80f
0 811 458 818
9 :3 0 6f :3 0
812 813 0 87
:2 0 814 815 0
817 45a 819 80b
811 0 81a 0
817 0 81a 45c
0 81b 45f 865
71 :3 0 9 :3 0
6f :3 0 81e 81f
0 70 :3 0 820
821 0 85b 55
:3 0 56 :3 0 823
824 0 55 :3 0
66 :3 0 826 827
0 72 :2 0 2
:4 0 c8 :2 0 68
:2 0 15 :2 0 462
82c 82e :3 0 465
828 830 825 832
831 :2 0 58 :3 0
69 :3 0 834 835
0 5a :4 0 c9
:4 0 5d :2 0 5e
:3 0 469 839 83b
:3 0 5d :2 0 75
:4 0 46c 83d 83f
:3 0 5d :2 0 76
:4 0 46f 841 843
:3 0 5d :2 0 70
:3 0 472 845 847
:3 0 5d :2 0 77
:4 0 475 849 84b
:3 0 5d :2 0 78
:3 0 79 :3 0 15
:2 0 7a :2 0 478
84e 852 47c 84d
854 :3 0 47f 836
856 :2 0 858 482
859 833 858 0
85a 484 0 85b
486 85e :3 0 85e
0 85e 85d 85b
85c :6 0 860 1e
:3 0 489 862 48b
861 860 :2 0 863
48d :2 0 865 0
865 864 81b 863
:6 0 867 b :3 0
48f 869 78b 7fc
0 86a 0 867
0 86a 491 0
872 1c :3 0 ca
:3 0 d :3 0 13
:3 0 494 86c 86f
86b 870 0 872
497 873 755 872
0 874 49b 0
875 49d 876 73a
875 0 877 49f
0 878 4a1 87a
85 :4 0 878 :4 0
8d0 cb :3 0 4a
:4 0 87e :2 0 884
87c 0 9 :3 0
6f :3 0 87f 880
0 70 :3 0 881
882 0 884 4ab
8ce 71 :3 0 9
:3 0 6f :3 0 887
888 0 70 :3 0
889 88a 0 8c4
55 :3 0 56 :3 0
88c 88d 0 55
:3 0 66 :3 0 88f
890 0 72 :2 0
2 :4 0 cc :2 0
68 :2 0 15 :2 0
4ae 895 897 :3 0
4b1 891 899 88e
89b 89a :2 0 58
:3 0 69 :3 0 89d
89e 0 5a :4 0
cd :4 0 5d :2 0
5e :3 0 4b5 8a2
8a4 :3 0 5d :2 0
75 :4 0 4b8 8a6
8a8 :3 0 5d :2 0
76 :4 0 4bb 8aa
8ac :3 0 5d :2 0
70 :3 0 4be 8ae
8b0 :3 0 5d :2 0
77 :4 0 4c1 8b2
8b4 :3 0 5d :2 0
78 :3 0 79 :3 0
15 :2 0 7a :2 0
4c4 8b7 8bb 4c8
8b6 8bd :3 0 4cb
89f 8bf :2 0 8c1
4ce 8c2 89c 8c1
0 8c3 4d0 0
8c4 4d2 8c7 :3 0
8c7 0 8c7 8c6
8c4 8c5 :6 0 8c9
20 :3 0 4d5 8cb
4d7 8ca 8c9 :2 0
8cc 4d9 :2 0 8ce
0 8ce 8cd 884
8cc :6 0 8d0 8
:3 0 4db 8d2 29d
329 0 8d3 0
8d0 0 8d3 4df
0 94e 33 :3 0
ce :3 0 cf :3 0
78 :3 0 30 :3 0
cf :3 0 78 :3 0
1a :3 0 d0 :3 0
cf :3 0 78 :3 0
30 :3 0 cf :3 0
78 :3 0 1a :3 0
30 :3 0 34 :3 0
d :3 0 2c :3 0
12 :4 0 d1 1
:8 0 8fe 86 :4 0
8e9 :3 0 8d :3 0
7b :2 0 4e4 8ec
8ed :3 0 9 :3 0
6f :3 0 8ef 8f0
0 17 :2 0 8f1
8f2 0 8f4 4e7
8fb 9 :3 0 6f
:3 0 8f5 8f6 0
87 :2 0 8f7 8f8
0 8fa 4e9 8fc
8ee 8f4 0 8fd
0 8fa 0 8fd
4eb 0 8fe 4ee
948 71 :3 0 9
:3 0 6f :3 0 901
902 0 70 :3 0
903 904 0 93e
55 :3 0 56 :3 0
906 907 0 55
:3 0 66 :3 0 909
90a 0 72 :2 0
2 :4 0 d2 :2 0
68 :2 0 15 :2 0
4f1 90f 911 :3 0
4f4 90b 913 908
915 914 :2 0 58
:3 0 69 :3 0 917
918 0 5a :4 0
d3 :4 0 5d :2 0
5e :3 0 4f8 91c
91e :3 0 5d :2 0
75 :4 0 4fb 920
922 :3 0 5d :2 0
76 :4 0 4fe 924
926 :3 0 5d :2 0
70 :3 0 501 928
92a :3 0 5d :2 0
77 :4 0 504 92c
92e :3 0 5d :2 0
78 :3 0 79 :3 0
15 :2 0 7a :2 0
507 931 935 50b
930 937 :3 0 50e
919 939 :2 0 93b
511 93c 916 93b
0 93d 513 0
93e 515 941 :3 0
941 0 941 940
93e 93f :6 0 943
22 :3 0 518 945
51a 944 943 :2 0
946 51c :2 0 948
0 948 947 8fe
946 :6 0 94e 8
:3 0 91 :5 0 94c
24 0 94d 51e
94c 94b 94e 520
950 85 :4 0 94e
:4 0 9bb cb :3 0
2b :4 0 954 :2 0
95a 952 0 9
:3 0 6f :3 0 955
956 0 70 :3 0
957 958 0 95a
527 9a4 71 :3 0
9 :3 0 6f :3 0
95d 95e 0 70
:3 0 95f 960 0
99a 55 :3 0 56
:3 0 962 963 0
55 :3 0 66 :3 0
965 966 0 72
:2 0 2 :4 0 d4
:2 0 68 :2 0 15
:2 0 52a 96b 96d
:3 0 52d 967 96f
964 971 970 :2 0
58 :3 0 69 :3 0
973 974 0 5a
:4 0 d5 :4 0 5d
:2 0 5e :3 0 531
978 97a :3 0 5d
:2 0 75 :4 0 534
97c 97e :3 0 5d
:2 0 76 :4 0 537
980 982 :3 0 5d
:2 0 70 :3 0 53a
984 986 :3 0 5d
:2 0 77 :4 0 53d
988 98a :3 0 5d
:2 0 78 :3 0 79
:3 0 15 :2 0 7a
:2 0 540 98d 991
544 98c 993 :3 0
547 975 995 :2 0
997 54a 998 972
997 0 999 54c
0 99a 54e 99d
:3 0 99d 0 99d
99c 99a 99b :6 0
99f 24 :3 0 551
9a1 553 9a0 99f
:2 0 9a2 555 :2 0
9a4 0 9a4 9a3
95a 9a2 :6 0 9bb
1 :3 0 62 :3 0
18 :3 0 17 :2 0
557 9a6 9a9 b9
:2 0 7f :2 0 15
:2 0 55a 9ac 9ae
:3 0 55e 9ab 9b0
:3 0 1c :3 0 d6
:3 0 d :3 0 561
9b3 9b5 9b2 9b6
0 9b8 563 9b9
9b1 9b8 0 9ba
565 0 9bb 567
9bc 1fc 9bb 0
9bd 56f 0 a0c
55 :3 0 56 :3 0
9be 9bf 0 55
:3 0 66 :3 0 9c1
9c2 0 d7 :2 0
2 :4 0 d8 :2 0
68 :2 0 15 :2 0
571 9c7 9c9 :3 0
574 9c3 9cb 9c0
9cd 9cc :2 0 58
:3 0 69 :3 0 9cf
9d0 0 5a :4 0
d9 :4 0 5d :2 0
5e :3 0 578 9d4
9d6 :3 0 5d :2 0
75 :4 0 57b 9d8
9da :3 0 5d :2 0
da :4 0 57e 9dc
9de :3 0 5d :2 0
62 :3 0 63 :3 0
9 :3 0 6f :3 0
9e3 9e4 0 581
9e2 9e6 64 :4 0
583 9e1 9e9 586
9e0 9eb :3 0 5d
:2 0 db :4 0 589
9ed 9ef :3 0 5d
:2 0 60 :4 0 58c
9f1 9f3 :3 0 5d
:2 0 3 :3 0 58f
9f5 9f7 :3 0 5d
:2 0 60 :4 0 592
9f9 9fb :3 0 595
9d1 9fd :2 0 9ff
598 a00 9ce 9ff
0 a01 59a 0
a0c dc :3 0 dd
:3 0 a02 a03 0
9 :3 0 6f :3 0
a05 a06 0 3
:3 0 8d :3 0 59c
a04 a0a :2 0 a0c
5a0 aad 9 :3 0
de :2 0 4 a0d
a0e 0 55 :3 0
56 :3 0 a10 a11
0 55 :3 0 66
:3 0 a13 a14 0
72 :2 0 2 :4 0
df :2 0 68 :2 0
15 :2 0 5ab a19
a1b :3 0 5ae a15
a1d a12 a1f a1e
:2 0 58 :3 0 69
:3 0 a21 a22 0
5a :4 0 e0 :4 0
5d :2 0 5e :3 0
5b2 a26 a28 :3 0
5b5 a23 a2a :2 0
a43 58 :3 0 69
:3 0 a2c a2d 0
5a :4 0 e1 :4 0
5d :2 0 9 :3 0
e2 :3 0 a32 a33
0 5b8 a31 a35
:3 0 5d :2 0 db
:4 0 5bb a37 a39
:3 0 5d :2 0 9
:3 0 e3 :3 0 a3c
a3d 0 5be a3b
a3f :3 0 5c1 a2e
a41 :2 0 a43 5c4
a44 a20 a43 0
a45 5c7 0 a55
84 :3 0 54 :3 0
9 :3 0 e2 :3 0
e4 :3 0 9 :3 0
e3 :3 0 e5 :3 0
e6 :4 0 e7 1
:a 0 a51 :2 0 a55
a47 a4f :2 0 8
:3 0 54 :3 0 a53
:2 0 a55 5c9 a57
5cd a56 a55 :2 0
aab 71 :3 0 9
:3 0 6f :3 0 a5a
a5b 0 70 :3 0
a5c a5d 0 aa3
55 :3 0 56 :3 0
a5f a60 0 55
:3 0 66 :3 0 a62
a63 0 72 :2 0
2 :4 0 e8 :2 0
68 :2 0 15 :2 0
5cf a68 a6a :3 0
5d2 a64 a6c a61
a6e a6d :2 0 58
:3 0 69 :3 0 a70
a71 0 5a :4 0
e9 :4 0 5d :2 0
5e :3 0 5d6 a75
a77 :3 0 5d9 a72
a79 :2 0 a93 58
:3 0 69 :3 0 a7b
a7c 0 5a :4 0
76 :4 0 5d :2 0
70 :3 0 5dc a80
a82 :3 0 5d :2 0
77 :4 0 5df a84
a86 :3 0 5d :2 0
78 :3 0 79 :3 0
15 :2 0 7a :2 0
5e2 a89 a8d 5e6
a88 a8f :3 0 5e9
a7d a91 :2 0 a93
5ec a94 a6f a93
0 a95 5ef 0
aa3 84 :3 0 54
:3 0 e4 :3 0 9
:3 0 e3 :3 0 e5
:3 0 e6 :4 0 ea
1 :a 0 a9f :2 0
aa3 a97 a9d :2 0
8 :3 0 54 :3 0
aa1 :2 0 aa3 5f1
aa6 :3 0 aa6 0
aa6 aa5 aa3 aa4
:6 0 aa8 1 :3 0
5f6 aaa 5f8 aa9
aa8 :2 0 aab 5fa
:2 0 aad 5fd aad
aac a0c aab :6 0
aae :2 0 2 14
aad ab1 :3 0 ab0
aae ab2 :8 0 
61a
4
:3 0 1 3 1
7 1 b 3
6 a e 1
16 1 1d 1
1b 1 24 1
22 1 29 1
30 1 2e 1
37 1 35 1
3e 1 3c 1
43 1 49 1
4f 1 55 1
5a 1 60 1
66 1 6c 1
72 1 78 1
7e 1 84 1
8c 1 8a 1
93 1 91 1
98 1 9e 1
a4 1 aa 1
e9 1 108 1
10e 1 11b 1
127 2 12a 12c
2 12f 131 2
133 135 2 137
139 2 13b 13d
1 143 2 145
146 2 13f 148
2 14a 14c 2
14e 150 2 152
154 2 156 158
2 15a 15c 4
123 129 12e 15e
1 160 1 162
2 16c 16e 3
16a 16b 170 2
179 17b 2 178
17d 1 17f 1
181 2 199 19e
2 1af 1b1 3
1ad 1ae 1b3 2
1bc 1be 2 1c0
1c2 2 1c4 1c6
2 1c8 1ca 2
1cc 1ce 3 1d3
1d4 1d5 2 1d0
1d7 2 1bb 1d9
1 1db 1 1dd
2 1a6 1de 1
1e2 1 1a1 1
1e6 1 1f1 2
1ed 1f1 1 1f5
2 1ff 201 3
203 204 205 1
20b 2 214 219
2 22a 22c 3
228 229 22e 2
237 239 2 23b
23d 2 23f 241
2 243 245 2
247 249 3 24e
24f 250 2 24b
252 2 236 254
1 256 1 258
2 221 259 1
25d 1 21c 1
261 4 26d 26e
26f 270 1 27b
1 281 2 283
284 1 28c 2
288 28c 1 291
1 293 2 296
297 1 29b 2
299 29b 2 29f
2a0 1 2a4 2
2a2 2a4 1 2b2
2 2b1 2b2 1
2ba 1 2c0 2
2c2 2c3 2 2af
2c4 2 2d5 2d7
3 2d3 2d4 2d9
2 2e2 2e4 2
2e6 2e8 2 2ea
2ec 2 2ee 2f0
2 2f2 2f4 3
2f9 2fa 2fb 2
2f6 2fd 2 2e1
2ff 1 301 1
303 2 2cc 304
1 308 1 2c7
1 30c 2 31b
31c 5 316 317
318 319 31e 3
30f 313 321 1
324 2 326 327
1 328 6 331
332 333 334 335
336 1 341 1
347 2 349 34a
1 352 2 34e
352 1 357 1
359 2 35f 360
1 364 2 362
364 3 368 369
36a 1 36e 2
36c 36e 1 37d
2 37c 37d 1
385 1 38b 2
38d 38e 2 37a
38f 2 3a0 3a2
3 39e 39f 3a4
2 3ad 3af 2
3b1 3b3 2 3b5
3b7 2 3b9 3bb
2 3bd 3bf 3
3c4 3c5 3c6 2
3c1 3c8 2 3ac
3ca 1 3cc 1
3ce 2 397 3cf
1 3d3 1 392
1 3d7 2 3dd
3de 1 3e3 1
3e5 2 3e0 3e5
1 402 2 401
402 1 40a 1
410 2 412 413
2 3ff 414 2
425 427 3 423
424 429 2 432
434 2 436 438
2 43a 43c 2
43e 440 2 442
444 3 449 44a
44b 2 446 44d
2 431 44f 1
451 1 453 2
41c 454 1 458
1 417 1 45c
1 45f 1 46d
2 46c 46d 1
475 1 47b 2
47d 47e 2 46a
47f 2 490 492
3 48e 48f 494
2 49d 49f 2
4a1 4a3 2 4a5
4a7 2 4a9 4ab
2 4ad 4af 3
4b4 4b5 4b6 2
4b1 4b8 2 49c
4ba 1 4bc 1
4be 2 487 4bf
1 4c3 1 482
1 4c7 1 4ca
2 4cd 4ce 2
3da 4cf 1 4dc
2 4db 4dc 1
4e4 1 4ea 2
4ec 4ed 2 4d9
4ee 2 4ff 501
3 4fd 4fe 503
2 50c 50e 2
510 512 2 514
516 2 518 51a
2 51c 51e 3
523 524 525 2
520 527 2 50b
529 1 52b 1
52d 2 4f6 52e
1 532 1 4f1
1 536 1 539
2 53c 53d 1
53e 2 541 542
1 546 2 544
546 1 552 2
551 552 1 55a
1 560 2 562
563 2 54f 564
2 575 577 3
573 574 579 2
582 584 2 586
588 2 58a 58c
2 58e 590 2
592 594 3 599
59a 59b 2 596
59d 2 581 59f
1 5a1 1 5a3
2 56c 5a4 1
5a8 1 567 1
5ac 1 5af 3
5b3 5b4 5b5 1
5b9 2 5b7 5b9
1 5c8 2 5c7
5c8 1 5d0 1
5d6 2 5d8 5d9
2 5c5 5da 2
5eb 5ed 3 5e9
5ea 5ef 2 5f8
5fa 2 5fc 5fe
2 600 602 2
604 606 2 608
60a 3 60f 610
611 2 60c 613
2 5f7 615 1
617 1 619 2
5e2 61a 1 61e
1 5dd 1 622
1 63a 2 639
63a 1 642 1
648 2 64a 64b
2 637 64c 2
65d 65f 3 65b
65c 661 2 66a
66c 2 66e 670
2 672 674 2
676 678 2 67a
67c 3 681 682
683 2 67e 685
2 669 687 1
689 1 68b 2
654 68c 1 690
1 64f 1 694
2 625 697 1
6a6 2 6a5 6a6
1 6ae 1 6b4
2 6b6 6b7 2
6a3 6b8 2 6c9
6cb 3 6c7 6c8
6cd 2 6d6 6d8
2 6da 6dc 2
6de 6e0 2 6e2
6e4 2 6e6 6e8
3 6ed 6ee 6ef
2 6ea 6f1 2
6d5 6f3 1 6f5
1 6f7 2 6c0
6f8 1 6fc 1
6bb 1 700 1
703 2 706 707
1 708 2 70a
70b 1 70c 2
70e 70f 1 717
2 713 717 1
71d 1 71f 2
72b 72c 5 726
727 728 729 72e
2 733 734 1
738 2 736 738
2 73d 73e 2
740 741 1 746
2 744 746 2
74b 74c 1 750
2 74e 750 1
75a 2 75c 75d
1 763 2 765
766 2 75f 768
2 76b 76d 2
773 774 2 770
776 1 778 1
77e 2 77c 77e
1 785 1 787
2 782 787 1
79d 2 79c 79d
1 7a5 1 7ab
2 7ad 7ae 2
79a 7af 2 7c0
7c2 3 7be 7bf
7c4 2 7cd 7cf
2 7d1 7d3 2
7d5 7d7 2 7d9
7db 2 7dd 7df
3 7e4 7e5 7e6
2 7e1 7e8 2
7cc 7ea 1 7ec
1 7ee 2 7b7
7ef 1 7f3 1
7b2 1 7f7 1
7fa 1 808 2
807 808 1 810
1 816 2 818
819 2 805 81a
2 82b 82d 3
829 82a 82f 2
838 83a 2 83c
83e 2 840 842
2 844 846 2
848 84a 3 84f
850 851 2 84c
853 2 837 855
1 857 1 859
2 822 85a 1
85e 1 81d 1
862 1 865 2
868 869 2 86d
86e 3 77b 86a
871 1 873 1
874 1 876 9
337 34b 35a 35d
710 720 723 731
877 2 87d 883
2 894 896 3
892 893 898 2
8a1 8a3 2 8a5
8a7 2 8a9 8ab
2 8ad 8af 2
8b1 8b3 3 8b8
8b9 8ba 2 8b5
8bc 2 8a0 8be
1 8c0 1 8c2
2 88b 8c3 1
8c7 1 886 1
8cb 3 32c 87a
8ce 2 8d1 8d2
1 8eb 2 8ea
8eb 1 8f3 1
8f9 2 8fb 8fc
2 8e8 8fd 2
90e 910 3 90c
90d 912 2 91b
91d 2 91f 921
2 923 925 2
927 929 2 92b
92d 3 932 933
934 2 92f 936
2 91a 938 1
93a 1 93c 2
905 93d 1 941
1 900 1 945
1 94a 6 271
285 294 8d3 948
94d 2 953 959
2 96a 96c 3
968 969 96e 2
977 979 2 97b
97d 2 97f 981
2 983 985 2
987 989 3 98e
98f 990 2 98b
992 2 976 994
1 996 1 998
2 961 999 1
99d 1 95c 1
9a1 2 9a7 9a8
1 9ad 1 9af
2 9aa 9af 1
9b4 1 9b7 1
9b9 7 208 20e
264 268 950 9a4
9ba 1 9bc 2
9c6 9c8 3 9c4
9c5 9ca 2 9d3
9d5 2 9d7 9d9
2 9db 9dd 1
9e5 2 9e7 9e8
2 9df 9ea 2
9ec 9ee 2 9f0
9f2 2 9f4 9f6
2 9f8 9fa 2
9d2 9fc 1 9fe
1 a00 3 a07
a08 a09 a 163
182 185 188 18b
18e 1e9 9bd a01
a0b 2 a18 a1a
3 a16 a17 a1c
2 a25 a27 2
a24 a29 2 a30
a34 2 a36 a38
2 a3a a3e 2
a2f a40 2 a2b
a42 1 a44 3
a45 a50 a54 1
a0f 2 a67 a69
3 a65 a66 a6b
2 a74 a76 2
a73 a78 2 a7f
a81 2 a83 a85
3 a8a a8b a8c
2 a87 a8e 2
a7e a90 2 a7a
a92 1 a94 4
a5e a95 a9e aa2
1 aa6 1 a59
2 a57 aaa 1c
19 20 27 2c
33 3a 41 47
4d 53 58 5e
64 6a 70 76
7c 82 88 8f
96 9c a2 a8
ad ea 109 113

1
4
0 
ab1
0
1
28
26
21
0 1 1 1 4 1 6 1
8 9 8 b c b e b
10 b 12 b 14 b 16 b
18 b 1a b 1c b 1e 8
20 8 22 1 24 1 0 0

b 1 0
60 1 0
7e 1 0
16 1 0
35 1 0
98 1 0
2 0 1
94a 8 24
84 1 0
5a 1 0
49 1 0
3 1 0
29 1 0
8a 1 0
f0 1 3
43 1 0
72 1 0
2e 1 0
22 1 0
78 1 0
a4 1 0
3c 1 0
6c 1 0
9e 1 0
4f 1 0
55 1 0
1b 1 0
66 1 0
7 1 0
91 1 0
b0 1 2
aa 1 0
10e 1 0
0

/
SHOW ERRORS FUNCTION SP_RJCT_ETC_WBS;
ALTER FUNCTION SP_RJCT_ETC_WBS COMPILE DEBUG;
Prompt == FUNCTION SP_U_WP_FORECAST ==
CREATE OR REPLACE FUNCTION SP_U_WP_FORECAST wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
12c
2 :e:
1FUNCTION:
1SP_U_WP_FORECAST:
1ID001:
1VARCHAR2:
1START_DATE001:
1TIMESTAMP:
1FINISH_DATE001:
1ACC_REJ_BITFLAG:
1PLS_INTEGER:
1REC_USER001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_PROJECT_ID:
132:
1H_TASK_ID:
1H_PRJ_ASSIGNMENT_ID:
1H_TSK_ASSIGNMENT_ID:
1H_RES_ASSIGNMENT_ID:
1H_RES_ID:
1H_REC_USER:
1H_SECURITY_ID:
1H_START_DATE:
1H_FINISH_DATE:
1H_START_DT:
1H_FINISH_DT:
1H_FORECAST_START:
1H_FORECAST_FINISH:
1H_ACTUAL_START:
1H_RANK:
1200:
1H_MLST_PERCENT:
10:
1H_TYPE:
1H_REG_COST:
1NUMBER:
10.00:
1H_REG_SALE:
1H_TA_START_DT:
1H_TA_FINISH_DT:
1H_LAST_SUBMITTED:
1DATE:
1H_PROJAFFECTED_START:
1H_DAYOFYEAR:
1H_WEEK_OF:
1H_BIT_FLAG:
11:
1H_BILLABLE:
1H_CAPITAL_EXPENSE:
1H_ETC:
1H_TOTAL:
1H_SCHED_WORK:
1H_CONTINUE:
1H_EFFORT:
1H_CONTOUR:
1H_BITFLAG:
1H_ACC_REJ_BITFLAG:
1H_REMAINING:
1H_FF:
1H_TEMP_VAR:
1H_TEMP_SC_STATE:
1H_ALERT_FLAG:
1H_ALERT_ID:
1NULL_RETURN:
1LONG:
1ORA_TEMP_SC_STATE:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_U_WP_FORECAST(:
1':
1, :
1COALESCE:
1NULLIF:
1'':
1NULL:
1TO_CHAR:
1);:
1CHECK_TRACE:
167:
1+:
1FPUT:
1               ENTER:: SP_U_WP_FORECAST(68) :: cplan.sql(19612) :: :
1:
1=:
1PMO_CNST:
1SC_ACCEPT_REJECT_FORECAST:
1PROJECT_ID:
1RES_ASSIGNMENT_ID:
1PROJECT_ASSIGNMENT_ID:
1ACTUAL_START:
1MILESTONE_PERCENT:
1BIT_FLAG:
1FORECAST_START:
1SCHED_START:
1FORECAST_FINISH:
1SCHED_FINISH:
1TASK_ID:
1RESOURCE_ID:
1SCHED_WORK:
1PLANNED_WORK:
1WORK_TODATE:
1ETC:
1C_CONTOUR:
1LAST_SUBMITTED:
1UNRESOLVED_START:
1UNRESOLVED_FINISH:
1BILLABLE:
1CAPITAL_EXPENSE:
1REGULAR_COST:
1REGULAR_RATE:
1TASK_ASSIGNMENTS:
1TSK_ASSIGNMENT_ID:
1SELECT PROJECT_ID, RES_ASSIGNMENT_ID, PROJECT_ASSIGNMENT_ID, ACTUAL_START, MI+
1LESTONE_PERCENT, BIT_FLAG, :n      COALESCE(FORECAST_START,SCHED_START), COAL+
1ESCE(FORECAST_FINISH,SCHED_FINISH), FORECAST_START, FORECAST_FINISH, TASK_ID,+
1 RESOURCE_ID, SCHED_WORK, (PLANNED_WORK + SCHED_WORK - WORK_TODATE), ETC,:n  +
1    C_CONTOUR, LAST_SUBMITTED, UNRESOLVED_START, UNRESOLVED_FINISH, BILLABLE,+
1 CAPITAL_EXPENSE, REGULAR_COST, REGULAR_RATE:n      INTO h_project_id, h_res_+
1assignment_id, h_prj_assignment_id, h_actual_start, h_mlst_percent, h_bit_fla+
1g,:n      h_start_DT, h_finish_DT, h_forecast_start, h_forecast_finish, h_tas+
1k_id, h_res_id, h_sched_work,h_remaining, h_etc,:n      h_contour, h_last_sub+
1mitted, h_ta_start_DT, h_ta_finish_DT, h_billable, h_capital_expense, h_reg_c+
1ost, h_reg_sale:n      FROM TASK_ASSIGNMENTS:n      WHERE TSK_ASSIGNMENT_ID =+
1 id001:
1SC_STATE:
1SQLCODE:
1OTHERS:
116:
1101:
1           EXCEPTION:: SP_U_WP_FORECAST(102) :: cplan.sql(19646) :: :
1 :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1SC_SQL_NO_DATA:
1109:
1        RETURN_ERROR:: SP_U_WP_FORECAST(110) :: cplan.sql(19654) :: :
1STATE:: :
1RECORD_NOT_FOUND:
1 ID:: :
1112:
1                EXIT:: SP_U_WP_FORECAST(113) :: cplan.sql(19657) :: :
1PMODEFINES:
1PMO_RETURN_ERROR_SP:
1TRUE:
110000:
1119:
1        RETURN_ERROR:: SP_U_WP_FORECAST(120) :: cplan.sql(19664) :: :
1ASSIGNMENT_ALREADY_CLOSED:
1122:
1                EXIT:: SP_U_WP_FORECAST(123) :: cplan.sql(19667) :: :
1IS NOT NULL:
1PMO_ORASTD:
1STRNCMP:
110:
1<:
1130:
1        RETURN_ERROR:: SP_U_WP_FORECAST(131) :: cplan.sql(19675) :: :
1F_DATE_EARLIER_THAN_S_DATE:
1133:
1                EXIT:: SP_U_WP_FORECAST(134) :: cplan.sql(19678) :: :
1MAX:
1WEEK_OF:
1TIMESHEET_APPROVAL_STATUS:
1ELEMENT_ID:
1CURRENT_STATE:
1SC_APV_STATE_RM_APPROVED:
1SC_APV_STATE_PM_APPROVED:
1SC_APV_STATE_SUBMITTED:
1SELECT MAX(WEEK_OF) + 7      INTO h_week_of FROM TIMESHEET_APPROVAL_STATUS:n +
1     WHERE ELEMENT_ID = h_project_id AND RESOURCE_ID = h_res_id:n      AND CU+
1RRENT_STATE IN (PMO_CNST.SC_APV_STATE_RM_APPROVED,PMO_CNST.SC_APV_STATE_PM_AP+
1PROVED,PMO_CNST.SC_APV_STATE_SUBMITTED):
1150:
1           EXCEPTION:: SP_U_WP_FORECAST(151) :: cplan.sql(19695) :: :
1STRCMP:
1!=:
1SCETCFORCASTCHANGED:
1FC_ISSUE_ALERT:
1SCREDUCEDETC:
1IS NULL:
1FORECAST_DURATION:
1UPDATE TASK_ASSIGNMENTS SET:n         FORECAST_START  = start_date001,:n     +
1    FORECAST_FINISH = finish_date001,:n         FORECAST_DURATION = 0:n      +
1   WHERE TSK_ASSIGNMENT_ID = id001:
1FOUND:
1100:
1194:
1           EXCEPTION:: SP_U_WP_FORECAST(195) :: cplan.sql(19739) :: :
1UPDATE TASK_ASSIGNMENTS SET:n            FORECAST_START  = start_date001,:n  +
1          FORECAST_DURATION = 0:n            WHERE TSK_ASSIGNMENT_ID = id001:
1219:
1           EXCEPTION:: SP_U_WP_FORECAST(220) :: cplan.sql(19764) :: :
1UPDATE TASK_ASSIGNMENTS SET:n            FORECAST_FINISH = finish_date001,:n +
1           FORECAST_DURATION = 0:n            WHERE TSK_ASSIGNMENT_ID = id001:
1249:
1           EXCEPTION:: SP_U_WP_FORECAST(250) :: cplan.sql(19794) :: :
1>:
1273:
1        RETURN_ERROR:: SP_U_WP_FORECAST(274) :: cplan.sql(19818) :: :
1FORECAST_APPROVAL_EXISTS:
1276:
1                EXIT:: SP_U_WP_FORECAST(277) :: cplan.sql(19821) :: :
1284:
1        RETURN_ERROR:: SP_U_WP_FORECAST(285) :: cplan.sql(19829) :: :
1CANNOT_UPDATE_HAS_ACTUAL:
1287:
1                EXIT:: SP_U_WP_FORECAST(288) :: cplan.sql(19832) :: :
1ELSIF:
1DB2TIMESTAMP:
1DAY_YEAR:
1TIME:
1PMO_STPU:
1FIRST_AVAIL_TIME:
1BIT_SCHED:
1CALENDAR_DAY_OF_YEAR:
1TO_DATE:
1SELECT PMO_ORASTD.DB2TIMESTAMP(DAY_YEAR, PMO_ORASTD.TIME(PMO_STPU.FIRST_AVAIL+
1_TIME(BIT_SCHED))) INTO h_start_date:n                  FROM CALENDAR_DAY_OF_+
1YEAR:n                  WHERE ELEMENT_ID = h_project_id:n                  AN+
1D DAY_YEAR = TO_DATE(SubStr(start_date001, 1, 10)):
1308:
1           EXCEPTION:: SP_U_WP_FORECAST(309) :: cplan.sql(19853) :: :
1DUAL:
1SELECT  (PMO_ORASTD.DB2TIMESTAMP(TO_DATE(SubStr(start_date001, 1, 10)), PMO_O+
1RASTD.TIME('08::00')))  INTO  h_start_date FROM DUAL:
1323:
1           EXCEPTION:: SP_U_WP_FORECAST(324) :: cplan.sql(19868) :: :
1330:
1        RETURN_ERROR:: SP_U_WP_FORECAST(331) :: cplan.sql(19875) :: :
1333:
1                EXIT:: SP_U_WP_FORECAST(334) :: cplan.sql(19878) :: :
1346:
1        RETURN_ERROR:: SP_U_WP_FORECAST(347) :: cplan.sql(19891) :: :
1INVALID_PARAMS:
1349:
1                EXIT:: SP_U_WP_FORECAST(350) :: cplan.sql(19894) :: :
1<=:
18:
1355:
1      RETURN_INVALID:: SP_U_WP_FORECAST(356) :: cplan.sql(19900) :: :
1358:
1                EXIT:: SP_U_WP_FORECAST(359) :: cplan.sql(19903) :: :
1PMO_RETURN_INVALID_SP:
1LAST_AVAIL_TIME:
1SELECT PMO_ORASTD.DB2TIMESTAMP(DAY_YEAR, PMO_ORASTD.TIME(PMO_STPU.LAST_AVAIL_+
1TIME(BIT_SCHED))) INTO h_finish_date:n                  FROM CALENDAR_DAY_OF_+
1YEAR:n                  WHERE ELEMENT_ID = h_project_id:n                  AN+
1D DAY_YEAR = TO_DATE(SubStr(finish_date001, 1, 10)):
1385:
1           EXCEPTION:: SP_U_WP_FORECAST(386) :: cplan.sql(19930) :: :
1SELECT  (PMO_ORASTD.DB2TIMESTAMP(TO_DATE(SubStr(finish_date001, 1, 10)), PMO_+
1ORASTD.TIME('17::00')))  INTO  h_finish_date FROM DUAL:
1401:
1           EXCEPTION:: SP_U_WP_FORECAST(402) :: cplan.sql(19946) :: :
1409:
1        RETURN_ERROR:: SP_U_WP_FORECAST(410) :: cplan.sql(19954) :: :
1412:
1                EXIT:: SP_U_WP_FORECAST(413) :: cplan.sql(19957) :: :
1UPDATE TASK_ASSIGNMENTS SET:n               FORECAST_START  = h_start_date,:n+
1               FORECAST_FINISH = h_finish_date,:n               FORECAST_DURA+
1TION = 0:n               WHERE TSK_ASSIGNMENT_ID = id001:
1441:
1           EXCEPTION:: SP_U_WP_FORECAST(442) :: cplan.sql(19986) :: :
1COUNT:
1TASK_DAY_OF_YEAR:
1SELECT COUNT('X') INTO h_temp_var:n                     FROM DUAL:n          +
1           WHERE EXISTS (SELECT DAY_YEAR FROM TASK_DAY_OF_YEAR:n             +
1        WHERE PROJECT_ID = h_project_id AND ((TSK_ASSIGNMENT_ID = h_prj_assig+
1nment_id) OR (TSK_ASSIGNMENT_ID = h_tsk_assignment_id)):n                    +
1 AND DAY_YEAR = TO_DATE(SubStr(finish_date001, 1, 10))):
1463:
1           EXCEPTION:: SP_U_WP_FORECAST(464) :: cplan.sql(20008) :: :
1471:
1        RETURN_ERROR:: SP_U_WP_FORECAST(472) :: cplan.sql(20016) :: :
1PROJECT_ASSIGNMENT_REMAINING:
1474:
1                EXIT:: SP_U_WP_FORECAST(475) :: cplan.sql(20019) :: :
1SELECT COUNT('X') INTO h_temp_var:n                     FROM DUAL:n          +
1           WHERE EXISTS (SELECT DAY_YEAR FROM TASK_DAY_OF_YEAR:n             +
1        WHERE PROJECT_ID = h_project_id AND ((TSK_ASSIGNMENT_ID = h_prj_assig+
1nment_id) OR (TSK_ASSIGNMENT_ID = h_tsk_assignment_id)):n                    +
1 AND DAY_YEAR = TO_DATE(SubStr(start_date001, 1, 10))):
1493:
1           EXCEPTION:: SP_U_WP_FORECAST(494) :: cplan.sql(20038) :: :
1501:
1        RETURN_ERROR:: SP_U_WP_FORECAST(502) :: cplan.sql(20046) :: :
1504:
1                EXIT:: SP_U_WP_FORECAST(505) :: cplan.sql(20049) :: :
1SUM:
1SCHED_MIN:
1PARENT_ID:
1SELECT SUM(SCHED_MIN) INTO h_total FROM TASK_DAY_OF_YEAR:n                   +
1     WHERE PROJECT_ID = h_project_id AND PARENT_ID = h_prj_assignment_id AND +
1DAY_YEAR >= TO_DATE(SubStr(start_date001, 1, 10)):
1522:
1           EXCEPTION:: SP_U_WP_FORECAST(523) :: cplan.sql(20067) :: :
1528:
1        RETURN_ERROR:: SP_U_WP_FORECAST(529) :: cplan.sql(20073) :: :
1531:
1                EXIT:: SP_U_WP_FORECAST(532) :: cplan.sql(20076) :: :
1539:
1        RETURN_ERROR:: SP_U_WP_FORECAST(540) :: cplan.sql(20084) :: :
1TASK_ASSIGNMENT_ERROR:
1542:
1                EXIT:: SP_U_WP_FORECAST(543) :: cplan.sql(20087) :: :
12:
1FC_ACPT_ETC_ASSIGN:
1U_ASSIGN_STRING:
13:
1FC_ROLLUP:
14:
1593:
1       RETURN_STATUS:: SP_U_WP_FORECAST(594) :: cplan.sql(20138) :: :
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
1601:
1           EXCEPTION:: SP_U_WP_FORECAST(602) :: cplan.sql(20146) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_ID:
1OPEN:
1ERROR:
1ID:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
1613:
1           EXCEPTION:: SP_U_WP_FORECAST(614) :: cplan.sql(20158) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
10ba
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 1c 81
b0 a3 a0 1c 81 b0 a3 a0
1c 81 b0 a3 a0 1c 81 b0
a3 a0 1c 81 b0 a3 a0 1c
81 b0 a3 a0 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 81 b0 a3 a0 1c 81 b0
a3 a0 1c 81 b0 a3 a0 1c
81 b0 a3 a0 1c 81 b0 a3
a0 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 1c 81
b0 a3 a0 1c 51 81 b0 a3
:2 a0 6b 1c 81 b0 :2 a0 6b :2 a0
6b 6e a5 b a 10 :2 a0 6b
6e :2 a0 6b 6e a5 b 6e 7e
a0 b4 2e 6e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :2 a0 6e 7e
a0 b4 2e 7e 6e b4 2e 6e
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e :2 a0 6e 7e a0
b4 2e 7e 6e b4 2e 6e a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c a0
6e d a0 6e d a0 51 d
:2 a0 d :2 a0 d :2 a0 d :2 a0 d
:2 a0 51 a5 b 7e 51 b4 2e
5a :3 a0 6b d b7 19 3c :37 a0
12a :2 a0 6b a0 d b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 6b a0 7e a0 6b
b4 2e 5a :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b :2 a0
a5 57 b7 19 3c :2 a0 51 a5
b 7e 51 b4 2e :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b :2 a0 a5 57 b7 19 3c a0
7e b4 2e :2 5a a0 7e b4 2e
:2 5a a 10 :2 a0 6b :2 a0 51 a5
b 7e 51 b4 2e :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b :2 a0 a5 57 b7 19 3c b7
19 3c a0 4d d :f a0 12a :2 a0
6b a0 d b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 d :2 a0 6b :2 a0 a5 b 7e
51 b4 2e 5a :2 a0 51 a5 b
a0 7e a0 6b b4 2e 5a a
10 a0 6e d a0 51 d :3 a0
6b d :6 a0 51 a5 b d :2 a0
6b a0 d a0 6e d a0 51
d :3 a0 6b d :6 a0 51 a5 b
d :2 a0 6b a0 d b7 19 3c
a0 7e b4 2e :2 5a :2 a0 6b :2 a0
51 a5 b 7e 51 b4 2e 5a
a 10 :2 a0 d b7 19 3c a0
7e b4 2e :2 5a a0 7e b4 2e
:2 5a a 10 :8 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 a0 7e b4
2e 5a a0 7e b4 2e 5a a
10 :6 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 6b :2 a0 51 a5 b
7e 51 b4 2e a0 51 d b7
19 3c b7 19 3c a0 7e b4
2e 5a a0 7e b4 2e 5a a
10 :6 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 6b :2 a0 51 a5 b
7e 51 b4 2e a0 51 d b7
19 3c b7 19 3c :2 a0 51 a5
b 7e 51 b4 2e a0 7e b4
2e :2 5a :2 a0 6b :2 a0 51 a5 b
7e 51 b4 2e 5a a 10 :2 a0
d b7 19 3c a0 7e b4 2e
:2 5a a0 7e b4 2e :2 5a a 10
:2 a0 6b :2 a0 a5 b 7e 51 b4
2e 5a a 10 :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :4 a0 6b a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
:2 a0 a5 57 b7 19 3c a0 7e
b4 2e 5a a0 7e b4 2e 5a
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b :2 a0 a5 57 b7
19 3c :2 a0 d :2 a0 6b :2 a0 51
a5 b 7e 51 b4 2e a0 4d
d a0 b7 :2 a0 6b :2 a0 51 a5
b 7e 51 b4 2e :10 a0 12a :2 a0
6b a0 d b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 6b a0 7e a0 6b b4 2e
5a :9 a0 12a :2 a0 6b a0 d b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 19 3c a0
b7 19 a0 7e b4 2e 5a :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :2 a0 51
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b 51 :2 a0 a5 57 b7 :2 19 3c
b7 a0 51 d a0 4d d b7
:2 19 3c a0 7e b4 2e 5a a0
7e b4 2e :2 5a :2 a0 6b :2 a0 51
a5 b 7e 51 b4 2e 5a a
10 :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b :2 a0 a5 57
a0 b7 a0 7e b4 2e :2 5a :2 a0
6b :2 a0 51 a5 b 7e 51 b4
2e 5a a 10 :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :4 a0 6b a5 b 6e
a5 b b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
a0 a5 57 b7 :2 19 3c a0 7e
b4 2e :2 5a :2 a0 6b :2 a0 51 a5
b 7e 51 b4 2e 5a a 10
a0 51 d b7 a0 51 d b7
:2 19 3c :2 a0 6b :2 a0 51 a5 b
7e 51 b4 2e a0 4d d a0
b7 :2 a0 6b :2 a0 a5 b 7e 51
b4 2e :10 a0 12a :2 a0 6b a0 d
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 6b a0
7e a0 6b b4 2e 5a :9 a0 12a
:2 a0 6b a0 d b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 19 3c a0 b7 19 :2 a0
6b :2 a0 51 a5 b 7e 51 b4
2e :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:2 a0 51 a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b 51 :2 a0 a5 57 b7
:2 19 3c b7 a0 4d d b7 :2 19
3c :2 a0 d a0 51 d :2 a0 51
a5 b a0 7e a0 6b b4 2e
:8 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 a0 7e b4 2e 5a a0
7e b4 2e 5a :f a0 12a :2 a0 6b
a0 d b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
51 a5 b 7e 51 b4 2e :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b :2 a0 a5 57 b7 19
3c a0 b7 a0 7e b4 2e 5a
:f a0 12a :2 a0 6b a0 d b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 51 a5 b 7e
51 b4 2e :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b :2 a0
a5 57 b7 :c a0 12a :2 a0 6b a0
d b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 51
a5 b a0 7e a0 51 a5 b
b4 2e :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b :2 a0 a5
57 b7 19 3c b7 :2 19 3c b7
19 :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b :2 a0 a5 57
b7 :2 19 3c b7 19 3c a0 51
d :2 a0 d a0 7e b4 2e 5a
a0 7e b4 2e :2 5a a 10 :2 a0
d b7 19 3c :18 a0 51 a5 b
d a0 51 d :5 a0 :2 51 a5 b
d a0 7e b4 2e 5a a0 51
d :5 a0 :2 51 a5 b d b7 19
3c b7 :2 19 3c b7 19 3c b7
:2 19 3c :2 a0 6b :2 a0 a5 b 7e
51 b4 2e 5a :2 a0 51 a5 b
a0 7e a0 6b b4 2e 5a a
10 a0 6e d a0 51 d :3 a0
6b d :6 a0 51 a5 b d :2 a0
6b a0 d a0 6e d a0 51
d :3 a0 6b d :6 a0 51 a5 b
d :2 a0 6b a0 d b7 19 3c
:3 a0 a5 b d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :4 a0 6b a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b :2 a0 a5 57
b7 :2 a0 6b :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 :2 a0 6b :2 6e 7e :2 a0
6b b4 2e 7e 6e b4 2e 7e
:2 a0 6b b4 2e a5 57 b7 19
3c :9 a0 12a e9 dd :2 a0 65 b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c :7 a0
12a e9 dd :2 a0 65 b7 a4 b1
11 4f b7 a6 9 a4 b1 11
68 4f 1d 17 b5 
10ba
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 5e
5a 30 66 6f 6b 59 77 56
7c 80 84 88 8b 8f ac 97
9b 9e 9f a7 96 c9 b7 93
bb bc c4 b6 e6 d4 b3 d8
d9 e1 d3 103 f1 d0 f5 f6
fe f0 120 10e ed 112 113 11b
10d 13d 12b 10a 12f 130 138 12a
15a 148 127 14c 14d 155 147 177
165 144 169 16a 172 164 193 182
186 18e 161 1ab 19a 19e 1a6 181
1c7 1b6 1ba 1c2 17e 1df 1ce 1d2
1da 1b5 1fb 1ea 1ee 1f6 1b2 213
202 206 20e 1e9 22f 21e 222 22a
1e6 24b 236 23a 23d 23e 246 21d
267 256 25a 21a 262 255 283 272
276 252 27e 271 29f 28e 292 26e
29a 28d 2bb 2aa 2ae 28a 2b6 2a9
2d7 2c6 2ca 2d2 2a6 2ef 2de 2e2
2ea 2c5 30b 2fa 2fe 306 2c2 323
312 316 31e 2f9 33f 32e 332 33a
2f6 357 346 34a 352 32d 374 362
32a 366 367 36f 361 390 37f 383
35e 38b 37e 3ac 39b 39f 37b 3a7
39a 3c8 3b7 3bb 397 3c3 3b6 3e4
3d3 3d7 3b3 3df 3d2 400 3ef 3f3
3cf 3fb 3ee 41c 40b 40f 3eb 417
40a 438 427 42b 407 433 426 454
443 447 423 44f 442 470 45f 463
43f 46b 45e 48c 47b 47f 45b 487
47a 4a8 497 49b 477 4a3 496 4c4
4b3 4b7 493 4bf 4b2 4e0 4cf 4d3
4af 4db 4ce 4fc 4eb 4ef 4cb 4f7
4ea 518 507 50b 4e7 513 506 535
523 503 527 528 530 522 551 540
544 54c 51f 56c 558 55c 564 567
53f 58c 577 57b 53c 57f 587 576
593 597 573 59b 59f 5a3 5a6 5ab
5ac 1 5ae 5b3 5b7 5bb 5be 5c3
5c7 5cb 5ce 5d3 5d4 5d6 5db 5de
5e2 5e3 5e8 5ed 5f0 5f5 5f6 5fb
5fe 602 603 608 60b 610 611 616
619 61e 61f 624 627 62b 62f 634
637 63b 63c 641 644 649 64a 64f
654 655 657 65c 65d 65f 660 665
668 66d 66e 673 676 67a 67e 683
686 68a 68b 690 693 698 699 69e
6a3 6a4 6a6 6ab 6ac 6ae 6af 6b4
6b7 6bc 6bd 6c2 6c5 6c9 6cd 6d1
6d2 6d4 6d9 6da 6dc 6dd 6e2 6e5
6ea 6eb 6f0 6f3 6f8 6f9 6fe 701
705 706 70b 70e 713 714 719 71c
721 722 727 728 72d 72f 733 736
73a 73e 741 745 749 74c 74f 754
757 75a 75d 75e 763 764 1 766
76b 76f 773 776 77b 780 783 787
788 78d 78e 793 795 799 79c 7a0
7a5 7a9 7ad 7b2 7b6 7ba 7bd 7c1
7c5 7c9 7cd 7d1 7d5 7d9 7dd 7e1
7e5 7e9 7ed 7f1 7f5 7f9 7fc 7fd
7ff 802 805 806 80b 80e 812 816
81a 81d 821 823 827 82a 82e 832
836 83a 83e 842 846 84a 84e 852
856 85a 85e 862 866 86a 86e 872
876 87a 87e 882 886 88a 88e 892
896 89a 89e 8a2 8a6 8aa 8ae 8b2
8b6 8ba 8be 8c2 8c6 8ca 8ce 8d2
8d6 8da 8de 8e2 8e6 8ea 8ee 8f2
8f6 8fa 8fe 902 906 912 916 91a
91d 921 925 927 1 92b 92f 933
936 93a 93e 942 946 949 94d 951
954 957 95c 95f 962 965 966 96b
96c 1 96e 973 977 97b 97e 983
988 98b 98f 990 995 998 99d 99e
9a3 9a6 9ab 9ac 9b1 9b4 9b8 9b9
9be 9c1 9c6 9c7 9cc 9cf 9d3 9d7
9da 9dd 9de 9e0 9e1 9e6 9e7 9ec
9ee 9f2 9f5 9f7 9fb 9fd a09 a0b
a0d a0e a13 a17 a19 a25 a27 a2b
a2f a32 a36 a39 a3d a40 a41 a46
a49 a4d a51 a54 a58 a5c a5f a62
a67 a6a a6d a70 a71 a76 a77 1
a79 a7e a82 a86 a89 a8e a93 a96
a9a a9b aa0 aa3 aa8 aa9 aae ab1
ab6 ab7 abc abf ac3 ac7 acb acf
ad2 ad3 ad5 ada adb add ade ae3
ae6 aeb aec af1 af4 af9 afa aff
b02 b06 b07 b0c b0f b14 b15 b1a
b1b b20 b22 b26 b29 b2d b31 b34
b38 b3c b3f b42 b47 b4a b4d b50
b51 b56 b57 1 b59 b5e b62 b66
b69 b6e b73 b76 b7a b7b b80 b81
b86 b88 b8c b8f b93 b97 b9a b9e
ba2 ba5 ba9 bad bae bb3 bb5 bb9
bbc bc0 bc4 bc7 bc8 bca bcd bd0
bd1 bd6 bda bde be1 be5 be9 bec
bef bf4 bf7 bfa bfd bfe c03 c04
1 c06 c0b c0f c13 c16 c1b c20
c23 c27 c28 c2d c30 c35 c36 c3b
c3e c43 c44 c49 c4c c50 c54 c58
c5c c5f c60 c62 c67 c68 c6a c6b
c70 c73 c78 c79 c7e c81 c86 c87
c8c c8f c93 c94 c99 c9c ca1 ca2
ca7 ca8 cad caf cb3 cb6 cba cbe
cc1 cc5 cc9 ccc ccf cd4 cd7 cda
cdd cde ce3 ce4 1 ce6 ceb cef
cf3 cf6 cfb d00 d03 d07 d08 d0d
d0e d13 d15 d19 d1c d20 d24 d27
d2b d2f d32 d36 d3a d3b d40 d42
d46 d49 d4d d50 d51 d56 d59 d5c
d60 d63 d64 d69 d6c 1 d6f d74
d78 d7c d7f d83 d87 d8a d8b d8d
d90 d93 d94 d99 d9d da1 da4 da8
dac daf db2 db7 dba dbd dc0 dc1
dc6 dc7 1 dc9 dce dd2 dd6 dd9
dde de3 de6 dea deb df0 df3 df8
df9 dfe e01 e06 e07 e0c e0f e13
e17 e1b e1f e22 e23 e25 e2a e2b
e2d e2e e33 e36 e3b e3c e41 e44
e49 e4a e4f e52 e56 e57 e5c e5f
e64 e65 e6a e6b e70 e72 e76 e79
e7d e81 e84 e88 e8c e8f e92 e97
e9a e9d ea0 ea1 ea6 ea7 1 ea9
eae eb2 eb6 eb9 ebe ec3 ec6 eca
ecb ed0 ed1 ed6 ed8 edc edf ee3
ee7 eea eee ef2 ef5 ef9 efd efe
f03 f05 f09 f0c f0e f12 f15 f19
f1a f1e f22 f26 f2a f2e f32 f36
f3a f3e f42 f46 f4a f4e f52 f56
f5a f66 f6a f6e f71 f75 f79 f7b
1 f7f f83 f87 f8a f8e f92 f96
f9a f9d fa1 fa5 fa8 fab fb0 fb3
fb6 fb9 fba fbf fc0 1 fc2 fc7
fcb fcf fd2 fd7 fdc fdf fe3 fe4
fe9 fec ff1 ff2 ff7 ffa fff 1000
1005 1008 100c 100d 1012 1015 101a 101b
1020 1023 1027 102b 102e 1031 1032 1034
1035 103a 103b 1040 1042 1046 1049 104b
104f 1051 105d 105f 1061 1062 1067 106b
106d 1079 107b 107f 1083 1087 108b 108f
1092 1096 109a 109b 109d 10a0 10a3 10a4
10a9 10ac 10b0 10b4 10b7 10b8 10ba 10be
10c1 10c5 10c8 10c9 10ce 1 10d1 10d6
10da 10df 10e3 10e7 10ea 10ee 10f2 10f6
10fa 10fd 1101 1105 1109 110d 1111 1115
1119 111c 111d 111f 1123 1127 112b 112e
1132 1136 113a 113f 1143 1147 114a 114e
1152 1156 115a 115d 1161 1165 1169 116d
1171 1175 1179 117c 117d 117f 1183 1187
118b 118e 1192 1196 1198 119c 119f 11a3
11a6 11a7 11ac 11af 11b2 11b6 11ba 11bd
11c1 11c5 11c8 11c9 11cb 11ce 11d1 11d2
11d7 1 11da 11df 11e3 11e7 11eb 11ed
11f1 11f4 11f8 11fb 11fc 1201 1204 1207
120b 120e 120f 1214 1217 1 121a 121f
1223 1227 122b 122f 1233 1237 123b 123f
124b 124f 1254 1258 125b 125c 1261 1265
1269 126c 126f 1273 1275 1279 127d 1280
1283 1287 1289 128d 1291 1294 1296 1
129a 129e 12a2 12a5 12a9 12ad 12b1 12b5
12b8 12bc 12c0 12c3 12c6 12cb 12ce 12d1
12d4 12d5 12da 12db 1 12dd 12e2 12e6
12ea 12ed 12f2 12f7 12fa 12fe 12ff 1304
1307 130c 130d 1312 1315 131a 131b 1320
1323 1327 1328 132d 1330 1335 1336 133b
133e 1342 1346 1349 134c 134d 134f 1350
1355 1356 135b 135d 1361 1364 1366 136a
136c 1378 137a 137c 137d 1382 1386 1388
1394 1396 1398 139c 139f 13a0 13a5 13a8
13ac 13af 13b0 13b5 1 13b8 13bd 13c1
13c5 13c9 13cd 13d1 13d5 13e1 13e5 13ea
13ee 13f1 13f2 13f7 13fb 13ff 1402 1405
1409 140b 140f 1413 1416 1419 141d 141f
1423 1427 142a 142c 1 1430 1434 1438
143b 143f 1443 1447 144b 144e 1452 1456
1459 145c 1461 1464 1467 146a 146b 1470
1471 1 1473 1478 147c 1480 1483 1488
148d 1490 1494 1495 149a 149d 14a2 14a3
14a8 14ab 14b0 14b1 14b6 14b9 14bd 14be
14c3 14c6 14cb 14cc 14d1 14d4 14d8 14dc
14df 14e2 14e3 14e5 14e6 14eb 14ec 14f1
14f3 14f7 14fa 14fc 1500 1502 150e 1510
1512 1513 1518 151c 151e 152a 152c 1530
1534 1537 153b 153f 1542 1543 1545 1548
154b 154c 1551 1555 1558 155c 155e 1562
1565 1567 156b 156e 1572 1575 1576 157b
157e 1582 1585 1586 158b 1 158e 1593
1597 159b 159f 15a3 15a7 15ab 15b7 15bb
15c0 15c4 15c7 15c8 15cd 15d1 15d5 15d8
15db 15df 15e1 15e5 15e9 15ec 15ef 15f3
15f5 15f9 15fd 1600 1602 1 1606 160a
160e 1611 1615 1619 161d 1621 1624 1628
162c 162f 1632 1637 163a 163d 1640 1641
1646 1647 1 1649 164e 1652 1656 1659
165e 1663 1666 166a 166b 1670 1673 1678
1679 167e 1681 1686 1687 168c 168f 1693
1694 1699 169c 16a1 16a2 16a7 16aa 16ae
16b2 16b5 16b8 16b9 16bb 16bc 16c1 16c2
16c7 16c9 16cd 16d0 16d2 16d6 16d8 16e4
16e6 16e8 16e9 16ee 16f2 16f4 1700 1702
1706 170a 170d 1711 1715 1718 1719 171b
171e 1721 1722 1727 172b 172e 1732 1734
1738 173b 173d 1741 1744 1748 174c 174f
1750 1752 1755 1758 1759 175e 1762 1765
1766 176b 176e 1771 1775 1779 177c 1780
1784 1787 1788 178a 178d 1790 1791 1796
1 1799 179e 17a2 17a6 17aa 17ac 17b0
17b3 17b7 17ba 17bb 17c0 17c3 17c6 17ca
17cd 17ce 17d3 17d6 1 17d9 17de 17e2
17e6 17e9 17ed 17f1 17f2 17f4 17f7 17fa
17fb 1800 1 1803 1808 180c 1810 1813
1817 181b 181e 1821 1826 1829 182c 182f
1830 1835 1836 1 1838 183d 1841 1845
1848 184d 1852 1855 1859 185a 185f 1862
1867 1868 186d 1870 1875 1876 187b 187e
1882 1886 188a 188e 1891 1892 1894 1899
189a 189c 189d 18a2 18a5 18aa 18ab 18b0
18b3 18b8 18b9 18be 18c1 18c5 18c6 18cb
18ce 18d3 18d4 18d9 18da 18df 18e1 18e5
18e8 18ec 18f0 18f3 18f7 18fb 18fe 1901
1906 1909 190c 190f 1910 1915 1916 1
1918 191d 1921 1925 1928 192d 1932 1935
1939 193a 193f 1940 1945 1947 194b 194e
1952 1956 1959 195d 1961 1964 1968 196c
196d 1972 1974 1978 197b 197f 1982 1983
1988 198b 198f 1992 1993 1998 199b 199f
19a3 19a6 19aa 19ae 19b1 19b4 19b9 19bc
19bf 19c2 19c3 19c8 19c9 1 19cb 19d0
19d4 19d8 19db 19e0 19e5 19e8 19ec 19ed
19f2 19f5 19fa 19fb 1a00 1a03 1a08 1a09
1a0e 1a11 1a15 1a19 1a1d 1a21 1a24 1a25
1a27 1a2c 1a2d 1a2f 1a30 1a35 1a38 1a3d
1a3e 1a43 1a46 1a4b 1a4c 1a51 1a54 1a58
1a59 1a5e 1a61 1a66 1a67 1a6c 1a6d 1a72
1a74 1a78 1a7b 1a7f 1a83 1a86 1a8a 1a8e
1a91 1a94 1a99 1a9c 1a9f 1aa2 1aa3 1aa8
1aa9 1 1aab 1ab0 1ab4 1ab8 1abb 1ac0
1ac5 1ac8 1acc 1acd 1ad2 1ad3 1ad8 1ada
1ade 1ae1 1ae5 1ae9 1aec 1af0 1af4 1af7
1afb 1aff 1b00 1b05 1b07 1b0b 1b0e 1b12
1b16 1b1a 1b1e 1b22 1b25 1b29 1b2d 1b30
1b31 1b33 1b36 1b39 1b3a 1b3f 1b43 1b44
1b48 1b4c 1b4e 1b52 1b56 1b59 1b5d 1b61
1b64 1b65 1b67 1b6a 1b6d 1b6e 1b73 1b77
1b7b 1b7f 1b83 1b87 1b8b 1b8f 1b93 1b97
1b9b 1b9f 1ba3 1ba7 1bab 1baf 1bb3 1bbf
1bc3 1bc7 1bca 1bce 1bd2 1bd4 1 1bd8
1bdc 1be0 1be3 1be7 1beb 1bef 1bf3 1bf6
1bfa 1bfe 1c01 1c04 1c09 1c0c 1c0f 1c12
1c13 1c18 1c19 1 1c1b 1c20 1c24 1c28
1c2b 1c30 1c35 1c38 1c3c 1c3d 1c42 1c45
1c4a 1c4b 1c50 1c53 1c58 1c59 1c5e 1c61
1c65 1c66 1c6b 1c6e 1c73 1c74 1c79 1c7c
1c80 1c84 1c87 1c8a 1c8b 1c8d 1c8e 1c93
1c94 1c99 1c9b 1c9f 1ca2 1ca4 1ca8 1caa
1cb6 1cb8 1cba 1cbb 1cc0 1cc4 1cc6 1cd2
1cd4 1cd8 1cdc 1cdf 1ce3 1ce6 1cea 1ced
1cee 1cf3 1cf6 1cfa 1cfe 1d02 1d06 1d0a
1d0e 1d12 1d16 1d1a 1d26 1d2a 1d2e 1d31
1d35 1d39 1d3b 1 1d3f 1d43 1d47 1d4a
1d4e 1d52 1d56 1d5a 1d5d 1d61 1d65 1d68
1d6b 1d70 1d73 1d76 1d79 1d7a 1d7f 1d80
1 1d82 1d87 1d8b 1d8f 1d92 1d97 1d9c
1d9f 1da3 1da4 1da9 1dac 1db1 1db2 1db7
1dba 1dbf 1dc0 1dc5 1dc8 1dcc 1dcd 1dd2
1dd5 1dda 1ddb 1de0 1de3 1de7 1deb 1dee
1df1 1df2 1df4 1df5 1dfa 1dfb 1e00 1e02
1e06 1e09 1e0b 1e0f 1e11 1e1d 1e1f 1e21
1e22 1e27 1e2b 1e2d 1e39 1e3b 1e3d 1e41
1e44 1e48 1e4a 1e4e 1e52 1e55 1e56 1e5b
1e5e 1e62 1e66 1e69 1e6d 1e71 1e74 1e77
1e7c 1e7f 1e82 1e85 1e86 1e8b 1e8c 1
1e8e 1e93 1e97 1e9b 1e9e 1ea3 1ea8 1eab
1eaf 1eb0 1eb5 1eb8 1ebd 1ebe 1ec3 1ec6
1ecb 1ecc 1ed1 1ed4 1ed8 1edc 1edf 1ee0
1ee2 1ee7 1ee8 1eea 1eeb 1ef0 1ef3 1ef8
1ef9 1efe 1f01 1f06 1f07 1f0c 1f0f 1f13
1f14 1f19 1f1c 1f21 1f22 1f27 1f28 1f2d
1f2f 1f33 1f36 1f3a 1f3e 1f41 1f45 1f49
1f4c 1f4f 1f54 1f57 1f5a 1f5d 1f5e 1f63
1f64 1 1f66 1f6b 1f6f 1f73 1f76 1f7b
1f80 1f83 1f87 1f88 1f8d 1f8e 1f93 1f95
1f99 1f9c 1fa0 1fa4 1fa7 1faa 1fae 1fb2
1fb3 1fb8 1fba 1fbe 1fc2 1fc5 1fc7 1fcb
1fce 1fd2 1fd6 1fd7 1fdb 1fdd 1fe1 1fe5
1fe8 1fec 1fef 1ff0 1ff5 1ff8 1ffc 1fff
2000 2005 2008 200b 200f 2013 2016 201a
201e 2021 2022 2024 2027 202a 202b 2030
1 2033 2038 203c 2040 2043 2047 204b
204e 2051 2056 2059 205c 205f 2060 2065
2066 1 2068 206d 2071 2075 2078 207d
2082 2085 2089 208a 208f 2092 2097 2098
209d 20a0 20a5 20a6 20ab 20ae 20b2 20b6
20ba 20be 20c1 20c2 20c4 20c9 20ca 20cc
20cd 20d2 20d5 20da 20db 20e0 20e3 20e8
20e9 20ee 20f1 20f5 20f6 20fb 20fe 2103
2104 2109 210a 210f 2111 2115 2118 211c
2120 2123 2127 212b 212e 2131 2136 2139
213c 213f 2140 2145 2146 1 2148 214d
2151 2155 2158 215d 2162 2165 2169 216a
216f 2170 2175 2177 217b 217e 2182 2186
2189 218d 2191 2194 2198 219c 219d 21a2
21a6 21a8 21ac 21af 21b0 21b5 21b8 21bb
21bf 21c3 21c6 21ca 21ce 21d1 21d2 21d4
21d7 21da 21db 21e0 1 21e3 21e8 21ec
21f0 21f3 21f7 21fb 21fe 2201 2206 2209
220c 220f 2210 2215 2216 1 2218 221d
2221 2225 2228 222d 2232 2235 2239 223a
223f 2242 2247 2248 224d 2250 2255 2256
225b 225e 2262 2266 226a 226e 2271 2272
2274 2279 227a 227c 227d 2282 2283 2288
228a 228e 2291 2295 2299 229c 22a0 22a4
22a7 22aa 22af 22b2 22b5 22b8 22b9 22be
22bf 1 22c1 22c6 22ca 22ce 22d1 22d6
22db 22de 22e2 22e3 22e8 22e9 22ee 22f0
22f4 22f7 22fb 22ff 2302 2306 230a 230d
2311 2312 2317 2319 231d 2321 2324 2328
232b 232c 2331 2334 2337 233b 233f 2342
2346 234a 234d 234e 2350 2353 2356 2357
235c 1 235f 2364 2368 236b 236f 2371
2375 2378 237c 237e 2382 2386 2389 238d
2391 2394 2398 239c 239f 23a0 23a2 23a5
23a8 23a9 23ae 23b2 23b3 23b7 23bb 23bd
23c1 23c5 23c8 23cc 23d0 23d1 23d3 23d6
23d9 23da 23df 23e3 23e7 23eb 23ef 23f3
23f7 23fb 23ff 2403 2407 240b 240f 2413
2417 241b 241f 242b 242f 2433 2436 243a
243e 2440 1 2444 2448 244c 244f 2453
2457 245b 245f 2462 2466 246a 246d 2470
2475 2478 247b 247e 247f 2484 2485 1
2487 248c 2490 2494 2497 249c 24a1 24a4
24a8 24a9 24ae 24b1 24b6 24b7 24bc 24bf
24c4 24c5 24ca 24cd 24d1 24d2 24d7 24da
24df 24e0 24e5 24e8 24ec 24f0 24f3 24f6
24f7 24f9 24fa 24ff 2500 2505 2507 250b
250e 2510 2514 2516 2522 2524 2526 2527
252c 2530 2532 253e 2540 2544 2548 254b
254f 2552 2556 2559 255a 255f 2562 2566
256a 256e 2572 2576 257a 257e 2582 2586
2592 2596 259a 259d 25a1 25a5 25a7 1
25ab 25af 25b3 25b6 25ba 25be 25c2 25c6
25c9 25cd 25d1 25d4 25d7 25dc 25df 25e2
25e5 25e6 25eb 25ec 1 25ee 25f3 25f7
25fb 25fe 2603 2608 260b 260f 2610 2615
2618 261d 261e 2623 2626 262b 262c 2631
2634 2638 2639 263e 2641 2646 2647 264c
264f 2653 2657 265a 265d 265e 2660 2661
2666 2667 266c 266e 2672 2675 2677 267b
267d 2689 268b 268d 268e 2693 2697 2699
26a5 26a7 26a9 26ad 26b0 26b4 26b6 26ba
26be 26c2 26c5 26c9 26cd 26d0 26d1 26d3
26d6 26d9 26da 26df 26e3 26e7 26ea 26ee
26f2 26f5 26f8 26fd 2700 2703 2706 2707
270c 270d 1 270f 2714 2718 271c 271f
2724 2729 272c 2730 2731 2736 2739 273e
273f 2744 2747 274c 274d 2752 2755 2759
275d 2760 2761 2763 2768 2769 276b 276c
2771 2774 2779 277a 277f 2782 2787 2788
278d 2790 2794 2795 279a 279d 27a2 27a3
27a8 27a9 27ae 27b0 27b4 27b7 27bb 27bf
27c2 27c6 27ca 27cd 27d0 27d5 27d8 27db
27de 27df 27e4 27e5 1 27e7 27ec 27f0
27f4 27f7 27fc 2801 2804 2808 2809 280e
280f 2814 2816 281a 281d 2821 2825 2828
282b 282f 2833 2834 2839 283b 283f 2843
2846 2848 284c 284d 2851 2853 2857 285b
285e 2862 2866 286a 286e 2871 2875 2879
287d 2880 2881 2883 2887 288a 288e 2891
2892 2897 289b 289f 28a3 28a7 28ab 28af
28b3 28b7 28c3 28c7 28cc 28d0 28d3 28d4
28d9 28dd 28e1 28e4 28e7 28eb 28ed 28f1
28f5 28f8 28fb 28ff 2901 2905 2909 290c
290e 1 2912 2916 291a 291d 2921 2925
2929 292d 2930 2934 2938 293b 293e 2943
2946 2949 294c 294d 2952 2953 1 2955
295a 295e 2962 2965 296a 296f 2972 2976
2977 297c 297f 2984 2985 298a 298d 2992
2993 2998 299b 299f 29a0 29a5 29a8 29ad
29ae 29b3 29b6 29ba 29be 29c1 29c4 29c5
29c7 29c8 29cd 29ce 29d3 29d5 29d9 29dc
29de 29e2 29e4 29f0 29f2 29f4 29f5 29fa
29fe 2a00 2a0c 2a0e 2a10 2a14 2a17 2a18
2a1d 2a20 2a24 2a27 2a28 2a2d 2a30 2a34
2a38 2a3c 2a40 2a44 2a48 2a4c 2a50 2a54
2a58 2a5c 2a60 2a64 2a68 2a6c 2a78 2a7c
2a80 2a83 2a87 2a8b 2a8d 1 2a91 2a95
2a99 2a9c 2aa0 2aa4 2aa8 2aac 2aaf 2ab3
2ab7 2aba 2abd 2ac2 2ac5 2ac8 2acb 2acc
2ad1 2ad2 1 2ad4 2ad9 2add 2ae1 2ae4
2ae9 2aee 2af1 2af5 2af6 2afb 2afe 2b03
2b04 2b09 2b0c 2b11 2b12 2b17 2b1a 2b1e
2b1f 2b24 2b27 2b2c 2b2d 2b32 2b35 2b39
2b3d 2b40 2b43 2b44 2b46 2b47 2b4c 2b4d
2b52 2b54 2b58 2b5b 2b5d 2b61 2b63 2b6f
2b71 2b73 2b74 2b79 2b7d 2b7f 2b8b 2b8d
2b91 2b95 2b98 2b99 2b9b 2b9e 2ba1 2ba2
2ba7 2bab 2baf 2bb2 2bb6 2bba 2bbd 2bc0
2bc5 2bc8 2bcb 2bce 2bcf 2bd4 2bd5 1
2bd7 2bdc 2be0 2be4 2be7 2bec 2bf1 2bf4
2bf8 2bf9 2bfe 2c01 2c06 2c07 2c0c 2c0f
2c14 2c15 2c1a 2c1d 2c21 2c25 2c29 2c2d
2c30 2c31 2c33 2c38 2c39 2c3b 2c3c 2c41
2c44 2c49 2c4a 2c4f 2c52 2c57 2c58 2c5d
2c60 2c64 2c65 2c6a 2c6d 2c72 2c73 2c78
2c79 2c7e 2c80 2c84 2c87 2c8b 2c8f 2c92
2c96 2c9a 2c9d 2ca0 2ca5 2ca8 2cab 2cae
2caf 2cb4 2cb5 1 2cb7 2cbc 2cc0 2cc4
2cc7 2ccc 2cd1 2cd4 2cd8 2cd9 2cde 2cdf
2ce4 2ce6 2cea 2ced 2cf1 2cf5 2cf8 2cfc
2d00 2d03 2d07 2d0b 2d0c 2d11 2d13 2d17
2d1a 2d1e 2d20 2d24 2d27 2d28 2d2d 2d30
2d34 2d38 2d3c 2d40 2d44 2d48 2d4c 2d50
2d54 2d58 2d5c 2d60 2d64 2d68 2d6c 2d78
2d7c 2d80 2d83 2d87 2d8b 2d8d 1 2d91
2d95 2d99 2d9c 2da0 2da4 2da8 2dac 2daf
2db3 2db7 2dba 2dbd 2dc2 2dc5 2dc8 2dcb
2dcc 2dd1 2dd2 1 2dd4 2dd9 2ddd 2de1
2de4 2de9 2dee 2df1 2df5 2df6 2dfb 2dfe
2e03 2e04 2e09 2e0c 2e11 2e12 2e17 2e1a
2e1e 2e1f 2e24 2e27 2e2c 2e2d 2e32 2e35
2e39 2e3d 2e40 2e43 2e44 2e46 2e47 2e4c
2e4d 2e52 2e54 2e58 2e5b 2e5d 2e61 2e63
2e6f 2e71 2e73 2e74 2e79 2e7d 2e7f 2e8b
2e8d 2e91 2e95 2e98 2e99 2e9b 2e9e 2ea1
2ea2 2ea7 2eab 2eaf 2eb2 2eb6 2eba 2ebd
2ec0 2ec5 2ec8 2ecb 2ece 2ecf 2ed4 2ed5
1 2ed7 2edc 2ee0 2ee4 2ee7 2eec 2ef1
2ef4 2ef8 2ef9 2efe 2f01 2f06 2f07 2f0c
2f0f 2f14 2f15 2f1a 2f1d 2f21 2f25 2f29
2f2d 2f30 2f31 2f33 2f38 2f39 2f3b 2f3c
2f41 2f44 2f49 2f4a 2f4f 2f52 2f57 2f58
2f5d 2f60 2f64 2f65 2f6a 2f6d 2f72 2f73
2f78 2f79 2f7e 2f80 2f84 2f87 2f8b 2f8f
2f92 2f96 2f9a 2f9d 2fa0 2fa5 2fa8 2fab
2fae 2faf 2fb4 2fb5 1 2fb7 2fbc 2fc0
2fc4 2fc7 2fcc 2fd1 2fd4 2fd8 2fd9 2fde
2fdf 2fe4 2fe6 2fea 2fed 2ff1 2ff5 2ff8
2ffc 3000 3003 3007 300b 300c 3011 3013
3017 301b 301f 3023 3027 302b 302f 3033
3037 303b 303f 3043 304f 3053 3057 305a
305e 3062 3064 1 3068 306c 3070 3073
3077 307b 307f 3083 3086 308a 308e 3091
3094 3099 309c 309f 30a2 30a3 30a8 30a9
1 30ab 30b0 30b4 30b8 30bb 30c0 30c5
30c8 30cc 30cd 30d2 30d5 30da 30db 30e0
30e3 30e8 30e9 30ee 30f1 30f5 30f6 30fb
30fe 3103 3104 3109 310c 3110 3114 3117
311a 311b 311d 311e 3123 3124 3129 312b
312f 3132 3134 3138 313a 3146 3148 314a
314b 3150 3154 3156 3162 3164 3168 316c
316f 3170 3172 3176 3179 317d 3180 3181
3183 3184 3189 318d 3191 3194 3198 319c
319f 31a2 31a7 31aa 31ad 31b0 31b1 31b6
31b7 1 31b9 31be 31c2 31c6 31c9 31ce
31d3 31d6 31da 31db 31e0 31e3 31e8 31e9
31ee 31f1 31f6 31f7 31fc 31ff 3203 3207
320b 320f 3212 3213 3215 321a 321b 321d
321e 3223 3226 322b 322c 3231 3234 3239
323a 323f 3242 3246 3247 324c 324f 3254
3255 325a 325b 3260 3262 3266 3269 326d
3271 3274 3278 327c 327f 3282 3287 328a
328d 3290 3291 3296 3297 1 3299 329e
32a2 32a6 32a9 32ae 32b3 32b6 32ba 32bb
32c0 32c1 32c6 32c8 32cc 32cf 32d3 32d7
32da 32de 32e2 32e5 32e9 32ed 32ee 32f3
32f5 32f9 32fc 32fe 3302 3306 3309 330b
330f 3313 3317 331a 331e 3322 3325 3328
332d 3330 3333 3336 3337 333c 333d 1
333f 3344 3348 334c 334f 3354 3359 335c
3360 3361 3366 3369 336e 336f 3374 3377
337c 337d 3382 3385 3389 338d 3391 3395
3398 3399 339b 33a0 33a1 33a3 33a4 33a9
33ac 33b1 33b2 33b7 33ba 33bf 33c0 33c5
33c8 33cc 33cd 33d2 33d5 33da 33db 33e0
33e1 33e6 33e8 33ec 33ef 33f3 33f7 33fa
33fe 3402 3405 3408 340d 3410 3413 3416
3417 341c 341d 1 341f 3424 3428 342c
342f 3434 3439 343c 3440 3441 3446 3447
344c 344e 3452 3455 3459 345d 3460 3464
3468 346b 346f 3473 3474 3479 347b 347f
3483 3486 3488 348c 348f 3493 3496 349a
349e 34a2 34a6 34aa 34ad 34ae 34b3 34b6
34ba 34bd 34be 34c3 34c6 1 34c9 34ce
34d2 34d6 34da 34dc 34e0 34e3 34e7 34eb
34ef 34f3 34f7 34fb 34ff 3503 3507 350b
350f 3513 3517 351b 351f 3523 3527 352b
352f 3533 3537 353b 353f 3543 3546 3547
3549 354d 3551 3554 3558 355c 3560 3564
3568 356c 356f 3572 3573 3575 3579 357d
3580 3581 3586 3589 358d 3590 3594 3598
359c 35a0 35a4 35a8 35ab 35ae 35af 35b1
35b5 35b7 35bb 35be 35c0 35c4 35c8 35cb
35cd 35d1 35d4 35d6 35da 35de 35e1 35e5
35e9 35ec 35f0 35f4 35f5 35f7 35fa 35fd
35fe 3603 3606 360a 360e 3611 3612 3614
3618 361b 361f 3622 3623 3628 1 362b
3630 3634 3639 363d 3641 3644 3648 364c
3650 3654 3657 365b 365f 3663 3667 366b
366f 3673 3676 3677 3679 367d 3681 3685
3688 368c 3690 3694 3699 369d 36a1 36a4
36a8 36ac 36b0 36b4 36b7 36bb 36bf 36c3
36c7 36cb 36cf 36d3 36d6 36d7 36d9 36dd
36e1 36e5 36e8 36ec 36f0 36f2 36f6 36f9
36fd 3701 3705 3706 3708 370c 3710 3714
3717 371b 371f 3722 3725 372a 372d 3730
3733 3734 3739 373a 1 373c 3741 3745
3749 374c 3751 3756 3759 375d 375e 3763
3766 376b 376c 3771 3774 3779 377a 377f
3782 3786 378a 378e 3792 3795 3796 3798
379d 379e 37a0 37a1 37a6 37a9 37ae 37af
37b4 37b7 37bc 37bd 37c2 37c5 37c9 37ca
37cf 37d2 37d7 37d8 37dd 37de 37e3 37e5
37e9 37ec 37f0 37f4 37f7 37fb 37ff 3802
3806 380a 380b 3810 3812 3816 381a 381d
3821 3825 3828 382c 3830 3833 3836 383b
383e 3841 3844 3845 384a 384b 1 384d
3852 3856 385a 385d 3862 3867 386a 386e
386f 3874 3875 387a 387e 3882 3885 388a
388f 3892 3896 389a 389d 389e 38a3 38a6
38ab 38ac 38b1 38b4 38b8 38bc 38bf 38c0
38c5 38c6 38cb 38cd 38d1 38d4 38d8 38dc
38e0 38e4 38e8 38ec 38f0 38f4 38f8 3904
3909 390d 3911 3915 3919 391b 391c 3921
1 3925 3929 392d 3930 3934 3938 393c
3940 3943 3947 394b 394e 3951 3956 3959
395c 395f 3960 3965 3966 1 3968 396d
3971 3975 3978 397d 3982 3985 3989 398a
398f 3990 3995 3999 399d 39a0 39a5 39aa
39ad 39b1 39b2 39b7 39ba 39bf 39c0 39c5
39c8 39cc 39d0 39d3 39d6 39d7 39d9 39da
39df 39e0 39e5 39e7 39eb 39ee 39f2 39f6
39fa 39fe 3a02 3a06 3a0a 3a16 3a1b 3a1f
3a23 3a27 3a2b 3a2d 3a31 3a33 3a3f 3a41
3a43 3a44 3a49 3a4d 3a4f 3a5b 3a5f 3a61
3a62 3a6b 
10ba
2
0 1 a 6 c :3 6 14 :3 6
15 :3 6 16 :3 6 12 :2 6 1 3
a 13 a :2 1 4 11 1a 19
:2 11 :2 4 e 17 16 :2 e :2 4 18
21 20 :2 18 :2 4 18 21 20 :2 18
:2 4 18 21 20 :2 18 :2 4 d 16
15 :2 d :2 4 f 18 17 :2 f :2 4
12 1b 1a :2 12 :2 4 :3 11 :2 4 :3 12
:2 4 :3 f :2 4 :3 10 :2 4 :3 15 :2 4 :3 16
:2 4 :3 13 :2 4 b 14 13 :2 b :2 4
:2 13 22 13 :2 4 :2 b 1a b :2 4
:2 f 19 f :2 4 :2 f 19 f :2 4
:3 12 :2 4 :3 13 :2 4 :3 15 :2 4 :3 19 :2 4
:3 10 :2 4 :3 e :2 4 f 18 17 :2 f
:2 4 :2 f 1e f :2 4 :2 16 25 16
:2 4 :2 a 19 a :2 4 :2 c 1b c
:2 4 :2 11 20 11 :2 4 :2 f 1e f
:2 4 :2 d 1c d :2 4 :2 e 1d e
:2 4 :2 e 1d e :2 4 :2 16 25 16
:2 4 :2 10 1f 10 :2 4 :2 9 18 9
:2 4 :2 f 1e f :2 4 :2 14 23 14
:2 4 :2 11 20 11 :2 4 f 18 17
:2 f :2 4 :3 10 :2 4 :2 16 2e 16 :2 4
e 17 :3 e 4 7 :2 11 23 :2 2d
3a :2 23 :3 7 :2 d 19 25 :2 2f 43
:2 25 58 5e 61 :2 58 6f 89 8
:2 6f d 10 :2 6f 16 19 :2 6f b
e :2 6f 13 16 1f 26 2b 2e
:2 26 3c 3f :2 26 44 :2 1f 4d :2 16
:2 6f b e :2 6f 13 16 1f 26
2b 2e :2 26 3d 40 :2 26 45 :2 1f
4e :2 16 :2 6f b e :2 6f 13 16
1f 27 :2 1f 39 :2 16 :2 6f b e
:2 6f 13 16 :2 6f 1b 1e :2 6f 2a
2d :2 6f 32 35 :2 6f :2 7 4e :2 4
7 :2 11 23 :2 2d 39 3c 50 52
53 :2 50 :2 23 :3 7 :2 d 12 1e 61
64 :2 1e :2 7 56 :3 4 14 :2 4 15
:2 4 12 :2 4 14 :2 4 15 :2 4 1b
:2 4 19 4 8 11 24 :2 8 27
29 :2 27 :2 7 1c :2 25 7 2c :2 4
e 1a 2d 44 52 65 7 10
1f 2d 36 46 55 65 76 7f
8c 99 a8 b5 c3 7 12 22
34 47 51 62 70 c 1a 2f
44 54 64 7 13 20 32 45
50 5a 67 74 7 12 24 33
43 4f 62 6e c d 21 :2 7
:2 10 1c 7 4 :2 c a :2 13 1f
a d :2 17 29 :2 33 3f 43 57
5a 5b :2 57 :2 29 :3 d :2 13 18 24
68 6b :2 24 78 7b :2 24 7f 82
:2 24 8e 91 :2 24 99 9c :2 24 a8
ab b2 bb be :2 ab :2 24 :2 d 5e
:2 a :2 7 :4 13 :2 7 4 :3 1 8 :2 11
1c 1a :2 25 :2 1a 7 a :2 14 26
:2 30 3c 40 54 57 58 :2 54 :2 26
:3 a :2 10 15 21 65 68 :2 21 75
78 :2 21 7c 7f :2 21 89 8c 95
9d :2 a6 :2 95 b9 :2 8c :2 21 c1 c4
:2 21 cc cf :2 21 d4 d7 :2 21 dd
e0 :2 21 :2 a 5b :2 7 a :2 14 26
:2 30 3c 3f 53 56 57 :2 53 :2 26
:3 a :2 10 15 21 65 68 :2 21 :2 a
5a :3 7 :2 12 26 :2 2f 41 48 :2 7
35 :2 4 7 10 20 :2 7 23 25
:2 23 a :2 14 26 :2 30 3c 40 54
57 58 :2 54 :2 26 :3 a :2 10 15 21
65 68 :2 21 75 78 :2 21 7c 7f
:2 21 89 8c 95 9d :2 a6 :2 95 c2
:2 8c :2 21 ca cd :2 21 d5 d8 :2 21
dd e0 :2 21 e6 e9 :2 21 :2 a 5b
:2 7 a :2 14 26 :2 30 3c 3f 53
56 57 :2 53 :2 26 :3 a :2 10 15 21
65 68 :2 21 :2 a 5a :3 7 :2 12 26
:2 2f 4a 51 :2 7 2b :2 4 :4 9 8
7 :4 2b 2a 29 :2 7 a :2 15 1d
2c 3a :2 a 3e 40 :2 3e d :2 17
29 :2 33 3f 43 57 5a 5b :2 57
:2 29 :3 d :2 13 18 24 68 6b :2 24
78 7b :2 24 7f 82 :2 24 8c 8f
98 a0 :2 a9 :2 98 c6 :2 8f :2 24 ce
d1 :2 24 d9 dc :2 24 e1 e4 :2 24
ea ed :2 24 :2 d 5e :2 a d :2 17
29 :2 33 3f 42 56 59 5a :2 56
:2 29 :3 d :2 13 18 24 68 6b :2 24
:2 d 5d :3 a :2 15 29 :2 32 4e 55
:2 a 42 :2 7 48 :3 4 11 4 e
12 29 38 d 1a 2b 39 b
1d 26 3f 48 61 6a :2 7 :2 10
1c 7 4 :2 c a :2 13 1f a
d :2 17 29 :2 33 3f 43 57 5a
5b :2 57 :2 29 :3 d :2 13 18 24 68
6b :2 24 78 7b :2 24 7f 82 :2 24
8e 91 :2 24 99 9c :2 24 a8 ab
b2 bb be :2 ab :2 24 :2 d 5e :2 a
:2 7 :4 13 :2 7 4 :3 1 4 12 4
8 :2 13 1a 24 :2 8 30 32 :2 30
7 3a a 1d :2 3a 23 20 :2 2c
:2 20 39 :3 7 15 :2 7 17 :2 7 1c
:2 25 :2 7 16 25 31 46 52 60
:2 16 :2 7 :2 10 1c :2 7 15 :2 7 17
:2 7 1c :2 25 :2 7 16 25 31 46
52 60 :2 16 :2 7 :2 10 1c 7 47
:2 4 :4 9 8 7 29 :2 34 3c 4a
56 :2 29 5a 5c :2 5a 28 :3 7 17
7 5f :2 4 :4 9 8 7 :4 27 26
25 :2 7 11 a 1c a 1c a
10 24 a 11 d 19 :3 17 d
:2 16 22 d 1e d :2 16 22 d
:4 a 7 :2 f d :2 16 22 d 10
:2 1a 2c :2 36 42 46 5a 5d 5e
:2 5a :2 2c :3 10 :2 16 1b 27 6b 6e
:2 27 7b 7e :2 27 82 85 :2 27 91
94 :2 27 9c 9f :2 27 ab ae b5
be c1 :2 ae :2 27 :2 10 61 :2 d :2 a
:4 16 :2 a 7 :4 40 :4 b a :4 27 26
:2 a 14 d 1f d 13 27 d
14 10 1c :3 1a 10 :2 19 25 10
21 10 :2 19 25 10 :4 d a :2 12
10 :2 19 25 10 13 :2 1d 2f :2 39
45 49 5d 60 61 :2 5d :2 2f :3 13
:2 19 1e 2a 6e 71 :2 2a 7e 81
:2 2a 85 88 :2 2a 94 97 :2 2a 9f
a2 :2 2a ae b1 b8 c1 c4 :2 b1
:2 2a :2 13 64 :2 10 :2 d :4 19 :2 d a
:3 45 d :2 18 20 2f 42 :2 d 46
48 :2 46 d 1b d 4a :2 a 45
:2 7 :4 b a :4 28 27 :2 a 14 d
1f d 13 27 d 14 10 1c
:3 1a 10 :2 19 25 10 21 10 :2 19
25 10 :4 d a :2 12 10 :2 19 25
10 13 :2 1d 2f :2 39 45 49 5d
60 61 :2 5d :2 2f :3 13 :2 19 1e 2a
6e 71 :2 2a 7e 81 :2 2a 85 88
:2 2a 94 97 :2 2a 9f a2 :2 2a ae
b1 b8 c1 c4 :2 b1 :2 2a :2 13 64
:2 10 :2 d :4 19 :2 d a :3 47 d :2 18
20 2e 40 :2 d 44 46 :2 44 d
1b d 48 :2 a 47 :2 7 a 13
1f :2 a 22 24 :2 22 :4 f e d
30 :2 3b 43 52 5f :2 30 63 65
:2 63 2f :3 d 1e d 68 :2 a :4 f
e d :4 2d 2c 2b :2 d 4e :2 59
60 12 :2 4e 21 23 :2 21 4d :2 d
10 :2 1a 2c :2 36 42 46 5a 5d
5e :2 5a :2 2c :3 10 :2 16 1b 27 6b
6e :2 27 7b 7e :2 27 82 85 :2 27
8f 92 9b a3 :2 ac :2 9b c7 :2 92
:2 27 cf d2 :2 27 da dd :2 27 e2
e5 :2 27 ee f1 :2 27 :2 10 61 :2 d
10 :2 1a 2c :2 36 42 45 59 5c
5d :2 59 :2 2c :3 10 :2 16 1b 27 6b
6e :2 27 :2 10 60 :3 d :2 18 2c :2 35
4f 59 :2 d 26 :2 a :4 e d :4 11
10 13 :2 1d 2f :2 39 45 49 5d
60 61 :2 5d :2 2f :3 13 :2 19 1e 2a
6e 71 :2 2a 7e 81 :2 2a 85 88
:2 2a 92 95 9e a6 :2 af :2 9e ca
:2 95 :2 2a d2 d5 :2 2a dd e0 :2 2a
e5 e8 :2 2a ee f1 :2 2a :2 13 64
:2 10 13 :2 1d 2f :2 39 45 48 5c
5f 60 :2 5c :2 2f :3 13 :2 19 1e 2a
6e 71 :2 2a :2 13 63 :3 10 :2 1b 2f
:2 38 52 59 :2 10 2d :3 d 19 d
10 :2 1b 23 31 40 :2 10 44 46
:2 44 10 20 10 d 48 13 :2 1e
26 34 40 :2 13 44 47 :2 44 1a
25 32 3c 47 4c 55 66 78
18 19 26 17 22 2a 31 :2 13
:2 1c 28 13 10 :2 18 16 :2 1f 2b
16 19 :2 23 35 :2 3f 4b 4f 63
66 67 :2 63 :2 35 :3 19 :2 1f 24 30
74 77 :2 30 84 87 :2 30 8b 8e
:2 30 9a 9d :2 30 a5 a8 :2 30 b4
b7 be c7 ca :2 b7 :2 30 :2 19 6a
:2 16 :2 13 :4 1f :2 13 10 :3 49 14 :2 1d
28 26 :2 31 :2 26 13 1f 2a 37
3f 46 5e 69 80 92 :2 16 :2 1f
2b 16 13 :2 1b 19 :2 22 2e 19
1c :2 26 38 :2 42 4e 52 66 69
6a :2 66 :2 38 :3 1c :2 22 27 33 77
7a :2 33 87 8a :2 33 8e 91 :2 33
9d a0 :2 33 a8 ab :2 33 b7 ba
c1 ca cd :2 ba :2 33 :2 1c 6d :2 19
:2 16 :4 22 :2 16 13 :4 41 :2 10 d 49
48 :4 14 :2 13 :2 1d 2f :2 39 45 49
5d 60 61 :2 5d :2 2f :3 13 :2 19 1e
2a 6e 71 :2 2a 7e 81 :2 2a 85
88 :2 2a 92 95 9e a6 :2 9e aa
:2 95 :2 2a b2 b5 :2 2a bd c0 :2 2a
c5 c8 :2 2a ce d1 :2 2a :2 13 64
:2 10 13 :2 1d 2f :2 39 45 48 5c
5f 60 :2 5c :2 2f :3 13 :2 19 1e 2a
6e 71 :2 2a :2 13 63 :3 10 :2 1b 2f
32 39 :2 10 2c 48 :2 d 29 d
19 :2 d 1d d :4 a :4 e d :4 12
11 10 2f :2 3a 42 51 60 :2 2f
64 66 :2 64 2e :2 10 13 :2 1d 2f
:2 39 45 49 5d 60 61 :2 5d :2 2f
:3 13 :2 19 1e 2a 6e 71 :2 2a 7e
81 :2 2a 85 88 :2 2a 92 95 9e
a6 :2 af :2 9e c0 :2 95 :2 2a c8 cb
:2 2a d3 d6 :2 2a db de :2 2a e4
e7 :2 2a :2 13 64 :2 10 13 :2 1d 2f
:2 39 45 48 5c 5f 60 :2 5c :2 2f
:3 13 :2 19 1e 2a 6e 71 :2 2a :2 13
63 :3 10 :2 1b 2f :2 38 48 4f :2 10
d 69 :4 15 14 13 39 :2 44 4c
5b 15 :2 39 19 1c :2 19 38 :3 13
:2 1d 2f :2 39 45 48 5c 5f 60
:2 5c :2 2f :3 13 :2 19 1e 2a 6e 71
:2 2a 7e 81 :2 2a 85 88 :2 2a 92
95 9e a6 :2 af :2 9e ca :2 95 :2 2a
:2 13 63 :2 10 13 :2 1d 2f :2 39 45
48 5c 5f 60 :2 5c :2 2f :3 13 :2 19
1e 2a 6e 71 :2 2a :2 13 63 :3 10
:2 1b 31 :2 3a 54 :2 10 1f 69 :2 d
:4 12 11 10 2f :2 3a 42 51 5e
:2 2f 62 64 :2 62 2e :3 10 18 10
67 10 18 10 :4 d 10 :2 1b 23
32 42 :2 10 46 48 :2 46 10 21
10 d 4a 13 :2 1e 25 34 :2 13
41 44 :2 41 1a 25 32 3c 47
4c 55 65 77 18 19 26 17
22 2a 31 :2 13 :2 1c 28 13 10
:2 18 16 :2 1f 2b 16 19 :2 23 35
:2 3f 4b 4f 63 66 67 :2 63 :2 35
:3 19 :2 1f 24 30 74 77 :2 30 84
87 :2 30 8b 8e :2 30 9a 9d :2 30
a5 a8 :2 30 b4 b7 be c7 ca
:2 b7 :2 30 :2 19 6a :2 16 :2 13 :4 1f :2 13
10 :3 46 14 :2 1d 28 26 :2 31 :2 26
13 1f 2a 37 3f 46 5f 6a
81 94 :2 16 :2 1f 2b 16 13 :2 1b
19 :2 22 2e 19 1c :2 26 38 :2 42
4e 52 66 69 6a :2 66 :2 38 :3 1c
:2 22 27 33 77 7a :2 33 87 8a
:2 33 8e 91 :2 33 9d a0 :2 33 a8
ab :2 33 b7 ba c1 ca cd :2 ba
:2 33 :2 1c 6d :2 19 :2 16 :4 22 :2 16 13
:4 41 :2 10 d 46 4a 13 :2 1e 26
35 44 :2 13 48 4a :2 48 13 :2 1d
2f :2 39 45 49 5d 60 61 :2 5d
:2 2f :3 13 :2 19 1e 2a 6e 71 :2 2a
7e 81 :2 2a 85 88 :2 2a 92 95
9e a6 :2 9e aa :2 95 :2 2a b2 b5
:2 2a bd c0 :2 2a c5 c8 :2 2a ce
d1 :2 2a :2 13 64 :2 10 13 :2 1d 2f
:2 39 45 48 5c 5f 60 :2 5c :2 2f
:3 13 :2 19 1e 2a 6e 71 :2 2a :2 13
63 :3 10 :2 1b 2f 32 39 :2 10 4c
4a :2 d 2a d 1e d :5 a 18
:2 a 18 a d 16 29 :2 d 2f
2c :2 38 :2 2c 17 10 22 10 22
10 16 2a 10 17 13 1f :3 1d
13 :2 1c 28 13 24 13 :2 1c 28
13 :4 10 d :2 15 13 :2 1c 28 13
16 :2 20 32 :2 3c 48 4c 60 63
64 :2 60 :2 32 :3 16 :2 1c 21 2d 71
74 :2 2d 81 84 :2 2d 88 8b :2 2d
97 9a :2 2d a2 a5 :2 2d b1 b4
bb c4 c7 :2 b4 :2 2d :2 16 67 :2 13
:2 10 :4 1c :2 10 d :4 52 :4 11 10 :4 14
13 1d 2d 1b 2b 39 1c 29
3c 50 69 7d 1a 25 2d 34
:2 16 :2 1f 2b 16 13 :2 1b 19 :2 22
2e 19 1c :2 26 38 :2 42 4e 52
66 69 6a :2 66 :2 38 :3 1c :2 22 27
33 77 7a :2 33 87 8a :2 33 8e
91 :2 33 9d a0 :2 33 a8 ab :2 33
b7 ba c1 ca cd :2 ba :2 33 :2 1c
6d :2 19 :2 16 :4 22 :2 16 13 :3 30 16
1f 2b :2 16 2e 30 :2 2e 19 :2 23
35 :2 3f 4b 4f 63 66 67 :2 63
:2 35 :3 19 :2 1f 24 30 74 77 :2 30
84 87 :2 30 8b 8e :2 30 98 9b
a4 ac :2 b5 :2 a4 d4 :2 9b :2 30 dc
df :2 30 e7 ea :2 30 ef f2 :2 30
106 109 :2 30 :2 19 6a :2 16 19 :2 23
35 :2 3f 4b 4e 62 65 66 :2 62
:2 35 :3 19 :2 1f 24 30 74 77 :2 30
:2 19 69 :3 16 :2 21 35 :2 3e 5c 1e
:2 16 32 :2 13 10 30 :4 17 16 1d
2d 1b 2b 39 1c 29 3c 50
69 7d 1a 25 2d 34 :2 16 :2 1f
2b 16 13 :2 1b 19 :2 22 2e 19
1c :2 26 38 :2 42 4e 52 66 69
6a :2 66 :2 38 :3 1c :2 22 27 33 77
7a :2 33 87 8a :2 33 8e 91 :2 33
9d a0 :2 33 a8 ab :2 33 b7 ba
c1 ca cd :2 ba :2 33 :2 1c 6d :2 19
:2 16 :4 22 :2 16 13 :3 32 16 1f 2b
:2 16 2e 30 :2 2e 19 :2 23 35 :2 3f
4b 4f 63 66 67 :2 63 :2 35 :3 19
:2 1f 24 30 74 77 :2 30 84 87
:2 30 8b 8e :2 30 98 9b a4 ac
:2 b5 :2 a4 d4 :2 9b :2 30 dc df :2 30
e7 ea :2 30 ef f2 :2 30 106 109
:2 30 :2 19 6a :2 16 19 :2 23 35 :2 3f
4b 4e 62 65 66 :2 62 :2 35 :3 19
:2 1f 24 30 74 77 :2 30 :2 19 69
:3 16 :2 21 35 :2 3e 5c 1e :2 16 32
20 24 34 41 1f 2c 3d 49
61 6d 75 7c :2 19 :2 22 2e 19
16 :2 1e 1c :2 25 31 1c 1f :2 29
3b :2 45 51 55 69 6c 6d :2 69
:2 3b :3 1f :2 25 2a 36 7a 7d :2 36
8a 8d :2 36 91 94 :2 36 a0 a3
:2 36 ab ae :2 36 ba bd c4 cd
d0 :2 bd :2 36 :2 1f 70 :2 1c :2 19 :4 25
:2 19 16 :3 13 19 22 2b :2 19 30
2e 39 40 :2 30 :2 2e 1c :2 26 38
:2 42 4e 52 66 69 6a :2 66 :2 38
:3 1c :2 22 27 33 77 7a :2 33 87
8a :2 33 8e 91 :2 33 9b 9e a7
af :2 b8 :2 a7 d7 :2 9e :2 33 df e2
:2 33 ea ed :2 33 f2 f5 :2 33 109
10c :2 33 :2 1c 6d :2 19 1c :2 26 38
:2 42 4e 51 65 68 69 :2 65 :2 38
:3 1c :2 22 27 33 77 7a :2 33 :2 1c
6c :3 19 :2 24 38 :2 41 5f 21 :2 19
43 :2 16 :4 13 32 30 16 :2 20 32
:2 3c 48 4c 60 63 64 :2 60 :2 32
:3 16 :2 1c 21 2d 71 74 :2 2d 81
84 :2 2d 88 8b :2 2d 95 98 a1
a9 :2 b2 :2 a1 ca :2 98 :2 2d d2 d5
:2 2d dd e0 :2 2d e5 e8 :2 2d fc
ff :2 2d :2 16 67 :2 13 16 :2 20 32
:2 3c 48 4b 5f 62 63 :2 5f :2 32
:3 16 :2 1c 21 2d 71 74 :2 2d :2 16
66 :3 13 :2 1e 32 :2 3b 52 1b :2 13
:4 10 32 :3 d 1a :2 d 24 d :4 11
10 :4 2d 2c 2b :3 10 20 10 4c
:3 d 20 33 41 4c 29 3e 4c
29 3b 47 51 29 37 3e 49
4f 29 38 48 54 29 35 48
54 :2 20 :2 d 1b :2 d 20 30 3e
53 5f 62 :2 20 d :4 11 :2 10 1e
:2 10 23 33 41 56 62 65 :2 23
10 32 :2 d :4 a 26 :2 7 :4 4 8
:2 13 1a 24 :2 8 30 32 :2 30 7
3a a 1d :2 3a 23 20 :2 2c :2 20
39 :3 7 15 :2 7 17 :2 7 1c :2 25
:2 7 16 25 31 46 52 60 :2 16
:2 7 :2 10 1c :2 7 15 :2 7 17 :2 7
1c :2 25 :2 7 16 25 31 46 52
60 :2 16 :2 7 :2 10 1c 7 47 :3 4
17 21 :2 17 4 7 :2 11 23 :2 2d
39 3c 50 53 54 :2 50 :2 23 :3 7
:2 d 12 1e 62 65 :2 1e 72 75
:2 1e 79 7c :2 1e 86 89 92 9a
:2 a3 :2 92 ae :2 89 :2 1e b6 b9 :2 1e
c1 c4 :2 1e c9 cc :2 1e d2 d5
:2 1e :2 7 57 :3 4 :2 f 21 :2 2a 34
3b :2 4 1 9 12 9 a :2 14
26 :2 30 3c 40 54 57 58 :2 54
:2 26 :3 a :2 10 15 21 65 68 :2 21
:3 a :2 10 15 39 5c 5f :2 68 :2 39
76 79 :2 39 81 84 :2 8d :2 39 :2 a
5b :3 7 c 15 1e 2c a 13
1e f e 7 e 7 e 7
29 :2 4 :2 9 7 :2 10 1c :2 7 :2 11
23 :2 2d 39 3d 51 54 55 :2 51
:2 23 :3 7 :2 d 12 1e 62 65 :2 1e
:3 7 :2 d 12 36 42 45 :2 36 4d
50 :2 36 5c 5f 66 6f 72 :2 5f
:2 36 :2 7 58 :2 4 7 c 1b a
13 1e f e 7 e 7 e
7 :2 4 :4 10 :2 4 :8 1 
10ba
4
0 :2 1 :4 3 :4 4
:4 5 :4 6 :4 7 2
:4 8 :2 1 :7 a :7 b
:7 c :7 d :7 e :7 f
:7 10 :7 11 :5 12 :5 13
:5 14 :5 15 :5 16 :5 17
:5 18 :7 19 :6 1a :6 1b
:6 1c :6 1d :5 1e :5 1f
:5 20 :5 21 :5 22 :5 23
:7 24 :6 25 :6 26 :6 27
:6 28 :6 29 :6 2a :6 2b
:6 2c :6 2d :6 2e :6 2f
:6 30 :6 31 :6 32 :6 33
:7 34 :5 35 :6 36 :7 38
:b 3a :11 3b 3c :2 3b
:2 3c :2 3b :2 3c :2 3b
:2 3d :2 3b :12 3d :2 3b
:2 3e :2 3b :12 3e :2 3b
:2 3f :2 3b :9 3f :2 3b
:2 40 :2 3b :2 40 :2 3b
:2 40 :2 3b :2 40 :2 3b
:2 40 :4 3b :3 3a :11 43
:b 44 :3 43 :3 4a :3 4b
:3 4d :3 4f :3 50 :3 51
:3 52 :a 53 :5 54 :3 53
:6 58 :f 59 :8 5a :6 5b
:9 5c :8 5d 5e :2 5f
58 :5 60 57 :2 62
:5 64 :11 65 :24 66 :3 65
:2 63 :6 62 61 :3 39
:a 6c :11 6d :30 6e :3 6d
:11 70 :b 71 :3 70 :a 73
:3 6c :9 76 :11 77 :30 78
:3 77 :11 7a :b 7b :3 7a
:a 7d :3 76 :e 80 :c 81
:11 82 :30 83 :3 82 :11 85
:b 86 :3 85 :a 88 :3 81
:3 80 :3 8c :4 8e :4 8f
:7 90 8e :5 91 8d
:2 93 :5 95 :11 96 :24 97
:3 96 :2 94 :6 93 92
:3 39 :3 9d :d 9e :2 9f
:2 9e :6 9f :3 9e :3 a0
:3 a1 :5 a2 :a a3 :5 a4
:3 a6 :3 a7 :5 a8 :a a9
:5 aa 9f :2 9e :15 ae
:3 af :3 ae :e b2 b4
:2 b5 :2 b6 b7 :2 b8
b4 :6 b9 :5 ba b9
:5 bc bb :3 b9 b3
:2 bf :5 c1 :11 c2 :24 c3
:3 c2 :2 c0 :6 bf be
:4 b2 :c ca ce :2 cf
d0 :2 d1 ce :6 d2
:5 d3 d2 :5 d5 d4
:3 d2 cd :2 d8 :5 da
:11 db :24 dc :3 db :2 d9
:6 d8 d7 :3 ca :c e3
:3 e5 :3 e3 :3 ca :c e9
ec :2 ed ee :2 ef
ec :6 f0 :5 f1 f0
:5 f3 f2 :3 f0 eb
:2 f6 :5 f8 :11 f9 :24 fa
:3 f9 :2 f7 :6 f6 f5
:3 e9 :c 102 :3 104 :3 102
:3 e9 :9 108 :15 10b :3 10c
:3 10b :12 10f 110 :2 10f
:4 110 :3 10f :11 111 :30 112
:3 111 :11 114 :b 115 :3 114
:a 117 110 :2 10f :5 11a
:5 11b :11 11c :30 11d :3 11c
:11 11f :b 120 :3 11f :a 122
:3 11b :3 126 :c 127 :3 128
129 127 :c 129 :9 12b
12c :2 12d :4 12e 12b
:5 12f 12a :2 131 :5 133
:11 134 :24 135 :3 134 :2 132
:6 131 130 :3 129 :a 13a
:a 13d :5 13e 13c :2 140
:5 142 :11 143 :24 144 :3 143
:2 141 :6 140 13f :6 13a
149 129 127 :5 149
:11 14a :2e 14b :3 14a :11 14d
:b 14e :3 14d :8 150 149
:3 127 11a :3 153 :3 154
152 :3 11a :5 157 :15 159
:11 15a :30 15b :3 15a :11 15d
:b 15e :3 15d :a 160 161
159 :b 161 162 :2 161
:4 162 :3 161 :11 163 :20 164
:3 163 :11 166 :b 167 :3 166
:9 169 162 :3 159 :15 16c
:3 16d 16c :3 16f 16e
:3 16c :c 173 :3 174 175
173 :b 175 :9 178 179
:2 17a :4 17b 178 :5 17c
177 :2 17e :5 180 :11 181
:24 182 :3 181 :2 17f :6 17e
17d :3 175 :a 188 :a 18b
:5 18c 18a :2 18e :5 190
:11 191 :24 192 :3 191 :2 18f
:6 18e 18d :6 188 197
175 173 :c 197 :11 199
:2e 19a :3 199 :11 19c :b 19d
:3 19c :8 19f 197 :3 173
157 :3 1a2 1a1 :3 157
:3 1a5 :3 1a6 :b 1a9 1ab
:2 1ac :2 1ad 1ae :2 1af
1ab :6 1b0 :5 1b1 1b0
:5 1b3 1b2 :3 1b0 1aa
:2 1b6 :5 1b8 :11 1b9 :24 1ba
:3 1b9 :2 1b7 :6 1b6 1b5
:4 1a9 :5 1c1 :5 1c3 :2 1c5
1c6 :2 1c7 :6 1c8 :4 1c9
1c5 :5 1ca 1c4 :2 1cc
:5 1ce :11 1cf :24 1d0 :3 1cf
:2 1cd :6 1cc 1cb :3 1c3
:9 1d4 :11 1d7 :30 1d8 :3 1d7
:11 1da :b 1db :3 1da :7 1dd
1de :2 1dd :3 1d4 1e0
1c3 :5 1e0 :2 1e3 1e4
:2 1e5 :6 1e6 :4 1e7 1e3
:5 1e8 1e2 :2 1ea :5 1ec
:11 1ed :24 1ee :3 1ed :2 1eb
:6 1ea 1e9 :3 1e0 :9 1f3
:11 1f5 :30 1f6 :3 1f5 :11 1f8
:b 1f9 :3 1f8 :7 1fb 1fc
:2 1fb 1f3 :4 203 :8 204
203 :5 205 202 :2 207
:5 209 :11 20a :24 20b :3 20a
:2 208 :6 207 206 :3 1fd
:d 20f :11 210 :30 211 :3 210
:11 213 :b 214 :3 213 :7 216
217 :2 216 :3 20f 1fd
:3 1f3 1e0 1c3 :11 21b
:30 21c :3 21b :11 21e :b 21f
:3 21e :7 221 222 :2 221
21a :3 1c3 :3 1c1 :3 227
:3 228 :d 22a :3 22b :3 22a
:5 22e :3 22f :4 230 :5 231
:4 232 :4 233 :3 22e :3 235
:a 236 :5 238 :3 239 :a 23a
:3 238 1be :3 1a9 :3 108
c8 :3 b2 :d 240 :2 241
:2 240 :6 241 :3 240 :3 242
:3 243 :5 244 :a 245 :5 246
:3 248 :3 249 :5 24a :a 24b
:5 24c 241 :2 240 :6 24f
:11 251 :30 252 :3 251 :a 254
39 :3 258 :11 259 :b 25a
:17 25b :3 259 :2 25d :3 25e
:3 25f 260 25e 25d
25e :3 261 :3 258 :2 262
:5 264 :11 265 :b 266 :18 267
:3 265 :2 269 26a :3 26b
26c 26a 269 26a
:3 26d :2 263 :6 262 257
:7 1 
3a6d
4
:3 0 1 :3 0 2
:a 0 10b5 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
56 0 7 6
:3 0 5 :7 0 9
8 :3 0 6 :3 0
7 :7 0 d c
:3 0 d :2 0 b
9 :3 0 8 :7 0
11 10 :3 0 4
:3 0 a :7 0 15
14 :3 0 b :3 0
c :3 0 d :2 0
4 19 1a 0
17 1b 0 10b5
2 1c :2 0 f
:2 0 15 4 :3 0
f :2 0 13 1f
21 :6 0 24 22
0 10b3 0 e
:6 0 f :2 0 19
4 :3 0 17 26
28 :6 0 2b 29
0 10b3 0 10
:6 0 f :2 0 1d
4 :3 0 1b 2d
2f :6 0 32 30
0 10b3 0 11
:6 0 f :2 0 21
4 :3 0 1f 34
36 :6 0 39 37
0 10b3 0 12
:6 0 f :2 0 25
4 :3 0 23 3b
3d :6 0 40 3e
0 10b3 0 13
:6 0 f :2 0 29
4 :3 0 27 42
44 :6 0 47 45
0 10b3 0 14
:6 0 f :2 0 2d
4 :3 0 2b 49
4b :6 0 4e 4c
0 10b3 0 15
:6 0 33 17e 0
31 4 :3 0 2f
50 52 :6 0 55
53 0 10b3 0
16 :6 0 37 1b2
0 35 6 :3 0
57 :7 0 5a 58
0 10b3 0 17
:6 0 6 :3 0 5c
:7 0 5f 5d 0
10b3 0 18 :6 0
3b 1e6 0 39
6 :3 0 61 :7 0
64 62 0 10b3
0 19 :6 0 6
:3 0 66 :7 0 69
67 0 10b3 0
1a :6 0 3f 21a
0 3d 6 :3 0
6b :7 0 6e 6c
0 10b3 0 1b
:6 0 6 :3 0 70
:7 0 73 71 0
10b3 0 1c :6 0
21 :2 0 43 6
:3 0 75 :7 0 78
76 0 10b3 0
1d :6 0 4 :3 0
1f :2 0 41 7a
7c :6 0 7f 7d
0 10b3 0 1e
:6 0 21 :2 0 45
9 :3 0 81 :7 0
85 82 83 10b3
0 20 :6 0 25
:2 0 47 9 :3 0
87 :7 0 8b 88
89 10b3 0 22
:6 0 25 :2 0 49
24 :3 0 8d :7 0
91 8e 8f 10b3
0 23 :6 0 4d
2c2 0 4b 24
:3 0 93 :7 0 97
94 95 10b3 0
26 :6 0 51 2f6
0 4f 6 :3 0
99 :7 0 9c 9a
0 10b3 0 27
:6 0 6 :3 0 9e
:7 0 a1 9f 0
10b3 0 28 :6 0
55 32a 0 53
2a :3 0 a3 :7 0
a6 a4 0 10b3
0 29 :6 0 2a
:3 0 a8 :7 0 ab
a9 0 10b3 0
2b :6 0 2f :2 0
57 2a :3 0 ad
:7 0 b0 ae 0
10b3 0 2c :6 0
2a :3 0 b2 :7 0
b5 b3 0 10b3
0 2d :6 0 21
:2 0 5b 4 :3 0
59 b7 b9 :6 0
bc ba 0 10b3
0 2e :6 0 21
:2 0 5d 9 :3 0
be :7 0 c2 bf
c0 10b3 0 30
:6 0 21 :2 0 5f
9 :3 0 c4 :7 0
c8 c5 c6 10b3
0 31 :6 0 21
:2 0 61 9 :3 0
ca :7 0 ce cb
cc 10b3 0 32
:6 0 21 :2 0 63
9 :3 0 d0 :7 0
d4 d1 d2 10b3
0 33 :6 0 21
:2 0 65 9 :3 0
d6 :7 0 da d7
d8 10b3 0 34
:6 0 21 :2 0 67
9 :3 0 dc :7 0
e0 dd de 10b3
0 35 :6 0 21
:2 0 69 9 :3 0
e2 :7 0 e6 e3
e4 10b3 0 36
:6 0 21 :2 0 6b
9 :3 0 e8 :7 0
ec e9 ea 10b3
0 37 :6 0 21
:2 0 6d 9 :3 0
ee :7 0 f2 ef
f0 10b3 0 38
:6 0 21 :2 0 6f
9 :3 0 f4 :7 0
f8 f5 f6 10b3
0 39 :6 0 21
:2 0 71 9 :3 0
fa :7 0 fe fb
fc 10b3 0 3a
:6 0 21 :2 0 73
9 :3 0 100 :7 0
104 101 102 10b3
0 3b :6 0 21
:2 0 75 9 :3 0
106 :7 0 10a 107
108 10b3 0 3c
:6 0 21 :2 0 77
9 :3 0 10c :7 0
110 10d 10e 10b3
0 3d :6 0 f
:2 0 79 9 :3 0
112 :7 0 116 113
114 10b3 0 3e
:6 0 7f 53c 0
7d 4 :3 0 7b
118 11a :6 0 11d
11b 0 10b3 0
3f :6 0 12a 12b
0 81 41 :3 0
11f :7 0 122 120
0 10b3 0 40
:6 0 9 :3 0 124
0 2 :5 0 21
:2 0 128 125 126
10b3 0 42 :6 0
130 131 0 83
c :3 0 d :2 0
4 12c :7 0 12f
12d 0 10b3 0
43 :6 0 44 :3 0
45 :3 0 44 :3 0
46 :3 0 133 134
0 2 :4 0 85
135 137 132 139
138 :2 0 47 :3 0
48 :3 0 13b 13c
0 49 :4 0 44
:3 0 4a :3 0 13f
140 0 2 :4 0
87 141 143 4b
:4 0 4c :2 0 4d
:3 0 89 146 148
:3 0 4e :4 0 4c
:2 0 4f :4 0 8c
14b 14d :3 0 4c
:2 0 3 :3 0 8f
14f 151 :3 0 4c
:2 0 4f :4 0 92
153 155 :3 0 4c
:2 0 50 :4 0 95
157 159 :3 0 4c
:2 0 51 :3 0 52
:3 0 4f :4 0 4c
:2 0 5 :3 0 98
15f 161 :3 0 4c
:2 0 4f :4 0 9b
163 165 :3 0 53
:4 0 9e 15d 168
54 :4 0 a1 15c
16b a4 15b 16d
:3 0 4c :2 0 50
:4 0 a7 16f 171
:3 0 4c :2 0 51
:3 0 52 :3 0 4f
:4 0 4c :2 0 7
:3 0 aa 177 179
:3 0 4c :2 0 4f
:4 0 ad 17b 17d
:3 0 53 :4 0 b0
175 180 54 :4 0
b3 174 183 b6
173 185 :3 0 4c
:2 0 50 :4 0 b9
187 189 :3 0 4c
:2 0 51 :3 0 55
:3 0 8 :3 0 bc
18d 18f 54 :4 0
be 18c 192 c1
18b 194 :3 0 4c
:2 0 50 :4 0 c4
196 198 :3 0 4c
:2 0 4f :4 0 c7
19a 19c :3 0 4c
:2 0 a :3 0 ca
19e 1a0 :3 0 4c
:2 0 4f :4 0 cd
1a2 1a4 :3 0 4c
:2 0 56 :4 0 d0
1a6 1a8 :3 0 d3
13d 1aa :2 0 1ac
d8 1ad 13a 1ac
0 1ae da 0
1013 44 :3 0 45
:3 0 1af 1b0 0
44 :3 0 57 :3 0
1b2 1b3 0 2f
:2 0 2 :4 0 58
:2 0 59 :2 0 2f
:2 0 dc 1b8 1ba
:3 0 df 1b4 1bc
1b1 1be 1bd :2 0
47 :3 0 5a :3 0
1c0 1c1 0 49
:4 0 5b :4 0 4c
:2 0 4d :3 0 e3
1c5 1c7 :3 0 e6
1c2 1c9 :2 0 1cb
e9 1cc 1bf 1cb
0 1cd eb 0
1013 17 :3 0 5c
:4 0 1ce 1cf 0
1013 18 :3 0 5c
:4 0 1d1 1d2 0
1013 35 :3 0 2f
:2 0 1d4 1d5 0
1013 17 :3 0 5
:3 0 1d7 1d8 0
1013 18 :3 0 7
:3 0 1da 1db 0
1013 12 :3 0 3
:3 0 1dd 1de 0
1013 39 :3 0 8
:3 0 1e0 1e1 0
1013 51 :3 0 39
:3 0 21 :2 0 ed
1e3 1e6 5d :2 0
2f :2 0 f2 1e8
1ea :3 0 1eb :2 0
39 :3 0 5e :3 0
5f :3 0 1ee 1ef
0 1ed 1f0 0
1f2 f5 1f3 1ec
1f2 0 1f4 f7
0 1013 60 :3 0
61 :3 0 62 :3 0
63 :3 0 64 :3 0
65 :3 0 51 :3 0
66 :3 0 67 :3 0
51 :3 0 68 :3 0
69 :3 0 66 :3 0
68 :3 0 6a :3 0
6b :3 0 6c :3 0
6d :3 0 6c :3 0
6e :3 0 6f :3 0
70 :3 0 71 :3 0
72 :3 0 73 :3 0
74 :3 0 75 :3 0
76 :3 0 77 :3 0
e :3 0 13 :3 0
11 :3 0 1d :3 0
20 :3 0 2e :3 0
19 :3 0 1a :3 0
1b :3 0 1c :3 0
10 :3 0 14 :3 0
34 :3 0 3a :3 0
32 :3 0 37 :3 0
29 :3 0 27 :3 0
28 :3 0 30 :3 0
31 :3 0 23 :3 0
26 :3 0 78 :3 0
79 :3 0 3 :4 0
7a 1 :8 0 232
c :3 0 7b :3 0
22d 22e 0 7c
:3 0 22f 230 0
232 f9 27c 7d
:3 0 c :3 0 7b
:3 0 235 236 0
7c :3 0 237 238
0 272 44 :3 0
45 :3 0 23a 23b
0 44 :3 0 57
:3 0 23d 23e 0
7e :2 0 2 :4 0
7f :2 0 59 :2 0
2f :2 0 fc 243
245 :3 0 ff 23f
247 23c 249 248
:2 0 47 :3 0 5a
:3 0 24b 24c 0
49 :4 0 80 :4 0
4c :2 0 4d :3 0
103 250 252 :3 0
4c :2 0 81 :4 0
106 254 256 :3 0
4c :2 0 82 :4 0
109 258 25a :3 0
4c :2 0 7c :3 0
10c 25c 25e :3 0
4c :2 0 83 :4 0
10f 260 262 :3 0
4c :2 0 84 :3 0
85 :3 0 2f :2 0
86 :2 0 112 265
269 116 264 26b
:3 0 119 24d 26d
:2 0 26f 11c 270
24a 26f 0 271
11e 0 272 120
275 :3 0 275 0
275 274 272 273
:6 0 277 2 :3 0
123 279 125 278
277 :2 0 27a 127
:2 0 27c 0 27c
27b 232 27a :6 0
1013 1 :3 0 c
:3 0 7b :3 0 27e
27f 0 c :3 0
5d :2 0 87 :3 0
281 283 0 12b
282 285 :3 0 286
:2 0 44 :3 0 45
:3 0 288 289 0
44 :3 0 57 :3 0
28b 28c 0 f
:2 0 2 :4 0 88
:2 0 59 :2 0 2f
:2 0 12e 291 293
:3 0 131 28d 295
28a 297 296 :2 0
47 :3 0 5a :3 0
299 29a 0 49
:4 0 89 :4 0 4c
:2 0 4d :3 0 135
29e 2a0 :3 0 4c
:2 0 81 :4 0 138
2a2 2a4 :3 0 4c
:2 0 8a :4 0 13b
2a6 2a8 :3 0 4c
:2 0 51 :3 0 55
:3 0 5e :3 0 8b
:3 0 2ad 2ae 0
13e 2ac 2b0 54
:4 0 140 2ab 2b3
143 2aa 2b5 :3 0
4c :2 0 8c :4 0
146 2b7 2b9 :3 0
4c :2 0 4f :4 0
149 2bb 2bd :3 0
4c :2 0 3 :3 0
14c 2bf 2c1 :3 0
4c :2 0 4f :4 0
14f 2c3 2c5 :3 0
152 29b 2c7 :2 0
2c9 155 2ca 298
2c9 0 2cb 157
0 2f5 44 :3 0
45 :3 0 2cc 2cd
0 44 :3 0 57
:3 0 2cf 2d0 0
2f :2 0 2 :4 0
8d :2 0 59 :2 0
2f :2 0 159 2d5
2d7 :3 0 15c 2d1
2d9 2ce 2db 2da
:2 0 47 :3 0 5a
:3 0 2dd 2de 0
49 :4 0 8e :4 0
4c :2 0 4d :3 0
160 2e2 2e4 :3 0
163 2df 2e6 :2 0
2e8 166 2e9 2dc
2e8 0 2ea 168
0 2f5 8f :3 0
90 :3 0 2eb 2ec
0 5e :3 0 8b
:3 0 2ee 2ef 0
3 :3 0 91 :3 0
16a 2ed 2f3 :2 0
2f5 16e 2f6 287
2f5 0 2f7 172
0 1013 51 :3 0
20 :3 0 21 :2 0
174 2f8 2fb 5d
:2 0 92 :2 0 179
2fd 2ff :3 0 44
:3 0 45 :3 0 301
302 0 44 :3 0
57 :3 0 304 305
0 f :2 0 2
:4 0 93 :2 0 59
:2 0 2f :2 0 17c
30a 30c :3 0 17f
306 30e 303 310
30f :2 0 47 :3 0
5a :3 0 312 313
0 49 :4 0 94
:4 0 4c :2 0 4d
:3 0 183 317 319
:3 0 4c :2 0 81
:4 0 186 31b 31d
:3 0 4c :2 0 8a
:4 0 189 31f 321
:3 0 4c :2 0 51
:3 0 55 :3 0 5e
:3 0 95 :3 0 326
327 0 18c 325
329 54 :4 0 18e
324 32c 191 323
32e :3 0 4c :2 0
8c :4 0 194 330
332 :3 0 4c :2 0
4f :4 0 197 334
336 :3 0 4c :2 0
3 :3 0 19a 338
33a :3 0 4c :2 0
4f :4 0 19d 33c
33e :3 0 1a0 314
340 :2 0 342 1a3
343 311 342 0
344 1a5 0 36e
44 :3 0 45 :3 0
345 346 0 44
:3 0 57 :3 0 348
349 0 2f :2 0
2 :4 0 96 :2 0
59 :2 0 2f :2 0
1a7 34e 350 :3 0
1aa 34a 352 347
354 353 :2 0 47
:3 0 5a :3 0 356
357 0 49 :4 0
97 :4 0 4c :2 0
4d :3 0 1ae 35b
35d :3 0 1b1 358
35f :2 0 361 1b4
362 355 361 0
363 1b6 0 36e
8f :3 0 90 :3 0
364 365 0 5e
:3 0 95 :3 0 367
368 0 3 :3 0
91 :3 0 1b8 366
36c :2 0 36e 1bc
36f 300 36e 0
370 1c0 0 1013
5 :3 0 98 :2 0
1c2 372 373 :3 0
374 :2 0 375 :2 0
7 :3 0 98 :2 0
1c4 378 379 :3 0
37a :2 0 37b :2 0
376 37d 37c :2 0
99 :3 0 9a :3 0
37f 380 0 18
:3 0 17 :3 0 9b
:2 0 1c6 381 385
9c :2 0 21 :2 0
1cc 387 389 :3 0
44 :3 0 45 :3 0
38b 38c 0 44
:3 0 57 :3 0 38e
38f 0 f :2 0
2 :4 0 9d :2 0
59 :2 0 2f :2 0
1cf 394 396 :3 0
1d2 390 398 38d
39a 399 :2 0 47
:3 0 5a :3 0 39c
39d 0 49 :4 0
9e :4 0 4c :2 0
4d :3 0 1d6 3a1
3a3 :3 0 4c :2 0
81 :4 0 1d9 3a5
3a7 :3 0 4c :2 0
8a :4 0 1dc 3a9
3ab :3 0 4c :2 0
51 :3 0 55 :3 0
5e :3 0 9f :3 0
3b0 3b1 0 1df
3af 3b3 54 :4 0
1e1 3ae 3b6 1e4
3ad 3b8 :3 0 4c
:2 0 8c :4 0 1e7
3ba 3bc :3 0 4c
:2 0 4f :4 0 1ea
3be 3c0 :3 0 4c
:2 0 3 :3 0 1ed
3c2 3c4 :3 0 4c
:2 0 4f :4 0 1f0
3c6 3c8 :3 0 1f3
39e 3ca :2 0 3cc
1f6 3cd 39b 3cc
0 3ce 1f8 0
3f8 44 :3 0 45
:3 0 3cf 3d0 0
44 :3 0 57 :3 0
3d2 3d3 0 2f
:2 0 2 :4 0 a0
:2 0 59 :2 0 2f
:2 0 1fa 3d8 3da
:3 0 1fd 3d4 3dc
3d1 3de 3dd :2 0
47 :3 0 5a :3 0
3e0 3e1 0 49
:4 0 a1 :4 0 4c
:2 0 4d :3 0 201
3e5 3e7 :3 0 204
3e2 3e9 :2 0 3eb
207 3ec 3df 3eb
0 3ed 209 0
3f8 8f :3 0 90
:3 0 3ee 3ef 0
5e :3 0 9f :3 0
3f1 3f2 0 3
:3 0 91 :3 0 20b
3f0 3f6 :2 0 3f8
20f 3f9 38a 3f8
0 3fa 213 0
3fb 215 3fc 37e
3fb 0 3fd 217
0 1013 2d :4 0
3fe 3ff 0 1013
a2 :3 0 a3 :3 0
2d :3 0 a4 :3 0
a5 :3 0 e :3 0
6b :3 0 14 :3 0
a6 :3 0 5e :3 0
a7 :3 0 5e :3 0
a8 :3 0 5e :3 0
a9 :4 0 aa 1
:8 0 416 c :3 0
7b :3 0 411 412
0 7c :3 0 413
414 0 416 219
460 7d :3 0 c
:3 0 7b :3 0 419
41a 0 7c :3 0
41b 41c 0 456
44 :3 0 45 :3 0
41e 41f 0 44
:3 0 57 :3 0 421
422 0 7e :2 0
2 :4 0 ab :2 0
59 :2 0 2f :2 0
21c 427 429 :3 0
21f 423 42b 420
42d 42c :2 0 47
:3 0 5a :3 0 42f
430 0 49 :4 0
ac :4 0 4c :2 0
4d :3 0 223 434
436 :3 0 4c :2 0
81 :4 0 226 438
43a :3 0 4c :2 0
82 :4 0 229 43c
43e :3 0 4c :2 0
7c :3 0 22c 440
442 :3 0 4c :2 0
83 :4 0 22f 444
446 :3 0 4c :2 0
84 :3 0 85 :3 0
2f :2 0 86 :2 0
232 449 44d 236
448 44f :3 0 239
431 451 :2 0 453
23c 454 42e 453
0 455 23e 0
456 240 459 :3 0
459 0 459 458
456 457 :6 0 45b
4 :3 0 243 45d
245 45c 45b :2 0
45e 247 :2 0 460
0 460 45f 416
45e :6 0 1013 1
:3 0 15 :3 0 a
:3 0 462 463 0
1013 99 :3 0 ad
:3 0 465 466 0
14 :3 0 15 :3 0
249 467 46a 5d
:2 0 21 :2 0 24e
46c 46e :3 0 46f
:2 0 51 :3 0 39
:3 0 21 :2 0 251
471 474 5e :3 0
ae :2 0 5f :3 0
476 478 0 256
477 47a :3 0 47b
:2 0 470 47d 47c
:2 0 3f :3 0 af
:4 0 47f 480 0
4b3 3e :3 0 2f
:2 0 482 483 0
4b3 42 :3 0 c
:3 0 7b :3 0 486
487 0 485 488
0 4b3 40 :3 0
b0 :3 0 3f :3 0
12 :3 0 15 :3 0
3e :3 0 21 :2 0
259 48b 491 48a
492 0 4b3 c
:3 0 7b :3 0 494
495 0 42 :3 0
496 497 0 4b3
3f :3 0 b1 :4 0
499 49a 0 4b3
3e :3 0 21 :2 0
49c 49d 0 4b3
42 :3 0 c :3 0
7b :3 0 4a0 4a1
0 49f 4a2 0
4b3 40 :3 0 b0
:3 0 3f :3 0 12
:3 0 15 :3 0 3e
:3 0 21 :2 0 25f
4a5 4ab 4a4 4ac
0 4b3 c :3 0
7b :3 0 4ae 4af
0 42 :3 0 4b0
4b1 0 4b3 265
4b4 47e 4b3 0
4b5 270 0 1013
17 :3 0 98 :2 0
272 4b7 4b8 :3 0
4b9 :2 0 4ba :2 0
99 :3 0 9a :3 0
4bc 4bd 0 17
:3 0 19 :3 0 9b
:2 0 274 4be 4c2
5d :2 0 21 :2 0
27a 4c4 4c6 :3 0
4c7 :2 0 4bb 4c9
4c8 :2 0 17 :3 0
19 :3 0 4cb 4cc
0 4ce 27d 4cf
4ca 4ce 0 4d0
27f 0 1013 5
:3 0 b2 :2 0 281
4d2 4d3 :3 0 4d4
:2 0 4d5 :2 0 7
:3 0 b2 :2 0 283
4d8 4d9 :3 0 4da
:2 0 4db :2 0 4d6
4dd 4dc :2 0 78
:3 0 66 :3 0 5
:3 0 68 :3 0 7
:3 0 b3 :3 0 79
:3 0 3 :4 0 b4
1 :8 0 4fd b5
:4 0 4e8 :3 0 91
:3 0 5d :2 0 287
4eb 4ec :3 0 c
:3 0 7b :3 0 4ee
4ef 0 21 :2 0
4f0 4f1 0 4f3
28a 4fa c :3 0
7b :3 0 4f4 4f5
0 b6 :2 0 4f6
4f7 0 4f9 28c
4fb 4ed 4f3 0
4fc 0 4f9 0
4fc 28e 0 4fd
291 547 7d :3 0
c :3 0 7b :3 0
500 501 0 7c
:3 0 502 503 0
53d 44 :3 0 45
:3 0 505 506 0
44 :3 0 57 :3 0
508 509 0 7e
:2 0 2 :4 0 b7
:2 0 59 :2 0 2f
:2 0 294 50e 510
:3 0 297 50a 512
507 514 513 :2 0
47 :3 0 5a :3 0
516 517 0 49
:4 0 b8 :4 0 4c
:2 0 4d :3 0 29b
51b 51d :3 0 4c
:2 0 81 :4 0 29e
51f 521 :3 0 4c
:2 0 82 :4 0 2a1
523 525 :3 0 4c
:2 0 7c :3 0 2a4
527 529 :3 0 4c
:2 0 83 :4 0 2a7
52b 52d :3 0 4c
:2 0 84 :3 0 85
:3 0 2f :2 0 86
:2 0 2aa 530 534
2ae 52f 536 :3 0
2b1 518 538 :2 0
53a 2b4 53b 515
53a 0 53c 2b6
0 53d 2b8 540
:3 0 540 0 540
53f 53d 53e :6 0
542 6 :3 0 2bb
544 2bd 543 542
:2 0 545 2bf :2 0
547 0 547 546
4fd 545 :6 0 549
1 :3 0 2c1 f6b
5 :3 0 b2 :2 0
2c3 54b 54c :3 0
54d :2 0 1b :3 0
98 :2 0 2c5 550
551 :3 0 552 :2 0
54e 554 553 :2 0
78 :3 0 66 :3 0
5 :3 0 b3 :3 0
79 :3 0 3 :4 0
b9 1 :8 0 572
b5 :4 0 55d :3 0
91 :3 0 5d :2 0
2c9 560 561 :3 0
c :3 0 7b :3 0
563 564 0 21
:2 0 565 566 0
568 2cc 56f c
:3 0 7b :3 0 569
56a 0 b6 :2 0
56b 56c 0 56e
2ce 570 562 568
0 571 0 56e
0 571 2d0 0
572 2d3 5bc 7d
:3 0 c :3 0 7b
:3 0 575 576 0
7c :3 0 577 578
0 5b2 44 :3 0
45 :3 0 57a 57b
0 44 :3 0 57
:3 0 57d 57e 0
7e :2 0 2 :4 0
ba :2 0 59 :2 0
2f :2 0 2d6 583
585 :3 0 2d9 57f
587 57c 589 588
:2 0 47 :3 0 5a
:3 0 58b 58c 0
49 :4 0 bb :4 0
4c :2 0 4d :3 0
2dd 590 592 :3 0
4c :2 0 81 :4 0
2e0 594 596 :3 0
4c :2 0 82 :4 0
2e3 598 59a :3 0
4c :2 0 7c :3 0
2e6 59c 59e :3 0
4c :2 0 83 :4 0
2e9 5a0 5a2 :3 0
4c :2 0 84 :3 0
85 :3 0 2f :2 0
86 :2 0 2ec 5a5
5a9 2f0 5a4 5ab
:3 0 2f3 58d 5ad
:2 0 5af 2f6 5b0
58a 5af 0 5b1
2f8 0 5b2 2fa
5b5 :3 0 5b5 0
5b5 5b4 5b2 5b3
:6 0 5b7 8 :3 0
2fd 5b9 2ff 5b8
5b7 :2 0 5ba 301
:2 0 5bc 0 5bc
5bb 572 5ba :6 0
5d0 1 :3 0 99
:3 0 9a :3 0 5be
5bf 0 18 :3 0
1c :3 0 9b :2 0
303 5c0 5c4 5d
:2 0 21 :2 0 309
5c6 5c8 :3 0 35
:3 0 21 :2 0 5ca
5cb 0 5cd 30c
5ce 5c9 5cd 0
5cf 30e 0 5d0
310 5d1 555 5d0
0 5d2 313 0
f6a 7 :3 0 b2
:2 0 315 5d4 5d5
:3 0 5d6 :2 0 1c
:3 0 98 :2 0 317
5d9 5da :3 0 5db
:2 0 5d7 5dd 5dc
:2 0 78 :3 0 68
:3 0 7 :3 0 b3
:3 0 79 :3 0 3
:4 0 bc 1 :8 0
5fb b5 :4 0 5e6
:3 0 91 :3 0 5d
:2 0 31b 5e9 5ea
:3 0 c :3 0 7b
:3 0 5ec 5ed 0
21 :2 0 5ee 5ef
0 5f1 31e 5f8
c :3 0 7b :3 0
5f2 5f3 0 b6
:2 0 5f4 5f5 0
5f7 320 5f9 5eb
5f1 0 5fa 0
5f7 0 5fa 322
0 5fb 325 645
7d :3 0 c :3 0
7b :3 0 5fe 5ff
0 7c :3 0 600
601 0 63b 44
:3 0 45 :3 0 603
604 0 44 :3 0
57 :3 0 606 607
0 7e :2 0 2
:4 0 bd :2 0 59
:2 0 2f :2 0 328
60c 60e :3 0 32b
608 610 605 612
611 :2 0 47 :3 0
5a :3 0 614 615
0 49 :4 0 be
:4 0 4c :2 0 4d
:3 0 32f 619 61b
:3 0 4c :2 0 81
:4 0 332 61d 61f
:3 0 4c :2 0 82
:4 0 335 621 623
:3 0 4c :2 0 7c
:3 0 338 625 627
:3 0 4c :2 0 83
:4 0 33b 629 62b
:3 0 4c :2 0 84
:3 0 85 :3 0 2f
:2 0 86 :2 0 33e
62e 632 342 62d
634 :3 0 345 616
636 :2 0 638 348
639 613 638 0
63a 34a 0 63b
34c 63e :3 0 63e
0 63e 63d 63b
63c :6 0 640 a
:3 0 34f 642 351
641 640 :2 0 643
353 :2 0 645 0
645 644 5fb 643
:6 0 659 1 :3 0
99 :3 0 9a :3 0
647 648 0 17
:3 0 1b :3 0 9b
:2 0 355 649 64d
5d :2 0 21 :2 0
35b 64f 651 :3 0
35 :3 0 21 :2 0
653 654 0 656
35e 657 652 656
0 658 360 0
659 362 65a 5de
659 0 65b 365
0 f6a 51 :3 0
35 :3 0 21 :2 0
367 65c 65f 5d
:2 0 2f :2 0 36c
661 663 :3 0 18
:3 0 98 :2 0 36f
666 667 :3 0 668
:2 0 669 :2 0 99
:3 0 9a :3 0 66b
66c 0 18 :3 0
1a :3 0 9b :2 0
371 66d 671 5d
:2 0 21 :2 0 377
673 675 :3 0 676
:2 0 66a 678 677
:2 0 18 :3 0 1a
:3 0 67a 67b 0
67d 37a 67e 679
67d 0 67f 37c
0 f67 2d :3 0
98 :2 0 37e 681
682 :3 0 683 :2 0
684 :2 0 18 :3 0
98 :2 0 380 687
688 :3 0 689 :2 0
68a :2 0 685 68c
68b :2 0 99 :3 0
ad :3 0 68e 68f
0 2d :3 0 18
:3 0 382 690 693
bf :2 0 21 :2 0
387 695 697 :3 0
698 :2 0 68d 69a
699 :2 0 44 :3 0
45 :3 0 69c 69d
0 44 :3 0 57
:3 0 69f 6a0 0
f :2 0 2 :4 0
c0 :2 0 59 :2 0
2f :2 0 38a 6a5
6a7 :3 0 38d 6a1
6a9 69e 6ab 6aa
:2 0 47 :3 0 5a
:3 0 6ad 6ae 0
49 :4 0 c1 :4 0
4c :2 0 4d :3 0
391 6b2 6b4 :3 0
4c :2 0 81 :4 0
394 6b6 6b8 :3 0
4c :2 0 8a :4 0
397 6ba 6bc :3 0
4c :2 0 51 :3 0
55 :3 0 5e :3 0
c2 :3 0 6c1 6c2
0 39a 6c0 6c4
54 :4 0 39c 6bf
6c7 39f 6be 6c9
:3 0 4c :2 0 8c
:4 0 3a2 6cb 6cd
:3 0 4c :2 0 4f
:4 0 3a5 6cf 6d1
:3 0 4c :2 0 14
:3 0 3a8 6d3 6d5
:3 0 4c :2 0 4f
:4 0 3ab 6d7 6d9
:3 0 3ae 6af 6db
:2 0 6dd 3b1 6de
6ac 6dd 0 6df
3b3 0 709 44
:3 0 45 :3 0 6e0
6e1 0 44 :3 0
57 :3 0 6e3 6e4
0 2f :2 0 2
:4 0 c3 :2 0 59
:2 0 2f :2 0 3b5
6e9 6eb :3 0 3b8
6e5 6ed 6e2 6ef
6ee :2 0 47 :3 0
5a :3 0 6f1 6f2
0 49 :4 0 c4
:4 0 4c :2 0 4d
:3 0 3bc 6f6 6f8
:3 0 3bf 6f3 6fa
:2 0 6fc 3c2 6fd
6f0 6fc 0 6fe
3c4 0 709 8f
:3 0 90 :3 0 6ff
700 0 5e :3 0
c2 :3 0 702 703
0 14 :3 0 91
:3 0 3c6 701 707
:2 0 709 3ca 70a
69b 709 0 70b
3ce 0 f67 5
:3 0 98 :2 0 3d0
70d 70e :3 0 70f
:2 0 1d :3 0 98
:2 0 3d2 712 713
:3 0 714 :2 0 44
:3 0 45 :3 0 716
717 0 44 :3 0
57 :3 0 719 71a
0 f :2 0 2
:4 0 c5 :2 0 59
:2 0 2f :2 0 3d4
71f 721 :3 0 3d7
71b 723 718 725
724 :2 0 47 :3 0
5a :3 0 727 728
0 49 :4 0 c6
:4 0 4c :2 0 4d
:3 0 3db 72c 72e
:3 0 4c :2 0 81
:4 0 3de 730 732
:3 0 4c :2 0 8a
:4 0 3e1 734 736
:3 0 4c :2 0 51
:3 0 55 :3 0 5e
:3 0 c7 :3 0 73b
73c 0 3e4 73a
73e 54 :4 0 3e6
739 741 3e9 738
743 :3 0 4c :2 0
8c :4 0 3ec 745
747 :3 0 4c :2 0
4f :4 0 3ef 749
74b :3 0 4c :2 0
3 :3 0 3f2 74d
74f :3 0 4c :2 0
4f :4 0 3f5 751
753 :3 0 3f8 729
755 :2 0 757 3fb
758 726 757 0
759 3fd 0 783
44 :3 0 45 :3 0
75a 75b 0 44
:3 0 57 :3 0 75d
75e 0 2f :2 0
2 :4 0 c8 :2 0
59 :2 0 2f :2 0
3ff 763 765 :3 0
402 75f 767 75c
769 768 :2 0 47
:3 0 5a :3 0 76b
76c 0 49 :4 0
c9 :4 0 4c :2 0
4d :3 0 406 770
772 :3 0 409 76d
774 :2 0 776 40c
777 76a 776 0
778 40e 0 783
8f :3 0 90 :3 0
779 77a 0 5e
:3 0 c7 :3 0 77c
77d 0 3 :3 0
91 :3 0 410 77b
781 :2 0 783 414
784 715 783 0
785 418 0 8e5
36 :3 0 32 :3 0
786 787 0 8e5
99 :3 0 9a :3 0
789 78a 0 17
:3 0 27 :3 0 9b
:2 0 41a 78b 78f
5d :2 0 21 :2 0
420 791 793 :3 0
17 :4 0 795 796
0 799 ca :3 0
423 8e3 99 :3 0
9a :3 0 79a 79b
0 17 :3 0 19
:3 0 9b :2 0 425
79c 7a0 ae :2 0
21 :2 0 42b 7a2
7a4 :3 0 99 :3 0
cb :3 0 cc :3 0
99 :3 0 cd :3 0
ce :3 0 cf :3 0
d0 :3 0 17 :3 0
d1 :3 0 a5 :3 0
e :3 0 cc :3 0
d2 :3 0 84 :3 0
5 :4 0 d3 1
:8 0 7bc c :3 0
7b :3 0 7b7 7b8
0 7c :3 0 7b9
7ba 0 7bc 42e
806 7d :3 0 c
:3 0 7b :3 0 7bf
7c0 0 7c :3 0
7c1 7c2 0 7fc
44 :3 0 45 :3 0
7c4 7c5 0 44
:3 0 57 :3 0 7c7
7c8 0 7e :2 0
2 :4 0 d4 :2 0
59 :2 0 2f :2 0
431 7cd 7cf :3 0
434 7c9 7d1 7c6
7d3 7d2 :2 0 47
:3 0 5a :3 0 7d5
7d6 0 49 :4 0
d5 :4 0 4c :2 0
4d :3 0 438 7da
7dc :3 0 4c :2 0
81 :4 0 43b 7de
7e0 :3 0 4c :2 0
82 :4 0 43e 7e2
7e4 :3 0 4c :2 0
7c :3 0 441 7e6
7e8 :3 0 4c :2 0
83 :4 0 444 7ea
7ec :3 0 4c :2 0
84 :3 0 85 :3 0
2f :2 0 86 :2 0
447 7ef 7f3 44b
7ee 7f5 :3 0 44e
7d7 7f7 :2 0 7f9
451 7fa 7d4 7f9
0 7fb 453 0
7fc 455 7ff :3 0
7ff 0 7ff 7fe
7fc 7fd :6 0 801
c :3 0 458 803
45a 802 801 :2 0
804 45c :2 0 806
0 806 805 7bc
804 :6 0 871 1
:3 0 c :3 0 7b
:3 0 808 809 0
c :3 0 5d :2 0
87 :3 0 80b 80d
0 460 80c 80f
:3 0 810 :2 0 99
:3 0 cb :3 0 d2
:3 0 84 :3 0 5
:3 0 99 :3 0 cd
:3 0 17 :3 0 d6
:4 0 d7 1 :8 0
821 c :3 0 7b
:3 0 81c 81d 0
7c :3 0 81e 81f
0 821 463 86b
7d :3 0 c :3 0
7b :3 0 824 825
0 7c :3 0 826
827 0 861 44
:3 0 45 :3 0 829
82a 0 44 :3 0
57 :3 0 82c 82d
0 7e :2 0 2
:4 0 d8 :2 0 59
:2 0 2f :2 0 466
832 834 :3 0 469
82e 836 82b 838
837 :2 0 47 :3 0
5a :3 0 83a 83b
0 49 :4 0 d9
:4 0 4c :2 0 4d
:3 0 46d 83f 841
:3 0 4c :2 0 81
:4 0 470 843 845
:3 0 4c :2 0 82
:4 0 473 847 849
:3 0 4c :2 0 7c
:3 0 476 84b 84d
:3 0 4c :2 0 83
:4 0 479 84f 851
:3 0 4c :2 0 84
:3 0 85 :3 0 2f
:2 0 86 :2 0 47c
854 858 480 853
85a :3 0 483 83c
85c :2 0 85e 486
85f 839 85e 0
860 488 0 861
48a 864 :3 0 864
0 864 863 861
862 :6 0 866 e
:3 0 48d 868 48f
867 866 :2 0 869
491 :2 0 86b 0
86b 86a 821 869
:6 0 86d 1 :3 0
493 86e 811 86d
0 86f 495 0
871 ca :3 0 497
872 7a5 871 0
8e4 7 :3 0 b2
:2 0 49a 874 875
:3 0 876 :2 0 44
:3 0 45 :3 0 878
879 0 44 :3 0
57 :3 0 87b 87c
0 f :2 0 2
:4 0 da :2 0 59
:2 0 2f :2 0 49c
881 883 :3 0 49f
87d 885 87a 887
886 :2 0 47 :3 0
5a :3 0 889 88a
0 49 :4 0 db
:4 0 4c :2 0 4d
:3 0 4a3 88e 890
:3 0 4c :2 0 81
:4 0 4a6 892 894
:3 0 4c :2 0 8a
:4 0 4a9 896 898
:3 0 4c :2 0 51
:3 0 55 :3 0 21
:2 0 4ac 89c 89e
54 :4 0 4ae 89b
8a1 4b1 89a 8a3
:3 0 4c :2 0 8c
:4 0 4b4 8a5 8a7
:3 0 4c :2 0 4f
:4 0 4b7 8a9 8ab
:3 0 4c :2 0 3
:3 0 4ba 8ad 8af
:3 0 4c :2 0 4f
:4 0 4bd 8b1 8b3
:3 0 4c0 88b 8b5
:2 0 8b7 4c3 8b8
888 8b7 0 8b9
4c5 0 8e1 44
:3 0 45 :3 0 8ba
8bb 0 44 :3 0
57 :3 0 8bd 8be
0 2f :2 0 2
:4 0 dc :2 0 59
:2 0 2f :2 0 4c7
8c3 8c5 :3 0 4ca
8bf 8c7 8bc 8c9
8c8 :2 0 47 :3 0
5a :3 0 8cb 8cc
0 49 :4 0 dd
:4 0 4c :2 0 4d
:3 0 4ce 8d0 8d2
:3 0 4d1 8cd 8d4
:2 0 8d6 4d4 8d7
8ca 8d6 0 8d8
4d6 0 8e1 8f
:3 0 90 :3 0 8d9
8da 0 21 :2 0
3 :3 0 91 :3 0
4d8 8db 8df :2 0
8e1 4dc 8e2 877
8e1 0 8e4 794
799 0 8e4 4e0
0 8e5 4e4 8ed
36 :3 0 21 :2 0
8e6 8e7 0 8ec
17 :4 0 8e9 8ea
0 8ec 4e8 8ee
710 8e5 0 8ef
0 8ec 0 8ef
4eb 0 f67 7
:3 0 98 :2 0 4ee
8f1 8f2 :3 0 8f3
:2 0 5 :3 0 b2
:2 0 4f0 8f6 8f7
:3 0 8f8 :2 0 8f9
:2 0 99 :3 0 9a
:3 0 8fb 8fc 0
18 :3 0 27 :3 0
9b :2 0 4f2 8fd
901 9c :2 0 21
:2 0 4f8 903 905
:3 0 906 :2 0 8fa
908 907 :2 0 44
:3 0 45 :3 0 90a
90b 0 44 :3 0
57 :3 0 90d 90e
0 f :2 0 2
:4 0 de :2 0 59
:2 0 2f :2 0 4fb
913 915 :3 0 4fe
90f 917 90c 919
918 :2 0 47 :3 0
5a :3 0 91b 91c
0 49 :4 0 df
:4 0 4c :2 0 4d
:3 0 502 920 922
:3 0 4c :2 0 81
:4 0 505 924 926
:3 0 4c :2 0 8a
:4 0 508 928 92a
:3 0 4c :2 0 51
:3 0 55 :3 0 5e
:3 0 e0 :3 0 92f
930 0 50b 92e
932 54 :4 0 50d
92d 935 510 92c
937 :3 0 4c :2 0
8c :4 0 513 939
93b :3 0 4c :2 0
4f :4 0 516 93d
93f :3 0 4c :2 0
3 :3 0 519 941
943 :3 0 4c :2 0
4f :4 0 51c 945
947 :3 0 51f 91d
949 :2 0 94b 522
94c 91a 94b 0
94d 524 0 978
44 :3 0 45 :3 0
94e 94f 0 44
:3 0 57 :3 0 951
952 0 2f :2 0
2 :4 0 e1 :2 0
59 :2 0 2f :2 0
526 957 959 :3 0
529 953 95b 950
95d 95c :2 0 47
:3 0 5a :3 0 95f
960 0 49 :4 0
e2 :4 0 4c :2 0
4d :3 0 52d 964
966 :3 0 530 961
968 :2 0 96a 533
96b 95e 96a 0
96c 535 0 978
8f :3 0 90 :3 0
96d 96e 0 5e
:3 0 e0 :3 0 970
971 0 3 :3 0
91 :3 0 537 96f
975 :2 0 978 ca
:3 0 53b 9ec 29
:3 0 98 :2 0 53f
97a 97b :3 0 97c
:2 0 97d :2 0 99
:3 0 9a :3 0 97f
980 0 18 :3 0
29 :3 0 9b :2 0
541 981 985 e3
:2 0 21 :2 0 547
987 989 :3 0 98a
:2 0 97e 98c 98b
:2 0 44 :3 0 45
:3 0 98e 98f 0
44 :3 0 57 :3 0
991 992 0 e4
:2 0 2 :4 0 e5
:2 0 59 :2 0 2f
:2 0 54a 997 999
:3 0 54d 993 99b
990 99d 99c :2 0
47 :3 0 5a :3 0
99f 9a0 0 49
:4 0 e6 :4 0 4c
:2 0 4d :3 0 551
9a4 9a6 :3 0 4c
:2 0 81 :4 0 554
9a8 9aa :3 0 4c
:2 0 8a :4 0 557
9ac 9ae :3 0 4c
:2 0 51 :3 0 55
:3 0 5e :3 0 c7
:3 0 9b3 9b4 0
55a 9b2 9b6 54
:4 0 55c 9b1 9b9
55f 9b0 9bb :3 0
562 9a1 9bd :2 0
9bf 565 9c0 99e
9bf 0 9c1 567
0 9ea 44 :3 0
45 :3 0 9c2 9c3
0 44 :3 0 57
:3 0 9c5 9c6 0
2f :2 0 2 :4 0
e7 :2 0 59 :2 0
2f :2 0 569 9cb
9cd :3 0 56c 9c7
9cf 9c4 9d1 9d0
:2 0 47 :3 0 5a
:3 0 9d3 9d4 0
49 :4 0 e8 :4 0
4c :2 0 4d :3 0
570 9d8 9da :3 0
573 9d5 9dc :2 0
9de 576 9df 9d2
9de 0 9e0 578
0 9ea 8f :3 0
e9 :3 0 9e1 9e2
0 5e :3 0 c7
:3 0 9e4 9e5 0
91 :3 0 57a 9e3
9e8 :2 0 9ea 57d
9eb 98d 9ea 0
9ed 909 978 0
9ed 581 0 b70
5 :3 0 b2 :2 0
584 9ef 9f0 :3 0
9f1 :2 0 9f2 :2 0
99 :3 0 9a :3 0
9f4 9f5 0 18
:3 0 1a :3 0 9b
:2 0 586 9f6 9fa
9c :2 0 21 :2 0
58c 9fc 9fe :3 0
9ff :2 0 9f3 a01
a00 :2 0 3b :3 0
2f :2 0 a03 a04
0 a06 58f a0b
3b :3 0 21 :2 0
a07 a08 0 a0a
591 a0c a02 a06
0 a0d 0 a0a
0 a0d 593 0
b70 99 :3 0 9a
:3 0 a0e a0f 0
18 :3 0 28 :3 0
9b :2 0 596 a10
a14 5d :2 0 21
:2 0 59c a16 a18
:3 0 18 :4 0 a1a
a1b 0 a1e ca
:3 0 59f b6e 99
:3 0 ad :3 0 a1f
a20 0 18 :3 0
1a :3 0 5a1 a21
a24 ae :2 0 21
:2 0 5a6 a26 a28
:3 0 99 :3 0 cb
:3 0 cc :3 0 99
:3 0 cd :3 0 ce
:3 0 ea :3 0 d0
:3 0 18 :3 0 d1
:3 0 a5 :3 0 e
:3 0 cc :3 0 d2
:3 0 84 :3 0 7
:4 0 eb 1 :8 0
a40 c :3 0 7b
:3 0 a3b a3c 0
7c :3 0 a3d a3e
0 a40 5a9 a8a
7d :3 0 c :3 0
7b :3 0 a43 a44
0 7c :3 0 a45
a46 0 a80 44
:3 0 45 :3 0 a48
a49 0 44 :3 0
57 :3 0 a4b a4c
0 7e :2 0 2
:4 0 ec :2 0 59
:2 0 2f :2 0 5ac
a51 a53 :3 0 5af
a4d a55 a4a a57
a56 :2 0 47 :3 0
5a :3 0 a59 a5a
0 49 :4 0 ed
:4 0 4c :2 0 4d
:3 0 5b3 a5e a60
:3 0 4c :2 0 81
:4 0 5b6 a62 a64
:3 0 4c :2 0 82
:4 0 5b9 a66 a68
:3 0 4c :2 0 7c
:3 0 5bc a6a a6c
:3 0 4c :2 0 83
:4 0 5bf a6e a70
:3 0 4c :2 0 84
:3 0 85 :3 0 2f
:2 0 86 :2 0 5c2
a73 a77 5c6 a72
a79 :3 0 5c9 a5b
a7b :2 0 a7d 5cc
a7e a58 a7d 0
a7f 5ce 0 a80
5d0 a83 :3 0 a83
0 a83 a82 a80
a81 :6 0 a85 10
:3 0 5d3 a87 5d5
a86 a85 :2 0 a88
5d7 :2 0 a8a 0
a8a a89 a40 a88
:6 0 af5 1 :3 0
c :3 0 7b :3 0
a8c a8d 0 c
:3 0 5d :2 0 87
:3 0 a8f a91 0
5db a90 a93 :3 0
a94 :2 0 99 :3 0
cb :3 0 d2 :3 0
84 :3 0 7 :3 0
99 :3 0 cd :3 0
18 :3 0 d6 :4 0
ee 1 :8 0 aa5
c :3 0 7b :3 0
aa0 aa1 0 7c
:3 0 aa2 aa3 0
aa5 5de aef 7d
:3 0 c :3 0 7b
:3 0 aa8 aa9 0
7c :3 0 aaa aab
0 ae5 44 :3 0
45 :3 0 aad aae
0 44 :3 0 57
:3 0 ab0 ab1 0
7e :2 0 2 :4 0
ef :2 0 59 :2 0
2f :2 0 5e1 ab6
ab8 :3 0 5e4 ab2
aba aaf abc abb
:2 0 47 :3 0 5a
:3 0 abe abf 0
49 :4 0 f0 :4 0
4c :2 0 4d :3 0
5e8 ac3 ac5 :3 0
4c :2 0 81 :4 0
5eb ac7 ac9 :3 0
4c :2 0 82 :4 0
5ee acb acd :3 0
4c :2 0 7c :3 0
5f1 acf ad1 :3 0
4c :2 0 83 :4 0
5f4 ad3 ad5 :3 0
4c :2 0 84 :3 0
85 :3 0 2f :2 0
86 :2 0 5f7 ad8
adc 5fb ad7 ade
:3 0 5fe ac0 ae0
:2 0 ae2 601 ae3
abd ae2 0 ae4
603 0 ae5 605
ae8 :3 0 ae8 0
ae8 ae7 ae5 ae6
:6 0 aea 12 :3 0
608 aec 60a aeb
aea :2 0 aed 60c
:2 0 aef 0 aef
aee aa5 aed :6 0
af1 1 :3 0 60e
af2 a95 af1 0
af3 610 0 af5
ca :3 0 612 af6
a29 af5 0 b6f
99 :3 0 9a :3 0
af7 af8 0 18
:3 0 27 :3 0 9b
:2 0 615 af9 afd
5d :2 0 21 :2 0
61b aff b01 :3 0
44 :3 0 45 :3 0
b03 b04 0 44
:3 0 57 :3 0 b06
b07 0 f :2 0
2 :4 0 f1 :2 0
59 :2 0 2f :2 0
61e b0c b0e :3 0
621 b08 b10 b05
b12 b11 :2 0 47
:3 0 5a :3 0 b14
b15 0 49 :4 0
f2 :4 0 4c :2 0
4d :3 0 625 b19
b1b :3 0 4c :2 0
81 :4 0 628 b1d
b1f :3 0 4c :2 0
8a :4 0 62b b21
b23 :3 0 4c :2 0
51 :3 0 55 :3 0
21 :2 0 62e b27
b29 54 :4 0 630
b26 b2c 633 b25
b2e :3 0 4c :2 0
8c :4 0 636 b30
b32 :3 0 4c :2 0
4f :4 0 639 b34
b36 :3 0 4c :2 0
3 :3 0 63c b38
b3a :3 0 4c :2 0
4f :4 0 63f b3c
b3e :3 0 642 b16
b40 :2 0 b42 645
b43 b13 b42 0
b44 647 0 b6c
44 :3 0 45 :3 0
b45 b46 0 44
:3 0 57 :3 0 b48
b49 0 2f :2 0
2 :4 0 f3 :2 0
59 :2 0 2f :2 0
649 b4e b50 :3 0
64c b4a b52 b47
b54 b53 :2 0 47
:3 0 5a :3 0 b56
b57 0 49 :4 0
f4 :4 0 4c :2 0
4d :3 0 650 b5b
b5d :3 0 653 b58
b5f :2 0 b61 656
b62 b55 b61 0
b63 658 0 b6c
8f :3 0 90 :3 0
b64 b65 0 21
:2 0 3 :3 0 91
:3 0 65a b66 b6a
:2 0 b6c 65e b6d
b02 b6c 0 b6f
a19 a1e 0 b6f
662 0 b70 666
b75 18 :4 0 b71
b72 0 b74 66a
b76 8f4 b70 0
b77 0 b74 0
b77 66c 0 f67
15 :3 0 a :3 0
b78 b79 0 f67
3c :3 0 21 :2 0
b7b b7c 0 f67
51 :3 0 39 :3 0
21 :2 0 66f b7e
b81 5e :3 0 ae
:2 0 5f :3 0 b83
b85 0 674 b84
b87 :3 0 78 :3 0
66 :3 0 17 :3 0
68 :3 0 18 :3 0
b3 :3 0 79 :3 0
3 :4 0 f5 1
:8 0 ba7 b5 :4 0
b92 :3 0 91 :3 0
5d :2 0 679 b95
b96 :3 0 c :3 0
7b :3 0 b98 b99
0 21 :2 0 b9a
b9b 0 b9d 67c
ba4 c :3 0 7b
:3 0 b9e b9f 0
b6 :2 0 ba0 ba1
0 ba3 67e ba5
b97 b9d 0 ba6
0 ba3 0 ba6
680 0 ba7 683
bf1 7d :3 0 c
:3 0 7b :3 0 baa
bab 0 7c :3 0
bac bad 0 be7
44 :3 0 45 :3 0
baf bb0 0 44
:3 0 57 :3 0 bb2
bb3 0 7e :2 0
2 :4 0 f6 :2 0
59 :2 0 2f :2 0
686 bb8 bba :3 0
689 bb4 bbc bb1
bbe bbd :2 0 47
:3 0 5a :3 0 bc0
bc1 0 49 :4 0
f7 :4 0 4c :2 0
4d :3 0 68d bc5
bc7 :3 0 4c :2 0
81 :4 0 690 bc9
bcb :3 0 4c :2 0
82 :4 0 693 bcd
bcf :3 0 4c :2 0
7c :3 0 696 bd1
bd3 :3 0 4c :2 0
83 :4 0 699 bd5
bd7 :3 0 4c :2 0
84 :3 0 85 :3 0
2f :2 0 86 :2 0
69c bda bde 6a0
bd9 be0 :3 0 6a3
bc2 be2 :2 0 be4
6a6 be5 bbf be4
0 be6 6a8 0
be7 6aa bea :3 0
bea 0 bea be9
be7 be8 :6 0 bec
14 :3 0 6ad bee
6af bed bec :2 0
bef 6b1 :2 0 bf1
0 bf1 bf0 ba7
bef :6 0 bf3 1
:3 0 6b3 f64 11
:3 0 98 :2 0 6b5
bf5 bf6 :3 0 bf7
:2 0 7 :3 0 98
:2 0 6b7 bfa bfb
:3 0 bfc :2 0 f8
:3 0 3c :3 0 d6
:3 0 cc :3 0 f9
:3 0 60 :3 0 e
:3 0 79 :3 0 11
:3 0 79 :3 0 12
:3 0 cc :3 0 d2
:3 0 84 :3 0 7
:4 0 fa 1 :8 0
c13 c :3 0 7b
:3 0 c0e c0f 0
7c :3 0 c10 c11
0 c13 6b9 c5d
7d :3 0 c :3 0
7b :3 0 c16 c17
0 7c :3 0 c18
c19 0 c53 44
:3 0 45 :3 0 c1b
c1c 0 44 :3 0
57 :3 0 c1e c1f
0 7e :2 0 2
:4 0 fb :2 0 59
:2 0 2f :2 0 6bc
c24 c26 :3 0 6bf
c20 c28 c1d c2a
c29 :2 0 47 :3 0
5a :3 0 c2c c2d
0 49 :4 0 fc
:4 0 4c :2 0 4d
:3 0 6c3 c31 c33
:3 0 4c :2 0 81
:4 0 6c6 c35 c37
:3 0 4c :2 0 82
:4 0 6c9 c39 c3b
:3 0 4c :2 0 7c
:3 0 6cc c3d c3f
:3 0 4c :2 0 83
:4 0 6cf c41 c43
:3 0 4c :2 0 84
:3 0 85 :3 0 2f
:2 0 86 :2 0 6d2
c46 c4a 6d6 c45
c4c :3 0 6d9 c2e
c4e :2 0 c50 6dc
c51 c2b c50 0
c52 6de 0 c53
6e0 c56 :3 0 c56
0 c56 c55 c53
c54 :6 0 c58 16
:3 0 6e3 c5a 6e5
c59 c58 :2 0 c5b
6e7 :2 0 c5d 0
c5d c5c c13 c5b
:6 0 cd9 1 :3 0
51 :3 0 3c :3 0
21 :2 0 6e9 c5f
c62 5d :2 0 21
:2 0 6ee c64 c66
:3 0 44 :3 0 45
:3 0 c68 c69 0
44 :3 0 57 :3 0
c6b c6c 0 f
:2 0 2 :4 0 fd
:2 0 59 :2 0 2f
:2 0 6f1 c71 c73
:3 0 6f4 c6d c75
c6a c77 c76 :2 0
47 :3 0 5a :3 0
c79 c7a 0 49
:4 0 fe :4 0 4c
:2 0 4d :3 0 6f8
c7e c80 :3 0 4c
:2 0 81 :4 0 6fb
c82 c84 :3 0 4c
:2 0 8a :4 0 6fe
c86 c88 :3 0 4c
:2 0 51 :3 0 55
:3 0 5e :3 0 ff
:3 0 c8d c8e 0
701 c8c c90 54
:4 0 703 c8b c93
706 c8a c95 :3 0
4c :2 0 8c :4 0
709 c97 c99 :3 0
4c :2 0 4f :4 0
70c c9b c9d :3 0
4c :2 0 12 :3 0
70f c9f ca1 :3 0
4c :2 0 4f :4 0
712 ca3 ca5 :3 0
715 c7b ca7 :2 0
ca9 718 caa c78
ca9 0 cab 71a
0 cd5 44 :3 0
45 :3 0 cac cad
0 44 :3 0 57
:3 0 caf cb0 0
2f :2 0 2 :4 0
100 :2 0 59 :2 0
2f :2 0 71c cb5
cb7 :3 0 71f cb1
cb9 cae cbb cba
:2 0 47 :3 0 5a
:3 0 cbd cbe 0
49 :4 0 101 :4 0
4c :2 0 4d :3 0
723 cc2 cc4 :3 0
726 cbf cc6 :2 0
cc8 729 cc9 cbc
cc8 0 cca 72b
0 cd5 8f :3 0
90 :3 0 ccb ccc
0 5e :3 0 ff
:3 0 cce ccf 0
12 :3 0 91 :3 0
72d ccd cd3 :2 0
cd5 731 cd6 c67
cd5 0 cd7 735
0 cd9 ca :3 0
737 f06 5 :3 0
98 :2 0 73a cdb
cdc :3 0 cdd :2 0
f8 :3 0 3c :3 0
d6 :3 0 cc :3 0
f9 :3 0 60 :3 0
e :3 0 79 :3 0
11 :3 0 79 :3 0
12 :3 0 cc :3 0
d2 :3 0 84 :3 0
5 :4 0 102 1
:8 0 cf4 c :3 0
7b :3 0 cef cf0
0 7c :3 0 cf1
cf2 0 cf4 73c
d3e 7d :3 0 c
:3 0 7b :3 0 cf7
cf8 0 7c :3 0
cf9 cfa 0 d34
44 :3 0 45 :3 0
cfc cfd 0 44
:3 0 57 :3 0 cff
d00 0 7e :2 0
2 :4 0 103 :2 0
59 :2 0 2f :2 0
73f d05 d07 :3 0
742 d01 d09 cfe
d0b d0a :2 0 47
:3 0 5a :3 0 d0d
d0e 0 49 :4 0
104 :4 0 4c :2 0
4d :3 0 746 d12
d14 :3 0 4c :2 0
81 :4 0 749 d16
d18 :3 0 4c :2 0
82 :4 0 74c d1a
d1c :3 0 4c :2 0
7c :3 0 74f d1e
d20 :3 0 4c :2 0
83 :4 0 752 d22
d24 :3 0 4c :2 0
84 :3 0 85 :3 0
2f :2 0 86 :2 0
755 d27 d2b 759
d26 d2d :3 0 75c
d0f d2f :2 0 d31
75f d32 d0c d31
0 d33 761 0
d34 763 d37 :3 0
d37 0 d37 d36
d34 d35 :6 0 d39
18 :3 0 766 d3b
768 d3a d39 :2 0
d3c 76a :2 0 d3e
0 d3e d3d cf4
d3c :6 0 e96 1
:3 0 51 :3 0 3c
:3 0 21 :2 0 76c
d40 d43 5d :2 0
21 :2 0 771 d45
d47 :3 0 44 :3 0
45 :3 0 d49 d4a
0 44 :3 0 57
:3 0 d4c d4d 0
f :2 0 2 :4 0
105 :2 0 59 :2 0
2f :2 0 774 d52
d54 :3 0 777 d4e
d56 d4b d58 d57
:2 0 47 :3 0 5a
:3 0 d5a d5b 0
49 :4 0 106 :4 0
4c :2 0 4d :3 0
77b d5f d61 :3 0
4c :2 0 81 :4 0
77e d63 d65 :3 0
4c :2 0 8a :4 0
781 d67 d69 :3 0
4c :2 0 51 :3 0
55 :3 0 5e :3 0
ff :3 0 d6e d6f
0 784 d6d d71
54 :4 0 786 d6c
d74 789 d6b d76
:3 0 4c :2 0 8c
:4 0 78c d78 d7a
:3 0 4c :2 0 4f
:4 0 78f d7c d7e
:3 0 4c :2 0 12
:3 0 792 d80 d82
:3 0 4c :2 0 4f
:4 0 795 d84 d86
:3 0 798 d5c d88
:2 0 d8a 79b d8b
d59 d8a 0 d8c
79d 0 db6 44
:3 0 45 :3 0 d8d
d8e 0 44 :3 0
57 :3 0 d90 d91
0 2f :2 0 2
:4 0 107 :2 0 59
:2 0 2f :2 0 79f
d96 d98 :3 0 7a2
d92 d9a d8f d9c
d9b :2 0 47 :3 0
5a :3 0 d9e d9f
0 49 :4 0 108
:4 0 4c :2 0 4d
:3 0 7a6 da3 da5
:3 0 7a9 da0 da7
:2 0 da9 7ac daa
d9d da9 0 dab
7ae 0 db6 8f
:3 0 90 :3 0 dac
dad 0 5e :3 0
ff :3 0 daf db0
0 12 :3 0 91
:3 0 7b0 dae db4
:2 0 db6 7b4 e93
109 :3 0 10a :3 0
33 :3 0 f9 :3 0
60 :3 0 e :3 0
10b :3 0 11 :3 0
cc :3 0 d2 :3 0
84 :3 0 5 :4 0
10c 1 :8 0 dc9
c :3 0 7b :3 0
dc4 dc5 0 7c
:3 0 dc6 dc7 0
dc9 7b8 e13 7d
:3 0 c :3 0 7b
:3 0 dcc dcd 0
7c :3 0 dce dcf
0 e09 44 :3 0
45 :3 0 dd1 dd2
0 44 :3 0 57
:3 0 dd4 dd5 0
7e :2 0 2 :4 0
10d :2 0 59 :2 0
2f :2 0 7bb dda
ddc :3 0 7be dd6
dde dd3 de0 ddf
:2 0 47 :3 0 5a
:3 0 de2 de3 0
49 :4 0 10e :4 0
4c :2 0 4d :3 0
7c2 de7 de9 :3 0
4c :2 0 81 :4 0
7c5 deb ded :3 0
4c :2 0 82 :4 0
7c8 def df1 :3 0
4c :2 0 7c :3 0
7cb df3 df5 :3 0
4c :2 0 83 :4 0
7ce df7 df9 :3 0
4c :2 0 84 :3 0
85 :3 0 2f :2 0
86 :2 0 7d1 dfc
e00 7d5 dfb e02
:3 0 7d8 de4 e04
:2 0 e06 7db e07
de1 e06 0 e08
7dd 0 e09 7df
e0c :3 0 e0c 0
e0c e0b e09 e0a
:6 0 e0e 1a :3 0
7e2 e10 7e4 e0f
e0e :2 0 e11 7e6
:2 0 e13 0 e13
e12 dc9 e11 :6 0
e92 1 :3 0 51
:3 0 33 :3 0 21
:2 0 7e8 e15 e18
51 :3 0 9c :2 0
32 :3 0 21 :2 0
7eb e1a e1e 7f0
e1b e20 :3 0 44
:3 0 45 :3 0 e22
e23 0 44 :3 0
57 :3 0 e25 e26
0 f :2 0 2
:4 0 10f :2 0 59
:2 0 2f :2 0 7f3
e2b e2d :3 0 7f6
e27 e2f e24 e31
e30 :2 0 47 :3 0
5a :3 0 e33 e34
0 49 :4 0 110
:4 0 4c :2 0 4d
:3 0 7fa e38 e3a
:3 0 4c :2 0 81
:4 0 7fd e3c e3e
:3 0 4c :2 0 8a
:4 0 800 e40 e42
:3 0 4c :2 0 51
:3 0 55 :3 0 5e
:3 0 ff :3 0 e47
e48 0 803 e46
e4a 54 :4 0 805
e45 e4d 808 e44
e4f :3 0 4c :2 0
8c :4 0 80b e51
e53 :3 0 4c :2 0
4f :4 0 80e e55
e57 :3 0 4c :2 0
12 :3 0 811 e59
e5b :3 0 4c :2 0
4f :4 0 814 e5d
e5f :3 0 817 e35
e61 :2 0 e63 81a
e64 e32 e63 0
e65 81c 0 e8f
44 :3 0 45 :3 0
e66 e67 0 44
:3 0 57 :3 0 e69
e6a 0 2f :2 0
2 :4 0 111 :2 0
59 :2 0 2f :2 0
81e e6f e71 :3 0
821 e6b e73 e68
e75 e74 :2 0 47
:3 0 5a :3 0 e77
e78 0 49 :4 0
112 :4 0 4c :2 0
4d :3 0 825 e7c
e7e :3 0 828 e79
e80 :2 0 e82 82b
e83 e76 e82 0
e84 82d 0 e8f
8f :3 0 90 :3 0
e85 e86 0 5e
:3 0 ff :3 0 e88
e89 0 12 :3 0
91 :3 0 82f e87
e8d :2 0 e8f 833
e90 e21 e8f 0
e91 837 0 e92
839 e94 d48 db6
0 e95 0 e92
0 e95 83c 0
e96 83f e97 cde
e96 0 f08 44
:3 0 45 :3 0 e98
e99 0 44 :3 0
57 :3 0 e9b e9c
0 f :2 0 2
:4 0 113 :2 0 59
:2 0 2f :2 0 842
ea1 ea3 :3 0 845
e9d ea5 e9a ea7
ea6 :2 0 47 :3 0
5a :3 0 ea9 eaa
0 49 :4 0 114
:4 0 4c :2 0 4d
:3 0 849 eae eb0
:3 0 4c :2 0 81
:4 0 84c eb2 eb4
:3 0 4c :2 0 8a
:4 0 84f eb6 eb8
:3 0 4c :2 0 51
:3 0 55 :3 0 5e
:3 0 115 :3 0 ebd
ebe 0 852 ebc
ec0 54 :4 0 854
ebb ec3 857 eba
ec5 :3 0 4c :2 0
8c :4 0 85a ec7
ec9 :3 0 4c :2 0
4f :4 0 85d ecb
ecd :3 0 4c :2 0
12 :3 0 860 ecf
ed1 :3 0 4c :2 0
4f :4 0 863 ed3
ed5 :3 0 866 eab
ed7 :2 0 ed9 869
eda ea8 ed9 0
edb 86b 0 f05
44 :3 0 45 :3 0
edc edd 0 44
:3 0 57 :3 0 edf
ee0 0 2f :2 0
2 :4 0 116 :2 0
59 :2 0 2f :2 0
86d ee5 ee7 :3 0
870 ee1 ee9 ede
eeb eea :2 0 47
:3 0 5a :3 0 eed
eee 0 49 :4 0
117 :4 0 4c :2 0
4d :3 0 874 ef2
ef4 :3 0 877 eef
ef6 :2 0 ef8 87a
ef9 eec ef8 0
efa 87c 0 f05
8f :3 0 90 :3 0
efb efc 0 5e
:3 0 115 :3 0 efe
eff 0 12 :3 0
91 :3 0 87e efd
f03 :2 0 f05 882
f07 bfd cd9 0
f08 0 f05 0
f08 886 0 f09
88a f0a bf8 f09
0 f0b 88c 0
f63 38 :3 0 118
:2 0 f0c f0d 0
f63 12 :3 0 3
:3 0 f0f f10 0
f63 17 :3 0 b2
:2 0 88e f13 f14
:3 0 f15 :2 0 29
:3 0 98 :2 0 890
f18 f19 :3 0 f1a
:2 0 f1b :2 0 f16
f1d f1c :2 0 17
:3 0 19 :3 0 f1f
f20 0 f22 892
f23 f1e f22 0
f24 894 0 f63
3d :3 0 119 :3 0
e :3 0 10 :3 0
12 :3 0 11 :3 0
17 :3 0 18 :3 0
29 :3 0 2e :3 0
36 :3 0 3a :3 0
34 :3 0 32 :3 0
37 :3 0 3b :3 0
38 :3 0 27 :3 0
28 :3 0 23 :3 0
26 :3 0 30 :3 0
31 :3 0 15 :3 0
21 :2 0 896 f26
f3e f25 f3f 0
f63 3c :3 0 118
:2 0 f41 f42 0
f63 3d :3 0 11a
:3 0 e :3 0 12
:3 0 3c :3 0 21
:2 0 21 :2 0 8ae
f45 f4b f44 f4c
0 f63 11 :3 0
98 :2 0 8b4 f4f
f50 :3 0 f51 :2 0
3c :3 0 11b :2 0
f53 f54 0 f60
3d :3 0 11a :3 0
e :3 0 11 :3 0
3c :3 0 21 :2 0
21 :2 0 8b6 f57
f5d f56 f5e 0
f60 8bc f61 f52
f60 0 f62 8bf
0 f63 8c1 f65
b88 bf3 0 f66
0 f63 0 f66
8ca 0 f67 8cd
f68 664 f67 0
f69 8d5 0 f6a
8d7 f6c 4de 549
0 f6d 0 f6a
0 f6d 8db 0
1013 99 :3 0 ad
:3 0 f6e f6f 0
14 :3 0 15 :3 0
8de f70 f73 5d
:2 0 21 :2 0 8e3
f75 f77 :3 0 f78
:2 0 51 :3 0 39
:3 0 21 :2 0 8e6
f7a f7d 5e :3 0
ae :2 0 5f :3 0
f7f f81 0 8eb
f80 f83 :3 0 f84
:2 0 f79 f86 f85
:2 0 3f :3 0 af
:4 0 f88 f89 0
fbc 3e :3 0 118
:2 0 f8b f8c 0
fbc 42 :3 0 c
:3 0 7b :3 0 f8f
f90 0 f8e f91
0 fbc 40 :3 0
b0 :3 0 3f :3 0
12 :3 0 15 :3 0
3e :3 0 21 :2 0
8ee f94 f9a f93
f9b 0 fbc c
:3 0 7b :3 0 f9d
f9e 0 42 :3 0
f9f fa0 0 fbc
3f :3 0 b1 :4 0
fa2 fa3 0 fbc
3e :3 0 118 :2 0
fa5 fa6 0 fbc
42 :3 0 c :3 0
7b :3 0 fa9 faa
0 fa8 fab 0
fbc 40 :3 0 b0
:3 0 3f :3 0 12
:3 0 15 :3 0 3e
:3 0 21 :2 0 8f4
fae fb4 fad fb5
0 fbc c :3 0
7b :3 0 fb7 fb8
0 42 :3 0 fb9
fba 0 fbc 8fa
fbd f87 fbc 0
fbe 905 0 1013
3d :3 0 11c :3 0
e :3 0 907 fc0
fc2 fbf fc3 0
1013 44 :3 0 45
:3 0 fc5 fc6 0
44 :3 0 57 :3 0
fc8 fc9 0 11d
:2 0 2 :4 0 11e
:2 0 59 :2 0 2f
:2 0 909 fce fd0
:3 0 90c fca fd2
fc7 fd4 fd3 :2 0
47 :3 0 5a :3 0
fd6 fd7 0 49
:4 0 11f :4 0 4c
:2 0 4d :3 0 910
fdb fdd :3 0 4c
:2 0 81 :4 0 913
fdf fe1 :3 0 4c
:2 0 8a :4 0 916
fe3 fe5 :3 0 4c
:2 0 51 :3 0 55
:3 0 c :3 0 7b
:3 0 fea feb 0
919 fe9 fed 54
:4 0 91b fe8 ff0
91e fe7 ff2 :3 0
4c :2 0 8c :4 0
921 ff4 ff6 :3 0
4c :2 0 4f :4 0
924 ff8 ffa :3 0
4c :2 0 3 :3 0
927 ffc ffe :3 0
4c :2 0 4f :4 0
92a 1000 1002 :3 0
92d fd8 1004 :2 0
1006 930 1007 fd5
1006 0 1008 932
0 1013 8f :3 0
120 :3 0 1009 100a
0 c :3 0 7b
:3 0 100c 100d 0
3 :3 0 91 :3 0
934 100b 1011 :2 0
1013 938 10b4 c
:3 0 121 :2 0 4
1014 1015 0 44
:3 0 45 :3 0 1017
1018 0 44 :3 0
57 :3 0 101a 101b
0 7e :2 0 2
:4 0 122 :2 0 59
:2 0 2f :2 0 951
1020 1022 :3 0 954
101c 1024 1019 1026
1025 :2 0 47 :3 0
5a :3 0 1028 1029
0 49 :4 0 123
:4 0 4c :2 0 4d
:3 0 958 102d 102f
:3 0 95b 102a 1031
:2 0 104a 47 :3 0
5a :3 0 1033 1034
0 49 :4 0 124
:4 0 4c :2 0 c
:3 0 a6 :3 0 1039
103a 0 95e 1038
103c :3 0 4c :2 0
8c :4 0 961 103e
1040 :3 0 4c :2 0
c :3 0 125 :3 0
1043 1044 0 964
1042 1046 :3 0 967
1035 1048 :2 0 104a
96a 104b 1027 104a
0 104c 96d 0
105c 126 :3 0 43
:3 0 c :3 0 a6
:3 0 127 :3 0 c
:3 0 125 :3 0 128
:3 0 d6 :4 0 129
1 :a 0 1058 :2 0
105c 104e 1056 :2 0
b :3 0 43 :3 0
105a :2 0 105c 96f
105e 973 105d 105c
:2 0 10b2 7d :3 0
c :3 0 7b :3 0
1061 1062 0 7c
:3 0 1063 1064 0
10aa 44 :3 0 45
:3 0 1066 1067 0
44 :3 0 57 :3 0
1069 106a 0 7e
:2 0 2 :4 0 12a
:2 0 59 :2 0 2f
:2 0 975 106f 1071
:3 0 978 106b 1073
1068 1075 1074 :2 0
47 :3 0 5a :3 0
1077 1078 0 49
:4 0 12b :4 0 4c
:2 0 4d :3 0 97c
107c 107e :3 0 97f
1079 1080 :2 0 109a
47 :3 0 5a :3 0
1082 1083 0 49
:4 0 82 :4 0 4c
:2 0 7c :3 0 982
1087 1089 :3 0 4c
:2 0 83 :4 0 985
108b 108d :3 0 4c
:2 0 84 :3 0 85
:3 0 2f :2 0 86
:2 0 988 1090 1094
98c 108f 1096 :3 0
98f 1084 1098 :2 0
109a 992 109b 1076
109a 0 109c 995
0 10aa 126 :3 0
43 :3 0 127 :3 0
c :3 0 125 :3 0
128 :3 0 d6 :4 0
12c 1 :a 0 10a6
:2 0 10aa 109e 10a4
:2 0 b :3 0 43
:3 0 10a8 :2 0 10aa
997 10ad :3 0 10ad
0 10ad 10ac 10aa
10ab :6 0 10af 1
:3 0 99c 10b1 99e
10b0 10af :2 0 10b2
9a0 :2 0 10b4 9a3
10b4 10b3 1013 10b2
:6 0 10b5 :2 0 2
1c 10b4 10b8 :3 0
10b7 10b5 10b9 :8 0

9d2
4
:3 0 1 3 1
7 1 b 1
f 1 13 5
6 a e 12
16 1 20 1
1e 1 27 1
25 1 2e 1
2c 1 35 1
33 1 3c 1
3a 1 43 1
41 1 4a 1
48 1 51 1
4f 1 56 1
5b 1 60 1
65 1 6a 1
6f 1 74 1
7b 1 79 1
80 1 86 1
8c 1 92 1
98 1 9d 1
a2 1 a7 1
ac 1 b1 1
b8 1 b6 1
bd 1 c3 1
c9 1 cf 1
d5 1 db 1
e1 1 e7 1
ed 1 f3 1
f9 1 ff 1
105 1 10b 1
111 1 119 1
117 1 11e 1
123 1 129 1
136 1 142 2
145 147 2 14a
14c 2 14e 150
2 152 154 2
156 158 2 15e
160 2 162 164
2 166 167 2
169 16a 2 15a
16c 2 16e 170
2 176 178 2
17a 17c 2 17e
17f 2 181 182
2 172 184 2
186 188 1 18e
2 190 191 2
18a 193 2 195
197 2 199 19b
2 19d 19f 2
1a1 1a3 2 1a5
1a7 4 13e 144
149 1a9 1 1ab
1 1ad 2 1b7
1b9 3 1b5 1b6
1bb 2 1c4 1c6
2 1c3 1c8 1
1ca 1 1cc 2
1e4 1e5 1 1e9
2 1e7 1e9 1
1f1 1 1f3 2
22c 231 2 242
244 3 240 241
246 2 24f 251
2 253 255 2
257 259 2 25b
25d 2 25f 261
3 266 267 268
2 263 26a 2
24e 26c 1 26e
1 270 2 239
271 1 275 1
234 1 279 1
284 2 280 284
2 290 292 3
28e 28f 294 2
29d 29f 2 2a1
2a3 2 2a5 2a7
1 2af 2 2b1
2b2 2 2a9 2b4
2 2b6 2b8 2
2ba 2bc 2 2be
2c0 2 2c2 2c4
2 29c 2c6 1
2c8 1 2ca 2
2d4 2d6 3 2d2
2d3 2d8 2 2e1
2e3 2 2e0 2e5
1 2e7 1 2e9
3 2f0 2f1 2f2
3 2cb 2ea 2f4
1 2f6 2 2f9
2fa 1 2fe 2
2fc 2fe 2 309
30b 3 307 308
30d 2 316 318
2 31a 31c 2
31e 320 1 328
2 32a 32b 2
322 32d 2 32f
331 2 333 335
2 337 339 2
33b 33d 2 315
33f 1 341 1
343 2 34d 34f
3 34b 34c 351
2 35a 35c 2
359 35e 1 360
1 362 3 369
36a 36b 3 344
363 36d 1 36f
1 371 1 377
3 382 383 384
1 388 2 386
388 2 393 395
3 391 392 397
2 3a0 3a2 2
3a4 3a6 2 3a8
3aa 1 3b2 2
3b4 3b5 2 3ac
3b7 2 3b9 3bb
2 3bd 3bf 2
3c1 3c3 2 3c5
3c7 2 39f 3c9
1 3cb 1 3cd
2 3d7 3d9 3
3d5 3d6 3db 2
3e4 3e6 2 3e3
3e8 1 3ea 1
3ec 3 3f3 3f4
3f5 3 3ce 3ed
3f7 1 3f9 1
3fa 1 3fc 2
410 415 2 426
428 3 424 425
42a 2 433 435
2 437 439 2
43b 43d 2 43f
441 2 443 445
3 44a 44b 44c
2 447 44e 2
432 450 1 452
1 454 2 41d
455 1 459 1
418 1 45d 2
468 469 1 46d
2 46b 46d 2
472 473 1 479
2 475 479 5
48c 48d 48e 48f
490 5 4a6 4a7
4a8 4a9 4aa a
481 484 489 493
498 49b 49e 4a3
4ad 4b2 1 4b4
1 4b6 3 4bf
4c0 4c1 1 4c5
2 4c3 4c5 1
4cd 1 4cf 1
4d1 1 4d7 1
4ea 2 4e9 4ea
1 4f2 1 4f8
2 4fa 4fb 2
4e7 4fc 2 50d
50f 3 50b 50c
511 2 51a 51c
2 51e 520 2
522 524 2 526
528 2 52a 52c
3 531 532 533
2 52e 535 2
519 537 1 539
1 53b 2 504
53c 1 540 1
4ff 1 544 1
547 1 54a 1
54f 1 55f 2
55e 55f 1 567
1 56d 2 56f
570 2 55c 571
2 582 584 3
580 581 586 2
58f 591 2 593
595 2 597 599
2 59b 59d 2
59f 5a1 3 5a6
5a7 5a8 2 5a3
5aa 2 58e 5ac
1 5ae 1 5b0
2 579 5b1 1
5b5 1 574 1
5b9 3 5c1 5c2
5c3 1 5c7 2
5c5 5c7 1 5cc
1 5ce 2 5bc
5cf 1 5d1 1
5d3 1 5d8 1
5e8 2 5e7 5e8
1 5f0 1 5f6
2 5f8 5f9 2
5e5 5fa 2 60b
60d 3 609 60a
60f 2 618 61a
2 61c 61e 2
620 622 2 624
626 2 628 62a
3 62f 630 631
2 62c 633 2
617 635 1 637
1 639 2 602
63a 1 63e 1
5fd 1 642 3
64a 64b 64c 1
650 2 64e 650
1 655 1 657
2 645 658 1
65a 2 65d 65e
1 662 2 660
662 1 665 3
66e 66f 670 1
674 2 672 674
1 67c 1 67e
1 680 1 686
2 691 692 1
696 2 694 696
2 6a4 6a6 3
6a2 6a3 6a8 2
6b1 6b3 2 6b5
6b7 2 6b9 6bb
1 6c3 2 6c5
6c6 2 6bd 6c8
2 6ca 6cc 2
6ce 6d0 2 6d2
6d4 2 6d6 6d8
2 6b0 6da 1
6dc 1 6de 2
6e8 6ea 3 6e6
6e7 6ec 2 6f5
6f7 2 6f4 6f9
1 6fb 1 6fd
3 704 705 706
3 6df 6fe 708
1 70a 1 70c
1 711 2 71e
720 3 71c 71d
722 2 72b 72d
2 72f 731 2
733 735 1 73d
2 73f 740 2
737 742 2 744
746 2 748 74a
2 74c 74e 2
750 752 2 72a
754 1 756 1
758 2 762 764
3 760 761 766
2 76f 771 2
76e 773 1 775
1 777 3 77e
77f 780 3 759
778 782 1 784
3 78c 78d 78e
1 792 2 790
792 1 797 3
79d 79e 79f 1
7a3 2 7a1 7a3
2 7b6 7bb 2
7cc 7ce 3 7ca
7cb 7d0 2 7d9
7db 2 7dd 7df
2 7e1 7e3 2
7e5 7e7 2 7e9
7eb 3 7f0 7f1
7f2 2 7ed 7f4
2 7d8 7f6 1
7f8 1 7fa 2
7c3 7fb 1 7ff
1 7be 1 803
1 80e 2 80a
80e 2 81b 820
2 831 833 3
82f 830 835 2
83e 840 2 842
844 2 846 848
2 84a 84c 2
84e 850 3 855
856 857 2 852
859 2 83d 85b
1 85d 1 85f
2 828 860 1
864 1 823 1
868 1 86b 1
86e 2 806 86f
1 873 2 880
882 3 87e 87f
884 2 88d 88f
2 891 893 2
895 897 1 89d
2 89f 8a0 2
899 8a2 2 8a4
8a6 2 8a8 8aa
2 8ac 8ae 2
8b0 8b2 2 88c
8b4 1 8b6 1
8b8 2 8c2 8c4
3 8c0 8c1 8c6
2 8cf 8d1 2
8ce 8d3 1 8d5
1 8d7 3 8dc
8dd 8de 3 8b9
8d8 8e0 3 8e3
872 8e2 3 785
788 8e4 2 8e8
8eb 2 8ed 8ee
1 8f0 1 8f5
3 8fe 8ff 900
1 904 2 902
904 2 912 914
3 910 911 916
2 91f 921 2
923 925 2 927
929 1 931 2
933 934 2 92b
936 2 938 93a
2 93c 93e 2
940 942 2 944
946 2 91e 948
1 94a 1 94c
2 956 958 3
954 955 95a 2
963 965 2 962
967 1 969 1
96b 3 972 973
974 3 94d 96c
976 1 979 3
982 983 984 1
988 2 986 988
2 996 998 3
994 995 99a 2
9a3 9a5 2 9a7
9a9 2 9ab 9ad
1 9b5 2 9b7
9b8 2 9af 9ba
2 9a2 9bc 1
9be 1 9c0 2
9ca 9cc 3 9c8
9c9 9ce 2 9d7
9d9 2 9d6 9db
1 9dd 1 9df
2 9e6 9e7 3
9c1 9e0 9e9 2
9ec 9eb 1 9ee
3 9f7 9f8 9f9
1 9fd 2 9fb
9fd 1 a05 1
a09 2 a0b a0c
3 a11 a12 a13
1 a17 2 a15
a17 1 a1c 2
a22 a23 1 a27
2 a25 a27 2
a3a a3f 2 a50
a52 3 a4e a4f
a54 2 a5d a5f
2 a61 a63 2
a65 a67 2 a69
a6b 2 a6d a6f
3 a74 a75 a76
2 a71 a78 2
a5c a7a 1 a7c
1 a7e 2 a47
a7f 1 a83 1
a42 1 a87 1
a92 2 a8e a92
2 a9f aa4 2
ab5 ab7 3 ab3
ab4 ab9 2 ac2
ac4 2 ac6 ac8
2 aca acc 2
ace ad0 2 ad2
ad4 3 ad9 ada
adb 2 ad6 add
2 ac1 adf 1
ae1 1 ae3 2
aac ae4 1 ae8
1 aa7 1 aec
1 aef 1 af2
2 a8a af3 3
afa afb afc 1
b00 2 afe b00
2 b0b b0d 3
b09 b0a b0f 2
b18 b1a 2 b1c
b1e 2 b20 b22
1 b28 2 b2a
b2b 2 b24 b2d
2 b2f b31 2
b33 b35 2 b37
b39 2 b3b b3d
2 b17 b3f 1
b41 1 b43 2
b4d b4f 3 b4b
b4c b51 2 b5a
b5c 2 b59 b5e
1 b60 1 b62
3 b67 b68 b69
3 b44 b63 b6b
3 b6e af6 b6d
3 9ed a0d b6f
1 b73 2 b75
b76 2 b7f b80
1 b86 2 b82
b86 1 b94 2
b93 b94 1 b9c
1 ba2 2 ba4
ba5 2 b91 ba6
2 bb7 bb9 3
bb5 bb6 bbb 2
bc4 bc6 2 bc8
bca 2 bcc bce
2 bd0 bd2 2
bd4 bd6 3 bdb
bdc bdd 2 bd8
bdf 2 bc3 be1
1 be3 1 be5
2 bae be6 1
bea 1 ba9 1
bee 1 bf1 1
bf4 1 bf9 2
c0d c12 2 c23
c25 3 c21 c22
c27 2 c30 c32
2 c34 c36 2
c38 c3a 2 c3c
c3e 2 c40 c42
3 c47 c48 c49
2 c44 c4b 2
c2f c4d 1 c4f
1 c51 2 c1a
c52 1 c56 1
c15 1 c5a 2
c60 c61 1 c65
2 c63 c65 2
c70 c72 3 c6e
c6f c74 2 c7d
c7f 2 c81 c83
2 c85 c87 1
c8f 2 c91 c92
2 c89 c94 2
c96 c98 2 c9a
c9c 2 c9e ca0
2 ca2 ca4 2
c7c ca6 1 ca8
1 caa 2 cb4
cb6 3 cb2 cb3
cb8 2 cc1 cc3
2 cc0 cc5 1
cc7 1 cc9 3
cd0 cd1 cd2 3
cab cca cd4 1
cd6 2 c5d cd7
1 cda 2 cee
cf3 2 d04 d06
3 d02 d03 d08
2 d11 d13 2
d15 d17 2 d19
d1b 2 d1d d1f
2 d21 d23 3
d28 d29 d2a 2
d25 d2c 2 d10
d2e 1 d30 1
d32 2 cfb d33
1 d37 1 cf6
1 d3b 2 d41
d42 1 d46 2
d44 d46 2 d51
d53 3 d4f d50
d55 2 d5e d60
2 d62 d64 2
d66 d68 1 d70
2 d72 d73 2
d6a d75 2 d77
d79 2 d7b d7d
2 d7f d81 2
d83 d85 2 d5d
d87 1 d89 1
d8b 2 d95 d97
3 d93 d94 d99
2 da2 da4 2
da1 da6 1 da8
1 daa 3 db1
db2 db3 3 d8c
dab db5 2 dc3
dc8 2 dd9 ddb
3 dd7 dd8 ddd
2 de6 de8 2
dea dec 2 dee
df0 2 df2 df4
2 df6 df8 3
dfd dfe dff 2
dfa e01 2 de5
e03 1 e05 1
e07 2 dd0 e08
1 e0c 1 dcb
1 e10 2 e16
e17 2 e1c e1d
1 e1f 2 e19
e1f 2 e2a e2c
3 e28 e29 e2e
2 e37 e39 2
e3b e3d 2 e3f
e41 1 e49 2
e4b e4c 2 e43
e4e 2 e50 e52
2 e54 e56 2
e58 e5a 2 e5c
e5e 2 e36 e60
1 e62 1 e64
2 e6e e70 3
e6c e6d e72 2
e7b e7d 2 e7a
e7f 1 e81 1
e83 3 e8a e8b
e8c 3 e65 e84
e8e 1 e90 2
e13 e91 2 e93
e94 2 d3e e95
2 ea0 ea2 3
e9e e9f ea4 2
ead eaf 2 eb1
eb3 2 eb5 eb7
1 ebf 2 ec1
ec2 2 eb9 ec4
2 ec6 ec8 2
eca ecc 2 ece
ed0 2 ed2 ed4
2 eac ed6 1
ed8 1 eda 2
ee4 ee6 3 ee2
ee3 ee8 2 ef1
ef3 2 ef0 ef5
1 ef7 1 ef9
3 f00 f01 f02
3 edb efa f04
3 f06 e97 f07
1 f08 1 f0a
1 f12 1 f17
1 f21 1 f23
17 f27 f28 f29
f2a f2b f2c f2d
f2e f2f f30 f31
f32 f33 f34 f35
f36 f37 f38 f39
f3a f3b f3c f3d
5 f46 f47 f48
f49 f4a 1 f4e
5 f58 f59 f5a
f5b f5c 2 f55
f5f 1 f61 8
f0b f0e f11 f24
f40 f43 f4d f62
2 f64 f65 7
67f 70b 8ef b77
b7a b7d f66 1
f68 3 5d2 65b
f69 2 f6b f6c
2 f71 f72 1
f76 2 f74 f76
2 f7b f7c 1
f82 2 f7e f82
5 f95 f96 f97
f98 f99 5 faf
fb0 fb1 fb2 fb3
a f8a f8d f92
f9c fa1 fa4 fa7
fac fb6 fbb 1
fbd 1 fc1 2
fcd fcf 3 fcb
fcc fd1 2 fda
fdc 2 fde fe0
2 fe2 fe4 1
fec 2 fee fef
2 fe6 ff1 2
ff3 ff5 2 ff7
ff9 2 ffb ffd
2 fff 1001 2
fd9 1003 1 1005
1 1007 3 100e
100f 1010 18 1ae
1cd 1d0 1d3 1d6
1d9 1dc 1df 1e2
1f4 27c 2f7 370
3fd 400 460 464
4b5 4d0 f6d fbe
fc4 1008 1012 2
101f 1021 3 101d
101e 1023 2 102c
102e 2 102b 1030
2 1037 103b 2
103d 103f 2 1041
1045 2 1036 1047
2 1032 1049 1
104b 3 104c 1057
105b 1 1016 2
106e 1070 3 106c
106d 1072 2 107b
107d 2 107a 107f
2 1086 1088 2
108a 108c 3 1091
1092 1093 2 108e
1095 2 1085 1097
2 1081 1099 1
109b 4 1065 109c
10a5 10a9 1 10ad
1 1060 2 105e
10b1 2e 23 2a
31 38 3f 46
4d 54 59 5e
63 68 6d 72
77 7e 84 8a
90 96 9b a0
a5 aa af b4
bb c1 c7 cd
d3 d9 df e5
eb f1 f7 fd
103 109 10f 115
11c 121 127 12e

1
4
0 
10b8
0
1
28
1c
34
0 1 2 1 4 1 6 1
8 1 a 1 c 1 e 1
10 1 12 1 14 1 16 1
18 1 1a 1 0 0 0 0
0 0 0 0 0 0 0 0

13 1 0
f9 1 0
105 1 0
6f 1 0
80 1 0
5b 1 0
33 1 0
2c 1 0
c9 1 0
111 1 0
92 1 0
f3 1 0
11e 1 0
ac 1 0
10b 1 0
a2 1 0
e1 1 0
60 1 0
3 1 0
98 1 0
56 1 0
117 1 0
bd 1 0
4f 1 0
ed 1 0
d5 1 0
65 1 0
ff 1 0
cf 1 0
3a 1 0
c3 1 0
25 1 0
79 1 0
a7 1 0
9d 1 0
74 1 0
123 1 0
7 1 0
b6 1 0
b1 1 0
86 1 0
41 1 0
1e 1 0
2 0 1
6a 1 0
f 1 0
8c 1 0
db 1 0
48 1 0
e7 1 0
b 1 0
129 1 0
0

/
SHOW ERRORS FUNCTION SP_U_WP_FORECAST;
ALTER FUNCTION SP_U_WP_FORECAST COMPILE DEBUG;
/*****************************************************************************/
Prompt == FUNCTION SP_U_ASSIGN_DESCR ==
CREATE OR REPLACE FUNCTION SP_U_ASSIGN_DESCR wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
56
2 :e:
1FUNCTION:
1SP_U_ASSIGN_DESCR:
1PRJ_ID:
1VARCHAR2:
1RES_ID001:
1DESCRIPTION001:
1REC_USER001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_U_ASSIGN_DESCR(:
1':
1, :
1);:
1CHECK_TRACE:
11:
120:
1+:
1FPUT:
1               ENTER:: SP_U_ASSIGN_DESCR(21) :: cplan.sql(20195) :: :
1IS NULL:
132:
125:
1        RETURN_ERROR:: SP_U_ASSIGN_DESCR(26) :: cplan.sql(20200) :: :
1 :
1STATE:: :
1COALESCE:
1TO_CHAR:
1PMO_CNST:
1INVALID_PARAMS:
1NULL:
1 ID:: :
128:
1                EXIT:: SP_U_ASSIGN_DESCR(29) :: cplan.sql(20203) :: :
1PMODEFINES:
1PMO_RETURN_ERROR_SP:
1TRUE:
1PROJECT_ASSIGNMENTS:
1DESCRIPTION:
1RESOURCE_ID:
1PROJECT_ID:
1UPDATE PROJECT_ASSIGNMENTS:n      SET DESCRIPTION = description001:n      WHE+
1RE RESOURCE_ID = res_id001:n      AND PROJECT_ID = prj_id:
1FOUND:
1=:
1SC_STATE:
10:
1100:
1OTHERS:
1SQLCODE:
116:
149:
1           EXCEPTION:: SP_U_ASSIGN_DESCR(50) :: cplan.sql(20224) :: :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
14:
155:
1       RETURN_STATUS:: SP_U_ASSIGN_DESCR(56) :: cplan.sql(20230) :: :
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
162:
1           EXCEPTION:: SP_U_ASSIGN_DESCR(63) :: cplan.sql(20237) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1ID:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
174:
1           EXCEPTION:: SP_U_ASSIGN_DESCR(75) :: cplan.sql(20249) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
27a
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d b4 :3 a0 6b 2c 6a
a3 :2 a0 6b 1c 81 b0 :2 a0 6b
:2 a0 6b 6e a5 b a 10 :2 a0
6b 6e :2 a0 6b 6e a5 b 6e
7e a0 b4 2e 6e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c a0 7e b4
2e 5a a0 7e b4 2e 5a 52
10 :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b :2 a0 a5 57
b7 19 3c :7 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :4 a0 6b a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b :2 a0 a5 57
b7 :2 a0 6b :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 :2 a0 6b :2 6e 7e :2 a0
6b b4 2e 7e 6e b4 2e 7e
:2 a0 6b b4 2e a5 57 b7 19
3c :9 a0 12a e9 dd :2 a0 65 b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c :7 a0
12a e9 dd :2 a0 65 b7 a4 b1
11 4f b7 a6 9 a4 b1 11
68 4f 1d 17 b5 
27a
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 5e
5a 30 66 59 6b 6f 73 56
77 7b 9b 83 87 8b 8e 96
82 a2 a6 7f aa ae b2 b5
ba bb 1 bd c2 c6 ca cd
d2 d6 da dd e2 e3 e5 ea
ed f1 f2 f7 fc ff 104 105
10a 10d 111 112 117 11a 11f 120
125 128 12d 12e 133 136 13b 13c
141 144 148 149 14e 151 156 157
15c 15f 164 165 16a 16d 172 173
178 17b 17f 180 185 188 18d 18e
193 196 19b 19c 1a1 1a4 1a9 1aa
1af 1b2 1b6 1b7 1bc 1bf 1c4 1c5
1ca 1cd 1d2 1d3 1d8 1d9 1de 1e0
1e4 1e7 1eb 1ef 1f2 1f6 1fa 1fd
200 205 208 20b 20e 20f 214 215
1 217 21c 220 224 227 22c 231
234 238 239 23e 23f 244 246 24a
24d 251 254 255 25a 25d 261 264
265 26a 1 26d 272 276 27a 27d
281 285 288 28b 290 293 296 299
29a 29f 2a0 1 2a2 2a7 2ab 2af
2b2 2b7 2bc 2bf 2c3 2c4 2c9 2cc
2d1 2d2 2d7 2da 2df 2e0 2e5 2e8
2ec 2f0 2f4 2f8 2fb 2fc 2fe 303
304 306 307 30c 30f 314 315 31a
31d 322 323 328 32b 32f 330 335
338 33d 33e 343 344 349 34b 34f
352 356 35a 35d 361 365 368 36b
370 373 376 379 37a 37f 380 1
382 387 38b 38f 392 397 39c 39f
3a3 3a4 3a9 3aa 3af 3b1 3b5 3b8
3bc 3c0 3c3 3c7 3cb 3ce 3d2 3d6
3d7 3dc 3de 3e2 3e5 3e9 3ed 3f1
3f5 3f9 3fd 401 40d 411 416 41a
41d 41e 423 427 42b 42e 431 435
437 43b 43f 442 445 449 44b 44f
453 456 458 1 45c 460 464 467
46b 46f 473 477 47a 47e 482 485
488 48d 490 493 496 497 49c 49d
1 49f 4a4 4a8 4ac 4af 4b4 4b9
4bc 4c0 4c1 4c6 4c9 4ce 4cf 4d4
4d7 4dc 4dd 4e2 4e5 4e9 4ea 4ef
4f2 4f7 4f8 4fd 500 504 508 50b
50e 50f 511 512 517 518 51d 51f
523 526 528 52c 52e 53a 53c 53e
53f 544 548 54a 556 558 55c 560
563 567 56b 56e 571 576 579 57c
57f 580 585 586 1 588 58d 591
595 598 59d 5a2 5a5 5a9 5aa 5af
5b2 5b7 5b8 5bd 5c0 5c5 5c6 5cb
5ce 5d2 5d6 5da 5de 5e1 5e2 5e4
5e9 5ea 5ec 5ed 5f2 5f5 5fa 5fb
600 603 608 609 60e 611 615 616
61b 61e 623 624 629 62a 62f 631
635 638 63c 640 643 647 64b 64e
652 656 657 65c 65e 662 666 669
66d 671 674 678 67c 67f 682 687
68a 68d 690 691 696 697 1 699
69e 6a2 6a6 6a9 6ae 6b3 6b6 6ba
6bb 6c0 6c1 6c6 6ca 6ce 6d1 6d6
6db 6de 6e2 6e6 6e9 6ea 6ef 6f2
6f7 6f8 6fd 700 704 708 70b 70c
711 712 717 719 71d 720 724 728
72c 730 734 738 73c 740 744 750
755 759 75d 761 765 767 768 76d
1 771 775 779 77c 780 784 788
78c 78f 793 797 79a 79d 7a2 7a5
7a8 7ab 7ac 7b1 7b2 1 7b4 7b9
7bd 7c1 7c4 7c9 7ce 7d1 7d5 7d6
7db 7dc 7e1 7e5 7e9 7ec 7f1 7f6
7f9 7fd 7fe 803 806 80b 80c 811
814 818 81c 81f 822 823 825 826
82b 82c 831 833 837 83a 83e 842
846 84a 84e 852 856 862 867 86b
86f 873 877 879 87d 87f 88b 88d
88f 890 895 899 89b 8a7 8ab 8ad
8ae 8b7 
27a
2
0 1 a 6 d :3 6 10 :3 6
15 :3 6 12 :2 6 1 3 a 13
a :2 1 4 e 17 :3 e 4 7
:2 11 23 :2 2d 3a :2 23 :3 7 :2 d 19
25 :2 2f 43 :2 25 59 5f 62 :2 59
70 8b 8 :2 70 d 10 :2 70 17
1a :2 70 b e :2 70 13 16 :2 70
1b 1e :2 70 28 2b :2 70 b e
:2 70 13 16 :2 70 1b 1e :2 70 2d
30 :2 70 b e :2 70 13 16 :2 70
1b 1e :2 70 2a 2d :2 70 32 35
:2 70 :2 7 4f :2 4 7 :2 11 23 :2 2d
39 3c 51 53 54 :2 51 :2 23 :3 7
:2 d 12 1e 62 65 :2 1e :2 7 57
:2 4 :4 8 7 :4 1c 1b :2 7 a :2 14
26 :2 30 3c 40 55 57 58 :2 55
:2 26 :3 a :2 10 15 21 65 68 :2 21
75 78 :2 21 7c 7f :2 21 89 8c
95 9d :2 a6 :2 95 b7 :2 8c :2 21 bf
c2 :2 21 ca cd :2 21 d2 d5 :2 21
dc df :2 21 :2 a 5b :2 7 a :2 14
26 :2 30 3c 3f 54 56 57 :2 54
:2 26 :3 a :2 10 15 21 65 68 :2 21
:2 a 5a :3 7 :2 12 26 :2 2f 3f 47
:2 7 2f :2 4 e b 19 d 1b
b 18 7 e a 16 :3 14 a
:2 13 1f a 1b a :2 13 1f a
:4 7 4 :2 c a :2 13 1f a d
:2 17 29 :2 33 3f 43 58 5a 5b
:2 58 :2 29 :3 d :2 13 18 24 68 6b
:2 24 78 7b :2 24 7f 82 :2 24 8e
91 :2 24 99 9c :2 24 a8 ab b2
bb be :2 ab :2 24 :2 d 5e :2 a :2 7
:4 13 :2 7 4 :3 1 7 :2 11 23 :2 2d
39 3c 51 53 54 :2 51 :2 23 :3 7
:2 d 12 1e 62 65 :2 1e 72 75
:2 1e 79 7c :2 1e 86 89 92 9a
:2 a3 :2 92 ae :2 89 :2 1e b6 b9 :2 1e
c1 c4 :2 1e c9 cc :2 1e d3 d6
:2 1e :2 7 57 :3 4 :2 f 21 :2 2a 34
3c :2 4 1 9 12 9 a :2 14
26 :2 30 3c 40 55 57 58 :2 55
:2 26 :3 a :2 10 15 21 65 68 :2 21
:3 a :2 10 15 39 5c 5f :2 68 :2 39
76 79 :2 39 81 84 :2 8d :2 39 :2 a
5b :3 7 c 15 1e 2c a 13
1e f e 7 e 7 e 7
29 :2 4 :2 9 7 :2 10 1c :2 7 :2 11
23 :2 2d 39 3d 52 54 55 :2 52
:2 23 :3 7 :2 d 12 1e 62 65 :2 1e
:3 7 :2 d 12 36 42 45 :2 36 4d
50 :2 36 5c 5f 66 6f 72 :2 5f
:2 36 :2 7 58 :2 4 7 c 1b a
13 1e f e 7 e 7 e
7 :2 4 :4 10 :2 4 :8 1 
27a
4
0 :2 1 :4 3 :4 4
:4 5 :4 6 2 :4 7
:2 1 :7 a :b c :11 d
e :2 d :2 e :2 d
:2 e :2 d :2 f :2 d
:2 f :2 d :2 f :2 d
:2 f :2 d :2 10 :2 d
:2 10 :2 d :2 10 :2 d
:2 10 :2 d :2 11 :2 d
:2 11 :2 d :2 11 :2 d
:2 11 :2 d :2 11 :4 d
:3 c :11 14 :b 15 :3 14
:c 18 :11 19 :30 1a :3 19
:11 1c :b 1d :3 1c :a 1f
:3 18 24 :2 25 :2 26
:2 27 24 :6 28 :5 29
28 :5 2b 2a :3 28
23 :2 2e :5 30 :11 31
:24 32 :3 31 :2 2f :6 2e
2d :3 b :11 37 :30 38
:3 37 :a 3a b :3 3d
:11 3e :b 3f :17 40 :3 3e
:2 42 :3 43 :3 44 45
43 42 43 :3 46
:3 3d :2 47 :5 49 :11 4a
:b 4b :18 4c :3 4a :2 4e
4f :3 50 51 4f
4e 4f :3 52 :2 48
:6 47 3c :7 1 
8b9
4
:3 0 1 :3 0 2
:a 0 275 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
56 0 7 4
:3 0 5 :7 0 9
8 :3 0 4 :3 0
6 :7 0 d c
:3 0 15 16 0
b 4 :3 0 7
:7 0 11 10 :3 0
8 :3 0 9 :3 0
a :2 0 4 13
17 0 275 2
18 :2 0 21 22
0 10 9 :3 0
a :2 0 4 1b
1c 0 1d :7 0
20 1e 0 273
0 b :6 0 c
:3 0 d :3 0 c
:3 0 e :3 0 24
25 0 2 :4 0
12 26 28 23
2a 29 :2 0 f
:3 0 10 :3 0 2c
2d 0 11 :4 0
c :3 0 12 :3 0
30 31 0 2
:4 0 14 32 34
13 :4 0 14 :2 0
15 :3 0 16 37
39 :3 0 16 :4 0
14 :2 0 17 :4 0
19 3c 3e :3 0
14 :2 0 3 :3 0
1c 40 42 :3 0
14 :2 0 17 :4 0
1f 44 46 :3 0
14 :2 0 18 :4 0
22 48 4a :3 0
14 :2 0 17 :4 0
25 4c 4e :3 0
14 :2 0 5 :3 0
28 50 52 :3 0
14 :2 0 17 :4 0
2b 54 56 :3 0
14 :2 0 18 :4 0
2e 58 5a :3 0
14 :2 0 17 :4 0
31 5c 5e :3 0
14 :2 0 6 :3 0
34 60 62 :3 0
14 :2 0 17 :4 0
37 64 66 :3 0
14 :2 0 18 :4 0
3a 68 6a :3 0
14 :2 0 17 :4 0
3d 6c 6e :3 0
14 :2 0 7 :3 0
40 70 72 :3 0
14 :2 0 17 :4 0
43 74 76 :3 0
14 :2 0 19 :4 0
46 78 7a :3 0
49 2e 7c :2 0
7e 4e 7f 2b
7e 0 80 50
0 1d3 c :3 0
d :3 0 81 82
0 c :3 0 1a
:3 0 84 85 0
1b :2 0 2 :4 0
1c :2 0 1d :2 0
1b :2 0 52 8a
8c :3 0 55 86
8e 83 90 8f
:2 0 f :3 0 1e
:3 0 92 93 0
11 :4 0 1f :4 0
14 :2 0 15 :3 0
59 97 99 :3 0
5c 94 9b :2 0
9d 5f 9e 91
9d 0 9f 61
0 1d3 3 :3 0
20 :2 0 63 a1
a2 :3 0 a3 :2 0
5 :3 0 20 :2 0
65 a6 a7 :3 0
a8 :2 0 a4 aa
a9 :2 0 c :3 0
d :3 0 ac ad
0 c :3 0 1a
:3 0 af b0 0
21 :2 0 2 :4 0
22 :2 0 1d :2 0
1b :2 0 67 b5
b7 :3 0 6a b1
b9 ae bb ba
:2 0 f :3 0 1e
:3 0 bd be 0
11 :4 0 23 :4 0
14 :2 0 15 :3 0
6e c2 c4 :3 0
14 :2 0 24 :4 0
71 c6 c8 :3 0
14 :2 0 25 :4 0
74 ca cc :3 0
14 :2 0 26 :3 0
27 :3 0 28 :3 0
29 :3 0 d1 d2
0 77 d0 d4
2a :4 0 79 cf
d7 7c ce d9
:3 0 14 :2 0 2b
:4 0 7f db dd
:3 0 14 :2 0 17
:4 0 82 df e1
:3 0 14 :2 0 3
:3 0 85 e3 e5
:3 0 14 :2 0 17
:4 0 88 e7 e9
:3 0 8b bf eb
:2 0 ed 8e ee
bc ed 0 ef
90 0 119 c
:3 0 d :3 0 f0
f1 0 c :3 0
1a :3 0 f3 f4
0 1b :2 0 2
:4 0 2c :2 0 1d
:2 0 1b :2 0 92
f9 fb :3 0 95
f5 fd f2 ff
fe :2 0 f :3 0
1e :3 0 101 102
0 11 :4 0 2d
:4 0 14 :2 0 15
:3 0 99 106 108
:3 0 9c 103 10a
:2 0 10c 9f 10d
100 10c 0 10e
a1 0 119 2e
:3 0 2f :3 0 10f
110 0 28 :3 0
29 :3 0 112 113
0 3 :3 0 30
:3 0 a3 111 117
:2 0 119 a7 11a
ab 119 0 11b
ab 0 1d3 31
:3 0 32 :3 0 6
:3 0 33 :3 0 5
:3 0 34 :3 0 3
:4 0 35 1 :8 0
139 36 :4 0 124
:3 0 30 :3 0 37
:2 0 af 127 128
:3 0 9 :3 0 38
:3 0 12a 12b 0
39 :2 0 12c 12d
0 12f b2 136
9 :3 0 38 :3 0
130 131 0 3a
:2 0 132 133 0
135 b4 137 129
12f 0 138 0
135 0 138 b6
0 139 b9 183
3b :3 0 9 :3 0
38 :3 0 13c 13d
0 3c :3 0 13e
13f 0 179 c
:3 0 d :3 0 141
142 0 c :3 0
1a :3 0 144 145
0 3d :2 0 2
:4 0 3e :2 0 1d
:2 0 1b :2 0 bc
14a 14c :3 0 bf
146 14e 143 150
14f :2 0 f :3 0
1e :3 0 152 153
0 11 :4 0 3f
:4 0 14 :2 0 15
:3 0 c3 157 159
:3 0 14 :2 0 24
:4 0 c6 15b 15d
:3 0 14 :2 0 40
:4 0 c9 15f 161
:3 0 14 :2 0 3c
:3 0 cc 163 165
:3 0 14 :2 0 41
:4 0 cf 167 169
:3 0 14 :2 0 42
:3 0 43 :3 0 1b
:2 0 44 :2 0 d2
16c 170 d6 16b
172 :3 0 d9 154
174 :2 0 176 dc
177 151 176 0
178 de 0 179
e0 17c :3 0 17c
0 17c 17b 179
17a :6 0 17e 2
:3 0 e3 180 e5
17f 17e :2 0 181
e7 :2 0 183 0
183 182 139 181
:6 0 1d3 1 :3 0
c :3 0 d :3 0
185 186 0 c
:3 0 1a :3 0 188
189 0 45 :2 0
2 :4 0 46 :2 0
1d :2 0 1b :2 0
e9 18e 190 :3 0
ec 18a 192 187
194 193 :2 0 f
:3 0 1e :3 0 196
197 0 11 :4 0
47 :4 0 14 :2 0
15 :3 0 f0 19b
19d :3 0 14 :2 0
24 :4 0 f3 19f
1a1 :3 0 14 :2 0
25 :4 0 f6 1a3
1a5 :3 0 14 :2 0
26 :3 0 27 :3 0
9 :3 0 38 :3 0
1aa 1ab 0 f9
1a9 1ad 2a :4 0
fb 1a8 1b0 fe
1a7 1b2 :3 0 14
:2 0 2b :4 0 101
1b4 1b6 :3 0 14
:2 0 17 :4 0 104
1b8 1ba :3 0 14
:2 0 3 :3 0 107
1bc 1be :3 0 14
:2 0 17 :4 0 10a
1c0 1c2 :3 0 10d
198 1c4 :2 0 1c6
110 1c7 195 1c6
0 1c8 112 0
1d3 2e :3 0 48
:3 0 1c9 1ca 0
9 :3 0 38 :3 0
1cc 1cd 0 3
:3 0 30 :3 0 114
1cb 1d1 :2 0 1d3
118 274 9 :3 0
49 :2 0 4 1d4
1d5 0 c :3 0
d :3 0 1d7 1d8
0 c :3 0 1a
:3 0 1da 1db 0
3d :2 0 2 :4 0
4a :2 0 1d :2 0
1b :2 0 11f 1e0
1e2 :3 0 122 1dc
1e4 1d9 1e6 1e5
:2 0 f :3 0 1e
:3 0 1e8 1e9 0
11 :4 0 4b :4 0
14 :2 0 15 :3 0
126 1ed 1ef :3 0
129 1ea 1f1 :2 0
20a f :3 0 1e
:3 0 1f3 1f4 0
11 :4 0 4c :4 0
14 :2 0 9 :3 0
4d :3 0 1f9 1fa
0 12c 1f8 1fc
:3 0 14 :2 0 2b
:4 0 12f 1fe 200
:3 0 14 :2 0 9
:3 0 4e :3 0 203
204 0 132 202
206 :3 0 135 1f5
208 :2 0 20a 138
20b 1e7 20a 0
20c 13b 0 21c
4f :3 0 b :3 0
9 :3 0 4d :3 0
50 :3 0 9 :3 0
4e :3 0 51 :3 0
52 :4 0 53 1
:a 0 218 :2 0 21c
20e 216 :2 0 8
:3 0 b :3 0 21a
:2 0 21c 13d 21e
141 21d 21c :2 0
272 3b :3 0 9
:3 0 38 :3 0 221
222 0 3c :3 0
223 224 0 26a
c :3 0 d :3 0
226 227 0 c
:3 0 1a :3 0 229
22a 0 3d :2 0
2 :4 0 54 :2 0
1d :2 0 1b :2 0
143 22f 231 :3 0
146 22b 233 228
235 234 :2 0 f
:3 0 1e :3 0 237
238 0 11 :4 0
55 :4 0 14 :2 0
15 :3 0 14a 23c
23e :3 0 14d 239
240 :2 0 25a f
:3 0 1e :3 0 242
243 0 11 :4 0
40 :4 0 14 :2 0
3c :3 0 150 247
249 :3 0 14 :2 0
41 :4 0 153 24b
24d :3 0 14 :2 0
42 :3 0 43 :3 0
1b :2 0 44 :2 0
156 250 254 15a
24f 256 :3 0 15d
244 258 :2 0 25a
160 25b 236 25a
0 25c 163 0
26a 4f :3 0 b
:3 0 50 :3 0 9
:3 0 4e :3 0 51
:3 0 52 :4 0 56
1 :a 0 266 :2 0
26a 25e 264 :2 0
8 :3 0 b :3 0
268 :2 0 26a 165
26d :3 0 26d 0
26d 26c 26a 26b
:6 0 26f 1 :3 0
16a 271 16c 270
26f :2 0 272 16e
:2 0 274 171 274
273 1d3 272 :6 0
275 :2 0 2 18
274 278 :3 0 277
275 279 :8 0 
173
4
:3 0 1 3 1
7 1 b 1
f 4 6 a
e 12 1 1a
1 27 1 33
2 36 38 2
3b 3d 2 3f
41 2 43 45
2 47 49 2
4b 4d 2 4f
51 2 53 55
2 57 59 2
5b 5d 2 5f
61 2 63 65
2 67 69 2
6b 6d 2 6f
71 2 73 75
2 77 79 4
2f 35 3a 7b
1 7d 1 7f
2 89 8b 3
87 88 8d 2
96 98 2 95
9a 1 9c 1
9e 1 a0 1
a5 2 b4 b6
3 b2 b3 b8
2 c1 c3 2
c5 c7 2 c9
cb 1 d3 2
d5 d6 2 cd
d8 2 da dc
2 de e0 2
e2 e4 2 e6
e8 2 c0 ea
1 ec 1 ee
2 f8 fa 3
f6 f7 fc 2
105 107 2 104
109 1 10b 1
10d 3 114 115
116 3 ef 10e
118 1 11a 1
126 2 125 126
1 12e 1 134
2 136 137 2
123 138 2 149
14b 3 147 148
14d 2 156 158
2 15a 15c 2
15e 160 2 162
164 2 166 168
3 16d 16e 16f
2 16a 171 2
155 173 1 175
1 177 2 140
178 1 17c 1
13b 1 180 2
18d 18f 3 18b
18c 191 2 19a
19c 2 19e 1a0
2 1a2 1a4 1
1ac 2 1ae 1af
2 1a6 1b1 2
1b3 1b5 2 1b7
1b9 2 1bb 1bd
2 1bf 1c1 2
199 1c3 1 1c5
1 1c7 3 1ce
1cf 1d0 6 80
9f 11b 183 1c8
1d2 2 1df 1e1
3 1dd 1de 1e3
2 1ec 1ee 2
1eb 1f0 2 1f7
1fb 2 1fd 1ff
2 201 205 2
1f6 207 2 1f2
209 1 20b 3
20c 217 21b 1
1d6 2 22e 230
3 22c 22d 232
2 23b 23d 2
23a 23f 2 246
248 2 24a 24c
3 251 252 253
2 24e 255 2
245 257 2 241
259 1 25b 4
225 25c 265 269
1 26d 1 220
2 21e 271 1
1f 
1
4
0 
278
0
1
14
4
6
0 1 2 1 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 
f 1 0
b 1 0
7 1 0
2 0 1
3 1 0
1a 1 0
0

/
SHOW ERRORS FUNCTION SP_U_ASSIGN_DESCR;
ALTER FUNCTION SP_U_ASSIGN_DESCR COMPILE DEBUG;
/****************************************************************************************/
Prompt == FUNCTION SP_TEST_ASSIGN ==
CREATE OR REPLACE FUNCTION SP_TEST_ASSIGN wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
bb
2 :e:
1FUNCTION:
1SP_TEST_ASSIGN:
1RANK001:
1VARCHAR2:
1BITFLAG001:
1PLS_INTEGER:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_RANK:
1200:
1H_FULL_NAME:
1255:
1H_PROJECT_ID:
132:
1H_RES_ASSIGNMENT_ID:
1H_TSK_ASSIGNMENT_ID:
1H_SECURITY_ID:
1H_RES_ID:
1H_RES_TYPE:
11:
1H_PARTICIPANT:
10:
1H_BITFLAG:
1CURSOR:
1C_RPA0:
1ELEMENT_ID:
1TMT_WBS:
1TYPE_ID:
1PMO_CNST:
1SC_PROJECT:
1SC_PROPOSAL:
1SC_PROJ_TYPE1:
1SC_PROJ_TYPE2:
1SC_PROJ_TYPE3:
1RANK:
1SELECT ELEMENT_ID FROM TMT_WBS:n         WHERE TYPE_ID IN (PMO_CNST.SC_PROJEC+
1T,PMO_CNST.SC_PROPOSAL,PMO_CNST.SC_PROJ_TYPE1,PMO_CNST.SC_PROJ_TYPE2,PMO_CNST+
1.SC_PROJ_TYPE3) AND RANK LIKE h_rank || '%':
1C_RPA1:
1RES_ASSIGNMENT_ID:
1TSK_ASSIGNMENT_ID:
1RESOURCE_ID:
1RESOURCE_TYPE:
1TASK_ASSIGNMENTS:
1PROJECT_ID:
1TASK_ID:
1SELECT RES_ASSIGNMENT_ID, TSK_ASSIGNMENT_ID, RESOURCE_ID, RESOURCE_TYPE:n    +
1     FROM TASK_ASSIGNMENTS:n         WHERE PROJECT_ID = h_project_id AND TASK+
1_ID = h_project_id:
1C_FPA1:
1RA:
1PARTICIPANT:
1SECURITY_ID:
1RESOURCE_ASSIGNMENTS:
1PROJECT_ASSIGNMENTS:
1PA:
1SELECT ra.RESOURCE_ID, ra.RESOURCE_TYPE, ra.PARTICIPANT, ra.SECURITY_ID:n    +
1     FROM RESOURCE_ASSIGNMENTS ra:n         WHERE ELEMENT_ID = h_project_id A+
1ND NOT EXISTS (:n         SELECT 'X' FROM PROJECT_ASSIGNMENTS pa WHERE pa.PRO+
1JECT_ID = h_project_id AND pa.RESOURCE_ID = ra.RESOURCE_ID):
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_TEST_ASSIGN(:
1':
1, :
1COALESCE:
1TO_CHAR:
1NULL:
1);:
1CHECK_TRACE:
141:
1+:
1FPUT:
1               ENTER:: SP_TEST_ASSIGN(42) :: cplan.sql(20307) :: :
1OPEN:
1LOOP:
1FOUND:
1SC_STATE:
1100:
1!=:
1SC_SQL_SUCCESS:
1EXIT:
1=:
1COUNT:
1DUAL:
1PROJECT_ASSIGNMENT_ID:
1SELECT COUNT('X') INTO h_bitflag FROM DUAL WHERE EXISTS (SELECT 'X' FROM TASK+
1_ASSIGNMENTS:n               WHERE PROJECT_ASSIGNMENT_ID = h_tsk_assignment_i+
1d AND RESOURCE_ID = h_res_id):
1SQLCODE:
1OTHERS:
116:
184:
1           EXCEPTION:: SP_TEST_ASSIGN(85) :: cplan.sql(20350) :: :
1 :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1UPDATE TASK_ASSIGNMENTS SET PROJECT_ASSIGNMENT_ID = NuLL:n                  W+
1HERE PROJECT_ASSIGNMENT_ID = h_tsk_assignment_id:
1TRUE:
1103:
1           EXCEPTION:: SP_TEST_ASSIGN(104) :: cplan.sql(20369) :: :
1TASK_DAY_OF_YEAR:
1PARENT_ID:
1UPDATE TASK_DAY_OF_YEAR SET PARENT_ID = TSK_ASSIGNMENT_ID:n                  +
1WHERE PROJECT_ID = h_project_id AND PARENT_ID = h_tsk_assignment_id:
1121:
1           EXCEPTION:: SP_TEST_ASSIGN(122) :: cplan.sql(20387) :: :
1DELETE FROM RESOURCE_ASSIGNMENTS:n               WHERE RES_ASSIGNMENT_ID = h_+
1res_assignment_id:n               AND SECURITY_ID = 'SCPROJECTASSIGNMENT':
1141:
1           EXCEPTION:: SP_TEST_ASSIGN(142) :: cplan.sql(20407) :: :
1DELETE FROM PROJECT_ASSIGNMENTS WHERE PROJECT_ID = h_project_id AND RESOURCE_+
1ID = h_res_id:
1159:
1           EXCEPTION:: SP_TEST_ASSIGN(160) :: cplan.sql(20425) :: :
1NICK_NAME:
1RESOURCES:
1SELECT NICK_NAME || ';' INTO h_full_name:n                     FROM RESOURCES+
1:n                     WHERE RESOURCE_ID = h_res_id:
1175:
1           EXCEPTION:: SP_TEST_ASSIGN(176) :: cplan.sql(20441) :: :
1PROFILE_NAME:
1PROFILES:
1PROFILE_ID:
1SELECT PROFILE_NAME || ';' INTO h_full_name:n                     FROM PROFIL+
1ES:n                     WHERE PROFILE_ID = h_res_id:
1190:
1           EXCEPTION:: SP_TEST_ASSIGN(191) :: cplan.sql(20456) :: :
1ASSIGN_NAMES:
1REPLACE:
1UPDATE TMT_WBS SET ASSIGN_NAMES = REPLACE (ASSIGN_NAMES, h_full_name, ''):n  +
1                WHERE PROJECT_ID = h_project_id AND ELEMENT_ID = h_project_id:
1209:
1           EXCEPTION:: SP_TEST_ASSIGN(210) :: cplan.sql(20475) :: :
1PMO_STPU:
1BIT_ANDNOT:
1UPDATE RESOURCE_ASSIGNMENTS SET PARTICIPANT = PMO_STPU.BIT_ANDNOT(PARTICIPANT+
1,4096):n                  WHERE RES_ASSIGNMENT_ID = h_res_assignment_id:
1227:
1           EXCEPTION:: SP_TEST_ASSIGN(228) :: cplan.sql(20493) :: :
1DELETE FROM TASK_ASSIGNMENTS WHERE TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
1245:
1           EXCEPTION:: SP_TEST_ASSIGN(246) :: cplan.sql(20511) :: :
1DELETE FROM TASK_DAY_OF_YEAR WHERE PROJECT_ID = h_project_id AND TSK_ASSIGNME+
1NT_ID = h_tsk_assignment_id:
1262:
1           EXCEPTION:: SP_TEST_ASSIGN(263) :: cplan.sql(20528) :: :
1CLOSE:
1276:
1           EXCEPTION:: SP_TEST_ASSIGN(277) :: cplan.sql(20542) :: :
1COMMIT:
1ELSIF:
1SELECT NICK_NAME || ';' INTO h_full_name:n                  FROM RESOURCES:n +
1                 WHERE RESOURCE_ID = h_res_id:
1307:
1           EXCEPTION:: SP_TEST_ASSIGN(308) :: cplan.sql(20573) :: :
1SELECT PROFILE_NAME || ';' INTO h_full_name:n                  FROM PROFILES+
1:n                  WHERE PROFILE_ID = h_res_id:
1322:
1           EXCEPTION:: SP_TEST_ASSIGN(323) :: cplan.sql(20588) :: :
1INSTR:
1UPDATE TMT_WBS SET ASSIGN_NAMES = CASE:n               WHEN InStr(ASSIGN_NAME+
1S, h_full_name) > 0 THEN ASSIGN_NAMES:n               ELSE ASSIGN_NAMES || h_+
1full_name END:n               WHERE PROJECT_ID = h_project_id AND ELEMENT_ID +
1= h_project_id:
1343:
1           EXCEPTION:: SP_TEST_ASSIGN(344) :: cplan.sql(20609) :: :
1ELEMENT_TYPE_BITS:
1ROLLUP_BITS:
1SC_ASSIGNMENT_BIT:
1INSERT INTO PROJECT_ASSIGNMENTS (PROJECT_ID, RESOURCE_ID, PARTICIPANT, SECURI+
1TY_ID, RESOURCE_TYPE, ELEMENT_TYPE_BITS,ROLLUP_BITS):n               VALUES(h+
1_project_id, h_res_id, h_participant, h_security_id, h_res_type, 1, PMO_CNST.+
1SC_ASSIGNMENT_BIT):
1361:
1           EXCEPTION:: SP_TEST_ASSIGN(362) :: cplan.sql(20627) :: :
1376:
1           EXCEPTION:: SP_TEST_ASSIGN(377) :: cplan.sql(20642) :: :
1393:
1           EXCEPTION:: SP_TEST_ASSIGN(394) :: cplan.sql(20659) :: :
14:
1399:
1       RETURN_STATUS:: SP_TEST_ASSIGN(400) :: cplan.sql(20665) :: :
1STATE:: :
1 ID:: :
1PMODEFINES:
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
1406:
1           EXCEPTION:: SP_TEST_ASSIGN(407) :: cplan.sql(20672) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1ERROR:
1ID:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
1418:
1           EXCEPTION:: SP_TEST_ASSIGN(419) :: cplan.sql(20684) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
9bb
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d b4 :3 a0 6b 2c 6a
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a0 f4 b4 bf
c8 :f a0 12a bd b7 11 a4 b1
a0 f4 b4 bf c8 :9 a0 12a bd
b7 11 a4 b1 a0 f4 b4 bf
c8 :15 a0 12a bd b7 11 a4 b1
a3 :2 a0 6b 1c 81 b0 :2 a0 6b
:2 a0 6b 6e a5 b a 10 :2 a0
6b 6e :2 a0 6b 6e a5 b 6e
7e a0 b4 2e 6e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :3 a0 a5
b 6e a5 b b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 d :2 a0 d :2 a0 e9
dd b3 :3 a0 e9 d3 :2 a0 f :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c :2 a0 6b a0 7e a0
6b b4 2e 5a a0 2b b7 19
3c :2 a0 51 a5 b 7e 51 b4
2e :2 a0 e9 dd b3 :6 a0 e9 d3
5 :2 a0 f :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c :2 a0
6b a0 7e a0 6b b4 2e 5a
a0 2b b7 19 3c :8 a0 12a :2 a0
6b a0 d b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 51 a5 b 7e 51 b4 2e
:4 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :7 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 19 3c :4 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
a0 7e a0 6b b4 2e 5a :5 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 :2 51 a5 b 7e 6e b4 2e
:5 a0 12a :2 a0 6b a0 d b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 :5 a0 12a :2 a0 6b
a0 d b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
:2 19 3c :9 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 :7 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 :2 19 3c
:3 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :5 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 a0 47 :2 a0 e9 c1
:2 a0 6b a0 d b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f a0 12a a0 b7 :2 a0 51 a5
b 7e 51 b4 2e :2 a0 e9 dd
b3 :6 a0 e9 d3 5 :2 a0 f :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c :2 a0 6b a0 7e a0
6b b4 2e 5a a0 2b b7 19
3c :2 a0 :2 51 a5 b 7e 6e b4
2e :5 a0 12a :2 a0 6b a0 d b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 :5 a0 12a :2 a0
6b a0 d b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 :2 19 3c :c a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :f a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 a0 47
:2 a0 e9 c1 :2 a0 6b a0 d b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f a0 12a b7 :2 19
3c b7 a0 47 :2 a0 e9 c1 :2 a0
6b a0 d b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b :2 a0 a5 57 b7 :2 a0 6b :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 :2 a0
6b :2 6e 7e :2 a0 6b b4 2e 7e
6e b4 2e 7e :2 a0 6b b4 2e
a5 57 b7 19 3c :9 a0 12a e9
dd :2 a0 65 b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c :7 a0 12a e9 dd :2 a0
65 b7 a4 b1 11 4f b7 a6
9 a4 b1 11 68 4f 1d 17
b5 
9bb
2
0 3 7 23 1f 1e 2b 38
34 1b 40 33 45 49 4d 30
51 55 72 5d 61 64 65 6d
5c 8f 7d 59 81 82 8a 7c
ac 9a 79 9e 9f a7 99 c9
b7 96 bb bc c4 b6 e6 d4
b3 d8 d9 e1 d3 103 f1 d0
f5 f6 fe f0 120 10e ed 112
113 11b 10d 13d 12b 10a 12f 130
138 12a 159 148 14c 127 154 147
175 164 168 144 170 163 17c 180
160 191 194 198 19c 1a0 1a4 1a8
1ac 1b0 1b4 1b8 1bc 1c0 1c4 1c8
1cc 1d0 1d4 1e0 1e5 1e7 1f3 1f7
1f9 1fd 20e 20f 212 216 21a 21e
222 226 22a 22e 232 236 23a 246
24b 24d 259 25d 25f 263 274 275
278 27c 280 284 288 28c 290 294
298 29c 2a0 2a4 2a8 2ac 2b0 2b4
2b8 2bc 2c0 2c4 2c8 2cc 2d0 2dc
2e1 2e3 2ef 2f3 311 2f9 2fd 301
304 30c 2f8 318 31c 2f5 320 324
328 32b 330 331 1 333 338 33c
340 343 348 34c 350 353 358 359
35b 360 363 367 368 36d 372 375
37a 37b 380 383 387 388 38d 390
395 396 39b 39e 3a3 3a4 3a9 3ac
3b0 3b4 3b8 3b9 3bb 3c0 3c1 3c3
3c4 3c9 3cc 3d1 3d2 3d7 3d8 3dd
3df 3e3 3e6 3ea 3ee 3f1 3f5 3f9
3fc 3ff 404 407 40a 40d 40e 413
414 1 416 41b 41f 423 426 42b
430 433 437 438 43d 43e 443 445
449 44c 450 454 458 45c 460 464
468 46c 471 475 476 47a 47e 482
487 48c 490 494 499 49d 4a1 4a4
4a7 4ab 4ad 4b1 4b5 4b8 4bb 4bf
4c1 4c5 4c9 4cc 4d0 4d4 4d7 4db
4de 4e2 4e5 4e6 4eb 4ee 4f2 4f8
4fa 4fe 501 505 509 50c 50d 50f
512 515 516 51b 51f 523 528 52c
52d 531 535 539 53d 541 545 54a
54f 553 557 55b 560 564 568 56b
56e 572 574 578 57c 57f 582 586
588 58c 590 593 597 59b 59e 5a2
5a5 5a9 5ac 5ad 5b2 5b5 5b9 5bf
5c1 5c5 5c8 5cc 5d0 5d4 5d8 5dc
5e0 5e4 5e8 5f4 5f8 5fc 5ff 603
607 609 1 60d 611 615 618 61c
620 624 628 62b 62f 633 636 639
63e 641 644 647 648 64d 64e 1
650 655 659 65d 660 665 66a 66d
671 672 677 67a 67f 680 685 688
68d 68e 693 696 69a 69b 6a0 6a3
6a8 6a9 6ae 6b1 6b5 6b9 6bc 6bf
6c0 6c2 6c3 6c8 6c9 6ce 6d0 6d4
6d7 6d9 6dd 6df 6eb 6ed 6ef 6f0
6f5 6f9 6fb 707 709 70d 711 714
715 717 71a 71d 71e 723 727 72b
72f 733 73f 743 748 74c 74f 750
755 759 75d 760 763 767 769 76d
771 774 777 77b 77d 781 785 788
78a 1 78e 792 796 799 79d 7a1
7a5 7a9 7ac 7b0 7b4 7b7 7ba 7bf
7c2 7c5 7c8 7c9 7ce 7cf 1 7d1
7d6 7da 7de 7e1 7e6 7eb 7ee 7f2
7f3 7f8 7fb 800 801 806 809 80e
80f 814 817 81b 81c 821 824 829
82a 82f 832 836 83a 83d 840 841
843 844 849 84a 84f 851 855 858
85a 85e 860 86c 86e 870 871 876
87a 87c 888 88a 88e 892 896 89a
89e 8a2 8a6 8b2 8b6 8bb 8bf 8c2
8c3 8c8 8cc 8d0 8d3 8d6 8da 8dc
8e0 8e4 8e7 8ea 8ee 8f0 8f4 8f8
8fb 8fd 1 901 905 909 90c 910
914 918 91c 91f 923 927 92a 92d
932 935 938 93b 93c 941 942 1
944 949 94d 951 954 959 95e 961
965 966 96b 96e 973 974 979 97c
981 982 987 98a 98e 98f 994 997
99c 99d 9a2 9a5 9a9 9ad 9b0 9b3
9b4 9b6 9b7 9bc 9bd 9c2 9c4 9c8
9cb 9cd 9d1 9d3 9df 9e1 9e3 9e4
9e9 9ed 9ef 9fb 9fd 9ff a03 a06
a0a a0e a12 a16 a22 a26 a2b a2f
a32 a33 a38 a3c a40 a43 a46 a4a
a4c a50 a54 a57 a5a a5e a60 a64
a68 a6b a6d 1 a71 a75 a79 a7c
a80 a84 a88 a8c a8f a93 a97 a9a
a9d aa2 aa5 aa8 aab aac ab1 ab2
1 ab4 ab9 abd ac1 ac4 ac9 ace
ad1 ad5 ad6 adb ade ae3 ae4 ae9
aec af1 af2 af7 afa afe aff b04
b07 b0c b0d b12 b15 b19 b1d b20
b23 b24 b26 b27 b2c b2d b32 b34
b38 b3b b3d b41 b43 b4f b51 b53
b54 b59 b5d b5f b6b b6d b71 b75
b78 b7c b7f b83 b86 b87 b8c b8f
b93 b97 b9b b9f ba3 baf bb3 bb8
bbc bbf bc0 bc5 bc9 bcd bd0 bd3
bd7 bd9 bdd be1 be4 be7 beb bed
bf1 bf5 bf8 bfa 1 bfe c02 c06
c09 c0d c11 c15 c19 c1c c20 c24
c27 c2a c2f c32 c35 c38 c39 c3e
c3f 1 c41 c46 c4a c4e c51 c56
c5b c5e c62 c63 c68 c6b c70 c71
c76 c79 c7e c7f c84 c87 c8b c8c
c91 c94 c99 c9a c9f ca2 ca6 caa
cad cb0 cb1 cb3 cb4 cb9 cba cbf
cc1 cc5 cc8 cca cce cd0 cdc cde
ce0 ce1 ce6 cea cec cf8 cfa cfe
d02 d05 d08 d09 d0b d0e d13 d14
d19 d1d d21 d25 d29 d2d d39 d3d
d41 d44 d48 d4c d4e 1 d52 d56
d5a d5d d61 d65 d69 d6d d70 d74
d78 d7b d7e d83 d86 d89 d8c d8d
d92 d93 1 d95 d9a d9e da2 da5
daa daf db2 db6 db7 dbc dbf dc4
dc5 dca dcd dd2 dd3 dd8 ddb ddf
de0 de5 de8 ded dee df3 df6 dfa
dfe e01 e04 e05 e07 e08 e0d e0e
e13 e15 e19 e1c e1e e22 e24 e30
e32 e34 e35 e3a e3e e40 e4c e4e
e50 e54 e58 e5c e60 e64 e70 e74
e78 e7b e7f e83 e85 1 e89 e8d
e91 e94 e98 e9c ea0 ea4 ea7 eab
eaf eb2 eb5 eba ebd ec0 ec3 ec4
ec9 eca 1 ecc ed1 ed5 ed9 edc
ee1 ee6 ee9 eed eee ef3 ef6 efb
efc f01 f04 f09 f0a f0f f12 f16
f17 f1c f1f f24 f25 f2a f2d f31
f35 f38 f3b f3c f3e f3f f44 f45
f4a f4c f50 f53 f55 f59 f5b f67
f69 f6b f6c f71 f75 f77 f83 f85
f87 f8b f8f f92 f96 f9a f9e fa2
fa6 faa fae fb2 fb6 fc2 fc6 fcb
fcf fd2 fd3 fd8 fdc fe0 fe3 fe6
fea fec ff0 ff4 ff7 ffa ffe 1000
1004 1008 100b 100d 1 1011 1015 1019
101c 1020 1024 1028 102c 102f 1033 1037
103a 103d 1042 1045 1048 104b 104c 1051
1052 1 1054 1059 105d 1061 1064 1069
106e 1071 1075 1076 107b 107e 1083 1084
1089 108c 1091 1092 1097 109a 109e 109f
10a4 10a7 10ac 10ad 10b2 10b5 10b9 10bd
10c0 10c3 10c4 10c6 10c7 10cc 10cd 10d2
10d4 10d8 10db 10dd 10e1 10e3 10ef 10f1
10f3 10f4 10f9 10fd 10ff 110b 110d 110f
1113 1117 111b 111f 1123 1127 112b 1137
113b 1140 1144 1147 1148 114d 1151 1155
1158 115b 115f 1161 1165 1169 116c 116f
1173 1175 1179 117d 1180 1182 1 1186
118a 118e 1191 1195 1199 119d 11a1 11a4
11a8 11ac 11af 11b2 11b7 11ba 11bd 11c0
11c1 11c6 11c7 1 11c9 11ce 11d2 11d6
11d9 11de 11e3 11e6 11ea 11eb 11f0 11f3
11f8 11f9 11fe 1201 1206 1207 120c 120f
1213 1214 1219 121c 1221 1222 1227 122a
122e 1232 1235 1238 1239 123b 123c 1241
1242 1247 1249 124d 1250 1252 1256 1258
1264 1266 1268 1269 126e 1272 1274 1280
1282 1284 1288 128c 128f 1293 1297 129b
12a7 12ab 12b0 12b4 12b7 12b8 12bd 12c1
12c5 12c8 12cb 12cf 12d1 12d5 12d9 12dc
12df 12e3 12e5 12e9 12ed 12f0 12f2 1
12f6 12fa 12fe 1301 1305 1309 130d 1311
1314 1318 131c 131f 1322 1327 132a 132d
1330 1331 1336 1337 1 1339 133e 1342
1346 1349 134e 1353 1356 135a 135b 1360
1363 1368 1369 136e 1371 1376 1377 137c
137f 1383 1384 1389 138c 1391 1392 1397
139a 139e 13a2 13a5 13a8 13a9 13ab 13ac
13b1 13b2 13b7 13b9 13bd 13c0 13c2 13c6
13c8 13d4 13d6 13d8 13d9 13de 13e2 13e4
13f0 13f2 13f6 13fa 13fe 1402 1406 1412
1416 141b 141f 1422 1423 1428 142c 1430
1433 1436 143a 143c 1440 1444 1447 144a
144e 1450 1454 1458 145b 145d 1 1461
1465 1469 146c 1470 1474 1478 147c 147f
1483 1487 148a 148d 1492 1495 1498 149b
149c 14a1 14a2 1 14a4 14a9 14ad 14b1
14b4 14b9 14be 14c1 14c5 14c6 14cb 14ce
14d3 14d4 14d9 14dc 14e1 14e2 14e7 14ea
14ee 14ef 14f4 14f7 14fc 14fd 1502 1505
1509 150d 1510 1513 1514 1516 1517 151c
151d 1522 1524 1528 152b 152d 1531 1533
153f 1541 1543 1544 1549 154d 154f 155b
155d 155f 1563 156a 156e 1572 1577 1579
157d 1581 1584 1588 158c 158e 1 1592
1596 159a 159d 15a1 15a5 15a9 15ad 15b0
15b4 15b8 15bb 15be 15c3 15c6 15c9 15cc
15cd 15d2 15d3 1 15d5 15da 15de 15e2
15e5 15ea 15ef 15f2 15f6 15f7 15fc 15ff
1604 1605 160a 160d 1612 1613 1618 161b
161f 1620 1625 1628 162d 162e 1633 1636
163a 163e 1641 1644 1645 1647 1648 164d
164e 1653 1655 1659 165c 165e 1662 1664
1670 1672 1674 1675 167a 167e 1680 168c
168e 1692 169e 16a2 16a4 16a8 16ac 16af
16b0 16b2 16b5 16b8 16b9 16be 16c2 16c6
16cb 16cf 16d0 16d4 16d8 16dc 16e0 16e4
16e8 16ed 16f2 16f6 16fa 16fe 1703 1707
170b 170e 1711 1715 1717 171b 171f 1722
1725 1729 172b 172f 1733 1736 173a 173e
1741 1745 1748 174c 174f 1750 1755 1758
175c 1762 1764 1768 176b 176f 1773 1776
1779 177a 177c 177f 1784 1785 178a 178e
1792 1796 179a 179e 17aa 17ae 17b2 17b5
17b9 17bd 17bf 1 17c3 17c7 17cb 17ce
17d2 17d6 17da 17de 17e1 17e5 17e9 17ec
17ef 17f4 17f7 17fa 17fd 17fe 1803 1804
1 1806 180b 180f 1813 1816 181b 1820
1823 1827 1828 182d 1830 1835 1836 183b
183e 1843 1844 1849 184c 1850 1851 1856
1859 185e 185f 1864 1867 186b 186f 1872
1875 1876 1878 1879 187e 187f 1884 1886
188a 188d 188f 1893 1895 18a1 18a3 18a5
18a6 18ab 18af 18b1 18bd 18bf 18c1 18c5
18c9 18cd 18d1 18d5 18e1 18e5 18e9 18ec
18f0 18f4 18f6 1 18fa 18fe 1902 1905
1909 190d 1911 1915 1918 191c 1920 1923
1926 192b 192e 1931 1934 1935 193a 193b
1 193d 1942 1946 194a 194d 1952 1957
195a 195e 195f 1964 1967 196c 196d 1972
1975 197a 197b 1980 1983 1987 1988 198d
1990 1995 1996 199b 199e 19a2 19a6 19a9
19ac 19ad 19af 19b0 19b5 19b6 19bb 19bd
19c1 19c4 19c6 19ca 19cc 19d8 19da 19dc
19dd 19e2 19e6 19e8 19f4 19f6 19f8 19fc
1a00 1a03 1a07 1a0b 1a0f 1a13 1a17 1a1b
1a1f 1a23 1a27 1a2b 1a2f 1a33 1a3f 1a43
1a48 1a4c 1a4f 1a50 1a55 1a59 1a5d 1a60
1a63 1a67 1a69 1a6d 1a71 1a74 1a77 1a7b
1a7d 1a81 1a85 1a88 1a8a 1 1a8e 1a92
1a96 1a99 1a9d 1aa1 1aa5 1aa9 1aac 1ab0
1ab4 1ab7 1aba 1abf 1ac2 1ac5 1ac8 1ac9
1ace 1acf 1 1ad1 1ad6 1ada 1ade 1ae1
1ae6 1aeb 1aee 1af2 1af3 1af8 1afb 1b00
1b01 1b06 1b09 1b0e 1b0f 1b14 1b17 1b1b
1b1c 1b21 1b24 1b29 1b2a 1b2f 1b32 1b36
1b3a 1b3d 1b40 1b41 1b43 1b44 1b49 1b4a
1b4f 1b51 1b55 1b58 1b5a 1b5e 1b60 1b6c
1b6e 1b70 1b71 1b76 1b7a 1b7c 1b88 1b8a
1b8e 1b92 1b96 1b9a 1b9e 1ba2 1ba6 1baa
1bae 1bb2 1bb6 1bba 1bbe 1bc2 1bc6 1bd2
1bd6 1bdb 1bdf 1be2 1be3 1be8 1bec 1bf0
1bf3 1bf6 1bfa 1bfc 1c00 1c04 1c07 1c0a
1c0e 1c10 1c14 1c18 1c1b 1c1d 1 1c21
1c25 1c29 1c2c 1c30 1c34 1c38 1c3c 1c3f
1c43 1c47 1c4a 1c4d 1c52 1c55 1c58 1c5b
1c5c 1c61 1c62 1 1c64 1c69 1c6d 1c71
1c74 1c79 1c7e 1c81 1c85 1c86 1c8b 1c8e
1c93 1c94 1c99 1c9c 1ca1 1ca2 1ca7 1caa
1cae 1caf 1cb4 1cb7 1cbc 1cbd 1cc2 1cc5
1cc9 1ccd 1cd0 1cd3 1cd4 1cd6 1cd7 1cdc
1cdd 1ce2 1ce4 1ce8 1ceb 1ced 1cf1 1cf3
1cff 1d01 1d03 1d04 1d09 1d0d 1d0f 1d1b
1d1d 1d1f 1d23 1d2a 1d2e 1d32 1d37 1d39
1d3d 1d41 1d44 1d48 1d4c 1d4e 1 1d52
1d56 1d5a 1d5d 1d61 1d65 1d69 1d6d 1d70
1d74 1d78 1d7b 1d7e 1d83 1d86 1d89 1d8c
1d8d 1d92 1d93 1 1d95 1d9a 1d9e 1da2
1da5 1daa 1daf 1db2 1db6 1db7 1dbc 1dbf
1dc4 1dc5 1dca 1dcd 1dd2 1dd3 1dd8 1ddb
1ddf 1de0 1de5 1de8 1ded 1dee 1df3 1df6
1dfa 1dfe 1e01 1e04 1e05 1e07 1e08 1e0d
1e0e 1e13 1e15 1e19 1e1c 1e1e 1e22 1e24
1e30 1e32 1e34 1e35 1e3a 1e3e 1e40 1e4c
1e4e 1e52 1e5e 1e60 1e64 1e68 1e6b 1e6d
1e71 1e78 1e7c 1e80 1e85 1e87 1e8b 1e8f
1e92 1e96 1e9a 1e9c 1 1ea0 1ea4 1ea8
1eab 1eaf 1eb3 1eb7 1ebb 1ebe 1ec2 1ec6
1ec9 1ecc 1ed1 1ed4 1ed7 1eda 1edb 1ee0
1ee1 1 1ee3 1ee8 1eec 1ef0 1ef3 1ef8
1efd 1f00 1f04 1f05 1f0a 1f0d 1f12 1f13
1f18 1f1b 1f20 1f21 1f26 1f29 1f2d 1f2e
1f33 1f36 1f3b 1f3c 1f41 1f44 1f48 1f4c
1f4f 1f52 1f53 1f55 1f56 1f5b 1f5c 1f61
1f63 1f67 1f6a 1f6c 1f70 1f72 1f7e 1f80
1f82 1f83 1f88 1f8c 1f8e 1f9a 1f9c 1fa0
1fa4 1fa7 1fab 1faf 1fb2 1fb5 1fba 1fbd
1fc0 1fc3 1fc4 1fc9 1fca 1 1fcc 1fd1
1fd5 1fd9 1fdc 1fe1 1fe6 1fe9 1fed 1fee
1ff3 1ff6 1ffb 1ffc 2001 2004 2009 200a
200f 2012 2016 201a 201e 2022 2025 2026
2028 202d 202e 2030 2031 2036 2039 203e
203f 2044 2047 204c 204d 2052 2055 2059
205a 205f 2062 2067 2068 206d 206e 2073
2075 2079 207c 2080 2084 2087 208b 208f
2092 2096 209a 209b 20a0 20a2 20a6 20aa
20ad 20b1 20b5 20b8 20bc 20c0 20c3 20c6
20cb 20ce 20d1 20d4 20d5 20da 20db 1
20dd 20e2 20e6 20ea 20ed 20f2 20f7 20fa
20fe 20ff 2104 2105 210a 210e 2112 2115
211a 211f 2122 2126 212a 212d 212e 2133
2136 213b 213c 2141 2144 2148 214c 214f
2150 2155 2156 215b 215d 2161 2164 2168
216c 2170 2174 2178 217c 2180 2184 2188
2194 2199 219d 21a1 21a5 21a9 21ab 21ac
21b1 1 21b5 21b9 21bd 21c0 21c4 21c8
21cc 21d0 21d3 21d7 21db 21de 21e1 21e6
21e9 21ec 21ef 21f0 21f5 21f6 1 21f8
21fd 2201 2205 2208 220d 2212 2215 2219
221a 221f 2220 2225 2229 222d 2230 2235
223a 223d 2241 2242 2247 224a 224f 2250
2255 2258 225c 2260 2263 2266 2267 2269
226a 226f 2270 2275 2277 227b 227e 2282
2286 228a 228e 2292 2296 229a 22a6 22ab
22af 22b3 22b7 22bb 22bd 22c1 22c3 22cf
22d1 22d3 22d4 22d9 22dd 22df 22eb 22ef
22f1 22f2 22fb 
9bb
2
0 1 a 6 e :3 6 11 :2 6
1 3 a 13 a :2 1 4 b
14 13 :2 b :2 4 10 19 18 :2 10
:2 4 11 1a 19 :2 11 :2 4 18 21
20 :2 18 :2 4 18 21 20 :2 18 :2 4
12 1b 1a :2 12 :2 4 d 16 15
:2 d :2 4 f 18 17 :2 f :2 4 :2 12
21 12 :2 4 :2 e 1d e 4 7
e 0 :2 7 11 21 10 1c 25
30 39 45 4e 5c 65 73 7c
8f 99 a :6 7 e 0 :2 7 11
24 37 44 f 10 1d 2e 38
a :6 7 e 0 :2 7 11 14 21
24 33 36 43 46 f 24 10
1d 1a 2e 37 3a 47 58 5b
69 6c a :5 7 4 e 17 :3 e
4 7 :2 11 23 :2 2d 3a :2 23 :3 7
:2 d 19 25 :2 2f 43 :2 25 56 5c
5f :2 56 6d 85 8 :2 6d d 10
:2 6d 18 1b :2 6d b e :2 6d 13
16 1f 27 :2 1f 34 :2 16 :2 6d 3c
3f :2 6d :2 7 4c :2 4 7 :2 11 23
:2 2d 39 3c 4e 50 51 :2 4e :2 23
:3 7 :2 d 12 1e 5f 62 :2 1e :2 7
54 :3 4 e :2 4 11 :2 4 9 :4 4
d 19 :2 7 a 11 :2 a :2 13 1f
a 17 a :2 13 1f a :4 7 b
:2 14 20 1d :2 29 :2 1d :3 a 39 :2 7
a 13 1e :2 a 21 23 :2 21 a
f :4 a 13 1f 34 49 53 :3 d
10 17 :2 10 :2 19 25 10 1d 10
:2 19 25 10 :4 d 11 :2 1a 26 23
:2 2f :2 23 :3 10 3f :2 d 17 27 36
59 16 2e 46 54 :2 10 :2 19 25
10 d :2 15 13 :2 1c 28 13 16
:2 20 32 :2 3c 48 4c 5e 60 61
:2 5e :2 32 :3 16 :2 1c 21 2d 6e 71
:2 2d 7e 81 :2 2d 85 88 :2 2d 94
97 :2 2d 9f a2 :2 2d ae b1 b8
c1 c4 :2 b1 :2 2d :2 16 64 :2 13 :2 10
:4 1c :2 10 d :3 a 10 19 24 :2 10
27 2a :2 27 1a 2f 19 31 13
1a 16 22 :3 20 16 :2 1f 2b 16
27 16 :2 1f 2b 16 :4 13 10 :2 18
16 :2 1f 2b 16 19 :2 23 35 :2 3f
4b 4f 61 64 65 :2 61 :2 35 :3 19
:2 1f 24 30 72 75 :2 30 82 85
:2 30 89 8c :2 30 98 9b :2 30 a3
a6 :2 30 b2 b5 bc c5 c8 :2 b5
:2 30 :2 19 68 :2 16 :2 13 :4 1f :2 13 10
:3 2c 1a 2f 3b 19 26 37 43
13 1a 16 22 :3 20 16 :2 1f 2b
16 27 16 :2 1f 2b 16 :4 13 10
:2 18 16 :2 1f 2b 16 19 :2 23 35
:2 3f 4b 4f 61 64 65 :2 61 :2 35
:3 19 :2 1f 24 30 72 75 :2 30 82
85 :2 30 89 8c :2 30 98 9b :2 30
a3 a6 :2 30 b2 b5 bc c5 c8
:2 b5 :2 30 :2 19 68 :2 16 :2 13 :4 1f :2 13
10 :4 2c :2 d 1c 16 2a 14 10
17 13 1f :3 1d 13 :2 1c 28 13
24 13 :2 1c 28 13 :4 10 d :2 15
13 :2 1c 28 13 16 :2 20 32 :2 3c
48 4c 5e 61 62 :2 5e :2 32 :3 16
:2 1c 21 2d 6f 72 :2 2d 7f 82
:2 2d 86 89 :2 2d 95 98 :2 2d a0
a3 :2 2d af b2 b9 c2 c5 :2 b2
:2 2d :2 16 65 :2 13 :2 10 :4 1c :2 10 d
:3 a 11 :2 1a 25 23 :2 2e :2 23 10
1f 39 46 57 65 13 1a 16
22 :3 20 16 :2 1f 2b 16 27 16
:2 1f 2b 16 :4 13 10 :2 18 16 :2 1f
2b 16 19 :2 23 35 :2 3f 4b 4f
61 64 65 :2 61 :2 35 :3 19 :2 1f 24
30 72 75 :2 30 82 85 :2 30 89
8c :2 30 98 9b :2 30 a3 a6 :2 30
b2 b5 bc c5 c8 :2 b5 :2 30 :2 19
68 :2 16 :2 13 :4 1f :2 13 10 :3 3e 13
1a 26 29 :2 13 2c 2e :2 2c 1d
33 1b 1c 2a :2 16 :2 1f 2b 16
13 :2 1b 19 :2 22 2e 19 1c :2 26
38 :2 42 4e 52 64 67 68 :2 64
:2 38 :3 1c :2 22 27 33 75 78 :2 33
85 88 :2 33 8c 8f :2 33 9b 9e
:2 33 a6 a9 :2 33 b5 b8 bf c8
cb :2 b8 :2 33 :2 1c 6b :2 19 :2 16 :4 22
:2 16 13 :4 32 1d 36 1b 1c 29
:2 16 :2 1f 2b 16 13 :2 1b 19 :2 22
2e 19 1c :2 26 38 :2 42 4e 52
64 67 68 :2 64 :2 38 :3 1c :2 22 27
33 75 78 :2 33 85 88 :2 33 8c
8f :2 33 9b 9e :2 33 a6 a9 :2 33
b5 b8 bf c8 cb :2 b8 :2 33 :2 1c
6b :2 19 :2 16 :4 22 :2 16 13 :7 10 1a
26 35 3e 4c 19 26 37 44
13 1a 16 22 :3 20 16 :2 1f 2b
16 27 16 :2 1f 2b 16 :4 13 10
:2 18 16 :2 1f 2b 16 19 :2 23 35
:2 3f 4b 4f 61 64 65 :2 61 :2 35
:3 19 :2 1f 24 30 72 75 :2 30 82
85 :2 30 89 8c :2 30 98 9b :2 30
a3 a6 :2 30 b2 b5 bc c5 c8
:2 b5 :2 30 :2 19 68 :2 16 :2 13 :4 1f :2 13
10 :4 3e 1a 33 41 4a 55 19
2d 13 1a 16 22 :3 20 16 :2 1f
2b 16 27 16 :2 1f 2b 16 :4 13
10 :2 18 16 :2 1f 2b 16 19 :2 23
35 :2 3f 4b 4f 61 64 65 :2 61
:2 35 :3 19 :2 1f 24 30 72 75 :2 30
82 85 :2 30 89 8c :2 30 98 9b
:2 30 a3 a6 :2 30 b2 b5 bc c5
c8 :2 b5 :2 30 :2 19 68 :2 16 :2 13 :4 1f
:2 13 10 :7 d 1c 33 47 10 17
13 1f :3 1d 13 :2 1c 28 13 24
13 :2 1c 28 13 :4 10 d :2 15 13
:2 1c 28 13 16 :2 20 32 :2 3c 48
4c 5e 61 62 :2 5e :2 32 :3 16 :2 1c
21 2d 6f 72 :2 2d 7f 82 :2 2d
86 89 :2 2d 95 98 :2 2d a0 a3
:2 2d af b2 b9 c2 c5 :2 b2 :2 2d
:2 16 65 :2 13 :2 10 :4 1c :2 10 d :3 a
1c 33 40 51 65 10 17 13
1f :3 1d 13 :2 1c 28 13 24 13
:2 1c 28 13 :4 10 d :2 15 13 :2 1c
28 13 16 :2 20 32 :2 3c 48 4c
5e 61 62 :2 5e :2 32 :3 16 :2 1c 21
2d 6f 72 :2 2d 7f 82 :2 2d 86
89 :2 2d 95 98 :2 2d a0 a3 :2 2d
af b2 b9 c2 c5 :2 b2 :2 2d :2 16
65 :2 13 :2 10 :4 1c :2 10 d :4 a e
25 d 13 :3 d :2 16 22 d a
:2 12 10 :2 19 25 10 13 :2 1d 2f
:2 39 45 49 5b 5e 5f :2 5b :2 2f
:3 13 :2 19 1e 2a 6c 6f :2 2a 7c
7f :2 2a 83 86 :2 2a 92 95 :2 2a
9d a0 :2 2a ac af b6 bf c2
:2 af :2 2a :2 13 62 :2 10 :2 d :4 19 :2 d
a :3 25 :2 a 7 25 d 16 21
:2 d 24 26 :2 24 a f :4 a 13
1f 29 35 44 :3 d 10 17 :2 10
:2 19 25 10 1d 10 :2 19 25 10
:4 d 11 :2 1a 26 23 :2 2f :2 23 :3 10
3f :2 d 10 17 23 26 :2 10 29
2b :2 29 1a 30 18 19 27 :2 13
:2 1c 28 13 10 :2 18 16 :2 1f 2b
16 19 :2 23 35 :2 3f 4b 4f 61
64 65 :2 61 :2 35 :3 19 :2 1f 24 30
72 75 :2 30 82 85 :2 30 89 8c
:2 30 98 9b :2 30 a3 a6 :2 30 b2
b5 bc c5 c8 :2 b5 :2 30 :2 19 68
:2 16 :2 13 :4 1f :2 13 10 :4 2f 1a 33
18 19 26 :2 13 :2 1c 28 13 10
:2 18 16 :2 1f 2b 16 19 :2 23 35
:2 3f 4b 4f 61 64 65 :2 61 :2 35
:3 19 :2 1f 24 30 72 75 :2 30 82
85 :2 30 89 8c :2 30 98 9b :2 30
a3 a6 :2 30 b2 b5 bc c5 c8
:2 b5 :2 30 :2 19 68 :2 16 :2 13 :4 1f :2 13
10 :7 d 17 23 15 1b 29 3f
15 25 16 23 34 41 10 17
13 1f :3 1d 13 :2 1c 28 13 24
13 :2 1c 28 13 :4 10 d :2 15 13
:2 1c 28 13 16 :2 20 32 :2 3c 48
4c 5e 61 62 :2 5e :2 32 :3 16 :2 1c
21 2d 6f 72 :2 2d 7f 82 :2 2d
86 89 :2 2d 95 98 :2 2d a0 a3
:2 2d af b2 b9 c2 c5 :2 b2 :2 2d
:2 16 65 :2 13 :2 10 :4 1c :2 10 d :3 a
1c 31 3d 4a 57 64 73 85
17 25 2f 3e 4d 5c 65 10
17 13 1f :3 1d 13 :2 1c 28 13
24 13 :2 1c 28 13 :4 10 d :2 15
13 :2 1c 28 13 16 :2 20 32 :2 3c
48 4c 5e 61 62 :2 5e :2 32 :3 16
:2 1c 21 2d 6f 72 :2 2d 7f 82
:2 2d 86 89 :2 2d 95 98 :2 2d a0
a3 :2 2d af b2 b9 c2 c5 :2 b2
:2 2d :2 16 65 :2 13 :2 10 :4 1c :2 10 d
:4 a e 28 d 13 :3 d :2 16 22
d a :2 12 10 :2 19 25 10 13
:2 1d 2f :2 39 45 49 5b 5e 5f
:2 5b :2 2f :3 13 :2 19 1e 2a 6c 6f
:2 2a 7c 7f :2 2a 83 86 :2 2a 92
95 :2 2a 9d a0 :2 2a ac af b6
bf c2 :2 af :2 2a :2 13 62 :2 10 :2 d
:4 19 :2 d a :3 28 :2 a 28 25 :2 7
4 8 1 7 d :3 7 :2 10 1c
7 4 :2 c a :2 13 1f a d
:2 17 29 :2 33 3f 43 55 58 59
:2 55 :2 29 :3 d :2 13 18 24 66 69
:2 24 76 79 :2 24 7d 80 :2 24 8c
8f :2 24 97 9a :2 24 a6 a9 b0
b9 bc :2 a9 :2 24 :2 d 5c :2 a :2 7
:4 13 :2 7 4 :3 1 7 :2 11 23 :2 2d
39 3c 4e 51 52 :2 4e :2 23 :3 7
:2 d 12 1e 60 63 :2 1e 70 73
:2 1e 77 7a :2 1e 84 87 90 98
:2 a1 :2 90 ac :2 87 :2 1e b4 b7 :2 1e
bf c2 :2 1e c7 ca :2 1e d1 d4
:2 1e :2 7 55 :3 4 :2 f 21 :2 2a 34
3c :2 4 1 9 12 9 a :2 14
26 :2 30 3c 40 52 55 56 :2 52
:2 26 :3 a :2 10 15 21 63 66 :2 21
:3 a :2 10 15 39 5c 5f :2 68 :2 39
76 79 :2 39 81 84 :2 8d :2 39 :2 a
59 :3 7 c 15 1e 2c a 13
1e f e 7 e 7 e 7
29 :2 4 :2 9 7 :2 10 1c :2 7 :2 11
23 :2 2d 39 3d 4f 52 53 :2 4f
:2 23 :3 7 :2 d 12 1e 60 63 :2 1e
:3 7 :2 d 12 36 42 45 :2 36 4d
50 :2 36 5c 5f 66 6f 72 :2 5f
:2 36 :2 7 56 :2 4 7 c 1b a
13 1e f e 7 e 7 e
7 :2 4 :4 10 :2 4 :8 1 
9bb
4
0 :2 1 :4 3 :4 4
2 :4 5 :2 1 :7 7
:7 8 :7 9 :7 a :7 b
:7 c :7 d :7 e :6 f
:6 10 :2 12 0 :2 12
:2 13 :d 14 13 :5 12
:2 16 0 :2 16 :4 17
18 :4 19 17 :5 16
:2 1b 0 :2 1b :8 1c
:2 1d :2 1e :9 1f 1c
:5 1b :7 21 :b 23 :11 24
25 :2 24 :2 25 :2 24
:2 25 :2 24 :2 26 :2 24
:9 26 :2 24 :2 26 :4 24
:3 23 :11 29 :b 2a :3 29
:3 2d :3 2e :5 30 32
:4 33 :3 34 :5 35 34
:5 37 36 :3 34 :a 39
:2 3a :3 39 :9 3e :5 3f
41 :8 42 :3 43 :5 44
43 :5 46 45 :3 43
:a 48 :2 49 :3 48 :4 4d
:4 4e 4d :5 4f 4c
:2 51 :5 53 :11 54 :24 55
:3 54 :2 52 :6 51 50
:3 41 :9 5a :2 5c :2 5d
5c :6 5e :5 5f 5e
:5 61 60 :3 5e 5b
:2 64 :5 66 :11 67 :24 68
:3 67 :2 65 :6 64 63
:3 5a :3 6e :4 6f 6e
:6 70 :5 71 70 :5 73
72 :3 70 6d :2 76
:5 78 :11 79 :24 7a :3 79
:2 77 :6 76 75 :6 5a
81 :2 82 83 81
:6 84 :5 85 84 :5 87
86 :3 84 80 :2 8a
:5 8c :11 8d :24 8e :3 8d
:2 8b :6 8a 89 :3 41
:a 93 :6 95 :6 96 :5 97
96 :5 99 98 :3 96
94 :2 9c :5 9e :11 9f
:24 a0 :3 9f :2 9d :6 9c
9b :3 93 :a a5 :2 a7
a8 :2 a9 a7 :5 aa
a6 :2 ac :5 ae :11 af
:24 b0 :3 af :2 ad :6 ac
ab :4 a5 :2 b6 b7
:2 b8 b6 :5 b9 b5
:2 bb :5 bd :11 be :24 bf
:3 be :2 bc :6 bb ba
:4 b4 :3 a5 :5 c6 :4 c7
c6 :6 c8 :5 c9 c8
:5 cb ca :3 c8 c5
:2 ce :5 d0 :11 d1 :24 d2
:3 d1 :2 cf :6 ce cd
:4 93 :5 d8 :2 d9 d8
:6 da :5 db da :5 dd
dc :3 da d7 :2 e0
:5 e2 :11 e3 :24 e4 :3 e3
:2 e1 :6 e0 df :4 d6
:3 93 :4 eb :6 ec :5 ed
ec :5 ef ee :3 ec
ea :2 f2 :5 f4 :11 f5
:24 f6 :3 f5 :2 f3 :6 f2
f1 :3 41 :6 fc :6 fd
:5 fe fd :5 100 ff
:3 fd fb :2 103 :5 105
:11 106 :24 107 :3 106 :2 104
:6 103 102 :4 41 10b
3e :4 10e :5 10f 10d
:2 111 :5 113 :11 114 :24 115
:3 114 :2 112 :6 111 110
:3 3e :2 11a 11b 3e
:9 11b :5 11c 11e :8 11f
:3 120 :5 121 120 :5 123
122 :3 120 :a 125 :2 126
:3 125 :a 129 :2 12b 12c
:2 12d 12b :5 12e 12a
:2 130 :5 132 :11 133 :24 134
:3 133 :2 131 :6 130 12f
:4 129 :2 13a 13b :2 13c
13a :5 13d 139 :2 13f
:5 141 :11 142 :24 143 :3 142
:2 140 :6 13f 13e :4 138
:3 129 :2 14a :4 14b :2 14c
:4 14d 14a :6 14e :5 14f
14e :5 151 150 :3 14e
149 :2 154 :5 156 :11 157
:24 158 :3 157 :2 155 :6 154
153 :3 11e :8 15e :7 15f
15e :6 160 :5 161 160
:5 163 162 :3 160 15d
:2 166 :5 168 :11 169 :24 16a
:3 169 :2 167 :6 166 165
:4 11e 16f 11b :4 172
:5 173 171 :2 175 :5 177
:11 178 :24 179 :3 178 :2 176
:6 175 174 :3 11b :2 17e
11b :3 3e 32 180
22 :4 183 :5 184 182
:2 186 :5 188 :11 189 :24 18a
:3 189 :2 187 :6 186 185
:3 22 :11 18f :30 190 :3 18f
:a 192 22 :3 195 :11 196
:b 197 :17 198 :3 196 :2 19a
:3 19b :3 19c 19d 19b
19a 19b :3 19e :3 195
:2 19f :5 1a1 :11 1a2 :b 1a3
:18 1a4 :3 1a2 :2 1a6 1a7
:3 1a8 1a9 1a7 1a6
1a7 :3 1aa :2 1a0 :6 19f
194 :7 1 
22fd
4
:3 0 1 :3 0 2
:a 0 9b6 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 d
e 0 7 6
:3 0 5 :7 0 9
8 :3 0 7 :3 0
8 :3 0 9 :2 0
4 b f 0
9b6 2 10 :2 0
d :2 0 c 4
:3 0 b :2 0 a
13 15 :6 0 18
16 0 9b4 0
a :6 0 f :2 0
10 4 :3 0 e
1a 1c :6 0 1f
1d 0 9b4 0
c :6 0 f :2 0
14 4 :3 0 12
21 23 :6 0 26
24 0 9b4 0
e :6 0 f :2 0
18 4 :3 0 16
28 2a :6 0 2d
2b 0 9b4 0
10 :6 0 f :2 0
1c 4 :3 0 1a
2f 31 :6 0 34
32 0 9b4 0
11 :6 0 f :2 0
20 4 :3 0 1e
36 38 :6 0 3b
39 0 9b4 0
12 :6 0 15 :2 0
24 4 :3 0 22
3d 3f :6 0 42
40 0 9b4 0
13 :6 0 17 :2 0
28 4 :3 0 26
44 46 :6 0 49
47 0 9b4 0
14 :6 0 17 :2 0
2a 6 :3 0 4b
:7 0 4f 4c 4d
9b4 0 16 :9 0
2c 6 :3 0 51
:7 0 55 52 53
9b4 0 18 :6 0
19 :3 0 1a :a 0
2 6b :4 0 57
5a 0 58 :3 0
1b :3 0 1c :3 0
1d :3 0 1e :3 0
1f :3 0 1e :3 0
20 :3 0 1e :3 0
21 :3 0 1e :3 0
22 :3 0 1e :3 0
23 :3 0 24 :3 0
a :4 0 25 1
:8 0 6c 57 5a
6d 0 9b4 2e
6d 6f 6c 6e
:6 0 6b :7 0 6d
19 :3 0 26 :a 0
3 7f :5 0 71
74 0 72 :3 0
27 :3 0 28 :3 0
29 :3 0 2a :3 0
2b :3 0 2c :3 0
e :3 0 2d :3 0
e :4 0 2e 1
:8 0 80 71 74
81 0 9b4 30
81 83 80 82
:6 0 7f :7 0 81
19 :3 0 2f :a 0
4 9f :5 0 85
88 0 86 :3 0
30 :3 0 29 :3 0
30 :3 0 2a :3 0
30 :3 0 31 :3 0
30 :3 0 32 :3 0
33 :3 0 30 :3 0
1b :3 0 e :3 0
34 :3 0 35 :3 0
35 :3 0 2c :3 0
e :3 0 35 :3 0
29 :3 0 30 :3 0
29 :4 0 36 1
:8 0 a0 85 88
a1 0 9b4 32
a1 a3 a0 a2
:6 0 9f :7 0 a1
ab ac 0 34
8 :3 0 9 :2 0
4 a5 a6 0
a7 :7 0 aa a8
0 9b4 0 37
:6 0 38 :3 0 39
:3 0 38 :3 0 3a
:3 0 ae af 0
2 :4 0 36 b0
b2 ad b4 b3
:2 0 3b :3 0 3c
:3 0 b6 b7 0
3d :4 0 38 :3 0
3e :3 0 ba bb
0 2 :4 0 38
bc be 3f :4 0
40 :2 0 41 :3 0
3a c1 c3 :3 0
42 :4 0 40 :2 0
43 :4 0 3d c6
c8 :3 0 40 :2 0
3 :3 0 40 ca
cc :3 0 40 :2 0
43 :4 0 43 ce
d0 :3 0 40 :2 0
44 :4 0 46 d2
d4 :3 0 40 :2 0
45 :3 0 46 :3 0
5 :3 0 49 d8
da 47 :4 0 4b
d7 dd 4e d6
df :3 0 40 :2 0
48 :4 0 51 e1
e3 :3 0 54 b8
e5 :2 0 e7 59
e8 b5 e7 0
e9 5b 0 914
38 :3 0 39 :3 0
ea eb 0 38
:3 0 49 :3 0 ed
ee 0 15 :2 0
2 :4 0 4a :2 0
4b :2 0 15 :2 0
5d f3 f5 :3 0
60 ef f7 ec
f9 f8 :2 0 3b
:3 0 4c :3 0 fb
fc 0 3d :4 0
4d :4 0 40 :2 0
41 :3 0 64 100
102 :3 0 67 fd
104 :2 0 106 6a
107 fa 106 0
108 6c 0 914
a :3 0 3 :3 0
109 10a 0 914
18 :3 0 5 :3 0
10c 10d 0 914
4e :3 0 1a :4 0
112 :2 0 914 110
113 :3 0 4f :3 0
1a :3 0 e :4 0
118 :2 0 86e 115
116 :3 0 1a :3 0
50 :3 0 119 11a
:3 0 8 :3 0 51
:3 0 11c 11d 0
17 :2 0 11e 11f
0 121 6e 128
8 :3 0 51 :3 0
122 123 0 52
:2 0 124 125 0
127 70 129 11b
121 0 12a 0
127 0 12a 72
0 86e 8 :3 0
51 :3 0 12b 12c
0 8 :3 0 53
:2 0 54 :3 0 12e
130 0 77 12f
132 :3 0 133 :2 0
55 :8 0 137 7a
138 134 137 0
139 7c 0 86e
45 :3 0 18 :3 0
17 :2 0 7e 13a
13d 56 :2 0 17
:2 0 83 13f 141
:3 0 4e :3 0 26
:4 0 146 :2 0 63b
144 147 :3 0 4f
:3 0 26 :3 0 10
:3 0 11 :3 0 13
:3 0 14 :4 0 14f
:2 0 5e0 149 150
:3 0 86 :3 0 26
:3 0 50 :3 0 151
152 :3 0 8 :3 0
51 :3 0 154 155
0 17 :2 0 156
157 0 159 8b
160 8 :3 0 51
:3 0 15a 15b 0
52 :2 0 15c 15d
0 15f 8d 161
153 159 0 162
0 15f 0 162
8f 0 5e0 8
:3 0 51 :3 0 163
164 0 8 :3 0
53 :2 0 54 :3 0
166 168 0 94
167 16a :3 0 16b
:2 0 55 :8 0 16f
97 170 16c 16f
0 171 99 0
5e0 57 :3 0 18
:3 0 58 :3 0 2b
:3 0 59 :3 0 11
:3 0 29 :3 0 13
:4 0 5a 1 :8 0
180 8 :3 0 51
:3 0 17b 17c 0
5b :3 0 17d 17e
0 180 9b 1ca
5c :3 0 8 :3 0
51 :3 0 183 184
0 5b :3 0 185
186 0 1c0 38
:3 0 39 :3 0 188
189 0 38 :3 0
49 :3 0 18b 18c
0 5d :2 0 2
:4 0 5e :2 0 4b
:2 0 15 :2 0 9e
191 193 :3 0 a1
18d 195 18a 197
196 :2 0 3b :3 0
4c :3 0 199 19a
0 3d :4 0 5f
:4 0 40 :2 0 41
:3 0 a5 19e 1a0
:3 0 40 :2 0 60
:4 0 a8 1a2 1a4
:3 0 40 :2 0 61
:4 0 ab 1a6 1a8
:3 0 40 :2 0 5b
:3 0 ae 1aa 1ac
:3 0 40 :2 0 62
:4 0 b1 1ae 1b0
:3 0 40 :2 0 63
:3 0 64 :3 0 15
:2 0 65 :2 0 b4
1b3 1b7 b8 1b2
1b9 :3 0 bb 19b
1bb :2 0 1bd be
1be 198 1bd 0
1bf c0 0 1c0
c2 1c3 :3 0 1c3
0 1c3 1c2 1c0
1c1 :6 0 1c5 7
:3 0 c5 1c7 c7
1c6 1c5 :2 0 1c8
c9 :2 0 1ca 0
1ca 1c9 180 1c8
:6 0 5e0 6 :3 0
45 :3 0 18 :3 0
17 :2 0 cb 1cc
1cf 53 :2 0 17
:2 0 d0 1d1 1d3
:3 0 2b :3 0 59
:3 0 59 :3 0 11
:4 0 66 1 :8 0
1ef 50 :4 0 1da
:3 0 67 :3 0 56
:2 0 d5 1dd 1de
:3 0 8 :3 0 51
:3 0 1e0 1e1 0
17 :2 0 1e2 1e3
0 1e5 d8 1ec
8 :3 0 51 :3 0
1e6 1e7 0 52
:2 0 1e8 1e9 0
1eb da 1ed 1df
1e5 0 1ee 0
1eb 0 1ee dc
0 1ef df 239
5c :3 0 8 :3 0
51 :3 0 1f2 1f3
0 5b :3 0 1f4
1f5 0 22f 38
:3 0 39 :3 0 1f7
1f8 0 38 :3 0
49 :3 0 1fa 1fb
0 5d :2 0 2
:4 0 68 :2 0 4b
:2 0 15 :2 0 e2
200 202 :3 0 e5
1fc 204 1f9 206
205 :2 0 3b :3 0
4c :3 0 208 209
0 3d :4 0 69
:4 0 40 :2 0 41
:3 0 e9 20d 20f
:3 0 40 :2 0 60
:4 0 ec 211 213
:3 0 40 :2 0 61
:4 0 ef 215 217
:3 0 40 :2 0 5b
:3 0 f2 219 21b
:3 0 40 :2 0 62
:4 0 f5 21d 21f
:3 0 40 :2 0 63
:3 0 64 :3 0 15
:2 0 65 :2 0 f8
222 226 fc 221
228 :3 0 ff 20a
22a :2 0 22c 102
22d 207 22c 0
22e 104 0 22f
106 232 :3 0 232
0 232 231 22f
230 :6 0 234 9
:3 0 109 236 10b
235 234 :2 0 237
10d :2 0 239 0
239 238 1ef 237
:6 0 2a4 6 :3 0
6a :3 0 6b :3 0
28 :3 0 2c :3 0
e :3 0 6b :3 0
11 :4 0 6c 1
:8 0 258 50 :4 0
243 :3 0 67 :3 0
56 :2 0 111 246
247 :3 0 8 :3 0
51 :3 0 249 24a
0 17 :2 0 24b
24c 0 24e 114
255 8 :3 0 51
:3 0 24f 250 0
52 :2 0 251 252
0 254 116 256
248 24e 0 257
0 254 0 257
118 0 258 11b
2a2 5c :3 0 8
:3 0 51 :3 0 25b
25c 0 5b :3 0
25d 25e 0 298
38 :3 0 39 :3 0
260 261 0 38
:3 0 49 :3 0 263
264 0 5d :2 0
2 :4 0 6d :2 0
4b :2 0 15 :2 0
11e 269 26b :3 0
121 265 26d 262
26f 26e :2 0 3b
:3 0 4c :3 0 271
272 0 3d :4 0
6e :4 0 40 :2 0
41 :3 0 125 276
278 :3 0 40 :2 0
60 :4 0 128 27a
27c :3 0 40 :2 0
61 :4 0 12b 27e
280 :3 0 40 :2 0
5b :3 0 12e 282
284 :3 0 40 :2 0
62 :4 0 131 286
288 :3 0 40 :2 0
63 :3 0 64 :3 0
15 :2 0 65 :2 0
134 28b 28f 138
28a 291 :3 0 13b
273 293 :2 0 295
13e 296 270 295
0 297 140 0
298 142 29b :3 0
29b 0 29b 29a
298 299 :6 0 29d
b :3 0 145 29f
147 29e 29d :2 0
2a0 149 :2 0 2a2
0 2a2 2a1 258
2a0 :6 0 2a4 6
:3 0 14b 2a5 1d4
2a4 0 2a6 14e
0 5e0 33 :3 0
27 :3 0 10 :3 0
32 :4 0 6f 1
:8 0 2c1 50 :4 0
2ac :3 0 67 :3 0
56 :2 0 152 2af
2b0 :3 0 8 :3 0
51 :3 0 2b2 2b3
0 17 :2 0 2b4
2b5 0 2b7 155
2be 8 :3 0 51
:3 0 2b8 2b9 0
52 :2 0 2ba 2bb
0 2bd 157 2bf
2b1 2b7 0 2c0
0 2bd 0 2c0
159 0 2c1 15c
30b 5c :3 0 8
:3 0 51 :3 0 2c4
2c5 0 5b :3 0
2c6 2c7 0 301
38 :3 0 39 :3 0
2c9 2ca 0 38
:3 0 49 :3 0 2cc
2cd 0 5d :2 0
2 :4 0 70 :2 0
4b :2 0 15 :2 0
15f 2d2 2d4 :3 0
162 2ce 2d6 2cb
2d8 2d7 :2 0 3b
:3 0 4c :3 0 2da
2db 0 3d :4 0
71 :4 0 40 :2 0
41 :3 0 166 2df
2e1 :3 0 40 :2 0
60 :4 0 169 2e3
2e5 :3 0 40 :2 0
61 :4 0 16c 2e7
2e9 :3 0 40 :2 0
5b :3 0 16f 2eb
2ed :3 0 40 :2 0
62 :4 0 172 2ef
2f1 :3 0 40 :2 0
63 :3 0 64 :3 0
15 :2 0 65 :2 0
175 2f4 2f8 179
2f3 2fa :3 0 17c
2dc 2fc :2 0 2fe
17f 2ff 2d9 2fe
0 300 181 0
301 183 304 :3 0
304 0 304 303
301 302 :6 0 306
d :3 0 186 308
188 307 306 :2 0
309 18a :2 0 30b
0 30b 30a 2c1
309 :6 0 5e0 6
:3 0 8 :3 0 51
:3 0 30d 30e 0
8 :3 0 56 :2 0
54 :3 0 310 312
0 18e 311 314
:3 0 315 :2 0 34
:3 0 2c :3 0 e
:3 0 29 :3 0 13
:4 0 72 1 :8 0
332 50 :4 0 31d
:3 0 67 :3 0 56
:2 0 193 320 321
:3 0 8 :3 0 51
:3 0 323 324 0
17 :2 0 325 326
0 328 196 32f
8 :3 0 51 :3 0
329 32a 0 52
:2 0 32b 32c 0
32e 198 330 322
328 0 331 0
32e 0 331 19a
0 332 19d 37c
5c :3 0 8 :3 0
51 :3 0 335 336
0 5b :3 0 337
338 0 372 38
:3 0 39 :3 0 33a
33b 0 38 :3 0
49 :3 0 33d 33e
0 5d :2 0 2
:4 0 73 :2 0 4b
:2 0 15 :2 0 1a0
343 345 :3 0 1a3
33f 347 33c 349
348 :2 0 3b :3 0
4c :3 0 34b 34c
0 3d :4 0 74
:4 0 40 :2 0 41
:3 0 1a7 350 352
:3 0 40 :2 0 60
:4 0 1aa 354 356
:3 0 40 :2 0 61
:4 0 1ad 358 35a
:3 0 40 :2 0 5b
:3 0 1b0 35c 35e
:3 0 40 :2 0 62
:4 0 1b3 360 362
:3 0 40 :2 0 63
:3 0 64 :3 0 15
:2 0 65 :2 0 1b6
365 369 1ba 364
36b :3 0 1bd 34d
36d :2 0 36f 1c0
370 34a 36f 0
371 1c2 0 372
1c4 375 :3 0 375
0 375 374 372
373 :6 0 377 f
:3 0 1c7 379 1c9
378 377 :2 0 37a
1cb :2 0 37c 0
37c 37b 332 37a
:6 0 4a6 6 :3 0
63 :3 0 14 :3 0
15 :2 0 15 :2 0
1cd 37e 382 56
:2 0 17 :4 0 1d3
384 386 :3 0 75
:3 0 c :3 0 76
:3 0 29 :3 0 13
:4 0 77 1 :8 0
393 8 :3 0 51
:3 0 38e 38f 0
5b :3 0 390 391
0 393 1d6 3dd
5c :3 0 8 :3 0
51 :3 0 396 397
0 5b :3 0 398
399 0 3d3 38
:3 0 39 :3 0 39b
39c 0 38 :3 0
49 :3 0 39e 39f
0 5d :2 0 2
:4 0 78 :2 0 4b
:2 0 15 :2 0 1d9
3a4 3a6 :3 0 1dc
3a0 3a8 39d 3aa
3a9 :2 0 3b :3 0
4c :3 0 3ac 3ad
0 3d :4 0 79
:4 0 40 :2 0 41
:3 0 1e0 3b1 3b3
:3 0 40 :2 0 60
:4 0 1e3 3b5 3b7
:3 0 40 :2 0 61
:4 0 1e6 3b9 3bb
:3 0 40 :2 0 5b
:3 0 1e9 3bd 3bf
:3 0 40 :2 0 62
:4 0 1ec 3c1 3c3
:3 0 40 :2 0 63
:3 0 64 :3 0 15
:2 0 65 :2 0 1ef
3c6 3ca 1f3 3c5
3cc :3 0 1f6 3ae
3ce :2 0 3d0 1f9
3d1 3ab 3d0 0
3d2 1fb 0 3d3
1fd 3d6 :3 0 3d6
0 3d6 3d5 3d3
3d4 :6 0 3d8 11
:3 0 200 3da 202
3d9 3d8 :2 0 3db
204 :2 0 3dd 0
3dd 3dc 393 3db
:6 0 3df 6 :3 0
206 438 7a :3 0
c :3 0 7b :3 0
7c :3 0 13 :4 0
7d 1 :8 0 3eb
8 :3 0 51 :3 0
3e6 3e7 0 5b
:3 0 3e8 3e9 0
3eb 208 435 5c
:3 0 8 :3 0 51
:3 0 3ee 3ef 0
5b :3 0 3f0 3f1
0 42b 38 :3 0
39 :3 0 3f3 3f4
0 38 :3 0 49
:3 0 3f6 3f7 0
5d :2 0 2 :4 0
7e :2 0 4b :2 0
15 :2 0 20b 3fc
3fe :3 0 20e 3f8
400 3f5 402 401
:2 0 3b :3 0 4c
:3 0 404 405 0
3d :4 0 7f :4 0
40 :2 0 41 :3 0
212 409 40b :3 0
40 :2 0 60 :4 0
215 40d 40f :3 0
40 :2 0 61 :4 0
218 411 413 :3 0
40 :2 0 5b :3 0
21b 415 417 :3 0
40 :2 0 62 :4 0
21e 419 41b :3 0
40 :2 0 63 :3 0
64 :3 0 15 :2 0
65 :2 0 221 41e
422 225 41d 424
:3 0 228 406 426
:2 0 428 22b 429
403 428 0 42a
22d 0 42b 22f
42e :3 0 42e 0
42e 42d 42b 42c
:6 0 430 13 :3 0
232 432 234 431
430 :2 0 433 236
:2 0 435 0 435
434 3eb 433 :6 0
437 6 :3 0 238
439 387 3df 0
43a 0 437 0
43a 23a 0 4a6
1c :3 0 80 :3 0
81 :3 0 80 :3 0
c :3 0 2c :3 0
e :3 0 1b :3 0
e :4 0 82 1
:8 0 45a 50 :4 0
445 :3 0 67 :3 0
56 :2 0 23f 448
449 :3 0 8 :3 0
51 :3 0 44b 44c
0 17 :2 0 44d
44e 0 450 242
457 8 :3 0 51
:3 0 451 452 0
52 :2 0 453 454
0 456 244 458
44a 450 0 459
0 456 0 459
246 0 45a 249
4a4 5c :3 0 8
:3 0 51 :3 0 45d
45e 0 5b :3 0
45f 460 0 49a
38 :3 0 39 :3 0
462 463 0 38
:3 0 49 :3 0 465
466 0 5d :2 0
2 :4 0 83 :2 0
4b :2 0 15 :2 0
24c 46b 46d :3 0
24f 467 46f 464
471 470 :2 0 3b
:3 0 4c :3 0 473
474 0 3d :4 0
84 :4 0 40 :2 0
41 :3 0 253 478
47a :3 0 40 :2 0
60 :4 0 256 47c
47e :3 0 40 :2 0
61 :4 0 259 480
482 :3 0 40 :2 0
5b :3 0 25c 484
486 :3 0 40 :2 0
62 :4 0 25f 488
48a :3 0 40 :2 0
63 :3 0 64 :3 0
15 :2 0 65 :2 0
262 48d 491 266
48c 493 :3 0 269
475 495 :2 0 497
26c 498 472 497
0 499 26e 0
49a 270 49d :3 0
49d 0 49d 49c
49a 49b :6 0 49f
15 :3 0 273 4a1
275 4a0 49f :2 0
4a2 277 :2 0 4a4
0 4a4 4a3 45a
4a2 :6 0 4a6 6
:3 0 279 511 33
:3 0 31 :3 0 85
:3 0 86 :3 0 31
:3 0 27 :3 0 10
:4 0 87 1 :8 0
4c4 50 :4 0 4af
:3 0 67 :3 0 56
:2 0 27f 4b2 4b3
:3 0 8 :3 0 51
:3 0 4b5 4b6 0
17 :2 0 4b7 4b8
0 4ba 282 4c1
8 :3 0 51 :3 0
4bb 4bc 0 52
:2 0 4bd 4be 0
4c0 284 4c2 4b4
4ba 0 4c3 0
4c0 0 4c3 286
0 4c4 289 50e
5c :3 0 8 :3 0
51 :3 0 4c7 4c8
0 5b :3 0 4c9
4ca 0 504 38
:3 0 39 :3 0 4cc
4cd 0 38 :3 0
49 :3 0 4cf 4d0
0 5d :2 0 2
:4 0 88 :2 0 4b
:2 0 15 :2 0 28c
4d5 4d7 :3 0 28f
4d1 4d9 4ce 4db
4da :2 0 3b :3 0
4c :3 0 4dd 4de
0 3d :4 0 89
:4 0 40 :2 0 41
:3 0 293 4e2 4e4
:3 0 40 :2 0 60
:4 0 296 4e6 4e8
:3 0 40 :2 0 61
:4 0 299 4ea 4ec
:3 0 40 :2 0 5b
:3 0 29c 4ee 4f0
:3 0 40 :2 0 62
:4 0 29f 4f2 4f4
:3 0 40 :2 0 63
:3 0 64 :3 0 15
:2 0 65 :2 0 2a2
4f7 4fb 2a6 4f6
4fd :3 0 2a9 4df
4ff :2 0 501 2ac
502 4dc 501 0
503 2ae 0 504
2b0 507 :3 0 507
0 507 506 504
505 :6 0 509 17
:3 0 2b3 50b 2b5
50a 509 :2 0 50c
2b7 :2 0 50e 0
50e 50d 4c4 50c
:6 0 510 6 :3 0
2b9 512 316 4a6
0 513 0 510
0 513 2bb 0
5e0 2b :3 0 28
:3 0 11 :4 0 8a
1 :8 0 52d 50
:4 0 518 :3 0 67
:3 0 56 :2 0 2c0
51b 51c :3 0 8
:3 0 51 :3 0 51e
51f 0 17 :2 0
520 521 0 523
2c3 52a 8 :3 0
51 :3 0 524 525
0 52 :2 0 526
527 0 529 2c5
52b 51d 523 0
52c 0 529 0
52c 2c7 0 52d
2ca 577 5c :3 0
8 :3 0 51 :3 0
530 531 0 5b
:3 0 532 533 0
56d 38 :3 0 39
:3 0 535 536 0
38 :3 0 49 :3 0
538 539 0 5d
:2 0 2 :4 0 8b
:2 0 4b :2 0 15
:2 0 2cd 53e 540
:3 0 2d0 53a 542
537 544 543 :2 0
3b :3 0 4c :3 0
546 547 0 3d
:4 0 8c :4 0 40
:2 0 41 :3 0 2d4
54b 54d :3 0 40
:2 0 60 :4 0 2d7
54f 551 :3 0 40
:2 0 61 :4 0 2da
553 555 :3 0 40
:2 0 5b :3 0 2dd
557 559 :3 0 40
:2 0 62 :4 0 2e0
55b 55d :3 0 40
:2 0 63 :3 0 64
:3 0 15 :2 0 65
:2 0 2e3 560 564
2e7 55f 566 :3 0
2ea 548 568 :2 0
56a 2ed 56b 545
56a 0 56c 2ef
0 56d 2f1 570
:3 0 570 0 570
56f 56d 56e :6 0
572 19 :3 0 2f4
574 2f6 573 572
:2 0 575 2f8 :2 0
577 0 577 576
52d 575 :6 0 5e0
6 :3 0 6a :3 0
2c :3 0 e :3 0
28 :3 0 11 :4 0
8d 1 :8 0 594
50 :4 0 57f :3 0
67 :3 0 56 :2 0
2fc 582 583 :3 0
8 :3 0 51 :3 0
585 586 0 17
:2 0 587 588 0
58a 2ff 591 8
:3 0 51 :3 0 58b
58c 0 52 :2 0
58d 58e 0 590
301 592 584 58a
0 593 0 590
0 593 303 0
594 306 5de 5c
:3 0 8 :3 0 51
:3 0 597 598 0
5b :3 0 599 59a
0 5d4 38 :3 0
39 :3 0 59c 59d
0 38 :3 0 49
:3 0 59f 5a0 0
5d :2 0 2 :4 0
8e :2 0 4b :2 0
15 :2 0 309 5a5
5a7 :3 0 30c 5a1
5a9 59e 5ab 5aa
:2 0 3b :3 0 4c
:3 0 5ad 5ae 0
3d :4 0 8f :4 0
40 :2 0 41 :3 0
310 5b2 5b4 :3 0
40 :2 0 60 :4 0
313 5b6 5b8 :3 0
40 :2 0 61 :4 0
316 5ba 5bc :3 0
40 :2 0 5b :3 0
319 5be 5c0 :3 0
40 :2 0 62 :4 0
31c 5c2 5c4 :3 0
40 :2 0 63 :3 0
64 :3 0 15 :2 0
65 :2 0 31f 5c7
5cb 323 5c6 5cd
:3 0 326 5af 5cf
:2 0 5d1 329 5d2
5ac 5d1 0 5d3
32b 0 5d4 32d
5d7 :3 0 5d7 0
5d7 5d6 5d4 5d5
:6 0 5d9 1b :3 0
330 5db 332 5da
5d9 :2 0 5dc 334
:2 0 5de 0 5de
5dd 594 5dc :6 0
5e0 6 :3 0 336
5e2 4f :4 0 5e0
:4 0 63b 90 :3 0
26 :4 0 5e6 :2 0
5ec 5e4 0 8
:3 0 51 :3 0 5e7
5e8 0 5b :3 0
5e9 5ea 0 5ec
340 636 5c :3 0
8 :3 0 51 :3 0
5ef 5f0 0 5b
:3 0 5f1 5f2 0
62c 38 :3 0 39
:3 0 5f4 5f5 0
38 :3 0 49 :3 0
5f7 5f8 0 5d
:2 0 2 :4 0 91
:2 0 4b :2 0 15
:2 0 343 5fd 5ff
:3 0 346 5f9 601
5f6 603 602 :2 0
3b :3 0 4c :3 0
605 606 0 3d
:4 0 92 :4 0 40
:2 0 41 :3 0 34a
60a 60c :3 0 40
:2 0 60 :4 0 34d
60e 610 :3 0 40
:2 0 61 :4 0 350
612 614 :3 0 40
:2 0 5b :3 0 353
616 618 :3 0 40
:2 0 62 :4 0 356
61a 61c :3 0 40
:2 0 63 :3 0 64
:3 0 15 :2 0 65
:2 0 359 61f 623
35d 61e 625 :3 0
360 607 627 :2 0
629 363 62a 604
629 0 62b 365
0 62c 367 62f
:3 0 62f 0 62f
62e 62c 62d :6 0
631 1d :3 0 36a
633 36c 632 631
:2 0 634 36e :2 0
636 0 636 635
5ec 634 :6 0 63b
5 :3 0 93 :4 0
93 1 :8 0 63b
94 :3 0 370 86c
45 :3 0 18 :3 0
17 :2 0 375 63c
63f 56 :2 0 15
:2 0 37a 641 643
:3 0 4e :3 0 2f
:4 0 648 :2 0 86a
646 649 :3 0 4f
:3 0 2f :3 0 13
:3 0 14 :3 0 16
:3 0 12 :4 0 651
:2 0 810 64b 652
:3 0 37d :3 0 2f
:3 0 50 :3 0 653
654 :3 0 8 :3 0
51 :3 0 656 657
0 17 :2 0 658
659 0 65b 382
662 8 :3 0 51
:3 0 65c 65d 0
52 :2 0 65e 65f
0 661 384 663
655 65b 0 664
0 661 0 664
386 0 810 8
:3 0 51 :3 0 665
666 0 8 :3 0
53 :2 0 54 :3 0
668 66a 0 38b
669 66c :3 0 66d
:2 0 55 :8 0 671
38e 672 66e 671
0 673 390 0
810 63 :3 0 14
:3 0 15 :2 0 15
:2 0 392 674 678
56 :2 0 17 :4 0
398 67a 67c :3 0
75 :3 0 c :3 0
76 :3 0 29 :3 0
13 :4 0 95 1
:8 0 689 8 :3 0
51 :3 0 684 685
0 5b :3 0 686
687 0 689 39b
6d3 5c :3 0 8
:3 0 51 :3 0 68c
68d 0 5b :3 0
68e 68f 0 6c9
38 :3 0 39 :3 0
691 692 0 38
:3 0 49 :3 0 694
695 0 5d :2 0
2 :4 0 96 :2 0
4b :2 0 15 :2 0
39e 69a 69c :3 0
3a1 696 69e 693
6a0 69f :2 0 3b
:3 0 4c :3 0 6a2
6a3 0 3d :4 0
97 :4 0 40 :2 0
41 :3 0 3a5 6a7
6a9 :3 0 40 :2 0
60 :4 0 3a8 6ab
6ad :3 0 40 :2 0
61 :4 0 3ab 6af
6b1 :3 0 40 :2 0
5b :3 0 3ae 6b3
6b5 :3 0 40 :2 0
62 :4 0 3b1 6b7
6b9 :3 0 40 :2 0
63 :3 0 64 :3 0
15 :2 0 65 :2 0
3b4 6bc 6c0 3b8
6bb 6c2 :3 0 3bb
6a4 6c4 :2 0 6c6
3be 6c7 6a1 6c6
0 6c8 3c0 0
6c9 3c2 6cc :3 0
6cc 0 6cc 6cb
6c9 6ca :6 0 6ce
20 :3 0 3c5 6d0
3c7 6cf 6ce :2 0
6d1 3c9 :2 0 6d3
0 6d3 6d2 689
6d1 :6 0 6d5 1f
:3 0 3cb 72e 7a
:3 0 c :3 0 7b
:3 0 7c :3 0 13
:4 0 98 1 :8 0
6e1 8 :3 0 51
:3 0 6dc 6dd 0
5b :3 0 6de 6df
0 6e1 3cd 72b
5c :3 0 8 :3 0
51 :3 0 6e4 6e5
0 5b :3 0 6e6
6e7 0 721 38
:3 0 39 :3 0 6e9
6ea 0 38 :3 0
49 :3 0 6ec 6ed
0 5d :2 0 2
:4 0 99 :2 0 4b
:2 0 15 :2 0 3d0
6f2 6f4 :3 0 3d3
6ee 6f6 6eb 6f8
6f7 :2 0 3b :3 0
4c :3 0 6fa 6fb
0 3d :4 0 9a
:4 0 40 :2 0 41
:3 0 3d7 6ff 701
:3 0 40 :2 0 60
:4 0 3da 703 705
:3 0 40 :2 0 61
:4 0 3dd 707 709
:3 0 40 :2 0 5b
:3 0 3e0 70b 70d
:3 0 40 :2 0 62
:4 0 3e3 70f 711
:3 0 40 :2 0 63
:3 0 64 :3 0 15
:2 0 65 :2 0 3e6
714 718 3ea 713
71a :3 0 3ed 6fc
71c :2 0 71e 3f0
71f 6f9 71e 0
720 3f2 0 721
3f4 724 :3 0 724
0 724 723 721
722 :6 0 726 22
:3 0 3f7 728 3f9
727 726 :2 0 729
3fb :2 0 72b 0
72b 72a 6e1 729
:6 0 72d 1f :3 0
3fd 72f 67d 6d5
0 730 0 72d
0 730 3ff 0
810 1c :3 0 80
:3 0 9b :3 0 80
:3 0 c :3 0 80
:3 0 80 :3 0 c
:3 0 2c :3 0 e
:3 0 1b :3 0 e
:4 0 9c 1 :8 0
753 50 :4 0 73e
:3 0 67 :3 0 56
:2 0 404 741 742
:3 0 8 :3 0 51
:3 0 744 745 0
17 :2 0 746 747
0 749 407 750
8 :3 0 51 :3 0
74a 74b 0 52
:2 0 74c 74d 0
74f 409 751 743
749 0 752 0
74f 0 752 40b
0 753 40e 79d
5c :3 0 8 :3 0
51 :3 0 756 757
0 5b :3 0 758
759 0 793 38
:3 0 39 :3 0 75b
75c 0 38 :3 0
49 :3 0 75e 75f
0 5d :2 0 2
:4 0 9d :2 0 4b
:2 0 15 :2 0 411
764 766 :3 0 414
760 768 75d 76a
769 :2 0 3b :3 0
4c :3 0 76c 76d
0 3d :4 0 9e
:4 0 40 :2 0 41
:3 0 418 771 773
:3 0 40 :2 0 60
:4 0 41b 775 777
:3 0 40 :2 0 61
:4 0 41e 779 77b
:3 0 40 :2 0 5b
:3 0 421 77d 77f
:3 0 40 :2 0 62
:4 0 424 781 783
:3 0 40 :2 0 63
:3 0 64 :3 0 15
:2 0 65 :2 0 427
786 78a 42b 785
78c :3 0 42e 76e
78e :2 0 790 431
791 76b 790 0
792 433 0 793
435 796 :3 0 796
0 796 795 793
794 :6 0 798 24
:3 0 438 79a 43a
799 798 :2 0 79b
43c :2 0 79d 0
79d 79c 753 79b
:6 0 810 1f :3 0
34 :3 0 2c :3 0
29 :3 0 31 :3 0
32 :3 0 2a :3 0
9f :3 0 a0 :3 0
e :3 0 13 :3 0
16 :3 0 12 :3 0
14 :3 0 1e :3 0
a1 :4 0 a2 1
:8 0 7c4 50 :4 0
7af :3 0 67 :3 0
56 :2 0 440 7b2
7b3 :3 0 8 :3 0
51 :3 0 7b5 7b6
0 17 :2 0 7b7
7b8 0 7ba 443
7c1 8 :3 0 51
:3 0 7bb 7bc 0
52 :2 0 7bd 7be
0 7c0 445 7c2
7b4 7ba 0 7c3
0 7c0 0 7c3
447 0 7c4 44a
80e 5c :3 0 8
:3 0 51 :3 0 7c7
7c8 0 5b :3 0
7c9 7ca 0 804
38 :3 0 39 :3 0
7cc 7cd 0 38
:3 0 49 :3 0 7cf
7d0 0 5d :2 0
2 :4 0 a3 :2 0
4b :2 0 15 :2 0
44d 7d5 7d7 :3 0
450 7d1 7d9 7ce
7db 7da :2 0 3b
:3 0 4c :3 0 7dd
7de 0 3d :4 0
a4 :4 0 40 :2 0
41 :3 0 454 7e2
7e4 :3 0 40 :2 0
60 :4 0 457 7e6
7e8 :3 0 40 :2 0
61 :4 0 45a 7ea
7ec :3 0 40 :2 0
5b :3 0 45d 7ee
7f0 :3 0 40 :2 0
62 :4 0 460 7f2
7f4 :3 0 40 :2 0
63 :3 0 64 :3 0
15 :2 0 65 :2 0
463 7f7 7fb 467
7f6 7fd :3 0 46a
7df 7ff :2 0 801
46d 802 7dc 801
0 803 46f 0
804 471 807 :3 0
807 0 807 806
804 805 :6 0 809
26 :3 0 474 80b
476 80a 809 :2 0
80c 478 :2 0 80e
0 80e 80d 7c4
80c :6 0 810 1f
:3 0 47a 812 4f
:4 0 810 :4 0 86a
90 :3 0 2f :4 0
816 :2 0 81c 814
0 8 :3 0 51
:3 0 817 818 0
5b :3 0 819 81a
0 81c 481 866
5c :3 0 8 :3 0
51 :3 0 81f 820
0 5b :3 0 821
822 0 85c 38
:3 0 39 :3 0 824
825 0 38 :3 0
49 :3 0 827 828
0 5d :2 0 2
:4 0 a5 :2 0 4b
:2 0 15 :2 0 484
82d 82f :3 0 487
829 831 826 833
832 :2 0 3b :3 0
4c :3 0 835 836
0 3d :4 0 a6
:4 0 40 :2 0 41
:3 0 48b 83a 83c
:3 0 40 :2 0 60
:4 0 48e 83e 840
:3 0 40 :2 0 61
:4 0 491 842 844
:3 0 40 :2 0 5b
:3 0 494 846 848
:3 0 40 :2 0 62
:4 0 497 84a 84c
:3 0 40 :2 0 63
:3 0 64 :3 0 15
:2 0 65 :2 0 49a
84f 853 49e 84e
855 :3 0 4a1 837
857 :2 0 859 4a4
85a 834 859 0
85b 4a6 0 85c
4a8 85f :3 0 85f
0 85f 85e 85c
85d :6 0 861 28
:3 0 4ab 863 4ad
862 861 :2 0 864
4af :2 0 866 0
866 865 81c 864
:6 0 86a 5 :3 0
93 :4 0 93 1
:8 0 86a 4b1 86b
644 86a 0 86d
142 63b 0 86d
4b6 0 86e 4b9
870 4f :4 0 86e
:4 0 914 90 :3 0
1a :4 0 874 :2 0
87a 872 0 8
:3 0 51 :3 0 875
876 0 5b :3 0
877 878 0 87a
4be 8c4 5c :3 0
8 :3 0 51 :3 0
87d 87e 0 5b
:3 0 87f 880 0
8ba 38 :3 0 39
:3 0 882 883 0
38 :3 0 49 :3 0
885 886 0 5d
:2 0 2 :4 0 a7
:2 0 4b :2 0 15
:2 0 4c1 88b 88d
:3 0 4c4 887 88f
884 891 890 :2 0
3b :3 0 4c :3 0
893 894 0 3d
:4 0 a8 :4 0 40
:2 0 41 :3 0 4c8
898 89a :3 0 40
:2 0 60 :4 0 4cb
89c 89e :3 0 40
:2 0 61 :4 0 4ce
8a0 8a2 :3 0 40
:2 0 5b :3 0 4d1
8a4 8a6 :3 0 40
:2 0 62 :4 0 4d4
8a8 8aa :3 0 40
:2 0 63 :3 0 64
:3 0 15 :2 0 65
:2 0 4d7 8ad 8b1
4db 8ac 8b3 :3 0
4de 895 8b5 :2 0
8b7 4e1 8b8 892
8b7 0 8b9 4e3
0 8ba 4e5 8bd
:3 0 8bd 0 8bd
8bc 8ba 8bb :6 0
8bf 2a :3 0 4e8
8c1 4ea 8c0 8bf
:2 0 8c2 4ec :2 0
8c4 0 8c4 8c3
87a 8c2 :6 0 914
1 :3 0 38 :3 0
39 :3 0 8c6 8c7
0 38 :3 0 49
:3 0 8c9 8ca 0
a9 :2 0 2 :4 0
aa :2 0 4b :2 0
15 :2 0 4ee 8cf
8d1 :3 0 4f1 8cb
8d3 8c8 8d5 8d4
:2 0 3b :3 0 4c
:3 0 8d7 8d8 0
3d :4 0 ab :4 0
40 :2 0 41 :3 0
4f5 8dc 8de :3 0
40 :2 0 60 :4 0
4f8 8e0 8e2 :3 0
40 :2 0 ac :4 0
4fb 8e4 8e6 :3 0
40 :2 0 45 :3 0
46 :3 0 8 :3 0
51 :3 0 8eb 8ec
0 4fe 8ea 8ee
47 :4 0 500 8e9
8f1 503 8e8 8f3
:3 0 40 :2 0 ad
:4 0 506 8f5 8f7
:3 0 40 :2 0 43
:4 0 509 8f9 8fb
:3 0 40 :2 0 a
:3 0 50c 8fd 8ff
:3 0 40 :2 0 43
:4 0 50f 901 903
:3 0 512 8d9 905
:2 0 907 515 908
8d6 907 0 909
517 0 914 ae
:3 0 af :3 0 90a
90b 0 8 :3 0
51 :3 0 90d 90e
0 a :3 0 67
:3 0 519 90c 912
:2 0 914 51d 9b5
8 :3 0 b0 :2 0
4 915 916 0
38 :3 0 39 :3 0
918 919 0 38
:3 0 49 :3 0 91b
91c 0 5d :2 0
2 :4 0 b1 :2 0
4b :2 0 15 :2 0
527 921 923 :3 0
52a 91d 925 91a
927 926 :2 0 3b
:3 0 4c :3 0 929
92a 0 3d :4 0
b2 :4 0 40 :2 0
41 :3 0 52e 92e
930 :3 0 531 92b
932 :2 0 94b 3b
:3 0 4c :3 0 934
935 0 3d :4 0
b3 :4 0 40 :2 0
8 :3 0 b4 :3 0
93a 93b 0 534
939 93d :3 0 40
:2 0 ad :4 0 537
93f 941 :3 0 40
:2 0 8 :3 0 b5
:3 0 944 945 0
53a 943 947 :3 0
53d 936 949 :2 0
94b 540 94c 928
94b 0 94d 543
0 95d 4e :3 0
37 :3 0 8 :3 0
b4 :3 0 b6 :3 0
8 :3 0 b5 :3 0
b7 :3 0 58 :4 0
b8 1 :a 0 959
:2 0 95d 94f 957
:2 0 7 :3 0 37
:3 0 95b :2 0 95d
545 95f 549 95e
95d :2 0 9b3 5c
:3 0 8 :3 0 51
:3 0 962 963 0
5b :3 0 964 965
0 9ab 38 :3 0
39 :3 0 967 968
0 38 :3 0 49
:3 0 96a 96b 0
5d :2 0 2 :4 0
b9 :2 0 4b :2 0
15 :2 0 54b 970
972 :3 0 54e 96c
974 969 976 975
:2 0 3b :3 0 4c
:3 0 978 979 0
3d :4 0 ba :4 0
40 :2 0 41 :3 0
552 97d 97f :3 0
555 97a 981 :2 0
99b 3b :3 0 4c
:3 0 983 984 0
3d :4 0 61 :4 0
40 :2 0 5b :3 0
558 988 98a :3 0
40 :2 0 62 :4 0
55b 98c 98e :3 0
40 :2 0 63 :3 0
64 :3 0 15 :2 0
65 :2 0 55e 991
995 562 990 997
:3 0 565 985 999
:2 0 99b 568 99c
977 99b 0 99d
56b 0 9ab 4e
:3 0 37 :3 0 b6
:3 0 8 :3 0 b5
:3 0 b7 :3 0 58
:4 0 bb 1 :a 0
9a7 :2 0 9ab 99f
9a5 :2 0 7 :3 0
37 :3 0 9a9 :2 0
9ab 56d 9ae :3 0
9ae 0 9ae 9ad
9ab 9ac :6 0 9b0
1 :3 0 572 9b2
574 9b1 9b0 :2 0
9b3 576 :2 0 9b5
579 9b5 9b4 914
9b3 :6 0 9b6 :2 0
2 10 9b5 9b9
:3 0 9b8 9b6 9ba
:8 0 
588
4
:3 0 1 3 1
7 2 6 a
1 14 1 12
1 1b 1 19
1 22 1 20
1 29 1 27
1 30 1 2e
1 37 1 35
1 3e 1 3c
1 45 1 43
1 4a 1 50
1 6a 1 7e
1 9e 1 a4
1 b1 1 bd
2 c0 c2 2
c5 c7 2 c9
cb 2 cd cf
2 d1 d3 1
d9 2 db dc
2 d5 de 2
e0 e2 4 b9
bf c4 e4 1
e6 1 e8 2
f2 f4 3 f0
f1 f6 2 ff
101 2 fe 103
1 105 1 107
1 120 1 126
2 128 129 1
131 2 12d 131
1 136 1 138
2 13b 13c 1
140 2 13e 140
4 14a 14b 14c
14d 1 158 1
15e 2 160 161
1 169 2 165
169 1 16e 1
170 2 17a 17f
2 190 192 3
18e 18f 194 2
19d 19f 2 1a1
1a3 2 1a5 1a7
2 1a9 1ab 2
1ad 1af 3 1b4
1b5 1b6 2 1b1
1b8 2 19c 1ba
1 1bc 1 1be
2 187 1bf 1
1c3 1 182 1
1c7 2 1cd 1ce
1 1d2 2 1d0
1d2 1 1dc 2
1db 1dc 1 1e4
1 1ea 2 1ec
1ed 2 1d9 1ee
2 1ff 201 3
1fd 1fe 203 2
20c 20e 2 210
212 2 214 216
2 218 21a 2
21c 21e 3 223
224 225 2 220
227 2 20b 229
1 22b 1 22d
2 1f6 22e 1
232 1 1f1 1
236 1 245 2
244 245 1 24d
1 253 2 255
256 2 242 257
2 268 26a 3
266 267 26c 2
275 277 2 279
27b 2 27d 27f
2 281 283 2
285 287 3 28c
28d 28e 2 289
290 2 274 292
1 294 1 296
2 25f 297 1
29b 1 25a 1
29f 2 239 2a2
1 2a5 1 2ae
2 2ad 2ae 1
2b6 1 2bc 2
2be 2bf 2 2ab
2c0 2 2d1 2d3
3 2cf 2d0 2d5
2 2de 2e0 2
2e2 2e4 2 2e6
2e8 2 2ea 2ec
2 2ee 2f0 3
2f5 2f6 2f7 2
2f2 2f9 2 2dd
2fb 1 2fd 1
2ff 2 2c8 300
1 304 1 2c3
1 308 1 313
2 30f 313 1
31f 2 31e 31f
1 327 1 32d
2 32f 330 2
31c 331 2 342
344 3 340 341
346 2 34f 351
2 353 355 2
357 359 2 35b
35d 2 35f 361
3 366 367 368
2 363 36a 2
34e 36c 1 36e
1 370 2 339
371 1 375 1
334 1 379 3
37f 380 381 1
385 2 383 385
2 38d 392 2
3a3 3a5 3 3a1
3a2 3a7 2 3b0
3b2 2 3b4 3b6
2 3b8 3ba 2
3bc 3be 2 3c0
3c2 3 3c7 3c8
3c9 2 3c4 3cb
2 3af 3cd 1
3cf 1 3d1 2
39a 3d2 1 3d6
1 395 1 3da
1 3dd 2 3e5
3ea 2 3fb 3fd
3 3f9 3fa 3ff
2 408 40a 2
40c 40e 2 410
412 2 414 416
2 418 41a 3
41f 420 421 2
41c 423 2 407
425 1 427 1
429 2 3f2 42a
1 42e 1 3ed
1 432 1 435
2 438 439 1
447 2 446 447
1 44f 1 455
2 457 458 2
444 459 2 46a
46c 3 468 469
46e 2 477 479
2 47b 47d 2
47f 481 2 483
485 2 487 489
3 48e 48f 490
2 48b 492 2
476 494 1 496
1 498 2 461
499 1 49d 1
45c 1 4a1 3
37c 43a 4a4 1
4b1 2 4b0 4b1
1 4b9 1 4bf
2 4c1 4c2 2
4ae 4c3 2 4d4
4d6 3 4d2 4d3
4d8 2 4e1 4e3
2 4e5 4e7 2
4e9 4eb 2 4ed
4ef 2 4f1 4f3
3 4f8 4f9 4fa
2 4f5 4fc 2
4e0 4fe 1 500
1 502 2 4cb
503 1 507 1
4c6 1 50b 1
50e 2 511 512
1 51a 2 519
51a 1 522 1
528 2 52a 52b
2 517 52c 2
53d 53f 3 53b
53c 541 2 54a
54c 2 54e 550
2 552 554 2
556 558 2 55a
55c 3 561 562
563 2 55e 565
2 549 567 1
569 1 56b 2
534 56c 1 570
1 52f 1 574
1 581 2 580
581 1 589 1
58f 2 591 592
2 57e 593 2
5a4 5a6 3 5a2
5a3 5a8 2 5b1
5b3 2 5b5 5b7
2 5b9 5bb 2
5bd 5bf 2 5c1
5c3 3 5c8 5c9
5ca 2 5c5 5cc
2 5b0 5ce 1
5d0 1 5d2 2
59b 5d3 1 5d7
1 596 1 5db
9 14e 162 171
1ca 2a6 30b 513
577 5de 2 5e5
5eb 2 5fc 5fe
3 5fa 5fb 600
2 609 60b 2
60d 60f 2 611
613 2 615 617
2 619 61b 3
620 621 622 2
61d 624 2 608
626 1 628 1
62a 2 5f3 62b
1 62f 1 5ee
1 633 4 145
5e2 636 639 2
63d 63e 1 642
2 640 642 4
64c 64d 64e 64f
1 65a 1 660
2 662 663 1
66b 2 667 66b
1 670 1 672
3 675 676 677
1 67b 2 679
67b 2 683 688
2 699 69b 3
697 698 69d 2
6a6 6a8 2 6aa
6ac 2 6ae 6b0
2 6b2 6b4 2
6b6 6b8 3 6bd
6be 6bf 2 6ba
6c1 2 6a5 6c3
1 6c5 1 6c7
2 690 6c8 1
6cc 1 68b 1
6d0 1 6d3 2
6db 6e0 2 6f1
6f3 3 6ef 6f0
6f5 2 6fe 700
2 702 704 2
706 708 2 70a
70c 2 70e 710
3 715 716 717
2 712 719 2
6fd 71b 1 71d
1 71f 2 6e8
720 1 724 1
6e3 1 728 1
72b 2 72e 72f
1 740 2 73f
740 1 748 1
74e 2 750 751
2 73d 752 2
763 765 3 761
762 767 2 770
772 2 774 776
2 778 77a 2
77c 77e 2 780
782 3 787 788
789 2 784 78b
2 76f 78d 1
78f 1 791 2
75a 792 1 796
1 755 1 79a
1 7b1 2 7b0
7b1 1 7b9 1
7bf 2 7c1 7c2
2 7ae 7c3 2
7d4 7d6 3 7d2
7d3 7d8 2 7e1
7e3 2 7e5 7e7
2 7e9 7eb 2
7ed 7ef 2 7f1
7f3 3 7f8 7f9
7fa 2 7f5 7fc
2 7e0 7fe 1
800 1 802 2
7cb 803 1 807
1 7c6 1 80b
6 650 664 673
730 79d 80e 2
815 81b 2 82c
82e 3 82a 82b
830 2 839 83b
2 83d 83f 2
841 843 2 845
847 2 849 84b
3 850 851 852
2 84d 854 2
838 856 1 858
1 85a 2 823
85b 1 85f 1
81e 1 863 4
647 812 866 869
2 86c 86b 4
117 12a 139 86d
2 873 879 2
88a 88c 3 888
889 88e 2 897
899 2 89b 89d
2 89f 8a1 2
8a3 8a5 2 8a7
8a9 3 8ae 8af
8b0 2 8ab 8b2
2 896 8b4 1
8b6 1 8b8 2
881 8b9 1 8bd
1 87c 1 8c1
2 8ce 8d0 3
8cc 8cd 8d2 2
8db 8dd 2 8df
8e1 2 8e3 8e5
1 8ed 2 8ef
8f0 2 8e7 8f2
2 8f4 8f6 2
8f8 8fa 2 8fc
8fe 2 900 902
2 8da 904 1
906 1 908 3
90f 910 911 9
e9 108 10b 10e
111 870 8c4 909
913 2 920 922
3 91e 91f 924
2 92d 92f 2
92c 931 2 938
93c 2 93e 940
2 942 946 2
937 948 2 933
94a 1 94c 3
94d 958 95c 1
917 2 96f 971
3 96d 96e 973
2 97c 97e 2
97b 980 2 987
989 2 98b 98d
3 992 993 994
2 98f 996 2
986 998 2 982
99a 1 99c 4
966 99d 9a6 9aa
1 9ae 1 961
2 95f 9b2 e
17 1e 25 2c
33 3a 41 48
4e 54 6b 7f
9f a9 
1
4
0 
9b9
0
1
50
2c
11
0 1 1 1 1 5 6 7
6 9 6 b 6 d 6 f
6 11 6 13 6 15 6 17
6 19 6 1b 5 1d 5 1f
20 1f 22 1f 24 1f 26 5
28 1 2a 1 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0

3 1 0
57 1 2
2e 1 0
71 1 3
85 1 4
43 1 0
4a 1 0
35 1 0
50 1 0
27 1 0
12 1 0
3c 1 0
20 1 0
2 0 1
7 1 0
19 1 0
a4 1 0
0

/
SHOW ERRORS FUNCTION SP_TEST_ASSIGN;
ALTER FUNCTION SP_TEST_ASSIGN COMPILE DEBUG;
/*********************************************************************************************************************************************/
Prompt == FUNCTION FC_MIGRATION ==
CREATE OR REPLACE FUNCTION FC_MIGRATION wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
82
2 :e:
1FUNCTION:
1FC_MIGRATION:
1H_PROJECT_ID:
1OUT:
1NOCOPY:
1VARCHAR2:
1RETURN:
1PLS_INTEGER:
1H_LEVEL:
10:
1H_ROLLUP_BITS:
1H_TEMP_SC_STATE:
1CURSOR:
1C01:
1PROJECT_ID:
1LEVEL_ID:
1TMT_WBS:
1TYPE_ID:
1PMO_CNST:
1SC_PROJECT:
1SC_PROPOSAL:
1SC_PROJ_TYPE1:
1SC_PROJ_TYPE2:
1SC_PROJ_TYPE3:
1RANK:
1SELECT PROJECT_ID, LEVEL_ID FROM TMT_WBS:n         WHERE TYPE_ID IN (PMO_CNST+
1.SC_PROJECT,PMO_CNST.SC_PROPOSAL,PMO_CNST.SC_PROJ_TYPE1,PMO_CNST.SC_PROJ_TYPE+
12,PMO_CNST.SC_PROJ_TYPE3):n         ORDER BY RANK DESC:
1C02:
1C03:
1ELEMENT_ID:
1SELECT LEVEL_ID FROM TMT_WBS:n         WHERE TYPE_ID IN (PMO_CNST.SC_PROJECT,+
1PMO_CNST.SC_PROPOSAL,PMO_CNST.SC_PROJ_TYPE1,PMO_CNST.SC_PROJ_TYPE2,PMO_CNST.S+
1C_PROJ_TYPE3) AND ELEMENT_ID = h_project_id:n         ORDER BY RANK DESC:
1C04:
1SELECT /*PROJECT_ID,*/ LEVEL_ID:n         FROM TMT_WBS:n         WHERE TYPE_I+
1D IN (PMO_CNST.SC_PROJECT,PMO_CNST.SC_PROPOSAL,PMO_CNST.SC_PROJ_TYPE1,PMO_CNS+
1T.SC_PROJ_TYPE2,PMO_CNST.SC_PROJ_TYPE3) AND ELEMENT_ID = h_project_id:n      +
1   ORDER BY RANK DESC:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= FC_MIGRATION(:
1':
1);:
1CHECK_TRACE:
11:
137:
1+:
1FPUT:
1               ENTER:: FC_MIGRATION(38) :: cplan.sql(20738) :: :
1IS NULL:
1OPEN:
1LOOP:
1FOUND:
1PMO_DB2M:
1SC_STATE:
1100:
1!=:
1SC_SQL_SUCCESS:
1EXIT:
13269638:
1TASK_ASSIGNMENTS:
1ROLLUP_BITS:
1ACTUAL_START:
1SC_SET_ALL_BITS:
1UPDATE TASK_ASSIGNMENTS SET ROLLUP_BITS = CASE WHEN ACTUAL_START IS NuLL THEN+
1 PMO_CNST.SC_SET_ALL_BITS ELSE h_rollup_bits END:n            WHERE PROJECT_I+
1D = h_project_id:
1TRUE:
1=:
1OTHERS:
1SQLCODE:
116:
172:
1           EXCEPTION:: FC_MIGRATION(73) :: cplan.sql(20773) :: :
1 :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1PMO_FUNC:
1BIT_OR:
1SC_PLANNED_BIT:
1SC_SCHED_BIT:
1PLANNED_FINISH:
1SCHED_FINISH:
1ACTUAL_FINISH:
1FORECAST_FINISH:
1FORECAST_START:
1PLANNED_EFFORT:
1SCHED_EFFORT:
1UPDATE TMT_WBS SET ROLLUP_BITS = PMO_CNST.SC_SET_ALL_BITS, PLANNED_FINISH = N+
1uLL, SCHED_FINISH = NuLL,:n            ACTUAL_FINISH = NuLL,:n            FOR+
1ECAST_FINISH = CASE WHEN FORECAST_START IS NuLL THEN FORECAST_FINISH ELSE NuL+
1L END:n            WHERE PROJECT_ID = h_project_id AND (PLANNED_EFFORT + SCHE+
1D_EFFORT > 0):
194:
1           EXCEPTION:: FC_MIGRATION(95) :: cplan.sql(20795) :: :
1UPDATE TMT_WBS SET ROLLUP_BITS = h_rollup_bits, PLANNED_FINISH = NuLL, SCHED_+
1FINISH = NuLL:n            WHERE PROJECT_ID = h_project_id AND ((PLANNED_EFFO+
1RT + SCHED_EFFORT) = 0):
1112:
1           EXCEPTION:: FC_MIGRATION(113) :: cplan.sql(20813) :: :
1TMT_CRI:
1UPDATE TMT_CRI SET ROLLUP_BITS = PMO_CNST.SC_SET_ALL_BITS, PLANNED_FINISH = N+
1uLL, SCHED_FINISH = NuLL:n            WHERE PROJECT_ID = h_project_id AND TYP+
1E_ID <> 14:
1130:
1           EXCEPTION:: FC_MIGRATION(131) :: cplan.sql(20831) :: :
1COALESCE:
1FC_ROLLUP:
1COMMIT:
1CLOSE:
1150:
1           EXCEPTION:: FC_MIGRATION(151) :: cplan.sql(20851) :: :
1UPDATE TMT_WBS SET ROLLUP_BITS = PMO_CNST.SC_SET_ALL_BITS, ACTUAL_FINISH = Nu+
1LL,:n            FORECAST_FINISH = CASE WHEN FORECAST_START IS NuLL THEN FORE+
1CAST_FINISH ELSE NuLL END:n            WHERE PROJECT_ID = h_project_id AND ((+
1PLANNED_EFFORT + SCHED_EFFORT) = 0):
1185:
1           EXCEPTION:: FC_MIGRATION(186) :: cplan.sql(20886) :: :
1205:
1           EXCEPTION:: FC_MIGRATION(206) :: cplan.sql(20906) :: :
1UPDATE TASK_ASSIGNMENTS SET ROLLUP_BITS = PMO_CNST.SC_SET_ALL_BITS WHERE PROJ+
1ECT_ID = h_project_id:
1240:
1           EXCEPTION:: FC_MIGRATION(241) :: cplan.sql(20941) :: :
1260:
1           EXCEPTION:: FC_MIGRATION(261) :: cplan.sql(20961) :: :
1278:
1           EXCEPTION:: FC_MIGRATION(279) :: cplan.sql(20979) :: :
1296:
1           EXCEPTION:: FC_MIGRATION(297) :: cplan.sql(20997) :: :
1316:
1           EXCEPTION:: FC_MIGRATION(317) :: cplan.sql(21017) :: :
1351:
1           EXCEPTION:: FC_MIGRATION(352) :: cplan.sql(21052) :: :
1371:
1           EXCEPTION:: FC_MIGRATION(372) :: cplan.sql(21072) :: :
1378:
1                EXIT:: FC_MIGRATION(379) :: cplan.sql(21079) :: :
1STATE:: :
0

0
0
7d5
2
0 a0 8d 90 :3 a0 b0 3f b4
:2 a0 2c 6a a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a0 f4 b4
bf c8 :f a0 12a bd b7 11 a4
b1 a0 f4 b4 bf c8 :f a0 12a
bd b7 11 a4 b1 a0 f4 b4
bf c8 :10 a0 12a bd b7 11 a4
b1 a0 f4 b4 bf c8 :10 a0 12a
bd b7 11 a4 b1 :2 a0 6b :2 a0
6b 6e a5 b a 10 :2 a0 6b
6e :2 a0 6b 6e a5 b 6e 7e
a0 b4 2e 6e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c a0 7e b4 2e
5a :2 a0 e9 dd b3 :4 a0 e9 d3
5 :2 a0 f :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c :2 a0
6b a0 7e a0 6b b4 2e 5a
a0 2b b7 19 3c a0 51 d
:8 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :3 a0 6b :2 a0 6b :2 a0 6b a5
b d :e a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :9 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :9 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 51 a5
b 7e 51 b4 2e :3 a0 a5 b
d a0 12a b7 19 3c b7 a0
47 :2 a0 e9 c1 :2 a0 6b a0 d
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 e9 dd
b3 :4 a0 e9 d3 5 :2 a0 f :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c :2 a0 6b a0 7e a0
6b b4 2e 5a a0 2b b7 19
3c :c a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 51 a5 b 7e 51
b4 2e :3 a0 a5 b d a0 12a
b7 19 3c b7 a0 47 :2 a0 e9
c1 :2 a0 6b a0 d b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 :2 a0 e9 dd b3 :3 a0
e9 d3 :2 a0 f :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
:2 a0 6b a0 7e a0 6b b4 2e
5a a0 2b b7 19 3c :3 a0 6b
:2 a0 6b :2 a0 6b a5 b d :6 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:e a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :9 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :9 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 51 a5 b 7e
51 b4 2e :3 a0 a5 b d a0
12a b7 19 3c b7 a0 47 :2 a0
e9 c1 :2 a0 6b a0 d b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 e9 dd b3 :3 a0
e9 d3 :2 a0 f :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
:2 a0 6b a0 7e a0 6b b4 2e
5a a0 2b b7 19 3c :c a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
51 a5 b 7e 51 b4 2e :3 a0
a5 b d a0 12a b7 19 3c
b7 a0 47 :2 a0 e9 c1 :2 a0 6b
a0 d b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
:2 19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :2 a0 6b b4 2e a5 57 b7
19 3c :3 a0 6b 65 b7 a4 b1
11 68 4f 1d 17 b5 
7d5
2
0 3 7 2b 1f 23 27 1e
32 1b 37 3b 3f 43 5f 4b
4f 57 5a 4a 7b 6a 6e 47
76 69 97 86 8a 66 92 85
9e a2 82 b3 b6 ba be c2
c6 ca ce d2 d6 da de e2
e6 ea ee f2 f6 102 107 109
115 119 11b 11f 130 131 134 138
13c 140 144 148 14c 150 154 158
15c 160 164 168 16c 170 174 180
185 187 193 197 199 19d 1ae 1af
1b2 1b6 1ba 1be 1c2 1c6 1ca 1ce
1d2 1d6 1da 1de 1e2 1e6 1ea 1ee
1f2 1f6 202 207 209 215 219 21b
21f 230 231 234 238 23c 240 244
248 24c 250 254 258 25c 260 264
268 26c 270 274 278 284 289 28b
297 29b 29d 2a1 2a5 2a8 2ac 2b0
2b3 2b8 2b9 1 2bb 2c0 2c4 2c8
2cb 2d0 2d4 2d8 2db 2e0 2e1 2e3
2e8 2eb 2ef 2f0 2f5 2fa 2fd 302
303 308 30b 30f 310 315 318 31d
31e 323 326 32b 32c 331 332 337
339 33d 340 344 348 34b 34f 353
356 359 35e 361 364 367 368 36d
36e 1 370 375 379 37d 380 385
38a 38d 391 392 397 398 39d 39f
3a3 3a6 3aa 3ad 3ae 3b3 3b6 3ba
3be 3c3 3c7 3c8 3cc 3d0 3d4 3d8
3dd 3e2 3e6 3ea 3ee 3f3 3f7 3fb
3fe 401 405 407 40b 40f 412 415
419 41b 41f 423 426 42a 42e 431
435 438 43c 43f 440 445 448 44c
452 454 458 45b 45f 462 466 46a
46e 472 476 47a 47e 482 486 492
496 49b 49f 4a2 4a3 4a8 4ac 4b0
4b3 4b6 4ba 4bc 4c0 4c4 4c7 4ca
4ce 4d0 4d4 4d8 4db 4dd 1 4e1
4e5 4e9 4ec 4f0 4f4 4f8 4fc 4ff
503 507 50a 50d 512 515 518 51b
51c 521 522 1 524 529 52d 531
534 539 53e 541 545 546 54b 54e
553 554 559 55c 561 562 567 56a
56e 56f 574 577 57c 57d 582 585
589 58d 590 593 594 596 597 59c
59d 5a2 5a4 5a8 5ab 5ad 5b1 5b3
5bf 5c1 5c3 5c4 5c9 5cd 5cf 5db
5dd 5e1 5e5 5e9 5ec 5f0 5f4 5f7
5fb 5ff 602 603 605 609 60d 611
615 619 61d 621 625 629 62d 631
635 639 63d 641 64d 651 656 65a
65d 65e 663 667 66b 66e 671 675
677 67b 67f 682 685 689 68b 68f
693 696 698 1 69c 6a0 6a4 6a7
6ab 6af 6b3 6b7 6ba 6be 6c2 6c5
6c8 6cd 6d0 6d3 6d6 6d7 6dc 6dd
1 6df 6e4 6e8 6ec 6ef 6f4 6f9
6fc 700 701 706 709 70e 70f 714
717 71c 71d 722 725 729 72a 72f
732 737 738 73d 740 744 748 74b
74e 74f 751 752 757 758 75d 75f
763 766 768 76c 76e 77a 77c 77e
77f 784 788 78a 796 798 79c 7a0
7a4 7a8 7ac 7b0 7b4 7b8 7bc 7c8
7cc 7d1 7d5 7d8 7d9 7de 7e2 7e6
7e9 7ec 7f0 7f2 7f6 7fa 7fd 800
804 806 80a 80e 811 813 1 817
81b 81f 822 826 82a 82e 832 835
839 83d 840 843 848 84b 84e 851
852 857 858 1 85a 85f 863 867
86a 86f 874 877 87b 87c 881 884
889 88a 88f 892 897 898 89d 8a0
8a4 8a5 8aa 8ad 8b2 8b3 8b8 8bb
8bf 8c3 8c6 8c9 8ca 8cc 8cd 8d2
8d3 8d8 8da 8de 8e1 8e3 8e7 8e9
8f5 8f7 8f9 8fa 8ff 903 905 911
913 917 91b 91f 923 927 92b 92f
933 937 943 947 94c 950 953 954
959 95d 961 964 967 96b 96d 971
975 978 97b 97f 981 985 989 98c
98e 1 992 996 99a 99d 9a1 9a5
9a9 9ad 9b0 9b4 9b8 9bb 9be 9c3
9c6 9c9 9cc 9cd 9d2 9d3 1 9d5
9da 9de 9e2 9e5 9ea 9ef 9f2 9f6
9f7 9fc 9ff a04 a05 a0a a0d a12
a13 a18 a1b a1f a20 a25 a28 a2d
a2e a33 a36 a3a a3e a41 a44 a45
a47 a48 a4d a4e a53 a55 a59 a5c
a5e a62 a64 a70 a72 a74 a75 a7a
a7e a80 a8c a8e a92 a96 a99 a9a
a9c a9f aa2 aa3 aa8 aac ab0 ab4
ab5 ab7 abb abf acb acd ad1 ad4
ad6 ada ae1 ae5 ae9 aee af0 af4
af8 afb aff b03 b05 1 b09 b0d
b11 b14 b18 b1c b20 b24 b27 b2b
b2f b32 b35 b3a b3d b40 b43 b44
b49 b4a 1 b4c b51 b55 b59 b5c
b61 b66 b69 b6d b6e b73 b76 b7b
b7c b81 b84 b89 b8a b8f b92 b96
b97 b9c b9f ba4 ba5 baa bad bb1
bb5 bb8 bbb bbc bbe bbf bc4 bc5
bca bcc bd0 bd3 bd5 bd9 bdb be7
be9 beb bec bf1 bf5 bf7 c03 c05
c09 c0d c12 c16 c17 c1b c1f c23
c27 c2c c31 c35 c39 c3d c42 c46
c4a c4d c50 c54 c56 c5a c5e c61
c64 c68 c6a c6e c72 c75 c79 c7d
c80 c84 c87 c8b c8e c8f c94 c97
c9b ca1 ca3 ca7 caa cae cb2 cb6
cba cbe cc2 cc6 cca cce cd2 cd6
cda ce6 cea cef cf3 cf6 cf7 cfc
d00 d04 d07 d0a d0e d10 d14 d18
d1b d1e d22 d24 d28 d2c d2f d31
1 d35 d39 d3d d40 d44 d48 d4c
d50 d53 d57 d5b d5e d61 d66 d69
d6c d6f d70 d75 d76 1 d78 d7d
d81 d85 d88 d8d d92 d95 d99 d9a
d9f da2 da7 da8 dad db0 db5 db6
dbb dbe dc2 dc3 dc8 dcb dd0 dd1
dd6 dd9 ddd de1 de4 de7 de8 dea
deb df0 df1 df6 df8 dfc dff e01
e05 e07 e13 e15 e17 e18 e1d e21
e23 e2f e31 e35 e39 e3c e3d e3f
e42 e45 e46 e4b e4f e53 e57 e58
e5a e5e e62 e6e e70 e74 e77 e79
e7d e84 e88 e8c e91 e93 e97 e9b
e9e ea2 ea6 ea8 1 eac eb0 eb4
eb7 ebb ebf ec3 ec7 eca ece ed2
ed5 ed8 edd ee0 ee3 ee6 ee7 eec
eed 1 eef ef4 ef8 efc eff f04
f09 f0c f10 f11 f16 f19 f1e f1f
f24 f27 f2c f2d f32 f35 f39 f3a
f3f f42 f47 f48 f4d f50 f54 f58
f5b f5e f5f f61 f62 f67 f68 f6d
f6f f73 f76 f78 f7c f7e f8a f8c
f8e f8f f94 f98 f9a fa6 fa8 faa
fae fb2 fb7 fbb fbc fc0 fc4 fc8
fcd fd2 fd6 fda fdf fe3 fe7 fea
fed ff1 ff3 ff7 ffb ffe 1001 1005
1007 100b 100f 1012 1016 101a 101d 1021
1024 1028 102b 102c 1031 1034 1038 103e
1040 1044 1047 104b 104f 1053 1056 105a
105e 1061 1065 1069 106c 106d 106f 1073
1077 107b 107f 1083 1087 108b 1097 109b
10a0 10a4 10a7 10a8 10ad 10b1 10b5 10b8
10bb 10bf 10c1 10c5 10c9 10cc 10cf 10d3
10d5 10d9 10dd 10e0 10e2 1 10e6 10ea
10ee 10f1 10f5 10f9 10fd 1101 1104 1108
110c 110f 1112 1117 111a 111d 1120 1121
1126 1127 1 1129 112e 1132 1136 1139
113e 1143 1146 114a 114b 1150 1153 1158
1159 115e 1161 1166 1167 116c 116f 1173
1174 1179 117c 1181 1182 1187 118a 118e
1192 1195 1198 1199 119b 119c 11a1 11a2
11a7 11a9 11ad 11b0 11b2 11b6 11b8 11c4
11c6 11c8 11c9 11ce 11d2 11d4 11e0 11e2
11e6 11ea 11ee 11f2 11f6 11fa 11fe 1202
1206 120a 120e 1212 1216 121a 1226 122a
122f 1233 1236 1237 123c 1240 1244 1247
124a 124e 1250 1254 1258 125b 125e 1262
1264 1268 126c 126f 1271 1 1275 1279
127d 1280 1284 1288 128c 1290 1293 1297
129b 129e 12a1 12a6 12a9 12ac 12af 12b0
12b5 12b6 1 12b8 12bd 12c1 12c5 12c8
12cd 12d2 12d5 12d9 12da 12df 12e2 12e7
12e8 12ed 12f0 12f5 12f6 12fb 12fe 1302
1303 1308 130b 1310 1311 1316 1319 131d
1321 1324 1327 1328 132a 132b 1330 1331
1336 1338 133c 133f 1341 1345 1347 1353
1355 1357 1358 135d 1361 1363 136f 1371
1375 1379 137d 1381 1385 1389 138d 1391
1395 13a1 13a5 13aa 13ae 13b1 13b2 13b7
13bb 13bf 13c2 13c5 13c9 13cb 13cf 13d3
13d6 13d9 13dd 13df 13e3 13e7 13ea 13ec
1 13f0 13f4 13f8 13fb 13ff 1403 1407
140b 140e 1412 1416 1419 141c 1421 1424
1427 142a 142b 1430 1431 1 1433 1438
143c 1440 1443 1448 144d 1450 1454 1455
145a 145d 1462 1463 1468 146b 1470 1471
1476 1479 147d 147e 1483 1486 148b 148c
1491 1494 1498 149c 149f 14a2 14a3 14a5
14a6 14ab 14ac 14b1 14b3 14b7 14ba 14bc
14c0 14c2 14ce 14d0 14d2 14d3 14d8 14dc
14de 14ea 14ec 14f0 14f4 14f8 14fc 1500
1504 1508 150c 1510 151c 1520 1525 1529
152c 152d 1532 1536 153a 153d 1540 1544
1546 154a 154e 1551 1554 1558 155a 155e
1562 1565 1567 1 156b 156f 1573 1576
157a 157e 1582 1586 1589 158d 1591 1594
1597 159c 159f 15a2 15a5 15a6 15ab 15ac
1 15ae 15b3 15b7 15bb 15be 15c3 15c8
15cb 15cf 15d0 15d5 15d8 15dd 15de 15e3
15e6 15eb 15ec 15f1 15f4 15f8 15f9 15fe
1601 1606 1607 160c 160f 1613 1617 161a
161d 161e 1620 1621 1626 1627 162c 162e
1632 1635 1637 163b 163d 1649 164b 164d
164e 1653 1657 1659 1665 1667 166b 166f
1672 1673 1675 1678 167b 167c 1681 1685
1689 168d 168e 1690 1694 1698 16a4 16a6
16aa 16ad 16af 16b3 16ba 16be 16c2 16c7
16c9 16cd 16d1 16d4 16d8 16dc 16de 1
16e2 16e6 16ea 16ed 16f1 16f5 16f9 16fd
1700 1704 1708 170b 170e 1713 1716 1719
171c 171d 1722 1723 1 1725 172a 172e
1732 1735 173a 173f 1742 1746 1747 174c
174f 1754 1755 175a 175d 1762 1763 1768
176b 176f 1770 1775 1778 177d 177e 1783
1786 178a 178e 1791 1794 1795 1797 1798
179d 179e 17a3 17a5 17a9 17ac 17ae 17b2
17b4 17c0 17c2 17c4 17c5 17ca 17ce 17d0
17dc 17de 17e2 17e6 17eb 17ef 17f0 17f4
17f8 17fc 1801 1806 180a 180e 1813 1817
181b 181e 1821 1825 1827 182b 182f 1832
1835 1839 183b 183f 1843 1846 184a 184e
1851 1855 1858 185c 185f 1860 1865 1868
186c 1872 1874 1878 187b 187f 1883 1887
188b 188f 1893 1897 189b 189f 18a3 18a7
18ab 18b7 18bb 18c0 18c4 18c7 18c8 18cd
18d1 18d5 18d8 18db 18df 18e1 18e5 18e9
18ec 18ef 18f3 18f5 18f9 18fd 1900 1902
1 1906 190a 190e 1911 1915 1919 191d
1921 1924 1928 192c 192f 1932 1937 193a
193d 1940 1941 1946 1947 1 1949 194e
1952 1956 1959 195e 1963 1966 196a 196b
1970 1973 1978 1979 197e 1981 1986 1987
198c 198f 1993 1994 1999 199c 19a1 19a2
19a7 19aa 19ae 19b2 19b5 19b8 19b9 19bb
19bc 19c1 19c2 19c7 19c9 19cd 19d0 19d2
19d6 19d8 19e4 19e6 19e8 19e9 19ee 19f2
19f4 1a00 1a02 1a06 1a0a 1a0d 1a0e 1a10
1a13 1a16 1a17 1a1c 1a20 1a24 1a28 1a29
1a2b 1a2f 1a33 1a3f 1a41 1a45 1a48 1a4a
1a4e 1a55 1a59 1a5d 1a62 1a64 1a68 1a6c
1a6f 1a73 1a77 1a79 1 1a7d 1a81 1a85
1a88 1a8c 1a90 1a94 1a98 1a9b 1a9f 1aa3
1aa6 1aa9 1aae 1ab1 1ab4 1ab7 1ab8 1abd
1abe 1 1ac0 1ac5 1ac9 1acd 1ad0 1ad5
1ada 1add 1ae1 1ae2 1ae7 1aea 1aef 1af0
1af5 1af8 1afd 1afe 1b03 1b06 1b0a 1b0b
1b10 1b13 1b18 1b19 1b1e 1b21 1b25 1b29
1b2c 1b2f 1b30 1b32 1b33 1b38 1b39 1b3e
1b40 1b44 1b47 1b49 1b4d 1b4f 1b5b 1b5d
1b5f 1b60 1b65 1b69 1b6b 1b77 1b79 1b7b
1b7f 1b83 1b86 1b8a 1b8e 1b91 1b95 1b99
1b9c 1b9f 1ba4 1ba7 1baa 1bad 1bae 1bb3
1bb4 1 1bb6 1bbb 1bbf 1bc3 1bc6 1bcb
1bd0 1bd3 1bd7 1bd8 1bdd 1be0 1be5 1be6
1beb 1bee 1bf3 1bf4 1bf9 1bfc 1c00 1c04
1c07 1c08 1c0d 1c0e 1c13 1c15 1c19 1c1c
1c20 1c24 1c28 1c2b 1c2f 1c31 1c35 1c37
1c43 1c47 1c49 1c4a 1c53 
7d5
2
0 1 a 6 16 1a 21 :2 6
1 3 a :2 1 4 :2 c 1b c
:2 4 :2 12 21 12 :2 4 :2 14 23 14
4 7 e 0 :2 7 11 1d 2b
10 1c 25 30 39 45 4e 5c
65 73 7c 13 a :6 7 e 0
:2 7 11 1d 2b 10 1c 25 30
39 45 4e 5c 65 73 7c 13
a :6 7 e 0 :2 7 11 1f 10
1c 25 30 39 45 4e 5c 65
73 7c 8f 9c 13 a :6 7 e
0 :2 7 21 f 10 1c 25 30
39 45 4e 5c 65 73 7c 8f
9c 13 a :6 7 :2 11 23 :2 2d 3a
:2 23 :3 7 :2 d 19 25 :2 2f 43 :2 25
54 5a 5d :2 54 6b 81 8 :2 6b
d 10 :2 6b 1d 20 :2 6b 25 28
:2 6b :2 7 4a :2 4 7 :2 11 23 :2 2d
39 3c 4c 4e 4f :2 4c :2 23 :3 7
:2 d 12 1e 5d 60 :2 1e :2 7 52
:2 4 :4 8 :2 7 c :4 7 10 19 27
:3 a d 11 :2 d :2 16 22 d 17
d :2 16 22 d :4 a e :2 17 23
20 :2 2c :2 20 :3 d 3c :3 a 1b a
14 29 41 5b 64 79 13 20
d 14 10 1c :3 1a 10 :2 19 25
10 21 10 :2 19 25 10 :4 d a
:2 12 10 :2 19 25 10 13 :2 1d 2f
:2 39 45 49 59 5b 5c :2 59 :2 2f
:3 13 :2 19 1e 2a 69 6c :2 2a 79
7c :2 2a 80 83 :2 2a 8f 92 :2 2a
9a 9d :2 2a a9 ac b3 bc bf
:2 ac :2 2a :2 13 5f :2 10 :2 d :4 19 :2 d
a :3 7 a 1b :2 24 2b :2 34 44
:2 4d :2 1b a 14 20 2e 37 48
5f :2 d 29 45 13 20 32 43
d 14 10 1c :3 1a 10 :2 19 25
10 21 10 :2 19 25 10 :4 d a
:2 12 10 :2 19 25 10 13 :2 1d 2f
:2 39 45 49 59 5b 5c :2 59 :2 2f
:3 13 :2 19 1e 2a 69 6c :2 2a 79
7c :2 2a 80 83 :2 2a 8f 92 :2 2a
9a 9d :2 2a a9 ac b3 bc bf
:2 ac :2 2a :2 13 5f :2 10 :2 d :4 19 :2 d
a :3 7 14 20 2e 3d 54 13
20 33 44 d 14 10 1c :3 1a
10 :2 19 25 10 21 10 :2 19 25
10 :4 d a :2 12 10 :2 19 25 10
13 :2 1d 2f :2 39 45 49 59 5c
5d :2 59 :2 2f :3 13 :2 19 1e 2a 6a
6d :2 2a 7a 7d :2 2a 81 84 :2 2a
90 93 :2 2a 9b 9e :2 2a aa ad
b4 bd c0 :2 ad :2 2a :2 13 60 :2 10
:2 d :4 19 :2 d a :3 7 14 20 2e
37 48 5f 13 20 31 d 14
10 1c :3 1a 10 :2 19 25 10 21
10 :2 19 25 10 :4 d a :2 12 10
:2 19 25 10 13 :2 1d 2f :2 39 45
49 59 5c 5d :2 59 :2 2f :3 13 :2 19
1e 2a 6a 6d :2 2a 7a 7d :2 2a
81 84 :2 2a 90 93 :2 2a 9b 9e
:2 2a aa ad b4 bd c0 :2 ad :2 2a
:2 13 60 :2 10 :2 d :4 19 :2 d a :3 7
d 16 1f :2 d 22 24 :2 22 d
20 2a :2 20 :3 d 26 :2 a 7 b
1e a 10 :3 a :2 13 1f a 7
:2 f d :2 16 22 d 10 :2 1a 2c
:2 36 42 46 56 59 5a :2 56 :2 2c
:3 10 :2 16 1b 27 67 6a :2 27 77
7a :2 27 7e 81 :2 27 8d 90 :2 27
98 9b :2 27 a7 aa b1 ba bd
:2 aa :2 27 :2 10 5d :2 d :2 a :4 16 :2 a
7 :3 1e 7 c :4 7 10 19 27
:3 a d 11 :2 d :2 16 22 d 17
d :2 16 22 d :4 a e :2 17 23
20 :2 2c :2 20 :3 d 3c :2 a 14 20
2e 37 48 d 29 45 13 20
33 44 d 14 10 1c :3 1a 10
:2 19 25 10 21 10 :2 19 25 10
:4 d a :2 12 10 :2 19 25 10 13
:2 1d 2f :2 39 45 49 59 5c 5d
:2 59 :2 2f :3 13 :2 19 1e 2a 6a 6d
:2 2a 7a 7d :2 2a 81 84 :2 2a 90
93 :2 2a 9b 9e :2 2a aa ad b4
bd c0 :2 ad :2 2a :2 13 60 :2 10 :2 d
:4 19 :2 d a :3 7 d 16 1f :2 d
22 24 :2 22 d 20 2a :2 20 :3 d
26 :2 a 7 b 1e a 10 :3 a
:2 13 1f a 7 :2 f d :2 16 22
d 10 :2 1a 2c :2 36 42 46 56
59 5a :2 56 :2 2c :3 10 :2 16 1b 27
67 6a :2 27 77 7a :2 27 7e 81
:2 27 8d 90 :2 27 98 9b :2 27 a7
aa b1 ba bd :2 aa :2 27 :2 10 5d
:2 d :2 a :4 16 :2 a 7 :4 1e 7 c
:4 7 10 19 :2 a d 11 :2 d :2 16
22 d 17 d :2 16 22 d :4 a
e :2 17 23 20 :2 2c :2 20 :3 d 3c
:3 a 1b :2 24 2b :2 34 44 :2 4d :2 1b
a 14 29 37 40 56 63 d
14 10 1c :3 1a 10 :2 19 25 10
21 10 :2 19 25 10 :4 d a :2 12
10 :2 19 25 10 13 :2 1d 2f :2 39
45 49 59 5c 5d :2 59 :2 2f :3 13
:2 19 1e 2a 6a 6d :2 2a 7a 7d
:2 2a 81 84 :2 2a 90 93 :2 2a 9b
9e :2 2a aa ad b4 bd c0 :2 ad
:2 2a :2 13 60 :2 10 :2 d :4 19 :2 d a
:3 7 14 20 2e 37 48 5f :2 d
29 45 13 20 32 43 d 14
10 1c :3 1a 10 :2 19 25 10 21
10 :2 19 25 10 :4 d a :2 12 10
:2 19 25 10 13 :2 1d 2f :2 39 45
49 59 5c 5d :2 59 :2 2f :3 13 :2 19
1e 2a 6a 6d :2 2a 7a 7d :2 2a
81 84 :2 2a 90 93 :2 2a 9b 9e
:2 2a aa ad b4 bd c0 :2 ad :2 2a
:2 13 60 :2 10 :2 d :4 19 :2 d a :3 7
14 20 2e 3d 54 13 20 33
44 d 14 10 1c :3 1a 10 :2 19
25 10 21 10 :2 19 25 10 :4 d
a :2 12 10 :2 19 25 10 13 :2 1d
2f :2 39 45 49 59 5c 5d :2 59
:2 2f :3 13 :2 19 1e 2a 6a 6d :2 2a
7a 7d :2 2a 81 84 :2 2a 90 93
:2 2a 9b 9e :2 2a aa ad b4 bd
c0 :2 ad :2 2a :2 13 60 :2 10 :2 d :4 19
:2 d a :3 7 14 20 2e 37 48
5f 13 20 31 d 14 10 1c
:3 1a 10 :2 19 25 10 21 10 :2 19
25 10 :4 d a :2 12 10 :2 19 25
10 13 :2 1d 2f :2 39 45 49 59
5c 5d :2 59 :2 2f :3 13 :2 19 1e 2a
6a 6d :2 2a 7a 7d :2 2a 81 84
:2 2a 90 93 :2 2a 9b 9e :2 2a aa
ad b4 bd c0 :2 ad :2 2a :2 13 60
:2 10 :2 d :4 19 :2 d a :3 7 d 16
1f :2 d 22 24 :2 22 d 20 2a
:2 20 :3 d 26 :2 a 7 b 4 a
10 :3 a :2 13 1f a 7 :2 f d
:2 16 22 d 10 :2 1a 2c :2 36 42
46 56 59 5a :2 56 :2 2c :3 10 :2 16
1b 27 67 6a :2 27 77 7a :2 27
7e 81 :2 27 8d 90 :2 27 98 9b
:2 27 a7 aa b1 ba bd :2 aa :2 27
:2 10 5d :2 d :2 a :4 16 :2 a 7 :3 4
7 c :4 7 10 19 :2 a d 11
:2 d :2 16 22 d 17 d :2 16 22
d :4 a e :2 17 23 20 :2 2c :2 20
:3 d 3c :2 a 14 20 2e 37 48
d 29 45 13 20 33 44 d
14 10 1c :3 1a 10 :2 19 25 10
21 10 :2 19 25 10 :4 d a :2 12
10 :2 19 25 10 13 :2 1d 2f :2 39
45 49 59 5c 5d :2 59 :2 2f :3 13
:2 19 1e 2a 6a 6d :2 2a 7a 7d
:2 2a 81 84 :2 2a 90 93 :2 2a 9b
9e :2 2a aa ad b4 bd c0 :2 ad
:2 2a :2 13 60 :2 10 :2 d :4 19 :2 d a
:3 7 d 16 1f :2 d 22 24 :2 22
d 20 2a :2 20 :3 d 26 :2 a 7
b 4 a 10 :3 a :2 13 1f a
7 :2 f d :2 16 22 d 10 :2 1a
2c :2 36 42 46 56 59 5a :2 56
:2 2c :3 10 :2 16 1b 27 67 6a :2 27
77 7a :2 27 7e 81 :2 27 8d 90
:2 27 98 9b :2 27 a7 aa b1 ba
bd :2 aa :2 27 :2 10 5d :2 d :2 a :4 16
:2 a 7 :7 4 7 :2 11 23 :2 2d 39
3c 4c 4f 50 :2 4c :2 23 :3 7 :2 d
12 1e 5e 61 :2 1e 6e 71 :2 1e
75 78 :2 1e 82 85 :2 8e :2 1e :2 7
53 :3 4 b :2 14 4 :9 1 
7d5
4
0 :2 1 :6 3 2
:2 4 :2 1 :6 6 :6 7
:6 8 :2 a 0 :2 a
:3 b :b c d b
:5 a :2 f 0 :2 f
:3 10 :b 11 12 10
:5 f :2 14 0 :2 14
:2 15 :d 16 17 15
:5 14 :2 19 0 :2 19
1a 1b :d 1c 1d
1a :5 19 :b 20 :11 21
22 :2 21 :2 22 :2 21
:2 22 :2 21 :2 22 :4 21
:3 20 :11 25 :b 26 :3 25
:5 29 :5 2c 2e :6 2f
:3 30 :5 31 30 :5 33
32 :3 30 :a 35 :2 36
:3 35 :3 39 :6 3d :2 3e
3d :6 3f :5 40 3f
:5 42 41 :3 3f 3c
:2 45 :5 47 :11 48 :24 49
:3 48 :2 46 :6 45 44
:3 2e :d 4e :6 51 52
:3 53 :4 54 51 :6 55
:5 56 55 :5 58 57
:3 55 50 :2 5b :5 5d
:11 5e :24 5f :3 5e :2 5c
:6 5b 5a :3 2e :5 65
:4 66 65 :6 67 :5 68
67 :5 6a 69 :3 67
64 :2 6d :5 6f :11 70
:24 71 :3 70 :2 6e :6 6d
6c :3 2e :6 77 :3 78
77 :6 79 :5 7a 79
:5 7c 7b :3 79 76
:2 7f :5 81 :11 82 :24 83
:3 82 :2 80 :6 7f 7e
:3 2e :9 88 :6 89 :2 8b
:3 88 2e 8d 29
:4 90 :5 91 8f :2 93
:5 95 :11 96 :24 97 :3 96
:2 94 :6 93 92 :3 29
:5 9e a0 :6 a1 :3 a2
:5 a3 a2 :5 a5 a4
:3 a2 :a a8 :2 a9 :3 a8
:5 ad :3 ae :4 af ad
:6 b0 :5 b1 b0 :5 b3
b2 :3 b0 ac :2 b6
:5 b8 :11 b9 :24 ba :3 b9
:2 b7 :6 b6 b5 :3 a0
:9 bf :6 c0 :2 c2 :3 bf
a0 c4 29 :4 c7
:5 c8 c6 :2 ca :5 cc
:11 cd :24 ce :3 cd :2 cb
:6 ca c9 :4 29 :5 d5
d7 :4 d8 :3 d9 :5 da
d9 :5 dc db :3 d9
:a df :2 e0 :3 df :d e3
:7 e6 :6 e7 :5 e8 e7
:5 ea e9 :3 e7 e5
:2 ed :5 ef :11 f0 :24 f1
:3 f0 :2 ee :6 ed ec
:3 d7 :6 f7 f8 :3 f9
:4 fa f7 :6 fb :5 fc
fb :5 fe fd :3 fb
f6 :2 101 :5 103 :11 104
:24 105 :3 104 :2 102 :6 101
100 :3 d7 :5 10b :4 10c
10b :6 10d :5 10e 10d
:5 110 10f :3 10d 10a
:2 113 :5 115 :11 116 :24 117
:3 116 :2 114 :6 113 112
:3 d7 :6 11d :3 11e 11d
:6 11f :5 120 11f :5 122
121 :3 11f 11c :2 125
:5 127 :11 128 :24 129 :3 128
:2 126 :6 125 124 :3 d7
:9 12e :6 12f :2 131 :3 12e
d7 133 d2 :4 136
:5 137 135 :2 139 :5 13b
:11 13c :24 13d :3 13c :2 13a
:6 139 138 :3 d2 :5 144
146 :4 147 :3 148 :5 149
148 :5 14b 14a :3 148
:a 14e :2 14f :3 14e :5 153
:3 154 :4 155 153 :6 156
:5 157 156 :5 159 158
:3 156 152 :2 15c :5 15e
:11 15f :24 160 :3 15f :2 15d
:6 15c 15b :3 146 :9 165
:6 166 :2 168 :3 165 146
16a d2 :4 16d :5 16e
16c :2 170 :5 172 :11 173
:24 174 :3 173 :2 171 :6 170
16f :4 d2 :3 29 :11 17a
:19 17b :3 17a :5 17d :2 1f
:7 1 
1c55
4
:3 0 1 :3 0 2
:a 0 7d0 1 :7 0
5 :2 0 3 4
:3 0 5 :3 0 6
:3 0 3 :5 0 1
7 6 :3 0 7
:3 0 8 :3 0 9
b 0 7d0 2
c :2 0 a :2 0
7 8 :3 0 f
:7 0 a :2 0 13
10 11 7ce 0
9 :6 0 a :2 0
9 8 :3 0 15
:7 0 19 16 17
7ce 0 b :9 0
b 8 :3 0 1b
:7 0 1f 1c 1d
7ce 0 c :6 0
d :3 0 e :a 0
2 35 :4 0 21
24 0 22 :3 0
f :3 0 10 :3 0
11 :3 0 12 :3 0
13 :3 0 14 :3 0
13 :3 0 15 :3 0
13 :3 0 16 :3 0
13 :3 0 17 :3 0
13 :3 0 18 :3 0
19 :4 0 1a 1
:8 0 36 21 24
37 0 7ce d
37 39 36 38
:6 0 35 :7 0 37
d :3 0 1b :a 0
3 4f :5 0 3b
3e 0 3c :3 0
f :3 0 10 :3 0
11 :3 0 12 :3 0
13 :3 0 14 :3 0
13 :3 0 15 :3 0
13 :3 0 16 :3 0
13 :3 0 17 :3 0
13 :3 0 18 :3 0
19 :4 0 1a 1
:8 0 50 3b 3e
51 0 7ce f
51 53 50 52
:6 0 4f :7 0 51
d :3 0 1c :a 0
4 6a :5 0 55
58 0 56 :3 0
10 :3 0 11 :3 0
12 :3 0 13 :3 0
14 :3 0 13 :3 0
15 :3 0 13 :3 0
16 :3 0 13 :3 0
17 :3 0 13 :3 0
18 :3 0 1d :3 0
3 :3 0 19 :4 0
1e 1 :8 0 6b
55 58 6c 0
7ce 11 6c 6e
6b 6d :6 0 6a
:7 0 6c d :3 0
1f :a 0 5 85
:5 0 70 73 0
71 :3 0 10 :3 0
11 :3 0 12 :3 0
13 :3 0 14 :3 0
13 :3 0 15 :3 0
13 :3 0 16 :3 0
13 :3 0 17 :3 0
13 :3 0 18 :3 0
1d :3 0 3 :3 0
19 :4 0 20 1
:8 0 86 70 73
87 0 7ce 13
87 89 86 88
:6 0 85 :7 0 87
21 :3 0 22 :3 0
8a 8b 0 21
:3 0 23 :3 0 8d
8e 0 2 :4 0
15 8f 91 8c
93 92 :2 0 24
:3 0 25 :3 0 95
96 0 26 :4 0
21 :3 0 27 :3 0
99 9a 0 2
:4 0 17 9b 9d
28 :4 0 29 :2 0
2a :3 0 19 a0
a2 :3 0 2b :4 0
29 :2 0 2c :4 0
1c a5 a7 :3 0
29 :2 0 3 :3 0
1f a9 ab :3 0
29 :2 0 2c :4 0
22 ad af :3 0
29 :2 0 2d :4 0
25 b1 b3 :3 0
28 97 b5 :2 0
b7 2d b8 94
b7 0 b9 2f
0 7cc 21 :3 0
22 :3 0 ba bb
0 21 :3 0 2e
:3 0 bd be 0
2f :2 0 2 :4 0
30 :2 0 31 :2 0
2f :2 0 31 c3
c5 :3 0 34 bf
c7 bc c9 c8
:2 0 24 :3 0 32
:3 0 cb cc 0
26 :4 0 33 :4 0
29 :2 0 2a :3 0
38 d0 d2 :3 0
3b cd d4 :2 0
d6 3e d7 ca
d6 0 d8 40
0 7cc 3 :3 0
34 :2 0 42 da
db :3 0 dc :2 0
35 :3 0 e :4 0
e1 :2 0 43e df
e2 :3 0 36 :3 0
e :3 0 3 :3 0
9 :4 0 e8 :2 0
2df e4 e9 :3 0
44 :3 0 e :3 0
37 :3 0 ea eb
:3 0 38 :3 0 39
:3 0 ed ee 0
a :2 0 ef f0
0 f2 47 f9
38 :3 0 39 :3 0
f3 f4 0 3a
:2 0 f5 f6 0
f8 49 fa ec
f2 0 fb 0
f8 0 fb 4b
0 2df 38 :3 0
39 :3 0 fc fd
0 38 :3 0 3b
:2 0 3c :3 0 ff
101 0 50 100
103 :3 0 104 :2 0
3d :8 0 108 53
109 105 108 0
10a 55 0 2df
b :3 0 3e :2 0
10b 10c 0 2df
3f :3 0 40 :3 0
41 :3 0 13 :3 0
42 :3 0 b :3 0
f :3 0 3 :4 0
43 1 :8 0 12c
37 :4 0 117 :3 0
44 :3 0 45 :2 0
59 11a 11b :3 0
38 :3 0 39 :3 0
11d 11e 0 a
:2 0 11f 120 0
122 5c 129 38
:3 0 39 :3 0 123
124 0 3a :2 0
125 126 0 128
5e 12a 11c 122
0 12b 0 128
0 12b 60 0
12c 63 176 46
:3 0 38 :3 0 39
:3 0 12f 130 0
47 :3 0 131 132
0 16c 21 :3 0
22 :3 0 134 135
0 21 :3 0 2e
:3 0 137 138 0
48 :2 0 2 :4 0
49 :2 0 31 :2 0
2f :2 0 66 13d
13f :3 0 69 139
141 136 143 142
:2 0 24 :3 0 32
:3 0 145 146 0
26 :4 0 4a :4 0
29 :2 0 2a :3 0
6d 14a 14c :3 0
29 :2 0 4b :4 0
70 14e 150 :3 0
29 :2 0 4c :4 0
73 152 154 :3 0
29 :2 0 47 :3 0
76 156 158 :3 0
29 :2 0 4d :4 0
79 15a 15c :3 0
29 :2 0 4e :3 0
4f :3 0 2f :2 0
50 :2 0 7c 15f
163 80 15e 165
:3 0 83 147 167
:2 0 169 86 16a
144 169 0 16b
88 0 16c 8a
16f :3 0 16f 0
16f 16e 16c 16d
:6 0 171 7 :3 0
8d 173 8f 172
171 :2 0 174 91
:2 0 176 0 176
175 12c 174 :6 0
2df 6 :3 0 b
:3 0 51 :3 0 52
:3 0 179 17a 0
13 :3 0 53 :3 0
17c 17d 0 13
:3 0 54 :3 0 17f
180 0 93 17b
182 178 183 0
2df 11 :3 0 40
:3 0 13 :3 0 42
:3 0 55 :3 0 56
:3 0 57 :3 0 58
:3 0 59 :3 0 58
:3 0 f :3 0 3
:3 0 5a :3 0 5b
:4 0 5c 1 :8 0
1a9 37 :4 0 194
:3 0 44 :3 0 45
:2 0 98 197 198
:3 0 38 :3 0 39
:3 0 19a 19b 0
a :2 0 19c 19d
0 19f 9b 1a6
38 :3 0 39 :3 0
1a0 1a1 0 3a
:2 0 1a2 1a3 0
1a5 9d 1a7 199
19f 0 1a8 0
1a5 0 1a8 9f
0 1a9 a2 1f3
46 :3 0 38 :3 0
39 :3 0 1ac 1ad
0 47 :3 0 1ae
1af 0 1e9 21
:3 0 22 :3 0 1b1
1b2 0 21 :3 0
2e :3 0 1b4 1b5
0 48 :2 0 2
:4 0 5d :2 0 31
:2 0 2f :2 0 a5
1ba 1bc :3 0 a8
1b6 1be 1b3 1c0
1bf :2 0 24 :3 0
32 :3 0 1c2 1c3
0 26 :4 0 5e
:4 0 29 :2 0 2a
:3 0 ac 1c7 1c9
:3 0 29 :2 0 4b
:4 0 af 1cb 1cd
:3 0 29 :2 0 4c
:4 0 b2 1cf 1d1
:3 0 29 :2 0 47
:3 0 b5 1d3 1d5
:3 0 29 :2 0 4d
:4 0 b8 1d7 1d9
:3 0 29 :2 0 4e
:3 0 4f :3 0 2f
:2 0 50 :2 0 bb
1dc 1e0 bf 1db
1e2 :3 0 c2 1c4
1e4 :2 0 1e6 c5
1e7 1c1 1e6 0
1e8 c7 0 1e9
c9 1ec :3 0 1ec
0 1ec 1eb 1e9
1ea :6 0 1ee 9
:3 0 cc 1f0 ce
1ef 1ee :2 0 1f1
d0 :2 0 1f3 0
1f3 1f2 1a9 1f1
:6 0 2df 6 :3 0
11 :3 0 40 :3 0
b :3 0 55 :3 0
56 :3 0 f :3 0
3 :3 0 5a :3 0
5b :4 0 5f 1
:8 0 214 37 :4 0
1ff :3 0 44 :3 0
45 :2 0 d4 202
203 :3 0 38 :3 0
39 :3 0 205 206
0 a :2 0 207
208 0 20a d7
211 38 :3 0 39
:3 0 20b 20c 0
3a :2 0 20d 20e
0 210 d9 212
204 20a 0 213
0 210 0 213
db 0 214 de
25e 46 :3 0 38
:3 0 39 :3 0 217
218 0 47 :3 0
219 21a 0 254
21 :3 0 22 :3 0
21c 21d 0 21
:3 0 2e :3 0 21f
220 0 48 :2 0
2 :4 0 60 :2 0
31 :2 0 2f :2 0
e1 225 227 :3 0
e4 221 229 21e
22b 22a :2 0 24
:3 0 32 :3 0 22d
22e 0 26 :4 0
61 :4 0 29 :2 0
2a :3 0 e8 232
234 :3 0 29 :2 0
4b :4 0 eb 236
238 :3 0 29 :2 0
4c :4 0 ee 23a
23c :3 0 29 :2 0
47 :3 0 f1 23e
240 :3 0 29 :2 0
4d :4 0 f4 242
244 :3 0 29 :2 0
4e :3 0 4f :3 0
2f :2 0 50 :2 0
f7 247 24b fb
246 24d :3 0 fe
22f 24f :2 0 251
101 252 22c 251
0 253 103 0
254 105 257 :3 0
257 0 257 256
254 255 :6 0 259
b :3 0 108 25b
10a 25a 259 :2 0
25c 10c :2 0 25e
0 25e 25d 214
25c :6 0 2df 6
:3 0 62 :3 0 40
:3 0 13 :3 0 42
:3 0 55 :3 0 56
:3 0 f :3 0 3
:3 0 12 :4 0 63
1 :8 0 27f 37
:4 0 26a :3 0 44
:3 0 45 :2 0 110
26d 26e :3 0 38
:3 0 39 :3 0 270
271 0 a :2 0
272 273 0 275
113 27c 38 :3 0
39 :3 0 276 277
0 3a :2 0 278
279 0 27b 115
27d 26f 275 0
27e 0 27b 0
27e 117 0 27f
11a 2c9 46 :3 0
38 :3 0 39 :3 0
282 283 0 47
:3 0 284 285 0
2bf 21 :3 0 22
:3 0 287 288 0
21 :3 0 2e :3 0
28a 28b 0 48
:2 0 2 :4 0 64
:2 0 31 :2 0 2f
:2 0 11d 290 292
:3 0 120 28c 294
289 296 295 :2 0
24 :3 0 32 :3 0
298 299 0 26
:4 0 65 :4 0 29
:2 0 2a :3 0 124
29d 29f :3 0 29
:2 0 4b :4 0 127
2a1 2a3 :3 0 29
:2 0 4c :4 0 12a
2a5 2a7 :3 0 29
:2 0 47 :3 0 12d
2a9 2ab :3 0 29
:2 0 4d :4 0 130
2ad 2af :3 0 29
:2 0 4e :3 0 4f
:3 0 2f :2 0 50
:2 0 133 2b2 2b6
137 2b1 2b8 :3 0
13a 29a 2ba :2 0
2bc 13d 2bd 297
2bc 0 2be 13f
0 2bf 141 2c2
:3 0 2c2 0 2c2
2c1 2bf 2c0 :6 0
2c4 d :3 0 144
2c6 146 2c5 2c4
:2 0 2c7 148 :2 0
2c9 0 2c9 2c8
27f 2c7 :6 0 2df
6 :3 0 66 :3 0
9 :3 0 a :2 0
14a 2cb 2ce 45
:2 0 a :2 0 14f
2d0 2d2 :3 0 c
:3 0 67 :3 0 3
:3 0 152 2d5 2d7
2d4 2d8 0 2dc
68 :4 0 68 1
:8 0 2dc 154 2dd
2d3 2dc 0 2de
157 0 2df 159
2e1 36 :4 0 2df
:4 0 43e 69 :3 0
e :4 0 2e5 :2 0
2eb 2e3 0 38
:3 0 39 :3 0 2e6
2e7 0 47 :3 0
2e8 2e9 0 2eb
164 335 46 :3 0
38 :3 0 39 :3 0
2ee 2ef 0 47
:3 0 2f0 2f1 0
32b 21 :3 0 22
:3 0 2f3 2f4 0
21 :3 0 2e :3 0
2f6 2f7 0 48
:2 0 2 :4 0 6a
:2 0 31 :2 0 2f
:2 0 167 2fc 2fe
:3 0 16a 2f8 300
2f5 302 301 :2 0
24 :3 0 32 :3 0
304 305 0 26
:4 0 6b :4 0 29
:2 0 2a :3 0 16e
309 30b :3 0 29
:2 0 4b :4 0 171
30d 30f :3 0 29
:2 0 4c :4 0 174
311 313 :3 0 29
:2 0 47 :3 0 177
315 317 :3 0 29
:2 0 4d :4 0 17a
319 31b :3 0 29
:2 0 4e :3 0 4f
:3 0 2f :2 0 50
:2 0 17d 31e 322
181 31d 324 :3 0
184 306 326 :2 0
328 187 329 303
328 0 32a 189
0 32b 18b 32e
:3 0 32e 0 32e
32d 32b 32c :6 0
330 f :3 0 18e
332 190 331 330
:2 0 333 192 :2 0
335 0 335 334
2eb 333 :6 0 43e
1 :3 0 35 :3 0
1b :4 0 33a :2 0
43e 338 33b :3 0
36 :3 0 1b :3 0
3 :3 0 9 :4 0
341 :2 0 3e6 33d
342 :3 0 194 :3 0
1b :3 0 37 :3 0
343 344 :3 0 38
:3 0 39 :3 0 346
347 0 a :2 0
348 349 0 34b
197 352 38 :3 0
39 :3 0 34c 34d
0 3a :2 0 34e
34f 0 351 199
353 345 34b 0
354 0 351 0
354 19b 0 3e6
38 :3 0 39 :3 0
355 356 0 38
:3 0 3b :2 0 3c
:3 0 358 35a 0
1a0 359 35c :3 0
35d :2 0 3d :8 0
361 1a3 362 35e
361 0 363 1a5
0 3e6 11 :3 0
40 :3 0 13 :3 0
42 :3 0 57 :3 0
58 :3 0 59 :3 0
58 :3 0 f :3 0
3 :3 0 5a :3 0
5b :4 0 6c 1
:8 0 386 37 :4 0
371 :3 0 44 :3 0
45 :2 0 1a9 374
375 :3 0 38 :3 0
39 :3 0 377 378
0 a :2 0 379
37a 0 37c 1ac
383 38 :3 0 39
:3 0 37d 37e 0
3a :2 0 37f 380
0 382 1ae 384
376 37c 0 385
0 382 0 385
1b0 0 386 1b3
3d0 46 :3 0 38
:3 0 39 :3 0 389
38a 0 47 :3 0
38b 38c 0 3c6
21 :3 0 22 :3 0
38e 38f 0 21
:3 0 2e :3 0 391
392 0 48 :2 0
2 :4 0 6d :2 0
31 :2 0 2f :2 0
1b6 397 399 :3 0
1b9 393 39b 390
39d 39c :2 0 24
:3 0 32 :3 0 39f
3a0 0 26 :4 0
6e :4 0 29 :2 0
2a :3 0 1bd 3a4
3a6 :3 0 29 :2 0
4b :4 0 1c0 3a8
3aa :3 0 29 :2 0
4c :4 0 1c3 3ac
3ae :3 0 29 :2 0
47 :3 0 1c6 3b0
3b2 :3 0 29 :2 0
4d :4 0 1c9 3b4
3b6 :3 0 29 :2 0
4e :3 0 4f :3 0
2f :2 0 50 :2 0
1cc 3b9 3bd 1d0
3b8 3bf :3 0 1d3
3a1 3c1 :2 0 3c3
1d6 3c4 39e 3c3
0 3c5 1d8 0
3c6 1da 3c9 :3 0
3c9 0 3c9 3c8
3c6 3c7 :6 0 3cb
12 :3 0 1dd 3cd
1df 3cc 3cb :2 0
3ce 1e1 :2 0 3d0
0 3d0 3cf 386
3ce :6 0 3e6 11
:3 0 66 :3 0 9
:3 0 a :2 0 1e3
3d2 3d5 45 :2 0
a :2 0 1e8 3d7
3d9 :3 0 c :3 0
67 :3 0 3 :3 0
1eb 3dc 3de 3db
3df 0 3e3 68
:4 0 68 1 :8 0
3e3 1ed 3e4 3da
3e3 0 3e5 1f0
0 3e6 1f2 3e8
36 :4 0 3e6 :4 0
43e 69 :3 0 1b
:4 0 3ec :2 0 3f2
3ea 0 38 :3 0
39 :3 0 3ed 3ee
0 47 :3 0 3ef
3f0 0 3f2 1f8
43c 46 :3 0 38
:3 0 39 :3 0 3f5
3f6 0 47 :3 0
3f7 3f8 0 432
21 :3 0 22 :3 0
3fa 3fb 0 21
:3 0 2e :3 0 3fd
3fe 0 48 :2 0
2 :4 0 6f :2 0
31 :2 0 2f :2 0
1fb 403 405 :3 0
1fe 3ff 407 3fc
409 408 :2 0 24
:3 0 32 :3 0 40b
40c 0 26 :4 0
70 :4 0 29 :2 0
2a :3 0 202 410
412 :3 0 29 :2 0
4b :4 0 205 414
416 :3 0 29 :2 0
4c :4 0 208 418
41a :3 0 29 :2 0
47 :3 0 20b 41c
41e :3 0 29 :2 0
4d :4 0 20e 420
422 :3 0 29 :2 0
4e :3 0 4f :3 0
2f :2 0 50 :2 0
211 425 429 215
424 42b :3 0 218
40d 42d :2 0 42f
21b 430 40a 42f
0 431 21d 0
432 21f 435 :3 0
435 0 435 434
432 433 :6 0 437
14 :3 0 222 439
224 438 437 :2 0
43a 226 :2 0 43c
0 43c 43b 3f2
43a :6 0 43e 1
:3 0 228 797 35
:3 0 1c :4 0 442
:2 0 796 440 443
:3 0 36 :3 0 1c
:3 0 9 :4 0 448
:2 0 639 445 446
:3 0 1c :3 0 37
:3 0 449 44a :3 0
38 :3 0 39 :3 0
44c 44d 0 a
:2 0 44e 44f 0
451 22f 458 38
:3 0 39 :3 0 452
453 0 3a :2 0
454 455 0 457
231 459 44b 451
0 45a 0 457
0 45a 233 0
639 38 :3 0 39
:3 0 45b 45c 0
38 :3 0 3b :2 0
3c :3 0 45e 460
0 238 45f 462
:3 0 463 :2 0 3d
:8 0 467 23b 468
464 467 0 469
23d 0 639 b
:3 0 51 :3 0 52
:3 0 46b 46c 0
13 :3 0 53 :3 0
46e 46f 0 13
:3 0 54 :3 0 471
472 0 23f 46d
474 46a 475 0
639 3f :3 0 40
:3 0 13 :3 0 42
:3 0 f :3 0 3
:4 0 71 1 :8 0
493 37 :4 0 47e
:3 0 44 :3 0 45
:2 0 244 481 482
:3 0 38 :3 0 39
:3 0 484 485 0
a :2 0 486 487
0 489 247 490
38 :3 0 39 :3 0
48a 48b 0 3a
:2 0 48c 48d 0
48f 249 491 483
489 0 492 0
48f 0 492 24b
0 493 24e 4dd
46 :3 0 38 :3 0
39 :3 0 496 497
0 47 :3 0 498
499 0 4d3 21
:3 0 22 :3 0 49b
49c 0 21 :3 0
2e :3 0 49e 49f
0 48 :2 0 2
:4 0 72 :2 0 31
:2 0 2f :2 0 251
4a4 4a6 :3 0 254
4a0 4a8 49d 4aa
4a9 :2 0 24 :3 0
32 :3 0 4ac 4ad
0 26 :4 0 73
:4 0 29 :2 0 2a
:3 0 258 4b1 4b3
:3 0 29 :2 0 4b
:4 0 25b 4b5 4b7
:3 0 29 :2 0 4c
:4 0 25e 4b9 4bb
:3 0 29 :2 0 47
:3 0 261 4bd 4bf
:3 0 29 :2 0 4d
:4 0 264 4c1 4c3
:3 0 29 :2 0 4e
:3 0 4f :3 0 2f
:2 0 50 :2 0 267
4c6 4ca 26b 4c5
4cc :3 0 26e 4ae
4ce :2 0 4d0 271
4d1 4ab 4d0 0
4d2 273 0 4d3
275 4d6 :3 0 4d6
0 4d6 4d5 4d3
4d4 :6 0 4d8 17
:3 0 278 4da 27a
4d9 4d8 :2 0 4db
27c :2 0 4dd 0
4dd 4dc 493 4db
:6 0 639 16 :3 0
11 :3 0 40 :3 0
13 :3 0 42 :3 0
55 :3 0 56 :3 0
57 :3 0 58 :3 0
59 :3 0 58 :3 0
f :3 0 3 :3 0
5a :3 0 5b :4 0
5c 1 :8 0 503
37 :4 0 4ee :3 0
44 :3 0 45 :2 0
280 4f1 4f2 :3 0
38 :3 0 39 :3 0
4f4 4f5 0 a
:2 0 4f6 4f7 0
4f9 283 500 38
:3 0 39 :3 0 4fa
4fb 0 3a :2 0
4fc 4fd 0 4ff
285 501 4f3 4f9
0 502 0 4ff
0 502 287 0
503 28a 54d 46
:3 0 38 :3 0 39
:3 0 506 507 0
47 :3 0 508 509
0 543 21 :3 0
22 :3 0 50b 50c
0 21 :3 0 2e
:3 0 50e 50f 0
48 :2 0 2 :4 0
74 :2 0 31 :2 0
2f :2 0 28d 514
516 :3 0 290 510
518 50d 51a 519
:2 0 24 :3 0 32
:3 0 51c 51d 0
26 :4 0 75 :4 0
29 :2 0 2a :3 0
294 521 523 :3 0
29 :2 0 4b :4 0
297 525 527 :3 0
29 :2 0 4c :4 0
29a 529 52b :3 0
29 :2 0 47 :3 0
29d 52d 52f :3 0
29 :2 0 4d :4 0
2a0 531 533 :3 0
29 :2 0 4e :3 0
4f :3 0 2f :2 0
50 :2 0 2a3 536
53a 2a7 535 53c
:3 0 2aa 51e 53e
:2 0 540 2ad 541
51b 540 0 542
2af 0 543 2b1
546 :3 0 546 0
546 545 543 544
:6 0 548 19 :3 0
2b4 54a 2b6 549
548 :2 0 54b 2b8
:2 0 54d 0 54d
54c 503 54b :6 0
639 16 :3 0 11
:3 0 40 :3 0 b
:3 0 55 :3 0 56
:3 0 f :3 0 3
:3 0 5a :3 0 5b
:4 0 5f 1 :8 0
56e 37 :4 0 559
:3 0 44 :3 0 45
:2 0 2bc 55c 55d
:3 0 38 :3 0 39
:3 0 55f 560 0
a :2 0 561 562
0 564 2bf 56b
38 :3 0 39 :3 0
565 566 0 3a
:2 0 567 568 0
56a 2c1 56c 55e
564 0 56d 0
56a 0 56d 2c3
0 56e 2c6 5b8
46 :3 0 38 :3 0
39 :3 0 571 572
0 47 :3 0 573
574 0 5ae 21
:3 0 22 :3 0 576
577 0 21 :3 0
2e :3 0 579 57a
0 48 :2 0 2
:4 0 76 :2 0 31
:2 0 2f :2 0 2c9
57f 581 :3 0 2cc
57b 583 578 585
584 :2 0 24 :3 0
32 :3 0 587 588
0 26 :4 0 77
:4 0 29 :2 0 2a
:3 0 2d0 58c 58e
:3 0 29 :2 0 4b
:4 0 2d3 590 592
:3 0 29 :2 0 4c
:4 0 2d6 594 596
:3 0 29 :2 0 47
:3 0 2d9 598 59a
:3 0 29 :2 0 4d
:4 0 2dc 59c 59e
:3 0 29 :2 0 4e
:3 0 4f :3 0 2f
:2 0 50 :2 0 2df
5a1 5a5 2e3 5a0
5a7 :3 0 2e6 589
5a9 :2 0 5ab 2e9
5ac 586 5ab 0
5ad 2eb 0 5ae
2ed 5b1 :3 0 5b1
0 5b1 5b0 5ae
5af :6 0 5b3 1b
:3 0 2f0 5b5 2f2
5b4 5b3 :2 0 5b6
2f4 :2 0 5b8 0
5b8 5b7 56e 5b6
:6 0 639 16 :3 0
62 :3 0 40 :3 0
13 :3 0 42 :3 0
55 :3 0 56 :3 0
f :3 0 3 :3 0
12 :4 0 63 1
:8 0 5d9 37 :4 0
5c4 :3 0 44 :3 0
45 :2 0 2f8 5c7
5c8 :3 0 38 :3 0
39 :3 0 5ca 5cb
0 a :2 0 5cc
5cd 0 5cf 2fb
5d6 38 :3 0 39
:3 0 5d0 5d1 0
3a :2 0 5d2 5d3
0 5d5 2fd 5d7
5c9 5cf 0 5d8
0 5d5 0 5d8
2ff 0 5d9 302
623 46 :3 0 38
:3 0 39 :3 0 5dc
5dd 0 47 :3 0
5de 5df 0 619
21 :3 0 22 :3 0
5e1 5e2 0 21
:3 0 2e :3 0 5e4
5e5 0 48 :2 0
2 :4 0 78 :2 0
31 :2 0 2f :2 0
305 5ea 5ec :3 0
308 5e6 5ee 5e3
5f0 5ef :2 0 24
:3 0 32 :3 0 5f2
5f3 0 26 :4 0
79 :4 0 29 :2 0
2a :3 0 30c 5f7
5f9 :3 0 29 :2 0
4b :4 0 30f 5fb
5fd :3 0 29 :2 0
4c :4 0 312 5ff
601 :3 0 29 :2 0
47 :3 0 315 603
605 :3 0 29 :2 0
4d :4 0 318 607
609 :3 0 29 :2 0
4e :3 0 4f :3 0
2f :2 0 50 :2 0
31b 60c 610 31f
60b 612 :3 0 322
5f4 614 :2 0 616
325 617 5f1 616
0 618 327 0
619 329 61c :3 0
61c 0 61c 61b
619 61a :6 0 61e
1d :3 0 32c 620
32e 61f 61e :2 0
621 330 :2 0 623
0 623 622 5d9
621 :6 0 639 16
:3 0 66 :3 0 9
:3 0 a :2 0 332
625 628 45 :2 0
a :2 0 337 62a
62c :3 0 c :3 0
67 :3 0 3 :3 0
33a 62f 631 62e
632 0 636 68
:4 0 68 1 :8 0
636 33c 637 62d
636 0 638 33f
0 639 341 63b
36 :4 0 639 :4 0
796 69 :3 0 1c
:4 0 63f :2 0 645
63d 0 38 :3 0
39 :3 0 640 641
0 47 :3 0 642
643 0 645 34b
68f 46 :3 0 38
:3 0 39 :3 0 648
649 0 47 :3 0
64a 64b 0 685
21 :3 0 22 :3 0
64d 64e 0 21
:3 0 2e :3 0 650
651 0 48 :2 0
2 :4 0 7a :2 0
31 :2 0 2f :2 0
34e 656 658 :3 0
351 652 65a 64f
65c 65b :2 0 24
:3 0 32 :3 0 65e
65f 0 26 :4 0
7b :4 0 29 :2 0
2a :3 0 355 663
665 :3 0 29 :2 0
4b :4 0 358 667
669 :3 0 29 :2 0
4c :4 0 35b 66b
66d :3 0 29 :2 0
47 :3 0 35e 66f
671 :3 0 29 :2 0
4d :4 0 361 673
675 :3 0 29 :2 0
4e :3 0 4f :3 0
2f :2 0 50 :2 0
364 678 67c 368
677 67e :3 0 36b
660 680 :2 0 682
36e 683 65d 682
0 684 370 0
685 372 688 :3 0
688 0 688 687
685 686 :6 0 68a
1f :3 0 375 68c
377 68b 68a :2 0
68d 379 :2 0 68f
0 68f 68e 645
68d :6 0 796 1
:3 0 35 :3 0 1f
:4 0 694 :2 0 796
692 695 :3 0 36
:3 0 1f :3 0 9
:4 0 69a :2 0 73e
697 698 :3 0 1f
:3 0 37 :3 0 69b
69c :3 0 38 :3 0
39 :3 0 69e 69f
0 a :2 0 6a0
6a1 0 6a3 37b
6aa 38 :3 0 39
:3 0 6a4 6a5 0
3a :2 0 6a6 6a7
0 6a9 37d 6ab
69d 6a3 0 6ac
0 6a9 0 6ac
37f 0 73e 38
:3 0 39 :3 0 6ad
6ae 0 38 :3 0
3b :2 0 3c :3 0
6b0 6b2 0 384
6b1 6b4 :3 0 6b5
:2 0 3d :8 0 6b9
387 6ba 6b6 6b9
0 6bb 389 0
73e 11 :3 0 40
:3 0 13 :3 0 42
:3 0 57 :3 0 58
:3 0 59 :3 0 58
:3 0 f :3 0 3
:3 0 5a :3 0 5b
:4 0 6c 1 :8 0
6de 37 :4 0 6c9
:3 0 44 :3 0 45
:2 0 38d 6cc 6cd
:3 0 38 :3 0 39
:3 0 6cf 6d0 0
a :2 0 6d1 6d2
0 6d4 390 6db
38 :3 0 39 :3 0
6d5 6d6 0 3a
:2 0 6d7 6d8 0
6da 392 6dc 6ce
6d4 0 6dd 0
6da 0 6dd 394
0 6de 397 728
46 :3 0 38 :3 0
39 :3 0 6e1 6e2
0 47 :3 0 6e3
6e4 0 71e 21
:3 0 22 :3 0 6e6
6e7 0 21 :3 0
2e :3 0 6e9 6ea
0 48 :2 0 2
:4 0 7c :2 0 31
:2 0 2f :2 0 39a
6ef 6f1 :3 0 39d
6eb 6f3 6e8 6f5
6f4 :2 0 24 :3 0
32 :3 0 6f7 6f8
0 26 :4 0 7d
:4 0 29 :2 0 2a
:3 0 3a1 6fc 6fe
:3 0 29 :2 0 4b
:4 0 3a4 700 702
:3 0 29 :2 0 4c
:4 0 3a7 704 706
:3 0 29 :2 0 47
:3 0 3aa 708 70a
:3 0 29 :2 0 4d
:4 0 3ad 70c 70e
:3 0 29 :2 0 4e
:3 0 4f :3 0 2f
:2 0 50 :2 0 3b0
711 715 3b4 710
717 :3 0 3b7 6f9
719 :2 0 71b 3ba
71c 6f6 71b 0
71d 3bc 0 71e
3be 721 :3 0 721
0 721 720 71e
71f :6 0 723 22
:3 0 3c1 725 3c3
724 723 :2 0 726
3c5 :2 0 728 0
728 727 6de 726
:6 0 73e 21 :3 0
66 :3 0 9 :3 0
a :2 0 3c7 72a
72d 45 :2 0 a
:2 0 3cc 72f 731
:3 0 c :3 0 67
:3 0 3 :3 0 3cf
734 736 733 737
0 73b 68 :4 0
68 1 :8 0 73b
3d1 73c 732 73b
0 73d 3d4 0
73e 3d6 740 36
:4 0 73e :4 0 796
69 :3 0 1f :4 0
744 :2 0 74a 742
0 38 :3 0 39
:3 0 745 746 0
47 :3 0 747 748
0 74a 3dc 794
46 :3 0 38 :3 0
39 :3 0 74d 74e
0 47 :3 0 74f
750 0 78a 21
:3 0 22 :3 0 752
753 0 21 :3 0
2e :3 0 755 756
0 48 :2 0 2
:4 0 7e :2 0 31
:2 0 2f :2 0 3df
75b 75d :3 0 3e2
757 75f 754 761
760 :2 0 24 :3 0
32 :3 0 763 764
0 26 :4 0 7f
:4 0 29 :2 0 2a
:3 0 3e6 768 76a
:3 0 29 :2 0 4b
:4 0 3e9 76c 76e
:3 0 29 :2 0 4c
:4 0 3ec 770 772
:3 0 29 :2 0 47
:3 0 3ef 774 776
:3 0 29 :2 0 4d
:4 0 3f2 778 77a
:3 0 29 :2 0 4e
:3 0 4f :3 0 2f
:2 0 50 :2 0 3f5
77d 781 3f9 77c
783 :3 0 3fc 765
785 :2 0 787 3ff
788 762 787 0
789 401 0 78a
403 78d :3 0 78d
0 78d 78c 78a
78b :6 0 78f 24
:3 0 406 791 408
790 78f :2 0 792
40a :2 0 794 0
794 793 74a 792
:6 0 796 1 :3 0
40c 798 dd 43e
0 799 0 796
0 799 413 0
7cc 21 :3 0 22
:3 0 79a 79b 0
21 :3 0 2e :3 0
79d 79e 0 2f
:2 0 2 :4 0 80
:2 0 31 :2 0 2f
:2 0 416 7a3 7a5
:3 0 419 79f 7a7
79c 7a9 7a8 :2 0
24 :3 0 32 :3 0
7ab 7ac 0 26
:4 0 81 :4 0 29
:2 0 2a :3 0 41d
7b0 7b2 :3 0 29
:2 0 4b :4 0 420
7b4 7b6 :3 0 29
:2 0 82 :4 0 423
7b8 7ba :3 0 29
:2 0 38 :3 0 39
:3 0 7bd 7be 0
426 7bc 7c0 :3 0
429 7ad 7c2 :2 0
7c4 42c 7c5 7aa
7c4 0 7c6 42e
0 7cc 7 :3 0
38 :3 0 39 :3 0
7c8 7c9 0 7ca
:2 0 7cc 430 7cf
:3 0 7cf 436 7cf
7ce 7cc 7cd :6 0
7d0 :2 0 2 c
7cf 7d3 :3 0 7d2
7d0 7d4 :8 0 
43e
4
:3 0 1 3 1
8 1 e 1
14 1 1a 1
34 1 4e 1
69 1 84 1
90 1 9c 2
9f a1 2 a4
a6 2 a8 aa
2 ac ae 2
b0 b2 4 98
9e a3 b4 1
b6 1 b8 2
c2 c4 3 c0
c1 c6 2 cf
d1 2 ce d3
1 d5 1 d7
1 d9 2 e5
e6 1 f1 1
f7 2 f9 fa
1 102 2 fe
102 1 107 1
109 1 119 2
118 119 1 121
1 127 2 129
12a 2 116 12b
2 13c 13e 3
13a 13b 140 2
149 14b 2 14d
14f 2 151 153
2 155 157 2
159 15b 3 160
161 162 2 15d
164 2 148 166
1 168 1 16a
2 133 16b 1
16f 1 12e 1
173 2 17e 181
1 196 2 195
196 1 19e 1
1a4 2 1a6 1a7
2 193 1a8 2
1b9 1bb 3 1b7
1b8 1bd 2 1c6
1c8 2 1ca 1cc
2 1ce 1d0 2
1d2 1d4 2 1d6
1d8 3 1dd 1de
1df 2 1da 1e1
2 1c5 1e3 1
1e5 1 1e7 2
1b0 1e8 1 1ec
1 1ab 1 1f0
1 201 2 200
201 1 209 1
20f 2 211 212
2 1fe 213 2
224 226 3 222
223 228 2 231
233 2 235 237
2 239 23b 2
23d 23f 2 241
243 3 248 249
24a 2 245 24c
2 230 24e 1
250 1 252 2
21b 253 1 257
1 216 1 25b
1 26c 2 26b
26c 1 274 1
27a 2 27c 27d
2 269 27e 2
28f 291 3 28d
28e 293 2 29c
29e 2 2a0 2a2
2 2a4 2a6 2
2a8 2aa 2 2ac
2ae 3 2b3 2b4
2b5 2 2b0 2b7
2 29b 2b9 1
2bb 1 2bd 2
286 2be 1 2c2
1 281 1 2c6
2 2cc 2cd 1
2d1 2 2cf 2d1
1 2d6 2 2d9
2db 1 2dd a
e7 fb 10a 10d
176 184 1f3 25e
2c9 2de 2 2e4
2ea 2 2fb 2fd
3 2f9 2fa 2ff
2 308 30a 2
30c 30e 2 310
312 2 314 316
2 318 31a 3
31f 320 321 2
31c 323 2 307
325 1 327 1
329 2 2f2 32a
1 32e 1 2ed
1 332 2 33e
33f 1 34a 1
350 2 352 353
1 35b 2 357
35b 1 360 1
362 1 373 2
372 373 1 37b
1 381 2 383
384 2 370 385
2 396 398 3
394 395 39a 2
3a3 3a5 2 3a7
3a9 2 3ab 3ad
2 3af 3b1 2
3b3 3b5 3 3ba
3bb 3bc 2 3b7
3be 2 3a2 3c0
1 3c2 1 3c4
2 38d 3c5 1
3c9 1 388 1
3cd 2 3d3 3d4
1 3d8 2 3d6
3d8 1 3dd 2
3e0 3e2 1 3e4
5 340 354 363
3d0 3e5 2 3eb
3f1 2 402 404
3 400 401 406
2 40f 411 2
413 415 2 417
419 2 41b 41d
2 41f 421 3
426 427 428 2
423 42a 2 40e
42c 1 42e 1
430 2 3f9 431
1 435 1 3f4
1 439 6 e0
2e1 335 339 3e8
43c 1 450 1
456 2 458 459
1 461 2 45d
461 1 466 1
468 2 470 473
1 480 2 47f
480 1 488 1
48e 2 490 491
2 47d 492 2
4a3 4a5 3 4a1
4a2 4a7 2 4b0
4b2 2 4b4 4b6
2 4b8 4ba 2
4bc 4be 2 4c0
4c2 3 4c7 4c8
4c9 2 4c4 4cb
2 4af 4cd 1
4cf 1 4d1 2
49a 4d2 1 4d6
1 495 1 4da
1 4f0 2 4ef
4f0 1 4f8 1
4fe 2 500 501
2 4ed 502 2
513 515 3 511
512 517 2 520
522 2 524 526
2 528 52a 2
52c 52e 2 530
532 3 537 538
539 2 534 53b
2 51f 53d 1
53f 1 541 2
50a 542 1 546
1 505 1 54a
1 55b 2 55a
55b 1 563 1
569 2 56b 56c
2 558 56d 2
57e 580 3 57c
57d 582 2 58b
58d 2 58f 591
2 593 595 2
597 599 2 59b
59d 3 5a2 5a3
5a4 2 59f 5a6
2 58a 5a8 1
5aa 1 5ac 2
575 5ad 1 5b1
1 570 1 5b5
1 5c6 2 5c5
5c6 1 5ce 1
5d4 2 5d6 5d7
2 5c3 5d8 2
5e9 5eb 3 5e7
5e8 5ed 2 5f6
5f8 2 5fa 5fc
2 5fe 600 2
602 604 2 606
608 3 60d 60e
60f 2 60a 611
2 5f5 613 1
615 1 617 2
5e0 618 1 61c
1 5db 1 620
2 626 627 1
62b 2 629 62b
1 630 2 633
635 1 637 9
447 45a 469 476
4dd 54d 5b8 623
638 2 63e 644
2 655 657 3
653 654 659 2
662 664 2 666
668 2 66a 66c
2 66e 670 2
672 674 3 679
67a 67b 2 676
67d 2 661 67f
1 681 1 683
2 64c 684 1
688 1 647 1
68c 1 6a2 1
6a8 2 6aa 6ab
1 6b3 2 6af
6b3 1 6b8 1
6ba 1 6cb 2
6ca 6cb 1 6d3
1 6d9 2 6db
6dc 2 6c8 6dd
2 6ee 6f0 3
6ec 6ed 6f2 2
6fb 6fd 2 6ff
701 2 703 705
2 707 709 2
70b 70d 3 712
713 714 2 70f
716 2 6fa 718
1 71a 1 71c
2 6e5 71d 1
721 1 6e0 1
725 2 72b 72c
1 730 2 72e
730 1 735 2
738 73a 1 73c
5 699 6ac 6bb
728 73d 2 743
749 2 75a 75c
3 758 759 75e
2 767 769 2
76b 76d 2 76f
771 2 773 775
2 777 779 3
77e 77f 780 2
77b 782 2 766
784 1 786 1
788 2 751 789
1 78d 1 74c
1 791 6 441
63b 68f 693 740
794 2 797 798
2 7a2 7a4 3
7a0 7a1 7a6 2
7af 7b1 2 7b3
7b5 2 7b7 7b9
2 7bb 7bf 2
7ae 7c1 1 7c3
1 7c5 5 b9
d8 799 7c6 7cb
7 12 18 1e
35 4f 6a 85

1
4
0 
7d3
0
1
28
25
9
0 1 1 1 1 1 6 7
6 9 6 b 6 d 1 f
1 11 12 1 14 1 16 17
16 19 16 1b 16 1d 1 1f
1 21 22 1 24 0 0 0

21 1 2
3b 1 3
55 1 4
70 1 5
1a 1 0
14 1 0
2 0 1
e 1 0
3 1 0
0

/
SHOW ERRORS FUNCTION FC_MIGRATION;
ALTER FUNCTION FC_MIGRATION COMPILE DEBUG;
